/* >>>>>>>>>> BEGIN javascript.js */
/* >>>>>>>>>> BEGIN source/jquery-1.11.1.js */
/*!
 * jQuery JavaScript Library v1.11.1
 * http://jquery.com/
 *
 * Includes Sizzle.js
 * http://sizzlejs.com/
 *
 * Copyright 2005, 2014 jQuery Foundation, Inc. and other contributors
 * Released under the MIT license
 * http://jquery.org/license
 *
 * Date: 2014-05-01T17:42Z
 */

(function( global, factory ) {

	if ( typeof module === "object" && typeof module.exports === "object" ) {
		// For CommonJS and CommonJS-like environments where a proper window is present,
		// execute the factory and get jQuery
		// For environments that do not inherently posses a window with a document
		// (such as Node.js), expose a jQuery-making factory as module.exports
		// This accentuates the need for the creation of a real window
		//
		// See ticket #14549 for more info
		module.exports = global.document ?
			factory( global, true ) :
			function( w ) {
				if ( !w.document ) {
					throw new Error( "jQuery requires a window with a document" );
				}
				return factory( w );
			};
	} else {
		factory( global );
	}

// Pass this if window is not defined yet
}(typeof window !== "undefined" ? window : this, function( window, noGlobal ) {

// Can't do this because several apps including ASP.NET trace
// the stack via arguments.caller.callee and Firefox dies if
// you try to trace through "use strict" call chains. (#13335)
// Support: Firefox 18+
//

var deletedIds = [];

var slice = deletedIds.slice;

var concat = deletedIds.concat;

var push = deletedIds.push;

var indexOf = deletedIds.indexOf;

var class2type = {};

var toString = class2type.toString;

var hasOwn = class2type.hasOwnProperty;

var support = {};



var
	version = "1.11.1",

	// Define a local copy of jQuery
	jQuery = function( selector, context ) {
		// The jQuery object is actually just the init constructor 'enhanced'
		// Need init if jQuery is called (just allow error to be thrown if not included)
		return new jQuery.fn.init( selector, context );
	},

	// Support: Android<4.1, IE<9
	// Make sure we trim BOM and NBSP
	rtrim = /^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,

	// Matches dashed string for camelizing
	rmsPrefix = /^-ms-/,
	rdashAlpha = /-([\da-z])/gi,

	// Used by jQuery.camelCase as callback to replace()
	fcamelCase = function( all, letter ) {
		return letter.toUpperCase();
	};

jQuery.fn = jQuery.prototype = {
	// The current version of jQuery being used
	jquery: version,

	constructor: jQuery,

	// Start with an empty selector
	selector: "",

	// The default length of a jQuery object is 0
	length: 0,

	toArray: function() {
		return slice.call( this );
	},

	// Get the Nth element in the matched element set OR
	// Get the whole matched element set as a clean array
	get: function( num ) {
		return num != null ?

			// Return just the one element from the set
			( num < 0 ? this[ num + this.length ] : this[ num ] ) :

			// Return all the elements in a clean array
			slice.call( this );
	},

	// Take an array of elements and push it onto the stack
	// (returning the new matched element set)
	pushStack: function( elems ) {

		// Build a new jQuery matched element set
		var ret = jQuery.merge( this.constructor(), elems );

		// Add the old object onto the stack (as a reference)
		ret.prevObject = this;
		ret.context = this.context;

		// Return the newly-formed element set
		return ret;
	},

	// Execute a callback for every element in the matched set.
	// (You can seed the arguments with an array of args, but this is
	// only used internally.)
	each: function( callback, args ) {
		return jQuery.each( this, callback, args );
	},

	map: function( callback ) {
		return this.pushStack( jQuery.map(this, function( elem, i ) {
			return callback.call( elem, i, elem );
		}));
	},

	slice: function() {
		return this.pushStack( slice.apply( this, arguments ) );
	},

	first: function() {
		return this.eq( 0 );
	},

	last: function() {
		return this.eq( -1 );
	},

	eq: function( i ) {
		var len = this.length,
			j = +i + ( i < 0 ? len : 0 );
		return this.pushStack( j >= 0 && j < len ? [ this[j] ] : [] );
	},

	end: function() {
		return this.prevObject || this.constructor(null);
	},

	// For internal use only.
	// Behaves like an Array's method, not like a jQuery method.
	push: push,
	sort: deletedIds.sort,
	splice: deletedIds.splice
};

jQuery.extend = jQuery.fn.extend = function() {
	var src, copyIsArray, copy, name, options, clone,
		target = arguments[0] || {},
		i = 1,
		length = arguments.length,
		deep = false;

	// Handle a deep copy situation
	if ( typeof target === "boolean" ) {
		deep = target;

		// skip the boolean and the target
		target = arguments[ i ] || {};
		i++;
	}

	// Handle case when target is a string or something (possible in deep copy)
	if ( typeof target !== "object" && !jQuery.isFunction(target) ) {
		target = {};
	}

	// extend jQuery itself if only one argument is passed
	if ( i === length ) {
		target = this;
		i--;
	}

	for ( ; i < length; i++ ) {
		// Only deal with non-null/undefined values
		if ( (options = arguments[ i ]) != null ) {
			// Extend the base object
			for ( name in options ) {
				src = target[ name ];
				copy = options[ name ];

				// Prevent never-ending loop
				if ( target === copy ) {
					continue;
				}

				// Recurse if we're merging plain objects or arrays
				if ( deep && copy && ( jQuery.isPlainObject(copy) || (copyIsArray = jQuery.isArray(copy)) ) ) {
					if ( copyIsArray ) {
						copyIsArray = false;
						clone = src && jQuery.isArray(src) ? src : [];

					} else {
						clone = src && jQuery.isPlainObject(src) ? src : {};
					}

					// Never move original objects, clone them
					target[ name ] = jQuery.extend( deep, clone, copy );

				// Don't bring in undefined values
				} else if ( copy !== undefined ) {
					target[ name ] = copy;
				}
			}
		}
	}

	// Return the modified object
	return target;
};

jQuery.extend({
	// Unique for each copy of jQuery on the page
	expando: "jQuery" + ( version + Math.random() ).replace( /\D/g, "" ),

	// Assume jQuery is ready without the ready module
	isReady: true,

	error: function( msg ) {
		throw new Error( msg );
	},

	noop: function() {},

	// See test/unit/core.js for details concerning isFunction.
	// Since version 1.3, DOM methods and functions like alert
	// aren't supported. They return false on IE (#2968).
	isFunction: function( obj ) {
		return jQuery.type(obj) === "function";
	},

	isArray: Array.isArray || function( obj ) {
		return jQuery.type(obj) === "array";
	},

	isWindow: function( obj ) {
		/* jshint eqeqeq: false */
		return obj != null && obj == obj.window;
	},

	isNumeric: function( obj ) {
		// parseFloat NaNs numeric-cast false positives (null|true|false|"")
		// ...but misinterprets leading-number strings, particularly hex literals ("0x...")
		// subtraction forces infinities to NaN
		return !jQuery.isArray( obj ) && obj - parseFloat( obj ) >= 0;
	},

	isEmptyObject: function( obj ) {
		var name;
		for ( name in obj ) {
			return false;
		}
		return true;
	},

	isPlainObject: function( obj ) {
		var key;

		// Must be an Object.
		// Because of IE, we also have to check the presence of the constructor property.
		// Make sure that DOM nodes and window objects don't pass through, as well
		if ( !obj || jQuery.type(obj) !== "object" || obj.nodeType || jQuery.isWindow( obj ) ) {
			return false;
		}

		try {
			// Not own constructor property must be Object
			if ( obj.constructor &&
				!hasOwn.call(obj, "constructor") &&
				!hasOwn.call(obj.constructor.prototype, "isPrototypeOf") ) {
				return false;
			}
		} catch ( e ) {
			// IE8,9 Will throw exceptions on certain host objects #9897
			return false;
		}

		// Support: IE<9
		// Handle iteration over inherited properties before own properties.
		if ( support.ownLast ) {
			for ( key in obj ) {
				return hasOwn.call( obj, key );
			}
		}

		// Own properties are enumerated firstly, so to speed up,
		// if last one is own, then all properties are own.
		for ( key in obj ) {}

		return key === undefined || hasOwn.call( obj, key );
	},

	type: function( obj ) {
		if ( obj == null ) {
			return obj + "";
		}
		return typeof obj === "object" || typeof obj === "function" ?
			class2type[ toString.call(obj) ] || "object" :
			typeof obj;
	},

	// Evaluates a script in a global context
	// Workarounds based on findings by Jim Driscoll
	// http://weblogs.java.net/blog/driscoll/archive/2009/09/08/eval-javascript-global-context
	globalEval: function( data ) {
		if ( data && jQuery.trim( data ) ) {
			// We use execScript on Internet Explorer
			// We use an anonymous function so that context is window
			// rather than jQuery in Firefox
			( window.execScript || function( data ) {
				window[ "eval" ].call( window, data );
			} )( data );
		}
	},

	// Convert dashed to camelCase; used by the css and data modules
	// Microsoft forgot to hump their vendor prefix (#9572)
	camelCase: function( string ) {
		return string.replace( rmsPrefix, "ms-" ).replace( rdashAlpha, fcamelCase );
	},

	nodeName: function( elem, name ) {
		return elem.nodeName && elem.nodeName.toLowerCase() === name.toLowerCase();
	},

	// args is for internal usage only
	each: function( obj, callback, args ) {
		var value,
			i = 0,
			length = obj.length,
			isArray = isArraylike( obj );

		if ( args ) {
			if ( isArray ) {
				for ( ; i < length; i++ ) {
					value = callback.apply( obj[ i ], args );

					if ( value === false ) {
						break;
					}
				}
			} else {
				for ( i in obj ) {
					value = callback.apply( obj[ i ], args );

					if ( value === false ) {
						break;
					}
				}
			}

		// A special, fast, case for the most common use of each
		} else {
			if ( isArray ) {
				for ( ; i < length; i++ ) {
					value = callback.call( obj[ i ], i, obj[ i ] );

					if ( value === false ) {
						break;
					}
				}
			} else {
				for ( i in obj ) {
					value = callback.call( obj[ i ], i, obj[ i ] );

					if ( value === false ) {
						break;
					}
				}
			}
		}

		return obj;
	},

	// Support: Android<4.1, IE<9
	trim: function( text ) {
		return text == null ?
			"" :
			( text + "" ).replace( rtrim, "" );
	},

	// results is for internal usage only
	makeArray: function( arr, results ) {
		var ret = results || [];

		if ( arr != null ) {
			if ( isArraylike( Object(arr) ) ) {
				jQuery.merge( ret,
					typeof arr === "string" ?
					[ arr ] : arr
				);
			} else {
				push.call( ret, arr );
			}
		}

		return ret;
	},

	inArray: function( elem, arr, i ) {
		var len;

		if ( arr ) {
			if ( indexOf ) {
				return indexOf.call( arr, elem, i );
			}

			len = arr.length;
			i = i ? i < 0 ? Math.max( 0, len + i ) : i : 0;

			for ( ; i < len; i++ ) {
				// Skip accessing in sparse arrays
				if ( i in arr && arr[ i ] === elem ) {
					return i;
				}
			}
		}

		return -1;
	},

	merge: function( first, second ) {
		var len = +second.length,
			j = 0,
			i = first.length;

		while ( j < len ) {
			first[ i++ ] = second[ j++ ];
		}

		// Support: IE<9
		// Workaround casting of .length to NaN on otherwise arraylike objects (e.g., NodeLists)
		if ( len !== len ) {
			while ( second[j] !== undefined ) {
				first[ i++ ] = second[ j++ ];
			}
		}

		first.length = i;

		return first;
	},

	grep: function( elems, callback, invert ) {
		var callbackInverse,
			matches = [],
			i = 0,
			length = elems.length,
			callbackExpect = !invert;

		// Go through the array, only saving the items
		// that pass the validator function
		for ( ; i < length; i++ ) {
			callbackInverse = !callback( elems[ i ], i );
			if ( callbackInverse !== callbackExpect ) {
				matches.push( elems[ i ] );
			}
		}

		return matches;
	},

	// arg is for internal usage only
	map: function( elems, callback, arg ) {
		var value,
			i = 0,
			length = elems.length,
			isArray = isArraylike( elems ),
			ret = [];

		// Go through the array, translating each of the items to their new values
		if ( isArray ) {
			for ( ; i < length; i++ ) {
				value = callback( elems[ i ], i, arg );

				if ( value != null ) {
					ret.push( value );
				}
			}

		// Go through every key on the object,
		} else {
			for ( i in elems ) {
				value = callback( elems[ i ], i, arg );

				if ( value != null ) {
					ret.push( value );
				}
			}
		}

		// Flatten any nested arrays
		return concat.apply( [], ret );
	},

	// A global GUID counter for objects
	guid: 1,

	// Bind a function to a context, optionally partially applying any
	// arguments.
	proxy: function( fn, context ) {
		var args, proxy, tmp;

		if ( typeof context === "string" ) {
			tmp = fn[ context ];
			context = fn;
			fn = tmp;
		}

		// Quick check to determine if target is callable, in the spec
		// this throws a TypeError, but we will just return undefined.
		if ( !jQuery.isFunction( fn ) ) {
			return undefined;
		}

		// Simulated bind
		args = slice.call( arguments, 2 );
		proxy = function() {
			return fn.apply( context || this, args.concat( slice.call( arguments ) ) );
		};

		// Set the guid of unique handler to the same of original handler, so it can be removed
		proxy.guid = fn.guid = fn.guid || jQuery.guid++;

		return proxy;
	},

	now: function() {
		return +( new Date() );
	},

	// jQuery.support is not used in Core but other projects attach their
	// properties to it so it needs to exist.
	support: support
});

// Populate the class2type map
jQuery.each("Boolean Number String Function Array Date RegExp Object Error".split(" "), function(i, name) {
	class2type[ "[object " + name + "]" ] = name.toLowerCase();
});

function isArraylike( obj ) {
	var length = obj.length,
		type = jQuery.type( obj );

	if ( type === "function" || jQuery.isWindow( obj ) ) {
		return false;
	}

	if ( obj.nodeType === 1 && length ) {
		return true;
	}

	return type === "array" || length === 0 ||
		typeof length === "number" && length > 0 && ( length - 1 ) in obj;
}
var Sizzle =
/*!
 * Sizzle CSS Selector Engine v1.10.19
 * http://sizzlejs.com/
 *
 * Copyright 2013 jQuery Foundation, Inc. and other contributors
 * Released under the MIT license
 * http://jquery.org/license
 *
 * Date: 2014-04-18
 */
(function( window ) {

var i,
	support,
	Expr,
	getText,
	isXML,
	tokenize,
	compile,
	select,
	outermostContext,
	sortInput,
	hasDuplicate,

	// Local document vars
	setDocument,
	document,
	docElem,
	documentIsHTML,
	rbuggyQSA,
	rbuggyMatches,
	matches,
	contains,

	// Instance-specific data
	expando = "sizzle" + -(new Date()),
	preferredDoc = window.document,
	dirruns = 0,
	done = 0,
	classCache = createCache(),
	tokenCache = createCache(),
	compilerCache = createCache(),
	sortOrder = function( a, b ) {
		if ( a === b ) {
			hasDuplicate = true;
		}
		return 0;
	},

	// General-purpose constants
	strundefined = typeof undefined,
	MAX_NEGATIVE = 1 << 31,

	// Instance methods
	hasOwn = ({}).hasOwnProperty,
	arr = [],
	pop = arr.pop,
	push_native = arr.push,
	push = arr.push,
	slice = arr.slice,
	// Use a stripped-down indexOf if we can't use a native one
	indexOf = arr.indexOf || function( elem ) {
		var i = 0,
			len = this.length;
		for ( ; i < len; i++ ) {
			if ( this[i] === elem ) {
				return i;
			}
		}
		return -1;
	},

	booleans = "checked|selected|async|autofocus|autoplay|controls|defer|disabled|hidden|ismap|loop|multiple|open|readonly|required|scoped",

	// Regular expressions

	// Whitespace characters http://www.w3.org/TR/css3-selectors/#whitespace
	whitespace = "[\\x20\\t\\r\\n\\f]",
	// http://www.w3.org/TR/css3-syntax/#characters
	characterEncoding = "(?:\\\\.|[\\w-]|[^\\x00-\\xa0])+",

	// Loosely modeled on CSS identifier characters
	// An unquoted value should be a CSS identifier http://www.w3.org/TR/css3-selectors/#attribute-selectors
	// Proper syntax: http://www.w3.org/TR/CSS21/syndata.html#value-def-identifier
	identifier = characterEncoding.replace( "w", "w#" ),

	// Attribute selectors: http://www.w3.org/TR/selectors/#attribute-selectors
	attributes = "\\[" + whitespace + "*(" + characterEncoding + ")(?:" + whitespace +
		// Operator (capture 2)
		"*([*^$|!~]?=)" + whitespace +
		// "Attribute values must be CSS identifiers [capture 5] or strings [capture 3 or capture 4]"
		"*(?:'((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\"|(" + identifier + "))|)" + whitespace +
		"*\\]",

	pseudos = ":(" + characterEncoding + ")(?:\\((" +
		// To reduce the number of selectors needing tokenize in the preFilter, prefer arguments:
		// 1. quoted (capture 3; capture 4 or capture 5)
		"('((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\")|" +
		// 2. simple (capture 6)
		"((?:\\\\.|[^\\\\()[\\]]|" + attributes + ")*)|" +
		// 3. anything else (capture 2)
		".*" +
		")\\)|)",

	// Leading and non-escaped trailing whitespace, capturing some non-whitespace characters preceding the latter
	rtrim = new RegExp( "^" + whitespace + "+|((?:^|[^\\\\])(?:\\\\.)*)" + whitespace + "+$", "g" ),

	rcomma = new RegExp( "^" + whitespace + "*," + whitespace + "*" ),
	rcombinators = new RegExp( "^" + whitespace + "*([>+~]|" + whitespace + ")" + whitespace + "*" ),

	rattributeQuotes = new RegExp( "=" + whitespace + "*([^\\]'\"]*?)" + whitespace + "*\\]", "g" ),

	rpseudo = new RegExp( pseudos ),
	ridentifier = new RegExp( "^" + identifier + "$" ),

	matchExpr = {
		"ID": new RegExp( "^#(" + characterEncoding + ")" ),
		"CLASS": new RegExp( "^\\.(" + characterEncoding + ")" ),
		"TAG": new RegExp( "^(" + characterEncoding.replace( "w", "w*" ) + ")" ),
		"ATTR": new RegExp( "^" + attributes ),
		"PSEUDO": new RegExp( "^" + pseudos ),
		"CHILD": new RegExp( "^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\(" + whitespace +
			"*(even|odd|(([+-]|)(\\d*)n|)" + whitespace + "*(?:([+-]|)" + whitespace +
			"*(\\d+)|))" + whitespace + "*\\)|)", "i" ),
		"bool": new RegExp( "^(?:" + booleans + ")$", "i" ),
		// For use in libraries implementing .is()
		// We use this for POS matching in `select`
		"needsContext": new RegExp( "^" + whitespace + "*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\(" +
			whitespace + "*((?:-\\d)?\\d*)" + whitespace + "*\\)|)(?=[^-]|$)", "i" )
	},

	rinputs = /^(?:input|select|textarea|button)$/i,
	rheader = /^h\d$/i,

	rnative = /^[^{]+\{\s*\[native \w/,

	// Easily-parseable/retrievable ID or TAG or CLASS selectors
	rquickExpr = /^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/,

	rsibling = /[+~]/,
	rescape = /'|\\/g,

	// CSS escapes http://www.w3.org/TR/CSS21/syndata.html#escaped-characters
	runescape = new RegExp( "\\\\([\\da-f]{1,6}" + whitespace + "?|(" + whitespace + ")|.)", "ig" ),
	funescape = function( _, escaped, escapedWhitespace ) {
		var high = "0x" + escaped - 0x10000;
		// NaN means non-codepoint
		// Support: Firefox<24
		// Workaround erroneous numeric interpretation of +"0x"
		return high !== high || escapedWhitespace ?
			escaped :
			high < 0 ?
				// BMP codepoint
				String.fromCharCode( high + 0x10000 ) :
				// Supplemental Plane codepoint (surrogate pair)
				String.fromCharCode( high >> 10 | 0xD800, high & 0x3FF | 0xDC00 );
	};

// Optimize for push.apply( _, NodeList )
try {
	push.apply(
		(arr = slice.call( preferredDoc.childNodes )),
		preferredDoc.childNodes
	);
	// Support: Android<4.0
	// Detect silently failing push.apply
	arr[ preferredDoc.childNodes.length ].nodeType;
} catch ( e ) {
	push = { apply: arr.length ?

		// Leverage slice if possible
		function( target, els ) {
			push_native.apply( target, slice.call(els) );
		} :

		// Support: IE<9
		// Otherwise append directly
		function( target, els ) {
			var j = target.length,
				i = 0;
			// Can't trust NodeList.length
			while ( (target[j++] = els[i++]) ) {}
			target.length = j - 1;
		}
	};
}

function Sizzle( selector, context, results, seed ) {
	var match, elem, m, nodeType,
		// QSA vars
		i, groups, old, nid, newContext, newSelector;

	if ( ( context ? context.ownerDocument || context : preferredDoc ) !== document ) {
		setDocument( context );
	}

	context = context || document;
	results = results || [];

	if ( !selector || typeof selector !== "string" ) {
		return results;
	}

	if ( (nodeType = context.nodeType) !== 1 && nodeType !== 9 ) {
		return [];
	}

	if ( documentIsHTML && !seed ) {

		// Shortcuts
		if ( (match = rquickExpr.exec( selector )) ) {
			// Speed-up: Sizzle("#ID")
			if ( (m = match[1]) ) {
				if ( nodeType === 9 ) {
					elem = context.getElementById( m );
					// Check parentNode to catch when Blackberry 4.6 returns
					// nodes that are no longer in the document (jQuery #6963)
					if ( elem && elem.parentNode ) {
						// Handle the case where IE, Opera, and Webkit return items
						// by name instead of ID
						if ( elem.id === m ) {
							results.push( elem );
							return results;
						}
					} else {
						return results;
					}
				} else {
					// Context is not a document
					if ( context.ownerDocument && (elem = context.ownerDocument.getElementById( m )) &&
						contains( context, elem ) && elem.id === m ) {
						results.push( elem );
						return results;
					}
				}

			// Speed-up: Sizzle("TAG")
			} else if ( match[2] ) {
				push.apply( results, context.getElementsByTagName( selector ) );
				return results;

			// Speed-up: Sizzle(".CLASS")
			} else if ( (m = match[3]) && support.getElementsByClassName && context.getElementsByClassName ) {
				push.apply( results, context.getElementsByClassName( m ) );
				return results;
			}
		}

		// QSA path
		if ( support.qsa && (!rbuggyQSA || !rbuggyQSA.test( selector )) ) {
			nid = old = expando;
			newContext = context;
			newSelector = nodeType === 9 && selector;

			// qSA works strangely on Element-rooted queries
			// We can work around this by specifying an extra ID on the root
			// and working up from there (Thanks to Andrew Dupont for the technique)
			// IE 8 doesn't work on object elements
			if ( nodeType === 1 && context.nodeName.toLowerCase() !== "object" ) {
				groups = tokenize( selector );

				if ( (old = context.getAttribute("id")) ) {
					nid = old.replace( rescape, "\\$&" );
				} else {
					context.setAttribute( "id", nid );
				}
				nid = "[id='" + nid + "'] ";

				i = groups.length;
				while ( i-- ) {
					groups[i] = nid + toSelector( groups[i] );
				}
				newContext = rsibling.test( selector ) && testContext( context.parentNode ) || context;
				newSelector = groups.join(",");
			}

			if ( newSelector ) {
				try {
					push.apply( results,
						newContext.querySelectorAll( newSelector )
					);
					return results;
				} catch(qsaError) {
				} finally {
					if ( !old ) {
						context.removeAttribute("id");
					}
				}
			}
		}
	}

	// All others
	return select( selector.replace( rtrim, "$1" ), context, results, seed );
}

/**
 * Create key-value caches of limited size
 * @returns {Function(string, Object)} Returns the Object data after storing it on itself with
 *	property name the (space-suffixed) string and (if the cache is larger than Expr.cacheLength)
 *	deleting the oldest entry
 */
function createCache() {
	var keys = [];

	function cache( key, value ) {
		// Use (key + " ") to avoid collision with native prototype properties (see Issue #157)
		if ( keys.push( key + " " ) > Expr.cacheLength ) {
			// Only keep the most recent entries
			delete cache[ keys.shift() ];
		}
		return (cache[ key + " " ] = value);
	}
	return cache;
}

/**
 * Mark a function for special use by Sizzle
 * @param {Function} fn The function to mark
 */
function markFunction( fn ) {
	fn[ expando ] = true;
	return fn;
}

/**
 * Support testing using an element
 * @param {Function} fn Passed the created div and expects a boolean result
 */
function assert( fn ) {
	var div = document.createElement("div");

	try {
		return !!fn( div );
	} catch (e) {
		return false;
	} finally {
		// Remove from its parent by default
		if ( div.parentNode ) {
			div.parentNode.removeChild( div );
		}
		// release memory in IE
		div = null;
	}
}

/**
 * Adds the same handler for all of the specified attrs
 * @param {String} attrs Pipe-separated list of attributes
 * @param {Function} handler The method that will be applied
 */
function addHandle( attrs, handler ) {
	var arr = attrs.split("|"),
		i = attrs.length;

	while ( i-- ) {
		Expr.attrHandle[ arr[i] ] = handler;
	}
}

/**
 * Checks document order of two siblings
 * @param {Element} a
 * @param {Element} b
 * @returns {Number} Returns less than 0 if a precedes b, greater than 0 if a follows b
 */
function siblingCheck( a, b ) {
	var cur = b && a,
		diff = cur && a.nodeType === 1 && b.nodeType === 1 &&
			( ~b.sourceIndex || MAX_NEGATIVE ) -
			( ~a.sourceIndex || MAX_NEGATIVE );

	// Use IE sourceIndex if available on both nodes
	if ( diff ) {
		return diff;
	}

	// Check if b follows a
	if ( cur ) {
		while ( (cur = cur.nextSibling) ) {
			if ( cur === b ) {
				return -1;
			}
		}
	}

	return a ? 1 : -1;
}

/**
 * Returns a function to use in pseudos for input types
 * @param {String} type
 */
function createInputPseudo( type ) {
	return function( elem ) {
		var name = elem.nodeName.toLowerCase();
		return name === "input" && elem.type === type;
	};
}

/**
 * Returns a function to use in pseudos for buttons
 * @param {String} type
 */
function createButtonPseudo( type ) {
	return function( elem ) {
		var name = elem.nodeName.toLowerCase();
		return (name === "input" || name === "button") && elem.type === type;
	};
}

/**
 * Returns a function to use in pseudos for positionals
 * @param {Function} fn
 */
function createPositionalPseudo( fn ) {
	return markFunction(function( argument ) {
		argument = +argument;
		return markFunction(function( seed, matches ) {
			var j,
				matchIndexes = fn( [], seed.length, argument ),
				i = matchIndexes.length;

			// Match elements found at the specified indexes
			while ( i-- ) {
				if ( seed[ (j = matchIndexes[i]) ] ) {
					seed[j] = !(matches[j] = seed[j]);
				}
			}
		});
	});
}

/**
 * Checks a node for validity as a Sizzle context
 * @param {Element|Object=} context
 * @returns {Element|Object|Boolean} The input node if acceptable, otherwise a falsy value
 */
function testContext( context ) {
	return context && typeof context.getElementsByTagName !== strundefined && context;
}

// Expose support vars for convenience
support = Sizzle.support = {};

/**
 * Detects XML nodes
 * @param {Element|Object} elem An element or a document
 * @returns {Boolean} True iff elem is a non-HTML XML node
 */
isXML = Sizzle.isXML = function( elem ) {
	// documentElement is verified for cases where it doesn't yet exist
	// (such as loading iframes in IE - #4833)
	var documentElement = elem && (elem.ownerDocument || elem).documentElement;
	return documentElement ? documentElement.nodeName !== "HTML" : false;
};

/**
 * Sets document-related variables once based on the current document
 * @param {Element|Object} [doc] An element or document object to use to set the document
 * @returns {Object} Returns the current document
 */
setDocument = Sizzle.setDocument = function( node ) {
	var hasCompare,
		doc = node ? node.ownerDocument || node : preferredDoc,
		parent = doc.defaultView;

	// If no document and documentElement is available, return
	if ( doc === document || doc.nodeType !== 9 || !doc.documentElement ) {
		return document;
	}

	// Set our document
	document = doc;
	docElem = doc.documentElement;

	// Support tests
	documentIsHTML = !isXML( doc );

	// Support: IE>8
	// If iframe document is assigned to "document" variable and if iframe has been reloaded,
	// IE will throw "permission denied" error when accessing "document" variable, see jQuery #13936
	// IE6-8 do not support the defaultView property so parent will be undefined
	if ( parent && parent !== parent.top ) {
		// IE11 does not have attachEvent, so all must suffer
		if ( parent.addEventListener ) {
			parent.addEventListener( "unload", function() {
				setDocument();
			}, false );
		} else if ( parent.attachEvent ) {
			parent.attachEvent( "onunload", function() {
				setDocument();
			});
		}
	}

	/* Attributes
	---------------------------------------------------------------------- */

	// Support: IE<8
	// Verify that getAttribute really returns attributes and not properties (excepting IE8 booleans)
	support.attributes = assert(function( div ) {
		div.className = "i";
		return !div.getAttribute("className");
	});

	/* getElement(s)By*
	---------------------------------------------------------------------- */

	// Check if getElementsByTagName("*") returns only elements
	support.getElementsByTagName = assert(function( div ) {
		div.appendChild( doc.createComment("") );
		return !div.getElementsByTagName("*").length;
	});

	// Check if getElementsByClassName can be trusted
	support.getElementsByClassName = rnative.test( doc.getElementsByClassName ) && assert(function( div ) {
		div.innerHTML = "<div class='a'></div><div class='a i'></div>";

		// Support: Safari<4
		// Catch class over-caching
		div.firstChild.className = "i";
		// Support: Opera<10
		// Catch gEBCN failure to find non-leading classes
		return div.getElementsByClassName("i").length === 2;
	});

	// Support: IE<10
	// Check if getElementById returns elements by name
	// The broken getElementById methods don't pick up programatically-set names,
	// so use a roundabout getElementsByName test
	support.getById = assert(function( div ) {
		docElem.appendChild( div ).id = expando;
		return !doc.getElementsByName || !doc.getElementsByName( expando ).length;
	});

	// ID find and filter
	if ( support.getById ) {
		Expr.find["ID"] = function( id, context ) {
			if ( typeof context.getElementById !== strundefined && documentIsHTML ) {
				var m = context.getElementById( id );
				// Check parentNode to catch when Blackberry 4.6 returns
				// nodes that are no longer in the document #6963
				return m && m.parentNode ? [ m ] : [];
			}
		};
		Expr.filter["ID"] = function( id ) {
			var attrId = id.replace( runescape, funescape );
			return function( elem ) {
				return elem.getAttribute("id") === attrId;
			};
		};
	} else {
		// Support: IE6/7
		// getElementById is not reliable as a find shortcut
		delete Expr.find["ID"];

		Expr.filter["ID"] =  function( id ) {
			var attrId = id.replace( runescape, funescape );
			return function( elem ) {
				var node = typeof elem.getAttributeNode !== strundefined && elem.getAttributeNode("id");
				return node && node.value === attrId;
			};
		};
	}

	// Tag
	Expr.find["TAG"] = support.getElementsByTagName ?
		function( tag, context ) {
			if ( typeof context.getElementsByTagName !== strundefined ) {
				return context.getElementsByTagName( tag );
			}
		} :
		function( tag, context ) {
			var elem,
				tmp = [],
				i = 0,
				results = context.getElementsByTagName( tag );

			// Filter out possible comments
			if ( tag === "*" ) {
				while ( (elem = results[i++]) ) {
					if ( elem.nodeType === 1 ) {
						tmp.push( elem );
					}
				}

				return tmp;
			}
			return results;
		};

	// Class
	Expr.find["CLASS"] = support.getElementsByClassName && function( className, context ) {
		if ( typeof context.getElementsByClassName !== strundefined && documentIsHTML ) {
			return context.getElementsByClassName( className );
		}
	};

	/* QSA/matchesSelector
	---------------------------------------------------------------------- */

	// QSA and matchesSelector support

	// matchesSelector(:active) reports false when true (IE9/Opera 11.5)
	rbuggyMatches = [];

	// qSa(:focus) reports false when true (Chrome 21)
	// We allow this because of a bug in IE8/9 that throws an error
	// whenever `document.activeElement` is accessed on an iframe
	// So, we allow :focus to pass through QSA all the time to avoid the IE error
	// See http://bugs.jquery.com/ticket/13378
	rbuggyQSA = [];

	if ( (support.qsa = rnative.test( doc.querySelectorAll )) ) {
		// Build QSA regex
		// Regex strategy adopted from Diego Perini
		assert(function( div ) {
			// Select is set to empty string on purpose
			// This is to test IE's treatment of not explicitly
			// setting a boolean content attribute,
			// since its presence should be enough
			// http://bugs.jquery.com/ticket/12359
			div.innerHTML = "<select msallowclip=''><option selected=''></option></select>";

			// Support: IE8, Opera 11-12.16
			// Nothing should be selected when empty strings follow ^= or $= or *=
			// The test attribute must be unknown in Opera but "safe" for WinRT
			// http://msdn.microsoft.com/en-us/library/ie/hh465388.aspx#attribute_section
			if ( div.querySelectorAll("[msallowclip^='']").length ) {
				rbuggyQSA.push( "[*^$]=" + whitespace + "*(?:''|\"\")" );
			}

			// Support: IE8
			// Boolean attributes and "value" are not treated correctly
			if ( !div.querySelectorAll("[selected]").length ) {
				rbuggyQSA.push( "\\[" + whitespace + "*(?:value|" + booleans + ")" );
			}

			// Webkit/Opera - :checked should return selected option elements
			// http://www.w3.org/TR/2011/REC-css3-selectors-20110929/#checked
			// IE8 throws error here and will not see later tests
			if ( !div.querySelectorAll(":checked").length ) {
				rbuggyQSA.push(":checked");
			}
		});

		assert(function( div ) {
			// Support: Windows 8 Native Apps
			// The type and name attributes are restricted during .innerHTML assignment
			var input = doc.createElement("input");
			input.setAttribute( "type", "hidden" );
			div.appendChild( input ).setAttribute( "name", "D" );

			// Support: IE8
			// Enforce case-sensitivity of name attribute
			if ( div.querySelectorAll("[name=d]").length ) {
				rbuggyQSA.push( "name" + whitespace + "*[*^$|!~]?=" );
			}

			// FF 3.5 - :enabled/:disabled and hidden elements (hidden elements are still enabled)
			// IE8 throws error here and will not see later tests
			if ( !div.querySelectorAll(":enabled").length ) {
				rbuggyQSA.push( ":enabled", ":disabled" );
			}

			// Opera 10-11 does not throw on post-comma invalid pseudos
			div.querySelectorAll("*,:x");
			rbuggyQSA.push(",.*:");
		});
	}

	if ( (support.matchesSelector = rnative.test( (matches = docElem.matches ||
		docElem.webkitMatchesSelector ||
		docElem.mozMatchesSelector ||
		docElem.oMatchesSelector ||
		docElem.msMatchesSelector) )) ) {

		assert(function( div ) {
			// Check to see if it's possible to do matchesSelector
			// on a disconnected node (IE 9)
			support.disconnectedMatch = matches.call( div, "div" );

			// This should fail with an exception
			// Gecko does not error, returns false instead
			matches.call( div, "[s!='']:x" );
			rbuggyMatches.push( "!=", pseudos );
		});
	}

	rbuggyQSA = rbuggyQSA.length && new RegExp( rbuggyQSA.join("|") );
	rbuggyMatches = rbuggyMatches.length && new RegExp( rbuggyMatches.join("|") );

	/* Contains
	---------------------------------------------------------------------- */
	hasCompare = rnative.test( docElem.compareDocumentPosition );

	// Element contains another
	// Purposefully does not implement inclusive descendent
	// As in, an element does not contain itself
	contains = hasCompare || rnative.test( docElem.contains ) ?
		function( a, b ) {
			var adown = a.nodeType === 9 ? a.documentElement : a,
				bup = b && b.parentNode;
			return a === bup || !!( bup && bup.nodeType === 1 && (
				adown.contains ?
					adown.contains( bup ) :
					a.compareDocumentPosition && a.compareDocumentPosition( bup ) & 16
			));
		} :
		function( a, b ) {
			if ( b ) {
				while ( (b = b.parentNode) ) {
					if ( b === a ) {
						return true;
					}
				}
			}
			return false;
		};

	/* Sorting
	---------------------------------------------------------------------- */

	// Document order sorting
	sortOrder = hasCompare ?
	function( a, b ) {

		// Flag for duplicate removal
		if ( a === b ) {
			hasDuplicate = true;
			return 0;
		}

		// Sort on method existence if only one input has compareDocumentPosition
		var compare = !a.compareDocumentPosition - !b.compareDocumentPosition;
		if ( compare ) {
			return compare;
		}

		// Calculate position if both inputs belong to the same document
		compare = ( a.ownerDocument || a ) === ( b.ownerDocument || b ) ?
			a.compareDocumentPosition( b ) :

			// Otherwise we know they are disconnected
			1;

		// Disconnected nodes
		if ( compare & 1 ||
			(!support.sortDetached && b.compareDocumentPosition( a ) === compare) ) {

			// Choose the first element that is related to our preferred document
			if ( a === doc || a.ownerDocument === preferredDoc && contains(preferredDoc, a) ) {
				return -1;
			}
			if ( b === doc || b.ownerDocument === preferredDoc && contains(preferredDoc, b) ) {
				return 1;
			}

			// Maintain original order
			return sortInput ?
				( indexOf.call( sortInput, a ) - indexOf.call( sortInput, b ) ) :
				0;
		}

		return compare & 4 ? -1 : 1;
	} :
	function( a, b ) {
		// Exit early if the nodes are identical
		if ( a === b ) {
			hasDuplicate = true;
			return 0;
		}

		var cur,
			i = 0,
			aup = a.parentNode,
			bup = b.parentNode,
			ap = [ a ],
			bp = [ b ];

		// Parentless nodes are either documents or disconnected
		if ( !aup || !bup ) {
			return a === doc ? -1 :
				b === doc ? 1 :
				aup ? -1 :
				bup ? 1 :
				sortInput ?
				( indexOf.call( sortInput, a ) - indexOf.call( sortInput, b ) ) :
				0;

		// If the nodes are siblings, we can do a quick check
		} else if ( aup === bup ) {
			return siblingCheck( a, b );
		}

		// Otherwise we need full lists of their ancestors for comparison
		cur = a;
		while ( (cur = cur.parentNode) ) {
			ap.unshift( cur );
		}
		cur = b;
		while ( (cur = cur.parentNode) ) {
			bp.unshift( cur );
		}

		// Walk down the tree looking for a discrepancy
		while ( ap[i] === bp[i] ) {
			i++;
		}

		return i ?
			// Do a sibling check if the nodes have a common ancestor
			siblingCheck( ap[i], bp[i] ) :

			// Otherwise nodes in our document sort first
			ap[i] === preferredDoc ? -1 :
			bp[i] === preferredDoc ? 1 :
			0;
	};

	return doc;
};

Sizzle.matches = function( expr, elements ) {
	return Sizzle( expr, null, null, elements );
};

Sizzle.matchesSelector = function( elem, expr ) {
	// Set document vars if needed
	if ( ( elem.ownerDocument || elem ) !== document ) {
		setDocument( elem );
	}

	// Make sure that attribute selectors are quoted
	expr = expr.replace( rattributeQuotes, "='$1']" );

	if ( support.matchesSelector && documentIsHTML &&
		( !rbuggyMatches || !rbuggyMatches.test( expr ) ) &&
		( !rbuggyQSA     || !rbuggyQSA.test( expr ) ) ) {

		try {
			var ret = matches.call( elem, expr );

			// IE 9's matchesSelector returns false on disconnected nodes
			if ( ret || support.disconnectedMatch ||
					// As well, disconnected nodes are said to be in a document
					// fragment in IE 9
					elem.document && elem.document.nodeType !== 11 ) {
				return ret;
			}
		} catch(e) {}
	}

	return Sizzle( expr, document, null, [ elem ] ).length > 0;
};

Sizzle.contains = function( context, elem ) {
	// Set document vars if needed
	if ( ( context.ownerDocument || context ) !== document ) {
		setDocument( context );
	}
	return contains( context, elem );
};

Sizzle.attr = function( elem, name ) {
	// Set document vars if needed
	if ( ( elem.ownerDocument || elem ) !== document ) {
		setDocument( elem );
	}

	var fn = Expr.attrHandle[ name.toLowerCase() ],
		// Don't get fooled by Object.prototype properties (jQuery #13807)
		val = fn && hasOwn.call( Expr.attrHandle, name.toLowerCase() ) ?
			fn( elem, name, !documentIsHTML ) :
			undefined;

	return val !== undefined ?
		val :
		support.attributes || !documentIsHTML ?
			elem.getAttribute( name ) :
			(val = elem.getAttributeNode(name)) && val.specified ?
				val.value :
				null;
};

Sizzle.error = function( msg ) {
	throw new Error( "Syntax error, unrecognized expression: " + msg );
};

/**
 * Document sorting and removing duplicates
 * @param {ArrayLike} results
 */
Sizzle.uniqueSort = function( results ) {
	var elem,
		duplicates = [],
		j = 0,
		i = 0;

	// Unless we *know* we can detect duplicates, assume their presence
	hasDuplicate = !support.detectDuplicates;
	sortInput = !support.sortStable && results.slice( 0 );
	results.sort( sortOrder );

	if ( hasDuplicate ) {
		while ( (elem = results[i++]) ) {
			if ( elem === results[ i ] ) {
				j = duplicates.push( i );
			}
		}
		while ( j-- ) {
			results.splice( duplicates[ j ], 1 );
		}
	}

	// Clear input after sorting to release objects
	// See https://github.com/jquery/sizzle/pull/225
	sortInput = null;

	return results;
};

/**
 * Utility function for retrieving the text value of an array of DOM nodes
 * @param {Array|Element} elem
 */
getText = Sizzle.getText = function( elem ) {
	var node,
		ret = "",
		i = 0,
		nodeType = elem.nodeType;

	if ( !nodeType ) {
		// If no nodeType, this is expected to be an array
		while ( (node = elem[i++]) ) {
			// Do not traverse comment nodes
			ret += getText( node );
		}
	} else if ( nodeType === 1 || nodeType === 9 || nodeType === 11 ) {
		// Use textContent for elements
		// innerText usage removed for consistency of new lines (jQuery #11153)
		if ( typeof elem.textContent === "string" ) {
			return elem.textContent;
		} else {
			// Traverse its children
			for ( elem = elem.firstChild; elem; elem = elem.nextSibling ) {
				ret += getText( elem );
			}
		}
	} else if ( nodeType === 3 || nodeType === 4 ) {
		return elem.nodeValue;
	}
	// Do not include comment or processing instruction nodes

	return ret;
};

Expr = Sizzle.selectors = {

	// Can be adjusted by the user
	cacheLength: 50,

	createPseudo: markFunction,

	match: matchExpr,

	attrHandle: {},

	find: {},

	relative: {
		">": { dir: "parentNode", first: true },
		" ": { dir: "parentNode" },
		"+": { dir: "previousSibling", first: true },
		"~": { dir: "previousSibling" }
	},

	preFilter: {
		"ATTR": function( match ) {
			match[1] = match[1].replace( runescape, funescape );

			// Move the given value to match[3] whether quoted or unquoted
			match[3] = ( match[3] || match[4] || match[5] || "" ).replace( runescape, funescape );

			if ( match[2] === "~=" ) {
				match[3] = " " + match[3] + " ";
			}

			return match.slice( 0, 4 );
		},

		"CHILD": function( match ) {
			/* matches from matchExpr["CHILD"]
				1 type (only|nth|...)
				2 what (child|of-type)
				3 argument (even|odd|\d*|\d*n([+-]\d+)?|...)
				4 xn-component of xn+y argument ([+-]?\d*n|)
				5 sign of xn-component
				6 x of xn-component
				7 sign of y-component
				8 y of y-component
			*/
			match[1] = match[1].toLowerCase();

			if ( match[1].slice( 0, 3 ) === "nth" ) {
				// nth-* requires argument
				if ( !match[3] ) {
					Sizzle.error( match[0] );
				}

				// numeric x and y parameters for Expr.filter.CHILD
				// remember that false/true cast respectively to 0/1
				match[4] = +( match[4] ? match[5] + (match[6] || 1) : 2 * ( match[3] === "even" || match[3] === "odd" ) );
				match[5] = +( ( match[7] + match[8] ) || match[3] === "odd" );

			// other types prohibit arguments
			} else if ( match[3] ) {
				Sizzle.error( match[0] );
			}

			return match;
		},

		"PSEUDO": function( match ) {
			var excess,
				unquoted = !match[6] && match[2];

			if ( matchExpr["CHILD"].test( match[0] ) ) {
				return null;
			}

			// Accept quoted arguments as-is
			if ( match[3] ) {
				match[2] = match[4] || match[5] || "";

			// Strip excess characters from unquoted arguments
			} else if ( unquoted && rpseudo.test( unquoted ) &&
				// Get excess from tokenize (recursively)
				(excess = tokenize( unquoted, true )) &&
				// advance to the next closing parenthesis
				(excess = unquoted.indexOf( ")", unquoted.length - excess ) - unquoted.length) ) {

				// excess is a negative index
				match[0] = match[0].slice( 0, excess );
				match[2] = unquoted.slice( 0, excess );
			}

			// Return only captures needed by the pseudo filter method (type and argument)
			return match.slice( 0, 3 );
		}
	},

	filter: {

		"TAG": function( nodeNameSelector ) {
			var nodeName = nodeNameSelector.replace( runescape, funescape ).toLowerCase();
			return nodeNameSelector === "*" ?
				function() { return true; } :
				function( elem ) {
					return elem.nodeName && elem.nodeName.toLowerCase() === nodeName;
				};
		},

		"CLASS": function( className ) {
			var pattern = classCache[ className + " " ];

			return pattern ||
				(pattern = new RegExp( "(^|" + whitespace + ")" + className + "(" + whitespace + "|$)" )) &&
				classCache( className, function( elem ) {
					return pattern.test( typeof elem.className === "string" && elem.className || typeof elem.getAttribute !== strundefined && elem.getAttribute("class") || "" );
				});
		},

		"ATTR": function( name, operator, check ) {
			return function( elem ) {
				var result = Sizzle.attr( elem, name );

				if ( result == null ) {
					return operator === "!=";
				}
				if ( !operator ) {
					return true;
				}

				result += "";

				return operator === "=" ? result === check :
					operator === "!=" ? result !== check :
					operator === "^=" ? check && result.indexOf( check ) === 0 :
					operator === "*=" ? check && result.indexOf( check ) > -1 :
					operator === "$=" ? check && result.slice( -check.length ) === check :
					operator === "~=" ? ( " " + result + " " ).indexOf( check ) > -1 :
					operator === "|=" ? result === check || result.slice( 0, check.length + 1 ) === check + "-" :
					false;
			};
		},

		"CHILD": function( type, what, argument, first, last ) {
			var simple = type.slice( 0, 3 ) !== "nth",
				forward = type.slice( -4 ) !== "last",
				ofType = what === "of-type";

			return first === 1 && last === 0 ?

				// Shortcut for :nth-*(n)
				function( elem ) {
					return !!elem.parentNode;
				} :

				function( elem, context, xml ) {
					var cache, outerCache, node, diff, nodeIndex, start,
						dir = simple !== forward ? "nextSibling" : "previousSibling",
						parent = elem.parentNode,
						name = ofType && elem.nodeName.toLowerCase(),
						useCache = !xml && !ofType;

					if ( parent ) {

						// :(first|last|only)-(child|of-type)
						if ( simple ) {
							while ( dir ) {
								node = elem;
								while ( (node = node[ dir ]) ) {
									if ( ofType ? node.nodeName.toLowerCase() === name : node.nodeType === 1 ) {
										return false;
									}
								}
								// Reverse direction for :only-* (if we haven't yet done so)
								start = dir = type === "only" && !start && "nextSibling";
							}
							return true;
						}

						start = [ forward ? parent.firstChild : parent.lastChild ];

						// non-xml :nth-child(...) stores cache data on `parent`
						if ( forward && useCache ) {
							// Seek `elem` from a previously-cached index
							outerCache = parent[ expando ] || (parent[ expando ] = {});
							cache = outerCache[ type ] || [];
							nodeIndex = cache[0] === dirruns && cache[1];
							diff = cache[0] === dirruns && cache[2];
							node = nodeIndex && parent.childNodes[ nodeIndex ];

							while ( (node = ++nodeIndex && node && node[ dir ] ||

								// Fallback to seeking `elem` from the start
								(diff = nodeIndex = 0) || start.pop()) ) {

								// When found, cache indexes on `parent` and break
								if ( node.nodeType === 1 && ++diff && node === elem ) {
									outerCache[ type ] = [ dirruns, nodeIndex, diff ];
									break;
								}
							}

						// Use previously-cached element index if available
						} else if ( useCache && (cache = (elem[ expando ] || (elem[ expando ] = {}))[ type ]) && cache[0] === dirruns ) {
							diff = cache[1];

						// xml :nth-child(...) or :nth-last-child(...) or :nth(-last)?-of-type(...)
						} else {
							// Use the same loop as above to seek `elem` from the start
							while ( (node = ++nodeIndex && node && node[ dir ] ||
								(diff = nodeIndex = 0) || start.pop()) ) {

								if ( ( ofType ? node.nodeName.toLowerCase() === name : node.nodeType === 1 ) && ++diff ) {
									// Cache the index of each encountered element
									if ( useCache ) {
										(node[ expando ] || (node[ expando ] = {}))[ type ] = [ dirruns, diff ];
									}

									if ( node === elem ) {
										break;
									}
								}
							}
						}

						// Incorporate the offset, then check against cycle size
						diff -= last;
						return diff === first || ( diff % first === 0 && diff / first >= 0 );
					}
				};
		},

		"PSEUDO": function( pseudo, argument ) {
			// pseudo-class names are case-insensitive
			// http://www.w3.org/TR/selectors/#pseudo-classes
			// Prioritize by case sensitivity in case custom pseudos are added with uppercase letters
			// Remember that setFilters inherits from pseudos
			var args,
				fn = Expr.pseudos[ pseudo ] || Expr.setFilters[ pseudo.toLowerCase() ] ||
					Sizzle.error( "unsupported pseudo: " + pseudo );

			// The user may use createPseudo to indicate that
			// arguments are needed to create the filter function
			// just as Sizzle does
			if ( fn[ expando ] ) {
				return fn( argument );
			}

			// But maintain support for old signatures
			if ( fn.length > 1 ) {
				args = [ pseudo, pseudo, "", argument ];
				return Expr.setFilters.hasOwnProperty( pseudo.toLowerCase() ) ?
					markFunction(function( seed, matches ) {
						var idx,
							matched = fn( seed, argument ),
							i = matched.length;
						while ( i-- ) {
							idx = indexOf.call( seed, matched[i] );
							seed[ idx ] = !( matches[ idx ] = matched[i] );
						}
					}) :
					function( elem ) {
						return fn( elem, 0, args );
					};
			}

			return fn;
		}
	},

	pseudos: {
		// Potentially complex pseudos
		"not": markFunction(function( selector ) {
			// Trim the selector passed to compile
			// to avoid treating leading and trailing
			// spaces as combinators
			var input = [],
				results = [],
				matcher = compile( selector.replace( rtrim, "$1" ) );

			return matcher[ expando ] ?
				markFunction(function( seed, matches, context, xml ) {
					var elem,
						unmatched = matcher( seed, null, xml, [] ),
						i = seed.length;

					// Match elements unmatched by `matcher`
					while ( i-- ) {
						if ( (elem = unmatched[i]) ) {
							seed[i] = !(matches[i] = elem);
						}
					}
				}) :
				function( elem, context, xml ) {
					input[0] = elem;
					matcher( input, null, xml, results );
					return !results.pop();
				};
		}),

		"has": markFunction(function( selector ) {
			return function( elem ) {
				return Sizzle( selector, elem ).length > 0;
			};
		}),

		"contains": markFunction(function( text ) {
			return function( elem ) {
				return ( elem.textContent || elem.innerText || getText( elem ) ).indexOf( text ) > -1;
			};
		}),

		// "Whether an element is represented by a :lang() selector
		// is based solely on the element's language value
		// being equal to the identifier C,
		// or beginning with the identifier C immediately followed by "-".
		// The matching of C against the element's language value is performed case-insensitively.
		// The identifier C does not have to be a valid language name."
		// http://www.w3.org/TR/selectors/#lang-pseudo
		"lang": markFunction( function( lang ) {
			// lang value must be a valid identifier
			if ( !ridentifier.test(lang || "") ) {
				Sizzle.error( "unsupported lang: " + lang );
			}
			lang = lang.replace( runescape, funescape ).toLowerCase();
			return function( elem ) {
				var elemLang;
				do {
					if ( (elemLang = documentIsHTML ?
						elem.lang :
						elem.getAttribute("xml:lang") || elem.getAttribute("lang")) ) {

						elemLang = elemLang.toLowerCase();
						return elemLang === lang || elemLang.indexOf( lang + "-" ) === 0;
					}
				} while ( (elem = elem.parentNode) && elem.nodeType === 1 );
				return false;
			};
		}),

		// Miscellaneous
		"target": function( elem ) {
			var hash = window.location && window.location.hash;
			return hash && hash.slice( 1 ) === elem.id;
		},

		"root": function( elem ) {
			return elem === docElem;
		},

		"focus": function( elem ) {
			return elem === document.activeElement && (!document.hasFocus || document.hasFocus()) && !!(elem.type || elem.href || ~elem.tabIndex);
		},

		// Boolean properties
		"enabled": function( elem ) {
			return elem.disabled === false;
		},

		"disabled": function( elem ) {
			return elem.disabled === true;
		},

		"checked": function( elem ) {
			// In CSS3, :checked should return both checked and selected elements
			// http://www.w3.org/TR/2011/REC-css3-selectors-20110929/#checked
			var nodeName = elem.nodeName.toLowerCase();
			return (nodeName === "input" && !!elem.checked) || (nodeName === "option" && !!elem.selected);
		},

		"selected": function( elem ) {
			// Accessing this property makes selected-by-default
			// options in Safari work properly
			if ( elem.parentNode ) {
				elem.parentNode.selectedIndex;
			}

			return elem.selected === true;
		},

		// Contents
		"empty": function( elem ) {
			// http://www.w3.org/TR/selectors/#empty-pseudo
			// :empty is negated by element (1) or content nodes (text: 3; cdata: 4; entity ref: 5),
			//   but not by others (comment: 8; processing instruction: 7; etc.)
			// nodeType < 6 works because attributes (2) do not appear as children
			for ( elem = elem.firstChild; elem; elem = elem.nextSibling ) {
				if ( elem.nodeType < 6 ) {
					return false;
				}
			}
			return true;
		},

		"parent": function( elem ) {
			return !Expr.pseudos["empty"]( elem );
		},

		// Element/input types
		"header": function( elem ) {
			return rheader.test( elem.nodeName );
		},

		"input": function( elem ) {
			return rinputs.test( elem.nodeName );
		},

		"button": function( elem ) {
			var name = elem.nodeName.toLowerCase();
			return name === "input" && elem.type === "button" || name === "button";
		},

		"text": function( elem ) {
			var attr;
			return elem.nodeName.toLowerCase() === "input" &&
				elem.type === "text" &&

				// Support: IE<8
				// New HTML5 attribute values (e.g., "search") appear with elem.type === "text"
				( (attr = elem.getAttribute("type")) == null || attr.toLowerCase() === "text" );
		},

		// Position-in-collection
		"first": createPositionalPseudo(function() {
			return [ 0 ];
		}),

		"last": createPositionalPseudo(function( matchIndexes, length ) {
			return [ length - 1 ];
		}),

		"eq": createPositionalPseudo(function( matchIndexes, length, argument ) {
			return [ argument < 0 ? argument + length : argument ];
		}),

		"even": createPositionalPseudo(function( matchIndexes, length ) {
			var i = 0;
			for ( ; i < length; i += 2 ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"odd": createPositionalPseudo(function( matchIndexes, length ) {
			var i = 1;
			for ( ; i < length; i += 2 ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"lt": createPositionalPseudo(function( matchIndexes, length, argument ) {
			var i = argument < 0 ? argument + length : argument;
			for ( ; --i >= 0; ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"gt": createPositionalPseudo(function( matchIndexes, length, argument ) {
			var i = argument < 0 ? argument + length : argument;
			for ( ; ++i < length; ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		})
	}
};

Expr.pseudos["nth"] = Expr.pseudos["eq"];

// Add button/input type pseudos
for ( i in { radio: true, checkbox: true, file: true, password: true, image: true } ) {
	Expr.pseudos[ i ] = createInputPseudo( i );
}
for ( i in { submit: true, reset: true } ) {
	Expr.pseudos[ i ] = createButtonPseudo( i );
}

// Easy API for creating new setFilters
function setFilters() {}
setFilters.prototype = Expr.filters = Expr.pseudos;
Expr.setFilters = new setFilters();

tokenize = Sizzle.tokenize = function( selector, parseOnly ) {
	var matched, match, tokens, type,
		soFar, groups, preFilters,
		cached = tokenCache[ selector + " " ];

	if ( cached ) {
		return parseOnly ? 0 : cached.slice( 0 );
	}

	soFar = selector;
	groups = [];
	preFilters = Expr.preFilter;

	while ( soFar ) {

		// Comma and first run
		if ( !matched || (match = rcomma.exec( soFar )) ) {
			if ( match ) {
				// Don't consume trailing commas as valid
				soFar = soFar.slice( match[0].length ) || soFar;
			}
			groups.push( (tokens = []) );
		}

		matched = false;

		// Combinators
		if ( (match = rcombinators.exec( soFar )) ) {
			matched = match.shift();
			tokens.push({
				value: matched,
				// Cast descendant combinators to space
				type: match[0].replace( rtrim, " " )
			});
			soFar = soFar.slice( matched.length );
		}

		// Filters
		for ( type in Expr.filter ) {
			if ( (match = matchExpr[ type ].exec( soFar )) && (!preFilters[ type ] ||
				(match = preFilters[ type ]( match ))) ) {
				matched = match.shift();
				tokens.push({
					value: matched,
					type: type,
					matches: match
				});
				soFar = soFar.slice( matched.length );
			}
		}

		if ( !matched ) {
			break;
		}
	}

	// Return the length of the invalid excess
	// if we're just parsing
	// Otherwise, throw an error or return tokens
	return parseOnly ?
		soFar.length :
		soFar ?
			Sizzle.error( selector ) :
			// Cache the tokens
			tokenCache( selector, groups ).slice( 0 );
};

function toSelector( tokens ) {
	var i = 0,
		len = tokens.length,
		selector = "";
	for ( ; i < len; i++ ) {
		selector += tokens[i].value;
	}
	return selector;
}

function addCombinator( matcher, combinator, base ) {
	var dir = combinator.dir,
		checkNonElements = base && dir === "parentNode",
		doneName = done++;

	return combinator.first ?
		// Check against closest ancestor/preceding element
		function( elem, context, xml ) {
			while ( (elem = elem[ dir ]) ) {
				if ( elem.nodeType === 1 || checkNonElements ) {
					return matcher( elem, context, xml );
				}
			}
		} :

		// Check against all ancestor/preceding elements
		function( elem, context, xml ) {
			var oldCache, outerCache,
				newCache = [ dirruns, doneName ];

			// We can't set arbitrary data on XML nodes, so they don't benefit from dir caching
			if ( xml ) {
				while ( (elem = elem[ dir ]) ) {
					if ( elem.nodeType === 1 || checkNonElements ) {
						if ( matcher( elem, context, xml ) ) {
							return true;
						}
					}
				}
			} else {
				while ( (elem = elem[ dir ]) ) {
					if ( elem.nodeType === 1 || checkNonElements ) {
						outerCache = elem[ expando ] || (elem[ expando ] = {});
						if ( (oldCache = outerCache[ dir ]) &&
							oldCache[ 0 ] === dirruns && oldCache[ 1 ] === doneName ) {

							// Assign to newCache so results back-propagate to previous elements
							return (newCache[ 2 ] = oldCache[ 2 ]);
						} else {
							// Reuse newcache so results back-propagate to previous elements
							outerCache[ dir ] = newCache;

							// A match means we're done; a fail means we have to keep checking
							if ( (newCache[ 2 ] = matcher( elem, context, xml )) ) {
								return true;
							}
						}
					}
				}
			}
		};
}

function elementMatcher( matchers ) {
	return matchers.length > 1 ?
		function( elem, context, xml ) {
			var i = matchers.length;
			while ( i-- ) {
				if ( !matchers[i]( elem, context, xml ) ) {
					return false;
				}
			}
			return true;
		} :
		matchers[0];
}

function multipleContexts( selector, contexts, results ) {
	var i = 0,
		len = contexts.length;
	for ( ; i < len; i++ ) {
		Sizzle( selector, contexts[i], results );
	}
	return results;
}

function condense( unmatched, map, filter, context, xml ) {
	var elem,
		newUnmatched = [],
		i = 0,
		len = unmatched.length,
		mapped = map != null;

	for ( ; i < len; i++ ) {
		if ( (elem = unmatched[i]) ) {
			if ( !filter || filter( elem, context, xml ) ) {
				newUnmatched.push( elem );
				if ( mapped ) {
					map.push( i );
				}
			}
		}
	}

	return newUnmatched;
}

function setMatcher( preFilter, selector, matcher, postFilter, postFinder, postSelector ) {
	if ( postFilter && !postFilter[ expando ] ) {
		postFilter = setMatcher( postFilter );
	}
	if ( postFinder && !postFinder[ expando ] ) {
		postFinder = setMatcher( postFinder, postSelector );
	}
	return markFunction(function( seed, results, context, xml ) {
		var temp, i, elem,
			preMap = [],
			postMap = [],
			preexisting = results.length,

			// Get initial elements from seed or context
			elems = seed || multipleContexts( selector || "*", context.nodeType ? [ context ] : context, [] ),

			// Prefilter to get matcher input, preserving a map for seed-results synchronization
			matcherIn = preFilter && ( seed || !selector ) ?
				condense( elems, preMap, preFilter, context, xml ) :
				elems,

			matcherOut = matcher ?
				// If we have a postFinder, or filtered seed, or non-seed postFilter or preexisting results,
				postFinder || ( seed ? preFilter : preexisting || postFilter ) ?

					// ...intermediate processing is necessary
					[] :

					// ...otherwise use results directly
					results :
				matcherIn;

		// Find primary matches
		if ( matcher ) {
			matcher( matcherIn, matcherOut, context, xml );
		}

		// Apply postFilter
		if ( postFilter ) {
			temp = condense( matcherOut, postMap );
			postFilter( temp, [], context, xml );

			// Un-match failing elements by moving them back to matcherIn
			i = temp.length;
			while ( i-- ) {
				if ( (elem = temp[i]) ) {
					matcherOut[ postMap[i] ] = !(matcherIn[ postMap[i] ] = elem);
				}
			}
		}

		if ( seed ) {
			if ( postFinder || preFilter ) {
				if ( postFinder ) {
					// Get the final matcherOut by condensing this intermediate into postFinder contexts
					temp = [];
					i = matcherOut.length;
					while ( i-- ) {
						if ( (elem = matcherOut[i]) ) {
							// Restore matcherIn since elem is not yet a final match
							temp.push( (matcherIn[i] = elem) );
						}
					}
					postFinder( null, (matcherOut = []), temp, xml );
				}

				// Move matched elements from seed to results to keep them synchronized
				i = matcherOut.length;
				while ( i-- ) {
					if ( (elem = matcherOut[i]) &&
						(temp = postFinder ? indexOf.call( seed, elem ) : preMap[i]) > -1 ) {

						seed[temp] = !(results[temp] = elem);
					}
				}
			}

		// Add elements to results, through postFinder if defined
		} else {
			matcherOut = condense(
				matcherOut === results ?
					matcherOut.splice( preexisting, matcherOut.length ) :
					matcherOut
			);
			if ( postFinder ) {
				postFinder( null, results, matcherOut, xml );
			} else {
				push.apply( results, matcherOut );
			}
		}
	});
}

function matcherFromTokens( tokens ) {
	var checkContext, matcher, j,
		len = tokens.length,
		leadingRelative = Expr.relative[ tokens[0].type ],
		implicitRelative = leadingRelative || Expr.relative[" "],
		i = leadingRelative ? 1 : 0,

		// The foundational matcher ensures that elements are reachable from top-level context(s)
		matchContext = addCombinator( function( elem ) {
			return elem === checkContext;
		}, implicitRelative, true ),
		matchAnyContext = addCombinator( function( elem ) {
			return indexOf.call( checkContext, elem ) > -1;
		}, implicitRelative, true ),
		matchers = [ function( elem, context, xml ) {
			return ( !leadingRelative && ( xml || context !== outermostContext ) ) || (
				(checkContext = context).nodeType ?
					matchContext( elem, context, xml ) :
					matchAnyContext( elem, context, xml ) );
		} ];

	for ( ; i < len; i++ ) {
		if ( (matcher = Expr.relative[ tokens[i].type ]) ) {
			matchers = [ addCombinator(elementMatcher( matchers ), matcher) ];
		} else {
			matcher = Expr.filter[ tokens[i].type ].apply( null, tokens[i].matches );

			// Return special upon seeing a positional matcher
			if ( matcher[ expando ] ) {
				// Find the next relative operator (if any) for proper handling
				j = ++i;
				for ( ; j < len; j++ ) {
					if ( Expr.relative[ tokens[j].type ] ) {
						break;
					}
				}
				return setMatcher(
					i > 1 && elementMatcher( matchers ),
					i > 1 && toSelector(
						// If the preceding token was a descendant combinator, insert an implicit any-element `*`
						tokens.slice( 0, i - 1 ).concat({ value: tokens[ i - 2 ].type === " " ? "*" : "" })
					).replace( rtrim, "$1" ),
					matcher,
					i < j && matcherFromTokens( tokens.slice( i, j ) ),
					j < len && matcherFromTokens( (tokens = tokens.slice( j )) ),
					j < len && toSelector( tokens )
				);
			}
			matchers.push( matcher );
		}
	}

	return elementMatcher( matchers );
}

function matcherFromGroupMatchers( elementMatchers, setMatchers ) {
	var bySet = setMatchers.length > 0,
		byElement = elementMatchers.length > 0,
		superMatcher = function( seed, context, xml, results, outermost ) {
			var elem, j, matcher,
				matchedCount = 0,
				i = "0",
				unmatched = seed && [],
				setMatched = [],
				contextBackup = outermostContext,
				// We must always have either seed elements or outermost context
				elems = seed || byElement && Expr.find["TAG"]( "*", outermost ),
				// Use integer dirruns iff this is the outermost matcher
				dirrunsUnique = (dirruns += contextBackup == null ? 1 : Math.random() || 0.1),
				len = elems.length;

			if ( outermost ) {
				outermostContext = context !== document && context;
			}

			// Add elements passing elementMatchers directly to results
			// Keep `i` a string if there are no elements so `matchedCount` will be "00" below
			// Support: IE<9, Safari
			// Tolerate NodeList properties (IE: "length"; Safari: <number>) matching elements by id
			for ( ; i !== len && (elem = elems[i]) != null; i++ ) {
				if ( byElement && elem ) {
					j = 0;
					while ( (matcher = elementMatchers[j++]) ) {
						if ( matcher( elem, context, xml ) ) {
							results.push( elem );
							break;
						}
					}
					if ( outermost ) {
						dirruns = dirrunsUnique;
					}
				}

				// Track unmatched elements for set filters
				if ( bySet ) {
					// They will have gone through all possible matchers
					if ( (elem = !matcher && elem) ) {
						matchedCount--;
					}

					// Lengthen the array for every element, matched or not
					if ( seed ) {
						unmatched.push( elem );
					}
				}
			}

			// Apply set filters to unmatched elements
			matchedCount += i;
			if ( bySet && i !== matchedCount ) {
				j = 0;
				while ( (matcher = setMatchers[j++]) ) {
					matcher( unmatched, setMatched, context, xml );
				}

				if ( seed ) {
					// Reintegrate element matches to eliminate the need for sorting
					if ( matchedCount > 0 ) {
						while ( i-- ) {
							if ( !(unmatched[i] || setMatched[i]) ) {
								setMatched[i] = pop.call( results );
							}
						}
					}

					// Discard index placeholder values to get only actual matches
					setMatched = condense( setMatched );
				}

				// Add matches to results
				push.apply( results, setMatched );

				// Seedless set matches succeeding multiple successful matchers stipulate sorting
				if ( outermost && !seed && setMatched.length > 0 &&
					( matchedCount + setMatchers.length ) > 1 ) {

					Sizzle.uniqueSort( results );
				}
			}

			// Override manipulation of globals by nested matchers
			if ( outermost ) {
				dirruns = dirrunsUnique;
				outermostContext = contextBackup;
			}

			return unmatched;
		};

	return bySet ?
		markFunction( superMatcher ) :
		superMatcher;
}

compile = Sizzle.compile = function( selector, match /* Internal Use Only */ ) {
	var i,
		setMatchers = [],
		elementMatchers = [],
		cached = compilerCache[ selector + " " ];

	if ( !cached ) {
		// Generate a function of recursive functions that can be used to check each element
		if ( !match ) {
			match = tokenize( selector );
		}
		i = match.length;
		while ( i-- ) {
			cached = matcherFromTokens( match[i] );
			if ( cached[ expando ] ) {
				setMatchers.push( cached );
			} else {
				elementMatchers.push( cached );
			}
		}

		// Cache the compiled function
		cached = compilerCache( selector, matcherFromGroupMatchers( elementMatchers, setMatchers ) );

		// Save selector and tokenization
		cached.selector = selector;
	}
	return cached;
};

/**
 * A low-level selection function that works with Sizzle's compiled
 *  selector functions
 * @param {String|Function} selector A selector or a pre-compiled
 *  selector function built with Sizzle.compile
 * @param {Element} context
 * @param {Array} [results]
 * @param {Array} [seed] A set of elements to match against
 */
select = Sizzle.select = function( selector, context, results, seed ) {
	var i, tokens, token, type, find,
		compiled = typeof selector === "function" && selector,
		match = !seed && tokenize( (selector = compiled.selector || selector) );

	results = results || [];

	// Try to minimize operations if there is no seed and only one group
	if ( match.length === 1 ) {

		// Take a shortcut and set the context if the root selector is an ID
		tokens = match[0] = match[0].slice( 0 );
		if ( tokens.length > 2 && (token = tokens[0]).type === "ID" &&
				support.getById && context.nodeType === 9 && documentIsHTML &&
				Expr.relative[ tokens[1].type ] ) {

			context = ( Expr.find["ID"]( token.matches[0].replace(runescape, funescape), context ) || [] )[0];
			if ( !context ) {
				return results;

			// Precompiled matchers will still verify ancestry, so step up a level
			} else if ( compiled ) {
				context = context.parentNode;
			}

			selector = selector.slice( tokens.shift().value.length );
		}

		// Fetch a seed set for right-to-left matching
		i = matchExpr["needsContext"].test( selector ) ? 0 : tokens.length;
		while ( i-- ) {
			token = tokens[i];

			// Abort if we hit a combinator
			if ( Expr.relative[ (type = token.type) ] ) {
				break;
			}
			if ( (find = Expr.find[ type ]) ) {
				// Search, expanding context for leading sibling combinators
				if ( (seed = find(
					token.matches[0].replace( runescape, funescape ),
					rsibling.test( tokens[0].type ) && testContext( context.parentNode ) || context
				)) ) {

					// If seed is empty or no tokens remain, we can return early
					tokens.splice( i, 1 );
					selector = seed.length && toSelector( tokens );
					if ( !selector ) {
						push.apply( results, seed );
						return results;
					}

					break;
				}
			}
		}
	}

	// Compile and execute a filtering function if one is not provided
	// Provide `match` to avoid retokenization if we modified the selector above
	( compiled || compile( selector, match ) )(
		seed,
		context,
		!documentIsHTML,
		results,
		rsibling.test( selector ) && testContext( context.parentNode ) || context
	);
	return results;
};

// One-time assignments

// Sort stability
support.sortStable = expando.split("").sort( sortOrder ).join("") === expando;

// Support: Chrome<14
// Always assume duplicates if they aren't passed to the comparison function
support.detectDuplicates = !!hasDuplicate;

// Initialize against the default document
setDocument();

// Support: Webkit<537.32 - Safari 6.0.3/Chrome 25 (fixed in Chrome 27)
// Detached nodes confoundingly follow *each other*
support.sortDetached = assert(function( div1 ) {
	// Should return 1, but returns 4 (following)
	return div1.compareDocumentPosition( document.createElement("div") ) & 1;
});

// Support: IE<8
// Prevent attribute/property "interpolation"
// http://msdn.microsoft.com/en-us/library/ms536429%28VS.85%29.aspx
if ( !assert(function( div ) {
	div.innerHTML = "<a href='#'></a>";
	return div.firstChild.getAttribute("href") === "#" ;
}) ) {
	addHandle( "type|href|height|width", function( elem, name, isXML ) {
		if ( !isXML ) {
			return elem.getAttribute( name, name.toLowerCase() === "type" ? 1 : 2 );
		}
	});
}

// Support: IE<9
// Use defaultValue in place of getAttribute("value")
if ( !support.attributes || !assert(function( div ) {
	div.innerHTML = "<input/>";
	div.firstChild.setAttribute( "value", "" );
	return div.firstChild.getAttribute( "value" ) === "";
}) ) {
	addHandle( "value", function( elem, name, isXML ) {
		if ( !isXML && elem.nodeName.toLowerCase() === "input" ) {
			return elem.defaultValue;
		}
	});
}

// Support: IE<9
// Use getAttributeNode to fetch booleans when getAttribute lies
if ( !assert(function( div ) {
	return div.getAttribute("disabled") == null;
}) ) {
	addHandle( booleans, function( elem, name, isXML ) {
		var val;
		if ( !isXML ) {
			return elem[ name ] === true ? name.toLowerCase() :
					(val = elem.getAttributeNode( name )) && val.specified ?
					val.value :
				null;
		}
	});
}

return Sizzle;

})( window );



jQuery.find = Sizzle;
jQuery.expr = Sizzle.selectors;
jQuery.expr[":"] = jQuery.expr.pseudos;
jQuery.unique = Sizzle.uniqueSort;
jQuery.text = Sizzle.getText;
jQuery.isXMLDoc = Sizzle.isXML;
jQuery.contains = Sizzle.contains;



var rneedsContext = jQuery.expr.match.needsContext;

var rsingleTag = (/^<(\w+)\s*\/?>(?:<\/\1>|)$/);



var risSimple = /^.[^:#\[\.,]*$/;

// Implement the identical functionality for filter and not
function winnow( elements, qualifier, not ) {
	if ( jQuery.isFunction( qualifier ) ) {
		return jQuery.grep( elements, function( elem, i ) {
			/* jshint -W018 */
			return !!qualifier.call( elem, i, elem ) !== not;
		});

	}

	if ( qualifier.nodeType ) {
		return jQuery.grep( elements, function( elem ) {
			return ( elem === qualifier ) !== not;
		});

	}

	if ( typeof qualifier === "string" ) {
		if ( risSimple.test( qualifier ) ) {
			return jQuery.filter( qualifier, elements, not );
		}

		qualifier = jQuery.filter( qualifier, elements );
	}

	return jQuery.grep( elements, function( elem ) {
		return ( jQuery.inArray( elem, qualifier ) >= 0 ) !== not;
	});
}

jQuery.filter = function( expr, elems, not ) {
	var elem = elems[ 0 ];

	if ( not ) {
		expr = ":not(" + expr + ")";
	}

	return elems.length === 1 && elem.nodeType === 1 ?
		jQuery.find.matchesSelector( elem, expr ) ? [ elem ] : [] :
		jQuery.find.matches( expr, jQuery.grep( elems, function( elem ) {
			return elem.nodeType === 1;
		}));
};

jQuery.fn.extend({
	find: function( selector ) {
		var i,
			ret = [],
			self = this,
			len = self.length;

		if ( typeof selector !== "string" ) {
			return this.pushStack( jQuery( selector ).filter(function() {
				for ( i = 0; i < len; i++ ) {
					if ( jQuery.contains( self[ i ], this ) ) {
						return true;
					}
				}
			}) );
		}

		for ( i = 0; i < len; i++ ) {
			jQuery.find( selector, self[ i ], ret );
		}

		// Needed because $( selector, context ) becomes $( context ).find( selector )
		ret = this.pushStack( len > 1 ? jQuery.unique( ret ) : ret );
		ret.selector = this.selector ? this.selector + " " + selector : selector;
		return ret;
	},
	filter: function( selector ) {
		return this.pushStack( winnow(this, selector || [], false) );
	},
	not: function( selector ) {
		return this.pushStack( winnow(this, selector || [], true) );
	},
	is: function( selector ) {
		return !!winnow(
			this,

			// If this is a positional/relative selector, check membership in the returned set
			// so $("p:first").is("p:last") won't return true for a doc with two "p".
			typeof selector === "string" && rneedsContext.test( selector ) ?
				jQuery( selector ) :
				selector || [],
			false
		).length;
	}
});


// Initialize a jQuery object


// A central reference to the root jQuery(document)
var rootjQuery,

	// Use the correct document accordingly with window argument (sandbox)
	document = window.document,

	// A simple way to check for HTML strings
	// Prioritize #id over <tag> to avoid XSS via location.hash (#9521)
	// Strict HTML recognition (#11290: must start with <)
	rquickExpr = /^(?:\s*(<[\w\W]+>)[^>]*|#([\w-]*))$/,

	init = jQuery.fn.init = function( selector, context ) {
		var match, elem;

		// HANDLE: $(""), $(null), $(undefined), $(false)
		if ( !selector ) {
			return this;
		}

		// Handle HTML strings
		if ( typeof selector === "string" ) {
			if ( selector.charAt(0) === "<" && selector.charAt( selector.length - 1 ) === ">" && selector.length >= 3 ) {
				// Assume that strings that start and end with <> are HTML and skip the regex check
				match = [ null, selector, null ];

			} else {
				match = rquickExpr.exec( selector );
			}

			// Match html or make sure no context is specified for #id
			if ( match && (match[1] || !context) ) {

				// HANDLE: $(html) -> $(array)
				if ( match[1] ) {
					context = context instanceof jQuery ? context[0] : context;

					// scripts is true for back-compat
					// Intentionally let the error be thrown if parseHTML is not present
					jQuery.merge( this, jQuery.parseHTML(
						match[1],
						context && context.nodeType ? context.ownerDocument || context : document,
						true
					) );

					// HANDLE: $(html, props)
					if ( rsingleTag.test( match[1] ) && jQuery.isPlainObject( context ) ) {
						for ( match in context ) {
							// Properties of context are called as methods if possible
							if ( jQuery.isFunction( this[ match ] ) ) {
								this[ match ]( context[ match ] );

							// ...and otherwise set as attributes
							} else {
								this.attr( match, context[ match ] );
							}
						}
					}

					return this;

				// HANDLE: $(#id)
				} else {
					elem = document.getElementById( match[2] );

					// Check parentNode to catch when Blackberry 4.6 returns
					// nodes that are no longer in the document #6963
					if ( elem && elem.parentNode ) {
						// Handle the case where IE and Opera return items
						// by name instead of ID
						if ( elem.id !== match[2] ) {
							return rootjQuery.find( selector );
						}

						// Otherwise, we inject the element directly into the jQuery object
						this.length = 1;
						this[0] = elem;
					}

					this.context = document;
					this.selector = selector;
					return this;
				}

			// HANDLE: $(expr, $(...))
			} else if ( !context || context.jquery ) {
				return ( context || rootjQuery ).find( selector );

			// HANDLE: $(expr, context)
			// (which is just equivalent to: $(context).find(expr)
			} else {
				return this.constructor( context ).find( selector );
			}

		// HANDLE: $(DOMElement)
		} else if ( selector.nodeType ) {
			this.context = this[0] = selector;
			this.length = 1;
			return this;

		// HANDLE: $(function)
		// Shortcut for document ready
		} else if ( jQuery.isFunction( selector ) ) {
			return typeof rootjQuery.ready !== "undefined" ?
				rootjQuery.ready( selector ) :
				// Execute immediately if ready is not present
				selector( jQuery );
		}

		if ( selector.selector !== undefined ) {
			this.selector = selector.selector;
			this.context = selector.context;
		}

		return jQuery.makeArray( selector, this );
	};

// Give the init function the jQuery prototype for later instantiation
init.prototype = jQuery.fn;

// Initialize central reference
rootjQuery = jQuery( document );


var rparentsprev = /^(?:parents|prev(?:Until|All))/,
	// methods guaranteed to produce a unique set when starting from a unique set
	guaranteedUnique = {
		children: true,
		contents: true,
		next: true,
		prev: true
	};

jQuery.extend({
	dir: function( elem, dir, until ) {
		var matched = [],
			cur = elem[ dir ];

		while ( cur && cur.nodeType !== 9 && (until === undefined || cur.nodeType !== 1 || !jQuery( cur ).is( until )) ) {
			if ( cur.nodeType === 1 ) {
				matched.push( cur );
			}
			cur = cur[dir];
		}
		return matched;
	},

	sibling: function( n, elem ) {
		var r = [];

		for ( ; n; n = n.nextSibling ) {
			if ( n.nodeType === 1 && n !== elem ) {
				r.push( n );
			}
		}

		return r;
	}
});

jQuery.fn.extend({
	has: function( target ) {
		var i,
			targets = jQuery( target, this ),
			len = targets.length;

		return this.filter(function() {
			for ( i = 0; i < len; i++ ) {
				if ( jQuery.contains( this, targets[i] ) ) {
					return true;
				}
			}
		});
	},

	closest: function( selectors, context ) {
		var cur,
			i = 0,
			l = this.length,
			matched = [],
			pos = rneedsContext.test( selectors ) || typeof selectors !== "string" ?
				jQuery( selectors, context || this.context ) :
				0;

		for ( ; i < l; i++ ) {
			for ( cur = this[i]; cur && cur !== context; cur = cur.parentNode ) {
				// Always skip document fragments
				if ( cur.nodeType < 11 && (pos ?
					pos.index(cur) > -1 :

					// Don't pass non-elements to Sizzle
					cur.nodeType === 1 &&
						jQuery.find.matchesSelector(cur, selectors)) ) {

					matched.push( cur );
					break;
				}
			}
		}

		return this.pushStack( matched.length > 1 ? jQuery.unique( matched ) : matched );
	},

	// Determine the position of an element within
	// the matched set of elements
	index: function( elem ) {

		// No argument, return index in parent
		if ( !elem ) {
			return ( this[0] && this[0].parentNode ) ? this.first().prevAll().length : -1;
		}

		// index in selector
		if ( typeof elem === "string" ) {
			return jQuery.inArray( this[0], jQuery( elem ) );
		}

		// Locate the position of the desired element
		return jQuery.inArray(
			// If it receives a jQuery object, the first element is used
			elem.jquery ? elem[0] : elem, this );
	},

	add: function( selector, context ) {
		return this.pushStack(
			jQuery.unique(
				jQuery.merge( this.get(), jQuery( selector, context ) )
			)
		);
	},

	addBack: function( selector ) {
		return this.add( selector == null ?
			this.prevObject : this.prevObject.filter(selector)
		);
	}
});

function sibling( cur, dir ) {
	do {
		cur = cur[ dir ];
	} while ( cur && cur.nodeType !== 1 );

	return cur;
}

jQuery.each({
	parent: function( elem ) {
		var parent = elem.parentNode;
		return parent && parent.nodeType !== 11 ? parent : null;
	},
	parents: function( elem ) {
		return jQuery.dir( elem, "parentNode" );
	},
	parentsUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "parentNode", until );
	},
	next: function( elem ) {
		return sibling( elem, "nextSibling" );
	},
	prev: function( elem ) {
		return sibling( elem, "previousSibling" );
	},
	nextAll: function( elem ) {
		return jQuery.dir( elem, "nextSibling" );
	},
	prevAll: function( elem ) {
		return jQuery.dir( elem, "previousSibling" );
	},
	nextUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "nextSibling", until );
	},
	prevUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "previousSibling", until );
	},
	siblings: function( elem ) {
		return jQuery.sibling( ( elem.parentNode || {} ).firstChild, elem );
	},
	children: function( elem ) {
		return jQuery.sibling( elem.firstChild );
	},
	contents: function( elem ) {
		return jQuery.nodeName( elem, "iframe" ) ?
			elem.contentDocument || elem.contentWindow.document :
			jQuery.merge( [], elem.childNodes );
	}
}, function( name, fn ) {
	jQuery.fn[ name ] = function( until, selector ) {
		var ret = jQuery.map( this, fn, until );

		if ( name.slice( -5 ) !== "Until" ) {
			selector = until;
		}

		if ( selector && typeof selector === "string" ) {
			ret = jQuery.filter( selector, ret );
		}

		if ( this.length > 1 ) {
			// Remove duplicates
			if ( !guaranteedUnique[ name ] ) {
				ret = jQuery.unique( ret );
			}

			// Reverse order for parents* and prev-derivatives
			if ( rparentsprev.test( name ) ) {
				ret = ret.reverse();
			}
		}

		return this.pushStack( ret );
	};
});
var rnotwhite = (/\S+/g);



// String to Object options format cache
var optionsCache = {};

// Convert String-formatted options into Object-formatted ones and store in cache
function createOptions( options ) {
	var object = optionsCache[ options ] = {};
	jQuery.each( options.match( rnotwhite ) || [], function( _, flag ) {
		object[ flag ] = true;
	});
	return object;
}

/*
 * Create a callback list using the following parameters:
 *
 *	options: an optional list of space-separated options that will change how
 *			the callback list behaves or a more traditional option object
 *
 * By default a callback list will act like an event callback list and can be
 * "fired" multiple times.
 *
 * Possible options:
 *
 *	once:			will ensure the callback list can only be fired once (like a Deferred)
 *
 *	memory:			will keep track of previous values and will call any callback added
 *					after the list has been fired right away with the latest "memorized"
 *					values (like a Deferred)
 *
 *	unique:			will ensure a callback can only be added once (no duplicate in the list)
 *
 *	stopOnFalse:	interrupt callings when a callback returns false
 *
 */
jQuery.Callbacks = function( options ) {

	// Convert options from String-formatted to Object-formatted if needed
	// (we check in cache first)
	options = typeof options === "string" ?
		( optionsCache[ options ] || createOptions( options ) ) :
		jQuery.extend( {}, options );

	var // Flag to know if list is currently firing
		firing,
		// Last fire value (for non-forgettable lists)
		memory,
		// Flag to know if list was already fired
		fired,
		// End of the loop when firing
		firingLength,
		// Index of currently firing callback (modified by remove if needed)
		firingIndex,
		// First callback to fire (used internally by add and fireWith)
		firingStart,
		// Actual callback list
		list = [],
		// Stack of fire calls for repeatable lists
		stack = !options.once && [],
		// Fire callbacks
		fire = function( data ) {
			memory = options.memory && data;
			fired = true;
			firingIndex = firingStart || 0;
			firingStart = 0;
			firingLength = list.length;
			firing = true;
			for ( ; list && firingIndex < firingLength; firingIndex++ ) {
				if ( list[ firingIndex ].apply( data[ 0 ], data[ 1 ] ) === false && options.stopOnFalse ) {
					memory = false; // To prevent further calls using add
					break;
				}
			}
			firing = false;
			if ( list ) {
				if ( stack ) {
					if ( stack.length ) {
						fire( stack.shift() );
					}
				} else if ( memory ) {
					list = [];
				} else {
					self.disable();
				}
			}
		},
		// Actual Callbacks object
		self = {
			// Add a callback or a collection of callbacks to the list
			add: function() {
				if ( list ) {
					// First, we save the current length
					var start = list.length;
					(function add( args ) {
						jQuery.each( args, function( _, arg ) {
							var type = jQuery.type( arg );
							if ( type === "function" ) {
								if ( !options.unique || !self.has( arg ) ) {
									list.push( arg );
								}
							} else if ( arg && arg.length && type !== "string" ) {
								// Inspect recursively
								add( arg );
							}
						});
					})( arguments );
					// Do we need to add the callbacks to the
					// current firing batch?
					if ( firing ) {
						firingLength = list.length;
					// With memory, if we're not firing then
					// we should call right away
					} else if ( memory ) {
						firingStart = start;
						fire( memory );
					}
				}
				return this;
			},
			// Remove a callback from the list
			remove: function() {
				if ( list ) {
					jQuery.each( arguments, function( _, arg ) {
						var index;
						while ( ( index = jQuery.inArray( arg, list, index ) ) > -1 ) {
							list.splice( index, 1 );
							// Handle firing indexes
							if ( firing ) {
								if ( index <= firingLength ) {
									firingLength--;
								}
								if ( index <= firingIndex ) {
									firingIndex--;
								}
							}
						}
					});
				}
				return this;
			},
			// Check if a given callback is in the list.
			// If no argument is given, return whether or not list has callbacks attached.
			has: function( fn ) {
				return fn ? jQuery.inArray( fn, list ) > -1 : !!( list && list.length );
			},
			// Remove all callbacks from the list
			empty: function() {
				list = [];
				firingLength = 0;
				return this;
			},
			// Have the list do nothing anymore
			disable: function() {
				list = stack = memory = undefined;
				return this;
			},
			// Is it disabled?
			disabled: function() {
				return !list;
			},
			// Lock the list in its current state
			lock: function() {
				stack = undefined;
				if ( !memory ) {
					self.disable();
				}
				return this;
			},
			// Is it locked?
			locked: function() {
				return !stack;
			},
			// Call all callbacks with the given context and arguments
			fireWith: function( context, args ) {
				if ( list && ( !fired || stack ) ) {
					args = args || [];
					args = [ context, args.slice ? args.slice() : args ];
					if ( firing ) {
						stack.push( args );
					} else {
						fire( args );
					}
				}
				return this;
			},
			// Call all the callbacks with the given arguments
			fire: function() {
				self.fireWith( this, arguments );
				return this;
			},
			// To know if the callbacks have already been called at least once
			fired: function() {
				return !!fired;
			}
		};

	return self;
};


jQuery.extend({

	Deferred: function( func ) {
		var tuples = [
				// action, add listener, listener list, final state
				[ "resolve", "done", jQuery.Callbacks("once memory"), "resolved" ],
				[ "reject", "fail", jQuery.Callbacks("once memory"), "rejected" ],
				[ "notify", "progress", jQuery.Callbacks("memory") ]
			],
			state = "pending",
			promise = {
				state: function() {
					return state;
				},
				always: function() {
					deferred.done( arguments ).fail( arguments );
					return this;
				},
				then: function( /* fnDone, fnFail, fnProgress */ ) {
					var fns = arguments;
					return jQuery.Deferred(function( newDefer ) {
						jQuery.each( tuples, function( i, tuple ) {
							var fn = jQuery.isFunction( fns[ i ] ) && fns[ i ];
							// deferred[ done | fail | progress ] for forwarding actions to newDefer
							deferred[ tuple[1] ](function() {
								var returned = fn && fn.apply( this, arguments );
								if ( returned && jQuery.isFunction( returned.promise ) ) {
									returned.promise()
										.done( newDefer.resolve )
										.fail( newDefer.reject )
										.progress( newDefer.notify );
								} else {
									newDefer[ tuple[ 0 ] + "With" ]( this === promise ? newDefer.promise() : this, fn ? [ returned ] : arguments );
								}
							});
						});
						fns = null;
					}).promise();
				},
				// Get a promise for this deferred
				// If obj is provided, the promise aspect is added to the object
				promise: function( obj ) {
					return obj != null ? jQuery.extend( obj, promise ) : promise;
				}
			},
			deferred = {};

		// Keep pipe for back-compat
		promise.pipe = promise.then;

		// Add list-specific methods
		jQuery.each( tuples, function( i, tuple ) {
			var list = tuple[ 2 ],
				stateString = tuple[ 3 ];

			// promise[ done | fail | progress ] = list.add
			promise[ tuple[1] ] = list.add;

			// Handle state
			if ( stateString ) {
				list.add(function() {
					// state = [ resolved | rejected ]
					state = stateString;

				// [ reject_list | resolve_list ].disable; progress_list.lock
				}, tuples[ i ^ 1 ][ 2 ].disable, tuples[ 2 ][ 2 ].lock );
			}

			// deferred[ resolve | reject | notify ]
			deferred[ tuple[0] ] = function() {
				deferred[ tuple[0] + "With" ]( this === deferred ? promise : this, arguments );
				return this;
			};
			deferred[ tuple[0] + "With" ] = list.fireWith;
		});

		// Make the deferred a promise
		promise.promise( deferred );

		// Call given func if any
		if ( func ) {
			func.call( deferred, deferred );
		}

		// All done!
		return deferred;
	},

	// Deferred helper
	when: function( subordinate /* , ..., subordinateN */ ) {
		var i = 0,
			resolveValues = slice.call( arguments ),
			length = resolveValues.length,

			// the count of uncompleted subordinates
			remaining = length !== 1 || ( subordinate && jQuery.isFunction( subordinate.promise ) ) ? length : 0,

			// the master Deferred. If resolveValues consist of only a single Deferred, just use that.
			deferred = remaining === 1 ? subordinate : jQuery.Deferred(),

			// Update function for both resolve and progress values
			updateFunc = function( i, contexts, values ) {
				return function( value ) {
					contexts[ i ] = this;
					values[ i ] = arguments.length > 1 ? slice.call( arguments ) : value;
					if ( values === progressValues ) {
						deferred.notifyWith( contexts, values );

					} else if ( !(--remaining) ) {
						deferred.resolveWith( contexts, values );
					}
				};
			},

			progressValues, progressContexts, resolveContexts;

		// add listeners to Deferred subordinates; treat others as resolved
		if ( length > 1 ) {
			progressValues = new Array( length );
			progressContexts = new Array( length );
			resolveContexts = new Array( length );
			for ( ; i < length; i++ ) {
				if ( resolveValues[ i ] && jQuery.isFunction( resolveValues[ i ].promise ) ) {
					resolveValues[ i ].promise()
						.done( updateFunc( i, resolveContexts, resolveValues ) )
						.fail( deferred.reject )
						.progress( updateFunc( i, progressContexts, progressValues ) );
				} else {
					--remaining;
				}
			}
		}

		// if we're not waiting on anything, resolve the master
		if ( !remaining ) {
			deferred.resolveWith( resolveContexts, resolveValues );
		}

		return deferred.promise();
	}
});


// The deferred used on DOM ready
var readyList;

jQuery.fn.ready = function( fn ) {
	// Add the callback
	jQuery.ready.promise().done( fn );

	return this;
};

jQuery.extend({
	// Is the DOM ready to be used? Set to true once it occurs.
	isReady: false,

	// A counter to track how many items to wait for before
	// the ready event fires. See #6781
	readyWait: 1,

	// Hold (or release) the ready event
	holdReady: function( hold ) {
		if ( hold ) {
			jQuery.readyWait++;
		} else {
			jQuery.ready( true );
		}
	},

	// Handle when the DOM is ready
	ready: function( wait ) {

		// Abort if there are pending holds or we're already ready
		if ( wait === true ? --jQuery.readyWait : jQuery.isReady ) {
			return;
		}

		// Make sure body exists, at least, in case IE gets a little overzealous (ticket #5443).
		if ( !document.body ) {
			return setTimeout( jQuery.ready );
		}

		// Remember that the DOM is ready
		jQuery.isReady = true;

		// If a normal DOM Ready event fired, decrement, and wait if need be
		if ( wait !== true && --jQuery.readyWait > 0 ) {
			return;
		}

		// If there are functions bound, to execute
		readyList.resolveWith( document, [ jQuery ] );

		// Trigger any bound ready events
		if ( jQuery.fn.triggerHandler ) {
			jQuery( document ).triggerHandler( "ready" );
			jQuery( document ).off( "ready" );
		}
	}
});

/**
 * Clean-up method for dom ready events
 */
function detach() {
	if ( document.addEventListener ) {
		document.removeEventListener( "DOMContentLoaded", completed, false );
		window.removeEventListener( "load", completed, false );

	} else {
		document.detachEvent( "onreadystatechange", completed );
		window.detachEvent( "onload", completed );
	}
}

/**
 * The ready event handler and self cleanup method
 */
function completed() {
	// readyState === "complete" is good enough for us to call the dom ready in oldIE
	if ( document.addEventListener || event.type === "load" || document.readyState === "complete" ) {
		detach();
		jQuery.ready();
	}
}

jQuery.ready.promise = function( obj ) {
	if ( !readyList ) {

		readyList = jQuery.Deferred();

		// Catch cases where $(document).ready() is called after the browser event has already occurred.
		// we once tried to use readyState "interactive" here, but it caused issues like the one
		// discovered by ChrisS here: http://bugs.jquery.com/ticket/12282#comment:15
		if ( document.readyState === "complete" ) {
			// Handle it asynchronously to allow scripts the opportunity to delay ready
			setTimeout( jQuery.ready );

		// Standards-based browsers support DOMContentLoaded
		} else if ( document.addEventListener ) {
			// Use the handy event callback
			document.addEventListener( "DOMContentLoaded", completed, false );

			// A fallback to window.onload, that will always work
			window.addEventListener( "load", completed, false );

		// If IE event model is used
		} else {
			// Ensure firing before onload, maybe late but safe also for iframes
			document.attachEvent( "onreadystatechange", completed );

			// A fallback to window.onload, that will always work
			window.attachEvent( "onload", completed );

			// If IE and not a frame
			// continually check to see if the document is ready
			var top = false;

			try {
				top = window.frameElement == null && document.documentElement;
			} catch(e) {}

			if ( top && top.doScroll ) {
				(function doScrollCheck() {
					if ( !jQuery.isReady ) {

						try {
							// Use the trick by Diego Perini
							// http://javascript.nwbox.com/IEContentLoaded/
							top.doScroll("left");
						} catch(e) {
							return setTimeout( doScrollCheck, 50 );
						}

						// detach all dom ready events
						detach();

						// and execute any waiting functions
						jQuery.ready();
					}
				})();
			}
		}
	}
	return readyList.promise( obj );
};


var strundefined = typeof undefined;



// Support: IE<9
// Iteration over object's inherited properties before its own
var i;
for ( i in jQuery( support ) ) {
	break;
}
support.ownLast = i !== "0";

// Note: most support tests are defined in their respective modules.
// false until the test is run
support.inlineBlockNeedsLayout = false;

// Execute ASAP in case we need to set body.style.zoom
jQuery(function() {
	// Minified: var a,b,c,d
	var val, div, body, container;

	body = document.getElementsByTagName( "body" )[ 0 ];
	if ( !body || !body.style ) {
		// Return for frameset docs that don't have a body
		return;
	}

	// Setup
	div = document.createElement( "div" );
	container = document.createElement( "div" );
	container.style.cssText = "position:absolute;border:0;width:0;height:0;top:0;left:-9999px";
	body.appendChild( container ).appendChild( div );

	if ( typeof div.style.zoom !== strundefined ) {
		// Support: IE<8
		// Check if natively block-level elements act like inline-block
		// elements when setting their display to 'inline' and giving
		// them layout
		div.style.cssText = "display:inline;margin:0;border:0;padding:1px;width:1px;zoom:1";

		support.inlineBlockNeedsLayout = val = div.offsetWidth === 3;
		if ( val ) {
			// Prevent IE 6 from affecting layout for positioned elements #11048
			// Prevent IE from shrinking the body in IE 7 mode #12869
			// Support: IE<8
			body.style.zoom = 1;
		}
	}

	body.removeChild( container );
});




(function() {
	var div = document.createElement( "div" );

	// Execute the test only if not already executed in another module.
	if (support.deleteExpando == null) {
		// Support: IE<9
		support.deleteExpando = true;
		try {
			delete div.test;
		} catch( e ) {
			support.deleteExpando = false;
		}
	}

	// Null elements to avoid leaks in IE.
	div = null;
})();


/**
 * Determines whether an object can have data
 */
jQuery.acceptData = function( elem ) {
	var noData = jQuery.noData[ (elem.nodeName + " ").toLowerCase() ],
		nodeType = +elem.nodeType || 1;

	// Do not set data on non-element DOM nodes because it will not be cleared (#8335).
	return nodeType !== 1 && nodeType !== 9 ?
		false :

		// Nodes accept data unless otherwise specified; rejection can be conditional
		!noData || noData !== true && elem.getAttribute("classid") === noData;
};


var rbrace = /^(?:\{[\w\W]*\}|\[[\w\W]*\])$/,
	rmultiDash = /([A-Z])/g;

function dataAttr( elem, key, data ) {
	// If nothing was found internally, try to fetch any
	// data from the HTML5 data-* attribute
	if ( data === undefined && elem.nodeType === 1 ) {

		var name = "data-" + key.replace( rmultiDash, "-$1" ).toLowerCase();

		data = elem.getAttribute( name );

		if ( typeof data === "string" ) {
			try {
				data = data === "true" ? true :
					data === "false" ? false :
					data === "null" ? null :
					// Only convert to a number if it doesn't change the string
					+data + "" === data ? +data :
					rbrace.test( data ) ? jQuery.parseJSON( data ) :
					data;
			} catch( e ) {}

			// Make sure we set the data so it isn't changed later
			jQuery.data( elem, key, data );

		} else {
			data = undefined;
		}
	}

	return data;
}

// checks a cache object for emptiness
function isEmptyDataObject( obj ) {
	var name;
	for ( name in obj ) {

		// if the public data object is empty, the private is still empty
		if ( name === "data" && jQuery.isEmptyObject( obj[name] ) ) {
			continue;
		}
		if ( name !== "toJSON" ) {
			return false;
		}
	}

	return true;
}

function internalData( elem, name, data, pvt /* Internal Use Only */ ) {
	if ( !jQuery.acceptData( elem ) ) {
		return;
	}

	var ret, thisCache,
		internalKey = jQuery.expando,

		// We have to handle DOM nodes and JS objects differently because IE6-7
		// can't GC object references properly across the DOM-JS boundary
		isNode = elem.nodeType,

		// Only DOM nodes need the global jQuery cache; JS object data is
		// attached directly to the object so GC can occur automatically
		cache = isNode ? jQuery.cache : elem,

		// Only defining an ID for JS objects if its cache already exists allows
		// the code to shortcut on the same path as a DOM node with no cache
		id = isNode ? elem[ internalKey ] : elem[ internalKey ] && internalKey;

	// Avoid doing any more work than we need to when trying to get data on an
	// object that has no data at all
	if ( (!id || !cache[id] || (!pvt && !cache[id].data)) && data === undefined && typeof name === "string" ) {
		return;
	}

	if ( !id ) {
		// Only DOM nodes need a new unique ID for each element since their data
		// ends up in the global cache
		if ( isNode ) {
			id = elem[ internalKey ] = deletedIds.pop() || jQuery.guid++;
		} else {
			id = internalKey;
		}
	}

	if ( !cache[ id ] ) {
		// Avoid exposing jQuery metadata on plain JS objects when the object
		// is serialized using JSON.stringify
		cache[ id ] = isNode ? {} : { toJSON: jQuery.noop };
	}

	// An object can be passed to jQuery.data instead of a key/value pair; this gets
	// shallow copied over onto the existing cache
	if ( typeof name === "object" || typeof name === "function" ) {
		if ( pvt ) {
			cache[ id ] = jQuery.extend( cache[ id ], name );
		} else {
			cache[ id ].data = jQuery.extend( cache[ id ].data, name );
		}
	}

	thisCache = cache[ id ];

	// jQuery data() is stored in a separate object inside the object's internal data
	// cache in order to avoid key collisions between internal data and user-defined
	// data.
	if ( !pvt ) {
		if ( !thisCache.data ) {
			thisCache.data = {};
		}

		thisCache = thisCache.data;
	}

	if ( data !== undefined ) {
		thisCache[ jQuery.camelCase( name ) ] = data;
	}

	// Check for both converted-to-camel and non-converted data property names
	// If a data property was specified
	if ( typeof name === "string" ) {

		// First Try to find as-is property data
		ret = thisCache[ name ];

		// Test for null|undefined property data
		if ( ret == null ) {

			// Try to find the camelCased property
			ret = thisCache[ jQuery.camelCase( name ) ];
		}
	} else {
		ret = thisCache;
	}

	return ret;
}

function internalRemoveData( elem, name, pvt ) {
	if ( !jQuery.acceptData( elem ) ) {
		return;
	}

	var thisCache, i,
		isNode = elem.nodeType,

		// See jQuery.data for more information
		cache = isNode ? jQuery.cache : elem,
		id = isNode ? elem[ jQuery.expando ] : jQuery.expando;

	// If there is already no cache entry for this object, there is no
	// purpose in continuing
	if ( !cache[ id ] ) {
		return;
	}

	if ( name ) {

		thisCache = pvt ? cache[ id ] : cache[ id ].data;

		if ( thisCache ) {

			// Support array or space separated string names for data keys
			if ( !jQuery.isArray( name ) ) {

				// try the string as a key before any manipulation
				if ( name in thisCache ) {
					name = [ name ];
				} else {

					// split the camel cased version by spaces unless a key with the spaces exists
					name = jQuery.camelCase( name );
					if ( name in thisCache ) {
						name = [ name ];
					} else {
						name = name.split(" ");
					}
				}
			} else {
				// If "name" is an array of keys...
				// When data is initially created, via ("key", "val") signature,
				// keys will be converted to camelCase.
				// Since there is no way to tell _how_ a key was added, remove
				// both plain key and camelCase key. #12786
				// This will only penalize the array argument path.
				name = name.concat( jQuery.map( name, jQuery.camelCase ) );
			}

			i = name.length;
			while ( i-- ) {
				delete thisCache[ name[i] ];
			}

			// If there is no data left in the cache, we want to continue
			// and let the cache object itself get destroyed
			if ( pvt ? !isEmptyDataObject(thisCache) : !jQuery.isEmptyObject(thisCache) ) {
				return;
			}
		}
	}

	// See jQuery.data for more information
	if ( !pvt ) {
		delete cache[ id ].data;

		// Don't destroy the parent cache unless the internal data object
		// had been the only thing left in it
		if ( !isEmptyDataObject( cache[ id ] ) ) {
			return;
		}
	}

	// Destroy the cache
	if ( isNode ) {
		jQuery.cleanData( [ elem ], true );

	// Use delete when supported for expandos or `cache` is not a window per isWindow (#10080)
	/* jshint eqeqeq: false */
	} else if ( support.deleteExpando || cache != cache.window ) {
		/* jshint eqeqeq: true */
		delete cache[ id ];

	// When all else fails, null
	} else {
		cache[ id ] = null;
	}
}

jQuery.extend({
	cache: {},

	// The following elements (space-suffixed to avoid Object.prototype collisions)
	// throw uncatchable exceptions if you attempt to set expando properties
	noData: {
		"applet ": true,
		"embed ": true,
		// ...but Flash objects (which have this classid) *can* handle expandos
		"object ": "clsid:D27CDB6E-AE6D-11cf-96B8-444553540000"
	},

	hasData: function( elem ) {
		elem = elem.nodeType ? jQuery.cache[ elem[jQuery.expando] ] : elem[ jQuery.expando ];
		return !!elem && !isEmptyDataObject( elem );
	},

	data: function( elem, name, data ) {
		return internalData( elem, name, data );
	},

	removeData: function( elem, name ) {
		return internalRemoveData( elem, name );
	},

	// For internal use only.
	_data: function( elem, name, data ) {
		return internalData( elem, name, data, true );
	},

	_removeData: function( elem, name ) {
		return internalRemoveData( elem, name, true );
	}
});

jQuery.fn.extend({
	data: function( key, value ) {
		var i, name, data,
			elem = this[0],
			attrs = elem && elem.attributes;

		// Special expections of .data basically thwart jQuery.access,
		// so implement the relevant behavior ourselves

		// Gets all values
		if ( key === undefined ) {
			if ( this.length ) {
				data = jQuery.data( elem );

				if ( elem.nodeType === 1 && !jQuery._data( elem, "parsedAttrs" ) ) {
					i = attrs.length;
					while ( i-- ) {

						// Support: IE11+
						// The attrs elements can be null (#14894)
						if ( attrs[ i ] ) {
							name = attrs[ i ].name;
							if ( name.indexOf( "data-" ) === 0 ) {
								name = jQuery.camelCase( name.slice(5) );
								dataAttr( elem, name, data[ name ] );
							}
						}
					}
					jQuery._data( elem, "parsedAttrs", true );
				}
			}

			return data;
		}

		// Sets multiple values
		if ( typeof key === "object" ) {
			return this.each(function() {
				jQuery.data( this, key );
			});
		}

		return arguments.length > 1 ?

			// Sets one value
			this.each(function() {
				jQuery.data( this, key, value );
			}) :

			// Gets one value
			// Try to fetch any internally stored data first
			elem ? dataAttr( elem, key, jQuery.data( elem, key ) ) : undefined;
	},

	removeData: function( key ) {
		return this.each(function() {
			jQuery.removeData( this, key );
		});
	}
});


jQuery.extend({
	queue: function( elem, type, data ) {
		var queue;

		if ( elem ) {
			type = ( type || "fx" ) + "queue";
			queue = jQuery._data( elem, type );

			// Speed up dequeue by getting out quickly if this is just a lookup
			if ( data ) {
				if ( !queue || jQuery.isArray(data) ) {
					queue = jQuery._data( elem, type, jQuery.makeArray(data) );
				} else {
					queue.push( data );
				}
			}
			return queue || [];
		}
	},

	dequeue: function( elem, type ) {
		type = type || "fx";

		var queue = jQuery.queue( elem, type ),
			startLength = queue.length,
			fn = queue.shift(),
			hooks = jQuery._queueHooks( elem, type ),
			next = function() {
				jQuery.dequeue( elem, type );
			};

		// If the fx queue is dequeued, always remove the progress sentinel
		if ( fn === "inprogress" ) {
			fn = queue.shift();
			startLength--;
		}

		if ( fn ) {

			// Add a progress sentinel to prevent the fx queue from being
			// automatically dequeued
			if ( type === "fx" ) {
				queue.unshift( "inprogress" );
			}

			// clear up the last queue stop function
			delete hooks.stop;
			fn.call( elem, next, hooks );
		}

		if ( !startLength && hooks ) {
			hooks.empty.fire();
		}
	},

	// not intended for public consumption - generates a queueHooks object, or returns the current one
	_queueHooks: function( elem, type ) {
		var key = type + "queueHooks";
		return jQuery._data( elem, key ) || jQuery._data( elem, key, {
			empty: jQuery.Callbacks("once memory").add(function() {
				jQuery._removeData( elem, type + "queue" );
				jQuery._removeData( elem, key );
			})
		});
	}
});

jQuery.fn.extend({
	queue: function( type, data ) {
		var setter = 2;

		if ( typeof type !== "string" ) {
			data = type;
			type = "fx";
			setter--;
		}

		if ( arguments.length < setter ) {
			return jQuery.queue( this[0], type );
		}

		return data === undefined ?
			this :
			this.each(function() {
				var queue = jQuery.queue( this, type, data );

				// ensure a hooks for this queue
				jQuery._queueHooks( this, type );

				if ( type === "fx" && queue[0] !== "inprogress" ) {
					jQuery.dequeue( this, type );
				}
			});
	},
	dequeue: function( type ) {
		return this.each(function() {
			jQuery.dequeue( this, type );
		});
	},
	clearQueue: function( type ) {
		return this.queue( type || "fx", [] );
	},
	// Get a promise resolved when queues of a certain type
	// are emptied (fx is the type by default)
	promise: function( type, obj ) {
		var tmp,
			count = 1,
			defer = jQuery.Deferred(),
			elements = this,
			i = this.length,
			resolve = function() {
				if ( !( --count ) ) {
					defer.resolveWith( elements, [ elements ] );
				}
			};

		if ( typeof type !== "string" ) {
			obj = type;
			type = undefined;
		}
		type = type || "fx";

		while ( i-- ) {
			tmp = jQuery._data( elements[ i ], type + "queueHooks" );
			if ( tmp && tmp.empty ) {
				count++;
				tmp.empty.add( resolve );
			}
		}
		resolve();
		return defer.promise( obj );
	}
});
var pnum = (/[+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|)/).source;

var cssExpand = [ "Top", "Right", "Bottom", "Left" ];

var isHidden = function( elem, el ) {
		// isHidden might be called from jQuery#filter function;
		// in that case, element will be second argument
		elem = el || elem;
		return jQuery.css( elem, "display" ) === "none" || !jQuery.contains( elem.ownerDocument, elem );
	};



// Multifunctional method to get and set values of a collection
// The value/s can optionally be executed if it's a function
var access = jQuery.access = function( elems, fn, key, value, chainable, emptyGet, raw ) {
	var i = 0,
		length = elems.length,
		bulk = key == null;

	// Sets many values
	if ( jQuery.type( key ) === "object" ) {
		chainable = true;
		for ( i in key ) {
			jQuery.access( elems, fn, i, key[i], true, emptyGet, raw );
		}

	// Sets one value
	} else if ( value !== undefined ) {
		chainable = true;

		if ( !jQuery.isFunction( value ) ) {
			raw = true;
		}

		if ( bulk ) {
			// Bulk operations run against the entire set
			if ( raw ) {
				fn.call( elems, value );
				fn = null;

			// ...except when executing function values
			} else {
				bulk = fn;
				fn = function( elem, key, value ) {
					return bulk.call( jQuery( elem ), value );
				};
			}
		}

		if ( fn ) {
			for ( ; i < length; i++ ) {
				fn( elems[i], key, raw ? value : value.call( elems[i], i, fn( elems[i], key ) ) );
			}
		}
	}

	return chainable ?
		elems :

		// Gets
		bulk ?
			fn.call( elems ) :
			length ? fn( elems[0], key ) : emptyGet;
};
var rcheckableType = (/^(?:checkbox|radio)$/i);



(function() {
	// Minified: var a,b,c
	var input = document.createElement( "input" ),
		div = document.createElement( "div" ),
		fragment = document.createDocumentFragment();

	// Setup
	div.innerHTML = "  <link/><table></table><a href='/a'>a</a><input type='checkbox'/>";

	// IE strips leading whitespace when .innerHTML is used
	support.leadingWhitespace = div.firstChild.nodeType === 3;

	// Make sure that tbody elements aren't automatically inserted
	// IE will insert them into empty tables
	support.tbody = !div.getElementsByTagName( "tbody" ).length;

	// Make sure that link elements get serialized correctly by innerHTML
	// This requires a wrapper element in IE
	support.htmlSerialize = !!div.getElementsByTagName( "link" ).length;

	// Makes sure cloning an html5 element does not cause problems
	// Where outerHTML is undefined, this still works
	support.html5Clone =
		document.createElement( "nav" ).cloneNode( true ).outerHTML !== "<:nav></:nav>";

	// Check if a disconnected checkbox will retain its checked
	// value of true after appended to the DOM (IE6/7)
	input.type = "checkbox";
	input.checked = true;
	fragment.appendChild( input );
	support.appendChecked = input.checked;

	// Make sure textarea (and checkbox) defaultValue is properly cloned
	// Support: IE6-IE11+
	div.innerHTML = "<textarea>x</textarea>";
	support.noCloneChecked = !!div.cloneNode( true ).lastChild.defaultValue;

	// #11217 - WebKit loses check when the name is after the checked attribute
	fragment.appendChild( div );
	div.innerHTML = "<input type='radio' checked='checked' name='t'/>";

	// Support: Safari 5.1, iOS 5.1, Android 4.x, Android 2.3
	// old WebKit doesn't clone checked state correctly in fragments
	support.checkClone = div.cloneNode( true ).cloneNode( true ).lastChild.checked;

	// Support: IE<9
	// Opera does not clone events (and typeof div.attachEvent === undefined).
	// IE9-10 clones events bound via attachEvent, but they don't trigger with .click()
	support.noCloneEvent = true;
	if ( div.attachEvent ) {
		div.attachEvent( "onclick", function() {
			support.noCloneEvent = false;
		});

		div.cloneNode( true ).click();
	}

	// Execute the test only if not already executed in another module.
	if (support.deleteExpando == null) {
		// Support: IE<9
		support.deleteExpando = true;
		try {
			delete div.test;
		} catch( e ) {
			support.deleteExpando = false;
		}
	}
})();


(function() {
	var i, eventName,
		div = document.createElement( "div" );

	// Support: IE<9 (lack submit/change bubble), Firefox 23+ (lack focusin event)
	for ( i in { submit: true, change: true, focusin: true }) {
		eventName = "on" + i;

		if ( !(support[ i + "Bubbles" ] = eventName in window) ) {
			// Beware of CSP restrictions (https://developer.mozilla.org/en/Security/CSP)
			div.setAttribute( eventName, "t" );
			support[ i + "Bubbles" ] = div.attributes[ eventName ].expando === false;
		}
	}

	// Null elements to avoid leaks in IE.
	div = null;
})();


var rformElems = /^(?:input|select|textarea)$/i,
	rkeyEvent = /^key/,
	rmouseEvent = /^(?:mouse|pointer|contextmenu)|click/,
	rfocusMorph = /^(?:focusinfocus|focusoutblur)$/,
	rtypenamespace = /^([^.]*)(?:\.(.+)|)$/;

function returnTrue() {
	return true;
}

function returnFalse() {
	return false;
}

function safeActiveElement() {
	try {
		return document.activeElement;
	} catch ( err ) { }
}

/*
 * Helper functions for managing events -- not part of the public interface.
 * Props to Dean Edwards' addEvent library for many of the ideas.
 */
jQuery.event = {

	global: {},

	add: function( elem, types, handler, data, selector ) {
		var tmp, events, t, handleObjIn,
			special, eventHandle, handleObj,
			handlers, type, namespaces, origType,
			elemData = jQuery._data( elem );

		// Don't attach events to noData or text/comment nodes (but allow plain objects)
		if ( !elemData ) {
			return;
		}

		// Caller can pass in an object of custom data in lieu of the handler
		if ( handler.handler ) {
			handleObjIn = handler;
			handler = handleObjIn.handler;
			selector = handleObjIn.selector;
		}

		// Make sure that the handler has a unique ID, used to find/remove it later
		if ( !handler.guid ) {
			handler.guid = jQuery.guid++;
		}

		// Init the element's event structure and main handler, if this is the first
		if ( !(events = elemData.events) ) {
			events = elemData.events = {};
		}
		if ( !(eventHandle = elemData.handle) ) {
			eventHandle = elemData.handle = function( e ) {
				// Discard the second event of a jQuery.event.trigger() and
				// when an event is called after a page has unloaded
				return typeof jQuery !== strundefined && (!e || jQuery.event.triggered !== e.type) ?
					jQuery.event.dispatch.apply( eventHandle.elem, arguments ) :
					undefined;
			};
			// Add elem as a property of the handle fn to prevent a memory leak with IE non-native events
			eventHandle.elem = elem;
		}

		// Handle multiple events separated by a space
		types = ( types || "" ).match( rnotwhite ) || [ "" ];
		t = types.length;
		while ( t-- ) {
			tmp = rtypenamespace.exec( types[t] ) || [];
			type = origType = tmp[1];
			namespaces = ( tmp[2] || "" ).split( "." ).sort();

			// There *must* be a type, no attaching namespace-only handlers
			if ( !type ) {
				continue;
			}

			// If event changes its type, use the special event handlers for the changed type
			special = jQuery.event.special[ type ] || {};

			// If selector defined, determine special event api type, otherwise given type
			type = ( selector ? special.delegateType : special.bindType ) || type;

			// Update special based on newly reset type
			special = jQuery.event.special[ type ] || {};

			// handleObj is passed to all event handlers
			handleObj = jQuery.extend({
				type: type,
				origType: origType,
				data: data,
				handler: handler,
				guid: handler.guid,
				selector: selector,
				needsContext: selector && jQuery.expr.match.needsContext.test( selector ),
				namespace: namespaces.join(".")
			}, handleObjIn );

			// Init the event handler queue if we're the first
			if ( !(handlers = events[ type ]) ) {
				handlers = events[ type ] = [];
				handlers.delegateCount = 0;

				// Only use addEventListener/attachEvent if the special events handler returns false
				if ( !special.setup || special.setup.call( elem, data, namespaces, eventHandle ) === false ) {
					// Bind the global event handler to the element
					if ( elem.addEventListener ) {
						elem.addEventListener( type, eventHandle, false );

					} else if ( elem.attachEvent ) {
						elem.attachEvent( "on" + type, eventHandle );
					}
				}
			}

			if ( special.add ) {
				special.add.call( elem, handleObj );

				if ( !handleObj.handler.guid ) {
					handleObj.handler.guid = handler.guid;
				}
			}

			// Add to the element's handler list, delegates in front
			if ( selector ) {
				handlers.splice( handlers.delegateCount++, 0, handleObj );
			} else {
				handlers.push( handleObj );
			}

			// Keep track of which events have ever been used, for event optimization
			jQuery.event.global[ type ] = true;
		}

		// Nullify elem to prevent memory leaks in IE
		elem = null;
	},

	// Detach an event or set of events from an element
	remove: function( elem, types, handler, selector, mappedTypes ) {
		var j, handleObj, tmp,
			origCount, t, events,
			special, handlers, type,
			namespaces, origType,
			elemData = jQuery.hasData( elem ) && jQuery._data( elem );

		if ( !elemData || !(events = elemData.events) ) {
			return;
		}

		// Once for each type.namespace in types; type may be omitted
		types = ( types || "" ).match( rnotwhite ) || [ "" ];
		t = types.length;
		while ( t-- ) {
			tmp = rtypenamespace.exec( types[t] ) || [];
			type = origType = tmp[1];
			namespaces = ( tmp[2] || "" ).split( "." ).sort();

			// Unbind all events (on this namespace, if provided) for the element
			if ( !type ) {
				for ( type in events ) {
					jQuery.event.remove( elem, type + types[ t ], handler, selector, true );
				}
				continue;
			}

			special = jQuery.event.special[ type ] || {};
			type = ( selector ? special.delegateType : special.bindType ) || type;
			handlers = events[ type ] || [];
			tmp = tmp[2] && new RegExp( "(^|\\.)" + namespaces.join("\\.(?:.*\\.|)") + "(\\.|$)" );

			// Remove matching events
			origCount = j = handlers.length;
			while ( j-- ) {
				handleObj = handlers[ j ];

				if ( ( mappedTypes || origType === handleObj.origType ) &&
					( !handler || handler.guid === handleObj.guid ) &&
					( !tmp || tmp.test( handleObj.namespace ) ) &&
					( !selector || selector === handleObj.selector || selector === "**" && handleObj.selector ) ) {
					handlers.splice( j, 1 );

					if ( handleObj.selector ) {
						handlers.delegateCount--;
					}
					if ( special.remove ) {
						special.remove.call( elem, handleObj );
					}
				}
			}

			// Remove generic event handler if we removed something and no more handlers exist
			// (avoids potential for endless recursion during removal of special event handlers)
			if ( origCount && !handlers.length ) {
				if ( !special.teardown || special.teardown.call( elem, namespaces, elemData.handle ) === false ) {
					jQuery.removeEvent( elem, type, elemData.handle );
				}

				delete events[ type ];
			}
		}

		// Remove the expando if it's no longer used
		if ( jQuery.isEmptyObject( events ) ) {
			delete elemData.handle;

			// removeData also checks for emptiness and clears the expando if empty
			// so use it instead of delete
			jQuery._removeData( elem, "events" );
		}
	},

	trigger: function( event, data, elem, onlyHandlers ) {
		var handle, ontype, cur,
			bubbleType, special, tmp, i,
			eventPath = [ elem || document ],
			type = hasOwn.call( event, "type" ) ? event.type : event,
			namespaces = hasOwn.call( event, "namespace" ) ? event.namespace.split(".") : [];

		cur = tmp = elem = elem || document;

		// Don't do events on text and comment nodes
		if ( elem.nodeType === 3 || elem.nodeType === 8 ) {
			return;
		}

		// focus/blur morphs to focusin/out; ensure we're not firing them right now
		if ( rfocusMorph.test( type + jQuery.event.triggered ) ) {
			return;
		}

		if ( type.indexOf(".") >= 0 ) {
			// Namespaced trigger; create a regexp to match event type in handle()
			namespaces = type.split(".");
			type = namespaces.shift();
			namespaces.sort();
		}
		ontype = type.indexOf(":") < 0 && "on" + type;

		// Caller can pass in a jQuery.Event object, Object, or just an event type string
		event = event[ jQuery.expando ] ?
			event :
			new jQuery.Event( type, typeof event === "object" && event );

		// Trigger bitmask: & 1 for native handlers; & 2 for jQuery (always true)
		event.isTrigger = onlyHandlers ? 2 : 3;
		event.namespace = namespaces.join(".");
		event.namespace_re = event.namespace ?
			new RegExp( "(^|\\.)" + namespaces.join("\\.(?:.*\\.|)") + "(\\.|$)" ) :
			null;

		// Clean up the event in case it is being reused
		event.result = undefined;
		if ( !event.target ) {
			event.target = elem;
		}

		// Clone any incoming data and prepend the event, creating the handler arg list
		data = data == null ?
			[ event ] :
			jQuery.makeArray( data, [ event ] );

		// Allow special events to draw outside the lines
		special = jQuery.event.special[ type ] || {};
		if ( !onlyHandlers && special.trigger && special.trigger.apply( elem, data ) === false ) {
			return;
		}

		// Determine event propagation path in advance, per W3C events spec (#9951)
		// Bubble up to document, then to window; watch for a global ownerDocument var (#9724)
		if ( !onlyHandlers && !special.noBubble && !jQuery.isWindow( elem ) ) {

			bubbleType = special.delegateType || type;
			if ( !rfocusMorph.test( bubbleType + type ) ) {
				cur = cur.parentNode;
			}
			for ( ; cur; cur = cur.parentNode ) {
				eventPath.push( cur );
				tmp = cur;
			}

			// Only add window if we got to document (e.g., not plain obj or detached DOM)
			if ( tmp === (elem.ownerDocument || document) ) {
				eventPath.push( tmp.defaultView || tmp.parentWindow || window );
			}
		}

		// Fire handlers on the event path
		i = 0;
		while ( (cur = eventPath[i++]) && !event.isPropagationStopped() ) {

			event.type = i > 1 ?
				bubbleType :
				special.bindType || type;

			// jQuery handler
			handle = ( jQuery._data( cur, "events" ) || {} )[ event.type ] && jQuery._data( cur, "handle" );
			if ( handle ) {
				handle.apply( cur, data );
			}

			// Native handler
			handle = ontype && cur[ ontype ];
			if ( handle && handle.apply && jQuery.acceptData( cur ) ) {
				event.result = handle.apply( cur, data );
				if ( event.result === false ) {
					event.preventDefault();
				}
			}
		}
		event.type = type;

		// If nobody prevented the default action, do it now
		if ( !onlyHandlers && !event.isDefaultPrevented() ) {

			if ( (!special._default || special._default.apply( eventPath.pop(), data ) === false) &&
				jQuery.acceptData( elem ) ) {

				// Call a native DOM method on the target with the same name name as the event.
				// Can't use an .isFunction() check here because IE6/7 fails that test.
				// Don't do default actions on window, that's where global variables be (#6170)
				if ( ontype && elem[ type ] && !jQuery.isWindow( elem ) ) {

					// Don't re-trigger an onFOO event when we call its FOO() method
					tmp = elem[ ontype ];

					if ( tmp ) {
						elem[ ontype ] = null;
					}

					// Prevent re-triggering of the same event, since we already bubbled it above
					jQuery.event.triggered = type;
					try {
						elem[ type ]();
					} catch ( e ) {
						// IE<9 dies on focus/blur to hidden element (#1486,#12518)
						// only reproducible on winXP IE8 native, not IE9 in IE8 mode
					}
					jQuery.event.triggered = undefined;

					if ( tmp ) {
						elem[ ontype ] = tmp;
					}
				}
			}
		}

		return event.result;
	},

	dispatch: function( event ) {

		// Make a writable jQuery.Event from the native event object
		event = jQuery.event.fix( event );

		var i, ret, handleObj, matched, j,
			handlerQueue = [],
			args = slice.call( arguments ),
			handlers = ( jQuery._data( this, "events" ) || {} )[ event.type ] || [],
			special = jQuery.event.special[ event.type ] || {};

		// Use the fix-ed jQuery.Event rather than the (read-only) native event
		args[0] = event;
		event.delegateTarget = this;

		// Call the preDispatch hook for the mapped type, and let it bail if desired
		if ( special.preDispatch && special.preDispatch.call( this, event ) === false ) {
			return;
		}

		// Determine handlers
		handlerQueue = jQuery.event.handlers.call( this, event, handlers );

		// Run delegates first; they may want to stop propagation beneath us
		i = 0;
		while ( (matched = handlerQueue[ i++ ]) && !event.isPropagationStopped() ) {
			event.currentTarget = matched.elem;

			j = 0;
			while ( (handleObj = matched.handlers[ j++ ]) && !event.isImmediatePropagationStopped() ) {

				// Triggered event must either 1) have no namespace, or
				// 2) have namespace(s) a subset or equal to those in the bound event (both can have no namespace).
				if ( !event.namespace_re || event.namespace_re.test( handleObj.namespace ) ) {

					event.handleObj = handleObj;
					event.data = handleObj.data;

					ret = ( (jQuery.event.special[ handleObj.origType ] || {}).handle || handleObj.handler )
							.apply( matched.elem, args );

					if ( ret !== undefined ) {
						if ( (event.result = ret) === false ) {
							event.preventDefault();
							event.stopPropagation();
						}
					}
				}
			}
		}

		// Call the postDispatch hook for the mapped type
		if ( special.postDispatch ) {
			special.postDispatch.call( this, event );
		}

		return event.result;
	},

	handlers: function( event, handlers ) {
		var sel, handleObj, matches, i,
			handlerQueue = [],
			delegateCount = handlers.delegateCount,
			cur = event.target;

		// Find delegate handlers
		// Black-hole SVG <use> instance trees (#13180)
		// Avoid non-left-click bubbling in Firefox (#3861)
		if ( delegateCount && cur.nodeType && (!event.button || event.type !== "click") ) {

			/* jshint eqeqeq: false */
			for ( ; cur != this; cur = cur.parentNode || this ) {
				/* jshint eqeqeq: true */

				// Don't check non-elements (#13208)
				// Don't process clicks on disabled elements (#6911, #8165, #11382, #11764)
				if ( cur.nodeType === 1 && (cur.disabled !== true || event.type !== "click") ) {
					matches = [];
					for ( i = 0; i < delegateCount; i++ ) {
						handleObj = handlers[ i ];

						// Don't conflict with Object.prototype properties (#13203)
						sel = handleObj.selector + " ";

						if ( matches[ sel ] === undefined ) {
							matches[ sel ] = handleObj.needsContext ?
								jQuery( sel, this ).index( cur ) >= 0 :
								jQuery.find( sel, this, null, [ cur ] ).length;
						}
						if ( matches[ sel ] ) {
							matches.push( handleObj );
						}
					}
					if ( matches.length ) {
						handlerQueue.push({ elem: cur, handlers: matches });
					}
				}
			}
		}

		// Add the remaining (directly-bound) handlers
		if ( delegateCount < handlers.length ) {
			handlerQueue.push({ elem: this, handlers: handlers.slice( delegateCount ) });
		}

		return handlerQueue;
	},

	fix: function( event ) {
		if ( event[ jQuery.expando ] ) {
			return event;
		}

		// Create a writable copy of the event object and normalize some properties
		var i, prop, copy,
			type = event.type,
			originalEvent = event,
			fixHook = this.fixHooks[ type ];

		if ( !fixHook ) {
			this.fixHooks[ type ] = fixHook =
				rmouseEvent.test( type ) ? this.mouseHooks :
				rkeyEvent.test( type ) ? this.keyHooks :
				{};
		}
		copy = fixHook.props ? this.props.concat( fixHook.props ) : this.props;

		event = new jQuery.Event( originalEvent );

		i = copy.length;
		while ( i-- ) {
			prop = copy[ i ];
			event[ prop ] = originalEvent[ prop ];
		}

		// Support: IE<9
		// Fix target property (#1925)
		if ( !event.target ) {
			event.target = originalEvent.srcElement || document;
		}

		// Support: Chrome 23+, Safari?
		// Target should not be a text node (#504, #13143)
		if ( event.target.nodeType === 3 ) {
			event.target = event.target.parentNode;
		}

		// Support: IE<9
		// For mouse/key events, metaKey==false if it's undefined (#3368, #11328)
		event.metaKey = !!event.metaKey;

		return fixHook.filter ? fixHook.filter( event, originalEvent ) : event;
	},

	// Includes some event props shared by KeyEvent and MouseEvent
	props: "altKey bubbles cancelable ctrlKey currentTarget eventPhase metaKey relatedTarget shiftKey target timeStamp view which".split(" "),

	fixHooks: {},

	keyHooks: {
		props: "char charCode key keyCode".split(" "),
		filter: function( event, original ) {

			// Add which for key events
			if ( event.which == null ) {
				event.which = original.charCode != null ? original.charCode : original.keyCode;
			}

			return event;
		}
	},

	mouseHooks: {
		props: "button buttons clientX clientY fromElement offsetX offsetY pageX pageY screenX screenY toElement".split(" "),
		filter: function( event, original ) {
			var body, eventDoc, doc,
				button = original.button,
				fromElement = original.fromElement;

			// Calculate pageX/Y if missing and clientX/Y available
			if ( event.pageX == null && original.clientX != null ) {
				eventDoc = event.target.ownerDocument || document;
				doc = eventDoc.documentElement;
				body = eventDoc.body;

				event.pageX = original.clientX + ( doc && doc.scrollLeft || body && body.scrollLeft || 0 ) - ( doc && doc.clientLeft || body && body.clientLeft || 0 );
				event.pageY = original.clientY + ( doc && doc.scrollTop  || body && body.scrollTop  || 0 ) - ( doc && doc.clientTop  || body && body.clientTop  || 0 );
			}

			// Add relatedTarget, if necessary
			if ( !event.relatedTarget && fromElement ) {
				event.relatedTarget = fromElement === event.target ? original.toElement : fromElement;
			}

			// Add which for click: 1 === left; 2 === middle; 3 === right
			// Note: button is not normalized, so don't use it
			if ( !event.which && button !== undefined ) {
				event.which = ( button & 1 ? 1 : ( button & 2 ? 3 : ( button & 4 ? 2 : 0 ) ) );
			}

			return event;
		}
	},

	special: {
		load: {
			// Prevent triggered image.load events from bubbling to window.load
			noBubble: true
		},
		focus: {
			// Fire native event if possible so blur/focus sequence is correct
			trigger: function() {
				if ( this !== safeActiveElement() && this.focus ) {
					try {
						this.focus();
						return false;
					} catch ( e ) {
						// Support: IE<9
						// If we error on focus to hidden element (#1486, #12518),
						// let .trigger() run the handlers
					}
				}
			},
			delegateType: "focusin"
		},
		blur: {
			trigger: function() {
				if ( this === safeActiveElement() && this.blur ) {
					this.blur();
					return false;
				}
			},
			delegateType: "focusout"
		},
		click: {
			// For checkbox, fire native event so checked state will be right
			trigger: function() {
				if ( jQuery.nodeName( this, "input" ) && this.type === "checkbox" && this.click ) {
					this.click();
					return false;
				}
			},

			// For cross-browser consistency, don't fire native .click() on links
			_default: function( event ) {
				return jQuery.nodeName( event.target, "a" );
			}
		},

		beforeunload: {
			postDispatch: function( event ) {

				// Support: Firefox 20+
				// Firefox doesn't alert if the returnValue field is not set.
				if ( event.result !== undefined && event.originalEvent ) {
					event.originalEvent.returnValue = event.result;
				}
			}
		}
	},

	simulate: function( type, elem, event, bubble ) {
		// Piggyback on a donor event to simulate a different one.
		// Fake originalEvent to avoid donor's stopPropagation, but if the
		// simulated event prevents default then we do the same on the donor.
		var e = jQuery.extend(
			new jQuery.Event(),
			event,
			{
				type: type,
				isSimulated: true,
				originalEvent: {}
			}
		);
		if ( bubble ) {
			jQuery.event.trigger( e, null, elem );
		} else {
			jQuery.event.dispatch.call( elem, e );
		}
		if ( e.isDefaultPrevented() ) {
			event.preventDefault();
		}
	}
};

jQuery.removeEvent = document.removeEventListener ?
	function( elem, type, handle ) {
		if ( elem.removeEventListener ) {
			elem.removeEventListener( type, handle, false );
		}
	} :
	function( elem, type, handle ) {
		var name = "on" + type;

		if ( elem.detachEvent ) {

			// #8545, #7054, preventing memory leaks for custom events in IE6-8
			// detachEvent needed property on element, by name of that event, to properly expose it to GC
			if ( typeof elem[ name ] === strundefined ) {
				elem[ name ] = null;
			}

			elem.detachEvent( name, handle );
		}
	};

jQuery.Event = function( src, props ) {
	// Allow instantiation without the 'new' keyword
	if ( !(this instanceof jQuery.Event) ) {
		return new jQuery.Event( src, props );
	}

	// Event object
	if ( src && src.type ) {
		this.originalEvent = src;
		this.type = src.type;

		// Events bubbling up the document may have been marked as prevented
		// by a handler lower down the tree; reflect the correct value.
		this.isDefaultPrevented = src.defaultPrevented ||
				src.defaultPrevented === undefined &&
				// Support: IE < 9, Android < 4.0
				src.returnValue === false ?
			returnTrue :
			returnFalse;

	// Event type
	} else {
		this.type = src;
	}

	// Put explicitly provided properties onto the event object
	if ( props ) {
		jQuery.extend( this, props );
	}

	// Create a timestamp if incoming event doesn't have one
	this.timeStamp = src && src.timeStamp || jQuery.now();

	// Mark it as fixed
	this[ jQuery.expando ] = true;
};

// jQuery.Event is based on DOM3 Events as specified by the ECMAScript Language Binding
// http://www.w3.org/TR/2003/WD-DOM-Level-3-Events-20030331/ecma-script-binding.html
jQuery.Event.prototype = {
	isDefaultPrevented: returnFalse,
	isPropagationStopped: returnFalse,
	isImmediatePropagationStopped: returnFalse,

	preventDefault: function() {
		var e = this.originalEvent;

		this.isDefaultPrevented = returnTrue;
		if ( !e ) {
			return;
		}

		// If preventDefault exists, run it on the original event
		if ( e.preventDefault ) {
			e.preventDefault();

		// Support: IE
		// Otherwise set the returnValue property of the original event to false
		} else {
			e.returnValue = false;
		}
	},
	stopPropagation: function() {
		var e = this.originalEvent;

		this.isPropagationStopped = returnTrue;
		if ( !e ) {
			return;
		}
		// If stopPropagation exists, run it on the original event
		if ( e.stopPropagation ) {
			e.stopPropagation();
		}

		// Support: IE
		// Set the cancelBubble property of the original event to true
		e.cancelBubble = true;
	},
	stopImmediatePropagation: function() {
		var e = this.originalEvent;

		this.isImmediatePropagationStopped = returnTrue;

		if ( e && e.stopImmediatePropagation ) {
			e.stopImmediatePropagation();
		}

		this.stopPropagation();
	}
};

// Create mouseenter/leave events using mouseover/out and event-time checks
jQuery.each({
	mouseenter: "mouseover",
	mouseleave: "mouseout",
	pointerenter: "pointerover",
	pointerleave: "pointerout"
}, function( orig, fix ) {
	jQuery.event.special[ orig ] = {
		delegateType: fix,
		bindType: fix,

		handle: function( event ) {
			var ret,
				target = this,
				related = event.relatedTarget,
				handleObj = event.handleObj;

			// For mousenter/leave call the handler if related is outside the target.
			// NB: No relatedTarget if the mouse left/entered the browser window
			if ( !related || (related !== target && !jQuery.contains( target, related )) ) {
				event.type = handleObj.origType;
				ret = handleObj.handler.apply( this, arguments );
				event.type = fix;
			}
			return ret;
		}
	};
});

// IE submit delegation
if ( !support.submitBubbles ) {

	jQuery.event.special.submit = {
		setup: function() {
			// Only need this for delegated form submit events
			if ( jQuery.nodeName( this, "form" ) ) {
				return false;
			}

			// Lazy-add a submit handler when a descendant form may potentially be submitted
			jQuery.event.add( this, "click._submit keypress._submit", function( e ) {
				// Node name check avoids a VML-related crash in IE (#9807)
				var elem = e.target,
					form = jQuery.nodeName( elem, "input" ) || jQuery.nodeName( elem, "button" ) ? elem.form : undefined;
				if ( form && !jQuery._data( form, "submitBubbles" ) ) {
					jQuery.event.add( form, "submit._submit", function( event ) {
						event._submit_bubble = true;
					});
					jQuery._data( form, "submitBubbles", true );
				}
			});
			// return undefined since we don't need an event listener
		},

		postDispatch: function( event ) {
			// If form was submitted by the user, bubble the event up the tree
			if ( event._submit_bubble ) {
				delete event._submit_bubble;
				if ( this.parentNode && !event.isTrigger ) {
					jQuery.event.simulate( "submit", this.parentNode, event, true );
				}
			}
		},

		teardown: function() {
			// Only need this for delegated form submit events
			if ( jQuery.nodeName( this, "form" ) ) {
				return false;
			}

			// Remove delegated handlers; cleanData eventually reaps submit handlers attached above
			jQuery.event.remove( this, "._submit" );
		}
	};
}

// IE change delegation and checkbox/radio fix
if ( !support.changeBubbles ) {

	jQuery.event.special.change = {

		setup: function() {

			if ( rformElems.test( this.nodeName ) ) {
				// IE doesn't fire change on a check/radio until blur; trigger it on click
				// after a propertychange. Eat the blur-change in special.change.handle.
				// This still fires onchange a second time for check/radio after blur.
				if ( this.type === "checkbox" || this.type === "radio" ) {
					jQuery.event.add( this, "propertychange._change", function( event ) {
						if ( event.originalEvent.propertyName === "checked" ) {
							this._just_changed = true;
						}
					});
					jQuery.event.add( this, "click._change", function( event ) {
						if ( this._just_changed && !event.isTrigger ) {
							this._just_changed = false;
						}
						// Allow triggered, simulated change events (#11500)
						jQuery.event.simulate( "change", this, event, true );
					});
				}
				return false;
			}
			// Delegated event; lazy-add a change handler on descendant inputs
			jQuery.event.add( this, "beforeactivate._change", function( e ) {
				var elem = e.target;

				if ( rformElems.test( elem.nodeName ) && !jQuery._data( elem, "changeBubbles" ) ) {
					jQuery.event.add( elem, "change._change", function( event ) {
						if ( this.parentNode && !event.isSimulated && !event.isTrigger ) {
							jQuery.event.simulate( "change", this.parentNode, event, true );
						}
					});
					jQuery._data( elem, "changeBubbles", true );
				}
			});
		},

		handle: function( event ) {
			var elem = event.target;

			// Swallow native change events from checkbox/radio, we already triggered them above
			if ( this !== elem || event.isSimulated || event.isTrigger || (elem.type !== "radio" && elem.type !== "checkbox") ) {
				return event.handleObj.handler.apply( this, arguments );
			}
		},

		teardown: function() {
			jQuery.event.remove( this, "._change" );

			return !rformElems.test( this.nodeName );
		}
	};
}

// Create "bubbling" focus and blur events
if ( !support.focusinBubbles ) {
	jQuery.each({ focus: "focusin", blur: "focusout" }, function( orig, fix ) {

		// Attach a single capturing handler on the document while someone wants focusin/focusout
		var handler = function( event ) {
				jQuery.event.simulate( fix, event.target, jQuery.event.fix( event ), true );
			};

		jQuery.event.special[ fix ] = {
			setup: function() {
				var doc = this.ownerDocument || this,
					attaches = jQuery._data( doc, fix );

				if ( !attaches ) {
					doc.addEventListener( orig, handler, true );
				}
				jQuery._data( doc, fix, ( attaches || 0 ) + 1 );
			},
			teardown: function() {
				var doc = this.ownerDocument || this,
					attaches = jQuery._data( doc, fix ) - 1;

				if ( !attaches ) {
					doc.removeEventListener( orig, handler, true );
					jQuery._removeData( doc, fix );
				} else {
					jQuery._data( doc, fix, attaches );
				}
			}
		};
	});
}

jQuery.fn.extend({

	on: function( types, selector, data, fn, /*INTERNAL*/ one ) {
		var type, origFn;

		// Types can be a map of types/handlers
		if ( typeof types === "object" ) {
			// ( types-Object, selector, data )
			if ( typeof selector !== "string" ) {
				// ( types-Object, data )
				data = data || selector;
				selector = undefined;
			}
			for ( type in types ) {
				this.on( type, selector, data, types[ type ], one );
			}
			return this;
		}

		if ( data == null && fn == null ) {
			// ( types, fn )
			fn = selector;
			data = selector = undefined;
		} else if ( fn == null ) {
			if ( typeof selector === "string" ) {
				// ( types, selector, fn )
				fn = data;
				data = undefined;
			} else {
				// ( types, data, fn )
				fn = data;
				data = selector;
				selector = undefined;
			}
		}
		if ( fn === false ) {
			fn = returnFalse;
		} else if ( !fn ) {
			return this;
		}

		if ( one === 1 ) {
			origFn = fn;
			fn = function( event ) {
				// Can use an empty set, since event contains the info
				jQuery().off( event );
				return origFn.apply( this, arguments );
			};
			// Use same guid so caller can remove using origFn
			fn.guid = origFn.guid || ( origFn.guid = jQuery.guid++ );
		}
		return this.each( function() {
			jQuery.event.add( this, types, fn, data, selector );
		});
	},
	one: function( types, selector, data, fn ) {
		return this.on( types, selector, data, fn, 1 );
	},
	off: function( types, selector, fn ) {
		var handleObj, type;
		if ( types && types.preventDefault && types.handleObj ) {
			// ( event )  dispatched jQuery.Event
			handleObj = types.handleObj;
			jQuery( types.delegateTarget ).off(
				handleObj.namespace ? handleObj.origType + "." + handleObj.namespace : handleObj.origType,
				handleObj.selector,
				handleObj.handler
			);
			return this;
		}
		if ( typeof types === "object" ) {
			// ( types-object [, selector] )
			for ( type in types ) {
				this.off( type, selector, types[ type ] );
			}
			return this;
		}
		if ( selector === false || typeof selector === "function" ) {
			// ( types [, fn] )
			fn = selector;
			selector = undefined;
		}
		if ( fn === false ) {
			fn = returnFalse;
		}
		return this.each(function() {
			jQuery.event.remove( this, types, fn, selector );
		});
	},

	trigger: function( type, data ) {
		return this.each(function() {
			jQuery.event.trigger( type, data, this );
		});
	},
	triggerHandler: function( type, data ) {
		var elem = this[0];
		if ( elem ) {
			return jQuery.event.trigger( type, data, elem, true );
		}
	}
});


function createSafeFragment( document ) {
	var list = nodeNames.split( "|" ),
		safeFrag = document.createDocumentFragment();

	if ( safeFrag.createElement ) {
		while ( list.length ) {
			safeFrag.createElement(
				list.pop()
			);
		}
	}
	return safeFrag;
}

var nodeNames = "abbr|article|aside|audio|bdi|canvas|data|datalist|details|figcaption|figure|footer|" +
		"header|hgroup|mark|meter|nav|output|progress|section|summary|time|video",
	rinlinejQuery = / jQuery\d+="(?:null|\d+)"/g,
	rnoshimcache = new RegExp("<(?:" + nodeNames + ")[\\s/>]", "i"),
	rleadingWhitespace = /^\s+/,
	rxhtmlTag = /<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:]+)[^>]*)\/>/gi,
	rtagName = /<([\w:]+)/,
	rtbody = /<tbody/i,
	rhtml = /<|&#?\w+;/,
	rnoInnerhtml = /<(?:script|style|link)/i,
	// checked="checked" or checked
	rchecked = /checked\s*(?:[^=]|=\s*.checked.)/i,
	rscriptType = /^$|\/(?:java|ecma)script/i,
	rscriptTypeMasked = /^true\/(.*)/,
	rcleanScript = /^\s*<!(?:\[CDATA\[|--)|(?:\]\]|--)>\s*$/g,

	// We have to close these tags to support XHTML (#13200)
	wrapMap = {
		option: [ 1, "<select multiple='multiple'>", "</select>" ],
		legend: [ 1, "<fieldset>", "</fieldset>" ],
		area: [ 1, "<map>", "</map>" ],
		param: [ 1, "<object>", "</object>" ],
		thead: [ 1, "<table>", "</table>" ],
		tr: [ 2, "<table><tbody>", "</tbody></table>" ],
		col: [ 2, "<table><tbody></tbody><colgroup>", "</colgroup></table>" ],
		td: [ 3, "<table><tbody><tr>", "</tr></tbody></table>" ],

		// IE6-8 can't serialize link, script, style, or any html5 (NoScope) tags,
		// unless wrapped in a div with non-breaking characters in front of it.
		_default: support.htmlSerialize ? [ 0, "", "" ] : [ 1, "X<div>", "</div>"  ]
	},
	safeFragment = createSafeFragment( document ),
	fragmentDiv = safeFragment.appendChild( document.createElement("div") );

wrapMap.optgroup = wrapMap.option;
wrapMap.tbody = wrapMap.tfoot = wrapMap.colgroup = wrapMap.caption = wrapMap.thead;
wrapMap.th = wrapMap.td;

function getAll( context, tag ) {
	var elems, elem,
		i = 0,
		found = typeof context.getElementsByTagName !== strundefined ? context.getElementsByTagName( tag || "*" ) :
			typeof context.querySelectorAll !== strundefined ? context.querySelectorAll( tag || "*" ) :
			undefined;

	if ( !found ) {
		for ( found = [], elems = context.childNodes || context; (elem = elems[i]) != null; i++ ) {
			if ( !tag || jQuery.nodeName( elem, tag ) ) {
				found.push( elem );
			} else {
				jQuery.merge( found, getAll( elem, tag ) );
			}
		}
	}

	return tag === undefined || tag && jQuery.nodeName( context, tag ) ?
		jQuery.merge( [ context ], found ) :
		found;
}

// Used in buildFragment, fixes the defaultChecked property
function fixDefaultChecked( elem ) {
	if ( rcheckableType.test( elem.type ) ) {
		elem.defaultChecked = elem.checked;
	}
}

// Support: IE<8
// Manipulating tables requires a tbody
function manipulationTarget( elem, content ) {
	return jQuery.nodeName( elem, "table" ) &&
		jQuery.nodeName( content.nodeType !== 11 ? content : content.firstChild, "tr" ) ?

		elem.getElementsByTagName("tbody")[0] ||
			elem.appendChild( elem.ownerDocument.createElement("tbody") ) :
		elem;
}

// Replace/restore the type attribute of script elements for safe DOM manipulation
function disableScript( elem ) {
	elem.type = (jQuery.find.attr( elem, "type" ) !== null) + "/" + elem.type;
	return elem;
}
function restoreScript( elem ) {
	var match = rscriptTypeMasked.exec( elem.type );
	if ( match ) {
		elem.type = match[1];
	} else {
		elem.removeAttribute("type");
	}
	return elem;
}

// Mark scripts as having already been evaluated
function setGlobalEval( elems, refElements ) {
	var elem,
		i = 0;
	for ( ; (elem = elems[i]) != null; i++ ) {
		jQuery._data( elem, "globalEval", !refElements || jQuery._data( refElements[i], "globalEval" ) );
	}
}

function cloneCopyEvent( src, dest ) {

	if ( dest.nodeType !== 1 || !jQuery.hasData( src ) ) {
		return;
	}

	var type, i, l,
		oldData = jQuery._data( src ),
		curData = jQuery._data( dest, oldData ),
		events = oldData.events;

	if ( events ) {
		delete curData.handle;
		curData.events = {};

		for ( type in events ) {
			for ( i = 0, l = events[ type ].length; i < l; i++ ) {
				jQuery.event.add( dest, type, events[ type ][ i ] );
			}
		}
	}

	// make the cloned public data object a copy from the original
	if ( curData.data ) {
		curData.data = jQuery.extend( {}, curData.data );
	}
}

function fixCloneNodeIssues( src, dest ) {
	var nodeName, e, data;

	// We do not need to do anything for non-Elements
	if ( dest.nodeType !== 1 ) {
		return;
	}

	nodeName = dest.nodeName.toLowerCase();

	// IE6-8 copies events bound via attachEvent when using cloneNode.
	if ( !support.noCloneEvent && dest[ jQuery.expando ] ) {
		data = jQuery._data( dest );

		for ( e in data.events ) {
			jQuery.removeEvent( dest, e, data.handle );
		}

		// Event data gets referenced instead of copied if the expando gets copied too
		dest.removeAttribute( jQuery.expando );
	}

	// IE blanks contents when cloning scripts, and tries to evaluate newly-set text
	if ( nodeName === "script" && dest.text !== src.text ) {
		disableScript( dest ).text = src.text;
		restoreScript( dest );

	// IE6-10 improperly clones children of object elements using classid.
	// IE10 throws NoModificationAllowedError if parent is null, #12132.
	} else if ( nodeName === "object" ) {
		if ( dest.parentNode ) {
			dest.outerHTML = src.outerHTML;
		}

		// This path appears unavoidable for IE9. When cloning an object
		// element in IE9, the outerHTML strategy above is not sufficient.
		// If the src has innerHTML and the destination does not,
		// copy the src.innerHTML into the dest.innerHTML. #10324
		if ( support.html5Clone && ( src.innerHTML && !jQuery.trim(dest.innerHTML) ) ) {
			dest.innerHTML = src.innerHTML;
		}

	} else if ( nodeName === "input" && rcheckableType.test( src.type ) ) {
		// IE6-8 fails to persist the checked state of a cloned checkbox
		// or radio button. Worse, IE6-7 fail to give the cloned element
		// a checked appearance if the defaultChecked value isn't also set

		dest.defaultChecked = dest.checked = src.checked;

		// IE6-7 get confused and end up setting the value of a cloned
		// checkbox/radio button to an empty string instead of "on"
		if ( dest.value !== src.value ) {
			dest.value = src.value;
		}

	// IE6-8 fails to return the selected option to the default selected
	// state when cloning options
	} else if ( nodeName === "option" ) {
		dest.defaultSelected = dest.selected = src.defaultSelected;

	// IE6-8 fails to set the defaultValue to the correct value when
	// cloning other types of input fields
	} else if ( nodeName === "input" || nodeName === "textarea" ) {
		dest.defaultValue = src.defaultValue;
	}
}

jQuery.extend({
	clone: function( elem, dataAndEvents, deepDataAndEvents ) {
		var destElements, node, clone, i, srcElements,
			inPage = jQuery.contains( elem.ownerDocument, elem );

		if ( support.html5Clone || jQuery.isXMLDoc(elem) || !rnoshimcache.test( "<" + elem.nodeName + ">" ) ) {
			clone = elem.cloneNode( true );

		// IE<=8 does not properly clone detached, unknown element nodes
		} else {
			fragmentDiv.innerHTML = elem.outerHTML;
			fragmentDiv.removeChild( clone = fragmentDiv.firstChild );
		}

		if ( (!support.noCloneEvent || !support.noCloneChecked) &&
				(elem.nodeType === 1 || elem.nodeType === 11) && !jQuery.isXMLDoc(elem) ) {

			// We eschew Sizzle here for performance reasons: http://jsperf.com/getall-vs-sizzle/2
			destElements = getAll( clone );
			srcElements = getAll( elem );

			// Fix all IE cloning issues
			for ( i = 0; (node = srcElements[i]) != null; ++i ) {
				// Ensure that the destination node is not null; Fixes #9587
				if ( destElements[i] ) {
					fixCloneNodeIssues( node, destElements[i] );
				}
			}
		}

		// Copy the events from the original to the clone
		if ( dataAndEvents ) {
			if ( deepDataAndEvents ) {
				srcElements = srcElements || getAll( elem );
				destElements = destElements || getAll( clone );

				for ( i = 0; (node = srcElements[i]) != null; i++ ) {
					cloneCopyEvent( node, destElements[i] );
				}
			} else {
				cloneCopyEvent( elem, clone );
			}
		}

		// Preserve script evaluation history
		destElements = getAll( clone, "script" );
		if ( destElements.length > 0 ) {
			setGlobalEval( destElements, !inPage && getAll( elem, "script" ) );
		}

		destElements = srcElements = node = null;

		// Return the cloned set
		return clone;
	},

	buildFragment: function( elems, context, scripts, selection ) {
		var j, elem, contains,
			tmp, tag, tbody, wrap,
			l = elems.length,

			// Ensure a safe fragment
			safe = createSafeFragment( context ),

			nodes = [],
			i = 0;

		for ( ; i < l; i++ ) {
			elem = elems[ i ];

			if ( elem || elem === 0 ) {

				// Add nodes directly
				if ( jQuery.type( elem ) === "object" ) {
					jQuery.merge( nodes, elem.nodeType ? [ elem ] : elem );

				// Convert non-html into a text node
				} else if ( !rhtml.test( elem ) ) {
					nodes.push( context.createTextNode( elem ) );

				// Convert html into DOM nodes
				} else {
					tmp = tmp || safe.appendChild( context.createElement("div") );

					// Deserialize a standard representation
					tag = (rtagName.exec( elem ) || [ "", "" ])[ 1 ].toLowerCase();
					wrap = wrapMap[ tag ] || wrapMap._default;

					tmp.innerHTML = wrap[1] + elem.replace( rxhtmlTag, "<$1></$2>" ) + wrap[2];

					// Descend through wrappers to the right content
					j = wrap[0];
					while ( j-- ) {
						tmp = tmp.lastChild;
					}

					// Manually add leading whitespace removed by IE
					if ( !support.leadingWhitespace && rleadingWhitespace.test( elem ) ) {
						nodes.push( context.createTextNode( rleadingWhitespace.exec( elem )[0] ) );
					}

					// Remove IE's autoinserted <tbody> from table fragments
					if ( !support.tbody ) {

						// String was a <table>, *may* have spurious <tbody>
						elem = tag === "table" && !rtbody.test( elem ) ?
							tmp.firstChild :

							// String was a bare <thead> or <tfoot>
							wrap[1] === "<table>" && !rtbody.test( elem ) ?
								tmp :
								0;

						j = elem && elem.childNodes.length;
						while ( j-- ) {
							if ( jQuery.nodeName( (tbody = elem.childNodes[j]), "tbody" ) && !tbody.childNodes.length ) {
								elem.removeChild( tbody );
							}
						}
					}

					jQuery.merge( nodes, tmp.childNodes );

					// Fix #12392 for WebKit and IE > 9
					tmp.textContent = "";

					// Fix #12392 for oldIE
					while ( tmp.firstChild ) {
						tmp.removeChild( tmp.firstChild );
					}

					// Remember the top-level container for proper cleanup
					tmp = safe.lastChild;
				}
			}
		}

		// Fix #11356: Clear elements from fragment
		if ( tmp ) {
			safe.removeChild( tmp );
		}

		// Reset defaultChecked for any radios and checkboxes
		// about to be appended to the DOM in IE 6/7 (#8060)
		if ( !support.appendChecked ) {
			jQuery.grep( getAll( nodes, "input" ), fixDefaultChecked );
		}

		i = 0;
		while ( (elem = nodes[ i++ ]) ) {

			// #4087 - If origin and destination elements are the same, and this is
			// that element, do not do anything
			if ( selection && jQuery.inArray( elem, selection ) !== -1 ) {
				continue;
			}

			contains = jQuery.contains( elem.ownerDocument, elem );

			// Append to fragment
			tmp = getAll( safe.appendChild( elem ), "script" );

			// Preserve script evaluation history
			if ( contains ) {
				setGlobalEval( tmp );
			}

			// Capture executables
			if ( scripts ) {
				j = 0;
				while ( (elem = tmp[ j++ ]) ) {
					if ( rscriptType.test( elem.type || "" ) ) {
						scripts.push( elem );
					}
				}
			}
		}

		tmp = null;

		return safe;
	},

	cleanData: function( elems, /* internal */ acceptData ) {
		var elem, type, id, data,
			i = 0,
			internalKey = jQuery.expando,
			cache = jQuery.cache,
			deleteExpando = support.deleteExpando,
			special = jQuery.event.special;

		for ( ; (elem = elems[i]) != null; i++ ) {
			if ( acceptData || jQuery.acceptData( elem ) ) {

				id = elem[ internalKey ];
				data = id && cache[ id ];

				if ( data ) {
					if ( data.events ) {
						for ( type in data.events ) {
							if ( special[ type ] ) {
								jQuery.event.remove( elem, type );

							// This is a shortcut to avoid jQuery.event.remove's overhead
							} else {
								jQuery.removeEvent( elem, type, data.handle );
							}
						}
					}

					// Remove cache only if it was not already removed by jQuery.event.remove
					if ( cache[ id ] ) {

						delete cache[ id ];

						// IE does not allow us to delete expando properties from nodes,
						// nor does it have a removeAttribute function on Document nodes;
						// we must handle all of these cases
						if ( deleteExpando ) {
							delete elem[ internalKey ];

						} else if ( typeof elem.removeAttribute !== strundefined ) {
							elem.removeAttribute( internalKey );

						} else {
							elem[ internalKey ] = null;
						}

						deletedIds.push( id );
					}
				}
			}
		}
	}
});

jQuery.fn.extend({
	text: function( value ) {
		return access( this, function( value ) {
			return value === undefined ?
				jQuery.text( this ) :
				this.empty().append( ( this[0] && this[0].ownerDocument || document ).createTextNode( value ) );
		}, null, value, arguments.length );
	},

	append: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.nodeType === 1 || this.nodeType === 11 || this.nodeType === 9 ) {
				var target = manipulationTarget( this, elem );
				target.appendChild( elem );
			}
		});
	},

	prepend: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.nodeType === 1 || this.nodeType === 11 || this.nodeType === 9 ) {
				var target = manipulationTarget( this, elem );
				target.insertBefore( elem, target.firstChild );
			}
		});
	},

	before: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.parentNode ) {
				this.parentNode.insertBefore( elem, this );
			}
		});
	},

	after: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.parentNode ) {
				this.parentNode.insertBefore( elem, this.nextSibling );
			}
		});
	},

	remove: function( selector, keepData /* Internal Use Only */ ) {
		var elem,
			elems = selector ? jQuery.filter( selector, this ) : this,
			i = 0;

		for ( ; (elem = elems[i]) != null; i++ ) {

			if ( !keepData && elem.nodeType === 1 ) {
				jQuery.cleanData( getAll( elem ) );
			}

			if ( elem.parentNode ) {
				if ( keepData && jQuery.contains( elem.ownerDocument, elem ) ) {
					setGlobalEval( getAll( elem, "script" ) );
				}
				elem.parentNode.removeChild( elem );
			}
		}

		return this;
	},

	empty: function() {
		var elem,
			i = 0;

		for ( ; (elem = this[i]) != null; i++ ) {
			// Remove element nodes and prevent memory leaks
			if ( elem.nodeType === 1 ) {
				jQuery.cleanData( getAll( elem, false ) );
			}

			// Remove any remaining nodes
			while ( elem.firstChild ) {
				elem.removeChild( elem.firstChild );
			}

			// If this is a select, ensure that it displays empty (#12336)
			// Support: IE<9
			if ( elem.options && jQuery.nodeName( elem, "select" ) ) {
				elem.options.length = 0;
			}
		}

		return this;
	},

	clone: function( dataAndEvents, deepDataAndEvents ) {
		dataAndEvents = dataAndEvents == null ? false : dataAndEvents;
		deepDataAndEvents = deepDataAndEvents == null ? dataAndEvents : deepDataAndEvents;

		return this.map(function() {
			return jQuery.clone( this, dataAndEvents, deepDataAndEvents );
		});
	},

	html: function( value ) {
		return access( this, function( value ) {
			var elem = this[ 0 ] || {},
				i = 0,
				l = this.length;

			if ( value === undefined ) {
				return elem.nodeType === 1 ?
					elem.innerHTML.replace( rinlinejQuery, "" ) :
					undefined;
			}

			// See if we can take a shortcut and just use innerHTML
			if ( typeof value === "string" && !rnoInnerhtml.test( value ) &&
				( support.htmlSerialize || !rnoshimcache.test( value )  ) &&
				( support.leadingWhitespace || !rleadingWhitespace.test( value ) ) &&
				!wrapMap[ (rtagName.exec( value ) || [ "", "" ])[ 1 ].toLowerCase() ] ) {

				value = value.replace( rxhtmlTag, "<$1></$2>" );

				try {
					for (; i < l; i++ ) {
						// Remove element nodes and prevent memory leaks
						elem = this[i] || {};
						if ( elem.nodeType === 1 ) {
							jQuery.cleanData( getAll( elem, false ) );
							elem.innerHTML = value;
						}
					}

					elem = 0;

				// If using innerHTML throws an exception, use the fallback method
				} catch(e) {}
			}

			if ( elem ) {
				this.empty().append( value );
			}
		}, null, value, arguments.length );
	},

	replaceWith: function() {
		var arg = arguments[ 0 ];

		// Make the changes, replacing each context element with the new content
		this.domManip( arguments, function( elem ) {
			arg = this.parentNode;

			jQuery.cleanData( getAll( this ) );

			if ( arg ) {
				arg.replaceChild( elem, this );
			}
		});

		// Force removal if there was no new content (e.g., from empty arguments)
		return arg && (arg.length || arg.nodeType) ? this : this.remove();
	},

	detach: function( selector ) {
		return this.remove( selector, true );
	},

	domManip: function( args, callback ) {

		// Flatten any nested arrays
		args = concat.apply( [], args );

		var first, node, hasScripts,
			scripts, doc, fragment,
			i = 0,
			l = this.length,
			set = this,
			iNoClone = l - 1,
			value = args[0],
			isFunction = jQuery.isFunction( value );

		// We can't cloneNode fragments that contain checked, in WebKit
		if ( isFunction ||
				( l > 1 && typeof value === "string" &&
					!support.checkClone && rchecked.test( value ) ) ) {
			return this.each(function( index ) {
				var self = set.eq( index );
				if ( isFunction ) {
					args[0] = value.call( this, index, self.html() );
				}
				self.domManip( args, callback );
			});
		}

		if ( l ) {
			fragment = jQuery.buildFragment( args, this[ 0 ].ownerDocument, false, this );
			first = fragment.firstChild;

			if ( fragment.childNodes.length === 1 ) {
				fragment = first;
			}

			if ( first ) {
				scripts = jQuery.map( getAll( fragment, "script" ), disableScript );
				hasScripts = scripts.length;

				// Use the original fragment for the last item instead of the first because it can end up
				// being emptied incorrectly in certain situations (#8070).
				for ( ; i < l; i++ ) {
					node = fragment;

					if ( i !== iNoClone ) {
						node = jQuery.clone( node, true, true );

						// Keep references to cloned scripts for later restoration
						if ( hasScripts ) {
							jQuery.merge( scripts, getAll( node, "script" ) );
						}
					}

					callback.call( this[i], node, i );
				}

				if ( hasScripts ) {
					doc = scripts[ scripts.length - 1 ].ownerDocument;

					// Reenable scripts
					jQuery.map( scripts, restoreScript );

					// Evaluate executable scripts on first document insertion
					for ( i = 0; i < hasScripts; i++ ) {
						node = scripts[ i ];
						if ( rscriptType.test( node.type || "" ) &&
							!jQuery._data( node, "globalEval" ) && jQuery.contains( doc, node ) ) {

							if ( node.src ) {
								// Optional AJAX dependency, but won't run scripts if not present
								if ( jQuery._evalUrl ) {
									jQuery._evalUrl( node.src );
								}
							} else {
								jQuery.globalEval( ( node.text || node.textContent || node.innerHTML || "" ).replace( rcleanScript, "" ) );
							}
						}
					}
				}

				// Fix #11809: Avoid leaking memory
				fragment = first = null;
			}
		}

		return this;
	}
});

jQuery.each({
	appendTo: "append",
	prependTo: "prepend",
	insertBefore: "before",
	insertAfter: "after",
	replaceAll: "replaceWith"
}, function( name, original ) {
	jQuery.fn[ name ] = function( selector ) {
		var elems,
			i = 0,
			ret = [],
			insert = jQuery( selector ),
			last = insert.length - 1;

		for ( ; i <= last; i++ ) {
			elems = i === last ? this : this.clone(true);
			jQuery( insert[i] )[ original ]( elems );

			// Modern browsers can apply jQuery collections as arrays, but oldIE needs a .get()
			push.apply( ret, elems.get() );
		}

		return this.pushStack( ret );
	};
});


var iframe,
	elemdisplay = {};

/**
 * Retrieve the actual display of a element
 * @param {String} name nodeName of the element
 * @param {Object} doc Document object
 */
// Called only from within defaultDisplay
function actualDisplay( name, doc ) {
	var style,
		elem = jQuery( doc.createElement( name ) ).appendTo( doc.body ),

		// getDefaultComputedStyle might be reliably used only on attached element
		display = window.getDefaultComputedStyle && ( style = window.getDefaultComputedStyle( elem[ 0 ] ) ) ?

			// Use of this method is a temporary fix (more like optmization) until something better comes along,
			// since it was removed from specification and supported only in FF
			style.display : jQuery.css( elem[ 0 ], "display" );

	// We don't have any data stored on the element,
	// so use "detach" method as fast way to get rid of the element
	elem.detach();

	return display;
}

/**
 * Try to determine the default display value of an element
 * @param {String} nodeName
 */
function defaultDisplay( nodeName ) {
	var doc = document,
		display = elemdisplay[ nodeName ];

	if ( !display ) {
		display = actualDisplay( nodeName, doc );

		// If the simple way fails, read from inside an iframe
		if ( display === "none" || !display ) {

			// Use the already-created iframe if possible
			iframe = (iframe || jQuery( "<iframe frameborder='0' width='0' height='0'/>" )).appendTo( doc.documentElement );

			// Always write a new HTML skeleton so Webkit and Firefox don't choke on reuse
			doc = ( iframe[ 0 ].contentWindow || iframe[ 0 ].contentDocument ).document;

			// Support: IE
			doc.write();
			doc.close();

			display = actualDisplay( nodeName, doc );
			iframe.detach();
		}

		// Store the correct default display
		elemdisplay[ nodeName ] = display;
	}

	return display;
}


(function() {
	var shrinkWrapBlocksVal;

	support.shrinkWrapBlocks = function() {
		if ( shrinkWrapBlocksVal != null ) {
			return shrinkWrapBlocksVal;
		}

		// Will be changed later if needed.
		shrinkWrapBlocksVal = false;

		// Minified: var b,c,d
		var div, body, container;

		body = document.getElementsByTagName( "body" )[ 0 ];
		if ( !body || !body.style ) {
			// Test fired too early or in an unsupported environment, exit.
			return;
		}

		// Setup
		div = document.createElement( "div" );
		container = document.createElement( "div" );
		container.style.cssText = "position:absolute;border:0;width:0;height:0;top:0;left:-9999px";
		body.appendChild( container ).appendChild( div );

		// Support: IE6
		// Check if elements with layout shrink-wrap their children
		if ( typeof div.style.zoom !== strundefined ) {
			// Reset CSS: box-sizing; display; margin; border
			div.style.cssText =
				// Support: Firefox<29, Android 2.3
				// Vendor-prefix box-sizing
				"-webkit-box-sizing:content-box;-moz-box-sizing:content-box;" +
				"box-sizing:content-box;display:block;margin:0;border:0;" +
				"padding:1px;width:1px;zoom:1";
			div.appendChild( document.createElement( "div" ) ).style.width = "5px";
			shrinkWrapBlocksVal = div.offsetWidth !== 3;
		}

		body.removeChild( container );

		return shrinkWrapBlocksVal;
	};

})();
var rmargin = (/^margin/);

var rnumnonpx = new RegExp( "^(" + pnum + ")(?!px)[a-z%]+$", "i" );



var getStyles, curCSS,
	rposition = /^(top|right|bottom|left)$/;

if ( window.getComputedStyle ) {
	getStyles = function( elem ) {
		return elem.ownerDocument.defaultView.getComputedStyle( elem, null );
	};

	curCSS = function( elem, name, computed ) {
		var width, minWidth, maxWidth, ret,
			style = elem.style;

		computed = computed || getStyles( elem );

		// getPropertyValue is only needed for .css('filter') in IE9, see #12537
		ret = computed ? computed.getPropertyValue( name ) || computed[ name ] : undefined;

		if ( computed ) {

			if ( ret === "" && !jQuery.contains( elem.ownerDocument, elem ) ) {
				ret = jQuery.style( elem, name );
			}

			// A tribute to the "awesome hack by Dean Edwards"
			// Chrome < 17 and Safari 5.0 uses "computed value" instead of "used value" for margin-right
			// Safari 5.1.7 (at least) returns percentage for a larger set of values, but width seems to be reliably pixels
			// this is against the CSSOM draft spec: http://dev.w3.org/csswg/cssom/#resolved-values
			if ( rnumnonpx.test( ret ) && rmargin.test( name ) ) {

				// Remember the original values
				width = style.width;
				minWidth = style.minWidth;
				maxWidth = style.maxWidth;

				// Put in the new values to get a computed value out
				style.minWidth = style.maxWidth = style.width = ret;
				ret = computed.width;

				// Revert the changed values
				style.width = width;
				style.minWidth = minWidth;
				style.maxWidth = maxWidth;
			}
		}

		// Support: IE
		// IE returns zIndex value as an integer.
		return ret === undefined ?
			ret :
			ret + "";
	};
} else if ( document.documentElement.currentStyle ) {
	getStyles = function( elem ) {
		return elem.currentStyle;
	};

	curCSS = function( elem, name, computed ) {
		var left, rs, rsLeft, ret,
			style = elem.style;

		computed = computed || getStyles( elem );
		ret = computed ? computed[ name ] : undefined;

		// Avoid setting ret to empty string here
		// so we don't default to auto
		if ( ret == null && style && style[ name ] ) {
			ret = style[ name ];
		}

		// From the awesome hack by Dean Edwards
		// http://erik.eae.net/archives/2007/07/27/18.54.15/#comment-102291

		// If we're not dealing with a regular pixel number
		// but a number that has a weird ending, we need to convert it to pixels
		// but not position css attributes, as those are proportional to the parent element instead
		// and we can't measure the parent instead because it might trigger a "stacking dolls" problem
		if ( rnumnonpx.test( ret ) && !rposition.test( name ) ) {

			// Remember the original values
			left = style.left;
			rs = elem.runtimeStyle;
			rsLeft = rs && rs.left;

			// Put in the new values to get a computed value out
			if ( rsLeft ) {
				rs.left = elem.currentStyle.left;
			}
			style.left = name === "fontSize" ? "1em" : ret;
			ret = style.pixelLeft + "px";

			// Revert the changed values
			style.left = left;
			if ( rsLeft ) {
				rs.left = rsLeft;
			}
		}

		// Support: IE
		// IE returns zIndex value as an integer.
		return ret === undefined ?
			ret :
			ret + "" || "auto";
	};
}




function addGetHookIf( conditionFn, hookFn ) {
	// Define the hook, we'll check on the first run if it's really needed.
	return {
		get: function() {
			var condition = conditionFn();

			if ( condition == null ) {
				// The test was not ready at this point; screw the hook this time
				// but check again when needed next time.
				return;
			}

			if ( condition ) {
				// Hook not needed (or it's not possible to use it due to missing dependency),
				// remove it.
				// Since there are no other hooks for marginRight, remove the whole object.
				delete this.get;
				return;
			}

			// Hook needed; redefine it so that the support test is not executed again.

			return (this.get = hookFn).apply( this, arguments );
		}
	};
}


(function() {
	// Minified: var b,c,d,e,f,g, h,i
	var div, style, a, pixelPositionVal, boxSizingReliableVal,
		reliableHiddenOffsetsVal, reliableMarginRightVal;

	// Setup
	div = document.createElement( "div" );
	div.innerHTML = "  <link/><table></table><a href='/a'>a</a><input type='checkbox'/>";
	a = div.getElementsByTagName( "a" )[ 0 ];
	style = a && a.style;

	// Finish early in limited (non-browser) environments
	if ( !style ) {
		return;
	}

	style.cssText = "float:left;opacity:.5";

	// Support: IE<9
	// Make sure that element opacity exists (as opposed to filter)
	support.opacity = style.opacity === "0.5";

	// Verify style float existence
	// (IE uses styleFloat instead of cssFloat)
	support.cssFloat = !!style.cssFloat;

	div.style.backgroundClip = "content-box";
	div.cloneNode( true ).style.backgroundClip = "";
	support.clearCloneStyle = div.style.backgroundClip === "content-box";

	// Support: Firefox<29, Android 2.3
	// Vendor-prefix box-sizing
	support.boxSizing = style.boxSizing === "" || style.MozBoxSizing === "" ||
		style.WebkitBoxSizing === "";

	jQuery.extend(support, {
		reliableHiddenOffsets: function() {
			if ( reliableHiddenOffsetsVal == null ) {
				computeStyleTests();
			}
			return reliableHiddenOffsetsVal;
		},

		boxSizingReliable: function() {
			if ( boxSizingReliableVal == null ) {
				computeStyleTests();
			}
			return boxSizingReliableVal;
		},

		pixelPosition: function() {
			if ( pixelPositionVal == null ) {
				computeStyleTests();
			}
			return pixelPositionVal;
		},

		// Support: Android 2.3
		reliableMarginRight: function() {
			if ( reliableMarginRightVal == null ) {
				computeStyleTests();
			}
			return reliableMarginRightVal;
		}
	});

	function computeStyleTests() {
		// Minified: var b,c,d,j
		var div, body, container, contents;

		body = document.getElementsByTagName( "body" )[ 0 ];
		if ( !body || !body.style ) {
			// Test fired too early or in an unsupported environment, exit.
			return;
		}

		// Setup
		div = document.createElement( "div" );
		container = document.createElement( "div" );
		container.style.cssText = "position:absolute;border:0;width:0;height:0;top:0;left:-9999px";
		body.appendChild( container ).appendChild( div );

		div.style.cssText =
			// Support: Firefox<29, Android 2.3
			// Vendor-prefix box-sizing
			"-webkit-box-sizing:border-box;-moz-box-sizing:border-box;" +
			"box-sizing:border-box;display:block;margin-top:1%;top:1%;" +
			"border:1px;padding:1px;width:4px;position:absolute";

		// Support: IE<9
		// Assume reasonable values in the absence of getComputedStyle
		pixelPositionVal = boxSizingReliableVal = false;
		reliableMarginRightVal = true;

		// Check for getComputedStyle so that this code is not run in IE<9.
		if ( window.getComputedStyle ) {
			pixelPositionVal = ( window.getComputedStyle( div, null ) || {} ).top !== "1%";
			boxSizingReliableVal =
				( window.getComputedStyle( div, null ) || { width: "4px" } ).width === "4px";

			// Support: Android 2.3
			// Div with explicit width and no margin-right incorrectly
			// gets computed margin-right based on width of container (#3333)
			// WebKit Bug 13343 - getComputedStyle returns wrong value for margin-right
			contents = div.appendChild( document.createElement( "div" ) );

			// Reset CSS: box-sizing; display; margin; border; padding
			contents.style.cssText = div.style.cssText =
				// Support: Firefox<29, Android 2.3
				// Vendor-prefix box-sizing
				"-webkit-box-sizing:content-box;-moz-box-sizing:content-box;" +
				"box-sizing:content-box;display:block;margin:0;border:0;padding:0";
			contents.style.marginRight = contents.style.width = "0";
			div.style.width = "1px";

			reliableMarginRightVal =
				!parseFloat( ( window.getComputedStyle( contents, null ) || {} ).marginRight );
		}

		// Support: IE8
		// Check if table cells still have offsetWidth/Height when they are set
		// to display:none and there are still other visible table cells in a
		// table row; if so, offsetWidth/Height are not reliable for use when
		// determining if an element has been hidden directly using
		// display:none (it is still safe to use offsets if a parent element is
		// hidden; don safety goggles and see bug #4512 for more information).
		div.innerHTML = "<table><tr><td></td><td>t</td></tr></table>";
		contents = div.getElementsByTagName( "td" );
		contents[ 0 ].style.cssText = "margin:0;border:0;padding:0;display:none";
		reliableHiddenOffsetsVal = contents[ 0 ].offsetHeight === 0;
		if ( reliableHiddenOffsetsVal ) {
			contents[ 0 ].style.display = "";
			contents[ 1 ].style.display = "none";
			reliableHiddenOffsetsVal = contents[ 0 ].offsetHeight === 0;
		}

		body.removeChild( container );
	}

})();


// A method for quickly swapping in/out CSS properties to get correct calculations.
jQuery.swap = function( elem, options, callback, args ) {
	var ret, name,
		old = {};

	// Remember the old values, and insert the new ones
	for ( name in options ) {
		old[ name ] = elem.style[ name ];
		elem.style[ name ] = options[ name ];
	}

	ret = callback.apply( elem, args || [] );

	// Revert the old values
	for ( name in options ) {
		elem.style[ name ] = old[ name ];
	}

	return ret;
};


var
		ralpha = /alpha\([^)]*\)/i,
	ropacity = /opacity\s*=\s*([^)]*)/,

	// swappable if display is none or starts with table except "table", "table-cell", or "table-caption"
	// see here for display values: https://developer.mozilla.org/en-US/docs/CSS/display
	rdisplayswap = /^(none|table(?!-c[ea]).+)/,
	rnumsplit = new RegExp( "^(" + pnum + ")(.*)$", "i" ),
	rrelNum = new RegExp( "^([+-])=(" + pnum + ")", "i" ),

	cssShow = { position: "absolute", visibility: "hidden", display: "block" },
	cssNormalTransform = {
		letterSpacing: "0",
		fontWeight: "400"
	},

	cssPrefixes = [ "Webkit", "O", "Moz", "ms" ];


// return a css property mapped to a potentially vendor prefixed property
function vendorPropName( style, name ) {

	// shortcut for names that are not vendor prefixed
	if ( name in style ) {
		return name;
	}

	// check for vendor prefixed names
	var capName = name.charAt(0).toUpperCase() + name.slice(1),
		origName = name,
		i = cssPrefixes.length;

	while ( i-- ) {
		name = cssPrefixes[ i ] + capName;
		if ( name in style ) {
			return name;
		}
	}

	return origName;
}

function showHide( elements, show ) {
	var display, elem, hidden,
		values = [],
		index = 0,
		length = elements.length;

	for ( ; index < length; index++ ) {
		elem = elements[ index ];
		if ( !elem.style ) {
			continue;
		}

		values[ index ] = jQuery._data( elem, "olddisplay" );
		display = elem.style.display;
		if ( show ) {
			// Reset the inline display of this element to learn if it is
			// being hidden by cascaded rules or not
			if ( !values[ index ] && display === "none" ) {
				elem.style.display = "";
			}

			// Set elements which have been overridden with display: none
			// in a stylesheet to whatever the default browser style is
			// for such an element
			if ( elem.style.display === "" && isHidden( elem ) ) {
				values[ index ] = jQuery._data( elem, "olddisplay", defaultDisplay(elem.nodeName) );
			}
		} else {
			hidden = isHidden( elem );

			if ( display && display !== "none" || !hidden ) {
				jQuery._data( elem, "olddisplay", hidden ? display : jQuery.css( elem, "display" ) );
			}
		}
	}

	// Set the display of most of the elements in a second loop
	// to avoid the constant reflow
	for ( index = 0; index < length; index++ ) {
		elem = elements[ index ];
		if ( !elem.style ) {
			continue;
		}
		if ( !show || elem.style.display === "none" || elem.style.display === "" ) {
			elem.style.display = show ? values[ index ] || "" : "none";
		}
	}

	return elements;
}

function setPositiveNumber( elem, value, subtract ) {
	var matches = rnumsplit.exec( value );
	return matches ?
		// Guard against undefined "subtract", e.g., when used as in cssHooks
		Math.max( 0, matches[ 1 ] - ( subtract || 0 ) ) + ( matches[ 2 ] || "px" ) :
		value;
}

function augmentWidthOrHeight( elem, name, extra, isBorderBox, styles ) {
	var i = extra === ( isBorderBox ? "border" : "content" ) ?
		// If we already have the right measurement, avoid augmentation
		4 :
		// Otherwise initialize for horizontal or vertical properties
		name === "width" ? 1 : 0,

		val = 0;

	for ( ; i < 4; i += 2 ) {
		// both box models exclude margin, so add it if we want it
		if ( extra === "margin" ) {
			val += jQuery.css( elem, extra + cssExpand[ i ], true, styles );
		}

		if ( isBorderBox ) {
			// border-box includes padding, so remove it if we want content
			if ( extra === "content" ) {
				val -= jQuery.css( elem, "padding" + cssExpand[ i ], true, styles );
			}

			// at this point, extra isn't border nor margin, so remove border
			if ( extra !== "margin" ) {
				val -= jQuery.css( elem, "border" + cssExpand[ i ] + "Width", true, styles );
			}
		} else {
			// at this point, extra isn't content, so add padding
			val += jQuery.css( elem, "padding" + cssExpand[ i ], true, styles );

			// at this point, extra isn't content nor padding, so add border
			if ( extra !== "padding" ) {
				val += jQuery.css( elem, "border" + cssExpand[ i ] + "Width", true, styles );
			}
		}
	}

	return val;
}

function getWidthOrHeight( elem, name, extra ) {

	// Start with offset property, which is equivalent to the border-box value
	var valueIsBorderBox = true,
		val = name === "width" ? elem.offsetWidth : elem.offsetHeight,
		styles = getStyles( elem ),
		isBorderBox = support.boxSizing && jQuery.css( elem, "boxSizing", false, styles ) === "border-box";

	// some non-html elements return undefined for offsetWidth, so check for null/undefined
	// svg - https://bugzilla.mozilla.org/show_bug.cgi?id=649285
	// MathML - https://bugzilla.mozilla.org/show_bug.cgi?id=491668
	if ( val <= 0 || val == null ) {
		// Fall back to computed then uncomputed css if necessary
		val = curCSS( elem, name, styles );
		if ( val < 0 || val == null ) {
			val = elem.style[ name ];
		}

		// Computed unit is not pixels. Stop here and return.
		if ( rnumnonpx.test(val) ) {
			return val;
		}

		// we need the check for style in case a browser which returns unreliable values
		// for getComputedStyle silently falls back to the reliable elem.style
		valueIsBorderBox = isBorderBox && ( support.boxSizingReliable() || val === elem.style[ name ] );

		// Normalize "", auto, and prepare for extra
		val = parseFloat( val ) || 0;
	}

	// use the active box-sizing model to add/subtract irrelevant styles
	return ( val +
		augmentWidthOrHeight(
			elem,
			name,
			extra || ( isBorderBox ? "border" : "content" ),
			valueIsBorderBox,
			styles
		)
	) + "px";
}

jQuery.extend({
	// Add in style property hooks for overriding the default
	// behavior of getting and setting a style property
	cssHooks: {
		opacity: {
			get: function( elem, computed ) {
				if ( computed ) {
					// We should always get a number back from opacity
					var ret = curCSS( elem, "opacity" );
					return ret === "" ? "1" : ret;
				}
			}
		}
	},

	// Don't automatically add "px" to these possibly-unitless properties
	cssNumber: {
		"columnCount": true,
		"fillOpacity": true,
		"flexGrow": true,
		"flexShrink": true,
		"fontWeight": true,
		"lineHeight": true,
		"opacity": true,
		"order": true,
		"orphans": true,
		"widows": true,
		"zIndex": true,
		"zoom": true
	},

	// Add in properties whose names you wish to fix before
	// setting or getting the value
	cssProps: {
		// normalize float css property
		"float": support.cssFloat ? "cssFloat" : "styleFloat"
	},

	// Get and set the style property on a DOM Node
	style: function( elem, name, value, extra ) {
		// Don't set styles on text and comment nodes
		if ( !elem || elem.nodeType === 3 || elem.nodeType === 8 || !elem.style ) {
			return;
		}

		// Make sure that we're working with the right name
		var ret, type, hooks,
			origName = jQuery.camelCase( name ),
			style = elem.style;

		name = jQuery.cssProps[ origName ] || ( jQuery.cssProps[ origName ] = vendorPropName( style, origName ) );

		// gets hook for the prefixed version
		// followed by the unprefixed version
		hooks = jQuery.cssHooks[ name ] || jQuery.cssHooks[ origName ];

		// Check if we're setting a value
		if ( value !== undefined ) {
			type = typeof value;

			// convert relative number strings (+= or -=) to relative numbers. #7345
			if ( type === "string" && (ret = rrelNum.exec( value )) ) {
				value = ( ret[1] + 1 ) * ret[2] + parseFloat( jQuery.css( elem, name ) );
				// Fixes bug #9237
				type = "number";
			}

			// Make sure that null and NaN values aren't set. See: #7116
			if ( value == null || value !== value ) {
				return;
			}

			// If a number was passed in, add 'px' to the (except for certain CSS properties)
			if ( type === "number" && !jQuery.cssNumber[ origName ] ) {
				value += "px";
			}

			// Fixes #8908, it can be done more correctly by specifing setters in cssHooks,
			// but it would mean to define eight (for every problematic property) identical functions
			if ( !support.clearCloneStyle && value === "" && name.indexOf("background") === 0 ) {
				style[ name ] = "inherit";
			}

			// If a hook was provided, use that value, otherwise just set the specified value
			if ( !hooks || !("set" in hooks) || (value = hooks.set( elem, value, extra )) !== undefined ) {

				// Support: IE
				// Swallow errors from 'invalid' CSS values (#5509)
				try {
					style[ name ] = value;
				} catch(e) {}
			}

		} else {
			// If a hook was provided get the non-computed value from there
			if ( hooks && "get" in hooks && (ret = hooks.get( elem, false, extra )) !== undefined ) {
				return ret;
			}

			// Otherwise just get the value from the style object
			return style[ name ];
		}
	},

	css: function( elem, name, extra, styles ) {
		var num, val, hooks,
			origName = jQuery.camelCase( name );

		// Make sure that we're working with the right name
		name = jQuery.cssProps[ origName ] || ( jQuery.cssProps[ origName ] = vendorPropName( elem.style, origName ) );

		// gets hook for the prefixed version
		// followed by the unprefixed version
		hooks = jQuery.cssHooks[ name ] || jQuery.cssHooks[ origName ];

		// If a hook was provided get the computed value from there
		if ( hooks && "get" in hooks ) {
			val = hooks.get( elem, true, extra );
		}

		// Otherwise, if a way to get the computed value exists, use that
		if ( val === undefined ) {
			val = curCSS( elem, name, styles );
		}

		//convert "normal" to computed value
		if ( val === "normal" && name in cssNormalTransform ) {
			val = cssNormalTransform[ name ];
		}

		// Return, converting to number if forced or a qualifier was provided and val looks numeric
		if ( extra === "" || extra ) {
			num = parseFloat( val );
			return extra === true || jQuery.isNumeric( num ) ? num || 0 : val;
		}
		return val;
	}
});

jQuery.each([ "height", "width" ], function( i, name ) {
	jQuery.cssHooks[ name ] = {
		get: function( elem, computed, extra ) {
			if ( computed ) {
				// certain elements can have dimension info if we invisibly show them
				// however, it must have a current display style that would benefit from this
				return rdisplayswap.test( jQuery.css( elem, "display" ) ) && elem.offsetWidth === 0 ?
					jQuery.swap( elem, cssShow, function() {
						return getWidthOrHeight( elem, name, extra );
					}) :
					getWidthOrHeight( elem, name, extra );
			}
		},

		set: function( elem, value, extra ) {
			var styles = extra && getStyles( elem );
			return setPositiveNumber( elem, value, extra ?
				augmentWidthOrHeight(
					elem,
					name,
					extra,
					support.boxSizing && jQuery.css( elem, "boxSizing", false, styles ) === "border-box",
					styles
				) : 0
			);
		}
	};
});

if ( !support.opacity ) {
	jQuery.cssHooks.opacity = {
		get: function( elem, computed ) {
			// IE uses filters for opacity
			return ropacity.test( (computed && elem.currentStyle ? elem.currentStyle.filter : elem.style.filter) || "" ) ?
				( 0.01 * parseFloat( RegExp.$1 ) ) + "" :
				computed ? "1" : "";
		},

		set: function( elem, value ) {
			var style = elem.style,
				currentStyle = elem.currentStyle,
				opacity = jQuery.isNumeric( value ) ? "alpha(opacity=" + value * 100 + ")" : "",
				filter = currentStyle && currentStyle.filter || style.filter || "";

			// IE has trouble with opacity if it does not have layout
			// Force it by setting the zoom level
			style.zoom = 1;

			// if setting opacity to 1, and no other filters exist - attempt to remove filter attribute #6652
			// if value === "", then remove inline opacity #12685
			if ( ( value >= 1 || value === "" ) &&
					jQuery.trim( filter.replace( ralpha, "" ) ) === "" &&
					style.removeAttribute ) {

				// Setting style.filter to null, "" & " " still leave "filter:" in the cssText
				// if "filter:" is present at all, clearType is disabled, we want to avoid this
				// style.removeAttribute is IE Only, but so apparently is this code path...
				style.removeAttribute( "filter" );

				// if there is no filter style applied in a css rule or unset inline opacity, we are done
				if ( value === "" || currentStyle && !currentStyle.filter ) {
					return;
				}
			}

			// otherwise, set new filter values
			style.filter = ralpha.test( filter ) ?
				filter.replace( ralpha, opacity ) :
				filter + " " + opacity;
		}
	};
}

jQuery.cssHooks.marginRight = addGetHookIf( support.reliableMarginRight,
	function( elem, computed ) {
		if ( computed ) {
			// WebKit Bug 13343 - getComputedStyle returns wrong value for margin-right
			// Work around by temporarily setting element display to inline-block
			return jQuery.swap( elem, { "display": "inline-block" },
				curCSS, [ elem, "marginRight" ] );
		}
	}
);

// These hooks are used by animate to expand properties
jQuery.each({
	margin: "",
	padding: "",
	border: "Width"
}, function( prefix, suffix ) {
	jQuery.cssHooks[ prefix + suffix ] = {
		expand: function( value ) {
			var i = 0,
				expanded = {},

				// assumes a single number if not a string
				parts = typeof value === "string" ? value.split(" ") : [ value ];

			for ( ; i < 4; i++ ) {
				expanded[ prefix + cssExpand[ i ] + suffix ] =
					parts[ i ] || parts[ i - 2 ] || parts[ 0 ];
			}

			return expanded;
		}
	};

	if ( !rmargin.test( prefix ) ) {
		jQuery.cssHooks[ prefix + suffix ].set = setPositiveNumber;
	}
});

jQuery.fn.extend({
	css: function( name, value ) {
		return access( this, function( elem, name, value ) {
			var styles, len,
				map = {},
				i = 0;

			if ( jQuery.isArray( name ) ) {
				styles = getStyles( elem );
				len = name.length;

				for ( ; i < len; i++ ) {
					map[ name[ i ] ] = jQuery.css( elem, name[ i ], false, styles );
				}

				return map;
			}

			return value !== undefined ?
				jQuery.style( elem, name, value ) :
				jQuery.css( elem, name );
		}, name, value, arguments.length > 1 );
	},
	show: function() {
		return showHide( this, true );
	},
	hide: function() {
		return showHide( this );
	},
	toggle: function( state ) {
		if ( typeof state === "boolean" ) {
			return state ? this.show() : this.hide();
		}

		return this.each(function() {
			if ( isHidden( this ) ) {
				jQuery( this ).show();
			} else {
				jQuery( this ).hide();
			}
		});
	}
});


function Tween( elem, options, prop, end, easing ) {
	return new Tween.prototype.init( elem, options, prop, end, easing );
}
jQuery.Tween = Tween;

Tween.prototype = {
	constructor: Tween,
	init: function( elem, options, prop, end, easing, unit ) {
		this.elem = elem;
		this.prop = prop;
		this.easing = easing || "swing";
		this.options = options;
		this.start = this.now = this.cur();
		this.end = end;
		this.unit = unit || ( jQuery.cssNumber[ prop ] ? "" : "px" );
	},
	cur: function() {
		var hooks = Tween.propHooks[ this.prop ];

		return hooks && hooks.get ?
			hooks.get( this ) :
			Tween.propHooks._default.get( this );
	},
	run: function( percent ) {
		var eased,
			hooks = Tween.propHooks[ this.prop ];

		if ( this.options.duration ) {
			this.pos = eased = jQuery.easing[ this.easing ](
				percent, this.options.duration * percent, 0, 1, this.options.duration
			);
		} else {
			this.pos = eased = percent;
		}
		this.now = ( this.end - this.start ) * eased + this.start;

		if ( this.options.step ) {
			this.options.step.call( this.elem, this.now, this );
		}

		if ( hooks && hooks.set ) {
			hooks.set( this );
		} else {
			Tween.propHooks._default.set( this );
		}
		return this;
	}
};

Tween.prototype.init.prototype = Tween.prototype;

Tween.propHooks = {
	_default: {
		get: function( tween ) {
			var result;

			if ( tween.elem[ tween.prop ] != null &&
				(!tween.elem.style || tween.elem.style[ tween.prop ] == null) ) {
				return tween.elem[ tween.prop ];
			}

			// passing an empty string as a 3rd parameter to .css will automatically
			// attempt a parseFloat and fallback to a string if the parse fails
			// so, simple values such as "10px" are parsed to Float.
			// complex values such as "rotate(1rad)" are returned as is.
			result = jQuery.css( tween.elem, tween.prop, "" );
			// Empty strings, null, undefined and "auto" are converted to 0.
			return !result || result === "auto" ? 0 : result;
		},
		set: function( tween ) {
			// use step hook for back compat - use cssHook if its there - use .style if its
			// available and use plain properties where available
			if ( jQuery.fx.step[ tween.prop ] ) {
				jQuery.fx.step[ tween.prop ]( tween );
			} else if ( tween.elem.style && ( tween.elem.style[ jQuery.cssProps[ tween.prop ] ] != null || jQuery.cssHooks[ tween.prop ] ) ) {
				jQuery.style( tween.elem, tween.prop, tween.now + tween.unit );
			} else {
				tween.elem[ tween.prop ] = tween.now;
			}
		}
	}
};

// Support: IE <=9
// Panic based approach to setting things on disconnected nodes

Tween.propHooks.scrollTop = Tween.propHooks.scrollLeft = {
	set: function( tween ) {
		if ( tween.elem.nodeType && tween.elem.parentNode ) {
			tween.elem[ tween.prop ] = tween.now;
		}
	}
};

jQuery.easing = {
	linear: function( p ) {
		return p;
	},
	swing: function( p ) {
		return 0.5 - Math.cos( p * Math.PI ) / 2;
	}
};

jQuery.fx = Tween.prototype.init;

// Back Compat <1.8 extension point
jQuery.fx.step = {};




var
	fxNow, timerId,
	rfxtypes = /^(?:toggle|show|hide)$/,
	rfxnum = new RegExp( "^(?:([+-])=|)(" + pnum + ")([a-z%]*)$", "i" ),
	rrun = /queueHooks$/,
	animationPrefilters = [ defaultPrefilter ],
	tweeners = {
		"*": [ function( prop, value ) {
			var tween = this.createTween( prop, value ),
				target = tween.cur(),
				parts = rfxnum.exec( value ),
				unit = parts && parts[ 3 ] || ( jQuery.cssNumber[ prop ] ? "" : "px" ),

				// Starting value computation is required for potential unit mismatches
				start = ( jQuery.cssNumber[ prop ] || unit !== "px" && +target ) &&
					rfxnum.exec( jQuery.css( tween.elem, prop ) ),
				scale = 1,
				maxIterations = 20;

			if ( start && start[ 3 ] !== unit ) {
				// Trust units reported by jQuery.css
				unit = unit || start[ 3 ];

				// Make sure we update the tween properties later on
				parts = parts || [];

				// Iteratively approximate from a nonzero starting point
				start = +target || 1;

				do {
					// If previous iteration zeroed out, double until we get *something*
					// Use a string for doubling factor so we don't accidentally see scale as unchanged below
					scale = scale || ".5";

					// Adjust and apply
					start = start / scale;
					jQuery.style( tween.elem, prop, start + unit );

				// Update scale, tolerating zero or NaN from tween.cur()
				// And breaking the loop if scale is unchanged or perfect, or if we've just had enough
				} while ( scale !== (scale = tween.cur() / target) && scale !== 1 && --maxIterations );
			}

			// Update tween properties
			if ( parts ) {
				start = tween.start = +start || +target || 0;
				tween.unit = unit;
				// If a +=/-= token was provided, we're doing a relative animation
				tween.end = parts[ 1 ] ?
					start + ( parts[ 1 ] + 1 ) * parts[ 2 ] :
					+parts[ 2 ];
			}

			return tween;
		} ]
	};

// Animations created synchronously will run synchronously
function createFxNow() {
	setTimeout(function() {
		fxNow = undefined;
	});
	return ( fxNow = jQuery.now() );
}

// Generate parameters to create a standard animation
function genFx( type, includeWidth ) {
	var which,
		attrs = { height: type },
		i = 0;

	// if we include width, step value is 1 to do all cssExpand values,
	// if we don't include width, step value is 2 to skip over Left and Right
	includeWidth = includeWidth ? 1 : 0;
	for ( ; i < 4 ; i += 2 - includeWidth ) {
		which = cssExpand[ i ];
		attrs[ "margin" + which ] = attrs[ "padding" + which ] = type;
	}

	if ( includeWidth ) {
		attrs.opacity = attrs.width = type;
	}

	return attrs;
}

function createTween( value, prop, animation ) {
	var tween,
		collection = ( tweeners[ prop ] || [] ).concat( tweeners[ "*" ] ),
		index = 0,
		length = collection.length;
	for ( ; index < length; index++ ) {
		if ( (tween = collection[ index ].call( animation, prop, value )) ) {

			// we're done with this property
			return tween;
		}
	}
}

function defaultPrefilter( elem, props, opts ) {
	/* jshint validthis: true */
	var prop, value, toggle, tween, hooks, oldfire, display, checkDisplay,
		anim = this,
		orig = {},
		style = elem.style,
		hidden = elem.nodeType && isHidden( elem ),
		dataShow = jQuery._data( elem, "fxshow" );

	// handle queue: false promises
	if ( !opts.queue ) {
		hooks = jQuery._queueHooks( elem, "fx" );
		if ( hooks.unqueued == null ) {
			hooks.unqueued = 0;
			oldfire = hooks.empty.fire;
			hooks.empty.fire = function() {
				if ( !hooks.unqueued ) {
					oldfire();
				}
			};
		}
		hooks.unqueued++;

		anim.always(function() {
			// doing this makes sure that the complete handler will be called
			// before this completes
			anim.always(function() {
				hooks.unqueued--;
				if ( !jQuery.queue( elem, "fx" ).length ) {
					hooks.empty.fire();
				}
			});
		});
	}

	// height/width overflow pass
	if ( elem.nodeType === 1 && ( "height" in props || "width" in props ) ) {
		// Make sure that nothing sneaks out
		// Record all 3 overflow attributes because IE does not
		// change the overflow attribute when overflowX and
		// overflowY are set to the same value
		opts.overflow = [ style.overflow, style.overflowX, style.overflowY ];

		// Set display property to inline-block for height/width
		// animations on inline elements that are having width/height animated
		display = jQuery.css( elem, "display" );

		// Test default display if display is currently "none"
		checkDisplay = display === "none" ?
			jQuery._data( elem, "olddisplay" ) || defaultDisplay( elem.nodeName ) : display;

		if ( checkDisplay === "inline" && jQuery.css( elem, "float" ) === "none" ) {

			// inline-level elements accept inline-block;
			// block-level elements need to be inline with layout
			if ( !support.inlineBlockNeedsLayout || defaultDisplay( elem.nodeName ) === "inline" ) {
				style.display = "inline-block";
			} else {
				style.zoom = 1;
			}
		}
	}

	if ( opts.overflow ) {
		style.overflow = "hidden";
		if ( !support.shrinkWrapBlocks() ) {
			anim.always(function() {
				style.overflow = opts.overflow[ 0 ];
				style.overflowX = opts.overflow[ 1 ];
				style.overflowY = opts.overflow[ 2 ];
			});
		}
	}

	// show/hide pass
	for ( prop in props ) {
		value = props[ prop ];
		if ( rfxtypes.exec( value ) ) {
			delete props[ prop ];
			toggle = toggle || value === "toggle";
			if ( value === ( hidden ? "hide" : "show" ) ) {

				// If there is dataShow left over from a stopped hide or show and we are going to proceed with show, we should pretend to be hidden
				if ( value === "show" && dataShow && dataShow[ prop ] !== undefined ) {
					hidden = true;
				} else {
					continue;
				}
			}
			orig[ prop ] = dataShow && dataShow[ prop ] || jQuery.style( elem, prop );

		// Any non-fx value stops us from restoring the original display value
		} else {
			display = undefined;
		}
	}

	if ( !jQuery.isEmptyObject( orig ) ) {
		if ( dataShow ) {
			if ( "hidden" in dataShow ) {
				hidden = dataShow.hidden;
			}
		} else {
			dataShow = jQuery._data( elem, "fxshow", {} );
		}

		// store state if its toggle - enables .stop().toggle() to "reverse"
		if ( toggle ) {
			dataShow.hidden = !hidden;
		}
		if ( hidden ) {
			jQuery( elem ).show();
		} else {
			anim.done(function() {
				jQuery( elem ).hide();
			});
		}
		anim.done(function() {
			var prop;
			jQuery._removeData( elem, "fxshow" );
			for ( prop in orig ) {
				jQuery.style( elem, prop, orig[ prop ] );
			}
		});
		for ( prop in orig ) {
			tween = createTween( hidden ? dataShow[ prop ] : 0, prop, anim );

			if ( !( prop in dataShow ) ) {
				dataShow[ prop ] = tween.start;
				if ( hidden ) {
					tween.end = tween.start;
					tween.start = prop === "width" || prop === "height" ? 1 : 0;
				}
			}
		}

	// If this is a noop like .hide().hide(), restore an overwritten display value
	} else if ( (display === "none" ? defaultDisplay( elem.nodeName ) : display) === "inline" ) {
		style.display = display;
	}
}

function propFilter( props, specialEasing ) {
	var index, name, easing, value, hooks;

	// camelCase, specialEasing and expand cssHook pass
	for ( index in props ) {
		name = jQuery.camelCase( index );
		easing = specialEasing[ name ];
		value = props[ index ];
		if ( jQuery.isArray( value ) ) {
			easing = value[ 1 ];
			value = props[ index ] = value[ 0 ];
		}

		if ( index !== name ) {
			props[ name ] = value;
			delete props[ index ];
		}

		hooks = jQuery.cssHooks[ name ];
		if ( hooks && "expand" in hooks ) {
			value = hooks.expand( value );
			delete props[ name ];

			// not quite $.extend, this wont overwrite keys already present.
			// also - reusing 'index' from above because we have the correct "name"
			for ( index in value ) {
				if ( !( index in props ) ) {
					props[ index ] = value[ index ];
					specialEasing[ index ] = easing;
				}
			}
		} else {
			specialEasing[ name ] = easing;
		}
	}
}

function Animation( elem, properties, options ) {
	var result,
		stopped,
		index = 0,
		length = animationPrefilters.length,
		deferred = jQuery.Deferred().always( function() {
			// don't match elem in the :animated selector
			delete tick.elem;
		}),
		tick = function() {
			if ( stopped ) {
				return false;
			}
			var currentTime = fxNow || createFxNow(),
				remaining = Math.max( 0, animation.startTime + animation.duration - currentTime ),
				// archaic crash bug won't allow us to use 1 - ( 0.5 || 0 ) (#12497)
				temp = remaining / animation.duration || 0,
				percent = 1 - temp,
				index = 0,
				length = animation.tweens.length;

			for ( ; index < length ; index++ ) {
				animation.tweens[ index ].run( percent );
			}

			deferred.notifyWith( elem, [ animation, percent, remaining ]);

			if ( percent < 1 && length ) {
				return remaining;
			} else {
				deferred.resolveWith( elem, [ animation ] );
				return false;
			}
		},
		animation = deferred.promise({
			elem: elem,
			props: jQuery.extend( {}, properties ),
			opts: jQuery.extend( true, { specialEasing: {} }, options ),
			originalProperties: properties,
			originalOptions: options,
			startTime: fxNow || createFxNow(),
			duration: options.duration,
			tweens: [],
			createTween: function( prop, end ) {
				var tween = jQuery.Tween( elem, animation.opts, prop, end,
						animation.opts.specialEasing[ prop ] || animation.opts.easing );
				animation.tweens.push( tween );
				return tween;
			},
			stop: function( gotoEnd ) {
				var index = 0,
					// if we are going to the end, we want to run all the tweens
					// otherwise we skip this part
					length = gotoEnd ? animation.tweens.length : 0;
				if ( stopped ) {
					return this;
				}
				stopped = true;
				for ( ; index < length ; index++ ) {
					animation.tweens[ index ].run( 1 );
				}

				// resolve when we played the last frame
				// otherwise, reject
				if ( gotoEnd ) {
					deferred.resolveWith( elem, [ animation, gotoEnd ] );
				} else {
					deferred.rejectWith( elem, [ animation, gotoEnd ] );
				}
				return this;
			}
		}),
		props = animation.props;

	propFilter( props, animation.opts.specialEasing );

	for ( ; index < length ; index++ ) {
		result = animationPrefilters[ index ].call( animation, elem, props, animation.opts );
		if ( result ) {
			return result;
		}
	}

	jQuery.map( props, createTween, animation );

	if ( jQuery.isFunction( animation.opts.start ) ) {
		animation.opts.start.call( elem, animation );
	}

	jQuery.fx.timer(
		jQuery.extend( tick, {
			elem: elem,
			anim: animation,
			queue: animation.opts.queue
		})
	);

	// attach callbacks from options
	return animation.progress( animation.opts.progress )
		.done( animation.opts.done, animation.opts.complete )
		.fail( animation.opts.fail )
		.always( animation.opts.always );
}

jQuery.Animation = jQuery.extend( Animation, {
	tweener: function( props, callback ) {
		if ( jQuery.isFunction( props ) ) {
			callback = props;
			props = [ "*" ];
		} else {
			props = props.split(" ");
		}

		var prop,
			index = 0,
			length = props.length;

		for ( ; index < length ; index++ ) {
			prop = props[ index ];
			tweeners[ prop ] = tweeners[ prop ] || [];
			tweeners[ prop ].unshift( callback );
		}
	},

	prefilter: function( callback, prepend ) {
		if ( prepend ) {
			animationPrefilters.unshift( callback );
		} else {
			animationPrefilters.push( callback );
		}
	}
});

jQuery.speed = function( speed, easing, fn ) {
	var opt = speed && typeof speed === "object" ? jQuery.extend( {}, speed ) : {
		complete: fn || !fn && easing ||
			jQuery.isFunction( speed ) && speed,
		duration: speed,
		easing: fn && easing || easing && !jQuery.isFunction( easing ) && easing
	};

	opt.duration = jQuery.fx.off ? 0 : typeof opt.duration === "number" ? opt.duration :
		opt.duration in jQuery.fx.speeds ? jQuery.fx.speeds[ opt.duration ] : jQuery.fx.speeds._default;

	// normalize opt.queue - true/undefined/null -> "fx"
	if ( opt.queue == null || opt.queue === true ) {
		opt.queue = "fx";
	}

	// Queueing
	opt.old = opt.complete;

	opt.complete = function() {
		if ( jQuery.isFunction( opt.old ) ) {
			opt.old.call( this );
		}

		if ( opt.queue ) {
			jQuery.dequeue( this, opt.queue );
		}
	};

	return opt;
};

jQuery.fn.extend({
	fadeTo: function( speed, to, easing, callback ) {

		// show any hidden elements after setting opacity to 0
		return this.filter( isHidden ).css( "opacity", 0 ).show()

			// animate to the value specified
			.end().animate({ opacity: to }, speed, easing, callback );
	},
	animate: function( prop, speed, easing, callback ) {
		var empty = jQuery.isEmptyObject( prop ),
			optall = jQuery.speed( speed, easing, callback ),
			doAnimation = function() {
				// Operate on a copy of prop so per-property easing won't be lost
				var anim = Animation( this, jQuery.extend( {}, prop ), optall );

				// Empty animations, or finishing resolves immediately
				if ( empty || jQuery._data( this, "finish" ) ) {
					anim.stop( true );
				}
			};
			doAnimation.finish = doAnimation;

		return empty || optall.queue === false ?
			this.each( doAnimation ) :
			this.queue( optall.queue, doAnimation );
	},
	stop: function( type, clearQueue, gotoEnd ) {
		var stopQueue = function( hooks ) {
			var stop = hooks.stop;
			delete hooks.stop;
			stop( gotoEnd );
		};

		if ( typeof type !== "string" ) {
			gotoEnd = clearQueue;
			clearQueue = type;
			type = undefined;
		}
		if ( clearQueue && type !== false ) {
			this.queue( type || "fx", [] );
		}

		return this.each(function() {
			var dequeue = true,
				index = type != null && type + "queueHooks",
				timers = jQuery.timers,
				data = jQuery._data( this );

			if ( index ) {
				if ( data[ index ] && data[ index ].stop ) {
					stopQueue( data[ index ] );
				}
			} else {
				for ( index in data ) {
					if ( data[ index ] && data[ index ].stop && rrun.test( index ) ) {
						stopQueue( data[ index ] );
					}
				}
			}

			for ( index = timers.length; index--; ) {
				if ( timers[ index ].elem === this && (type == null || timers[ index ].queue === type) ) {
					timers[ index ].anim.stop( gotoEnd );
					dequeue = false;
					timers.splice( index, 1 );
				}
			}

			// start the next in the queue if the last step wasn't forced
			// timers currently will call their complete callbacks, which will dequeue
			// but only if they were gotoEnd
			if ( dequeue || !gotoEnd ) {
				jQuery.dequeue( this, type );
			}
		});
	},
	finish: function( type ) {
		if ( type !== false ) {
			type = type || "fx";
		}
		return this.each(function() {
			var index,
				data = jQuery._data( this ),
				queue = data[ type + "queue" ],
				hooks = data[ type + "queueHooks" ],
				timers = jQuery.timers,
				length = queue ? queue.length : 0;

			// enable finishing flag on private data
			data.finish = true;

			// empty the queue first
			jQuery.queue( this, type, [] );

			if ( hooks && hooks.stop ) {
				hooks.stop.call( this, true );
			}

			// look for any active animations, and finish them
			for ( index = timers.length; index--; ) {
				if ( timers[ index ].elem === this && timers[ index ].queue === type ) {
					timers[ index ].anim.stop( true );
					timers.splice( index, 1 );
				}
			}

			// look for any animations in the old queue and finish them
			for ( index = 0; index < length; index++ ) {
				if ( queue[ index ] && queue[ index ].finish ) {
					queue[ index ].finish.call( this );
				}
			}

			// turn off finishing flag
			delete data.finish;
		});
	}
});

jQuery.each([ "toggle", "show", "hide" ], function( i, name ) {
	var cssFn = jQuery.fn[ name ];
	jQuery.fn[ name ] = function( speed, easing, callback ) {
		return speed == null || typeof speed === "boolean" ?
			cssFn.apply( this, arguments ) :
			this.animate( genFx( name, true ), speed, easing, callback );
	};
});

// Generate shortcuts for custom animations
jQuery.each({
	slideDown: genFx("show"),
	slideUp: genFx("hide"),
	slideToggle: genFx("toggle"),
	fadeIn: { opacity: "show" },
	fadeOut: { opacity: "hide" },
	fadeToggle: { opacity: "toggle" }
}, function( name, props ) {
	jQuery.fn[ name ] = function( speed, easing, callback ) {
		return this.animate( props, speed, easing, callback );
	};
});

jQuery.timers = [];
jQuery.fx.tick = function() {
	var timer,
		timers = jQuery.timers,
		i = 0;

	fxNow = jQuery.now();

	for ( ; i < timers.length; i++ ) {
		timer = timers[ i ];
		// Checks the timer has not already been removed
		if ( !timer() && timers[ i ] === timer ) {
			timers.splice( i--, 1 );
		}
	}

	if ( !timers.length ) {
		jQuery.fx.stop();
	}
	fxNow = undefined;
};

jQuery.fx.timer = function( timer ) {
	jQuery.timers.push( timer );
	if ( timer() ) {
		jQuery.fx.start();
	} else {
		jQuery.timers.pop();
	}
};

jQuery.fx.interval = 13;

jQuery.fx.start = function() {
	if ( !timerId ) {
		timerId = setInterval( jQuery.fx.tick, jQuery.fx.interval );
	}
};

jQuery.fx.stop = function() {
	clearInterval( timerId );
	timerId = null;
};

jQuery.fx.speeds = {
	slow: 600,
	fast: 200,
	// Default speed
	_default: 400
};


// Based off of the plugin by Clint Helfers, with permission.
// http://blindsignals.com/index.php/2009/07/jquery-delay/
jQuery.fn.delay = function( time, type ) {
	time = jQuery.fx ? jQuery.fx.speeds[ time ] || time : time;
	type = type || "fx";

	return this.queue( type, function( next, hooks ) {
		var timeout = setTimeout( next, time );
		hooks.stop = function() {
			clearTimeout( timeout );
		};
	});
};


(function() {
	// Minified: var a,b,c,d,e
	var input, div, select, a, opt;

	// Setup
	div = document.createElement( "div" );
	div.setAttribute( "className", "t" );
	div.innerHTML = "  <link/><table></table><a href='/a'>a</a><input type='checkbox'/>";
	a = div.getElementsByTagName("a")[ 0 ];

	// First batch of tests.
	select = document.createElement("select");
	opt = select.appendChild( document.createElement("option") );
	input = div.getElementsByTagName("input")[ 0 ];

	a.style.cssText = "top:1px";

	// Test setAttribute on camelCase class. If it works, we need attrFixes when doing get/setAttribute (ie6/7)
	support.getSetAttribute = div.className !== "t";

	// Get the style information from getAttribute
	// (IE uses .cssText instead)
	support.style = /top/.test( a.getAttribute("style") );

	// Make sure that URLs aren't manipulated
	// (IE normalizes it by default)
	support.hrefNormalized = a.getAttribute("href") === "/a";

	// Check the default checkbox/radio value ("" on WebKit; "on" elsewhere)
	support.checkOn = !!input.value;

	// Make sure that a selected-by-default option has a working selected property.
	// (WebKit defaults to false instead of true, IE too, if it's in an optgroup)
	support.optSelected = opt.selected;

	// Tests for enctype support on a form (#6743)
	support.enctype = !!document.createElement("form").enctype;

	// Make sure that the options inside disabled selects aren't marked as disabled
	// (WebKit marks them as disabled)
	select.disabled = true;
	support.optDisabled = !opt.disabled;

	// Support: IE8 only
	// Check if we can trust getAttribute("value")
	input = document.createElement( "input" );
	input.setAttribute( "value", "" );
	support.input = input.getAttribute( "value" ) === "";

	// Check if an input maintains its value after becoming a radio
	input.value = "t";
	input.setAttribute( "type", "radio" );
	support.radioValue = input.value === "t";
})();


var rreturn = /\r/g;

jQuery.fn.extend({
	val: function( value ) {
		var hooks, ret, isFunction,
			elem = this[0];

		if ( !arguments.length ) {
			if ( elem ) {
				hooks = jQuery.valHooks[ elem.type ] || jQuery.valHooks[ elem.nodeName.toLowerCase() ];

				if ( hooks && "get" in hooks && (ret = hooks.get( elem, "value" )) !== undefined ) {
					return ret;
				}

				ret = elem.value;

				return typeof ret === "string" ?
					// handle most common string cases
					ret.replace(rreturn, "") :
					// handle cases where value is null/undef or number
					ret == null ? "" : ret;
			}

			return;
		}

		isFunction = jQuery.isFunction( value );

		return this.each(function( i ) {
			var val;

			if ( this.nodeType !== 1 ) {
				return;
			}

			if ( isFunction ) {
				val = value.call( this, i, jQuery( this ).val() );
			} else {
				val = value;
			}

			// Treat null/undefined as ""; convert numbers to string
			if ( val == null ) {
				val = "";
			} else if ( typeof val === "number" ) {
				val += "";
			} else if ( jQuery.isArray( val ) ) {
				val = jQuery.map( val, function( value ) {
					return value == null ? "" : value + "";
				});
			}

			hooks = jQuery.valHooks[ this.type ] || jQuery.valHooks[ this.nodeName.toLowerCase() ];

			// If set returns undefined, fall back to normal setting
			if ( !hooks || !("set" in hooks) || hooks.set( this, val, "value" ) === undefined ) {
				this.value = val;
			}
		});
	}
});

jQuery.extend({
	valHooks: {
		option: {
			get: function( elem ) {
				var val = jQuery.find.attr( elem, "value" );
				return val != null ?
					val :
					// Support: IE10-11+
					// option.text throws exceptions (#14686, #14858)
					jQuery.trim( jQuery.text( elem ) );
			}
		},
		select: {
			get: function( elem ) {
				var value, option,
					options = elem.options,
					index = elem.selectedIndex,
					one = elem.type === "select-one" || index < 0,
					values = one ? null : [],
					max = one ? index + 1 : options.length,
					i = index < 0 ?
						max :
						one ? index : 0;

				// Loop through all the selected options
				for ( ; i < max; i++ ) {
					option = options[ i ];

					// oldIE doesn't update selected after form reset (#2551)
					if ( ( option.selected || i === index ) &&
							// Don't return options that are disabled or in a disabled optgroup
							( support.optDisabled ? !option.disabled : option.getAttribute("disabled") === null ) &&
							( !option.parentNode.disabled || !jQuery.nodeName( option.parentNode, "optgroup" ) ) ) {

						// Get the specific value for the option
						value = jQuery( option ).val();

						// We don't need an array for one selects
						if ( one ) {
							return value;
						}

						// Multi-Selects return an array
						values.push( value );
					}
				}

				return values;
			},

			set: function( elem, value ) {
				var optionSet, option,
					options = elem.options,
					values = jQuery.makeArray( value ),
					i = options.length;

				while ( i-- ) {
					option = options[ i ];

					if ( jQuery.inArray( jQuery.valHooks.option.get( option ), values ) >= 0 ) {

						// Support: IE6
						// When new option element is added to select box we need to
						// force reflow of newly added node in order to workaround delay
						// of initialization properties
						try {
							option.selected = optionSet = true;

						} catch ( _ ) {

							// Will be executed only in IE6
							option.scrollHeight;
						}

					} else {
						option.selected = false;
					}
				}

				// Force browsers to behave consistently when non-matching value is set
				if ( !optionSet ) {
					elem.selectedIndex = -1;
				}

				return options;
			}
		}
	}
});

// Radios and checkboxes getter/setter
jQuery.each([ "radio", "checkbox" ], function() {
	jQuery.valHooks[ this ] = {
		set: function( elem, value ) {
			if ( jQuery.isArray( value ) ) {
				return ( elem.checked = jQuery.inArray( jQuery(elem).val(), value ) >= 0 );
			}
		}
	};
	if ( !support.checkOn ) {
		jQuery.valHooks[ this ].get = function( elem ) {
			// Support: Webkit
			// "" is returned instead of "on" if a value isn't specified
			return elem.getAttribute("value") === null ? "on" : elem.value;
		};
	}
});




var nodeHook, boolHook,
	attrHandle = jQuery.expr.attrHandle,
	ruseDefault = /^(?:checked|selected)$/i,
	getSetAttribute = support.getSetAttribute,
	getSetInput = support.input;

jQuery.fn.extend({
	attr: function( name, value ) {
		return access( this, jQuery.attr, name, value, arguments.length > 1 );
	},

	removeAttr: function( name ) {
		return this.each(function() {
			jQuery.removeAttr( this, name );
		});
	}
});

jQuery.extend({
	attr: function( elem, name, value ) {
		var hooks, ret,
			nType = elem.nodeType;

		// don't get/set attributes on text, comment and attribute nodes
		if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
			return;
		}

		// Fallback to prop when attributes are not supported
		if ( typeof elem.getAttribute === strundefined ) {
			return jQuery.prop( elem, name, value );
		}

		// All attributes are lowercase
		// Grab necessary hook if one is defined
		if ( nType !== 1 || !jQuery.isXMLDoc( elem ) ) {
			name = name.toLowerCase();
			hooks = jQuery.attrHooks[ name ] ||
				( jQuery.expr.match.bool.test( name ) ? boolHook : nodeHook );
		}

		if ( value !== undefined ) {

			if ( value === null ) {
				jQuery.removeAttr( elem, name );

			} else if ( hooks && "set" in hooks && (ret = hooks.set( elem, value, name )) !== undefined ) {
				return ret;

			} else {
				elem.setAttribute( name, value + "" );
				return value;
			}

		} else if ( hooks && "get" in hooks && (ret = hooks.get( elem, name )) !== null ) {
			return ret;

		} else {
			ret = jQuery.find.attr( elem, name );

			// Non-existent attributes return null, we normalize to undefined
			return ret == null ?
				undefined :
				ret;
		}
	},

	removeAttr: function( elem, value ) {
		var name, propName,
			i = 0,
			attrNames = value && value.match( rnotwhite );

		if ( attrNames && elem.nodeType === 1 ) {
			while ( (name = attrNames[i++]) ) {
				propName = jQuery.propFix[ name ] || name;

				// Boolean attributes get special treatment (#10870)
				if ( jQuery.expr.match.bool.test( name ) ) {
					// Set corresponding property to false
					if ( getSetInput && getSetAttribute || !ruseDefault.test( name ) ) {
						elem[ propName ] = false;
					// Support: IE<9
					// Also clear defaultChecked/defaultSelected (if appropriate)
					} else {
						elem[ jQuery.camelCase( "default-" + name ) ] =
							elem[ propName ] = false;
					}

				// See #9699 for explanation of this approach (setting first, then removal)
				} else {
					jQuery.attr( elem, name, "" );
				}

				elem.removeAttribute( getSetAttribute ? name : propName );
			}
		}
	},

	attrHooks: {
		type: {
			set: function( elem, value ) {
				if ( !support.radioValue && value === "radio" && jQuery.nodeName(elem, "input") ) {
					// Setting the type on a radio button after the value resets the value in IE6-9
					// Reset value to default in case type is set after value during creation
					var val = elem.value;
					elem.setAttribute( "type", value );
					if ( val ) {
						elem.value = val;
					}
					return value;
				}
			}
		}
	}
});

// Hook for boolean attributes
boolHook = {
	set: function( elem, value, name ) {
		if ( value === false ) {
			// Remove boolean attributes when set to false
			jQuery.removeAttr( elem, name );
		} else if ( getSetInput && getSetAttribute || !ruseDefault.test( name ) ) {
			// IE<8 needs the *property* name
			elem.setAttribute( !getSetAttribute && jQuery.propFix[ name ] || name, name );

		// Use defaultChecked and defaultSelected for oldIE
		} else {
			elem[ jQuery.camelCase( "default-" + name ) ] = elem[ name ] = true;
		}

		return name;
	}
};

// Retrieve booleans specially
jQuery.each( jQuery.expr.match.bool.source.match( /\w+/g ), function( i, name ) {

	var getter = attrHandle[ name ] || jQuery.find.attr;

	attrHandle[ name ] = getSetInput && getSetAttribute || !ruseDefault.test( name ) ?
		function( elem, name, isXML ) {
			var ret, handle;
			if ( !isXML ) {
				// Avoid an infinite loop by temporarily removing this function from the getter
				handle = attrHandle[ name ];
				attrHandle[ name ] = ret;
				ret = getter( elem, name, isXML ) != null ?
					name.toLowerCase() :
					null;
				attrHandle[ name ] = handle;
			}
			return ret;
		} :
		function( elem, name, isXML ) {
			if ( !isXML ) {
				return elem[ jQuery.camelCase( "default-" + name ) ] ?
					name.toLowerCase() :
					null;
			}
		};
});

// fix oldIE attroperties
if ( !getSetInput || !getSetAttribute ) {
	jQuery.attrHooks.value = {
		set: function( elem, value, name ) {
			if ( jQuery.nodeName( elem, "input" ) ) {
				// Does not return so that setAttribute is also used
				elem.defaultValue = value;
			} else {
				// Use nodeHook if defined (#1954); otherwise setAttribute is fine
				return nodeHook && nodeHook.set( elem, value, name );
			}
		}
	};
}

// IE6/7 do not support getting/setting some attributes with get/setAttribute
if ( !getSetAttribute ) {

	// Use this for any attribute in IE6/7
	// This fixes almost every IE6/7 issue
	nodeHook = {
		set: function( elem, value, name ) {
			// Set the existing or create a new attribute node
			var ret = elem.getAttributeNode( name );
			if ( !ret ) {
				elem.setAttributeNode(
					(ret = elem.ownerDocument.createAttribute( name ))
				);
			}

			ret.value = value += "";

			// Break association with cloned elements by also using setAttribute (#9646)
			if ( name === "value" || value === elem.getAttribute( name ) ) {
				return value;
			}
		}
	};

	// Some attributes are constructed with empty-string values when not defined
	attrHandle.id = attrHandle.name = attrHandle.coords =
		function( elem, name, isXML ) {
			var ret;
			if ( !isXML ) {
				return (ret = elem.getAttributeNode( name )) && ret.value !== "" ?
					ret.value :
					null;
			}
		};

	// Fixing value retrieval on a button requires this module
	jQuery.valHooks.button = {
		get: function( elem, name ) {
			var ret = elem.getAttributeNode( name );
			if ( ret && ret.specified ) {
				return ret.value;
			}
		},
		set: nodeHook.set
	};

	// Set contenteditable to false on removals(#10429)
	// Setting to empty string throws an error as an invalid value
	jQuery.attrHooks.contenteditable = {
		set: function( elem, value, name ) {
			nodeHook.set( elem, value === "" ? false : value, name );
		}
	};

	// Set width and height to auto instead of 0 on empty string( Bug #8150 )
	// This is for removals
	jQuery.each([ "width", "height" ], function( i, name ) {
		jQuery.attrHooks[ name ] = {
			set: function( elem, value ) {
				if ( value === "" ) {
					elem.setAttribute( name, "auto" );
					return value;
				}
			}
		};
	});
}

if ( !support.style ) {
	jQuery.attrHooks.style = {
		get: function( elem ) {
			// Return undefined in the case of empty string
			// Note: IE uppercases css property names, but if we were to .toLowerCase()
			// .cssText, that would destroy case senstitivity in URL's, like in "background"
			return elem.style.cssText || undefined;
		},
		set: function( elem, value ) {
			return ( elem.style.cssText = value + "" );
		}
	};
}




var rfocusable = /^(?:input|select|textarea|button|object)$/i,
	rclickable = /^(?:a|area)$/i;

jQuery.fn.extend({
	prop: function( name, value ) {
		return access( this, jQuery.prop, name, value, arguments.length > 1 );
	},

	removeProp: function( name ) {
		name = jQuery.propFix[ name ] || name;
		return this.each(function() {
			// try/catch handles cases where IE balks (such as removing a property on window)
			try {
				this[ name ] = undefined;
				delete this[ name ];
			} catch( e ) {}
		});
	}
});

jQuery.extend({
	propFix: {
		"for": "htmlFor",
		"class": "className"
	},

	prop: function( elem, name, value ) {
		var ret, hooks, notxml,
			nType = elem.nodeType;

		// don't get/set properties on text, comment and attribute nodes
		if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
			return;
		}

		notxml = nType !== 1 || !jQuery.isXMLDoc( elem );

		if ( notxml ) {
			// Fix name and attach hooks
			name = jQuery.propFix[ name ] || name;
			hooks = jQuery.propHooks[ name ];
		}

		if ( value !== undefined ) {
			return hooks && "set" in hooks && (ret = hooks.set( elem, value, name )) !== undefined ?
				ret :
				( elem[ name ] = value );

		} else {
			return hooks && "get" in hooks && (ret = hooks.get( elem, name )) !== null ?
				ret :
				elem[ name ];
		}
	},

	propHooks: {
		tabIndex: {
			get: function( elem ) {
				// elem.tabIndex doesn't always return the correct value when it hasn't been explicitly set
				// http://fluidproject.org/blog/2008/01/09/getting-setting-and-removing-tabindex-values-with-javascript/
				// Use proper attribute retrieval(#12072)
				var tabindex = jQuery.find.attr( elem, "tabindex" );

				return tabindex ?
					parseInt( tabindex, 10 ) :
					rfocusable.test( elem.nodeName ) || rclickable.test( elem.nodeName ) && elem.href ?
						0 :
						-1;
			}
		}
	}
});

// Some attributes require a special call on IE
// http://msdn.microsoft.com/en-us/library/ms536429%28VS.85%29.aspx
if ( !support.hrefNormalized ) {
	// href/src property should get the full normalized URL (#10299/#12915)
	jQuery.each([ "href", "src" ], function( i, name ) {
		jQuery.propHooks[ name ] = {
			get: function( elem ) {
				return elem.getAttribute( name, 4 );
			}
		};
	});
}

// Support: Safari, IE9+
// mis-reports the default selected property of an option
// Accessing the parent's selectedIndex property fixes it
if ( !support.optSelected ) {
	jQuery.propHooks.selected = {
		get: function( elem ) {
			var parent = elem.parentNode;

			if ( parent ) {
				parent.selectedIndex;

				// Make sure that it also works with optgroups, see #5701
				if ( parent.parentNode ) {
					parent.parentNode.selectedIndex;
				}
			}
			return null;
		}
	};
}

jQuery.each([
	"tabIndex",
	"readOnly",
	"maxLength",
	"cellSpacing",
	"cellPadding",
	"rowSpan",
	"colSpan",
	"useMap",
	"frameBorder",
	"contentEditable"
], function() {
	jQuery.propFix[ this.toLowerCase() ] = this;
});

// IE6/7 call enctype encoding
if ( !support.enctype ) {
	jQuery.propFix.enctype = "encoding";
}




var rclass = /[\t\r\n\f]/g;

jQuery.fn.extend({
	addClass: function( value ) {
		var classes, elem, cur, clazz, j, finalValue,
			i = 0,
			len = this.length,
			proceed = typeof value === "string" && value;

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( j ) {
				jQuery( this ).addClass( value.call( this, j, this.className ) );
			});
		}

		if ( proceed ) {
			// The disjunction here is for better compressibility (see removeClass)
			classes = ( value || "" ).match( rnotwhite ) || [];

			for ( ; i < len; i++ ) {
				elem = this[ i ];
				cur = elem.nodeType === 1 && ( elem.className ?
					( " " + elem.className + " " ).replace( rclass, " " ) :
					" "
				);

				if ( cur ) {
					j = 0;
					while ( (clazz = classes[j++]) ) {
						if ( cur.indexOf( " " + clazz + " " ) < 0 ) {
							cur += clazz + " ";
						}
					}

					// only assign if different to avoid unneeded rendering.
					finalValue = jQuery.trim( cur );
					if ( elem.className !== finalValue ) {
						elem.className = finalValue;
					}
				}
			}
		}

		return this;
	},

	removeClass: function( value ) {
		var classes, elem, cur, clazz, j, finalValue,
			i = 0,
			len = this.length,
			proceed = arguments.length === 0 || typeof value === "string" && value;

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( j ) {
				jQuery( this ).removeClass( value.call( this, j, this.className ) );
			});
		}
		if ( proceed ) {
			classes = ( value || "" ).match( rnotwhite ) || [];

			for ( ; i < len; i++ ) {
				elem = this[ i ];
				// This expression is here for better compressibility (see addClass)
				cur = elem.nodeType === 1 && ( elem.className ?
					( " " + elem.className + " " ).replace( rclass, " " ) :
					""
				);

				if ( cur ) {
					j = 0;
					while ( (clazz = classes[j++]) ) {
						// Remove *all* instances
						while ( cur.indexOf( " " + clazz + " " ) >= 0 ) {
							cur = cur.replace( " " + clazz + " ", " " );
						}
					}

					// only assign if different to avoid unneeded rendering.
					finalValue = value ? jQuery.trim( cur ) : "";
					if ( elem.className !== finalValue ) {
						elem.className = finalValue;
					}
				}
			}
		}

		return this;
	},

	toggleClass: function( value, stateVal ) {
		var type = typeof value;

		if ( typeof stateVal === "boolean" && type === "string" ) {
			return stateVal ? this.addClass( value ) : this.removeClass( value );
		}

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( i ) {
				jQuery( this ).toggleClass( value.call(this, i, this.className, stateVal), stateVal );
			});
		}

		return this.each(function() {
			if ( type === "string" ) {
				// toggle individual class names
				var className,
					i = 0,
					self = jQuery( this ),
					classNames = value.match( rnotwhite ) || [];

				while ( (className = classNames[ i++ ]) ) {
					// check each className given, space separated list
					if ( self.hasClass( className ) ) {
						self.removeClass( className );
					} else {
						self.addClass( className );
					}
				}

			// Toggle whole class name
			} else if ( type === strundefined || type === "boolean" ) {
				if ( this.className ) {
					// store className if set
					jQuery._data( this, "__className__", this.className );
				}

				// If the element has a class name or if we're passed "false",
				// then remove the whole classname (if there was one, the above saved it).
				// Otherwise bring back whatever was previously saved (if anything),
				// falling back to the empty string if nothing was stored.
				this.className = this.className || value === false ? "" : jQuery._data( this, "__className__" ) || "";
			}
		});
	},

	hasClass: function( selector ) {
		var className = " " + selector + " ",
			i = 0,
			l = this.length;
		for ( ; i < l; i++ ) {
			if ( this[i].nodeType === 1 && (" " + this[i].className + " ").replace(rclass, " ").indexOf( className ) >= 0 ) {
				return true;
			}
		}

		return false;
	}
});




// Return jQuery for attributes-only inclusion


jQuery.each( ("blur focus focusin focusout load resize scroll unload click dblclick " +
	"mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave " +
	"change select submit keydown keypress keyup error contextmenu").split(" "), function( i, name ) {

	// Handle event binding
	jQuery.fn[ name ] = function( data, fn ) {
		return arguments.length > 0 ?
			this.on( name, null, data, fn ) :
			this.trigger( name );
	};
});

jQuery.fn.extend({
	hover: function( fnOver, fnOut ) {
		return this.mouseenter( fnOver ).mouseleave( fnOut || fnOver );
	},

	bind: function( types, data, fn ) {
		return this.on( types, null, data, fn );
	},
	unbind: function( types, fn ) {
		return this.off( types, null, fn );
	},

	delegate: function( selector, types, data, fn ) {
		return this.on( types, selector, data, fn );
	},
	undelegate: function( selector, types, fn ) {
		// ( namespace ) or ( selector, types [, fn] )
		return arguments.length === 1 ? this.off( selector, "**" ) : this.off( types, selector || "**", fn );
	}
});


var nonce = jQuery.now();

var rquery = (/\?/);



var rvalidtokens = /(,)|(\[|{)|(}|])|"(?:[^"\\\r\n]|\\["\\\/bfnrt]|\\u[\da-fA-F]{4})*"\s*:?|true|false|null|-?(?!0\d)\d+(?:\.\d+|)(?:[eE][+-]?\d+|)/g;

jQuery.parseJSON = function( data ) {
	// Attempt to parse using the native JSON parser first
	if ( window.JSON && window.JSON.parse ) {
		// Support: Android 2.3
		// Workaround failure to string-cast null input
		return window.JSON.parse( data + "" );
	}

	var requireNonComma,
		depth = null,
		str = jQuery.trim( data + "" );

	// Guard against invalid (and possibly dangerous) input by ensuring that nothing remains
	// after removing valid tokens
	return str && !jQuery.trim( str.replace( rvalidtokens, function( token, comma, open, close ) {

		// Force termination if we see a misplaced comma
		if ( requireNonComma && comma ) {
			depth = 0;
		}

		// Perform no more replacements after returning to outermost depth
		if ( depth === 0 ) {
			return token;
		}

		// Commas must not follow "[", "{", or ","
		requireNonComma = open || comma;

		// Determine new depth
		// array/object open ("[" or "{"): depth += true - false (increment)
		// array/object close ("]" or "}"): depth += false - true (decrement)
		// other cases ("," or primitive): depth += true - true (numeric cast)
		depth += !close - !open;

		// Remove this token
		return "";
	}) ) ?
		( Function( "return " + str ) )() :
		jQuery.error( "Invalid JSON: " + data );
};


// Cross-browser xml parsing
jQuery.parseXML = function( data ) {
	var xml, tmp;
	if ( !data || typeof data !== "string" ) {
		return null;
	}
	try {
		if ( window.DOMParser ) { // Standard
			tmp = new DOMParser();
			xml = tmp.parseFromString( data, "text/xml" );
		} else { // IE
			xml = new ActiveXObject( "Microsoft.XMLDOM" );
			xml.async = "false";
			xml.loadXML( data );
		}
	} catch( e ) {
		xml = undefined;
	}
	if ( !xml || !xml.documentElement || xml.getElementsByTagName( "parsererror" ).length ) {
		jQuery.error( "Invalid XML: " + data );
	}
	return xml;
};


var
	// Document location
	ajaxLocParts,
	ajaxLocation,

	rhash = /#.*$/,
	rts = /([?&])_=[^&]*/,
	rheaders = /^(.*?):[ \t]*([^\r\n]*)\r?$/mg, // IE leaves an \r character at EOL
	// #7653, #8125, #8152: local protocol detection
	rlocalProtocol = /^(?:about|app|app-storage|.+-extension|file|res|widget):$/,
	rnoContent = /^(?:GET|HEAD)$/,
	rprotocol = /^\/\//,
	rurl = /^([\w.+-]+:)(?:\/\/(?:[^\/?#]*@|)([^\/?#:]*)(?::(\d+)|)|)/,

	/* Prefilters
	 * 1) They are useful to introduce custom dataTypes (see ajax/jsonp.js for an example)
	 * 2) These are called:
	 *    - BEFORE asking for a transport
	 *    - AFTER param serialization (s.data is a string if s.processData is true)
	 * 3) key is the dataType
	 * 4) the catchall symbol "*" can be used
	 * 5) execution will start with transport dataType and THEN continue down to "*" if needed
	 */
	prefilters = {},

	/* Transports bindings
	 * 1) key is the dataType
	 * 2) the catchall symbol "*" can be used
	 * 3) selection will start with transport dataType and THEN go to "*" if needed
	 */
	transports = {},

	// Avoid comment-prolog char sequence (#10098); must appease lint and evade compression
	allTypes = "*/".concat("*");

// #8138, IE may throw an exception when accessing
// a field from window.location if document.domain has been set
try {
	ajaxLocation = location.href;
} catch( e ) {
	// Use the href attribute of an A element
	// since IE will modify it given document.location
	ajaxLocation = document.createElement( "a" );
	ajaxLocation.href = "";
	ajaxLocation = ajaxLocation.href;
}

// Segment location into parts
ajaxLocParts = rurl.exec( ajaxLocation.toLowerCase() ) || [];

// Base "constructor" for jQuery.ajaxPrefilter and jQuery.ajaxTransport
function addToPrefiltersOrTransports( structure ) {

	// dataTypeExpression is optional and defaults to "*"
	return function( dataTypeExpression, func ) {

		if ( typeof dataTypeExpression !== "string" ) {
			func = dataTypeExpression;
			dataTypeExpression = "*";
		}

		var dataType,
			i = 0,
			dataTypes = dataTypeExpression.toLowerCase().match( rnotwhite ) || [];

		if ( jQuery.isFunction( func ) ) {
			// For each dataType in the dataTypeExpression
			while ( (dataType = dataTypes[i++]) ) {
				// Prepend if requested
				if ( dataType.charAt( 0 ) === "+" ) {
					dataType = dataType.slice( 1 ) || "*";
					(structure[ dataType ] = structure[ dataType ] || []).unshift( func );

				// Otherwise append
				} else {
					(structure[ dataType ] = structure[ dataType ] || []).push( func );
				}
			}
		}
	};
}

// Base inspection function for prefilters and transports
function inspectPrefiltersOrTransports( structure, options, originalOptions, jqXHR ) {

	var inspected = {},
		seekingTransport = ( structure === transports );

	function inspect( dataType ) {
		var selected;
		inspected[ dataType ] = true;
		jQuery.each( structure[ dataType ] || [], function( _, prefilterOrFactory ) {
			var dataTypeOrTransport = prefilterOrFactory( options, originalOptions, jqXHR );
			if ( typeof dataTypeOrTransport === "string" && !seekingTransport && !inspected[ dataTypeOrTransport ] ) {
				options.dataTypes.unshift( dataTypeOrTransport );
				inspect( dataTypeOrTransport );
				return false;
			} else if ( seekingTransport ) {
				return !( selected = dataTypeOrTransport );
			}
		});
		return selected;
	}

	return inspect( options.dataTypes[ 0 ] ) || !inspected[ "*" ] && inspect( "*" );
}

// A special extend for ajax options
// that takes "flat" options (not to be deep extended)
// Fixes #9887
function ajaxExtend( target, src ) {
	var deep, key,
		flatOptions = jQuery.ajaxSettings.flatOptions || {};

	for ( key in src ) {
		if ( src[ key ] !== undefined ) {
			( flatOptions[ key ] ? target : ( deep || (deep = {}) ) )[ key ] = src[ key ];
		}
	}
	if ( deep ) {
		jQuery.extend( true, target, deep );
	}

	return target;
}

/* Handles responses to an ajax request:
 * - finds the right dataType (mediates between content-type and expected dataType)
 * - returns the corresponding response
 */
function ajaxHandleResponses( s, jqXHR, responses ) {
	var firstDataType, ct, finalDataType, type,
		contents = s.contents,
		dataTypes = s.dataTypes;

	// Remove auto dataType and get content-type in the process
	while ( dataTypes[ 0 ] === "*" ) {
		dataTypes.shift();
		if ( ct === undefined ) {
			ct = s.mimeType || jqXHR.getResponseHeader("Content-Type");
		}
	}

	// Check if we're dealing with a known content-type
	if ( ct ) {
		for ( type in contents ) {
			if ( contents[ type ] && contents[ type ].test( ct ) ) {
				dataTypes.unshift( type );
				break;
			}
		}
	}

	// Check to see if we have a response for the expected dataType
	if ( dataTypes[ 0 ] in responses ) {
		finalDataType = dataTypes[ 0 ];
	} else {
		// Try convertible dataTypes
		for ( type in responses ) {
			if ( !dataTypes[ 0 ] || s.converters[ type + " " + dataTypes[0] ] ) {
				finalDataType = type;
				break;
			}
			if ( !firstDataType ) {
				firstDataType = type;
			}
		}
		// Or just use first one
		finalDataType = finalDataType || firstDataType;
	}

	// If we found a dataType
	// We add the dataType to the list if needed
	// and return the corresponding response
	if ( finalDataType ) {
		if ( finalDataType !== dataTypes[ 0 ] ) {
			dataTypes.unshift( finalDataType );
		}
		return responses[ finalDataType ];
	}
}

/* Chain conversions given the request and the original response
 * Also sets the responseXXX fields on the jqXHR instance
 */
function ajaxConvert( s, response, jqXHR, isSuccess ) {
	var conv2, current, conv, tmp, prev,
		converters = {},
		// Work with a copy of dataTypes in case we need to modify it for conversion
		dataTypes = s.dataTypes.slice();

	// Create converters map with lowercased keys
	if ( dataTypes[ 1 ] ) {
		for ( conv in s.converters ) {
			converters[ conv.toLowerCase() ] = s.converters[ conv ];
		}
	}

	current = dataTypes.shift();

	// Convert to each sequential dataType
	while ( current ) {

		if ( s.responseFields[ current ] ) {
			jqXHR[ s.responseFields[ current ] ] = response;
		}

		// Apply the dataFilter if provided
		if ( !prev && isSuccess && s.dataFilter ) {
			response = s.dataFilter( response, s.dataType );
		}

		prev = current;
		current = dataTypes.shift();

		if ( current ) {

			// There's only work to do if current dataType is non-auto
			if ( current === "*" ) {

				current = prev;

			// Convert response if prev dataType is non-auto and differs from current
			} else if ( prev !== "*" && prev !== current ) {

				// Seek a direct converter
				conv = converters[ prev + " " + current ] || converters[ "* " + current ];

				// If none found, seek a pair
				if ( !conv ) {
					for ( conv2 in converters ) {

						// If conv2 outputs current
						tmp = conv2.split( " " );
						if ( tmp[ 1 ] === current ) {

							// If prev can be converted to accepted input
							conv = converters[ prev + " " + tmp[ 0 ] ] ||
								converters[ "* " + tmp[ 0 ] ];
							if ( conv ) {
								// Condense equivalence converters
								if ( conv === true ) {
									conv = converters[ conv2 ];

								// Otherwise, insert the intermediate dataType
								} else if ( converters[ conv2 ] !== true ) {
									current = tmp[ 0 ];
									dataTypes.unshift( tmp[ 1 ] );
								}
								break;
							}
						}
					}
				}

				// Apply converter (if not an equivalence)
				if ( conv !== true ) {

					// Unless errors are allowed to bubble, catch and return them
					if ( conv && s[ "throws" ] ) {
						response = conv( response );
					} else {
						try {
							response = conv( response );
						} catch ( e ) {
							return { state: "parsererror", error: conv ? e : "No conversion from " + prev + " to " + current };
						}
					}
				}
			}
		}
	}

	return { state: "success", data: response };
}

jQuery.extend({

	// Counter for holding the number of active queries
	active: 0,

	// Last-Modified header cache for next request
	lastModified: {},
	etag: {},

	ajaxSettings: {
		url: ajaxLocation,
		type: "GET",
		isLocal: rlocalProtocol.test( ajaxLocParts[ 1 ] ),
		global: true,
		processData: true,
		async: true,
		contentType: "application/x-www-form-urlencoded; charset=UTF-8",
		/*
		timeout: 0,
		data: null,
		dataType: null,
		username: null,
		password: null,
		cache: null,
		throws: false,
		traditional: false,
		headers: {},
		*/

		accepts: {
			"*": allTypes,
			text: "text/plain",
			html: "text/html",
			xml: "application/xml, text/xml",
			json: "application/json, text/javascript"
		},

		contents: {
			xml: /xml/,
			html: /html/,
			json: /json/
		},

		responseFields: {
			xml: "responseXML",
			text: "responseText",
			json: "responseJSON"
		},

		// Data converters
		// Keys separate source (or catchall "*") and destination types with a single space
		converters: {

			// Convert anything to text
			"* text": String,

			// Text to html (true = no transformation)
			"text html": true,

			// Evaluate text as a json expression
			"text json": jQuery.parseJSON,

			// Parse text as xml
			"text xml": jQuery.parseXML
		},

		// For options that shouldn't be deep extended:
		// you can add your own custom options here if
		// and when you create one that shouldn't be
		// deep extended (see ajaxExtend)
		flatOptions: {
			url: true,
			context: true
		}
	},

	// Creates a full fledged settings object into target
	// with both ajaxSettings and settings fields.
	// If target is omitted, writes into ajaxSettings.
	ajaxSetup: function( target, settings ) {
		return settings ?

			// Building a settings object
			ajaxExtend( ajaxExtend( target, jQuery.ajaxSettings ), settings ) :

			// Extending ajaxSettings
			ajaxExtend( jQuery.ajaxSettings, target );
	},

	ajaxPrefilter: addToPrefiltersOrTransports( prefilters ),
	ajaxTransport: addToPrefiltersOrTransports( transports ),

	// Main method
	ajax: function( url, options ) {

		// If url is an object, simulate pre-1.5 signature
		if ( typeof url === "object" ) {
			options = url;
			url = undefined;
		}

		// Force options to be an object
		options = options || {};

		var // Cross-domain detection vars
			parts,
			// Loop variable
			i,
			// URL without anti-cache param
			cacheURL,
			// Response headers as string
			responseHeadersString,
			// timeout handle
			timeoutTimer,

			// To know if global events are to be dispatched
			fireGlobals,

			transport,
			// Response headers
			responseHeaders,
			// Create the final options object
			s = jQuery.ajaxSetup( {}, options ),
			// Callbacks context
			callbackContext = s.context || s,
			// Context for global events is callbackContext if it is a DOM node or jQuery collection
			globalEventContext = s.context && ( callbackContext.nodeType || callbackContext.jquery ) ?
				jQuery( callbackContext ) :
				jQuery.event,
			// Deferreds
			deferred = jQuery.Deferred(),
			completeDeferred = jQuery.Callbacks("once memory"),
			// Status-dependent callbacks
			statusCode = s.statusCode || {},
			// Headers (they are sent all at once)
			requestHeaders = {},
			requestHeadersNames = {},
			// The jqXHR state
			state = 0,
			// Default abort message
			strAbort = "canceled",
			// Fake xhr
			jqXHR = {
				readyState: 0,

				// Builds headers hashtable if needed
				getResponseHeader: function( key ) {
					var match;
					if ( state === 2 ) {
						if ( !responseHeaders ) {
							responseHeaders = {};
							while ( (match = rheaders.exec( responseHeadersString )) ) {
								responseHeaders[ match[1].toLowerCase() ] = match[ 2 ];
							}
						}
						match = responseHeaders[ key.toLowerCase() ];
					}
					return match == null ? null : match;
				},

				// Raw string
				getAllResponseHeaders: function() {
					return state === 2 ? responseHeadersString : null;
				},

				// Caches the header
				setRequestHeader: function( name, value ) {
					var lname = name.toLowerCase();
					if ( !state ) {
						name = requestHeadersNames[ lname ] = requestHeadersNames[ lname ] || name;
						requestHeaders[ name ] = value;
					}
					return this;
				},

				// Overrides response content-type header
				overrideMimeType: function( type ) {
					if ( !state ) {
						s.mimeType = type;
					}
					return this;
				},

				// Status-dependent callbacks
				statusCode: function( map ) {
					var code;
					if ( map ) {
						if ( state < 2 ) {
							for ( code in map ) {
								// Lazy-add the new callback in a way that preserves old ones
								statusCode[ code ] = [ statusCode[ code ], map[ code ] ];
							}
						} else {
							// Execute the appropriate callbacks
							jqXHR.always( map[ jqXHR.status ] );
						}
					}
					return this;
				},

				// Cancel the request
				abort: function( statusText ) {
					var finalText = statusText || strAbort;
					if ( transport ) {
						transport.abort( finalText );
					}
					done( 0, finalText );
					return this;
				}
			};

		// Attach deferreds
		deferred.promise( jqXHR ).complete = completeDeferred.add;
		jqXHR.success = jqXHR.done;
		jqXHR.error = jqXHR.fail;

		// Remove hash character (#7531: and string promotion)
		// Add protocol if not provided (#5866: IE7 issue with protocol-less urls)
		// Handle falsy url in the settings object (#10093: consistency with old signature)
		// We also use the url parameter if available
		s.url = ( ( url || s.url || ajaxLocation ) + "" ).replace( rhash, "" ).replace( rprotocol, ajaxLocParts[ 1 ] + "//" );

		// Alias method option to type as per ticket #12004
		s.type = options.method || options.type || s.method || s.type;

		// Extract dataTypes list
		s.dataTypes = jQuery.trim( s.dataType || "*" ).toLowerCase().match( rnotwhite ) || [ "" ];

		// A cross-domain request is in order when we have a protocol:host:port mismatch
		if ( s.crossDomain == null ) {
			parts = rurl.exec( s.url.toLowerCase() );
			s.crossDomain = !!( parts &&
				( parts[ 1 ] !== ajaxLocParts[ 1 ] || parts[ 2 ] !== ajaxLocParts[ 2 ] ||
					( parts[ 3 ] || ( parts[ 1 ] === "http:" ? "80" : "443" ) ) !==
						( ajaxLocParts[ 3 ] || ( ajaxLocParts[ 1 ] === "http:" ? "80" : "443" ) ) )
			);
		}

		// Convert data if not already a string
		if ( s.data && s.processData && typeof s.data !== "string" ) {
			s.data = jQuery.param( s.data, s.traditional );
		}

		// Apply prefilters
		inspectPrefiltersOrTransports( prefilters, s, options, jqXHR );

		// If request was aborted inside a prefilter, stop there
		if ( state === 2 ) {
			return jqXHR;
		}

		// We can fire global events as of now if asked to
		fireGlobals = s.global;

		// Watch for a new set of requests
		if ( fireGlobals && jQuery.active++ === 0 ) {
			jQuery.event.trigger("ajaxStart");
		}

		// Uppercase the type
		s.type = s.type.toUpperCase();

		// Determine if request has content
		s.hasContent = !rnoContent.test( s.type );

		// Save the URL in case we're toying with the If-Modified-Since
		// and/or If-None-Match header later on
		cacheURL = s.url;

		// More options handling for requests with no content
		if ( !s.hasContent ) {

			// If data is available, append data to url
			if ( s.data ) {
				cacheURL = ( s.url += ( rquery.test( cacheURL ) ? "&" : "?" ) + s.data );
				// #9682: remove data so that it's not used in an eventual retry
				delete s.data;
			}

			// Add anti-cache in url if needed
			if ( s.cache === false ) {
				s.url = rts.test( cacheURL ) ?

					// If there is already a '_' parameter, set its value
					cacheURL.replace( rts, "$1_=" + nonce++ ) :

					// Otherwise add one to the end
					cacheURL + ( rquery.test( cacheURL ) ? "&" : "?" ) + "_=" + nonce++;
			}
		}

		// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
		if ( s.ifModified ) {
			if ( jQuery.lastModified[ cacheURL ] ) {
				jqXHR.setRequestHeader( "If-Modified-Since", jQuery.lastModified[ cacheURL ] );
			}
			if ( jQuery.etag[ cacheURL ] ) {
				jqXHR.setRequestHeader( "If-None-Match", jQuery.etag[ cacheURL ] );
			}
		}

		// Set the correct header, if data is being sent
		if ( s.data && s.hasContent && s.contentType !== false || options.contentType ) {
			jqXHR.setRequestHeader( "Content-Type", s.contentType );
		}

		// Set the Accepts header for the server, depending on the dataType
		jqXHR.setRequestHeader(
			"Accept",
			s.dataTypes[ 0 ] && s.accepts[ s.dataTypes[0] ] ?
				s.accepts[ s.dataTypes[0] ] + ( s.dataTypes[ 0 ] !== "*" ? ", " + allTypes + "; q=0.01" : "" ) :
				s.accepts[ "*" ]
		);

		// Check for headers option
		for ( i in s.headers ) {
			jqXHR.setRequestHeader( i, s.headers[ i ] );
		}

		// Allow custom headers/mimetypes and early abort
		if ( s.beforeSend && ( s.beforeSend.call( callbackContext, jqXHR, s ) === false || state === 2 ) ) {
			// Abort if not done already and return
			return jqXHR.abort();
		}

		// aborting is no longer a cancellation
		strAbort = "abort";

		// Install callbacks on deferreds
		for ( i in { success: 1, error: 1, complete: 1 } ) {
			jqXHR[ i ]( s[ i ] );
		}

		// Get transport
		transport = inspectPrefiltersOrTransports( transports, s, options, jqXHR );

		// If no transport, we auto-abort
		if ( !transport ) {
			done( -1, "No Transport" );
		} else {
			jqXHR.readyState = 1;

			// Send global event
			if ( fireGlobals ) {
				globalEventContext.trigger( "ajaxSend", [ jqXHR, s ] );
			}
			// Timeout
			if ( s.async && s.timeout > 0 ) {
				timeoutTimer = setTimeout(function() {
					jqXHR.abort("timeout");
				}, s.timeout );
			}

			try {
				state = 1;
				transport.send( requestHeaders, done );
			} catch ( e ) {
				// Propagate exception as error if not done
				if ( state < 2 ) {
					done( -1, e );
				// Simply rethrow otherwise
				} else {
					throw e;
				}
			}
		}

		// Callback for when everything is done
		function done( status, nativeStatusText, responses, headers ) {
			var isSuccess, success, error, response, modified,
				statusText = nativeStatusText;

			// Called once
			if ( state === 2 ) {
				return;
			}

			// State is "done" now
			state = 2;

			// Clear timeout if it exists
			if ( timeoutTimer ) {
				clearTimeout( timeoutTimer );
			}

			// Dereference transport for early garbage collection
			// (no matter how long the jqXHR object will be used)
			transport = undefined;

			// Cache response headers
			responseHeadersString = headers || "";

			// Set readyState
			jqXHR.readyState = status > 0 ? 4 : 0;

			// Determine if successful
			isSuccess = status >= 200 && status < 300 || status === 304;

			// Get response data
			if ( responses ) {
				response = ajaxHandleResponses( s, jqXHR, responses );
			}

			// Convert no matter what (that way responseXXX fields are always set)
			response = ajaxConvert( s, response, jqXHR, isSuccess );

			// If successful, handle type chaining
			if ( isSuccess ) {

				// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
				if ( s.ifModified ) {
					modified = jqXHR.getResponseHeader("Last-Modified");
					if ( modified ) {
						jQuery.lastModified[ cacheURL ] = modified;
					}
					modified = jqXHR.getResponseHeader("etag");
					if ( modified ) {
						jQuery.etag[ cacheURL ] = modified;
					}
				}

				// if no content
				if ( status === 204 || s.type === "HEAD" ) {
					statusText = "nocontent";

				// if not modified
				} else if ( status === 304 ) {
					statusText = "notmodified";

				// If we have data, let's convert it
				} else {
					statusText = response.state;
					success = response.data;
					error = response.error;
					isSuccess = !error;
				}
			} else {
				// We extract error from statusText
				// then normalize statusText and status for non-aborts
				error = statusText;
				if ( status || !statusText ) {
					statusText = "error";
					if ( status < 0 ) {
						status = 0;
					}
				}
			}

			// Set data for the fake xhr object
			jqXHR.status = status;
			jqXHR.statusText = ( nativeStatusText || statusText ) + "";

			// Success/Error
			if ( isSuccess ) {
				deferred.resolveWith( callbackContext, [ success, statusText, jqXHR ] );
			} else {
				deferred.rejectWith( callbackContext, [ jqXHR, statusText, error ] );
			}

			// Status-dependent callbacks
			jqXHR.statusCode( statusCode );
			statusCode = undefined;

			if ( fireGlobals ) {
				globalEventContext.trigger( isSuccess ? "ajaxSuccess" : "ajaxError",
					[ jqXHR, s, isSuccess ? success : error ] );
			}

			// Complete
			completeDeferred.fireWith( callbackContext, [ jqXHR, statusText ] );

			if ( fireGlobals ) {
				globalEventContext.trigger( "ajaxComplete", [ jqXHR, s ] );
				// Handle the global AJAX counter
				if ( !( --jQuery.active ) ) {
					jQuery.event.trigger("ajaxStop");
				}
			}
		}

		return jqXHR;
	},

	getJSON: function( url, data, callback ) {
		return jQuery.get( url, data, callback, "json" );
	},

	getScript: function( url, callback ) {
		return jQuery.get( url, undefined, callback, "script" );
	}
});

jQuery.each( [ "get", "post" ], function( i, method ) {
	jQuery[ method ] = function( url, data, callback, type ) {
		// shift arguments if data argument was omitted
		if ( jQuery.isFunction( data ) ) {
			type = type || callback;
			callback = data;
			data = undefined;
		}

		return jQuery.ajax({
			url: url,
			type: method,
			dataType: type,
			data: data,
			success: callback
		});
	};
});

// Attach a bunch of functions for handling common AJAX events
jQuery.each( [ "ajaxStart", "ajaxStop", "ajaxComplete", "ajaxError", "ajaxSuccess", "ajaxSend" ], function( i, type ) {
	jQuery.fn[ type ] = function( fn ) {
		return this.on( type, fn );
	};
});


jQuery._evalUrl = function( url ) {
	return jQuery.ajax({
		url: url,
		type: "GET",
		dataType: "script",
		async: false,
		global: false,
		"throws": true
	});
};


jQuery.fn.extend({
	wrapAll: function( html ) {
		if ( jQuery.isFunction( html ) ) {
			return this.each(function(i) {
				jQuery(this).wrapAll( html.call(this, i) );
			});
		}

		if ( this[0] ) {
			// The elements to wrap the target around
			var wrap = jQuery( html, this[0].ownerDocument ).eq(0).clone(true);

			if ( this[0].parentNode ) {
				wrap.insertBefore( this[0] );
			}

			wrap.map(function() {
				var elem = this;

				while ( elem.firstChild && elem.firstChild.nodeType === 1 ) {
					elem = elem.firstChild;
				}

				return elem;
			}).append( this );
		}

		return this;
	},

	wrapInner: function( html ) {
		if ( jQuery.isFunction( html ) ) {
			return this.each(function(i) {
				jQuery(this).wrapInner( html.call(this, i) );
			});
		}

		return this.each(function() {
			var self = jQuery( this ),
				contents = self.contents();

			if ( contents.length ) {
				contents.wrapAll( html );

			} else {
				self.append( html );
			}
		});
	},

	wrap: function( html ) {
		var isFunction = jQuery.isFunction( html );

		return this.each(function(i) {
			jQuery( this ).wrapAll( isFunction ? html.call(this, i) : html );
		});
	},

	unwrap: function() {
		return this.parent().each(function() {
			if ( !jQuery.nodeName( this, "body" ) ) {
				jQuery( this ).replaceWith( this.childNodes );
			}
		}).end();
	}
});


jQuery.expr.filters.hidden = function( elem ) {
	// Support: Opera <= 12.12
	// Opera reports offsetWidths and offsetHeights less than zero on some elements
	return elem.offsetWidth <= 0 && elem.offsetHeight <= 0 ||
		(!support.reliableHiddenOffsets() &&
			((elem.style && elem.style.display) || jQuery.css( elem, "display" )) === "none");
};

jQuery.expr.filters.visible = function( elem ) {
	return !jQuery.expr.filters.hidden( elem );
};




var r20 = /%20/g,
	rbracket = /\[\]$/,
	rCRLF = /\r?\n/g,
	rsubmitterTypes = /^(?:submit|button|image|reset|file)$/i,
	rsubmittable = /^(?:input|select|textarea|keygen)/i;

function buildParams( prefix, obj, traditional, add ) {
	var name;

	if ( jQuery.isArray( obj ) ) {
		// Serialize array item.
		jQuery.each( obj, function( i, v ) {
			if ( traditional || rbracket.test( prefix ) ) {
				// Treat each array item as a scalar.
				add( prefix, v );

			} else {
				// Item is non-scalar (array or object), encode its numeric index.
				buildParams( prefix + "[" + ( typeof v === "object" ? i : "" ) + "]", v, traditional, add );
			}
		});

	} else if ( !traditional && jQuery.type( obj ) === "object" ) {
		// Serialize object item.
		for ( name in obj ) {
			buildParams( prefix + "[" + name + "]", obj[ name ], traditional, add );
		}

	} else {
		// Serialize scalar item.
		add( prefix, obj );
	}
}

// Serialize an array of form elements or a set of
// key/values into a query string
jQuery.param = function( a, traditional ) {
	var prefix,
		s = [],
		add = function( key, value ) {
			// If value is a function, invoke it and return its value
			value = jQuery.isFunction( value ) ? value() : ( value == null ? "" : value );
			s[ s.length ] = encodeURIComponent( key ) + "=" + encodeURIComponent( value );
		};

	// Set traditional to true for jQuery <= 1.3.2 behavior.
	if ( traditional === undefined ) {
		traditional = jQuery.ajaxSettings && jQuery.ajaxSettings.traditional;
	}

	// If an array was passed in, assume that it is an array of form elements.
	if ( jQuery.isArray( a ) || ( a.jquery && !jQuery.isPlainObject( a ) ) ) {
		// Serialize the form elements
		jQuery.each( a, function() {
			add( this.name, this.value );
		});

	} else {
		// If traditional, encode the "old" way (the way 1.3.2 or older
		// did it), otherwise encode params recursively.
		for ( prefix in a ) {
			buildParams( prefix, a[ prefix ], traditional, add );
		}
	}

	// Return the resulting serialization
	return s.join( "&" ).replace( r20, "+" );
};

jQuery.fn.extend({
	serialize: function() {
		return jQuery.param( this.serializeArray() );
	},
	serializeArray: function() {
		return this.map(function() {
			// Can add propHook for "elements" to filter or add form elements
			var elements = jQuery.prop( this, "elements" );
			return elements ? jQuery.makeArray( elements ) : this;
		})
		.filter(function() {
			var type = this.type;
			// Use .is(":disabled") so that fieldset[disabled] works
			return this.name && !jQuery( this ).is( ":disabled" ) &&
				rsubmittable.test( this.nodeName ) && !rsubmitterTypes.test( type ) &&
				( this.checked || !rcheckableType.test( type ) );
		})
		.map(function( i, elem ) {
			var val = jQuery( this ).val();

			return val == null ?
				null :
				jQuery.isArray( val ) ?
					jQuery.map( val, function( val ) {
						return { name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
					}) :
					{ name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
		}).get();
	}
});


// Create the request object
// (This is still attached to ajaxSettings for backward compatibility)
jQuery.ajaxSettings.xhr = window.ActiveXObject !== undefined ?
	// Support: IE6+
	function() {

		// XHR cannot access local files, always use ActiveX for that case
		return !this.isLocal &&

			// Support: IE7-8
			// oldIE XHR does not support non-RFC2616 methods (#13240)
			// See http://msdn.microsoft.com/en-us/library/ie/ms536648(v=vs.85).aspx
			// and http://www.w3.org/Protocols/rfc2616/rfc2616-sec9.html#sec9
			// Although this check for six methods instead of eight
			// since IE also does not support "trace" and "connect"
			/^(get|post|head|put|delete|options)$/i.test( this.type ) &&

			createStandardXHR() || createActiveXHR();
	} :
	// For all other browsers, use the standard XMLHttpRequest object
	createStandardXHR;

var xhrId = 0,
	xhrCallbacks = {},
	xhrSupported = jQuery.ajaxSettings.xhr();

// Support: IE<10
// Open requests must be manually aborted on unload (#5280)
if ( window.ActiveXObject ) {
	jQuery( window ).on( "unload", function() {
		for ( var key in xhrCallbacks ) {
			xhrCallbacks[ key ]( undefined, true );
		}
	});
}

// Determine support properties
support.cors = !!xhrSupported && ( "withCredentials" in xhrSupported );
xhrSupported = support.ajax = !!xhrSupported;

// Create transport if the browser can provide an xhr
if ( xhrSupported ) {

	jQuery.ajaxTransport(function( options ) {
		// Cross domain only allowed if supported through XMLHttpRequest
		if ( !options.crossDomain || support.cors ) {

			var callback;

			return {
				send: function( headers, complete ) {
					var i,
						xhr = options.xhr(),
						id = ++xhrId;

					// Open the socket
					xhr.open( options.type, options.url, options.async, options.username, options.password );

					// Apply custom fields if provided
					if ( options.xhrFields ) {
						for ( i in options.xhrFields ) {
							xhr[ i ] = options.xhrFields[ i ];
						}
					}

					// Override mime type if needed
					if ( options.mimeType && xhr.overrideMimeType ) {
						xhr.overrideMimeType( options.mimeType );
					}

					// X-Requested-With header
					// For cross-domain requests, seeing as conditions for a preflight are
					// akin to a jigsaw puzzle, we simply never set it to be sure.
					// (it can always be set on a per-request basis or even using ajaxSetup)
					// For same-domain requests, won't change header if already provided.
					if ( !options.crossDomain && !headers["X-Requested-With"] ) {
						headers["X-Requested-With"] = "XMLHttpRequest";
					}

					// Set headers
					for ( i in headers ) {
						// Support: IE<9
						// IE's ActiveXObject throws a 'Type Mismatch' exception when setting
						// request header to a null-value.
						//
						// To keep consistent with other XHR implementations, cast the value
						// to string and ignore `undefined`.
						if ( headers[ i ] !== undefined ) {
							xhr.setRequestHeader( i, headers[ i ] + "" );
						}
					}

					// Do send the request
					// This may raise an exception which is actually
					// handled in jQuery.ajax (so no try/catch here)
					xhr.send( ( options.hasContent && options.data ) || null );

					// Listener
					callback = function( _, isAbort ) {
						var status, statusText, responses;

						// Was never called and is aborted or complete
						if ( callback && ( isAbort || xhr.readyState === 4 ) ) {
							// Clean up
							delete xhrCallbacks[ id ];
							callback = undefined;
							xhr.onreadystatechange = jQuery.noop;

							// Abort manually if needed
							if ( isAbort ) {
								if ( xhr.readyState !== 4 ) {
									xhr.abort();
								}
							} else {
								responses = {};
								status = xhr.status;

								// Support: IE<10
								// Accessing binary-data responseText throws an exception
								// (#11426)
								if ( typeof xhr.responseText === "string" ) {
									responses.text = xhr.responseText;
								}

								// Firefox throws an exception when accessing
								// statusText for faulty cross-domain requests
								try {
									statusText = xhr.statusText;
								} catch( e ) {
									// We normalize with Webkit giving an empty statusText
									statusText = "";
								}

								// Filter status for non standard behaviors

								// If the request is local and we have data: assume a success
								// (success with no data won't get notified, that's the best we
								// can do given current implementations)
								if ( !status && options.isLocal && !options.crossDomain ) {
									status = responses.text ? 200 : 404;
								// IE - #1450: sometimes returns 1223 when it should be 204
								} else if ( status === 1223 ) {
									status = 204;
								}
							}
						}

						// Call complete if needed
						if ( responses ) {
							complete( status, statusText, responses, xhr.getAllResponseHeaders() );
						}
					};

					if ( !options.async ) {
						// if we're in sync mode we fire the callback
						callback();
					} else if ( xhr.readyState === 4 ) {
						// (IE6 & IE7) if it's in cache and has been
						// retrieved directly we need to fire the callback
						setTimeout( callback );
					} else {
						// Add to the list of active xhr callbacks
						xhr.onreadystatechange = xhrCallbacks[ id ] = callback;
					}
				},

				abort: function() {
					if ( callback ) {
						callback( undefined, true );
					}
				}
			};
		}
	});
}

// Functions to create xhrs
function createStandardXHR() {
	try {
		return new window.XMLHttpRequest();
	} catch( e ) {}
}

function createActiveXHR() {
	try {
		return new window.ActiveXObject( "Microsoft.XMLHTTP" );
	} catch( e ) {}
}




// Install script dataType
jQuery.ajaxSetup({
	accepts: {
		script: "text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"
	},
	contents: {
		script: /(?:java|ecma)script/
	},
	converters: {
		"text script": function( text ) {
			jQuery.globalEval( text );
			return text;
		}
	}
});

// Handle cache's special case and global
jQuery.ajaxPrefilter( "script", function( s ) {
	if ( s.cache === undefined ) {
		s.cache = false;
	}
	if ( s.crossDomain ) {
		s.type = "GET";
		s.global = false;
	}
});

// Bind script tag hack transport
jQuery.ajaxTransport( "script", function(s) {

	// This transport only deals with cross domain requests
	if ( s.crossDomain ) {

		var script,
			head = document.head || jQuery("head")[0] || document.documentElement;

		return {

			send: function( _, callback ) {

				script = document.createElement("script");

				script.async = true;

				if ( s.scriptCharset ) {
					script.charset = s.scriptCharset;
				}

				script.src = s.url;

				// Attach handlers for all browsers
				script.onload = script.onreadystatechange = function( _, isAbort ) {

					if ( isAbort || !script.readyState || /loaded|complete/.test( script.readyState ) ) {

						// Handle memory leak in IE
						script.onload = script.onreadystatechange = null;

						// Remove the script
						if ( script.parentNode ) {
							script.parentNode.removeChild( script );
						}

						// Dereference the script
						script = null;

						// Callback if not abort
						if ( !isAbort ) {
							callback( 200, "success" );
						}
					}
				};

				// Circumvent IE6 bugs with base elements (#2709 and #4378) by prepending
				// Use native DOM manipulation to avoid our domManip AJAX trickery
				head.insertBefore( script, head.firstChild );
			},

			abort: function() {
				if ( script ) {
					script.onload( undefined, true );
				}
			}
		};
	}
});




var oldCallbacks = [],
	rjsonp = /(=)\?(?=&|$)|\?\?/;

// Default jsonp settings
jQuery.ajaxSetup({
	jsonp: "callback",
	jsonpCallback: function() {
		var callback = oldCallbacks.pop() || ( jQuery.expando + "_" + ( nonce++ ) );
		this[ callback ] = true;
		return callback;
	}
});

// Detect, normalize options and install callbacks for jsonp requests
jQuery.ajaxPrefilter( "json jsonp", function( s, originalSettings, jqXHR ) {

	var callbackName, overwritten, responseContainer,
		jsonProp = s.jsonp !== false && ( rjsonp.test( s.url ) ?
			"url" :
			typeof s.data === "string" && !( s.contentType || "" ).indexOf("application/x-www-form-urlencoded") && rjsonp.test( s.data ) && "data"
		);

	// Handle iff the expected data type is "jsonp" or we have a parameter to set
	if ( jsonProp || s.dataTypes[ 0 ] === "jsonp" ) {

		// Get callback name, remembering preexisting value associated with it
		callbackName = s.jsonpCallback = jQuery.isFunction( s.jsonpCallback ) ?
			s.jsonpCallback() :
			s.jsonpCallback;

		// Insert callback into url or form data
		if ( jsonProp ) {
			s[ jsonProp ] = s[ jsonProp ].replace( rjsonp, "$1" + callbackName );
		} else if ( s.jsonp !== false ) {
			s.url += ( rquery.test( s.url ) ? "&" : "?" ) + s.jsonp + "=" + callbackName;
		}

		// Use data converter to retrieve json after script execution
		s.converters["script json"] = function() {
			if ( !responseContainer ) {
				jQuery.error( callbackName + " was not called" );
			}
			return responseContainer[ 0 ];
		};

		// force json dataType
		s.dataTypes[ 0 ] = "json";

		// Install callback
		overwritten = window[ callbackName ];
		window[ callbackName ] = function() {
			responseContainer = arguments;
		};

		// Clean-up function (fires after converters)
		jqXHR.always(function() {
			// Restore preexisting value
			window[ callbackName ] = overwritten;

			// Save back as free
			if ( s[ callbackName ] ) {
				// make sure that re-using the options doesn't screw things around
				s.jsonpCallback = originalSettings.jsonpCallback;

				// save the callback name for future use
				oldCallbacks.push( callbackName );
			}

			// Call if it was a function and we have a response
			if ( responseContainer && jQuery.isFunction( overwritten ) ) {
				overwritten( responseContainer[ 0 ] );
			}

			responseContainer = overwritten = undefined;
		});

		// Delegate to script
		return "script";
	}
});




// data: string of html
// context (optional): If specified, the fragment will be created in this context, defaults to document
// keepScripts (optional): If true, will include scripts passed in the html string
jQuery.parseHTML = function( data, context, keepScripts ) {
	if ( !data || typeof data !== "string" ) {
		return null;
	}
	if ( typeof context === "boolean" ) {
		keepScripts = context;
		context = false;
	}
	context = context || document;

	var parsed = rsingleTag.exec( data ),
		scripts = !keepScripts && [];

	// Single tag
	if ( parsed ) {
		return [ context.createElement( parsed[1] ) ];
	}

	parsed = jQuery.buildFragment( [ data ], context, scripts );

	if ( scripts && scripts.length ) {
		jQuery( scripts ).remove();
	}

	return jQuery.merge( [], parsed.childNodes );
};


// Keep a copy of the old load method
var _load = jQuery.fn.load;

/**
 * Load a url into a page
 */
jQuery.fn.load = function( url, params, callback ) {
	if ( typeof url !== "string" && _load ) {
		return _load.apply( this, arguments );
	}

	var selector, response, type,
		self = this,
		off = url.indexOf(" ");

	if ( off >= 0 ) {
		selector = jQuery.trim( url.slice( off, url.length ) );
		url = url.slice( 0, off );
	}

	// If it's a function
	if ( jQuery.isFunction( params ) ) {

		// We assume that it's the callback
		callback = params;
		params = undefined;

	// Otherwise, build a param string
	} else if ( params && typeof params === "object" ) {
		type = "POST";
	}

	// If we have elements to modify, make the request
	if ( self.length > 0 ) {
		jQuery.ajax({
			url: url,

			// if "type" variable is undefined, then "GET" method will be used
			type: type,
			dataType: "html",
			data: params
		}).done(function( responseText ) {

			// Save response for use in complete callback
			response = arguments;

			self.html( selector ?

				// If a selector was specified, locate the right elements in a dummy div
				// Exclude scripts to avoid IE 'Permission Denied' errors
				jQuery("<div>").append( jQuery.parseHTML( responseText ) ).find( selector ) :

				// Otherwise use the full result
				responseText );

		}).complete( callback && function( jqXHR, status ) {
			self.each( callback, response || [ jqXHR.responseText, status, jqXHR ] );
		});
	}

	return this;
};




jQuery.expr.filters.animated = function( elem ) {
	return jQuery.grep(jQuery.timers, function( fn ) {
		return elem === fn.elem;
	}).length;
};





var docElem = window.document.documentElement;

/**
 * Gets a window from an element
 */
function getWindow( elem ) {
	return jQuery.isWindow( elem ) ?
		elem :
		elem.nodeType === 9 ?
			elem.defaultView || elem.parentWindow :
			false;
}

jQuery.offset = {
	setOffset: function( elem, options, i ) {
		var curPosition, curLeft, curCSSTop, curTop, curOffset, curCSSLeft, calculatePosition,
			position = jQuery.css( elem, "position" ),
			curElem = jQuery( elem ),
			props = {};

		// set position first, in-case top/left are set even on static elem
		if ( position === "static" ) {
			elem.style.position = "relative";
		}

		curOffset = curElem.offset();
		curCSSTop = jQuery.css( elem, "top" );
		curCSSLeft = jQuery.css( elem, "left" );
		calculatePosition = ( position === "absolute" || position === "fixed" ) &&
			jQuery.inArray("auto", [ curCSSTop, curCSSLeft ] ) > -1;

		// need to be able to calculate position if either top or left is auto and position is either absolute or fixed
		if ( calculatePosition ) {
			curPosition = curElem.position();
			curTop = curPosition.top;
			curLeft = curPosition.left;
		} else {
			curTop = parseFloat( curCSSTop ) || 0;
			curLeft = parseFloat( curCSSLeft ) || 0;
		}

		if ( jQuery.isFunction( options ) ) {
			options = options.call( elem, i, curOffset );
		}

		if ( options.top != null ) {
			props.top = ( options.top - curOffset.top ) + curTop;
		}
		if ( options.left != null ) {
			props.left = ( options.left - curOffset.left ) + curLeft;
		}

		if ( "using" in options ) {
			options.using.call( elem, props );
		} else {
			curElem.css( props );
		}
	}
};

jQuery.fn.extend({
	offset: function( options ) {
		if ( arguments.length ) {
			return options === undefined ?
				this :
				this.each(function( i ) {
					jQuery.offset.setOffset( this, options, i );
				});
		}

		var docElem, win,
			box = { top: 0, left: 0 },
			elem = this[ 0 ],
			doc = elem && elem.ownerDocument;

		if ( !doc ) {
			return;
		}

		docElem = doc.documentElement;

		// Make sure it's not a disconnected DOM node
		if ( !jQuery.contains( docElem, elem ) ) {
			return box;
		}

		// If we don't have gBCR, just use 0,0 rather than error
		// BlackBerry 5, iOS 3 (original iPhone)
		if ( typeof elem.getBoundingClientRect !== strundefined ) {
			box = elem.getBoundingClientRect();
		}
		win = getWindow( doc );
		return {
			top: box.top  + ( win.pageYOffset || docElem.scrollTop )  - ( docElem.clientTop  || 0 ),
			left: box.left + ( win.pageXOffset || docElem.scrollLeft ) - ( docElem.clientLeft || 0 )
		};
	},

	position: function() {
		if ( !this[ 0 ] ) {
			return;
		}

		var offsetParent, offset,
			parentOffset = { top: 0, left: 0 },
			elem = this[ 0 ];

		// fixed elements are offset from window (parentOffset = {top:0, left: 0}, because it is its only offset parent
		if ( jQuery.css( elem, "position" ) === "fixed" ) {
			// we assume that getBoundingClientRect is available when computed position is fixed
			offset = elem.getBoundingClientRect();
		} else {
			// Get *real* offsetParent
			offsetParent = this.offsetParent();

			// Get correct offsets
			offset = this.offset();
			if ( !jQuery.nodeName( offsetParent[ 0 ], "html" ) ) {
				parentOffset = offsetParent.offset();
			}

			// Add offsetParent borders
			parentOffset.top  += jQuery.css( offsetParent[ 0 ], "borderTopWidth", true );
			parentOffset.left += jQuery.css( offsetParent[ 0 ], "borderLeftWidth", true );
		}

		// Subtract parent offsets and element margins
		// note: when an element has margin: auto the offsetLeft and marginLeft
		// are the same in Safari causing offset.left to incorrectly be 0
		return {
			top:  offset.top  - parentOffset.top - jQuery.css( elem, "marginTop", true ),
			left: offset.left - parentOffset.left - jQuery.css( elem, "marginLeft", true)
		};
	},

	offsetParent: function() {
		return this.map(function() {
			var offsetParent = this.offsetParent || docElem;

			while ( offsetParent && ( !jQuery.nodeName( offsetParent, "html" ) && jQuery.css( offsetParent, "position" ) === "static" ) ) {
				offsetParent = offsetParent.offsetParent;
			}
			return offsetParent || docElem;
		});
	}
});

// Create scrollLeft and scrollTop methods
jQuery.each( { scrollLeft: "pageXOffset", scrollTop: "pageYOffset" }, function( method, prop ) {
	var top = /Y/.test( prop );

	jQuery.fn[ method ] = function( val ) {
		return access( this, function( elem, method, val ) {
			var win = getWindow( elem );

			if ( val === undefined ) {
				return win ? (prop in win) ? win[ prop ] :
					win.document.documentElement[ method ] :
					elem[ method ];
			}

			if ( win ) {
				win.scrollTo(
					!top ? val : jQuery( win ).scrollLeft(),
					top ? val : jQuery( win ).scrollTop()
				);

			} else {
				elem[ method ] = val;
			}
		}, method, val, arguments.length, null );
	};
});

// Add the top/left cssHooks using jQuery.fn.position
// Webkit bug: https://bugs.webkit.org/show_bug.cgi?id=29084
// getComputedStyle returns percent when specified for top/left/bottom/right
// rather than make the css module depend on the offset module, we just check for it here
jQuery.each( [ "top", "left" ], function( i, prop ) {
	jQuery.cssHooks[ prop ] = addGetHookIf( support.pixelPosition,
		function( elem, computed ) {
			if ( computed ) {
				computed = curCSS( elem, prop );
				// if curCSS returns percentage, fallback to offset
				return rnumnonpx.test( computed ) ?
					jQuery( elem ).position()[ prop ] + "px" :
					computed;
			}
		}
	);
});


// Create innerHeight, innerWidth, height, width, outerHeight and outerWidth methods
jQuery.each( { Height: "height", Width: "width" }, function( name, type ) {
	jQuery.each( { padding: "inner" + name, content: type, "": "outer" + name }, function( defaultExtra, funcName ) {
		// margin is only for outerHeight, outerWidth
		jQuery.fn[ funcName ] = function( margin, value ) {
			var chainable = arguments.length && ( defaultExtra || typeof margin !== "boolean" ),
				extra = defaultExtra || ( margin === true || value === true ? "margin" : "border" );

			return access( this, function( elem, type, value ) {
				var doc;

				if ( jQuery.isWindow( elem ) ) {
					// As of 5/8/2012 this will yield incorrect results for Mobile Safari, but there
					// isn't a whole lot we can do. See pull request at this URL for discussion:
					// https://github.com/jquery/jquery/pull/764
					return elem.document.documentElement[ "client" + name ];
				}

				// Get document width or height
				if ( elem.nodeType === 9 ) {
					doc = elem.documentElement;

					// Either scroll[Width/Height] or offset[Width/Height] or client[Width/Height], whichever is greatest
					// unfortunately, this causes bug #3838 in IE6/8 only, but there is currently no good, small way to fix it.
					return Math.max(
						elem.body[ "scroll" + name ], doc[ "scroll" + name ],
						elem.body[ "offset" + name ], doc[ "offset" + name ],
						doc[ "client" + name ]
					);
				}

				return value === undefined ?
					// Get width or height on the element, requesting but not forcing parseFloat
					jQuery.css( elem, type, extra ) :

					// Set width or height on the element
					jQuery.style( elem, type, value, extra );
			}, type, chainable ? margin : undefined, chainable, null );
		};
	});
});


// The number of elements contained in the matched element set
jQuery.fn.size = function() {
	return this.length;
};

jQuery.fn.andSelf = jQuery.fn.addBack;




// Register as a named AMD module, since jQuery can be concatenated with other
// files that may use define, but not via a proper concatenation script that
// understands anonymous AMD modules. A named AMD is safest and most robust
// way to register. Lowercase jquery is used because AMD module names are
// derived from file names, and jQuery is normally delivered in a lowercase
// file name. Do this after creating the global so that if an AMD module wants
// to call noConflict to hide this version of jQuery, it will work.

// Note that for maximum portability, libraries that are not jQuery should
// declare themselves as anonymous modules, and avoid setting a global if an
// AMD loader is present. jQuery is a special case. For more information, see
// https://github.com/jrburke/requirejs/wiki/Updating-existing-libraries#wiki-anon

if ( typeof define === "function" && define.amd ) {
	define( "jquery", [], function() {
		return jQuery;
	});
}




var
	// Map over jQuery in case of overwrite
	_jQuery = window.jQuery,

	// Map over the $ in case of overwrite
	_$ = window.$;

jQuery.noConflict = function( deep ) {
	if ( window.$ === jQuery ) {
		window.$ = _$;
	}

	if ( deep && window.jQuery === jQuery ) {
		window.jQuery = _jQuery;
	}

	return jQuery;
};

// Expose jQuery and $ identifiers, even in
// AMD (#7102#comment:10, https://github.com/jquery/jquery/pull/557)
// and CommonJS for browser emulators (#13566)
if ( typeof noGlobal === strundefined ) {
	window.jQuery = window.$ = jQuery;
}




return jQuery;

}));


/* >>>>>>>>>> BEGIN javascript.js */
/* >>>>>>>>>> BEGIN source/license.js */
/**
 * @license
 * ==========================================================================
 * SproutCore Costello -- Property Observing Library
 * Copyright ©2006-2011, Strobe Inc. and contributors.
 * Portions copyright ©2008-2011 Apple Inc. All rights reserved.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 * DEALINGS IN THE SOFTWARE.
 * 
 * For more information about SproutCore, visit http://www.sproutcore.com
 * 
 * ==========================================================================
 */

/* >>>>>>>>>> BEGIN source/core.js */
// ==========================================================================
// Project:   SproutCore Costello - Property Observing Library
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
/*global require, console */

// These commands are used by the build tools to control load order.  On the
// client side these are a no-op.
if (!window.require) { window.require = function require() {}; }
if (!window.sc_require) { window.sc_require = require; }
if (!window.sc_resource) { window.sc_resource = function sc_resource() {}; }
sc_require('license');

// ........................................
// GLOBAL CONSTANTS
//
// Most global constants should be defined inside of the SC namespace.
// However the following two are useful enough and generally benign enough
// to put into the global object.
window.YES = true;
window.NO = false;

// prevent a console.log from blowing things up if we are on a browser that
// does not support it
if (typeof console === 'undefined') {
  window.console = {};
  console.log = console.info = console.warn = console.error = function () {};
}

window.SC = window.SC || {};
window.SproutCore = window.SproutCore || SC;

// ........................................
// BOOTSTRAP
//
// The root namespace and some common utility methods are defined here. The
// rest of the methods go into the mixin defined below.

/**
  @version 1.11.0
  @namespace

  All SproutCore methods and functions are defined
  inside of this namespace.  You generally should not add new properties to
  this namespace as it may be overwritten by future versions of SproutCore.

  You can also use the shorthand "SC" instead of "SproutCore".

  SproutCore-runtime is a framework that provides core functions for SproutCore
  including cross-platform functions, support for property observing and
  objects.  It's focus is on small size and performance.  You can use this
  in place of or along-side other cross-platform libraries such as jQuery or
  Prototype.
*/
SC = window.SC; // This is dumb but necessary for jsdoc to get it right

SC.VERSION = '1.11.0';

/**
  @private

  Adds properties to a target object. You must specify whether
  to overwrite a value for a property or not.

  Used as a base function for the wrapper functions SC.mixin and SC.supplement.

  @param {Boolean} overwrite if a target has a value for a property, this specifies
                  whether or not to overwrite that value with the copyied object's
                  property value.
  @param {Object} target the target object to extend
  @param {Object} properties one or more objects with properties to copy.
  @returns {Object} the target object.
  @static
*/
SC._baseMixin = function (override, args) {
  // Copy reference to target object
  var target = args[0] || {},
      idx = 1,
      length = args.length,
      options, copy, key;

  // Handle case where we have only one item...extend SC
  if (length === 1) {
    target = this || {};
    idx = 0;
  }

  for (; idx < length; idx++) {
    if (!(options = args[idx])) continue;
    for (key in options) {
      if (!options.hasOwnProperty(key)) continue;
      copy = options[key];
      if (target === copy) continue; // prevent never-ending loop
      if (copy !== undefined && (override || (target[key] === undefined))) target[key] = copy;
    }
    // Manually copy toString() because some JS engines do not enumerate it
    // (such as IE8)
    if (options.hasOwnProperty('toString')) target.toString = options.toString;
  }

  return target;
};

/**
  Adds properties to a target object.

  Takes the root object and adds the attributes for any additional
  arguments passed.

  @param {Object} target the target object to extend
  @param {Object} properties one or more objects with properties to copy.
  @returns {Object} the target object.
  @static
*/
SC.mixin = function () {
  // Accessing `arguments.length` is just a Number and doesn't materialize the `arguments` object, which is costly.
  // TODO: Add macro to build tools for this.
  var args = new Array(arguments.length); // Array.prototype.slice.call(arguments)
  for (var i = 0, len = args.length; i < len; i++) { args[i] = arguments[i]; }

  return SC._baseMixin(true, args);
};

/**
  Adds properties to a target object.  Unlike SC.mixin, however, if the target
  already has a value for a property, it will not be overwritten.

  Takes the root object and adds the attributes for any additional
  arguments passed.

  @param {Object} target the target object to extend
  @param {Object} properties one or more objects with properties to copy.
  @returns {Object} the target object.
  @static
*/
SC.supplement = function () {
  // Accessing `arguments.length` is just a Number and doesn't materialize the `arguments` object which is costly.
  // TODO: Add macro to build tools for this.
  var args = new Array(arguments.length); // Array.prototype.slice.call(arguments)
  for (var i = 0, len = args.length; i < len; i++) { args[i] = arguments[i]; }

  return SC._baseMixin(false, args);
};

/**
  Alternative to mixin.  Provided for compatibility with jQuery.
  @function
*/
SC.extend = SC.mixin;

// ..........................................................
// CORE FUNCTIONS
//
// Enough with the bootstrap code.  Let's define some core functions

SC.mixin(/** @scope window.SC.prototype */ {

  // ........................................
  // GLOBAL CONSTANTS
  //
  T_ERROR:     'error',
  T_OBJECT:    'object',
  T_NULL:      'null',
  T_CLASS:     'class',
  T_HASH:      'hash',
  T_FUNCTION:  'function',
  T_UNDEFINED: 'undefined',
  T_NUMBER:    'number',
  T_BOOL:      'boolean',
  T_ARRAY:     'array',
  T_STRING:    'string',
  T_DATE:      'date',
  T_REGEXP:    'regexp',

  // ........................................
  // TYPING & ARRAY MESSAGING
  //

  /**
    Returns a consistent type for the passed item.

    Use this instead of the built-in typeOf() to get the type of an item.
    It will return the same result across all browsers and includes a bit
    more detail.

    @param {Object} item the item to check
    @returns {String} One of the following, depending on the type of the item<br>
            SC.T_STRING: String primitive,<br>
            SC.T_NUMBER: Number primitive,<br>
            SC.T_BOOLEAN: Boolean primitive,<br>
            SC.T_NULL: Null value,<br>
            SC.T_UNDEFINED: Undefined value,<br>
            SC.T_FUNCTION: A function,<br>
            SC.T_DATE: Date primitive,<br>
            SC.T_REGEXP: RegExp primitive,<br>
            SC.T_ARRAY: An instance of Array,<br>
            SC.T_CLASS: A SproutCore class (created using SC.Object.extend()),<br>
            SC.T_OBJECT: A SproutCore object instance,<br>
            SC.T_HASH: A JavaScript object not inheriting from SC.Object, <br>
            SC.T_ERROR: A SproutCore SC.Error object <br>
  */
  typeOf: function (item) {
    var nativeType = SC._nativeTypeOf(item);

    // Translate it into an SC type.
    if (nativeType === "function") {
      return item.isClass ? SC.T_CLASS : SC.T_FUNCTION;
    } else if (nativeType === "object") {

      // Note: typeOf() may be called before SC.Error has had a chance to load
      // so this code checks for the presence of SC.Error first just to make
      // sure.  No error instance can exist before the class loads anyway so
      // this is safe.
      if (SC.Error && (item instanceof SC.Error)) {
        return SC.T_ERROR;
      } else if (item instanceof SC.Object) {
        return SC.T_OBJECT;
      } else {
        return SC.T_HASH;
      }
    }

    return nativeType;
  },
  // Inlined from jQuery.type to avoid dependency.
  _nativeTypeOf: function(item) {
    if (item === undefined) return SC.T_UNDEFINED;
    if (item === null) return SC.T_NULL;

    var nativeType = typeof item,
        toString;
    if (nativeType === "object" || nativeType === "function") {
      toString = SC._nativeToString.call(item);
      return SC._nativeTypeHash[toString] || "object";
    } else {
      return nativeType;
    }
  } ,
  // Inlined from jQuery's class2type to avoid dependency.
  _nativeTypeHash: {
    "[object Boolean]": "boolean",
    "[object Number]": "number",
    "[object String]": "string",
    "[object Function]": "function",
    "[object Array]": "array",
    "[object Date]": "date",
    "[object RegExp]": "regexp",
    "[object Object]": "object"
  },
  // Inlined from jQuery to avoid dependency.
  _nativeToString: Object.prototype.toString,

  /**
    Returns YES if the passed value is null or undefined.  This avoids errors
    from JSLint complaining about use of ==, which can be technically
    confusing.

    @param {Object} obj value to test
    @returns {Boolean}
  */
  none: function (obj) {
    /*jshint eqnull:true */
    return obj == null;
  },

  /**
    Verifies that a value is either null or an empty string. Return false if
    the object is not a string.

    @param {Object} obj value to test
    @returns {Boolean}
  */
  empty: function (obj) {
    return obj === null || obj === undefined || obj === '';
  },

  /**
    Returns YES if the passed object is an array or Array-like.

    SproutCore Array Protocol:
    * the object has an objectAt property; or
    * the object is a native Array; or
    * the object is an Object, and has a length property

    Unlike SC.typeOf this method returns true even if the passed object is
    not formally array but appears to be array-like (i.e. has a length
    property, responds to .objectAt, etc.)

    @param {Object} obj the object to test
    @returns {Boolean}
  */
  isArray: function (obj) {
    if (!obj || obj.setInterval) { return false; }
    if (Array.isArray && Array.isArray(obj)) { return true; }
    if (obj.objectAt) { return true; }
    if (obj.length !== undefined && SC._nativeTypeOf(obj) === "object") { return true; }

    return false;
  },

  /**
    Makes an object into an Array if it is not array or array-like already.
    Unlike SC.A(), this method will not clone the object if it is already
    an array.

    @param {Object} obj object to convert
    @returns {Array} Actual array
  */
  makeArray: function (obj) {
    return SC.isArray(obj) ? obj : SC.A(obj);
  },

  /**
    Converts the passed object to an Array.  If the object appears to be
    array-like, a new array will be cloned from it.  Otherwise, a new array
    will be created with the item itself as the only item in the array.

    @param {Object} object any enumerable or array-like object.
    @returns {Array} Array of items
  */
  A: function (obj) {
    // null or undefined -- fast path
    if (obj === null || obj === undefined) return [];

    // primitive -- fast path
    if (obj.slice instanceof Function) {
      // do we have a string?
      if (typeof(obj) === 'string') return [obj];
      else return obj.slice();
    }

    // enumerable -- fast path
    if (obj.toArray) return obj.toArray();

    // if not array-like, then just wrap in array.
    if (!SC.isArray(obj)) return [obj];

    // when all else fails, do a manual convert...
    var ret = [], len = obj.length;
    while (--len >= 0) ret[len] = obj[len];
    return ret;
  },

  //
  // GUIDS & HASHES
  //

  // Like jQuery.expando but without any risk of conflict
  guidKey: "SproutCore" + (SC.VERSION + Math.random()).replace(/\D/g, ""),

  // Used for guid generation...
  _guidPrefixes: {"number": "nu", "string": "st"},
  _guidCaches:   {"number": {},   "string": {}},
  _numberGuids: [],
  _stringGuids: {},
  _keyCache: {},
  _uuid: 0,

  /**"
    Returns a unique GUID for the object.  If the object does not yet have
    a guid, one will be assigned to it.  You can call this on any object,
    SC.Object-based or not, but be aware that it will add a _guid property.

    You can also use this method on DOM Element objects.

    @param {Object} obj any object, string, number, Element, or primitive
    @returns {String} the unique guid for this instance.
  */
  guidFor: function (obj) {
    var cache, ret,
        type = typeof obj;

    // special cases where we don't want to add a key to object
    if (obj === undefined) return "(undefined)";
    if (obj === null) return "(null)";

    // Don't allow prototype changes to String etc. to change the guidFor
    if (type === SC.T_NUMBER || type === SC.T_STRING) {
      cache = this._guidCaches[type];
      ret   = cache[obj];
      if (!ret) {
        ret        = "st" + (SC._uuid++);
        cache[obj] = ret;
      }
      return ret;
    } else if (type === SC.T_BOOL) {
      return (obj) ? "(true)" : "(false)";
    }

    var guidKey = this.guidKey;
    if (obj[guidKey]) return obj[guidKey];

    // More special cases; not as common, so we check for them after the cache
    // lookup
    if (obj === Object) return '(Object)';
    if (obj === Array) return '(Array)';

    return SC.generateGuid(obj, "sc");
  },

  /**
    Returns a key name that combines the named key + prefix.  This is more
    efficient than simply combining strings because it uses a cache
    internally for performance.

    @param {String} prefix the prefix to attach to the key
    @param {String} key The key
    @returns {String} result
  */
  keyFor: function (prefix, key) {
    var ret, pcache = this._keyCache[prefix];
    if (!pcache) pcache = this._keyCache[prefix] = {}; // get cache for prefix
    ret = pcache[key];
    if (!ret) ret = pcache[key] = prefix + '_' + key;
    return ret;
  },

  /**
    Generates a new guid, optionally saving the guid to the object that you
    pass in.  You will rarely need to use this method.  Instead you should
    call SC.guidFor(obj), which return an existing guid if available.

    @param {Object} obj the object to assign the guid to
    @param {String} prefix prefixes the generated guid
    @returns {String} the guid
  */
  generateGuid: function (obj, prefix) {
    var ret = (prefix + (SC._uuid++));
    if (obj) obj[this.guidKey] = ret;
    return ret;
  },

  /**
    Returns a unique hash code for the object. If the object implements
    a hash() method, the value of that method will be returned. Otherwise,
    this will return the same value as guidFor().

    If you pass multiple arguments, hashFor returns a string obtained by
    concatenating the hash code of each argument.

    Unlike guidFor(), this method allows you to implement logic in your
    code to cause two separate instances of the same object to be treated as
    if they were equal for comparisons and other functions.

    <b>IMPORTANT</b>: If you implement a hash() method, it MUST NOT return a
    number or a string that contains only a number. Typically hash codes
    are strings that begin with a "%".

    @param {Object...} objects the object(s)
    @returns {String} the hash code for this instance.
  */
  hashFor: function () {
    var l = arguments.length,
      h = '',
      obj, f, i;

    for (i = 0; i < l; ++i) {
      obj = arguments[i];
      h += (obj && (f = obj.hash) && (typeof f === SC.T_FUNCTION)) ? f.call(obj) : this.guidFor(obj);
    }

    return h === '' ? null : h;
  },

  /**
    This will compare the two object values using their hash codes.

    @param {Object} a first value to compare
    @param {Object} b the second value to compare
    @returns {Boolean} YES if the two have equal hash code values.

  */
  isEqual: function (a, b) {
    // QUESTION: is there a compelling performance reason to special-case
    // undefined here?
    return this.hashFor(a) === this.hashFor(b);
  },

  /**
   This will compare two javascript values of possibly different types.
   It will tell you which one is greater than the other by returning
   -1 if the first is smaller than the second,
    0 if both are equal,
    1 if the first is greater than the second.

   The order is calculated based on SC.ORDER_DEFINITION , if types are different.
   In case they have the same type an appropriate comparison for this type is made.

   @param {Object} v first value to compare
   @param {Object} w the second value to compare
   @returns {NUMBER} -1 if v < w, 0 if v = w and 1 if v > w.

  */
  compare: function (v, w) {
    // Doing a '===' check is very cheap, so in the case of equality, checking
    // this up-front is a big win.
    if (v === w) return 0;

    var type1 = SC.typeOf(v);
    var type2 = SC.typeOf(w);

    // If we haven't yet generated a reverse-mapping of SC.ORDER_DEFINITION,
    // do so now.
    var mapping = SC.ORDER_DEFINITION_MAPPING;
    if (!mapping) {
      var order = SC.ORDER_DEFINITION;
      mapping = SC.ORDER_DEFINITION_MAPPING = {};
      var idx, len;
      for (idx = 0, len = order.length;  idx < len;  ++idx) {
        mapping[order[idx]] = idx;
      }

      // We no longer need SC.ORDER_DEFINITION.
      delete SC.ORDER_DEFINITION;
    }

    var type1Index = mapping[type1];
    var type2Index = mapping[type2];

    if (type1Index < type2Index) return -1;
    if (type1Index > type2Index) return 1;

    // ok - types are equal - so we have to check values now
    switch (type1) {
    case SC.T_BOOL:
    case SC.T_NUMBER:
      if (v < w) return -1;
      if (v > w) return 1;
      return 0;

    case SC.T_STRING:
      var comp = v.localeCompare(w);
      if (comp < 0) return -1;
      if (comp > 0) return 1;
      return 0;

    case SC.T_ARRAY:
      var vLen = v.length;
      var wLen = w.length;
      var l = Math.min(vLen, wLen);
      var r = 0;
      var i = 0;
      var thisFunc = arguments.callee;
      while (r === 0 && i < l) {
        r = thisFunc(v[i], w[i]);
        i++;
      }
      if (r !== 0) return r;

      // all elements are equal now
      // shorter array should be ordered first
      if (vLen < wLen) return -1;
      if (vLen > wLen) return 1;
      // arrays are equal now
      return 0;

    case SC.T_OBJECT:
      if (v.constructor.isComparable === YES) return v.constructor.compare(v, w);
      return 0;

    default:
      return 0;
    }
  },

  // ..........................................................
  // OBJECT MANAGEMENT
  //

  /**
    Empty function.  Useful for some operations.

    @returns {Object}
  */
  K: function () { return this; },

  /**
    Empty array.  Useful for some optimizations.

    @type Array
  */
  EMPTY_ARRAY: [],

  /**
    Empty hash.  Useful for some optimizations.

    @type Hash
  */
  EMPTY_HASH: {},

  /**
    Empty range. Useful for some optimizations.

    @type Range
  */
  EMPTY_RANGE: {start: 0, length: 0},

  /**
    Creates a new object with the passed object as its prototype.

    This method uses JavaScript's native inheritance method to create a new
    object.

    You cannot use beget() to create new SC.Object-based objects, but you
    can use it to beget Arrays, Hashes, Sets and objects you build yourself.
    Note that when you beget() a new object, this method will also call the
    didBeget() method on the object you passed in if it is defined.  You can
    use this method to perform any other setup needed.

    In general, you will not use beget() often as SC.Object is much more
    useful, but for certain rare algorithms, this method can be very useful.

    For more information on using beget(), see the section on beget() in
    Crockford's JavaScript: The Good Parts.

    @param {Object} obj the object to beget
    @returns {Object} the new object.
  */
  beget: function (obj) {
    if (obj === null || obj === undefined) return null;
    var K = SC.K;
    K.prototype = obj;
    var ret = new K();
    K.prototype = null; // avoid leaks
    if (typeof obj.didBeget === "function") ret = obj.didBeget(ret);
    return ret;
  },

  /**
    Creates a clone of the passed object.  This function can take just about
    any type of object and create a clone of it, including primitive values
    (which are not actually cloned because they are immutable).

    If the passed object implements the clone() method, then this function
    will simply call that method and return the result.

    @param {Object} object the object to clone
    @param {Boolean} deep if true, a deep copy of the object is made
    @returns {Object} the cloned object
  */
  copy: function (object, deep) {
    var ret = object, idx;

    // fast paths
    if (object) {
      if (object.isCopyable) return object.copy(deep);
      if (object.clone)      return object.clone();
    }

    switch (SC._nativeTypeOf(object)) {
    case "array":
      ret = object.slice();

      if (deep) {
        idx = ret.length;
        while (idx--) { ret[idx] = SC.copy(ret[idx], true); }
      }
      break;

    case "object":
      ret = {};
      for (var key in object) { ret[key] = deep ? SC.copy(object[key], true) : object[key]; }
    }

    return ret;
  },

  /**
    Returns a new object combining the values of all passed hashes.

    @param {Object...} object one or more objects
    @returns {Object} new Object
  */
  merge: function () {
    var ret = {}, len = arguments.length, idx;
    for (idx = 0; idx < len; idx++) SC.mixin(ret, arguments[idx]);
    return ret;
  },

  /**
    Returns all of the keys defined on an object or hash.  This is useful
    when inspecting objects for debugging.

    @param {Object} obj The Object
    @returns {Array} array of keys
  */
  keys: function (obj) {
    var ret = [];
    for (var key in obj) ret.push(key);
    return ret;
  },

  /**
    Convenience method to inspect an object.  This method will attempt to
    convert the object into a useful string description.

    @param {Object} obj The object you want to inspect.

    @returns {String} A description of the object
  */
  inspect: function (obj) {
    var v, ret = [];
    for (var key in obj) {
      v = obj[key];
      if (v === 'toString') continue; // ignore useless items
      if (SC.typeOf(v) === SC.T_FUNCTION) v = "function () { ... }";
      ret.push(key + ": " + v);
    }
    return "{ " + ret.join(", ") + " }";
  },

  /**
    Returns a tuple containing the object and key for the specified property
    path.  If no object could be found to match the property path, then
    returns null.

    This is the standard method used throughout SproutCore to resolve property
    paths.

    @param {String} path the property path
    @param {Object} root optional parameter specifying the place to start
    @returns {Array} array with [object, property] if found or null
  */
  tupleForPropertyPath: function (path, root) {
    /* jshint eqnull:true */
    // if passed nothing, return nothing.
    if (path == null) return null;

    // if the passed path is itself a tuple, return it
    if (typeof path === "object" && (path instanceof Array)) return path;

    // find the key.  It is the last . or first *
    var key;
    var stopAt = path.indexOf('*');
    if (stopAt < 0) stopAt = path.lastIndexOf('.');
    key = (stopAt >= 0) ? path.slice(stopAt + 1) : path;

    // convert path to object.
    var obj = this.objectForPropertyPath(path, root, stopAt);
    return (obj && key) ? [obj, key] : null;
  },

  /**
    Finds the object for the passed path or array of path components.  This is
    the standard method used in SproutCore to traverse object paths.

    @param {String} path the path
    @param {Object} root optional root object.  window is used otherwise
    @param {Integer} stopAt optional point to stop searching the path.
    @returns {Object} the found object or undefined.
  */
  objectForPropertyPath: function (path, root, stopAt) {

    var loc, nextDotAt, key, max;

    if (!root) root = window;

    // faster method for strings
    if (typeof path === "string") {
      if (stopAt === undefined) stopAt = path.length;
      loc = 0;
      while ((root) && (loc < stopAt)) {
        nextDotAt = path.indexOf('.', loc);
        if ((nextDotAt < 0) || (nextDotAt > stopAt)) nextDotAt = stopAt;
        key = path.slice(loc, nextDotAt);
        root = root.get ? root.get(key) : root[key];
        loc = nextDotAt + 1;
      }
      if (loc < stopAt) root = undefined; // hit a dead end. :(

    // older method using an array
    } else {
      loc = 0;
      max = path.length;
      key = null;

      while ((loc < max) && root) {
        key = path[loc++];
        if (key) root = (root.get) ? root.get(key) : root[key];
      }
      if (loc < max) root = undefined;
    }

    return root;
  },

  /**
   Acts very similar to SC.objectForPropertyPath(), the only difference is
   that it will throw an error when object can't be found.

    @param {String} path the path
    @param {Object} root optional root object.  window is used otherwise
    @param {Integer} stopAt optional point to stop searching the path.
    @returns {Object} the found object or throws an error.
  */
  requiredObjectForPropertyPath: function (path, root, stopAt) {
    var o = SC.objectForPropertyPath(path, root, stopAt);
    if (!o) {
      throw path + " could not be found";
    }
    return o;
  }

}); // end mixin

/** @private Alias for SC.clone() */
SC.clone = SC.copy;

/** @private Alias for SC.A() */
SC.$A = SC.A;

/** @private Provided for compatibility with old HTML templates. */
SC.didLoad = SC.K;

/** @private Used by SC.compare */
SC.ORDER_DEFINITION = [ SC.T_ERROR,
                        SC.T_UNDEFINED,
                        SC.T_NULL,
                        SC.T_BOOL,
                        SC.T_NUMBER,
                        SC.T_STRING,
                        SC.T_ARRAY,
                        SC.T_HASH,
                        SC.T_OBJECT,
                        SC.T_FUNCTION,
                        SC.T_CLASS ];

/* >>>>>>>>>> BEGIN source/system/function.js */
// ==========================================================================
// Project:   SproutCore Costello - Property Observing Library
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @class
*/
SC.Function = /** @scope SC.Function.prototype */{

  /**
    @see Function.prototype.property
  */
  property: function (fn, keys) {
    fn.dependentKeys = SC.$A(keys);
    var guid = SC.guidFor(fn);
    fn.cacheKey = "__cache__" + guid;
    fn.lastSetValueKey = "__lastValue__" + guid;
    fn.isProperty = true;
    return fn;
  },

  /**
    @see Function.prototype.cacheable
  */
  cacheable: function (fn, aFlag) {
    fn.isProperty = true;  // also make a property just in case
    if (!fn.dependentKeys) fn.dependentKeys = [];
    fn.isCacheable = (aFlag === undefined) ? true : aFlag;
    return fn;
  },

  /**
    @see Function.prototype.idempotent
  */
  idempotent: function (fn, aFlag) {
    fn.isProperty = true;  // also make a property just in case
    if (!fn.dependentKeys) this.dependentKeys = [];
    fn.isVolatile = (aFlag === undefined) ? true : aFlag;
    return fn;
  },

  /**
    @see Function.prototype.enhance
  */
  enhance: function (fn) {
    fn.isEnhancement = true;
    return fn;
  },

  /**
    @see Function.prototype.observes
  */
  observes: function (fn, propertyPaths) {
    // sort property paths into local paths (i.e just a property name) and
    // full paths (i.e. those with a . or * in them)
    var loc = propertyPaths.length, local = null, paths = null;
    while (--loc >= 0) {
      var path = propertyPaths[loc];
      // local
      if ((path.indexOf('.') < 0) && (path.indexOf('*') < 0)) {
        if (!local) local = fn.localPropertyPaths = [];
        local.push(path);

      // regular
      } else {
        if (!paths) paths = fn.propertyPaths = [];
        paths.push(path);
      }
    }
    return fn;
  }

};

/* >>>>>>>>>> BEGIN source/ext/function.js */
// ==========================================================================
// Project:   SproutCore Costello - Property Observing Library
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('system/function');

SC.mixin(Function.prototype,
/** @lends Function.prototype */ {

  /**
    Indicates that the function should be treated as a computed property.

    Computed properties are methods that you want to treat as if they were
    static properties.  When you use get() or set() on a computed property,
    the object will call the property method and return its value instead of
    returning the method itself.  This makes it easy to create "virtual
    properties" that are computed dynamically from other properties.

    Consider the following example:

          contact = SC.Object.create({

            firstName: "Charles",
            lastName: "Jolley",

            // This is a computed property!
            fullName: function() {
              return this.getEach('firstName','lastName').compact().join(' ') ;
            }.property('firstName', 'lastName'),

            // this is not
            getFullName: function() {
              return this.getEach('firstName','lastName').compact().join(' ') ;
            }
          });

          contact.get('firstName') ;
          --> "Charles"

          contact.get('fullName') ;
          --> "Charles Jolley"

          contact.get('getFullName') ;
          --> function()

    Note that when you get the fullName property, SproutCore will call the
    fullName() function and return its value whereas when you get() a property
    that contains a regular method (such as getFullName above), then the
    function itself will be returned instead.

    Using Dependent Keys
    ----

    Computed properties are often computed dynamically from other member
    properties.  Whenever those properties change, you need to notify any
    object that is observing the computed property that the computed property
    has changed also.  We call these properties the computed property is based
    upon "dependent keys".

    For example, in the contact object above, the fullName property depends on
    the firstName and lastName property.  If either property value changes,
    any observer watching the fullName property will need to be notified as
    well.

    You inform SproutCore of these dependent keys by passing the key names
    as parameters to the property() function.  Whenever the value of any key
    you name here changes, the computed property will be marked as changed
    also.

    You should always register dependent keys for computed properties to
    ensure they update.

    Sometimes you may need to depend on keys that are several objects deep. In
    that case, you can provide a path to property():

        capitalizedName: function() {
          return this.getPath('person.fullName').toUpper();
        }.property('person.fullName')

    This will cause observers of +capitalizedName+ to be fired when either
    +fullName+ _or_ +person+ changes.

    Using Computed Properties as Setters
    ---

    Computed properties can be used to modify the state of an object as well
    as to return a value.  Unlike many other key-value system, you use the
    same method to both get and set values on a computed property.  To
    write a setter, simply declare two extra parameters: key and value.

    Whenever your property function is called as a setter, the value
    parameter will be set.  Whenever your property is called as a getter the
    value parameter will be undefined.

    For example, the following object will split any full name that you set
    into a first name and last name components and save them.

          contact = SC.Object.create({

            fullName: function(key, value) {
              if (value !== undefined) {
                var parts = value.split(' ') ;
                this.beginPropertyChanges()
                  .set('firstName', parts[0])
                  .set('lastName', parts[1])
                .endPropertyChanges() ;
              }
              return this.getEach('firstName', 'lastName').compact().join(' ');
            }.property('firstName','lastName')

          }) ;

    Why Use The Same Method for Getters and Setters?
    ---

    Most property-based frameworks expect you to write two methods for each
    property but SproutCore only uses one. We do this because most of the time
    when you write a setter is is basically a getter plus some extra work.
    There is little added benefit in writing both methods when you can
    conditionally exclude part of it. This helps to keep your code more
    compact and easier to maintain.

    @param {String...} dependentKeys optional set of dependent keys
    @returns {Function} the declared function instance
  */
  property: function() {
    return SC.Function.property(this, arguments);
  },

  /**
    You can call this method on a computed property to indicate that the
    property is cacheable (or not cacheable).  By default all computed
    properties are not cached.  Enabling this feature will allow SproutCore
    to cache the return value of your computed property and to use that
    value until one of your dependent properties changes or until you
    invoke propertyDidChange() and name the computed property itself.

    If you do not specify this option, computed properties are assumed to be
    not cacheable.

    @param {Boolean} aFlag optionally indicate cacheable or no, default YES
    @returns {Function} receiver, useful for chaining calls.
  */
  cacheable: function(aFlag) {
    return SC.Function.cacheable(this, aFlag);
  },

  /**
    Indicates that the computed property is volatile.  Normally SproutCore
    assumes that your computed property is idempotent.  That is, calling
    set() on your property more than once with the same value has the same
    effect as calling it only once.

    All non-computed properties are idempotent and normally you should make
    your computed properties behave the same way.  However, if you need to
    make your property change its return value every time your method is
    called, you may chain this to your property to make it volatile.

    If you do not specify this option, properties are assumed to be
    non-volatile.

    @param {Boolean} aFlag optionally indicate state, default to YES
    @returns {Function} receiver, useful for chaining calls.
  */
  idempotent: function(aFlag) {
    return SC.Function.idempotent(this, aFlag);
  },

  enhance: function() {
    return SC.Function.enhance(this);
  },

  /**
    Declare that a function should observe an object or property at the named
    path.  Note that the path is used only to construct the observation one time.

    @param {String...} propertyPaths A list of strings which indicate the
      properties being observed

    @returns {Function} receiver, useful for chaining calls.
  */
  observes: function(propertyPaths) {
    return SC.Function.observes(this, arguments);
  }

});

/* >>>>>>>>>> BEGIN source/private/observer_set.js */
// ==========================================================================
// Project:   SproutCore Costello - Property Observing Library
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

// ........................................................................
// ObserverSet
//

/**
  @namespace

  This private class is used to store information about observers on a
  particular key.  Note that this object is not observable.  You create new
  instances by calling SC.beget(SC.ObserverSet) ;

  @private
  @since SproutCore 1.0
*/
SC.ObserverSet = {

  /**
    Adds the named target/method observer to the set.  The method must be
    a function, not a string.
  */
  add: function(target, method, context) {
    var targetGuid = SC.guidFor(target),
        methodGuid = SC.guidFor(method),
        targets    = this._members,
        members    = this.members,
        indexes    = targets[targetGuid],       // get the set of methods
        index, member;

    if ( !indexes ) indexes = targets[targetGuid] = { _size: 0 };

    index = indexes[methodGuid];
    if (index === undefined) {
      indexes[methodGuid] = members.length;
      // Increase the size of the indexes for this target so that it can be cleaned up.
      indexes._size++;
      member = [target, method, context];

      


      members.push(member);
    }
    else {
      

    }
  },

  /**
    removes the named target/method observer from the set.  If this is the
    last method for the named target, then the number of targets will also
    be reduced.

    returns YES if the items was removed, NO if it was not found.
  */
  remove: function(target, method) {
    var targetGuid = SC.guidFor(target), methodGuid = SC.guidFor(method);
    var indexes = this._members[targetGuid], members = this.members;

    if( !indexes ) return false;

    var index = indexes[methodGuid];
    if ( index === undefined) return false;

    if (index !== members.length - 1) {
      var entry = (members[index] = members[members.length - 1]);
      this._members[SC.guidFor(entry[0])][SC.guidFor(entry[1])] = index;
    }

    // Throw away the last member (it has been moved or is the member we are removing).
    members.pop();

    // Remove the method tracked for the target.
    delete this._members[targetGuid][methodGuid];

    // If there are no more methods tracked on the target, remove the target.
    if (--this._members[targetGuid]._size === 0) {
      delete this._members[targetGuid];
    }

    return true;
  },

  /**
    Invokes the target/method pairs in the receiver.  Used by SC.RunLoop
    Note: does not support context
  */
  invokeMethods: function() {
    var members = this.members, member;

    


    for( var i=0, l=members.length; i<l; i++ ) {
      member = members[i];

      // Call the method (member[1]) on the target (member[0]) with the context (member[2])
      member[1].call(member[0], member[2]);

      

    }
  },

  /**
    Returns a new instance of the set with the contents cloned.
  */
  clone: function() {
    var newSet = SC.ObserverSet.create(), memberArray = this.members;

    newSet._members = SC.clone(this._members);
    var newMembers = newSet.members;

    for( var i=0, l=memberArray.length; i<l; i++ ) {
      newMembers[i] = SC.clone(memberArray[i]);
      newMembers[i].length = 3;
      

    }

    return newSet;
  },

  /**
    Creates a new instance of the observer set.
  */
  create: function() {
    return new SC.ObserverSet.constructor();
  },

  getMembers: function() {
    return this.members.slice(0);
  },

  constructor: function() {
    this._members = {};
    this.members = [];
  }

} ;

SC.ObserverSet.constructor.prototype = SC.ObserverSet;
SC.ObserverSet.slice = SC.ObserverSet.clone;
SC.ObserverSet.copy = SC.ObserverSet.clone;


/* >>>>>>>>>> BEGIN source/private/chain_observer.js */
// ==========================================================================
// Project:   SproutCore Costello - Property Observing Library
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

// ........................................................................
// CHAIN OBSERVER
//

// This is a private class used by the observable mixin to support chained
// properties.

// ChainObservers are used to automatically monitor a property several
// layers deep.
// org.plan.name = SC._ChainObserver.create({
//    target: this, property: 'org',
//    next: SC._ChainObserver.create({
//      property: 'plan',
//      next: SC._ChainObserver.create({
//        property: 'name', func: myFunc
//      })
//    })
//  })
//
SC._ChainObserver = function (property, root) {
  this.property = property;
  this.root = root || this;
};

/** @private
  This is the primary entry point.  Configures the chain.

  @param {String} path The property path for the chain.  Ex. 'propA.propB.propC.@each.propD'
  */
SC._ChainObserver.createChain = function (rootObject, path, target, method, context) {
  // First we create the chain.
  var parts = path.split('.'), // ex. ['propA', 'propB', '@each', 'propC']
      root  = new SC._ChainObserver(parts[0]), // ex. _ChainObserver({ property: 'propA' })
      tail  = root;

  for (var i = 1, len = parts.length; i < len; i++) {
    tail = tail.next = new SC._ChainObserver(parts[i], root);
  }

  var tails = root.tails = [tail]; // ex. [_ChainObserver({ property: 'propC' })]

  // Now root has the first observer and tail has the last one.
  // Feed the rootObject into the front to setup the chain...
  // do this BEFORE we set the target/method so they will not be triggered.
  root.objectDidChange(rootObject);

  tails.forEach(function (tail) {
    // Finally, set the target/method on the tail so that future changes will trigger.
    tail.target = target;
    tail.method = method;
    tail.context = context;
  });

  // no need to hold onto references to the tails; if the underlying
  // objects go away, let them get garbage collected
  root.tails = null;

  // and return the root to save
  return root;
};

SC._ChainObserver.prototype = {
  isChainObserver: true,

  // the object this instance is observing
  object: null,

  // the property on the object this link is observing.
  property: null,

  // if not null, this is the next link in the chain.  Whenever the
  // current property changes, the next observer will be notified.
  next: null,

  root: null,

  // if not null, this is the final target observer.
  target: null,

  // if not null, this is the final target method
  method: null,

  // an accessor method that traverses the list and finds the tail
  tail: function () {
    if (this._tail) { return this._tail; }

    var tail = this;

    while (tail.next) {
      tail = tail.next;
    }

    this._tail = tail;
    return tail;
  },

  // invoked when the source object changes.  removes observer on old
  // object, sets up new observer, if needed.
  objectDidChange: function (newObject) {
    if (newObject === this.object) return; // nothing to do.

    // if an old object, remove observer on it.
    if (this.object) {
      if (this.property === '@each' && this.object._removeContentObserver) {
        this.object._removeContentObserver(this);
      } else if (this.object.removeObserver) {
        this.object.removeObserver(this.property, this, this.propertyDidChange);
      }
    }

    // if a new object, add observer on it...
    this.object = newObject;

    // when [].propName is used, we will want to set up observers on each item
    // added to the Enumerable, and remove them when the item is removed from
    // the Enumerable.
    //
    // In this case, we invoke addEnumerableObserver, which handles setting up
    // and tearing down observers as items are added and removed from the
    // Enumerable.
    if (this.property === '@each' && this.next) {
      if (this.object && this.object._addContentObserver) {
        this.object._addContentObserver(this);
      }
    } else {
      if (this.object && this.object.addObserver) {
        this.object.addObserver(this.property, this, this.propertyDidChange);
      }

      // now, notify myself that my property value has probably changed.
      this.propertyDidChange();
    }
  },

  // the observer method invoked when the observed property changes.
  propertyDidChange: function () {
    // get the new value
    var object = this.object;
    var property = this.property;
    var value = (object && object.get) ? object.get(property) : null;

    // if we have a next object in the chain, notify it that its object
    // did change...
    if (this.next) { this.next.objectDidChange(value); }

    // if we have a target/method, call it.
    var target  = this.target,
        method  = this.method,
        context = this.context;

    if (target && method) {
      var rev = object ? object.propertyRevision : null;
      if (context) {
        method.call(target, object, property, value, context, rev);
      } else {
        method.call(target, object, property, value, rev);
      }
    }
  },

  // teardown the chain...
  destroyChain: function () {

    // remove observer
    var obj = this.object;
    if (obj) {
      if (this.property === '@each' && this.next && obj._removeContentObserver) {
        obj._removeContentObserver(this);
      }

      if (obj.removeObserver) {
        obj.removeObserver(this.property, this, this.propertyDidChange);
      }
    }

    // destroy next item in chain
    if (this.next) this.next.destroyChain();

    // and clear left overs...
    this.next = this.target = this.method = this.object = this.context = null;
    return null;
  }

};

/* >>>>>>>>>> BEGIN source/mixins/observable.js */
// ==========================================================================
// Project:   SproutCore Costello - Property Observing Library
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('ext/function');
sc_require('private/observer_set');
sc_require('private/chain_observer');




SC.OBSERVES_HANDLER_ADD = 0;
SC.OBSERVES_HANDLER_REMOVE = 1;

/**
  @class

  Key-Value-Observing (KVO) simply allows one object to observe changes to a
  property on another object. It is one of the fundamental ways that models,
  controllers and views communicate with each other in a SproutCore
  application.  Any object that has this module applied to it can be used in
  KVO-operations.

  This module is applied automatically to all objects that inherit from
  SC.Object, which includes most objects bundled with the SproutCore
  framework.  You will not generally apply this module to classes yourself,
  but you will use the features provided by this module frequently, so it is
  important to understand how to use it.

  Enabling Key Value Observing
  ---

  With KVO, you can write functions that will be called automatically whenever
  a property on a particular object changes.  You can use this feature to
  reduce the amount of "glue code" that you often write to tie the various
  parts of your application together.

  To use KVO, just use the KVO-aware methods get() and set() to access
  properties instead of accessing properties directly.  Instead of writing:

        var aName = contact.firstName;
        contact.firstName = 'Charles';

  use:

        var aName = contact.get('firstName');
        contact.set('firstName', 'Charles');

  get() and set() work just like the normal "dot operators" provided by
  JavaScript but they provide you with much more power, including not only
  observing but computed properties as well.

  Observing Property Changes
  ---

  You typically observe property changes simply by adding the observes()
  call to the end of your method declarations in classes that you write.  For
  example:

        SC.Object.create({
          valueObserver: function () {
            // Executes whenever the "Value" property changes
          }.observes('value')
        });

  Although this is the most common way to add an observer, this capability is
  actually built into the SC.Object class on top of two methods defined in
  this mixin called addObserver() and removeObserver().  You can use these two
  methods to add and remove observers yourself if you need to do so at run
  time.

  To add an observer for a property, just call:

        object.addObserver('propertyKey', targetObject, targetAction);

  This will call the 'targetAction' method on the targetObject to be called
  whenever the value of the propertyKey changes.

  Observer Parameters
  ---

  An observer function typically does not need to accept any parameters,
  however you can accept certain arguments when writing generic observers.
  An observer function can have the following arguments:

        propertyObserver(target, key, value, revision);

  - *target* - This is the object whose value changed.  Usually this.
  - *key* - The key of the value that changed
  - *value* - this property is no longer used.  It will always be null
  - *revision* - this is the revision of the target object

  Implementing Manual Change Notifications
  ---

  Sometimes you may want to control the rate at which notifications for
  a property are delivered, for example by checking first to make sure
  that the value has changed.

  To do this, you need to implement a computed property for the property
  you want to change and override automaticallyNotifiesObserversFor().

  The example below will only notify if the "balance" property value actually
  changes:


        automaticallyNotifiesObserversFor: function (key) {
          return (key === 'balance') ? NO : arguments.callee.base.apply(this,arguments);
        },

        balance: function (key, value) {
          var balance = this._balance;
          if ((value !== undefined) && (balance !== value)) {
            this.propertyWillChange(key);
            balance = this._balance = value;
            this.propertyDidChange(key);
          }
          return balance;
        }


  Implementation Details
  ---

  Internally, SproutCore keeps track of observable information by adding a
  number of properties to the object adopting the observable.  All of these
  properties begin with "_kvo_" to separate them from the rest of your object.

  @since SproutCore 1.0
*/
SC.Observable = /** @scope SC.Observable.prototype */ {

  


  /** @private Property cache. */
  _kvo_cache: null,

  /** @private Whether properties of the object will be cacheable. Becomes true if any one computed property is .cacheable() */
  _kvo_cacheable: false,

  /** @private Cache of dependepents for a property. */
  _kvo_cachedep: null,

  /** @private */
  _kvo_changeLevel: 0,

  /** @private */
  _kvo_changes: null,

  /** @private */
  _kvo_cloned: null,

  /** @private */
  _kvo_revision: 0,

  /** @private */
  _observableInited: false,

  /**
    Walk like that ol' duck

    @type Boolean
  */
  isObservable: YES,

  /**
    Determines whether observers should be automatically notified of changes
    to a key.

    If you are manually implementing change notifications for a property, you
    can override this method to return NO for properties you do not want the
    observing system to automatically notify for.

    The default implementation always returns YES.

    @param {String} key the key that is changing
    @returns {Boolean} YES if automatic notification should occur.
  */
  automaticallyNotifiesObserversFor: function (key) {
    return YES;
  },

  // ..........................................
  // PROPERTIES
  //
  // Use these methods to get/set properties.  This will handle observing
  // notifications as well as allowing you to define functions that can be
  // used as properties.

  /**
    Retrieves the value of key from the object.

    This method is generally very similar to using object[key] or object.key,
    however it supports both computed properties and the unknownProperty
    handler.

    Computed Properties
    ---

    Computed properties are methods defined with the property() modifier
    declared at the end, such as:

          fullName: function () {
            return this.getEach('firstName', 'lastName').compact().join(' ');
          }.property('firstName', 'lastName')

    When you call get() on a computed property, the property function will be
    called and the return value will be returned instead of the function
    itself.

    Unknown Properties
    ---

    Likewise, if you try to call get() on a property whose values is
    undefined, the unknownProperty() method will be called on the object.
    If this method returns any value other than undefined, it will be returned
    instead.  This allows you to implement "virtual" properties that are
    not defined upfront.

    @param {String} key the property to retrieve
    @returns {Object} the property value or undefined.

  */
  get: function (key) {
    var ret = this[key], cache;
    if (ret === undefined) {
      return this.unknownProperty(key);
    } else if (ret && ret.isProperty) {
      if (ret.isCacheable) {
        cache = this._kvo_cache;
        if (!cache) cache = this._kvo_cache = {};

        return (cache[ret.cacheKey] !== undefined) ? cache[ret.cacheKey] : (cache[ret.cacheKey] = ret.call(this, key));
      } else return ret.call(this, key);
    } else return ret;
  },

  /**
    Sets the key equal to value.

    This method is generally very similar to calling object[key] = value or
    object.key = value, except that it provides support for computed
    properties, the unknownProperty() method and property observers.

    Computed Properties
    ---

    If you try to set a value on a key that has a computed property handler
    defined (see the get() method for an example), then set() will call
    that method, passing both the value and key instead of simply changing
    the value itself.  This is useful for those times when you need to
    implement a property that is composed of one or more member
    properties.

    Unknown Properties
    ---

    If you try to set a value on a key that is undefined in the target
    object, then the unknownProperty() handler will be called instead.  This
    gives you an opportunity to implement complex "virtual" properties that
    are not predefined on the object.  If unknownProperty() returns
    undefined, then set() will simply set the value on the object.

    Property Observers
    ---

    In addition to changing the property, set() will also register a
    property change with the object.  Unless you have placed this call
    inside of a beginPropertyChanges() and endPropertyChanges(), any "local"
    observers (i.e. observer methods declared on the same object), will be
    called immediately.  Any "remote" observers (i.e. observer methods
    declared on another object) will be placed in a queue and called at a
    later time in a coalesced manner.

    Chaining
    ---

    In addition to property changes, set() returns the value of the object
    itself so you can do chaining like this:

          record.set('firstName', 'Charles').set('lastName', 'Jolley');

    @param {String|Hash} key the property to set
    @param {Object} value the value to set or null.
    @returns {SC.Observable}
  */
  set: function (key, value) {
    var func   = this[key],
        notify = this.automaticallyNotifiesObserversFor(key),
        ret    = value,
        cachedep, cache, idx, dfunc;

    if (value === undefined && SC.typeOf(key) === SC.T_HASH) {
      var hash = key;

      for (var hashKey in hash) {
        if (!hash.hasOwnProperty(hashKey)) continue;
        this.set(hashKey, hash[hashKey]);
      }

      return this;
    }

    // if there are any dependent keys and they use caching, then clear the
    // cache.  (If we're notifying, then propertyDidChange will do this for
    // us.)
    if (!notify && this._kvo_cacheable && (cache = this._kvo_cache)) {
      // lookup the cached dependents for this key.  if undefined, compute.
      // note that if cachdep is set to null is means we figure out it has no
      // cached dependencies already.  this is different from undefined.
      cachedep = this._kvo_cachedep;
      if (!cachedep || (cachedep = cachedep[key]) === undefined) {
        cachedep = this._kvo_computeCachedDependentsFor(key);
      }

      if (cachedep) {
        idx = cachedep.length;
        while (--idx >= 0) {
          dfunc = cachedep[idx];
          cache[dfunc.cacheKey] = cache[dfunc.lastSetValueKey] = undefined;
        }
      }
    }

    // set the value.
    if (func && func.isProperty) {
      cache = this._kvo_cache;
      if (func.isVolatile || !cache || (cache[func.lastSetValueKey] !== value)) {
        if (!cache) cache = this._kvo_cache = {};

        cache[func.lastSetValueKey] = value;
        if (notify) this.propertyWillChange(key);
        ret = func.call(this, key, value);

        // update cached value
        if (func.isCacheable) cache[func.cacheKey] = ret;
        if (notify) this.propertyDidChange(key, ret, YES);
      }

    } else if (func === undefined) {
      if (notify) this.propertyWillChange(key);
      this.unknownProperty(key, value);
      if (notify) this.propertyDidChange(key, ret);

    } else {
      if (this[key] !== value) {
        if (notify) this.propertyWillChange(key);
        ret = this[key] = value;
        if (notify) this.propertyDidChange(key, ret);
      }
    }

    return this;
  },

  /**
    Called whenever you try to get or set an undefined property.

    This is a generic property handler.  If you define it, it will be called
    when the named property is not yet set in the object.  The default does
    nothing.

    @param {String} key the key that was requested
    @param {Object} value The value if called as a setter, undefined if called as a getter.
    @returns {Object} The new value for key.
  */
  unknownProperty: function (key, value) {
    if (value !== undefined) { this[key] = value; }
    return value;
  },

  /**
    Begins a grouping of property changes.

    You can use this method to group property changes so that notifications
    will not be sent until the changes are finished.  If you plan to make a
    large number of changes to an object at one time, you should call this
    method at the beginning of the changes to suspend change notifications.
    When you are done making changes, call endPropertyChanges() to allow
    notification to resume.

    @returns {SC.Observable}
  */
  beginPropertyChanges: function () {
    this._kvo_changeLevel = this._kvo_changeLevel + 1;
    return this;
  },

  /**
    Ends a grouping of property changes.

    You can use this method to group property changes so that notifications
    will not be sent until the changes are finished.  If you plan to make a
    large number of changes to an object at one time, you should call
    beginPropertyChanges() at the beginning of the changes to suspend change
    notifications. When you are done making changes, call this method to allow
    notification to resume.

    @returns {SC.Observable}
  */
  endPropertyChanges: function () {
    this._kvo_changeLevel = (this._kvo_changeLevel || 1) - 1;
    var level = this._kvo_changeLevel, changes = this._kvo_changes;
    if ((level <= 0) && changes && (changes.length > 0) && !SC.Observers.isObservingSuspended) {
      this._notifyPropertyObservers();
    }
    return this;
  },

  /**
    Notify the observer system that a property is about to change.

    Sometimes you need to change a value directly or indirectly without
    actually calling get() or set() on it.  In this case, you can use this
    method and propertyDidChange() instead.  Calling these two methods
    together will notify all observers that the property has potentially
    changed value.

    Note that you must always call propertyWillChange and propertyDidChange as
    a pair.  If you do not, it may get the property change groups out of order
    and cause notifications to be delivered more often than you would like.

    @param {String} key The property key that is about to change.
    @returns {SC.Observable}
  */
  propertyWillChange: function (key) {
    return this;
  },

  /**
    Notify the observer system that a property has just changed.

    Sometimes you need to change a value directly or indirectly without
    actually calling get() or set() on it.  In this case, you can use this
    method and propertyWillChange() instead.  Calling these two methods
    together will notify all observers that the property has potentially
    changed value.

    Note that you must always call propertyWillChange and propertyDidChange as
    a pair. If you do not, it may get the property change groups out of order
    and cause notifications to be delivered more often than you would like.

    @param {String} key The property key that has just changed.
    @param {Object} value The new value of the key.  May be null.
    @param {Boolean} _keepCache Private property
    @returns {SC.Observable}
  */
  propertyDidChange: function (key, value, _keepCache) {
    this._kvo_revision = this._kvo_revision + 1;
    var level = this._kvo_changeLevel,
        cachedep, idx, dfunc, func;

    


    // If any dependent keys contain this property in their path,
    // invalidate the cache of the computed property and re-setup chain with
    // new value.
    var chains = this._kvo_property_chains;
    if (chains) {
      var keyChains = chains[key];

      if (keyChains) {
        this.beginPropertyChanges();
        keyChains = SC.clone(keyChains);
        keyChains.forEach(function (chain) {
          // Invalidate the property that depends on the changed key.
          chain.notifyPropertyDidChange();
        });
        this.endPropertyChanges();
      }
    }

    var cache = this._kvo_cache;
    if (cache) {

      // clear any cached value
      if (!_keepCache) {
        func = this[key];
        if (func && func.isProperty) {
          cache[func.cacheKey] = cache[func.lastSetValueKey] = undefined;
        }
      }

      if (this._kvo_cacheable) {
        // if there are any dependent keys and they use caching, then clear the
        // cache.  This is the same code as is in set.  It is inlined for perf.
        cachedep = this._kvo_cachedep;
        if (!cachedep || (cachedep = cachedep[key]) === undefined) {
          cachedep = this._kvo_computeCachedDependentsFor(key);
        }

        if (cachedep) {
          idx = cachedep.length;
          while (--idx >= 0) {
            dfunc = cachedep[idx];
            cache[dfunc.cacheKey] = cache[dfunc.lastSetValueKey] = undefined;
          }
        }
      }
    }

    // save in the change set if queuing changes
    var suspended = SC.Observers.isObservingSuspended;
    if ((level > 0) || suspended) {
      var changes = this._kvo_changes;
      if (!changes) changes = this._kvo_changes = SC.CoreSet.create();
      changes.add(key);

      if (suspended) {
        

        SC.Observers.objectHasPendingChanges(this);
      }

    // otherwise notify property observers immediately
    } else {
      this._notifyPropertyObservers(key);
    }

    return this;
  },

  // ..........................................
  // DEPENDENT KEYS
  //

  /**
    Use this to indicate that one key changes if other keys it depends on
    change.  Pass the key that is dependent and additional keys it depends
    upon.  You can either pass the additional keys inline as arguments or
    in a single array.

    You generally do not call this method, but instead pass dependent keys to
    your property() method when you declare a computed property.

    You can call this method during your init to register the keys that should
    trigger a change notification for your computed properties.

    @param {String} key the dependent key
    @param {Array|String} dependentKeys one or more dependent keys
    @returns {Object} this
  */
  registerDependentKey: function (key, dependentKeys) {
    var dependents      = this._kvo_dependents,
      // chainDependents = this._kvo_chain_dependents,
      keys, idx, lim, dep, queue;

    // normalize input.
    if (typeof dependentKeys === "object" && (dependentKeys instanceof Array)) {
      keys = dependentKeys;
      lim  = 0;
    } else {
      keys = arguments;
      lim  = 1;
    }
    idx  = keys.length;

    // define dependents if not defined already.
    if (!dependents) this._kvo_dependents = dependents = {};

    // for each key, build array of dependents, add this key...
    // note that we ignore the first argument since it is the key...
    while (--idx >= lim) {
      dep = keys[idx];

      if (dep.indexOf('.') >= 0) {
        SC._PropertyChain.createChain(dep, this, key).activate();
      } else {
        // add dependent key to dependents array of key it depends on
        queue = dependents[dep];
        if (!queue) { queue = dependents[dep] = []; }
        queue.push(key);
      }
    }
  },

  /** @private
    Register a property chain so that dependent keys can be invalidated
    when a property on this object changes.

    @param {String} property the property on this object that invalidates the chain
    @param {SC._PropertyChain} chain the chain to notify
  */
  registerDependentKeyWithChain: function (property, chain) {
    var chains = this._chainsFor(property);
    chains.add(chain);
  },

  /** @private
    Removes a property chain from the object.

    @param {String} property the property on this object that invalidates the chain
    @param {SC._PropertyChain} chain the chain to notify
  */
  removeDependentKeyWithChain: function (property, chain) {
    var chains = this._chainsFor(property);
    chains.remove(chain);

    if (chains.get('length') === 0) {
      delete this._kvo_property_chains[property];
    }
  },

  /** @private
    Returns an instance of SC.CoreSet in which to save SC._PropertyChains.

    @param {String} property the property associated with the SC._PropertyChain
    @returns {SC.CoreSet}
  */
  _chainsFor: function (property) {
    this._kvo_property_chains = this._kvo_property_chains || {};
    var chains = this._kvo_property_chains[property] || SC.CoreSet.create();
    this._kvo_property_chains[property] = chains;

    return chains;
  },

  /** @private

    Helper method used by computeCachedDependents.  Just loops over the
    array of dependent keys.  If the passed function is cacheable, it will
    be added to the queue.  Also, recursively call on each keys dependent
    keys.

    @param {Array} queue the queue to add functions to
    @param {Array} keys the array of dependent keys for this key
    @param {Hash} dependents the _kvo_dependents cache
    @param {SC.Set} seen already seen keys
    @returns {void}
  */
  _kvo_addCachedDependents: function (queue, keys, dependents, seen) {
    var idx = keys.length,
        func, key, deps;

    while (--idx >= 0) {
      key  = keys[idx];
      seen.add(key);

      // if the value for this key is a computed property, then add it to the
      // set if it is cacheable, and process any of its dependent keys also.
      func = this[key];
      if (func && (func instanceof Function) && func.isProperty) {
        if (func.isCacheable) queue.push(func); // handle this func
        if ((deps = dependents[key]) && deps.length > 0) { // and any dependents
          this._kvo_addCachedDependents(queue, deps, dependents, seen);
        }
      }
    }

  },

  /** @private

    Called by set() whenever it needs to determine which cached dependent
    keys to clear.  Recursively searches dependent keys to determine all
    cached property directly or indirectly affected.

    The return value is also saved for future reference

    @param {String} key the key to compute
    @returns {Array}
  */
  _kvo_computeCachedDependentsFor: function (key) {
    var cached     = this._kvo_cachedep,
        dependents = this._kvo_dependents,
        keys       = dependents ? dependents[key] : null,
        queue, seen;
    if (!cached) cached = this._kvo_cachedep = {};

    // if there are no dependent keys, then just set and return null to avoid
    // this mess again.
    if (!keys || keys.length === 0) return cached[key] = null;

    // there are dependent keys, so we need to do the work to find out if
    // any of them or their dependent keys are cached.
    queue = cached[key] = [];
    seen  = SC._TMP_SEEN_SET = (SC._TMP_SEEN_SET || SC.CoreSet.create());
    seen.add(key);
    this._kvo_addCachedDependents(queue, keys, dependents, seen);
    seen.clear(); // reset

    if (queue.length === 0) queue = cached[key] = null; // turns out nothing
    return queue;
  },

  // ..........................................
  // OBSERVERS
  //

  _kvo_for: function (kvoKey, type) {
    var ret = this[kvoKey];

    if (!this._kvo_cloned) this._kvo_cloned = {};

    // if the item does not exist, create it.  Unless type is passed,
    // assume array.
    if (!ret) {
      ret = this[kvoKey] = (type === undefined) ? [] : type.create();
      this._kvo_cloned[kvoKey] = YES;

    // if item does exist but has not been cloned, then clone it.  Note
    // that all types must implement copy().0
    } else if (!this._kvo_cloned[kvoKey]) {
      ret = this[kvoKey] = ret.copy();
      this._kvo_cloned[kvoKey] = YES;
    }

    return ret;
  },

  /**
    Adds an observer on a property.

    This is the core method used to register an observer for a property.

    Once you call this method, anytime the key's value is set, your observer
    will be notified.  Note that the observers are triggered anytime the
    value is set, regardless of whether it has actually changed.  Your
    observer should be prepared to handle that.

    You can also pass an optional context parameter to this method.  The
    context will be passed to your observer method whenever it is triggered.
    Note that if you add the same target/method pair on a key multiple times
    with different context parameters, your observer will only be called once
    with the last context you passed.

    Observer Methods
    ---

    Observer methods you pass should generally have the following signature if
    you do not pass a "context" parameter:

          fooDidChange: function (sender, key, value, rev);

    The sender is the object that changed.  The key is the property that
    changes.  The value property is currently reserved and unused.  The rev
    is the last property revision of the object when it changed, which you can
    use to detect if the key value has really changed or not.

    If you pass a "context" parameter, the context will be passed before the
    revision like so:

          fooDidChange: function (sender, key, value, context, rev);

    Usually you will not need the value, context or revision parameters at
    the end.  In this case, it is common to write observer methods that take
    only a sender and key value as parameters or, if you aren't interested in
    any of these values, to write an observer that has no parameters at all.

    @param {String} key the key to observer
    @param {Object} target the target object to invoke
    @param {String|Function} method the method to invoke.
    @param {Object} context optional context
    @returns {SC.Object} self
  */
  addObserver: function (key, target, method, context) {
    var kvoKey, chain;

    // normalize.  if a function is passed to target, make it the method.
    if (method === undefined) {
      method = target;
      target = this;
    }
    if (!target) target = this;

    if (typeof method === "string") method = target[method];
    if (!method) throw new Error("You must pass a method to addObserver()");

    // Normalize key...
    key = key.toString();
    if (key.indexOf('.') >= 0) {

      // create the chain and save it for later so we can tear it down if
      // needed.
      chain = SC._ChainObserver.createChain(this, key, target, method, context);
      chain.masterTarget = target;
      chain.masterMethod = method;

      // Save in set for chain observers.
      this._kvo_for(SC.keyFor('_kvo_chains', key)).push(chain);

    // Create observers if needed...
    } else {

      // Special case to support reduced properties.  If the property
      // key begins with '@' and its value is unknown, then try to get its
      // value.  This will configure the dependent keys if needed.
      if ((this[key] === undefined) && (key.indexOf('@') === 0)) {
        this.get(key);
      }

      if (target === this) target = null; // use null for observers only.
      kvoKey = SC.keyFor('_kvo_observers', key);
      this._kvo_for(kvoKey, SC.ObserverSet).add(target, method, context);
      this._kvo_for('_kvo_observed_keys', SC.CoreSet).add(key);
    }

    if (this.didAddObserver) this.didAddObserver(key, target, method);
    return this;
  },

  /**
    Remove an observer you have previously registered on this object.  Pass
    the same key, target, and method you passed to addObserver() and your
    target will no longer receive notifications.

    @param {String} key the key to observer
    @param {Object} target the target object to invoke
    @param {String|Function} method the method to invoke.
    @returns {SC.Observable} receiver
  */
  removeObserver: function (key, target, method) {

    var kvoKey, chains, chain, observers, idx;

    // normalize.  if a function is passed to target, make it the method.
    if (method === undefined) {
      method = target;
      target = this;
    }
    if (!target) target = this;

    if (typeof method === "string") method = target[method];
    if (!method) throw new Error("You must pass a method to removeObserver()");

    // if the key contains a '.', this is a chained observer.
    key = key.toString();
    if (key.indexOf('.') >= 0) {

      // try to find matching chains
      kvoKey = SC.keyFor('_kvo_chains', key);
      if (chains = this[kvoKey]) {

        // if chains have not been cloned yet, do so now.
        chains = this._kvo_for(kvoKey);

        // remove any chains
        idx = chains.length;
        while (--idx >= 0) {
          chain = chains[idx];
          if (chain && (chain.masterTarget === target) && (chain.masterMethod === method)) {
            chains[idx] = chain.destroyChain();
          }
        }
      }

    // otherwise, just like a normal observer.
    } else {
      if (target === this) target = null; // use null for observers only.
      kvoKey = SC.keyFor('_kvo_observers', key);
      if (observers = this[kvoKey]) {
        // if observers have not been cloned yet, do so now
        observers = this._kvo_for(kvoKey);
        observers.remove(target, method);

        // Remove the key when no members remain.
        if (observers.getMembers().length === 0) {
          this._kvo_for('_kvo_observed_keys', SC.CoreSet).remove(key);
        }
      }
    }

    if (this.didRemoveObserver) this.didRemoveObserver(key, target, method);
    return this;
  },

  /**
    Returns YES if the object currently has observers registered for a
    particular key.  You can use this method to potentially defer performing
    an expensive action until someone begins observing a particular property
    on the object.

    Optionally, you may pass a target and method to check for the
    presence of a particular observer. You can use this to avoid creating
    duplicate observers in situations where that's likely.

    @param {String} key key to check
    @param {Object} [target] the target that the observer uses
    @param {Function|String} [method]) the method on the target that the observer uses
    @returns {Boolean}
  */
  hasObserverFor: function (key, target, method) {
    SC.Observers.flush(this); // hookup as many observers as possible.

    var observers = this[SC.keyFor('_kvo_observers', key)],
        chains = this._kvo_for(SC.keyFor('_kvo_chains', key)),
        locals = this[SC.keyFor('_kvo_local', key)],
        isChain = key.indexOf('.') >= 0;

    // Fast path: no target/method.
    if (target === undefined) {
      if (isChain) {
        if (chains && chains.length > 0) return YES;
      } else {
        // Found locally.
        if (locals && locals.length > 0) return YES;
        if (observers && observers.getMembers().length > 0) return YES;
      }
      return NO;

    // Slow path: target/method.
    } else {
      if (method === undefined) {
        method = target;
        target = this;
      }
      if (typeof method === "string") method = target[method];
      if (!method) throw new Error("Developer Error: If present, the `method` argument of hasObserverFor must be (or refer to) a function.");

      // Declare our iterators.
      var i, len;

      // Check remote chains.
      if (isChain) {
        if (!chains || !chains.length) return NO;
        len = chains.length;
        for (i = 0; i < len; i++) {
          if (chains[i].masterTarget === target && chains[i].masterMethod === method) return YES;
        }
        return NO;

      // Check locals.
      } else if (target === this) {
        if (!locals) return NO;
        len = locals.length;
        for (i = 0; i < len; i++) {
          if (this[locals[i]] === method) return YES;
        }
        return NO;

      // Check remotes.
      } else {
        if (!observers || !observers.members) return NO;

        len = observers.members.length;
        var member;
        for (i = 0; i < len; i++) {
          member = observers.members[i];
          // If this is a non-chained observer, the first item is the target and the second is the method.
          if (member[0] === target && member[1] === method) return YES;
        }
        return NO;
      }
      // TODO: Remote chains.
    }
  },

  /**
    This method will register any observers and computed properties saved on
    the object.  Normally you do not need to call this method yourself.  It
    is invoked automatically just before property notifications are sent and
    from the init() method of SC.Object.  You may choose to call this
    from your own initialization method if you are using SC.Observable in
    a non-SC.Object-based object.

    This method looks for several private variables, which you can setup,
    to initialize:

      - _observers: this should contain an array of key names for observers
        you need to configure.

      - _bindings: this should contain an array of key names that configure
        bindings.

      - _properties: this should contain an array of key names for computed
        properties.

    @returns {Object} this
  */
  initObservable: function () {
    if (this._observableInited) return;
    this._observableInited = YES;

    var loc, keys, key, value, observer, propertyPaths, propertyPathsLength,
        len, ploc, path, propertyKey, keysLen;

    // Loop through observer functions and register them
    if (keys = this._observers) {
      len = keys.length;
      for (loc = 0; loc < len; loc++) {
        key = keys[loc];
        observer = this[key];
        propertyPaths = observer.propertyPaths;
        propertyPathsLength = (propertyPaths) ? propertyPaths.length : 0;
        for (ploc = 0 ; ploc < propertyPathsLength; ploc++) {
          path = propertyPaths[ploc];
          this.addObservesHandler(observer, path);
        }
      }
    }

    // Add Bindings
    this.bindings = []; // will be filled in by the bind() method.
    if (keys = this._bindings) {
      for (loc = 0, keysLen = keys.length; loc < keysLen; loc++) {
        // get propertyKey
        key = keys[loc];
        value = this[key];
        propertyKey = key.slice(0, -7); // contentBinding => content

        // Replace the short form property with the new binding object.
        this[key] = this.bind(propertyKey, value);
      }
    }

    // Add Properties
    if (keys = this._properties) {
      for (loc = 0, keysLen = keys.length; loc < keysLen; loc++) {
        key = keys[loc];
        if (value = this[key]) {

          // activate cacheable only if needed for perf reasons
          if (value.isCacheable) this._kvo_cacheable = YES;

          // register dependent keys
          if (value.dependentKeys && (value.dependentKeys.length > 0)) {
            this.registerDependentKey(key, value.dependentKeys);
          }
        }
      }
    }

    // Clean up these properties once they have been used.
    delete this._bindings;
    delete this._properties;

    return this;
  },

  /**
    This method will destroy the observable.

    @returns {Object} this
  */
  destroyObservable: function () {
    var key, keys,
      len,
      observer,
      path,
      propertyPaths,
      propertyPathsLength;

    // Destroy bindings
    this.bindings.invoke('destroy');
    delete this.bindings;

    // Loop through observer functions and remove them
    if (keys = this._observers) {
      len = keys.length;
      for (var loc = 0; loc < len; loc++) {
        key = keys[loc];
        observer = this[key];
        propertyPaths = observer.propertyPaths;
        propertyPathsLength = (propertyPaths) ? propertyPaths.length : 0;

        for (var ploc = 0; ploc < propertyPathsLength; ploc++) {
          path = propertyPaths[ploc];
          this.removeObservesHandler(observer, path);
        }
      }
    }

    delete this._observers;

    return this;
  },

  /**
    Will add an observes handler to this object for a given property path.

    In most cases, the path provided is relative to this object. However,
    if the path begins with a capital character then the path is considered
    relative to the window object.

    @param {Function} observer the function on this object that will be
      notified of changes
    @param {String} path a property path string
    @return {Object} returns this
  */
  addObservesHandler: function (observer, path) {
    this._configureObservesHandler(SC.OBSERVES_HANDLER_ADD, observer, path);
    return this;
  },

  /**
    Will remove an observes handler from this object for a given property path.

    In most cases, the path provided is relative to this object. However,
    if the path begins with a capital character then the path is considered
    relative to the window object.

    @param {Function} observer the function on this object that will be
      notified of changes
    @param {String} path a property path string
    @return {Object} returns this
  */
  removeObservesHandler: function (observer, path) {
    this._configureObservesHandler(SC.OBSERVES_HANDLER_REMOVE, observer, path);
    return this;
  },

  /** @private

    Used to either add or remove an observer handler on this object
    for a given property path.

    In most cases, the path provided is relative to this object. However,
    if the path begins with a capital character then the path is considered
    relative to the window object.

    You must supply an action that is to be performed by this method. The
    action can either be `SC.OBSERVES_HANDLER_ADD` or `SC.OBSERVES_HANDLER_REMOVE`.

    @param {Function} observer the function on this object that will be
      notified of changes
    @param {String} path a property path string
    @param {String} path a dot-notation property path string
  */
  _configureObservesHandler: function (action, observer, path) {
    var dotIndex, root;

    switch (action) {
    case SC.OBSERVES_HANDLER_ADD:
      action = "addObserver";
      break;
    case SC.OBSERVES_HANDLER_REMOVE:
      action = "removeObserver";
      break;
    default:
      throw new Error("invalid action provided: " + action);
    }

    dotIndex = path.indexOf('.');

    if (dotIndex < 0) {
      this[action](path, this, observer);
    } else if (path.indexOf('*') === 0) {
      this[action](path.slice(1), this, observer);
    } else {
      root = null;

      if (dotIndex === 0) {
        root = this;
        path = path.slice(1);
      } else if (dotIndex === 4 && path.slice(0, 5) === 'this.') {
        root = this;
        path = path.slice(5);
      } else if (dotIndex < 0 && path.length === 4 && path === 'this') {
        root = this;
        path = '';
      } else if (dotIndex > 0 && path[0] === path.charAt(0).toLowerCase()) {
        // if the first character for the given path is lower case
        // then we assume the path is relative to this
        root = this;
      }

      SC.Observers[action](path, this, observer, root);
    }
  },

  // ..........................................
  // NOTIFICATION
  //

  /**
    Returns an array with all of the observers registered for the specified
    key.  This is intended for debugging purposes only.  You generally do not
    want to rely on this method for production code.

    @param {String} key the key to evaluate
    @returns {Array} array of Observer objects, describing the observer.
  */
  observersForKey: function (key) {
    SC.Observers.flush(this); // hookup as many observers as possible.

    var observers = this[SC.keyFor('_kvo_observers', key)];
    return observers ? observers.getMembers() : [];
  },

  /** @private
    This private method actually notifies the observers for any keys in the observer queue.  If you
    pass a key it will be added to the queue.
  */
  _notifyPropertyObservers: function (key) {
    // Ensure that this object has been initialized.
    if (!this._observableInited) this.initObservable();

    SC.Observers.flush(this); // hookup as many observers as possible.

    var observers, changes, dependents, starObservers, idx, keys, rev,
        members, membersLength, member, memberLoc, target, method, loc, func,
        context, spaces, cache;

    


    // Get any starObservers -- they will be notified of all changes.
    starObservers = this['_kvo_observers_*'];

    // prevent notifications from being sent until complete
    this._kvo_changeLevel = this._kvo_changeLevel + 1;

    // keep sending notifications as long as there are changes
    while (((changes = this._kvo_changes) && (changes.length > 0)) || key) {

      // increment revision
      rev = ++this.propertyRevision;

      // save the current set of changes and swap out the kvo_changes so that
      // any set() calls by observers will be saved in a new set.
      if (!changes) changes = SC.CoreSet.create();
      this._kvo_changes = null;

      // Add the passed key to the changes set.  If a '*' was passed, then
      // add all keys in the observers to the set...
      // once finished, clear the key so the loop will end.
      if (key === '*') {
        changes.add('*');
        changes.addEach(this._kvo_for('_kvo_observed_keys', SC.CoreSet));

      } else if (key) {
        changes.add(key);
      }

      // Now go through the set and add all dependent keys...
      dependents = this._kvo_dependents;
      if (dependents) {

        // NOTE: each time we loop, we check the changes length, this
        // way any dependent keys added to the set will also be evaluated...
        for (idx = 0; idx < changes.length; idx++) {
          key = changes[idx];
          keys = dependents[key];

          // for each dependent key, add to set of changes.  Also, if key
          // value is a cacheable property, clear the cached value...
          if (keys && (loc = keys.length)) {
            

            cache = this._kvo_cache;
            if (!cache) cache = this._kvo_cache = {};
            while (--loc >= 0) {
              changes.add(key = keys[loc]);
              if (func = this[key]) {
                this[func.cacheKey] = undefined;
                cache[func.cacheKey] = cache[func.lastSetValueKey] = undefined;
              } // if (func=)
            } // while (--loc)
          } // if (keys &&
        } // for(idx...
      } // if (dependents...)

      // now iterate through all changed keys and notify observers.
      while (changes.length > 0) {
        key = changes.pop(); // the changed key

        // find any observers and notify them...
        observers = this[SC.keyFor('_kvo_observers', key)];

        if (observers) {
          // We need to clone the 'members' structure here in case any of the
          // observers we're about to notify happen to remove observers for
          // this key, which would mutate the structure underneath us.
          // (Cloning it rather than mutating gives us a clear policy:  if you
          // were registered as an observer at the time notification begins,
          // you will be notified, regardless of whether you're removed as an
          // observer during that round of notification.  Similarly, if you're
          // added as an observer during the notification round by another
          // observer, you will not be notified until the next time.)
          members = observers.getMembers();
          membersLength = members.length;

          for (memberLoc = 0; memberLoc < membersLength; memberLoc++) {
            member = members[memberLoc];

            if (member[3] === rev) continue; // skip notified items.

            if (!member[1]) console.log(member);

            target = member[0] || this;
            method = member[1];
            context = member[2];
            member[3] = rev;

            

            if (context !== undefined) {
              method.call(target, this, key, null, context, rev);
            } else {
              method.call(target, this, key, null, rev);
            }
          }
        }

        // look for local observers.  Local observers are added by SC.Object
        // as an optimization to avoid having to add observers for every
        // instance when you are just observing your local object.
        members = this[SC.keyFor('_kvo_local', key)];
        if (members) {
          // Note:  Since, unlike above, we don't expect local observers to be
          //        removed in general, we will not clone 'members'.
          membersLength = members.length;
          for (memberLoc = 0; memberLoc < membersLength; memberLoc++) {
            member = members[memberLoc];
            method = this[member]; // try to find observer function
            if (method) {
              


              method.call(this, this, key, null, rev);
            }
          }
        }

        // if there are starObservers, do the same thing for them
        if (starObservers && key !== '*') {
          // We clone the structure per the justification, above, for regular
          // observers.
          members = starObservers.getMembers();
          membersLength = members.length;
          for (memberLoc = 0; memberLoc < membersLength; memberLoc++) {
            member = members[memberLoc];
            target = member[0] || this;
            method = member[1];
            context = member[2];

            

            if (context !== undefined) {
              method.call(target, this, key, null, context, rev);
            } else {
              method.call(target, this, key, null, rev);
            }
          }
        }

        // if there is a default property observer, call that also
        if (this.propertyObserver) {
          

          this.propertyObserver(this, key, null, rev);
        }
      } // while(changes.length>0)

      // changes set should be empty. release it for reuse
      if (changes) changes.destroy();

      // key is no longer needed; clear it to avoid infinite loops
      key = null;

    } // while (changes)

    // done with loop, reduce change level so that future sets can resume
    this._kvo_changeLevel = (this._kvo_changeLevel || 1) - 1;

    


    return YES; // finished successfully
  },

  // ..........................................
  // BINDINGS
  //

  /**
    Manually add a new binding to an object.  This is the same as doing
    the more familiar propertyBinding: 'property.path' approach.

    @param {String} toKey the key to bind to
    @param {Object} target target or property path to bind from
    @param {String|Function} method method for target to bind from
    @returns {SC.Binding} new binding instance
  */
  bind: function (toKey, target, method) {
    var binding, pathType;

    


    // normalize...
    if (method !== undefined) target = [target, method];

    pathType = typeof target;

    // if a string or array (i.e. tuple) is passed, convert this into a
    // binding.  If a binding default was provided, use that.
    if (pathType === "string" || (pathType === "object" && (target instanceof Array))) {
      binding = this[toKey + 'BindingDefault'] || SC.Binding;
      binding = binding.beget().from(target);
    } else {
      // If a binding object was provided, clone it so that it gets
      // connected again if the original example binding was already
      // connected.
      binding = target.beget();
    }

    // finish configuring the binding and then connect it.
    binding = binding.to(toKey, this).connect();
    this.bindings.push(binding);

    return binding;
  },

  /**
    didChangeFor is a very important method which allows you to tell whether
    a property or properties have changed.

    The key to using didChangeFor is to pass a unique string as the first argument,
    which signals, "Has anything changed since the last time this was called with
    this unique key?" The string can be anything you want, as long as it's unique
    and stays the same from call to call.

    After the key argument, you can pass as many property arguments as you like;
    didChangeFor will only return `true` if any of those properties have changed
    since the last call.

    For example, in your view's update method, you might want to gate DOM changes
    (generally a slow operation) on whether the root values have changed. You might
    ask the following:

        if (this.didChangeFor('updateOnDisplayValue', 'displayValue')) {
          // Update the DOM.
        }

    In another method on the same view, you might send an event if that same value
    has changed:

        if (this.didChangeFor('otherMethodDisplayValue', 'displayValue')) {
          // Send a statechart action.
        }

    Each call will correctly return whether the property has changed since the last
    time displayDidChange was called *with that key*. The following sequence of calls
    will return the following values:

      - this.set('displayValue', 'value1');
      - this.didChangeFor('updateOnDisplayValue', 'displayValue');
      > true;
      - this.didChangeFor('updateOnDisplayValue', 'displayValue');
      > false;
      - this.didChangeFor('otherMethodDisplayValue', 'displayValue');
      > true;
      - this.set('displayValue', 'value2');
      - this.didChangeFor('updateOnDisplayValue', 'displayValue');
      > true;
      - this.didChangeFor('updateOnDisplayValue', 'displayValue');
      > false;
      - this.didChangeFor('updateOnDisplayValue', 'displayValue');
      > false;
      - this.didChangeFor('otherMethodDisplayValue', 'displayValue');
      > false;

    This method works by comparing property revision counts. Every time a
    property changes, an internal counter is incremented. When didChangeFor is
    invoked, the current revision count of the property is compared to the
    revision count from the last time this method was called.

    @param {String|Object} context a unique identifier
    @param {String…} propertyNames one or more property names
  */
  didChangeFor: function (context) {
    var valueCache, revisionCache, seenValues, seenRevisions, ret,
        currentRevision, idx, key, value;
    context = SC.hashFor(context); // get a hash key we can use in caches.

    // setup caches...
    valueCache = this._kvo_didChange_valueCache;
    if (!valueCache) valueCache = this._kvo_didChange_valueCache = {};
    revisionCache = this._kvo_didChange_revisionCache;
    if (!revisionCache) revisionCache = this._kvo_didChange_revisionCache = {};

    // get the cache of values and revisions already seen in this context
    seenValues = valueCache[context] || {};
    seenRevisions = revisionCache[context] || {};

    // prepare to loop!
    ret = false;
    currentRevision = this._kvo_revision;
    idx = arguments.length;
    while (--idx >= 1) {  // NB: loop only to 1 to ignore context arg.
      key = arguments[idx];

      // has the kvo revision changed since the last time we did this?
      if (seenRevisions[key] != currentRevision) {
        // yes, check the value with the last seen value
        value = this.get(key);
        if (seenValues[key] !== value) {
          ret = true; // did change!
          seenValues[key] = value;
        }
      }
      seenRevisions[key] = currentRevision;
    }

    valueCache[context] = seenValues;
    revisionCache[context] = seenRevisions;
    return ret;
  },

  /**
    Sets the property only if the passed value is different from the
    current value.  Depending on how expensive a get() is on this property,
    this may be more efficient.

    NOTE: By default, the set() method will not set the value unless it has
    changed. However, this check can skipped by setting .property().idempotent(NO)
    setIfChanged() may be useful in this case.

    @param {String|Hash} key the key to change
    @param {Object} value the value to change
    @returns {SC.Observable}
  */
  setIfChanged: function (key, value) {
    if (value === undefined && SC.typeOf(key) === SC.T_HASH) {
      var hash = key;

      for (key in hash) {
        if (!hash.hasOwnProperty(key)) continue;
        this.setIfChanged(key, hash[key]);
      }

      return this;
    }

    return (this.get(key) !== value) ? this.set(key, value) : this;
  },

  /**
    Navigates the property path, returning the value at that point.

    If any object in the path is undefined, returns undefined.
    @param {String} path The property path you want to retrieve
  */
  getPath: function (path) {
    var tuple = SC.tupleForPropertyPath(path, this);
    if (tuple === null || tuple[0] === null) return undefined;
    return SC.get(tuple[0], tuple[1]);
  },

  /**
    Navigates the property path, finally setting the value.

    @param {String} path the property path to set
    @param {Object} value the value to set
    @returns {SC.Observable}
  */
  setPath: function (path, value) {
    if (path.indexOf('.') >= 0) {
      var tuple = SC.tupleForPropertyPath(path, this);
      if (!tuple || !tuple[0]) return null;
      tuple[0].set(tuple[1], value);
    } else this.set(path, value); // shortcut
    return this;
  },

  /**
    Navigates the property path, finally setting the value but only if
    the value does not match the current value.  This will avoid sending
    unnecessary change notifications.

    @param {String} path the property path to set
    @param {Object} value the value to set
    @returns {Object} this
  */
  setPathIfChanged: function (path, value) {
    if (path.indexOf('.') >= 0) {
      var tuple = SC.tupleForPropertyPath(path, this);
      if (!tuple || !tuple[0]) return null;
      if (tuple[0].get(tuple[1]) !== value) {
        tuple[0].set(tuple[1], value);
      }
    } else this.setIfChanged(path, value); // shortcut
    return this;
  },

  /**
    Convenience method to get an array of properties.

    Pass in multiple property keys or an array of property keys.  This
    method uses getPath() so you can also pass key paths.

    @returns {Array} Values of property keys.
  */
  getEach: function () {
    var ret = [], idx, idxLen;

    for (idx = 0, idxLen = arguments.length; idx < idxLen; idx++) {
      ret[ret.length] = this.getPath(arguments[idx]);
    }
    return ret;
  },


  /**
    Increments the value of a property.

    @param {String} key property name
    @param {Number} increment the amount to increment (optional)
    @returns {Number} new value of property
  */
  incrementProperty: function (key, increment) {
    if (!increment) increment = 1;
    this.set(key, (this.get(key) || 0) + increment);
    return this.get(key);
  },

  /**
    Decrements the value of a property.

    @param {String} key property name
    @param {Number} increment the amount to decrement (optional)
    @returns {Number} new value of property
  */
  decrementProperty: function (key, increment) {
    if (!increment) increment = 1;
    this.set(key, (this.get(key) || 0) - increment);
    return this.get(key);
  },

  /**
    Inverts a property.  Property should be a bool.

    @param {String} key property name
    @param {Object} value optional parameter for "true" value
    @param {Object} alt optional parameter for "false" value
    @returns {Object} new value
  */
  toggleProperty: function (key, value, alt) {
    if (value === undefined) value = true;
    if (alt === undefined) alt = false;
    value = (this.get(key) == value) ? alt : value;
    this.set(key, value);
    return this.get(key);
  },

  /**
    Convenience method to call propertyWillChange/propertyDidChange.

    Sometimes you need to notify observers that a property has changed value
    without actually changing this value.  In those cases, you can use this
    method as a convenience instead of calling propertyWillChange() and
    propertyDidChange().

    @param {String} key The property key that has just changed.
    @param {Object} value The new value of the key.  May be null.
    @returns {SC.Observable}
  */
  notifyPropertyChange: function (key, value) {
    this.propertyWillChange(key);
    this.propertyDidChange(key, value);
    return this;
  },

  /**
    Notifies observers of all possible property changes.

    Sometimes when you make a major update to your object, it is cheaper to
    simply notify all observers that their property might have changed than
    to figure out specifically which properties actually did change.

    In those cases, you can simply call this method to notify all property
    observers immediately.  Note that this ignores property groups.

    @returns {SC.Observable}
  */
  allPropertiesDidChange: function () {
    this._kvo_cache = null; //clear cached props
    this._notifyPropertyObservers('*');
    return this;
  },

  propertyRevision: 1

};




/**
  Retrieves a property from an object, using get() if the
  object implements SC.Observable.

  @param  {Object}  object  the object to query
  @param  {String}  key the property to retrieve
*/
SC.mixin(SC, {

  get: function (object, key) {
    if (!object) return undefined;
    if (key === undefined) return this[object];
    if (object.get) return object.get(key);
    return object[key];
  },

  /**
    Retrieves a property from an object at a specified path, using get() if
    the object implements SC.Observable.

    @param  {Object}  object  the object to query
    @param  {String}  path the path to the property to retrieve
  */
  getPath: function (object, path) {
    if (path === undefined) {
      path = object;
      object = window;
    }
    return SC.objectForPropertyPath(path, object);
  }

});

// Make all Array's observable
SC.mixin(Array.prototype, SC.Observable);

/* >>>>>>>>>> BEGIN source/system/enumerator.js */
// ==========================================================================
// Project:   SproutCore Costello - Property Observing Library
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @class

  An object that iterates over all of the values in an object.

  An instance of this object is returned every time you call the
  enumerator() method on an object that implements the SC.Enumerable mixin.

  Once you create an enumerator instance, you can call nextObject() on it
  until you can iterated through the entire collection.  Once you have
  exhausted the enumerator, you can reuse it if you want by calling reset().

  @since SproutCore 1.0
*/
SC.Enumerator = function(enumerableObject) {
  this.enumerable = enumerableObject ;
  this.reset() ;
  return this ;
} ;

SC.Enumerator.prototype = /** @scope SC.Enumerator.prototype */{

  /**
    Returns the next object in the enumeration or undefined when complete.

    @returns {Object} the next object or undefined
  */
  nextObject: function() {
    var index = this._index ;
    var len = this._length;
    if (index >= len) return undefined ; // nothing to do

    // get the value
    var ret = this.enumerable.nextObject(index, this._previousObject, this._context) ;
    this._previousObject = ret ;
    this._index = index + 1 ;

    if (index >= len) {
      this._context = SC.Enumerator._pushContext(this._context);
    }

    return ret ;
  },

  /**
    Resets the enumerator to the beginning.  This is a nice way to reuse
    an existing enumerator.

    @returns {Object} this
  */
  reset: function() {
    var e = this.enumerable ;
    if (!e) SC.throw("Enumerator has been destroyed");
    this._length = e.get ? e.get('length') : e.length ;
    var len = this._length;
    this._index = 0;
    this._previousObject = null ;
    this._context = (len > 0) ? SC.Enumerator._popContext() : null;
  },

  /**
    Releases the enumerators enumerable object.  You cannot use this object
    anymore.  This is not often needed but it is useful when you need to
    make sure memory gets cleared.

    @returns {Object} null
  */
  destroy: function() {
    this.enumerable = this._length = this._index = this._previousObject = this._context = null;
  }

} ;

/**
  Use this method to manually create a new Enumerator object.  Usually you
  will not access this method directly but instead call enumerator() on the
  item you want to enumerate.

  @param {SC.Enumerable}  enumerableObject enumerable object.
  @returns {SC.Enumerator} the enumerator
*/
SC.Enumerator.create = function(enumerableObject) {
  return new SC.Enumerator(enumerableObject) ;
};

// Private context caching methods.  This avoids recreating lots of context
// objects.

SC.Enumerator._popContext = function() {
  var ret = this._contextCache ? this._contextCache.pop() : null ;
  return ret || {} ;
} ;

SC.Enumerator._pushContext = function(context) {
  this._contextCache = this._contextCache || [] ;
  var cache = this._contextCache;
  cache.push(context);
  return null ;
};


/* >>>>>>>>>> BEGIN source/mixins/enumerable.js */
// ==========================================================================
// Project:   SproutCore Costello - Property Observing Library
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('core');
sc_require('ext/function');
sc_require('system/enumerator');

/*global Prototype */

/**
  @class

  This mixin defines the common interface implemented by enumerable objects
  in SproutCore.  Most of these methods follow the standard Array iteration
  API defined up to JavaScript 1.8 (excluding language-specific features that
  cannot be emulated in older versions of JavaScript).

  This mixin is applied automatically to the Array class on page load, so you
  can use any of these methods on simple arrays.  If Array already implements
  one of these methods, the mixin will not override them.

  Writing Your Own Enumerable
  -----

  To make your own custom class enumerable, you need two items:

  1. You must have a length property.  This property should change whenever
     the number of items in your enumerable object changes.  If you using this
     with an SC.Object subclass, you should be sure to change the length
     property using set().

  2. You must implement nextObject().  See documentation.

  Once you have these two methods implemented, apply the SC.Enumerable mixin
  to your class and you will be able to enumerate the contents of your object
  like any other collection.

  Using SproutCore Enumeration with Other Libraries
  -----

  Many other libraries provide some kind of iterator or enumeration like
  facility.  This is often where the most common API conflicts occur.
  SproutCore's API is designed to be as friendly as possible with other
  libraries by implementing only methods that mostly correspond to the
  JavaScript 1.8 API.

  @since SproutCore 1.0
*/
SC.Enumerable = /** @scope SC.Enumerable.prototype */{

  /**
    Walk like a duck.

    @type Boolean
  */
  isEnumerable: YES,

  /**
    Implement this method to make your class enumerable.

    This method will be called repeatedly during enumeration.  The index value
    will always begin with 0 and increment monotonically.  You don't have to
    rely on the index value to determine what object to return, but you should
    always check the value and start from the beginning when you see the
    requested index is 0.

    The previousObject is the object that was returned from the last call
    to nextObject for the current iteration.  This is a useful way to
    manage iteration if you are tracing a linked list, for example.

    Finally the context parameter will always contain a hash you can use as
    a "scratchpad" to maintain any other state you need in order to iterate
    properly.  The context object is reused and is not reset between
    iterations so make sure you setup the context with a fresh state whenever
    the index parameter is 0.

    Generally iterators will continue to call nextObject until the index
    reaches the your current length-1.  If you run out of data before this
    time for some reason, you should simply return undefined.

    The default implementation of this method simply looks up the index.
    This works great on any Array-like objects.

    @param {Number} index the current index of the iteration
    @param {Object} previousObject the value returned by the last call to nextObject.
    @param {Object} context a context object you can use to maintain state.
    @returns {Object} the next object in the iteration or undefined
  */
  nextObject: function (index, previousObject, context) {
    return this.objectAt ? this.objectAt(index) : this[index];
  },

  /**
    Helper method returns the first object from a collection.  This is usually
    used by bindings and other parts of the framework to extract a single
    object if the enumerable contains only one item.

    If you override this method, you should implement it so that it will
    always return the same value each time it is called.  If your enumerable
    contains only one object, this method should always return that object.
    If your enumerable is empty, this method should return undefined.

    This property is observable if the enumerable supports it.  Examples
    of enumerables where firstObject is observable include SC.Array,
    SC.ManyArray and SC.SparseArray.  To implement a custom enumerable where
    firstObject is observable, see {@link #enumerableContentDidChange}.

    @see #enumerableContentDidChange

    @returns {Object} the object or undefined
  */
  firstObject: function () {
    if (this.get('length') === 0) return undefined;
    if (this.objectAt) return this.objectAt(0); // support arrays out of box

    // handle generic enumerables
    var context = SC.Enumerator._popContext(), ret;
    ret = this.nextObject(0, null, context);
    context = SC.Enumerator._pushContext(context);
    return ret;
  }.property().cacheable(),

  /**
    Helper method returns the last object from a collection.

    This property is observable if the enumerable supports it.  Examples
    of enumerables where lastObject is observable include SC.Array,
    SC.ManyArray and SC.SparseArray.  To implement a custom enumerable where
    lastObject is observable, see {@link #enumerableContentDidChange}.

    @see #enumerableContentDidChange

    @returns {Object} the object or undefined
  */
  lastObject: function () {
    var len = this.get('length');
    if (len === 0) return undefined;
    if (this.objectAt) return this.objectAt(len - 1); // support arrays out of box
  }.property().cacheable(),

  /**
    Returns a new enumerator for this object.  See SC.Enumerator for
    documentation on how to use this object.  Enumeration is an alternative
    to using one of the other iterators described here.

    @returns {SC.Enumerator} an enumerator for the receiver
  */
  enumerator: function () { return SC.Enumerator.create(this); },

  /**
    Iterates through the enumerable, calling the passed function on each
    item.  This method corresponds to the forEach() method defined in
    JavaScript 1.6.

    The callback method you provide should have the following signature (all
    parameters are optional):

          function (item, index, enumerable);

    - *item* is the current item in the iteration.
    - *index* is the current index in the iteration
    - *enumerable* is the enumerable object itself.

    Note that in addition to a callback, you can also pass an optional target
    object that will be set as "this" on the context.  This is a good way
    to give your iterator function access to the current object.

    @param {Function} callback the callback to execute
    @param {Object} target the target object to use
    @returns {Object} this
  */
  forEach: function (callback, target) {
    if (typeof callback !== "function") throw new TypeError();
    var len = this.get ? this.get('length') : this.length;
    if (target === undefined) target = null;

    var last = null;
    var context = SC.Enumerator._popContext();
    for (var idx = 0; idx < len;idx++) {
      var next = this.nextObject(idx, last, context);
      callback.call(target, next, idx, this);
      last = next;
    }
    last = null;
    context = SC.Enumerator._pushContext(context);
    return this;
  },

  /**
    Retrieves the named value on each member object.  This is more efficient
    than using one of the wrapper methods defined here.  Objects that
    implement SC.Observable will use the get() method, otherwise the property
    will be accessed directly.

    @param {String} key the key to retrieve
    @returns {Array} extracted values
  */
  getEach: function (key) {
    return this.map(function (next) {
      return next ? (next.get ? next.get(key) : next[key]) : null;
    }, this);
  },

  /**
    Sets the value on the named property for each member.  This is more
    efficient than using other methods defined on this helper.  If the object
    implements SC.Observable, the value will be changed to set(), otherwise
    it will be set directly.  null objects are skipped.

    @param {String} key the key to set
    @param {Object} value the object to set
    @returns {Object} receiver
  */
  setEach: function (key, value) {
    this.forEach(function (next) {
      if (next) {
        if (next.set) next.set(key, value);
        else next[key] = value;
      }
    }, this);
    return this;
  },

  /**
    Maps all of the items in the enumeration to another value, returning
    a new array.  This method corresponds to map() defined in JavaScript 1.6.

    The callback method you provide should have the following signature (all
    parameters are optional):

        function (item, index, enumerable);

    - *item* is the current item in the iteration.
    - *index* is the current index in the iteration
    - *enumerable* is the enumerable object itself.

    It should return the mapped value.

    Note that in addition to a callback, you can also pass an optional target
    object that will be set as "this" on the context.  This is a good way
    to give your iterator function access to the current object.

    @param {Function} callback the callback to execute
    @param {Object} target the target object to use
    @returns {Array} The mapped array.
  */
  map: function (callback, target) {
    if (typeof callback !== "function") throw new TypeError();
    var len = this.get ? this.get('length') : this.length;
    if (target === undefined) target = null;

    var ret  = [];
    var last = null;
    var context = SC.Enumerator._popContext();
    for (var idx = 0; idx < len;idx++) {
      var next = this.nextObject(idx, last, context);
      ret[idx] = callback.call(target, next, idx, this);
      last = next;
    }
    last = null;
    context = SC.Enumerator._pushContext(context);
    return ret;
  },

  /**
    Similar to map, this specialized function returns the value of the named
    property on all items in the enumeration.

    @param {String} key name of the property
    @returns {Array} The mapped array.
  */
  mapProperty: function (key) {
    return this.map(function (next) {
      return next ? (next.get ? next.get(key) : next[key]) : null;
    });
  },

  /**
    Returns an array with all of the items in the enumeration that the passed
    function returns YES for. This method corresponds to filter() defined in
    JavaScript 1.6.

    The callback method you provide should have the following signature (all
    parameters are optional):

          function (item, index, enumerable);

    - *item* is the current item in the iteration.
    - *index* is the current index in the iteration
    - *enumerable* is the enumerable object itself.

    It should return the YES to include the item in the results, NO otherwise.

    Note that in addition to a callback, you can also pass an optional target
    object that will be set as "this" on the context.  This is a good way
    to give your iterator function access to the current object.

    @param {Function} callback the callback to execute
    @param {Object} target the target object to use
    @returns {Array} A filtered array.
  */
  filter: function (callback, target) {
    if (typeof callback !== "function") throw new TypeError();
    var len = this.get ? this.get('length') : this.length;
    if (target === undefined) target = null;

    var ret  = [];
    var last = null;
    var context = SC.Enumerator._popContext();
    for (var idx = 0; idx < len;idx++) {
      var next = this.nextObject(idx, last, context);
      if (callback.call(target, next, idx, this)) ret.push(next);
      last = next;
    }
    last = null;
    context = SC.Enumerator._pushContext(context);
    return ret;
  },

  /**
    Returns an array sorted by the value of the passed key parameters.
    null objects will be sorted first.  You can pass either an array of keys
    or multiple parameters which will act as key names

    @param {String} key one or more key names
    @returns {Array}
  */
  sortProperty: function (key) {
    var keys = (typeof key === SC.T_STRING) ? arguments : key,
        len  = keys.length,
        src;

    // get the src array to sort
    if (this instanceof Array) src = this;
    else {
      src = [];
      this.forEach(function (i) { src.push(i); });
    }

    if (!src) return [];
    return src.sort(function (a, b) {
      var idx, key, aValue, bValue, ret = 0;

      for (idx = 0; ret === 0 && idx < len; idx++) {
        key = keys[idx];
        aValue = a ? (a.get ? a.get(key) : a[key]) : null;
        bValue = b ? (b.get ? b.get(key) : b[key]) : null;
        ret = SC.compare(aValue, bValue);
      }
      return ret;
    });
  },


  /**
    Returns an array with just the items with the matched property.  You
    can pass an optional second argument with the target value.  Otherwise
    this will match any property that evaluates to true.

    Note: null, undefined, false and the empty string all evaulate to false.

    @param {String} key the property to test
    @param {String} value optional value to test against.
    @returns {Array} filtered array
  */
  filterProperty: function (key, value) {
    var len = this.get ? this.get('length') : this.length,
        ret = [],
        last = null,
        context = SC.Enumerator._popContext(),
        idx, item, cur;
    // Although the code for value and no value are almost identical, we want to make as many decisions outside
    // the loop as possible.
    if (value === undefined) {
      for (idx = 0; idx < len; idx++) {
        item = this.nextObject(idx, last, context);
        cur = item ? (item.get ? item.get(key) : item[key]) : null;
        if (!!cur) ret.push(item);
        last = item;
      }
    } else {
      for (idx = 0; idx < len; idx++) {
        item = this.nextObject(idx, last, context);
        cur = item ? (item.get ? item.get(key) : item[key]) : null;
        if (SC.isEqual(cur, value)) ret.push(item);
        last = item;
      }
    }
    last = null;
    context = SC.Enumerator._pushContext(context);
    return ret;
  },

  /**
    Returns the first item in the array for which the callback returns YES.
    This method works similar to the filter() method defined in JavaScript 1.6
    except that it will stop working on the array once a match is found.

    The callback method you provide should have the following signature (all
    parameters are optional):

          function (item, index, enumerable);

    - *item* is the current item in the iteration.
    - *index* is the current index in the iteration
    - *enumerable* is the enumerable object itself.

    It should return the YES to include the item in the results, NO otherwise.

    Note that in addition to a callback, you can also pass an optional target
    object that will be set as "this" on the context.  This is a good way
    to give your iterator function access to the current object.

    @param {Function} callback the callback to execute
    @param {Object} target the target object to use
    @returns {Object} Found item or null.
  */
  find: function (callback, target) {
    var len = this.get ? this.get('length') : this.length;
    if (target === undefined) target = null;

    var last = null, next, found = NO, ret = null;
    var context = SC.Enumerator._popContext();
    for (var idx = 0; idx < len && !found;idx++) {
      next = this.nextObject(idx, last, context);
      if (found = callback.call(target, next, idx, this)) ret = next;
      last = next;
    }
    next = last = null;
    context = SC.Enumerator._pushContext(context);
    return ret;
  },

  /**
    Returns an the first item with a property matching the passed value.  You
    can pass an optional second argument with the target value.  Otherwise
    this will match any property that evaluates to true.

    This method works much like the more generic find() method.

    @param {String} key the property to test
    @param {String} value optional value to test against.
    @returns {Object} found item or null
  */
  findProperty: function (key, value) {
    var len = this.get ? this.get('length') : this.length;
    var found = NO, ret = null, last = null, next, cur;
    var context = SC.Enumerator._popContext();
    for (var idx = 0; idx < len && !found;idx++) {
      next = this.nextObject(idx, last, context);
      cur = next ? (next.get ? next.get(key) : next[key]) : null;
      found = (value === undefined) ? !!cur : SC.isEqual(cur, value);
      if (found) ret = next;
      last = next;
    }
    last = next = null;
    context = SC.Enumerator._pushContext(context);
    return ret;
  },

  /**
    Returns YES if the passed function returns YES for every item in the
    enumeration.  This corresponds with the every() method in JavaScript 1.6.

    The callback method you provide should have the following signature (all
    parameters are optional):

          function (item, index, enumerable);

    - *item* is the current item in the iteration.
    - *index* is the current index in the iteration
    - *enumerable* is the enumerable object itself.

    It should return the YES or NO.

    Note that in addition to a callback, you can also pass an optional target
    object that will be set as "this" on the context.  This is a good way
    to give your iterator function access to the current object.

    Example Usage:

          if (people.every(isEngineer)) { Paychecks.addBigBonus(); }

    @param {Function} callback the callback to execute
    @param {Object} target the target object to use
    @returns {Boolean}
  */
  every: function (callback, target) {
    if (typeof callback !== "function") throw new TypeError();
    var len = this.get ? this.get('length') : this.length;
    if (target === undefined) target = null;

    var ret  = YES;
    var last = null;
    var context = SC.Enumerator._popContext();
    for (var idx = 0;ret && (idx < len);idx++) {
      var next = this.nextObject(idx, last, context);
      if (!callback.call(target, next, idx, this)) ret = NO;
      last = next;
    }
    last = null;
    context = SC.Enumerator._pushContext(context);
    return ret;
  },

  /**
    Returns YES if the passed property resolves to true for all items in the
    enumerable.  This method is often simpler/faster than using a callback.

    @param {String} key the property to test
    @param {String} value optional value to test against.
    @returns {Array} filtered array
  */
  everyProperty: function (key, value) {
    var len = this.get ? this.get('length') : this.length;
    var ret  = YES;
    var last = null;
    var context = SC.Enumerator._popContext();
    for (var idx = 0;ret && (idx < len);idx++) {
      var next = this.nextObject(idx, last, context);
      var cur = next ? (next.get ? next.get(key) : next[key]) : null;
      ret = (value === undefined) ? !!cur : SC.isEqual(cur, value);
      last = next;
    }
    last = null;
    context = SC.Enumerator._pushContext(context);
    return ret;
  },


  /**
    Returns YES if the passed function returns true for any item in the
    enumeration. This corresponds with the every() method in JavaScript 1.6.

    The callback method you provide should have the following signature (all
    parameters are optional):

          function (item, index, enumerable);

    - *item* is the current item in the iteration.
    - *index* is the current index in the iteration
    - *enumerable* is the enumerable object itself.

    It should return the YES to include the item in the results, NO otherwise.

    Note that in addition to a callback, you can also pass an optional target
    object that will be set as "this" on the context.  This is a good way
    to give your iterator function access to the current object.

    Usage Example:

          if (people.some(isManager)) { Paychecks.addBiggerBonus(); }

    @param {Function} callback the callback to execute
    @param {Object} target the target object to use
    @returns {Boolean} YES
  */
  some: function (callback, target) {
    if (typeof callback !== "function") throw new TypeError();
    var len = this.get ? this.get('length') : this.length;
    if (target === undefined) target = null;

    var ret  = NO;
    var last = null;
    var context = SC.Enumerator._popContext();
    for (var idx = 0;(!ret) && (idx < len);idx++) {
      var next = this.nextObject(idx, last, context);
      if (callback.call(target, next, idx, this)) ret = YES;
      last = next;
    }
    last = null;
    context = SC.Enumerator._pushContext(context);
    return ret;
  },

  /**
    Returns YES if the passed property resolves to true for any item in the
    enumerable.  This method is often simpler/faster than using a callback.

    @param {String} key the property to test
    @param {String} value optional value to test against.
    @returns {Boolean} YES
  */
  someProperty: function (key, value) {
    var len = this.get ? this.get('length') : this.length;
    var ret  = NO;
    var last = null;
    var context = SC.Enumerator._popContext();
    for (var idx = 0; !ret && (idx < len); idx++) {
      var next = this.nextObject(idx, last, context);
      var cur = next ? (next.get ? next.get(key) : next[key]) : null;
      ret = (value === undefined) ? !!cur : SC.isEqual(cur, value);
      last = next;
    }
    last = null;
    context = SC.Enumerator._pushContext(context);
    return ret;  // return the invert
  },

  /**
    This will combine the values of the enumerator into a single value. It
    is a useful way to collect a summary value from an enumeration.  This
    corresponds to the reduce() method defined in JavaScript 1.8.

    The callback method you provide should have the following signature (all
    parameters are optional):

          function (previousValue, item, index, enumerable);

    - *previousValue* is the value returned by the last call to the iterator.
    - *item* is the current item in the iteration.
    - *index* is the current index in the iteration
    - *enumerable* is the enumerable object itself.

    Return the new cumulative value.

    In addition to the callback you can also pass an initialValue.  An error
    will be raised if you do not pass an initial value and the enumerator is
    empty.

    Note that unlike the other methods, this method does not allow you to
    pass a target object to set as this for the callback.  It's part of the
    spec. Sorry.

    @param {Function} callback the callback to execute
    @param {Object} initialValue initial value for the reduce
    @param {String} reducerProperty internal use only.  May not be available.
    @returns {Object} The reduced value.
  */
  reduce: function (callback, initialValue, reducerProperty) {
    if (typeof callback !== "function") throw new TypeError();
    var len = this.get ? this.get('length') : this.length;

    // no value to return if no initial value & empty
    if (len === 0 && initialValue === undefined) throw new TypeError();

    var ret  = initialValue;
    var last = null;
    var context = SC.Enumerator._popContext();
    for (var idx = 0; idx < len;idx++) {
      var next = this.nextObject(idx, last, context);

      // while ret is still undefined, just set the first value we get as ret.
      // this is not the ideal behavior actually but it matches the FireFox
      // implementation... :(
      if (next !== null) {
        if (ret === undefined) {
          ret = next;
        } else {
          ret = callback.call(null, ret, next, idx, this, reducerProperty);
        }
      }
      last = next;
    }
    last = null;
    context = SC.Enumerator._pushContext(context);

    // uh oh...we never found a value!
    if (ret === undefined) throw new TypeError();
    return ret;
  },

  /**
    Invokes the named method on every object in the receiver that
    implements it.  This method corresponds to the implementation in
    Prototype 1.6.

    @param {String} methodName the name of the method
    @param {Object...} args optional arguments to pass as well.
    @returns {Array} return values from calling invoke.
  */
  invoke: function (methodName) {
    var len = this.get ? this.get('length') : this.length;
    if (len <= 0) return []; // nothing to invoke....

    var idx;

    // collect the arguments
    var args = [];
    var alen = arguments.length;
    if (alen > 1) {
      for (idx = 1; idx < alen; idx++) args.push(arguments[idx]);
    }

    // call invoke
    var ret = [];
    var last = null;
    var context = SC.Enumerator._popContext();
    for (idx = 0; idx < len; idx++) {
      var next = this.nextObject(idx, last, context);
      var method = next ? next[methodName] : null;
      if (method) ret[idx] = method.apply(next, args);
      last = next;
    }
    last = null;
    context = SC.Enumerator._pushContext(context);
    return ret;
  },

  /**
    Invokes the passed method and optional arguments on the receiver elements
    as long as the methods return value matches the target value.  This is
    a useful way to attempt to apply changes to a collection of objects unless
    or until one fails.

    @param {Object} targetValue the target return value
    @param {String} methodName the name of the method
    @param {Object...} args optional arguments to pass as well.
    @returns {Array} return values from calling invoke.
  */
  invokeWhile: function (targetValue, methodName) {
    var len = this.get ? this.get('length') : this.length;
    if (len <= 0) return null; // nothing to invoke....

    var idx;

    // collect the arguments
    var args = [];
    var alen = arguments.length;
    if (alen > 2) {
      for (idx = 2; idx < alen; idx++) args.push(arguments[idx]);
    }

    // call invoke
    var ret = targetValue;
    var last = null;
    var context = SC.Enumerator._popContext();
    for (idx = 0; (ret === targetValue) && (idx < len); idx++) {
      var next = this.nextObject(idx, last, context);
      var method = next ? next[methodName] : null;
      if (method) ret = method.apply(next, args);
      last = next;
    }
    last = null;
    context = SC.Enumerator._pushContext(context);
    return ret;
  },

  /**
    Simply converts the enumerable into a genuine array.  The order, of
    course, is not gauranteed.  Corresponds to the method implemented by
    Prototype.

    @returns {Array} the enumerable as an array.
  */
  toArray: function () {
    var ret = [];
    this.forEach(function (o) { ret.push(o); }, this);
    return ret;
  },

  /**
    Converts an enumerable into a matrix, with inner arrays grouped based
    on a particular property of the elements of the enumerable.

    @param {String} key the property to test
    @returns {Array} matrix of arrays
  */
  groupBy: function (key) {
    var len = this.get ? this.get('length') : this.length,
        ret = [],
        last = null,
        context = SC.Enumerator._popContext(),
        grouped = [],
        keyValues = [],
        idx, next, cur;

    for (idx = 0; idx < len;idx++) {
      next = this.nextObject(idx, last, context);
      cur = next ? (next.get ? next.get(key) : next[key]) : null;
      if (SC.none(grouped[cur])) {
        grouped[cur] = [];
        keyValues.push(cur);
      }
      grouped[cur].push(next);
      last = next;
    }
    last = null;
    context = SC.Enumerator._pushContext(context);

    for (idx = 0, len = keyValues.length; idx < len; idx++) {
      ret.push(grouped[keyValues[idx]]);
    }
    return ret;
  }

};

// Build in a separate function to avoid unintentional leaks through closures...
SC._buildReducerFor = function (reducerKey, reducerProperty) {
  return function (key, value) {
    var reducer = this[reducerKey];
    if (SC.typeOf(reducer) !== SC.T_FUNCTION) {
      return this.unknownProperty ? this.unknownProperty(key, value) : null;
    } else {
      // Invoke the reduce method defined in enumerable instead of using the
      // one implemented in the receiver.  The receiver might be a native
      // implementation that does not support reducerProperty.
      var ret = SC.Enumerable.reduce.call(this, reducer, null, reducerProperty);
      return ret;
    }
  }.property('[]');
};

/** @class */
SC.Reducers = /** @scope SC.Reducers.prototype */ {
  /**
    This property will trigger anytime the enumerable's content changes.
    You can observe this property to be notified of changes to the enumerables
    content.

    For plain enumerables, this property is read only.  SC.Array overrides
    this method.

    @type SC.Array
  */
  '[]': function (key, value) { return this; }.property(),

  /**
    Invoke this method when the contents of your enumerable has changed.
    This will notify any observers watching for content changes.  If you are
    implementing an ordered enumerable (such as an Array), also pass the
    start and length values so that it can be used to notify range observers.
    Passing start and length values will also ensure that the computed
    properties `firstObject` and `lastObject` are updated.

    @param {Number} [start] start offset for the content change
    @param {Number} [length] length of change
    @param {Number} [deltas] if you added or removed objects, the delta change
    @returns {Object} receiver
  */
  enumerableContentDidChange: function (start, length, deltas) {
    // If the start & length are provided, we can also indicate if the firstObject
    // or lastObject properties changed, thus making them independently observable.
    if (!SC.none(start)) {
      if (start === 0) this.notifyPropertyChange('firstObject');
      if (!SC.none(length) && start + length >= this.get('length') - 1) this.notifyPropertyChange('lastObject');
    }

    this.notifyPropertyChange('[]');
  },

  /**
    Call this method from your unknownProperty() handler to implement
    automatic reduced properties.  A reduced property is a property that
    collects its contents dynamically from your array contents.  Reduced
    properties always begin with "@".  Getting this property will call
    reduce() on your array with the function matching the key name as the
    processor.

    The return value of this will be either the return value from the
    reduced property or undefined, which means this key is not a reduced
    property.  You can call this at the top of your unknownProperty handler
    like so:

      unknownProperty: function (key, value) {
        var ret = this.handleReduceProperty(key, value);
        if (ret === undefined) {
          // process like normal
        }
      }

    @param {String} key the reduce property key

    @param {Object} value a value or undefined.

    @param {Boolean} generateProperty only set to false if you do not want
      an optimized computed property handler generated for this.  Not common.

    @returns {Object} the reduced property or undefined
  */
  reducedProperty: function (key, value, generateProperty) {

    if (!key || typeof key !== SC.T_STRING || key.charAt(0) !== '@') return undefined; // not a reduced property

    // get the reducer key and the reducer
    var matches = key.match(/^@([^(]*)(\(([^)]*)\))?$/);
    if (!matches || matches.length < 2) return undefined; // no match

    var reducerKey = matches[1]; // = 'max' if key = '@max(balance)'
    var reducerProperty = matches[3]; // = 'balance' if key = '@max(balance)'
    reducerKey = "reduce" + reducerKey.slice(0, 1).toUpperCase() + reducerKey.slice(1);
    var reducer = this[reducerKey];

    // if there is no reduce function defined for this key, then we can't
    // build a reducer for it.
    if (SC.typeOf(reducer) !== SC.T_FUNCTION) return undefined;

    // if we can't generate the property, just run reduce
    if (generateProperty === NO) {
      return SC.Enumerable.reduce.call(this, reducer, null, reducerProperty);
    }

    // ok, found the reducer.  Let's build the computed property and install
    var func = SC._buildReducerFor(reducerKey, reducerProperty);
    var p = this.constructor.prototype;

    if (p) {
      p[key] = func;

      // add the function to the properties array so that new instances
      // will have their dependent key registered.
      var props = p._properties || [];
      props.push(key);
      p._properties = props;
      this.registerDependentKey(key, '[]');
    }

    // and reduce anyway...
    return SC.Enumerable.reduce.call(this, reducer, null, reducerProperty);
  },

  /**
    Reducer for @max reduced property.

    @param {Object} previousValue The previous value in the enumerable
    @param {Object} item The current value in the enumerable
    @param {Number} index The index of the current item in the enumerable
    @param {String} reducerProperty (Optional) The property in the enumerable being reduced

    @returns {Object} reduced value
  */
  reduceMax: function (previousValue, item, index, e, reducerProperty) {
    if (reducerProperty && item) {
      item = item.get ? item.get(reducerProperty) : item[reducerProperty];
    }
    if (previousValue === null) return item;
    return (item > previousValue) ? item : previousValue;
  },

  /**
    Reduces an enumerable to the max of the items in the enumerable. If
    reducerProperty is passed, it will reduce that property. Otherwise, it will
    reduce the item itself.

    @param {Object} previousValue The previous value in the enumerable
    @param {Object} item The current value in the enumerable
    @param {Number} index The index of the current item in the enumerable
    @param {String} reducerProperty (Optional) The property in the enumerable being reduced

    @returns {Object} reduced value
  */
  reduceMaxObject: function (previousItem, item, index, e, reducerProperty) {

    // get the value for both the previous and current item.  If no
    // reducerProperty was supplied, use the items themselves.
    var previousValue = previousItem, itemValue = item;
    if (reducerProperty) {
      if (item) {
        itemValue = item.get ? item.get(reducerProperty) : item[reducerProperty];
      }

      if (previousItem) {
        previousValue = previousItem.get ? previousItem.get(reducerProperty) : previousItem[reducerProperty];
      }
    }
    if (previousValue === null) return item;
    return (itemValue > previousValue) ? item : previousItem;
  },

  /**
    Reduces an enumerable to the min of the items in the enumerable. If
    reducerProperty is passed, it will reduce that property. Otherwise, it will
    reduce the item itself.

    @param {Object} previousValue The previous value in the enumerable
    @param {Object} item The current value in the enumerable
    @param {Number} index The index of the current item in the enumerable
    @param {String} reducerProperty (Optional) The property in the enumerable being reduced

    @returns {Object} reduced value
  */
  reduceMin: function (previousValue, item, index, e, reducerProperty) {
    if (reducerProperty && item) {
      item = item.get ? item.get(reducerProperty) : item[reducerProperty];
    }
    if (previousValue === null) return item;
    return (item < previousValue) ? item : previousValue;
  },

  /**
    Reduces an enumerable to the max of the items in the enumerable. If
    reducerProperty is passed, it will reduce that property. Otherwise, it will
    reduce the item itself.

    @param {Object} previousValue The previous value in the enumerable
    @param {Object} item The current value in the enumerable
    @param {Number} index The index of the current item in the enumerable
    @param {String} reducerProperty (Optional) The property in the enumerable being reduced

    @returns {Object} reduced value
  */
  reduceMinObject: function (previousItem, item, index, e, reducerProperty) {

    // get the value for both the previous and current item.  If no
    // reducerProperty was supplied, use the items themselves.
    var previousValue = previousItem, itemValue = item;
    if (reducerProperty) {
      if (item) {
        itemValue = item.get ? item.get(reducerProperty) : item[reducerProperty];
      }

      if (previousItem) {
        previousValue = previousItem.get ? previousItem.get(reducerProperty) : previousItem[reducerProperty];
      }
    }
    if (previousValue === null) return item;
    return (itemValue < previousValue) ? item : previousItem;
  },

  /**
    Reduces an enumerable to the average of the items in the enumerable. If
    reducerProperty is passed, it will reduce that property. Otherwise, it will
    reduce the item itself.

    @param {Object} previousValue The previous value in the enumerable
    @param {Object} item The current value in the enumerable
    @param {Number} index The index of the current item in the enumerable
    @param {String} reducerProperty (Optional) The property in the enumerable being reduced

    @returns {Object} reduced value
  */
  reduceAverage: function (previousValue, item, index, e, reducerProperty) {
    if (reducerProperty && item) {
      item = item.get ? item.get(reducerProperty) : item[reducerProperty];
    }
    var ret = (previousValue || 0) + item;
    var len = e.get ? e.get('length') : e.length;
    if (index >= len - 1) ret = ret / len; //avg after last item.
    return ret;
  },

  /**
    Reduces an enumerable to the sum of the items in the enumerable. If
    reducerProperty is passed, it will reduce that property. Otherwise, it will
    reduce the item itself.

    @param {Object} previousValue The previous value in the enumerable
    @param {Object} item The current value in the enumerable
    @param {Number} index The index of the current item in the enumerable
    @param {String} reducerProperty (Optional) The property in the enumerable being reduced

    @returns {Object} reduced value
  */
  reduceSum: function (previousValue, item, index, e, reducerProperty) {
    if (reducerProperty && item) {
      item = item.get ? item.get(reducerProperty) : item[reducerProperty];
    }
    return (previousValue === null) ? item : previousValue + item;
  }
};

// Apply reducers...
SC.mixin(SC.Enumerable, SC.Reducers);
SC.mixin(Array.prototype, SC.Reducers);
Array.prototype.isEnumerable = YES;

// ......................................................
// ARRAY SUPPORT
//

// Implement the same enhancements on Array.  We use specialized methods
// because working with arrays are so common.
(function () {

  // These methods will be applied even if they already exist b/c we do it
  // better.
  var alwaysMixin = {

    // this is supported so you can get an enumerator.  The rest of the
    // methods do not use this just to squeeze every last ounce of perf as
    // possible.
    nextObject: SC.Enumerable.nextObject,
    enumerator: SC.Enumerable.enumerator,
    firstObject: SC.Enumerable.firstObject,
    lastObject: SC.Enumerable.lastObject,
    sortProperty: SC.Enumerable.sortProperty,

    // see above...
    mapProperty: function (key) {
      var len = this.length;
      var ret  = [];
      for (var idx = 0; idx < len; idx++) {
        var next = this[idx];
        ret[idx] = next ? (next.get ? next.get(key) : next[key]) : null;
      }
      return ret;
    },

    filterProperty: function (key, value) {
      var len = this.length,
          ret = [],
          idx, item, cur;
      // Although the code for value and no value are almost identical, we want to make as many decisions outside
      // the loop as possible.
      if (value === undefined) {
        for (idx = 0; idx < len; idx++) {
          item = this[idx];
          cur = item ? (item.get ? item.get(key) : item[key]) : null;
          if (!!cur) ret.push(item);
        }
      } else {
        for (idx = 0; idx < len; idx++) {
          item = this[idx];
          cur = item ? (item.get ? item.get(key) : item[key]) : null;
          if (SC.isEqual(cur, value)) ret.push(item);
        }
      }
      return ret;
    },
    //returns a matrix
    groupBy: function (key) {
      var len = this.length,
          ret = [],
          grouped = [],
          keyValues = [],
          idx, next, cur;

      for (idx = 0; idx < len; idx++) {
        next = this[idx];
        cur = next ? (next.get ? next.get(key) : next[key]) : null;
        if (SC.none(grouped[cur])) { grouped[cur] = []; keyValues.push(cur); }
        grouped[cur].push(next);
      }

      for (idx = 0, len = keyValues.length; idx < len; idx++) {
        ret.push(grouped[keyValues[idx]]);
      }
      return ret;
    },

    find: function (callback, target) {
      if (typeof callback !== "function") throw new TypeError();
      var len = this.length;
      if (target === undefined) target = null;

      var next, ret = null, found = NO;
      for (var idx = 0; idx < len && !found; idx++) {
        next = this[idx];
        if (found = callback.call(target, next, idx, this)) ret = next;
      }
      next = null;
      return ret;
    },

    findProperty: function (key, value) {
      var len = this.length;
      var next, cur, found = NO, ret = null;
      for (var idx = 0; idx < len && !found; idx++) {
        cur = (next = this[idx]) ? (next.get ? next.get(key): next[key]):null;
        found = (value === undefined) ? !!cur : SC.isEqual(cur, value);
        if (found) ret = next;
      }
      next = null;
      return ret;
    },

    everyProperty: function (key, value) {
      var len = this.length;
      var ret  = YES;
      for (var idx = 0; ret && (idx < len); idx++) {
        var next = this[idx];
        var cur = next ? (next.get ? next.get(key) : next[key]) : null;
        ret = (value === undefined) ? !!cur : SC.isEqual(cur, value);
      }
      return ret;
    },

    someProperty: function (key, value) {
      var len = this.length;
      var ret  = NO;
      for (var idx = 0; !ret && (idx < len); idx++) {
        var next = this[idx];
        var cur = next ? (next.get ? next.get(key) : next[key]) : null;
        ret = (value === undefined) ? !!cur : SC.isEqual(cur, value);
      }
      return ret;  // return the invert
    },

    invoke: function (methodName) {
      var len = this.length;
      if (len <= 0) return []; // nothing to invoke....

      var idx;

      // collect the arguments
      var args = [];
      var alen = arguments.length;
      if (alen > 1) {
        for (idx = 1; idx < alen; idx++) args.push(arguments[idx]);
      }

      // call invoke
      var ret = [];
      for (idx = 0; idx < len; idx++) {
        var next = this[idx];
        var method = next ? next[methodName] : null;
        if (method) ret[idx] = method.apply(next, args);
      }
      return ret;
    },

    invokeWhile: function (targetValue, methodName) {
      var len = this.length;
      if (len <= 0) return null; // nothing to invoke....

      var idx;

      // collect the arguments
      var args = [];
      var alen = arguments.length;
      if (alen > 2) {
        for (idx = 2; idx < alen; idx++) args.push(arguments[idx]);
      }

      // call invoke
      var ret = targetValue;
      for (idx = 0; (ret === targetValue) && (idx < len); idx++) {
        var next = this[idx];
        var method = next ? next[methodName] : null;
        if (method) ret = method.apply(next, args);
      }
      return ret;
    },

    toArray: function () {
      var len = this.length;
      if (len <= 0) return []; // nothing to invoke....

      // call invoke
      var ret = [];
      for (var idx = 0; idx < len; idx++) {
        var next = this[idx];
        ret.push(next);
      }
      return ret;
    },

    getEach: function (key) {
      var ret = [];
      var len = this.length;
      for (var idx = 0; idx < len; idx++) {
        var obj = this[idx];
        ret[idx] = obj ? (obj.get ? obj.get(key) : obj[key]) : null;
      }
      return ret;
    },

    setEach: function (key, value) {
      var len = this.length;
      for (var idx = 0; idx < len; idx++) {
        var obj = this[idx];
        if (obj) {
          if (obj.set) {
            obj.set(key, value);
          } else obj[key] = value;
        }
      }
      return this;
    }

  };

  // These methods will only be applied if they are not already defined b/c
  // the browser is probably getting it.
  var mixinIfMissing = {

    // QUESTION: The lack of DRY is burning my eyes [YK]
    forEach: function (callback, target) {
      if (typeof callback !== "function") throw new TypeError();

      // QUESTION: Is this necessary?
      if (target === undefined) target = null;

      for (var i = 0, l = this.length; i < l; i++) {
        var next = this[i];
        callback.call(target, next, i, this);
      }
      return this;
    },

    map: function (callback, target) {
      if (typeof callback !== "function") throw new TypeError();

      if (target === undefined) target = null;

      var ret = [];
      for (var i = 0, l = this.length; i < l; i++) {
        var next = this[i];
        ret[i] = callback.call(target, next, i, this);
      }
      return ret;
    },

    filter: function (callback, target) {
      if (typeof callback !== "function") throw new TypeError();

      if (target === undefined) target = null;

      var ret = [];
      for (var i = 0, l = this.length; i < l; i++) {
        var next = this[i];
        if (callback.call(target, next, i, this)) ret.push(next);
      }
      return ret;
    },

    every: function (callback, target) {
      if (typeof callback !== "function") throw new TypeError();
      var len = this.length;
      if (target === undefined) target = null;

      var ret  = YES;
      for (var idx = 0; ret && (idx < len); idx++) {
        var next = this[idx];
        if (!callback.call(target, next, idx, this)) ret = NO;
      }
      return ret;
    },

    some: function (callback, target) {
      if (typeof callback !== "function") throw new TypeError();
      var len = this.length;
      if (target === undefined) target = null;

      var ret  = NO;
      for (var idx = 0; (!ret) && (idx < len); idx++) {
        var next = this[idx];
        if (callback.call(target, next, idx, this)) ret = YES;
      }
      return ret;
    },

    reduce: function (callback, initialValue, reducerProperty) {
      if (typeof callback !== "function") throw new TypeError();
      var len = this.length;

      // no value to return if no initial value & empty
      if (len === 0 && initialValue === undefined) throw new TypeError();

      var ret  = initialValue;
      for (var idx = 0; idx < len; idx++) {
        var next = this[idx];

        // while ret is still undefined, just set the first value we get as
        // ret. this is not the ideal behavior actually but it matches the
        // FireFox implementation... :(
        if (next !== null) {
          if (ret === undefined) {
            ret = next;
          } else {
            ret = callback.call(null, ret, next, idx, this, reducerProperty);
          }
        }
      }

      // uh oh...we never found a value!
      if (ret === undefined) throw new TypeError();
      return ret;
    }
  };

  // Apply methods if missing...
  for (var key in mixinIfMissing) {
    if (!mixinIfMissing.hasOwnProperty(key)) continue;

    // The mixinIfMissing methods should be applied if they are not defined.
    // If Prototype 1.6 is included, some of these methods will be defined
    // already, but we want to override them anyway in this special case
    // because our version is faster and functionally identical.
    if (!Array.prototype[key] || ((typeof Prototype === 'object') && Prototype.Version.match(/^1\.6/))) {
      Array.prototype[key] = mixinIfMissing[key];
    }
  }

  // Apply other methods...
  SC.mixin(Array.prototype, alwaysMixin);

})();


/* >>>>>>>>>> BEGIN source/system/range_observer.js */
// ==========================================================================
// Project:   SproutCore Costello - Property Observing Library
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


/** @class

  A RangeObserver is used by Arrays to automatically observe all of the
  objects in a particular range on the array.  Whenever any property on one
  of those objects changes, it will notify its delegate.  Likewise, whenever
  the contents of the array itself changes, it will notify its delegate and
  possibly update its own registration.

  This implementation uses only SC.Array methods.  It can be used on any
  object that complies with SC.Array.  You may, however, choose to subclass
  this object in a way that is more optimized for your particular design.

  @since SproutCore 1.0
*/
SC.RangeObserver = /** @scope SC.RangeObserver.prototype */{

  /**
    Walk like a duck.

    @type Boolean
  */
  isRangeObserver: YES,

  /** @private */
  toString: function() {
    var base = this.indexes ? this.indexes.toString() : "SC.IndexSet<..>";
    return base.replace('IndexSet', 'RangeObserver(%@)'.fmt(SC.guidFor(this)));
  },

  /**
    Creates a new range observer owned by the source.  The indexSet you pass
    must identify the indexes you are interested in observing.  The passed
    target/method will be invoked whenever the observed range changes.

    Note that changes to a range are buffered until the end of a run loop
    unless a property on the record itself changes.

    @param {SC.Array} source the source array
    @param {SC.IndexSet} indexSet set of indexes to observer
    @param {Object} target the target
    @param {Function|String} method the method to invoke
    @param {Object} context optional context to include in callback
    @param {Boolean} isDeep if YES, observe property changes as well
    @returns {SC.RangeObserver} instance
  */
  create: function(source, indexSet, target, method, context, isDeep) {
    var ret = SC.beget(this);
    ret.source = source;
    ret.indexes = indexSet ? indexSet.frozenCopy() : null;
    ret.target = target;
    ret.method = (typeof method === 'string') ? target[method] : method;
    ret.context = context ;
    ret.isDeep  = isDeep || false ;
    ret.beginObserving();
    return ret ;
  },

  /**
    Create subclasses for the RangeObserver.  Pass one or more attribute
    hashes.  Use this to create customized RangeObservers if needed for your
    classes.

    @param {Hash} attrs one or more attribute hashes
    @returns {SC.RangeObserver} extended range observer class
  */
  extend: function(attrs) {
    var ret = SC.beget(this), args = arguments;
    for(var i=0, l=args.length; i<l; i++) { SC.mixin(ret, args[i]); }
    return ret ;
  },

  /**
    Destroys an active ranger observer, cleaning up first.

    @param {SC.Array} source the source array
    @returns {SC.RangeObserver} receiver
  */
  destroy: function(source) {
    this.endObserving();
    return this;
  },

  /**
    Updates the set of indexes the range observer applies to.  This will
    stop observing the old objects for changes and start observing the
    new objects instead.

    @param {SC.Array} source the source array
    @param {SC.IndexSet} indexSet The index set representing the change
    @returns {SC.RangeObserver} receiver
  */
  update: function(source, indexSet) {
    if (this.indexes && this.indexes.isEqual(indexSet)) { return this ; }

    this.indexes = indexSet ? indexSet.frozenCopy() : null ;
    this.endObserving().beginObserving();
    return this;
  },

  /**
    Configures observing for each item in the current range.  Should update
    the observing array with the list of observed objects so they can be
    torn down later

    @returns {SC.RangeObserver} receiver
  */
  beginObserving: function() {
    if ( !this.isDeep ) { return this; } // nothing to do

    var observing = this.observing = this.observing || SC.CoreSet.create();

    // cache iterator function to keep things fast
    var func = this._beginObservingForEach, source = this.source;

    if( !func ) {
      func = this._beginObservingForEach = function(idx) {
        var obj = source.objectAt(idx);
        if (obj && obj.addObserver) {
          observing.push(obj);
          obj._kvo_needsRangeObserver = true ;
        }
      };
    }

    this.indexes.forEach(func);

    // add to pending range observers queue so that if any of these objects
    // change we will have a chance to setup observing on them.
    this.isObserving = false ;
    SC.Observers.addPendingRangeObserver(this);

    return this;
  },

  /** @private
    Called when an object that appears to need range observers has changed.
    Check to see if the range observer contains this object in its list.  If
    it does, go ahead and setup observers on all objects and remove ourself
    from the queue.
  */
  setupPending: function(object) {
    var observing = this.observing ;

    if ( this.isObserving || !observing || (observing.get('length')===0) ) {
      return true ;
    }

    if (observing.contains(object)) {
      this.isObserving = true ;

      // cache iterator function to keep things fast
      var func = this._setupPendingForEach;
      if (!func) {
        var source = this.source,
            method = this.objectPropertyDidChange,
            self   = this;

        func = this._setupPendingForEach = function(idx) {
          var obj = source.objectAt(idx),
              guid = SC.guidFor(obj),
              key ;

          if (obj && obj.addObserver) {
            observing.push(obj);
            obj.addObserver('*', self, method);

            // also save idx of object on range observer itself.  If there is
            // more than one idx, convert to IndexSet.
            key = self[guid];
            if ( key == null ) {
              self[guid] = idx ;
            } else if (key.isIndexSet) {
              key.add(idx);
            } else {
              self[guid] = SC.IndexSet.create(key).add(idx);
            }

          }
        };
      }
      this.indexes.forEach(func);
      return true ;
    } else {
      return false ;
    }
  },

  /**
    Remove observers for any objects currently begin observed.  This is
    called whenever the observed range changes due to an array change or
    due to destroying the observer.

    @returns {SC.RangeObserver} receiver
  */
  endObserving: function() {
    if ( !this.isDeep ) return this; // nothing to do

    var observing = this.observing;

    if (this.isObserving) {
      var meth      = this.objectPropertyDidChange,
          source    = this.source,
          idx, lim, obj;

      if (observing) {
        lim = observing.length;
        for(idx=0;idx<lim;idx++) {
          obj = observing[idx];
          obj.removeObserver('*', this, meth);
          this[SC.guidFor(obj)] = null;
        }
        observing.length = 0 ; // reset
      }

      this.isObserving = false ;
    }

    if (observing) { observing.clear(); } // empty set.
    return this ;
  },

  /**
    Whenever the actual objects in the range changes, notify the delegate
    then begin observing again.  Usually this method will be passed an
    IndexSet with the changed indexes.  The range observer will only notify
    its delegate if the changed indexes include some of all of the indexes
    this range observer is monitoring.

    @param {SC.IndexSet} changes optional set of changed indexes
    @returns {SC.RangeObserver} receiver
  */
  rangeDidChange: function(changes) {
    var indexes = this.indexes;
    if ( !changes || !indexes || indexes.intersects(changes) ) {
      this.endObserving(); // remove old observers
      this.method.call(this.target, this.source, null, '[]', changes, this.context);
      this.beginObserving(); // setup new ones
    }
    return this ;
  },

  /**
    Whenever an object changes, notify the delegate

    @param {Object} the object that changed
    @param {String} key the property that changed
    @param {Null} value No longer used
    @param {Number} rev The revision of the change
    @returns {SC.RangeObserver} receiver
  */
  objectPropertyDidChange: function(object, key, value, rev) {
    var context = this.context,
        method  = this.method,
        guid    = SC.guidFor(object),
        index   = this[guid];

    // lazily convert index to IndexSet.
    if ( index && !index.isIndexSet ) {
      index = this[guid] = SC.IndexSet.create(index).freeze();
    }

    method.call(this.target, this.source, object, key, index, context || rev, rev);
  }

};

/* >>>>>>>>>> BEGIN source/mixins/array.js */
// ==========================================================================
// Project:   SproutCore Costello - Property Observing Library
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

// note: SC.Observable also enhances array.  make sure we are called after
// SC.Observable so our version of unknownProperty wins.
sc_require('ext/function');
sc_require('mixins/observable');
sc_require('mixins/enumerable');
sc_require('system/range_observer');

SC.OUT_OF_RANGE_EXCEPTION = "Index out of range";

SC.CoreArray = /** @lends SC.Array.prototype */ {

  /**
    Walk like a duck - use isSCArray to avoid conflicts
    @type Boolean
  */
  isSCArray: YES,

  /**
    @field {Number} length

    Your array must support the length property.  Your replace methods should
    set this property whenever it changes.
  */
  // length: 0,

  /**
    This is one of the primitives you must implement to support SC.Array.  You
    should replace amt objects started at idx with the objects in the passed
    array.

    Before mutating the underlying data structure, you must call
    this.arrayContentWillChange(). After the mutation is complete, you must
    call arrayContentDidChange().

    NOTE: JavaScript arrays already implement SC.Array and automatically call
    the correct callbacks.

    @param {Number} idx
      Starting index in the array to replace.  If idx >= length, then append to
      the end of the array.

    @param {Number} amt
      Number of elements that should be removed from the array, starting at
      *idx*.

    @param {Array} objects
      An array of zero or more objects that should be inserted into the array at
      *idx*
  */
  replace: function (idx, amt, objects) {
    throw new Error("replace() must be implemented to support SC.Array");
  },

  /**
    Returns the index for a particular object in the index.

    @param {Object} object the item to search for
    @param {Number} startAt optional starting location to search, default 0
    @returns {Number} index of -1 if not found
  */
  indexOf: function (object, startAt) {
    var idx, len = this.get('length');

    if (startAt === undefined) startAt = 0;
    else startAt = (startAt < 0) ? Math.ceil(startAt) : Math.floor(startAt);
    if (startAt < 0) startAt += len;

    for (idx = startAt; idx < len; idx++) {
      if (this.objectAt(idx, YES) === object) return idx;
    }
    return -1;
  },

  /**
    Returns the last index for a particular object in the index.

    @param {Object} object the item to search for
    @param {Number} startAt optional starting location to search, default 0
    @returns {Number} index of -1 if not found
  */
  lastIndexOf: function (object, startAt) {
    var idx, len = this.get('length');

    if (startAt === undefined) startAt = len - 1;
    else startAt = (startAt < 0) ? Math.ceil(startAt) : Math.floor(startAt);
    if (startAt < 0) startAt += len;

    for (idx = startAt; idx >= 0; idx--) {
      if (this.objectAt(idx) === object) return idx;
    }
    return -1;
  },

  /**
    This is one of the primitives you must implement to support SC.Array.
    Returns the object at the named index.  If your object supports retrieving
    the value of an array item using get() (i.e. myArray.get(0)), then you do
    not need to implement this method yourself.

    @param {Number} idx
      The index of the item to return.  If idx exceeds the current length,
      return null.
  */
  objectAt: function (idx) {
    if (idx < 0) return undefined;
    if (idx >= this.get('length')) return undefined;
    return this.get(idx);
  },

  /**
    @field []

    This is the handler for the special array content property.  If you get
    this property, it will return this.  If you set this property it a new
    array, it will replace the current content.

    This property overrides the default property defined in SC.Enumerable.
  */
  '[]': function (key, value) {
    if (value !== undefined) {
      this.replace(0, this.get('length'), value);
    }
    return this;
  }.property(),

  /**
    This will use the primitive replace() method to insert an object at the
    specified index.

    @param {Number} idx index of insert the object at.
    @param {Object} object object to insert
  */
  insertAt: function (idx, object) {
    if (idx > this.get('length')) throw new Error(SC.OUT_OF_RANGE_EXCEPTION);
    this.replace(idx, 0, [object]);
    return this;
  },

  /**
    Remove an object at the specified index using the replace() primitive
    method.  You can pass either a single index, a start and a length or an
    index set.

    If you pass a single index or a start and length that is beyond the
    length this method will throw an SC.OUT_OF_RANGE_EXCEPTION

    @param {Number|SC.IndexSet} start index, start of range, or index set
    @param {Number} length length of passing range
    @returns {Object} receiver
  */
  removeAt: function (start, length) {
    var delta = 0, // used to shift range
        empty = [];

    if (typeof start === SC.T_NUMBER) {

      if ((start < 0) || (start >= this.get('length'))) {
        throw new Error(SC.OUT_OF_RANGE_EXCEPTION);
      }

      // fast case
      if (length === undefined) {
        this.replace(start, 1, empty);
        return this;
      } else {
        start = SC.IndexSet.create(start, length);
      }
    }

    this.beginPropertyChanges();
    start.forEachRange(function (start, length) {
      start -= delta;
      delta += length;
      this.replace(start, length, empty); // remove!
    }, this);
    this.endPropertyChanges();

    return this;
  },

  /**
    Search the array of this object, removing any occurrences of it.
    @param {object} obj object to remove
  */
  removeObject: function (obj) {
    var loc = this.get('length') || 0;
    while (--loc >= 0) {
      var curObject = this.objectAt(loc);
      if (curObject === obj) this.removeAt(loc);
    }
    return this;
  },

  /**
    Search the array for the passed set of objects and remove any occurrences
    of the.

    @param {SC.Enumerable} objects the objects to remove
    @returns {SC.Array} receiver
  */
  removeObjects: function (objects) {
    this.beginPropertyChanges();
    objects.forEach(function (obj) { this.removeObject(obj); }, this);
    this.endPropertyChanges();
    return this;
  },

  /**
    Returns a new array that is a slice of the receiver.  This implementation
    uses the observable array methods to retrieve the objects for the new
    slice.

    If you don't pass in beginIndex and endIndex, it will act as a copy of the
    array.

    @param beginIndex {Integer} (Optional) index to begin slicing from.
    @param endIndex {Integer} (Optional) index to end the slice at.
    @returns {Array} New array with specified slice
  */
  slice: function (beginIndex, endIndex) {
    var ret = [];
    var length = this.get('length');
    if (SC.none(beginIndex)) beginIndex = 0;
    if (SC.none(endIndex) || (endIndex > length)) endIndex = length;
    while (beginIndex < endIndex) ret[ret.length] = this.objectAt(beginIndex++);
    return ret;
  },

  /**
    Push the object onto the end of the array.  Works just like push() but it
    is KVO-compliant.

    @param {Object} object the objects to push

    @return {Object} The passed object
  */
  pushObject: function (obj) {
    this.insertAt(this.get('length'), obj);
    return obj;
  },


  /**
    Add the objects in the passed numerable to the end of the array.  Defers
    notifying observers of the change until all objects are added.

    @param {SC.Enumerable} objects the objects to add
    @returns {SC.Array} receiver
  */
  pushObjects: function (objects) {
    this.beginPropertyChanges();
    objects.forEach(function (obj) { this.pushObject(obj); }, this);
    this.endPropertyChanges();
    return this;
  },

  /**
    Pop object from array or nil if none are left.  Works just like pop() but
    it is KVO-compliant.

    @return {Object} The popped object
  */
  popObject: function () {
    var len = this.get('length');
    if (len === 0) return null;

    var ret = this.objectAt(len - 1);
    this.removeAt(len - 1);
    return ret;
  },

  /**
    Shift an object from start of array or nil if none are left.  Works just
    like shift() but it is KVO-compliant.

    @return {Object} The shifted object
  */
  shiftObject: function () {
    if (this.get('length') === 0) return null;
    var ret = this.objectAt(0);
    this.removeAt(0);
    return ret;
  },

  /**
    Unshift an object to start of array.  Works just like unshift() but it is
    KVO-compliant.

    @param {Object} obj the object to add
    @return {Object} The passed object
  */
  unshiftObject: function (obj) {
    this.insertAt(0, obj);
    return obj;
  },

  /**
    Adds the named objects to the beginning of the array.  Defers notifying
    observers until all objects have been added.

    @param {SC.Enumerable} objects the objects to add
    @returns {SC.Array} receiver
  */
  unshiftObjects: function (objects) {
    this.beginPropertyChanges();
    objects.forEach(function (obj) { this.unshiftObject(obj); }, this);
    this.endPropertyChanges();
    return this;
  },

  /**
    Compares each item in the passed array to this one.

    @param {Array} ary The array you want to compare to
    @returns {Boolean} true if they are equal.
  */
  isEqual: function (ary) {
    if (!ary) return false;
    if (ary == this) return true;

    var loc = ary.get('length');
    if (loc != this.get('length')) return false;

    while (--loc >= 0) {
      if (!SC.isEqual(ary.objectAt(loc), this.objectAt(loc))) return false;
    }
    return true;
  },

  /**
    Generates a new array with the contents of the old array, sans any null
    values.

    @returns {Array} The new, compact array
  */
  compact: function () { return this.without(null); },

  /**
    Generates a new array with the contents of the old array, sans the passed
    value.

    @param {Object} value The value you want to be removed
    @returns {Array} The new, filtered array
  */
  without: function (value) {
    if (this.indexOf(value) < 0) return this; // value not present.
    var ret = [];
    this.forEach(function (k) {
      if (k !== value) ret[ret.length] = k;
    });
    return ret;
  },

  /**
    Generates a new array with only unique values from the contents of the
    old array.

    @returns {Array} The new, de-duped array
  */
  uniq: function () {
    var ret = [];
    this.forEach(function (k) {
      if (ret.indexOf(k) < 0) ret[ret.length] = k;
    });
    return ret;
  },

  /**
    Returns a new array that is a one-dimensional flattening of this array,
    i.e. for every element of this array extract that and it's elements into
    a new array.

    @returns {Array}
   */
  flatten: function () {
    var ret = [];
    this.forEach(function (k) {
      if (k && k.isEnumerable) {
        ret = ret.pushObjects(k.flatten());
      } else {
        ret.pushObject(k);
      }
    });
    return ret;
  },

  /**
    Returns the largest Number in an array of Numbers. Make sure the array
    only contains values of type Number to get expected result.

    Note: This only works for dense arrays.

    @returns {Number}
  */
  max: function () {
    return Math.max.apply(Math, this);
  },

  /**
    Returns the smallest Number in an array of Numbers. Make sure the array
    only contains values of type Number to get expected result.

    Note: This only works for dense arrays.

    @returns {Number}
  */
  min: function () {
    return Math.min.apply(Math, this);
  },

  rangeObserverClass: SC.RangeObserver,

  /**
    Returns YES if object is in the array

    @param {Object} object to look for
    @returns {Boolean}
  */
  contains: function (obj) {
    return this.indexOf(obj) >= 0;
  },

  /**
    Creates a new range observer on the receiver.  The target/method callback
    you provide will be invoked anytime any property on the objects in the
    specified range changes.  It will also be invoked if the objects in the
    range itself changes also.

    The callback for a range observer should have the signature:

          function rangePropertyDidChange(array, objects, key, indexes, context)

    If the passed key is '[]' it means that the object itself changed.

    The return value from this method is an opaque reference to the
    range observer object.  You can use this reference to destroy the
    range observer when you are done with it or to update its range.

    @param {SC.IndexSet} indexes indexes to observe
    @param {Object} target object to invoke on change
    @param {String|Function} method the method to invoke
    @param {Object} context optional context
    @returns {SC.RangeObserver} range observer
  */
  addRangeObserver: function (indexes, target, method, context) {
    var rangeob = this._array_rangeObservers;
    if (!rangeob) rangeob = this._array_rangeObservers = SC.CoreSet.create();

    // The first time a range observer is added, cache the current length so
    // we can properly notify observers the first time through
    if (this._array_oldLength === undefined) {
      this._array_oldLength = this.get('length');
    }

    var C = this.rangeObserverClass;
    var isDeep = NO; //disable this feature for now
    var ret = C.create(this, indexes, target, method, context, isDeep);
    rangeob.add(ret);

    // first time a range observer is added, begin observing the [] property
    if (!this._array_isNotifyingRangeObservers) {
      this._array_isNotifyingRangeObservers = YES;
      this.addObserver('[]', this, this._array_notifyRangeObservers);
    }

    return ret;
  },

  /**
    Moves a range observer so that it observes a new range of objects on the
    array.  You must have an existing range observer object from a call to
    addRangeObserver().

    The return value should replace the old range observer object that you
    pass in.

    @param {SC.RangeObserver} rangeObserver the range observer
    @param {SC.IndexSet} indexes new indexes to observe
    @returns {SC.RangeObserver} the range observer (or a new one)
  */
  updateRangeObserver: function (rangeObserver, indexes) {
    return rangeObserver.update(this, indexes);
  },

  /**
    Removes a range observer from the receiver.  The range observer must
    already be active on the array.

    The return value should replace the old range observer object.  It will
    usually be null.

    @param {SC.RangeObserver} rangeObserver the range observer
    @returns {SC.RangeObserver} updated range observer or null
  */
  removeRangeObserver: function (rangeObserver) {
    var ret = rangeObserver.destroy(this);
    var rangeob = this._array_rangeObservers;
    if (rangeob) rangeob.remove(rangeObserver); // clear
    return ret;
  },

  addArrayObservers: function (options) {
    this._modifyObserverSet('add', options);
  },

  removeArrayObservers: function (options) {
    this._modifyObserverSet('remove', options);
  },

  _modifyObserverSet: function (method, options) {
    var willChangeObservers, didChangeObservers;

    var target     = options.target || this;
    var willChange = options.willChange || 'arrayWillChange';
    var didChange  = options.didChange || 'arrayDidChange';
    var context    = options.context;

    if (typeof willChange === "string") {
      willChange = target[willChange];
    }

    if (typeof didChange === "string") {
      didChange = target[didChange];
    }

    willChangeObservers = this._kvo_for('_kvo_array_will_change', SC.ObserverSet);
    didChangeObservers  = this._kvo_for('_kvo_array_did_change', SC.ObserverSet);

    willChangeObservers[method](target, willChange, context);
    didChangeObservers[method](target, didChange, context);
  },

  arrayContentWillChange: function (start, removedCount, addedCount) {
    this._teardownContentObservers(start, removedCount);

    var member, members, membersLen, idx;
    var target, action;
    var willChangeObservers = this._kvo_array_will_change;
    if (willChangeObservers) {
      members = willChangeObservers.members;
      membersLen = members.length;

      for (idx = 0; idx < membersLen; idx++) {
        member = members[idx];
        target = member[0];
        action = member[1];
        action.call(target, start, removedCount, addedCount, this);
      }
    }
  },

  arrayContentDidChange: function (start, removedCount, addedCount) {
    var rangeob = this._array_rangeObservers,
      length, changes;

    this.beginPropertyChanges();
    this.notifyPropertyChange('length'); // flush caches

    // schedule info for range observers
    if (rangeob && rangeob.length > 0) {
      changes = this._array_rangeChanges;
      if (!changes) { changes = this._array_rangeChanges = SC.IndexSet.create(); }
      if (removedCount === addedCount) {
        length = removedCount;
      } else {
        length = this.get('length') - start;

        if (removedCount > addedCount) {
          length += (removedCount - addedCount);
        }
      }
      changes.add(start, length);
    }

    this._setupContentObservers(start, addedCount);

    var member, members, membersLen, idx;
    var target, action;
    var didChangeObservers = this._kvo_array_did_change;
    if (didChangeObservers) {
      // If arrayContentDidChange is called with no parameters, assume the
      // entire array has changed.
      if (start === undefined) {
        start = 0;
        removedCount = this.get('length');
        addedCount = 0;
      }

      members = didChangeObservers.members;
      membersLen = members.length;

      for (idx = 0; idx < membersLen; idx++) {
        member = members[idx];
        target = member[0];
        action = member[1];
        action.call(target, start, removedCount, addedCount, this);
      }
    }

    this.enumerableContentDidChange(start, addedCount, addedCount - removedCount);
    this.endPropertyChanges();

    return this;
  },

  /**
    @private

    When enumerable content has changed, remove enumerable observers from
    items that are no longer in the enumerable, and add observers to newly
    added items.

    @param {Array} addedObjects the array of objects that have been added
    @param {Array} removedObjects the array of objects that have been removed
  */
  _setupContentObservers: function (start, addedCount) {
    var observedKeys = this._kvo_for('_kvo_content_observed_keys', SC.CoreSet);
    var addedObjects;
    var kvoKey;

    // Only setup and teardown enumerable observers if we have keys to observe
    if (observedKeys.get('length') > 0) {
      addedObjects = this.slice(start, start + addedCount);

      var self = this;
      // added and resume the chain observer.
      observedKeys.forEach(function (key) {
        kvoKey = SC.keyFor('_kvo_content_observers', key);

        // Get all original ChainObservers associated with the key
        self._kvo_for(kvoKey).forEach(function (observer) {
          addedObjects.forEach(function (item) {
            self._resumeChainObservingForItemWithChainObserver(item, observer);
          });
        });
      });
    }
  },

  _teardownContentObservers: function (start, removedCount) {
    var observedKeys = this._kvo_for('_kvo_content_observed_keys', SC.CoreSet);
    var removedObjects;
    var kvoKey;

    // Only setup and teardown enumerable observers if we have keys to observe
    if (observedKeys.get('length') > 0) {
      removedObjects = this.slice(start, start + removedCount);

      // added and resume the chain observer.
      observedKeys.forEach(function (key) {
        kvoKey = SC.keyFor('_kvo_content_observers', key);

        // Loop through removed objects and remove any enumerable observers that
        // belong to them.
        removedObjects.forEach(function (item) {
          item._kvo_for(kvoKey).forEach(function (observer) {
            observer.destroyChain();
          });
        });
      });
    }
  },

  teardownEnumerablePropertyChains: function (removedObjects) {
    var chains = this._kvo_enumerable_property_chains;

    if (chains) {
      chains.forEach(function (chain) {
        var idx, len = removedObjects.get('length'),
            chainGuid = SC.guidFor(chain),
            clonedChain, item, kvoChainList = '_kvo_enumerable_property_clones';

        chain.notifyPropertyDidChange();

        for (idx = 0; idx < len; idx++) {
          item = removedObjects.objectAt(idx);
          clonedChain = item[kvoChainList][chainGuid];
          clonedChain.deactivate();
          delete item[kvoChainList][chainGuid];
        }
      }, this);
    }
    return this;
  },

  /**
    For all registered property chains on this object, removed them from objects
    being removed from the enumerable, and clone them onto newly added objects.

    @param {Object[]} addedObjects the objects being added to the enumerable
    @param {Object[]} removedObjects the objected being removed from the enumerable
    @returns {Object} receiver
  */
  setupEnumerablePropertyChains: function (addedObjects) {
    var chains = this._kvo_enumerable_property_chains;

    if (chains) {
      chains.forEach(function (chain) {
        var idx, len = addedObjects.get('length');

        chain.notifyPropertyDidChange();

        len = addedObjects.get('length');
        for (idx = 0; idx < len; idx++) {
          this._clonePropertyChainToItem(chain, addedObjects.objectAt(idx));
        }
      }, this);
    }
    return this;
  },

  /**
    Register a property chain to propagate to enumerable content.

    This will clone the property chain to each item in the enumerable,
    then save it so that it is automatically set up and torn down when
    the enumerable content changes.

    @param {String} property the property being listened for on this object
    @param {SC._PropertyChain} chain the chain to clone to items
  */
  registerDependentKeyWithChain: function (property, chain) {
    // Get the set of all existing property chains that should
    // be propagated to enumerable contents. If that set doesn't
    // exist yet, _kvo_for() will create it.
    var kvoChainList = '_kvo_enumerable_property_chains',
        chains;

    chains = this._kvo_for(kvoChainList, SC.CoreSet);

    // Save a reference to the chain on this object. If new objects
    // are added to the enumerable, we will clone this chain and add
    // it to the new object.
    chains.add(chain);

    this.forEach(function (item) {
      this._clonePropertyChainToItem(chain, item);
    }, this);
  },

  /**
    Clones an SC._PropertyChain to a content item.

    @param {SC._PropertyChain} chain
    @param {Object} item
  */
  _clonePropertyChainToItem: function (chain, item) {
    var clone        = SC.clone(chain),
        kvoCloneList = '_kvo_enumerable_property_clones',
        cloneList;

    clone.object = item;

    cloneList = item[kvoCloneList] = item[kvoCloneList] || {};
    cloneList[SC.guidFor(chain)] = clone;

    clone.activate(item);
  },

  /**
    Removes a dependent key from the enumerable, and tears it down on
    all content objects.

    @param {String} property
    @param {SC._PropertyChain} chain
  */
  removeDependentKeyWithChain: function (property, chain) {
    var kvoCloneList = '_kvo_enumerable_property_clones',
        clone, cloneList;

    this.forEach(function (item) {
      item.removeDependentKeyWithChain(property, chain);

      cloneList = item[kvoCloneList];
      clone = cloneList[SC.guidFor(chain)];

      clone.deactivate(item);
    }, this);
  },

  /**
    @private

    Clones a segment of an observer chain and applies it
    to an element of this Enumerable.

    @param {Object} item The element
    @param {SC._ChainObserver} chainObserver the chain segment to begin from
  */
  _resumeChainObservingForItemWithChainObserver: function (item, chainObserver) {
    var observer = SC.clone(chainObserver.next);
    var key = observer.property;

    // The chain observer should create new observers on the child object
    observer.object = item;
    item.addObserver(key, observer, observer.propertyDidChange);

    // if we're in the initial chained observer setup phase, add the tail
    // of the current observer segment to the list of tracked tails.
    if (chainObserver.root.tails) {
      chainObserver.root.tails.pushObject(observer.tail());
    }


    // Maintain a list of observers on the item so we can remove them
    // if it is removed from the enumerable.
    item._kvo_for(SC.keyFor('_kvo_content_observers', key)).push(observer);
  },

  /**
    @private

    Adds a content observer. Content observers are able to
    propagate chain observers to each member item in the enumerable,
    so that the observer is fired whenever a single item changes.

    You should never call this method directly. Instead, you should
    call addObserver() with the special '@each' property in the path.

    For example, if you wanted to observe changes to each item's isDone
    property, you could call:

        arrayController.addObserver('@each.isDone');

    @param {SC._ChainObserver} chainObserver the chain observer to propagate
  */
  _addContentObserver: function (chainObserver) {
    var key = chainObserver.next.property;

    // Add the key to a set so we know what we are observing
    this._kvo_for('_kvo_content_observed_keys', SC.CoreSet).push(key);

    // Add the passed ChainObserver to an ObserverSet for that key
    var kvoKey = SC.keyFor('_kvo_content_observers', key);
    this._kvo_for(kvoKey).push(chainObserver);

    // Add an observer on the '[]' property of this array.
    var observer = chainObserver.tail();
    this.addObserver('[]', observer, observer.propertyDidChange);

    // Set up chained observers on the initial content
    this._setupContentObservers(0, chainObserver.object.get('length'));
  },

  /**
    @private

    Removes a content observer. Pass the same chain observer
    that was used to add the content observer.

    @param {SC._ChainObserver} chainObserver the chain observer to propagate
  */

  _removeContentObserver: function (chainObserver) {
    var observers, kvoKey;
    var observedKeys = this._kvo_content_observed_keys;
    var key = chainObserver.next.property;

    // Clean up the observer on the '[]' property of this array.
    var observer = chainObserver.tail();
    this.removeObserver('[]', observer, observer.propertyDidChange);

    if (observedKeys.contains(key)) {

      kvoKey = SC.keyFor('_kvo_content_observers', key);
      observers = this._kvo_for(kvoKey);

      observers.removeObject(chainObserver);

      this._teardownContentObservers(0, chainObserver.object.get('length'));

      if (observers.length === 0) {
        this._kvo_for('_kvo_content_observed_keys').remove(key);
      }
    }
  },

  /**  @private
    Observer fires whenever the '[]' property changes.  If there are
    range observers, will notify observers of change.
  */
  _array_notifyRangeObservers: function () {
    var rangeob = this._array_rangeObservers,
        changes = this._array_rangeChanges,
        len     = rangeob ? rangeob.length : 0,
        idx;

    if (len > 0 && changes && changes.length > 0) {
      for (idx = 0; idx < len; idx++) rangeob[idx].rangeDidChange(changes);
      changes.clear(); // reset for later notifications
    }
  }

};

/**
  @namespace

  This module implements Observer-friendly Array-like behavior.  This mixin is
  picked up by the Array class as well as other controllers, etc. that want to
  appear to be arrays.

  Unlike SC.Enumerable, this mixin defines methods specifically for
  collections that provide index-ordered access to their contents.  When you
  are designing code that needs to accept any kind of Array-like object, you
  should use these methods instead of Array primitives because these will
  properly notify observers of changes to the array.

  Although these methods are efficient, they do add a layer of indirection to
  your application so it is a good idea to use them only when you need the
  flexibility of using both true JavaScript arrays and "virtual" arrays such
  as controllers and collections.

  You can use the methods defined in this module to access and modify array
  contents in a KVO-friendly way.  You can also be notified whenever the
  membership if an array changes by changing the syntax of the property to
  .observes('*myProperty.[]') .

  To support SC.Array in your own class, you must override two
  primitives to use it: replace() and objectAt().

  Note that the SC.Array mixin also incorporates the SC.Enumerable mixin.  All
  SC.Array-like objects are also enumerable.

  @extends SC.Enumerable
  @since SproutCore 0.9.0
*/
SC.Array = SC.mixin({}, SC.Enumerable, SC.CoreArray);

/* >>>>>>>>>> BEGIN source/ext/array.js */
// ==========================================================================
// Project:   SproutCore Costello - Property Observing Library
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('mixins/array');

SC.supplement(Array.prototype, SC.CoreArray);

// Because Arrays are dealt with so much, we add specialized functions.

SC.mixin(Array.prototype,
  /** @lends Array.prototype */ {

  // primitive for array support.
  replace: function (idx, amt, objects) {
    if (this.isFrozen) { throw new Error(SC.FROZEN_ERROR); }

    var args;
    var len = objects ? (objects.get ? objects.get('length') : objects.length) : 0;

    // Notify that array content is about to mutate.
    this.arrayContentWillChange(idx, amt, len);

    if (len === 0) {
      this.splice(idx, amt);
    } else {
      args = [idx, amt].concat(objects);
      this.splice.apply(this, args);
    }

    this.arrayContentDidChange(idx, amt, len);

    return this;
  },

  // If you ask for an unknown property, then try to collect the value
  // from member items.
  unknownProperty: function (key, value) {
    var ret = this.reducedProperty(key, value);
    if ((value !== undefined) && ret === undefined) {
      ret = this[key] = value;
    }
    return ret;
  }

});

if (Array.prototype.indexOf === SC.CoreArray.indexOf) {
  /**
    Returns the index for a particular object in the index.

    @param {Object} object the item to search for
    @param {Number} startAt optional starting location to search, default 0
    @returns {Number} index of -1 if not found
  */
  Array.prototype.indexOf = function (object, startAt) {
    var idx, len = this.length;

    if (startAt === undefined) startAt = 0;
    else startAt = (startAt < 0) ? Math.ceil(startAt) : Math.floor(startAt);
    if (startAt < 0) startAt += len;

    for (idx = startAt; idx < len; idx++) {
      if (this[idx] === object) return idx;
    }
    return -1;
  };
}

if (Array.prototype.lastIndexOf === SC.CoreArray.lastIndexOf) {
  /**
    Returns the last index for a particular object in the index.

    @param {Object} object the item to search for
    @param {Number} startAt optional starting location to search, default 0
    @returns {Number} index of -1 if not found
  */
  Array.prototype.lastIndexOf = function (object, startAt) {
    var idx, len = this.length;

    if (startAt === undefined) startAt = len - 1;
    else startAt = (startAt < 0) ? Math.ceil(startAt) : Math.floor(startAt);
    if (startAt < 0) startAt += len;

    for (idx = startAt; idx >= 0; idx--) {
      if (this[idx] === object) return idx;
    }
    return -1;
  };
}

/* >>>>>>>>>> BEGIN source/ext/date.js */
// ==========================================================================
// Project:   SproutCore Costello - Property Observing Library
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

if (!Date.now) {
  /**
    @ignore
  */
  Date.now = function() {
    return new Date().getTime() ;
  };
}

/* >>>>>>>>>> BEGIN source/ext/number.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

SC.supplement(Number.prototype, {

  /**
   * Returns the ordinal associated for the current number:
   *
   * eg: 1 => 'st', 2 => 'nd'
   *
   *
   * If the current Locale exists (which it almost always does except for in
   * testing) we try and delegate to it. Otherwise we use this inner anonymous
   * function (to prevent further mucking with the prototype)
   *
   */
  ordinal: function () {
    // FAST PATH: If we have a localization, use its ordinals.
    if (SC.Locale) {
      return SC.Locale.currentLocale.ordinalForNumber(this);
    }

    // Otherwise, fall back on a basic (en) implementation (e.g. in testing, or as
    // the datetime framework only requires the runtime framework).
    var d = this % 10;
    return (~~(this % 100 / 10) === 1) ? 'th' :
      (d === 1) ? 'st' :
        (d === 2) ? 'nd' :
          (d === 3) ? 'rd' : 'th';
  }

});
/* >>>>>>>>>> BEGIN source/system/string.js */
// ==========================================================================
// Project:   SproutCore Costello - Property Observing Library
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @class

  Implements support methods useful when working with strings in SproutCore
  applications.
*/
SC.String = /** @scope SC.String.prototype */ {

  /**
    This finds the value for a key in a formatting string.

    Keys take the form:

        key[:argument to formatter]
  */
  _scs_valueForKey: function(key, data, /* for debugging purposes: */ string) {
    var arg, value, formatter, argsplit = key.indexOf(':');
    if (argsplit > -1) {
      arg = key.substr(argsplit + 1);
      key = key.substr(0, argsplit);
    }

    value = data.get ? data.get(key): data[key];
    formatter = data[key + 'Formatter'];

    // formatters are optional
    if (formatter) value = formatter(value, arg);
    else if (arg) {
      throw new Error("String.fmt was given a formatting string, but key `" + key + "` has no formatter! String: " + string);
    }

    return value;
  },

  /**
    Formats a string. You can format either with named parameters or
    indexed, but not both.

    Indexed Parameters
    --------------------
    Indexed parameters are just arguments you pass into format. For example:

        "%@1 %@3 %@2".fmt(1, 2, 3)

        // -> "1 3 2"

    If you don't supply a number, it will use them in the order you supplied. For example:

        "%@, %@".fmt("Iskander", "Alex")

        // -> "Iskander, Alex"

    Named Paramters
    --------------------
    You can use named parameters like this:

        "Value: %{key_name}".fmt({ key_name: "A Value" })

        // -> "Value: A Value"

    You can supply formatters for each field. A formatter is a method to get applied
    to the parameter:

        Currency = function(v) { return "$" + v; };
        "Value: %{val}".fmt({ val: 12.00, valFormatter: Currency })

        // -> $12.00

    Formatters can also use arguments:

        Currency = function(v, sign) { return sign + v; };
        "Value: %{val:£}".fmt({ val: 12.00, valFormatter: Currency })

        // -> £12.00

    You can supply a different formatter for each named parameter. Formatters can ONLY be
    used with named parameters (not indexed parameters).

  */
  fmt: function(string, args) {
    var i = 0, data, hasHadNamedArguments;
    if (args) {
      data = args[0];
    }

    return string.replace(/%\{(.*?)\}/g, function(match, propertyPath) {
      hasHadNamedArguments = YES;
      if (!data) {
        throw new Error("Cannot use named parameters with `fmt` without a data hash. String: '" + string + "'");
      }

      var ret = SC.String._scs_valueForKey(propertyPath, data, string);
      // If a value was found, return that; otherwise return the original matched text to retain it in the string
      // for future formatting.
      if (!SC.none(ret)) { return ret; }
      else { return match; }
    }).replace(/%@([0-9]+)?/g, function(match, index) {
      if (hasHadNamedArguments) {
        throw new Error("Invalid attempt to use both named parameters and indexed parameters. String: '" + string + "'");
      }
      index = index ? parseInt(index, 10) - 1 : i++;
      if(args[index]!==undefined) return args[index];
      else return "";
    });
  },

  /**
    Splits the string into words, separated by spaces. Empty strings are
    removed from the results.

    @returns {Array} An array of non-empty strings
  */
  w: function(str) {
    var ary = [], ary2 = str.split(' '), len = ary2.length, string, idx=0;
    for (idx=0; idx<len; ++idx) {
      string = ary2[idx] ;
      if (string.length !== 0) ary.push(string) ; // skip empty strings
    }
    return ary ;
  }
};

/* >>>>>>>>>> BEGIN source/ext/string.js */
// ==========================================================================
// Project:   SproutCore Costello - Property Observing Library
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('system/string');

/** 
  @namespace
  Extends String by adding a few helpful methods.
*/
SC.mixin(String.prototype,
/** @scope String.prototype */ {

  /**
    @see SC.String.fmt
  */
  fmt: function() {
    return SC.String.fmt(this, arguments);
  },

  /**
    @see SC.String.w
  */
  w: function() {
    return SC.String.w(this);
  }

});

/* >>>>>>>>>> BEGIN source/ext/window.js */
/**
  Polyfills!
*/

// window.performance
(function() {
  // TODO: Include polyfill for node.js
  if (window && typeof window.performance === 'undefined') {
    window.performance = {};
  }

  if (window && !window.performance.now) {
    var initTimestamp;
    if (window.performance.timing && window.performance.timing.navigationStart) {
      initTimestamp = window.performance.timing.navigationStart;
    } else {
      window.performance.timing = {};
      initTimestamp = window.performance.timing.navigationStart = Date.now ? Date.now() : (new Date()).getTime();
    }
    window.performance.now = function() {
      var now = Date.now ? Date.now() : (new Date()).getTime();
      return now - initTimestamp;
    };
  }
})();

/* >>>>>>>>>> BEGIN source/mixins/comparable.js */
// ==========================================================================
// Project:   SproutCore Costello - Property Observing Library
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @class

  Implements some standard methods for comparing objects. Add this mixin to
  any class you create that can compare its instances.

  You should implement the compare() method.

  @since SproutCore 1.0
*/
SC.Comparable = {

  /**
    walk like a duck. Indicates that the object can be compared.

    @type Boolean
  */
  isComparable: YES,

  /**
    Override to return the result of the comparison of the two parameters. The
    compare method should return
    
    <pre>
      -1 if a < b
       0 if a == b
       1 if a > b
    </pre>


    Default implementation raises an exception.

    @param a {Object} the first object to compare
    @param b {Object} the second object to compare
    @returns {Integer} the result of the comparison
  */
  compare: function(a, b) {
    throw new Error("%@.compare() is not implemented".fmt(this.toString()));
  }

};

/* >>>>>>>>>> BEGIN source/mixins/copyable.js */
// ==========================================================================
// Project:   SproutCore Costello - Property Observing Library
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @class

  Implements some standard methods for copying an object.  Add this mixin to
  any object you create that can create a copy of itself.  This mixin is
  added automatically to the built-in array.

  You should generally implement the copy() method to return a copy of the
  receiver.

  Note that frozenCopy() will only work if you also implement SC.Freezable.

  @since SproutCore 1.0
*/
SC.Copyable = /** @scope SC.Copyable.prototype */{

  /**
    Walk like a duck.  Indicates that the object can be copied.

    @type Boolean
  */
  isCopyable: YES,

  /**
    Override to return a copy of the receiver.  Default implementation raises
    an exception.

    @param deep {Boolean} if true, a deep copy of the object should be made
    @returns {Object} copy of receiver
  */
  copy: function(deep) {
    var className = SC._object_className(this.constructor);
    throw new Error("%@.copy() is not implemented".fmt(className));
  },

  /**
    If the object implements SC.Freezable, then this will return a new copy
    if the object is not frozen and the receiver if the object is frozen.

    Raises an exception if you try to call this method on a object that does
    not support freezing.

    You should use this method whenever you want a copy of a freezable object
    since a freezable object can simply return itself without actually
    consuming more memory.

    @returns {Object} copy of receiver or receiver
  */
  frozenCopy: function() {
    var isFrozen = this.get ? this.get('isFrozen') : this.isFrozen;
    if (isFrozen === YES) return this;
    else if (isFrozen === undefined) throw new Error("%@ does not support freezing".fmt(this));
    else return this.copy().freeze();
  }
};

// Make Array copyable
SC.mixin(Array.prototype, SC.Copyable);
/**
  Override to return a copy of the receiver.  Default implementation raises
  an exception.

  @param deep {Boolean} if true, a deep copy of the object should be made
  @returns {Object} copy of receiver
*/
Array.prototype.copy = function(deep) {
	var ret = this.slice(), idx;
	if (deep) {
      idx = ret.length;
	  while (idx--) ret[idx] = SC.copy(ret[idx], true);
	}
	return ret;
};

/* >>>>>>>>>> BEGIN source/mixins/freezable.js */
// ==========================================================================
// Project:   SproutCore Costello - Property Observing Library
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


/**
  Standard Error that should be raised when you try to modify a frozen object.

  @type Error
*/
SC.FROZEN_ERROR = "Cannot modify a frozen object";

/**
  @class

  The SC.Freezable mixin implements some basic methods for marking an object
  as frozen.  Once an object is frozen it should be read only.  No changes
  may be made the internal state of the object.

  Enforcement
  ---

  To fully support freezing in your subclass, you must include this mixin and
  override any method that might alter any property on the object to instead
  raise an exception.  You can check the state of an object by checking the
  isFrozen property.

  Although future versions of JavaScript may support language-level freezing
  object objects, that is not the case today.  Even if an object is freezable,
  it is still technically possible to modify the object, even though it could
  break other parts of your application that do not expect a frozen object to
  change.  It is, therefore, very important that you always respect the
  isFrozen property on all freezable objects.

  Example

  The example below shows a simple object that implement the SC.Freezable
  protocol.

        Contact = SC.Object.extend(SC.Freezable, {

          firstName: null,

          lastName: null,

          // swaps the names
          swapNames: function() {
            if (this.get('isFrozen')) throw new Error(SC.FROZEN_ERROR);
            var tmp = this.get('firstName');
            this.set('firstName', this.get('lastName'));
            this.set('lastName', tmp);
            return this;
          }

        });

        c = Context.create({ firstName: "John", lastName: "Doe" });
        c.swapNames();  => returns c
        c.freeze();
        c.swapNames();  => EXCEPTION

  Copying
  ---

  Usually the SC.Freezable protocol is implemented in cooperation with the
  SC.Copyable protocol, which defines a frozenCopy() method that will return
  a frozen object, if the object implements this method as well.

*/
SC.Freezable = /** @scope SC.Freezable.prototype */ {

  /**
    Walk like a duck.

    @type Boolean
  */
  isFreezable: YES,

  /**
    Set to YES when the object is frozen.  Use this property to detect whether
    your object is frozen or not.

    @type Boolean
  */
  isFrozen: NO,

  /**
    Freezes the object.  Once this method has been called the object should
    no longer allow any properties to be edited.

    @returns {Object} receiver
  */
  freeze: function() {
    // NOTE: Once someone actually implements Object.freeze() in the browser,
    // add a call to that here also.

    if (this.set) this.set('isFrozen', YES);
    else this.isFrozen = YES;
    return this;
  }

};


// Add to Array
SC.mixin(Array.prototype, SC.Freezable);

/* >>>>>>>>>> BEGIN source/mixins/tree.js */
// ==========================================================================
// Project:   SproutCore Costello - Property Observing Library
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/** @private */
SC.Tree = /** @scope SC.Tree.prototype */ {

  /** @private Call the method recursively on all child views. */
  invoke: function (methodName, isTopDown, context) {
    var childView,
      childViews = this.get('childViews'),
      method,
      shouldContinue;

    for (var i = childViews.length - 1; i >= 0; i--) {
      childView = childViews[i];

      // We allow missing childViews in the array so ignore them.
      if (!childView) { continue; }

      // Look up the method on the child.
      method = childView[methodName];

      // Call the method on this view *before* its children.
      if (isTopDown === undefined || isTopDown) {
        shouldContinue = method.call(childView, context);
      }

      // Recurse.
      if (shouldContinue === undefined || shouldContinue) {
        childView._callOnChildViews(methodName, isTopDown, context);
      }

      // Call the method on this view *after* its children.
      if (isTopDown === false) {
        method.call(childView, context);
      }
    }
  }

};

/* >>>>>>>>>> BEGIN source/system/set.js */
// ==========================================================================
// Project:   SproutCore Costello - Property Observing Library
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('mixins/enumerable') ;
sc_require('mixins/observable') ;
sc_require('mixins/freezable');
sc_require('mixins/copyable');

// IMPORTANT NOTE:  This file actually defines two classes:
// SC.Set is a fully observable set class documented below.
// SC.CoreSet is just like SC.Set but is not observable.  This is required
// because SC.Observable is built on using sets and requires sets without
// observability.
//
// We use pointer swizzling below to swap around the actual definitions so
// that the documentation will turn out right.  (The docs should only
// define SC.Set - not SC.CoreSet)

/**
  @class

  An unordered collection of objects.

  A Set works a bit like an array except that its items are not ordered.
  You can create a set to efficiently test for membership for an object. You
  can also iterate through a set just like an array, even accessing objects
  by index, however there is no gaurantee as to their order.

  Whether or not property observing is enabled, sets offer very powerful
  notifications of items being added and removed, through the
  `:addSetObserver` and `:removeSetObserver` methods; this can be
  very useful, for instance, for filtering or mapping sets.

  Note that SC.Set is a primitive object, like an array.  It does implement
  limited key-value observing support, but it does not extend from SC.Object
  so you should not subclass it.

  Creating a Set
  --------------
  You can create a set like you would most objects using SC.Set.create().
  Most new sets you create will be empty, but you can also initialize the set
  with some content by passing an array or other enumerable of objects to the
  constructor.

  Finally, you can pass in an existing set and the set will be copied.  You
  can also create a copy of a set by calling SC.Set#clone().

        // creates a new empty set
        var foundNames = SC.Set.create();

        // creates a set with four names in it.
        var names = SC.Set.create(["Charles", "Tom", "Juan", "Alex"]);

        // creates a copy of the names set.
        var namesCopy = SC.Set.create(names);

        // same as above.
        var anotherNamesCopy = names.clone();

  Adding/Removing Objects
  -----------------------
  You generally add or remove objects from a set using add() or remove().
  You can add any type of object including primitives such as numbers,
  strings, and booleans.

  Note that objects can only exist one time in a set.  If you call add() on
  a set with the same object multiple times, the object will only be added
  once.  Likewise, calling remove() with the same object multiple times will
  remove the object the first time and have no effect on future calls until
  you add the object to the set again.

  Note that you cannot add/remove null or undefined to a set.  Any attempt to
  do so will be ignored.

  In addition to add/remove you can also call push()/pop().  Push behaves just
  like add() but pop(), unlike remove() will pick an arbitrary object, remove
  it and return it.  This is a good way to use a set as a job queue when you
  don't care which order the jobs are executed in.

  Testing for an Object
  ---------------------
  To test for an object's presence in a set you simply call SC.Set#contains().
  This method tests for the object's hash, which is generally the same as the
  object's guid; however, if you implement the hash() method on the object, it will
  use the return value from that method instead.

  Observing changes
  -----------------
  When using `:SC.Set` (rather than `:SC.CoreSet`), you can observe the
  `:"[]"` property to be alerted whenever the content changes.

  This is often unhelpful. If you are filtering sets of objects, for instance,
  it is very inefficient to re-filter all of the items each time the set changes.
  It would be better if you could just adjust the filtered set based on what
  was changed on the original set. The same issue applies to merging sets,
  as well.

  `:SC.Set` and `:SC.CoreSet` both offer another method of being observed:
  `:addSetObserver` and `:removeSetObserver`. These take a single parameter:
  an object which implements `:didAddItem(set, item)` and
  `:didRemoveItem(set, item)`.

  Whenever an item is added or removed from the set, all objects in the set
  (a SC.CoreSet, actually) of observing objects will be alerted appropriately.

  BIG WARNING
  ===========
  SetObservers are not intended to be used "_creatively_"; for instance, do
  not expect to be alerted immediately to any changes. **While the notifications
  are currently sent out immediately, if we find a fast way to send them at end
  of run loop, we most likely will do so.**

  @extends SC.Enumerable
  @extends SC.Observable
  @extends SC.Copyable
  @extends SC.Freezable

  @since SproutCore 1.0
*/
SC.Set = SC.mixin({},
  SC.Observable,
  SC.Enumerable,
  SC.Freezable,
/** @scope SC.Set.prototype */ {

  /**
    Creates a new set, with the optional array of items included in the
    return set.

    @param {SC.Enumerable} items items to add
    @return {SC.Set}
  */
  create: function(items) {
    var ret, idx, pool = SC.Set._pool, isObservable = this.isObservable, len;
    if (!isObservable && items===undefined && pool.length>0) {
      return pool.pop();
    } else {
      ret = SC.beget(this);
      if (isObservable) ret.initObservable();

      if (items && items.isEnumerable && items.get('length') > 0) {

        ret.isObservable = NO; // suspend change notifications

        // arrays and sets get special treatment to make them a bit faster
        if (items.isSCArray) {
          len = items.get('length');
          for(idx = 0; idx < len; idx++) ret.add(items.objectAt(idx));

        } else if (items.isSet) {
          len = items.length;
          for(idx = 0; idx < len; idx++) ret.add(items[idx]);

        // otherwise use standard SC.Enumerable API
        } else {
          items.forEach(function(i) { ret.add(i); }, this);
        }

        ret.isObservable = isObservable;
      }
    }
    return ret ;
  },

  /**
    Walk like a duck

    @type Boolean
  */
  isSet: YES,

  /**
    This property will change as the number of objects in the set changes.

    @type Number
  */
  length: 0,

  /**
    Returns the first object in the set or null if the set is empty

    @type Object
  */
  firstObject: function() {
    return (this.length > 0) ? this[0] : undefined ;
  }.property(),

  /**
    Clears the set

    @returns {SC.Set}
  */
  clear: function() {
    if (this.isFrozen) throw new Error(SC.FROZEN_ERROR);
    this.length = 0;

    return this;
  },

  /**
    Call this method to test for membership.

    @returns {Boolean}
  */
  contains: function(obj) {

    // because of the way a set is "reset", the guid for an object may
    // still be stored as a key, but points to an index that is beyond the
    // length.  Therefore the found idx must both be defined and less than
    // the current length.
    if (obj === null) return NO ;
    var idx = this[SC.hashFor(obj)] ;
    return (!SC.none(idx) && (idx < this.length) && (this[idx]===obj)) ;
  },

  /**
    Returns YES if the passed object is also a set that contains the same
    objects as the receiver.

    @param {SC.Set} obj the other object
    @returns {Boolean}
  */
  isEqual: function(obj) {
    // fail fast
    if (!obj || !obj.isSet || (obj.get('length') !== this.get('length'))) {
      return NO ;
    }

    var loc = this.get('length');
    while(--loc>=0) {
      if (!obj.contains(this[loc])) return NO ;
    }

    return YES;
  },

  /**
    Adds a set observers. Set observers must implement two methods:

    - didAddItem(set, item)
    - didRemoveItem(set, item)

    Set observers are, in fact, stored in another set (a CoreSet).
  */
  addSetObserver: function(setObserver) {
    // create set observer set if needed
    if (!this.setObservers) {
      this.setObservers = SC.CoreSet.create();
    }

    // add
    this.setObservers.add(setObserver);
  },

  /**
    Removes a set observer.
  */
  removeSetObserver: function(setObserver) {
    // if there is no set, there can be no currently observing set observers
    if (!this.setObservers) return;

    // remove the set observer. Pretty simple, if you think about it.
    this.setObservers.remove(setObserver);
  },

  /**
    Call this method to add an object. performs a basic add.

    If the object is already in the set it will not be added again.

    @param {Object} obj the object to add
    @returns {SC.Set} receiver
  */
  add: function(obj) {
    if (this.isFrozen) throw new Error(SC.FROZEN_ERROR);

    // Implementation note:  SC.none() and SC.hashFor() is inlined because sets are
    // fundamental in SproutCore, and the inlined code is ~ 25% faster than
    // calling SC.hashFor() in IE8.

    // Cannot add null to a set.
    if (obj === null || obj === undefined) return this;

    var hashFunc,
        guid = ((hashFunc = obj.hash) && (typeof hashFunc === "function")) ? hashFunc.call(obj) : SC.guidFor(obj),
        idx  = this[guid],
        len  = this.length;

    if ((idx >= len) || (this[idx] !== obj)) {
      this[len] = obj;
      this[guid] = len;
      this.length = len + 1;
      if (this.setObservers) this.didAddItem(obj);
    }

    if (this.isObservable) this.enumerableContentDidChange();

    return this;
  },

  /**
    Add all the items in the passed array or enumerable

    @param {Array} objects
    @returns {SC.Set} receiver
  */
  addEach: function(objects) {
    if (this.isFrozen) throw new Error(SC.FROZEN_ERROR);
    if (!objects || !objects.isEnumerable) {
      throw new Error("%@.addEach must pass enumerable".fmt(this));
    }

    var idx, isObservable = this.isObservable ;

    if (isObservable) this.beginPropertyChanges();
    if (objects.isSCArray) {
      idx = objects.get('length');
      while(--idx >= 0) this.add(objects.objectAt(idx)) ;
    } else if (objects.isSet) {
      idx = objects.length;
      while(--idx>=0) this.add(objects[idx]);

    } else objects.forEach(function(i) { this.add(i); }, this);
    if (isObservable) this.endPropertyChanges();

    return this ;
  },

  /**
    Removes the object from the set if it is found.

    If the object is not in the set, nothing will be changed.

    @param {Object} obj the object to remove
    @returns {SC.Set} receiver
  */
  remove: function(obj) {
    if (this.isFrozen) throw new Error(SC.FROZEN_ERROR);

    // Implementation note:  SC.none() and SC.hashFor() are inlined because
    // sets are fundamental in SproutCore, and the inlined code is ~ 25%
    // faster than calling them "normally" in IE8.
    if (obj === null || obj === undefined) return this ;

    var hashFunc,
        guid = (obj && (hashFunc = obj.hash) && (typeof hashFunc === SC.T_FUNCTION)) ? hashFunc.call(obj) : SC.guidFor(obj),
        idx  = this[guid],
        len  = this.length,
        tmp;

    // not in set.
    // (SC.none is inlined for the reasons given above)
    if ((idx === null || idx === undefined) || (idx >= len) || (this[idx] !== obj)) return this;

    // clear the guid key
    delete this[guid];

    // to clear the index, we will swap the object stored in the last index.
    // if this is the last object, just reduce the length.
    if (idx < (len-1)) {
      // we need to keep a reference to "obj" so we can alert others below;
      // so, no changing it. Instead, create a temporary variable.
      tmp = this[idx] = this[len-1];
      guid = (tmp && (hashFunc = tmp.hash) && (typeof hashFunc === SC.T_FUNCTION)) ? hashFunc.call(tmp) : SC.guidFor(tmp);
      this[guid] = idx;
    }

    // Throw away the last object (it has been moved or is the object we are removing).
    delete this[len-1];
    this.length = len-1;

    if (this.isObservable) this.enumerableContentDidChange();
    if (this.setObservers) this.didRemoveItem(obj);

    return this ;
  },

  /**
    Removes an arbitrary object from the set and returns it.

    @returns {Object} an object from the set or null
  */
  pop: function() {
    if (this.isFrozen) throw new Error(SC.FROZEN_ERROR);
    var obj = (this.length > 0) ? this[this.length-1] : null ;
    this.remove(obj) ;
    return obj ;
  },

  /**
    Removes all the items in the passed array.

    @param {Array} objects
    @returns {SC.Set} receiver
  */
  removeEach: function(objects) {
    if (this.isFrozen) throw new Error(SC.FROZEN_ERROR);
    if (!objects || !objects.isEnumerable) {
      throw new Error("%@.addEach must pass enumerable".fmt(this));
    }

    var idx, isObservable = this.isObservable ;

    if (isObservable) this.beginPropertyChanges();
    if (objects.isSCArray) {
      idx = objects.get('length');
      while(--idx >= 0) this.remove(objects.objectAt(idx)) ;
    } else if (objects.isSet) {
      idx = objects.length;
      while(--idx>=0) this.remove(objects[idx]);
    } else objects.forEach(function(i) { this.remove(i); }, this);
    if (isObservable) this.endPropertyChanges();

    return this ;
  },

  /**
   Clones the set into a new set.

    @returns {SC.Set} new copy
  */
  copy: function() {
    return this.constructor.create(this);
  },

  /**
    Return a set to the pool for reallocation.

    @returns {SC.Set} receiver
  */
  destroy: function() {
    this.isFrozen = NO; // unfreeze to return to pool

    if (!this.isObservable) SC.Set._pool.push(this.clear());

    return this;
  },

  // .......................................
  // PRIVATE
  //

  /** @private - optimized */
  forEach: function(iterator, target) {
    var len = this.length;

    if (!target) target = this;
    for (var idx = 0; idx < len; idx++) iterator.call(target, this[idx], idx, this);
    return this ;
  },

  /** @private */
  toString: function() {
    var len = this.length, idx, ary = [];
    for (idx = 0; idx < len; idx++) ary[idx] = this[idx];
    return "SC.Set<%@>".fmt(ary.join(',')) ;
  },

  /**
    @private
    Alerts set observers that an item has been added.
  */
  didAddItem: function(item) {
    // get the set observers
    var o = this.setObservers;

    // return if there aren't any
    if (!o) return;

    // loop through and call didAddItem.
    var len = o.length, idx;
    for (idx = 0; idx < len; idx++) o[idx].didAddItem(this, item);
  },

  /**
    @private
    Alerts set observers that an item has been removed.
  */
  didRemoveItem: function(item) {
    // get the set observers
    var o = this.setObservers;

    // return if there aren't any
    if (!o) return;

    // loop through and call didAddItem.
    var len = o.length, idx;
    for (idx = 0; idx < len; idx++) o[idx].didRemoveItem(this, item);
  },

  /** @private */
  isObservable: YES

});

SC.Set.constructor = SC.Set;

// Make SC.Set look a bit more like other enumerables

/** @private */
SC.Set.clone = SC.Set.copy;

/** @private */
SC.Set.push = SC.Set.unshift = SC.Set.add;

/** @private */
SC.Set.shift = SC.Set.pop;

// add generic add/remove enumerable support

/** @private */
SC.Set.addObject = SC.Set.add;

/** @private */
SC.Set.removeObject = SC.Set.remove;

SC.Set._pool = [];

// ..........................................................
// CORE SET
//

/** @class

  CoreSet is just like Set but not observable.  If you want to use the set
  as a simple data structure with no observing, CoreSet is slightly faster
  and more memory efficient.

  @extends SC.Set
  @since SproutCore 1.0
*/
SC.CoreSet = SC.beget(SC.Set);

/** @private */
SC.CoreSet.isObservable = NO;

/** @private */
SC.CoreSet.constructor = SC.CoreSet;

/* >>>>>>>>>> BEGIN source/private/observer_queue.js */
// ==========================================================================
// Project:   SproutCore Costello - Property Observing Library
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('mixins/observable');
sc_require('system/set');

// ........................................................................
// OBSERVER QUEUE
//
// This queue is used to hold observers when the object you tried to observe
// does not exist yet.  This queue is flushed just before any property
// notification is sent.

/**
  @namespace

  The private ObserverQueue is used to maintain a set of pending observers.
  This allows you to setup an observer on an object before the object exists.

  Whenever the observer fires, the queue will be flushed to connect any
  pending observers.

  @private
  @since SproutCore 1.0
*/
SC.Observers = {

  queue: [],

  /**
   @private

   Attempt to add the named observer.  If the observer cannot be found, put
   it into a queue for later.
  */
  addObserver: function(propertyPath, target, method, pathRoot) {
    var tuple ;

    // try to get the tuple for this.
    if (typeof propertyPath === "string") {
      tuple = SC.tupleForPropertyPath(propertyPath, pathRoot) ;
    } else {
      tuple = propertyPath;
    }

    // if a tuple was found and is observable, add the observer immediately...
    if (tuple && tuple[0].addObserver) {
      tuple[0].addObserver(tuple[1],target, method) ;

    // otherwise, save this in the queue.
    } else {
      this.queue.push([propertyPath, target, method, pathRoot]) ;
    }
  },

  /**
    @private

    Remove the observer.  If it is already in the queue, remove it.  Also
    if already found on the object, remove that.
  */
  removeObserver: function(propertyPath, target, method, pathRoot) {
    var idx, queue, tuple, item;

    tuple = SC.tupleForPropertyPath(propertyPath, pathRoot) ;
    if (tuple) {
      tuple[0].removeObserver(tuple[1], target, method);
    }
    


    // tests show that the fastest way is to create a new array. On Safari,
    // it is fastest to set to null then loop over again to collapse, but for all other browsers
    // it is not. Plus, this code shouldn't get hit very often anyway (it may not ever get hit
    // for some apps).
    idx = this.queue.length;
    queue = this.queue;

    var newQueue;
    while(--idx >= 0) {
      item = queue[idx];

      if (item[0] !== propertyPath || item[1] !== target || item[2] !== method || item[3] !== pathRoot) {
        if (!newQueue) newQueue = [];
        newQueue.push(item);
      }
    }

    // even though performance probably won't be a problem, we are defensive about memory alloc.
    this.queue = newQueue || this.queue;
  },

  /**
    @private

    Range Observers register here to indicate that they may potentially
    need to start observing.
  */
  addPendingRangeObserver: function(observer) {
    var ro = this.rangeObservers;
    if (!ro) ro = this.rangeObservers = SC.CoreSet.create();
    ro.add(observer);
    return this ;
  },

  _TMP_OUT: [],

  /**
    Flush the queue.  Attempt to add any saved observers.
  */
  flush: function(object) {

    // flush any observers that we tried to setup but didn't have a path yet
    var oldQueue = this.queue, i,
        queueLen = oldQueue.length;

    if (oldQueue && queueLen > 0) {
      var newQueue = (this.queue = []) ;

      for (i=0; i<queueLen; i++ ) {
        var item = oldQueue[i];
        if ( !item ) continue;

        var tuple = SC.tupleForPropertyPath( item[0], item[3] );
        // check if object is observable (yet) before adding an observer
        if( tuple && tuple[0].addObserver ) {
          tuple[0].addObserver( tuple[1], item[1], item[2] );
        } else {
          newQueue.push( item );
        }
      }
    }

    // if this object needsRangeObserver then see if any pending range
    // observers need it.
    if ( object._kvo_needsRangeObserver ) {
      var set = this.rangeObservers,
          len = set ? set.get('length') : 0,
          out = this._TMP_OUT,
          ro;

      for ( i=0; i<len; i++ ) {
        ro = set[i]; // get the range observer
        if ( ro.setupPending(object) ) {
          out.push(ro); // save to remove later
        }
      }

      // remove any that have setup
      if ( out.length > 0 ) set.removeEach(out);
      out.length = 0; // reset
      object._kvo_needsRangeObserver = false ;
    }

  },

  /** @private */
  isObservingSuspended: 0,

  _pending: SC.CoreSet.create(),

  /** @private */
  objectHasPendingChanges: function(obj) {
    this._pending.add(obj) ; // save for later
  },

  /** @private */
  // temporarily suspends all property change notifications.
  suspendPropertyObserving: function() {
    this.isObservingSuspended++ ;
  },

  // resume change notifications.  This will call notifications to be
  // delivered for all pending objects.
  /** @private */
  resumePropertyObserving: function() {
    var pending ;
    if(--this.isObservingSuspended <= 0) {
      pending = this._pending ;
      this._pending = SC.CoreSet.create() ;

      var idx, len = pending.length;
      for(idx=0;idx<len;idx++) {
        pending[idx]._notifyPropertyObservers() ;
      }
      pending.clear();
      pending = null ;
    }
  }

} ;

/* >>>>>>>>>> BEGIN source/system/object.js */
// ==========================================================================
// Project:   SproutCore Costello - Property Observing Library
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('core');
sc_require('mixins/observable');
sc_require('private/observer_queue');
sc_require('mixins/array');
sc_require('system/set');

/*global*/

SC.BENCHMARK_OBJECTS = NO;

// ..........................................................
// PRIVATE HELPER METHODS
//
// Private helper methods.  These are not kept as part of the class
// definition because SC.Object is copied frequently and we want to keep the
// number of class methods to a minimum.

/** @private */
SC._detect_base = function _detect_base(func, parent, name) {

  return function invoke_superclass_method() {
    var base = parent[name],
      args,
      i, len;

    


    // NOTE: It is possible to cache the base, so that the first
    // call to sc_super will avoid doing the lookup again. However,
    // since the cost of the extra method dispatch is low and is
    // only incurred on sc_super, but also creates another possible
    // weird edge-case (when a class is enhanced after first used),
    // we'll leave it off for now unless profiling demonstrates that
    // it's a hotspot.
    //if(base && func === base) { func.base = function () {}; }
    //else { func.base = base; }

    // Accessing `arguments.length` is just a Number and doesn't materialize the `arguments` object, which is costly.
    // TODO: Add macro to build tools for this.
    if (func.isEnhancement) {
      // Fast copy.
      args = new Array(arguments.length - 1); // Array.prototype.slice.call(arguments, 1)
      for (i = 0, len = args.length; i < len; i++) { args[i] = arguments[i + 1]; }
    } else {
      // Fast copy.
      args = new Array(arguments.length);
      for (i = 0, len = args.length; i < len; i++) { args[i] = arguments[i]; }
    }

    return base.apply(this, args);
  };
};

/** @private
  Augments a base object by copying the properties from the extended hash.
  In addition to simply copying properties, this method also performs a
  number of optimizations that can make init'ing a new object much faster
  including:

  - concatenating concatenatedProperties
  - prepping a list of bindings, observers, and dependent keys
  - caching local observers so they don't need to be manually constructed.

  @param {Hash} base hash
  @param {Hash} extension
  @returns {Hash} base hash
*/
SC._object_extend = function _object_extend(base, ext, proto) {
  

  // set _kvo_cloned for later use
  base._kvo_cloned = null;

  // get some common vars
  var key, idx, cur,
    cprops = base.concatenatedProperties,
    K = SC.K,
    p1, p2;

  // first, save any concat props.  use old or new array or concat
  idx = (cprops) ? cprops.length : 0;
  var concats = (idx > 0) ? {} : null;
  while (--idx >= 0) {
    key = cprops[idx];
    p1 = base[key];
    p2 = ext[key];

    if (p1) {
      if (!(p1 instanceof Array)) p1 = SC.$A(p1);
      concats[key] = (p2) ? p1.concat(p2) : p2;
    } else {
      if (!(p2 instanceof Array)) p2 = SC.$A(p2);
      concats[key] = p2;
    }
  }

  // setup arrays for bindings, observers, and properties.  Normally, just
  // save the arrays from the base.  If these need to be changed during
  // processing, then they will be cloned first.
  var bindings = base._bindings, clonedBindings = NO,
      observers = base._observers, clonedObservers = NO,
      properties = base._properties, clonedProperties = NO,
      paths, pathLoc, local, value;

  // outlets are treated a little differently because you can manually
  // name outlets in the passed in hash. If this is the case, then clone
  // the array first.
  var outlets = base.outlets, clonedOutlets = NO;
  if (ext.outlets) {
    outlets = (outlets || SC.EMPTY_ARRAY).concat(ext.outlets);
    clonedOutlets = YES;
  }

  // now copy properties, add superclass to func.
  for (key in ext) {

    if (key === '_kvo_cloned') continue; // do not copy

    // avoid copying builtin methods
    if (!ext.hasOwnProperty(key)) continue;

    // get the value.  use concats if defined
    value = (concats.hasOwnProperty(key) ? concats[key] : null) || ext[key];

    // Support fooBinding syntax...
    if (key.length > 7 && key.slice(-7) === "Binding") {
      if (!clonedBindings) {
        bindings = (bindings || SC.EMPTY_ARRAY).slice();
        clonedBindings = YES;
      }
      // If the binding key is new (not found on base), add it to the list of binding keys. (If it's on
      // base, we assume that it's already in there. We don't check for performance reasons. If that's
      // failing, fix the failure not the check.)

      /* jshint eqnull:true */
      if (base[key] == null) { // (SC.none is inlined here for performance.)
        bindings[bindings.length] = key;
      }
    }

    // Add observers, outlets, properties and extensions for functions...
    else if (value && (value instanceof Function)) {

      // add super to funcs.  Be sure not to set the base of a func to
      // itself to avoid infinite loops.
      if (!value.superclass && (value !== (cur = base[key]))) {
        value.superclass = cur || K;
        value.base = proto ? SC._detect_base(value, proto, key) : cur || K;
      }

      // handle regular observers
      if (value.propertyPaths) {
        if (!clonedObservers) {
          observers = (observers || SC.EMPTY_ARRAY).slice();
          clonedObservers = YES;
        }
        observers[observers.length] = key;

      // handle local properties
      }

      paths = value.localPropertyPaths;
      if (paths) {
        pathLoc = paths.length;
        while (--pathLoc >= 0) {
          local = base._kvo_for(SC.keyFor('_kvo_local', paths[pathLoc]), SC.CoreSet);
          local.add(key);
          base._kvo_for('_kvo_observed_keys', SC.CoreSet).add(paths[pathLoc]);
        }

      // handle computed properties
      }

      if (value.dependentKeys) {
        if (!clonedProperties) {
          properties = (properties || SC.EMPTY_ARRAY).slice();
          clonedProperties = YES;
        }
        properties[properties.length] = key;

      // handle outlets
      }

      if (value.autoconfiguredOutlet) {
        if (!clonedOutlets) {
          outlets = (outlets || SC.EMPTY_ARRAY).slice();
          clonedOutlets = YES;
        }
        outlets[outlets.length] = key;
      }

      if (value.isEnhancement) {
        value = SC._enhance(base[key] || K, value);
      }
    }

    // copy property
    base[key] = value;
  }

  // Manually set base on toString() because some JS engines (such as IE8) do
  // not enumerate it
  if (ext.hasOwnProperty('toString')) {
    key = 'toString';
    // get the value.  use concats if defined
    value = (concats.hasOwnProperty(key) ? concats[key] : null) || ext[key];
    if (!value.superclass && (value !== (cur = base[key]))) {
      value.superclass = value.base = cur || K;
    }
    // copy property
    base[key] = value;
  }


  // copy bindings, observers, and properties
  base._bindings = bindings || [];
  base._observers = observers || [];
  base._properties = properties || [];
  base.outlets = outlets || [];

  return base;
};

/** @private */
SC._enhance = function (originalFunction, enhancement) {

  return function () {
    // Accessing `arguments.length` is just a Number and doesn't materialize the `arguments` object, which is costly.
    // TODO: Add macro to build tools for this.
    var enhancedArgs = new Array(arguments.length + 1); // Array.prototype.slice.call(arguments)
    for (var i = 1, len = enhancedArgs.length; i < len; i++) {
      enhancedArgs[i] = arguments[i - 1];
    }

    // Add the original function as the first argument passed to the enhancement.
    var self = this;
    enhancedArgs[0] = function () {
      // Fast copy.
      var originalArgs = new Array(arguments.length);
      for (var i = 0, len = originalArgs.length; i < len; i++) {
        originalArgs[i] = arguments[i];
      }

      return originalFunction.apply(self, originalArgs);
    }; // args.unshift(function ...

    return enhancement.apply(this, enhancedArgs);
  };

};

/** @class

  Root object for the SproutCore framework.  SC.Object is the root class for
  most classes defined by SproutCore.  It builds on top of the native object
  support provided by JavaScript to provide support for class-like
  inheritance, automatic bindings, properties observers, and more.

  Most of the classes you define in your application should inherit from
  SC.Object or one of its subclasses.  If you are writing objects of your
  own, you should read this documentation to learn some of the details of
  how SC.Object's behave and how they differ from other frameworks.

  About SproutCore Classes
  ===

  JavaScript is not a class-based language.  Instead it uses a type of
  inheritance inspired by self called "prototypical" inheritance.
  ...

  Using SproutCore objects with other JavaScript object.
  ===

  You can create a SproutCore object just like any other object...
  obj = new SC.Object();

  @extends SC.Observable
  @since SproutCore 1.0
*/
SC.Object = function (props) {
  this.__sc_super__ = SC.Object.prototype;
  return this._object_init(props);
};

SC.mixin(SC.Object, /** @scope SC.Object */ {

  /**
    Adds the passed properties to the object's class definition.  You can
    pass as many hashes as you want, including Mixins, and they will be
    added in the order they are passed.

    This is a shorthand for calling SC.mixin(MyClass, props...);

    @param {Hash} props the properties you want to add.
    @returns {Object} receiver
  */
  mixin: function () {
    var len = arguments.length, loc;
    for (loc = 0; loc < len; loc++) SC.mixin(this, arguments[loc]);
    return this;
  },

  // ..........................................
  // CREATING CLASSES AND INSTANCES
  //

  /**
    Points to the superclass for this class.  You can use this to trace a
    class hierarchy.

    @type SC.Object
  */
  superclass: null,

  /**
    Creates a new subclass of the receiver, adding any passed properties to
    the instance definition of the new class.  You should use this method
    when you plan to create several objects based on a class with similar
    properties.

    Init:

    If you define an init() method, it will be called when you create
    instances of your new class.  Since SproutCore uses the init() method to
    do important setup, you must be sure to always call arguments.callee.base.apply(this,arguments) somewhere
    in your init() to allow the normal setup to proceed.

    @param {Hash} props the methods of properties you want to add
    @returns {Class} A new object class
  */
  extend: function () {
    


    // build a new constructor and copy class methods.  Do this before
    // adding any other properties so they are not overwritten by the copy.
    var prop, ret = function (props) {
      this.__sc_super__ = ret.prototype;
      return this._object_init(props);
    };
    for (prop in this) {
      if (!this.hasOwnProperty(prop)) continue;
      ret[prop] = this[prop];
    }

    // manually copy toString() because some JS engines do not enumerate it
    if (this.hasOwnProperty('toString')) ret.toString = this.toString;

    // now setup superclass, guid
    ret.superclass = this;
    ret.__sc_super__ = this.prototype;
    SC.generateGuid(ret, "sc"); // setup guid

    ret.subclasses = SC.Set.create();
    this.subclasses.add(ret); // now we can walk a class hierarchy

    // setup new prototype and add properties to it
    var base = (ret.prototype = SC.beget(this.prototype)),
        idx, len = arguments.length;

    for (idx = 0; idx < len; idx++) {
      SC._object_extend(base, arguments[idx], ret.__sc_super__);
    }
    base.constructor = ret; // save constructor

    


    return ret;
  },

  // Tested in ../tests/system/object/enhance.js
  reopen: function (props) {
    // Reopen subclasses.
    if (this.subclasses) {
      var subclass, key, value, theseProps,
          len = this.subclasses.length, i;
      for (i = 0; i < len; i++) {
        theseProps = null;
        subclass = this.subclasses[i];
        for (key in props) {
          // avoid copying builtin methods
          if (!props.hasOwnProperty(key)) continue;

          // Remove properties that have already been overridden by the subclass.
          if (subclass.prototype.hasOwnProperty(key)) {
            if (!theseProps) {
              theseProps = SC.clone(props);
            }
            delete theseProps[key];
            continue;
          }

          // Remove enhancements that are only intended for the superclass's
          // function.
          value = props[key];
          if (value && (value instanceof Function) && (value.isEnhancement)) {
            if (!theseProps) {
              theseProps = SC.clone(props);
            }
            delete theseProps[key];
            continue;
          }
        }

        subclass.reopen(theseProps || props);
      }
    }

    // Reopen this.
    return SC._object_extend(this.prototype, props, this.__sc_super__);
  },

  /**
    Creates a new instance of the class.

    Unlike most frameworks, you do not pass parameters to the init function
    for an object.  Instead, you pass a hash of additional properties you
    want to have assigned to the object when it is first created.  This is
    functionally like creating an anonymous subclass of the receiver and then
    instantiating it, but more efficient.

    You can use create() like you would a normal constructor in a
    class-based system, or you can use it to create highly customized
    singleton objects such as controllers or app-level objects.  This is
    often more efficient than creating subclasses and then instantiating
    them.

    You can pass any hash of properties to this method, including mixins.

    @param {Hash} props
      optional hash of method or properties to add to the instance.

    @returns {SC.Object} new instance of the receiver class.
  */
  create: function () {
    var C = this, ret = new C(arguments);

    if (SC.ObjectDesigner) {
      SC.ObjectDesigner.didCreateObject(ret, SC.$A(arguments));
    }
    return ret;
  },
  /**
    Walk like a duck.  You can use this to quickly test classes.

    @type Boolean
  */
  isClass: YES,

  /**
    Set of subclasses that extend from this class.  You can observe this
    array if you want to be notified when the object is extended.

    @type SC.Set
  */
  subclasses: SC.Set.create(),

  /** @private */
  toString: function () { return SC._object_className(this); },

  // ..........................................
  // PROPERTY SUPPORT METHODS
  //

  /**
    Returns YES if the receiver is a subclass of the named class.  If the
    receiver is the class passed, this will return NO since the class is not
    a subclass of itself.  See also kindOf().

    Example:

          ClassA = SC.Object.extend();
          ClassB = ClassA.extend();

          ClassB.subclassOf(ClassA) => YES
          ClassA.subclassOf(ClassA) => NO

    @param {Class} scClass class to compare
    @returns {Boolean}
  */
  subclassOf: function (scClass) {
    if (this === scClass) return NO;
    var t = this;
    while ((t = t.superclass)) if (t === scClass) return YES;
    return NO;
  },

  /**
    Returns YES if the passed object is a subclass of the receiver.  This is
    the inverse of subclassOf() which you call on the class you want to test.

    @param {Class} scClass class to compare
    @returns {Boolean}
  */
  hasSubclass: function (scClass) {
    return (scClass && scClass.subclassOf) ? scClass.subclassOf(this) : NO;
  },

  /**
    Returns YES if the receiver is the passed class or is a subclass of the
    passed class.  Unlike subclassOf(), this method will return YES if you
    pass the receiver itself, since class is a kind of itself.  See also
    subclassOf().

    Example:

          ClassA = SC.Object.extend();
          ClassB = ClassA.extend();

          ClassB.kindOf(ClassA) => YES
          ClassA.kindOf(ClassA) => YES

    @param {Class} scClass class to compare
    @returns {Boolean}
  */
  kindOf: function (scClass) {
    return (this === scClass) || this.subclassOf(scClass);
  },

  // ..........................................................
  // Designers
  //
  /**
    This method works just like extend() except that it will also preserve
    the passed attributes.

    @param {Hash} attrs Attributes to add to view
    @returns {Class} SC.Object subclass to create
    @function
  */
  design: function () {
    if (this.isDesign) {
      

      return this;
    }

    var ret = this.extend.apply(this, arguments);
    ret.isDesign = YES;
    if (SC.ObjectDesigner) {
      SC.ObjectDesigner.didLoadDesign(ret, this, SC.A(arguments));
    }
    return ret;
  }

});

// ..........................................
// DEFAULT OBJECT INSTANCE
//
SC.Object.prototype = {

  _kvo_enabled: YES,

  /** @private
    This is the first method invoked on a new instance.  It will first apply
    any added properties to the new instance and then calls the real init()
    method.

    @param {Array} extensions an array-like object with hashes to apply.
    @returns {Object} receiver
  */
  _object_init: function (extensions) {
    // apply any new properties
    var idx,
      len = (extensions) ? extensions.length : 0;
    for (idx = 0; idx < len; idx++) { SC._object_extend(this, extensions[idx], this.__sc_super__); }
    SC.generateGuid(this, "sc"); // add guid
    this.init(); // call real init

    // Call 'initMixin' methods to automatically setup modules.
    var inits = this.initMixin;
    len = (inits) ? inits.length : 0;
    for (idx = 0; idx < len; idx++) inits[idx].call(this);

    return this; // done!
  },

  /**
    You can call this method on an object to mixin one or more hashes of
    properties on the receiver object.  In addition to simply copying
    properties, this method will also prepare the properties for use in
    bindings, computed properties, etc.

    If you plan to use this method, you should call it before you call
    the inherited init method from SC.Object or else your instance may not
    function properly.

    Example:

          // dynamically apply a mixin specified in an object property
          var MyClass = SC.Object.extend({
             extraMixin: null,

             init: function () {
               this.mixin(this.extraMixin);
               arguments.callee.base.apply(this,arguments);
             }
          });

          var ExampleMixin = { foo: "bar" };

          var instance = MyClass.create({ extraMixin: ExampleMixin });

          instance.get('foo') => "bar"

    @param {Hash} ext a hash to copy.  Only one.
    @returns {Object} receiver
  */
  mixin: function () {
    var idx, len = arguments.length, init;
    for (idx = 0; idx < len; idx++) SC._object_extend(this, arguments[idx]);

    // Reset the observable initialized status so that we can setup any new observables.
    this._observableInited = NO;
    this.initObservable();

    // Call initMixin
    for (idx = 0; idx < len; idx++) {
      init = arguments[idx].initMixin;
      if (init) init.call(this);
    }
    return this;
  },

  /**
    This method is invoked automatically whenever a new object is
    instantiated.  You can override this method as you like to setup your
    new object.

    Within your object, be sure to call arguments.callee.base.apply(this,arguments) to ensure that the
    built-in init method is also called or your observers and computed
    properties may not be configured.

    Although the default init() method returns the receiver, the return
    value is ignored.
  */
  init: function () {
    

    this.initObservable();
    return this;
  },

  /**
    This is set to YES once this object has been destroyed.

    @type Boolean
  */
  isDestroyed: NO,

  /**
    Call this method when you are finished with an object to teardown its
    contents.  Because JavaScript is garbage collected, you do not usually
    need to call this method.  However, you may choose to do so for certain
    objects, especially views, in order to let them reclaim memory they
    consume immediately.

    If you would like to perform additional cleanup when an object is
    finished, you may override this method.  Be sure to call arguments.callee.base.apply(this,arguments).

    @returns {SC.Object} receiver
  */
  destroy: function () {
    if (this.get('isDestroyed')) return this; // nothing to do
    this.set('isDestroyed', YES);

    // destroy any mixins
    var idx, inits = this.destroyMixin, len = (inits) ? inits.length : 0;
    for (idx = 0; idx < len; idx++) inits[idx].call(this);

    // destroy observables.
    this.destroyObservable();

    return this;
  },

  /**
    Walk like a duck. Always YES since this is an object and not a class.

    @type Boolean
  */
  isObject: true,

  /**
    Returns YES if the named value is an executable function.

    @param {String} methodName the property name to check
    @returns {Boolean}
  */
  respondsTo: function (methodName) {
    return !!(this[methodName] instanceof Function);
  },

  /**
    Attempts to invoke the named method, passing the included two arguments.
    Returns NO if the method is either not implemented or if the handler
    returns NO (indicating that it did not handle the event).  This method
    is invoked to deliver actions from menu items and to deliver events.
    You can override this method to provide additional handling if you
    prefer.

    @param {String} methodName
    @param {Object} arg1
    @param {Object} arg2
    @returns {Boolean} YES if handled, NO if not handled
  */
  tryToPerform: function (methodName, arg1, arg2) {
    return this.respondsTo(methodName) && (this[methodName](arg1, arg2) !== NO);
  },

  /**
    @deprecated v1.11 - use arguments.callee.base.apply(this,arguments) (with build tools) or arguments.callee.base.apply(this, arguments) instead.

    EXPERIMENTAL:  You can use this to invoke a superclass implementation in
    any method.  This does not work in Safari 2 or earlier.  If you need to
    target these methods, you should use one of the alternatives below:

    - *With Build Tools:* arguments.callee.base.apply(this,arguments);
    - *Without Build Tools:* arguments.callee.base.apply(this, arguments);

    Example

    All of the following methods will call the superclass implementation of
    your method:

          SC.Object.create({

            // DOES NOT WORK IN SAFARI 2 OR EARLIER
            method1: function () {
              this.superclass();
            },

            // REQUIRES SC-BUILD TOOLS
            method2: function () {
              arguments.callee.base.apply(this,arguments);
            },

            // WORKS ANYTIME
            method3: function () {
              arguments.callee.base.apply(this, arguments);
            }
          });

    @param {*args} args any arguments you want to pass along.
    @returns {Object} return value from super
  */
  superclass: function () {
    


    var caller = arguments.callee.caller;

    


    return caller.superclass ? caller.superclass.apply(this, arguments) : null;
  },

  /**
    returns YES if the receiver is an instance of the named class.  See also
    kindOf().

    Example

          var ClassA = SC.Object.extend();
          var ClassB = SC.Object.extend();

          var instA = ClassA.create();
          var instB = ClassB.create();

          instA.instanceOf(ClassA) => YES
          instB.instanceOf(ClassA) => NO

    @param {Class} scClass the class
    @returns {Boolean}
  */
  instanceOf: function (scClass) {
    return this.constructor === scClass;
  },

  /**
    Returns true if the receiver is an instance of the named class or any
    subclass of the named class.  See also instanceOf().

    Example

          var ClassA = SC.Object.extend();
          var ClassB = SC.Object.extend();

          var instA = ClassA.create();
          var instB = ClassB.create();

          instA.kindOf(ClassA) => YES
          instB.kindOf(ClassA) => YES

    @param {Class} scClass the class
    @returns {Boolean}
  */
  kindOf: function (scClass) { return this.constructor.kindOf(scClass); },

  /** @private */
  toString: function () {
    if (!this._object_toString) {
      // only cache the string if the klass name is available
      var klassName = SC._object_className(this.constructor),
          string = klassName + ":" + SC.guidFor(this);
      if (klassName) this._object_toString = string;
      else return string;
    }
    return this._object_toString;
  },

  /** @deprecated v1.11 - use init instead. */
  


  /**
    Invokes the passed method or method name one time during the runloop.  You
    can use this method to schedule methods that need to execute but may be
    too expensive to execute more than once, such as methods that update the
    DOM.

    Note that in development mode only, the object and method that call this
    method will be recorded, for help in debugging scheduled code.

    @param {Function|String} method method or method name
    @returns {SC.Object} receiver
  */
  invokeOnce: function (method) {
    

    SC.RunLoop.currentRunLoop.invokeOnce(this, method);
    return this;
  },

  /**
    Invokes the passed method once at the end of the current run of the run loop,
    before any other methods (including new events) are processed. This is useful
    for situations where you know you need to update something, but due to
    the way the run loop works, you can't actually do the update until the
    run loop has completed.

    A simple example is setting the selection on a collection controller to a
    newly created object. Because the collection controller won't have its
    content collection updated until later in the run loop, setting the
    selection immediately will have no effect. In this situation, you could do
    this instead:

          // Creates a new MyRecord object and sets the selection of the
          // myRecord collection controller to the new object.
          createObjectAction: function (sender, evt) {
            // create a new record and add it to the store
            var obj = MyRecord.newRecord();

            // update the collection controller's selection
            MyApp.myRecordCollectionController.invokeLast( function () {
              this.set('selection', [obj]);
            });
          }

    Note that in development mode only, the object and method that call this
    method will be recorded, for help in debugging scheduled code.

    @param {Function|String} method method or method name
    @returns {SC.Object} receiver
  */
  invokeLast: function (method) {
    

    SC.RunLoop.currentRunLoop.invokeLast(this, method);
    return this;
  },

  /**
    Invokes the passed target/method pair once at the beginning of the next
    run of the run loop, before any other methods (including events) are
    processed.  Use this to defer painting to make views more responsive or
    to ensure that the layer has been updated before using it.

    If you call this with the same target/method pair multiple times it will
    only invoke the pair only once at the beginning of the next runloop.

    Note that in development mode only, the object and method that call this
    method will be recorded, for help in debugging scheduled code.

    @param {Function|String} method method or method name
    @returns {SC.Object} receiver
   */
  invokeNext: function (method) {
    

    SC.RunLoop.currentRunLoop.invokeNext(this, method);
    return this;
  },

  /**
    The properties named in this array will be concatenated in subclasses
    instead of replaced.  This allows you to name special properties that
    should contain any values you specify plus values specified by parents.

    It is used by SproutCore and is available for your use, though you
    should limit the number of properties you include in this list as it
    adds a slight overhead to new class and instance creation.

    @type Array
  */
  concatenatedProperties: ['concatenatedProperties', 'initMixin', 'destroyMixin']

};

// bootstrap the constructor for SC.Object.
SC.Object.prototype.constructor = SC.Object;

// Add observable to mixin
SC.mixin(SC.Object.prototype, SC.Observable);

// ..........................................................
// CLASS NAME SUPPORT
//

/** @private
  This is a way of performing brute-force introspection.  This searches
  through all the top-level properties looking for classes.  When it finds
  one, it saves the class path name.
*/
SC.findClassNames = function () {
  if (SC._object_foundObjectClassNames) return;
  SC._object_foundObjectClassNames = true;

  var seen = [],
      detectedSC = false;
  var searchObject = function (root, object, levels) {

    var path, value, type;
    levels--;

    // not the fastest, but safe
    if (seen.indexOf(object) >= 0) return;
    seen.push(object);

    for (var key in object) {
      if (key === '__scope__') continue;
      if (key === 'superclass') continue;
      if (key === '__SC__') key = 'SC';
      if (!key.match(/^[A-Z0-9]/)) continue;
      if (key === 'SC') {
        if (detectedSC) continue;
        detectedSC = true;
      }

      path = (root) ? [root, key].join('.') : key;
      value = object[key];

      try {
        type = SC.typeOf(value);
      } catch (e) {
        // Firefox gives security errors when trying to run typeOf on certain objects
        break;
      }

      switch (type) {
      case SC.T_CLASS:
        if (!value._object_className) value._object_className = path;
        if (levels >= 0) searchObject(path, value, levels);
        break;

      case SC.T_OBJECT:
        if (levels >= 0) searchObject(path, value, levels);
        break;

      case SC.T_HASH:
        if (((root) || (path === 'SC')) && (levels >= 0)) searchObject(path, value, levels);
        break;

      default:
        break;
      }
    }
  };

  // Fix for IE 7 and 8 in order to detect the SC global variable. When you create
  // a global variable in IE, it is not added to the window object like in other
  // browsers. Therefore the searchObject method will not pick it up. So we have to
  // update the window object to have a reference to the global variable. And
  // doing window['SC'] does not work since the global variable already exists. For
  // any object that you create that is used act as a namespace, be sure to create it
  // like so:
  //
  //   window.MyApp = window.MyApp || SC.Object.create({ ... })
  //
  window.__SC__ = SC;
  searchObject(null, window, 2);
};

/**
  Same as the instance method, but lets you check instanceOf without
  having to first check if instanceOf exists as a method.

  @param {Object} scObject the object to check instance of
  @param {Class} scClass the class
  @returns {Boolean} if object1 is instance of class
*/
SC.instanceOf = function (scObject, scClass) {
  return !!(scObject && scObject.constructor === scClass);
};

/**
  Same as the instance method, but lets you check kindOf without having to
  first check if kindOf exists as a method.

  @param {Object} scObject object to check kind of
  @param {Class} scClass the class to check
  @returns {Boolean} if object is an instance of class or subclass
*/
SC.kindOf = function (scObject, scClass) {
  if (scObject && !scObject.isClass) scObject = scObject.constructor;
  return !!(scObject && scObject.kindOf && scObject.kindOf(scClass));
};

/** @private
  Returns the name of this class.  If the name is not known, triggers
  a search.  This can be expensive the first time it is called.

  This method is used to allow classes to determine their own name.
*/
SC._object_className = function (obj) {
  if (SC.isReady === NO) return ''; // class names are not available until ready
  if (!obj._object_className) SC.findClassNames();
  if (obj._object_className) return obj._object_className;

  // if no direct classname was found, walk up class chain looking for a
  // match.
  var ret = obj;
  while (ret && !ret._object_className) ret = ret.superclass;
  return (ret && ret._object_className) ? ret._object_className : 'Anonymous';
};


/* >>>>>>>>>> BEGIN source/private/property_chain.js */
sc_require('system/object');

/**
  @class
  @private

  SC._PropertyChain is used as the bookkeeping system for notifying the KVO
  system of changes to computed properties that contains paths as dependent
  keys.

  Each instance of SC._PropertyChain serves as a node in a linked list. One node
  is created for each property in the path, and stores a reference to the name
  of the property and the object to which it belongs. If that property changes,
  the SC._PropertyChain instance notifies its associated computed property to
  invalidate, then rebuilds the chain with the new value.

  To create a new chain, call SC._PropertyChain.createChain() with the target,
  path, and property to invalidate if any of the objects in the path change.

  For example, if you called createChain() with 'foo.bar.baz', it would
  create a linked list like this:

   ---------------------     ---------------------     ---------------------
  | property:     'foo' |   | property:     'bar' |   | property:     'baz' |
  | nextProperty: 'bar' |   | nextProperty: 'baz' |   | nextProperty: undef |
  | next:           ------->| next:           ------->| next:     undefined |
   ---------------------     ---------------------     ---------------------

  @extends SC.Object
  @since SproutCore 1.5
*/

SC._PropertyChain = SC.Object.extend(
/** @scope SC.Object.prototype */ {
  /**
    The object represented by this node in the chain.

    @type Object
  */
  object: null,

  /**
    The key on the previous object in the chain that contains the object
    represented by this node in the chain.

    @type String
  */
  property: null,

  /**
    The target object. This is the object passed to createChain(), and the
    object which contains the +toInvalidate+ property that will be invalidated
    if +property+ changes.

    @type Object
  */
  target: null,

  /**
    The property of +target+ to invalidate when +property+ changes.

    @type String
  */
  toInvalidate: null,

  /**
    The property key on +object+ that contains the object represented by the
    next node in the chain.

    @type String
  */
  nextProperty: null,

  /**
    Registers this segment of the chain with the object it represents.

    This should be called with the object represented by the previous node in
    the chain as the first parameter. If no previous object is provided, it will
    assume it is the root node in the chain and treat the target as the previous
    object.

    @param {Object} [newObject] The object in the chain to hook to.
  */
  activate: function(newObject) {
    var curObject = this.get('object'),
        property  = this.get('property'),
        nextObject;

    // If no parameter is passed, assume we are the root in the chain
    // and look up property relative to the target, since dependent key
    // paths are always relative.
    if (!newObject) { newObject = this.get('target'); }

    if (curObject && curObject!==newObject) {
      this.deactivate();
    }
    this.set('object', newObject);

    // In the special case of @each, we treat the enumerable as the next
    // property so just skip registering it
    if (newObject && property!=='@each') {
      newObject.registerDependentKeyWithChain(property, this);
    }

    // now - lookup the object for the next one...
    if (this.next) {
      nextObject = newObject ? newObject.get(property) : undefined;
      this.next.activate(nextObject);
    }

    return this;
  },

  /**
    Removes this segment of the chain from the object it represents. This is
    usually called when the object represented by the previous segment in the
    chain changes.
  */
  deactivate: function() {
    var object   = this.get('object'),
        property = this.get('property');

    // If the chain element is not associated with an object,
    // we don't need to deactivate anything.
    if (object) object.removeDependentKeyWithChain(property, this);
    if (this.next) this.next.deactivate();
    return this;
  },

  /**
    Invalidates the +toInvalidate+ property of the +target+ object.
  */
  notifyPropertyDidChange: function() {
    var target       = this.get('target'),
        toInvalidate = this.get('toInvalidate'),
        curObj, newObj;

    // Tell the target of the chain to invalidate the property
    // that depends on this element of the chain
    target.propertyDidChange(toInvalidate);

    // If there are more dependent keys in the chain, we need
    // to invalidate them and set them up again.
    if (this.next) {
      // Get the new value of the object associated with this node to pass to
      // activate().
      curObj = this.get('object');
      newObj = curObj.get(this.get('property'));

      this.next.activate(newObj); // reactivate down the line
    }
  }

  

});

SC._PropertyChain.createChain = function(path, target, toInvalidate) {
  var parts = path.split('.');
  var len = parts.length,
      i   = 1;

  var root = SC._PropertyChain.create({
    property:     parts[0],
    target:       target,
    toInvalidate: toInvalidate,
    nextProperty: parts[1]
  });


  root.set('length', len);
  var tail = root;

  while(--len >= 1) {
    tail = tail.next = SC._PropertyChain.create({
      property:     parts[i],
      target:       target,
      toInvalidate: toInvalidate,
      nextProperty: parts[++i]
    });

    tail.set('length', len);
  }

  return root;
};

/* >>>>>>>>>> BEGIN source/system/binding.js */
// ==========================================================================
// Project:   SproutCore Costello - Property Observing Library
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('ext/function');
sc_require('system/object');




/**
  Default placeholder for multiple values in bindings.

  @type String
*/
SC.MULTIPLE_PLACEHOLDER = '@@MULT@@';

/**
  Default placeholder for null values in bindings.

  @type String
*/
SC.NULL_PLACEHOLDER = '@@NULL@@';

/**
  Default placeholder for empty values in bindings.

  @type String
*/
SC.EMPTY_PLACEHOLDER = '@@EMPTY@@';


/**
  @class

  A binding simply connects the properties of two objects so that whenever the
  value of one property changes, the other property will be changed also.  You
  do not usually work with Binding objects directly but instead describe
  bindings in your class definition using something like:

        valueBinding: "MyApp.someController.title"

  This will create a binding from "MyApp.someController.title" to the "value"
  property of your object instance automatically.  Now the two values will be
  kept in sync.

  One-Way Bindings
  ===

  By default, bindings are set up as two-way. In cases where you only need the
  binding to function in one direction, for example if a value from a controller
  is bound into a read-only LabelView, then for performance reasons you should
  use a one-way binding. To do this, call the very useful `oneWay` helper:

      valueBinding: SC.Binding.oneWay('MyApp.someController.title')

  or:

      valueBinding: SC.Binding.from('MyApp.someController.title').oneWay()

  This way if the value of MyApp.someController.title changes, your object's
  `value` will also update. Since `value` will never update on its own, this will
  avoid the setup time required to plumb the binding in the other direction,
  nearly doubling performance for this binding.

  Transforms
  ===

  In addition to synchronizing values, bindings can also perform some basic
  transforms on values.  These transforms can help to make sure the data fed
  into one object always meets the expectations of that object, regardless of
  what the other object outputs.

  To customize a binding, you can use one of the many helper methods defined
  on SC.Binding. For example:

        valueBinding: SC.Binding.single("MyApp.someController.title")

  This will create a binding just like the example above, except that now the
  binding will convert the value of MyApp.someController.title to a single
  object (removing any arrays) before applying it to the "value" property of
  your object.

  You can also chain helper methods to build custom bindings like so:

        valueBinding: SC.Binding.single("MyApp.someController.title").notEmpty(null,"(EMPTY)")

  This will force the value of MyApp.someController.title to be a single value
  and then check to see if the value is "empty" (null, undefined, empty array,
  or an empty string).  If it is empty, the value will be set to the string
  "(EMPTY)".

  The following transform helper methods are included: `noError`, `single`, `notEmpty`,
  `notNull`, `multiple`, `bool`, `not`, `isNull`, `and` (two values only), `or` (two
  values only), and `equalTo`. See each method's documentation for a full description.

  (Note that transforms are only applied in the forward direction (the 'to' side); values
  are applied untransformed to the 'from' side. If the 'from' object has validation
  needs, it should own and apply them itself, for example via a read/write calculated
  property.)

  Adding Custom Transforms
  ===

  In addition to using the standard helpers provided by SproutCore, you can
  also defined your own custom transform functions which will be used to
  convert the value.  To do this, just define your transform function and add
  it to the binding with the transform() helper.  The following example will
  not allow Integers less than ten.  Note that it checks the value of the
  bindings and allows all other values to pass:

        valueBinding: SC.Binding.transform(function (value, binding) {
          return ((SC.typeOf(value) === SC.T_NUMBER) && (value < 10)) ? 10 : value;
        }).from("MyApp.someController.value")

  If you would like to instead use this transform on a number of bindings,
  you can also optionally add your own helper method to SC.Binding.  This
  method should simply return the value of this.transform(). The example
  below adds a new helper called notLessThan() which will limit the value to
  be not less than the passed minimum:

      SC.Binding.notLessThan = function (minValue) {
        return this.transform(function (value, binding) {
          return ((SC.typeOf(value) === SC.T_NUMBER) && (value < minValue)) ? minValue : value;
        });
      };

  You could specify this in your core.js file, for example.  Then anywhere in
  your application you can use it to define bindings like so:

        valueBinding: SC.Binding.from("MyApp.someController.value").notLessThan(10)

  Also, remember that helpers are chained so you can use your helper along with
  any other helpers.  The example below will create a one way binding that
  does not allow empty values or values less than 10:

        valueBinding: SC.Binding.oneWay("MyApp.someController.value").notEmpty().notLessThan(10)

  Note that the built in helper methods all allow you to pass a "from"
  property path so you don't have to use the from() helper to set the path.
  You can do the same thing with your own helper methods if you like, but it
  is not required.

  Creating Custom Binding Templates
  ===

  Another way you can customize bindings is to create a binding template.  A
  template is simply a binding that is already partially or completely
  configured.  You can specify this template anywhere in your app and then use
  it instead of designating your own custom bindings.  This is a bit faster on
  app startup but it is mostly useful in making your code less verbose.

  For example, let's say you will be frequently creating one way, not empty
  bindings that allow values greater than 10 throughout your app.  You could
  create a binding template in your core.js like this:

        MyApp.LimitBinding = SC.Binding.oneWay().notEmpty().notLessThan(10);

  Then anywhere you want to use this binding, just refer to the template like
  so:

        valueBinding: MyApp.LimitBinding.beget("MyApp.someController.value")

  Note that when you use binding templates, it is very important that you
  always start by using beget() to extend the template.  If you do not do
  this, you will end up using the same binding instance throughout your app
  which will lead to erratic behavior.

  How to Manually Activate a Binding
  ===

  All of the examples above show you how to configure a custom binding, but
  the result of these customizations will be a binding template, not a fully
  active binding.  The binding will actually become active only when you
  instantiate the object the binding belongs to.  It is useful however, to
  understand what actually happens when the binding is activated. (Of course
  you should always use the highest-level APIs available, even if you understand
  how it works underneath; unless you have specific needs, you should rely on
  the convenience `fooBinding` format.)

  For a binding to function it must have at least a "from" property and a "to"
  property.  The from property path points to the object/key that you want to
  bind from while the to path points to the object/key you want to bind to.

  When you define a custom binding, you are usually describing the property
  you want to bind from (such as "MyApp.someController.value" in the examples
  above).  When your object is created, it will automatically assign the value
  you want to bind "to" based on the name of your binding key.  In the
  examples above, during init, SproutCore objects will effectively call
  something like this on your binding:

        binding = this.valueBinding.beget().to("value", this);

  This creates a new binding instance based on the template you provide, and
  sets the to path to the "value" property of the new object.  Now that the
  binding is fully configured with a "from" and a "to", it simply needs to be
  connected to become active.  This is done through the connect() method:

        binding.connect();

  Now that the binding is connected, it will observe both the from and to side
  and relay changes.

  If you ever needed to do so (you almost never will, but it is useful to
  understand this anyway), you could manually create an active binding by
  doing the following:

        SC.Binding.from("MyApp.someController.value")
         .to("MyApp.anotherObject.value")
         .connect();

  You could also use the bind() helper method provided by SC.Object. (This is
  the same method used by SC.Object.init() to setup your bindings):

        MyApp.anotherObject.bind("value", "MyApp.someController.value");

  Both of these code fragments have the same effect as doing the most friendly
  form of binding creation like so:


        MyApp.anotherObject = SC.Object.create({
          valueBinding: "MyApp.someController.value",

          // OTHER CODE FOR THIS OBJECT...

        });

  SproutCore's built in binding creation method make it easy to automatically
  create bindings for you. If you need further documentation on SC.Binding's inner
  workings, see the private method documentation in the source code.

  @since SproutCore 1.0
*/
SC.Binding = /** @scope SC.Binding.prototype */{

  /**
    Quack.
  */
  isBinding: YES,

  /** @private
    This is the core method you use to create a new binding instance.  The
    binding instance will have the receiver instance as its parent which means
    any configuration you have there will be inherited.

    The returned instance will also have its parentBinding property set to the
    receiver.

    @param {String} [fromPath]
    @returns {SC.Binding} new binding instance
  */
  beget: function (fromPath) {
    var ret = SC.beget(this);
    ret.parentBinding = this;

    // Mix adapters must be recreated on beget.
    if (ret._MixAdapter) {
      ret._mixAdapter = ret._MixAdapter.create(ret._mixAdapterHash);
      ret = ret.from('aggregateProperty', ret._mixAdapter).oneWay();
    }

    // Enables duplicate API calls for SC.Binding.beget and SC.Binding.from
    if (fromPath !== undefined) ret = ret.from(fromPath);
    return ret;
  },

  /** @private
    Returns a builder function for compatibility.
  */
  builder: function () {
    var binding = this,
        ret = function (fromProperty) { return binding.beget().from(fromProperty); };
    ret.beget = function () { return binding.beget(); };
    return ret;
  },

  /**
    This will set "from" property path to the specified value.  It will not
    attempt to resolve this property path to an actual object/property tuple
    until you connect the binding.

    The binding will search for the property path starting at the root level
    unless you specify an alternate root object as the second parameter to this
    method.  Alternatively, you can begin your property path with either "." or
    "*", which will use the root object of the to side be default.  This special
    behavior is used to support the high-level API provided by SC.Object.

    @param {String|Tuple} propertyPath A property path or tuple
    @param {Object} [root] root object to use when resolving the path.
    @returns {SC.Binding} this
  */
  from: function (propertyPath, root) {

    // if the propertyPath is null/undefined, return this.  This allows the
    // method to be called from other methods when the fromPath might be
    // optional. (cf single(), multiple())
    if (!propertyPath) return this;

    // beget if needed.
    var binding = (this === SC.Binding) ? this.beget() : this;
    binding._fromPropertyPath = propertyPath;
    binding._fromRoot = root;
    binding._fromTuple = null;
    return binding;
  },

  /**
    This will set the "to" property path to the specified value.  It will not
    attempt to reoslve this property path to an actual object/property tuple
    until you connect the binding.

    If you are using the convenience format `fooBinding`, for example
    `isVisibleBinding`, you do not need to call this method, as the `to` property
    path will be generated for you when its object is created.

    @param {String|Tuple} propertyPath A property path or tuple
    @param {Object} [root] root object to use when resolving the path.
    @returns {SC.Binding} this
  */
  to: function (propertyPath, root) {
    // beget if needed.
    var binding = (this === SC.Binding) ? this.beget() : this;
    binding._toPropertyPath = propertyPath;
    binding._toRoot = root;
    binding._toTuple = null; // clear out any existing one.
    return binding;
  },

  /**
    Attempts to connect this binding instance so that it can receive and relay
    changes.  This method will raise an exception if you have not set the
    from/to properties yet.

    @returns {SC.Binding} this
  */
  connect: function () {
    // If the binding is already connected, do nothing.
    if (this.isConnected) return this;
    this.isConnected = YES;
    this._connectionPending = YES; // its connected but not really...
    this._syncOnConnect = YES;

    SC.Binding._connectQueue.add(this);

    if (!SC.RunLoop.isRunLoopInProgress()) {
      this._scheduleSync();
    }

    return this;
  },

  /** @private
    Actually connects the binding.  This is done at the end of the runloop
    to give you time to setup your entire object graph before the bindings
    try to activate.
  */
  _connect: function () {
    if (!this._connectionPending) return; //nothing to do
    this._connectionPending = NO;

    var path, root;

    


    // try to connect the from side.
    // as a special behavior, if the from property path begins with either a
    // . or * and the fromRoot is null, use the toRoot instead.  This allows
    // for support for the SC.Object shorthand:
    //
    // contentBinding: "*owner.value"
    //
    path = this._fromPropertyPath;
    root = this._fromRoot;

    if (typeof path === "string") {

      // if the first character is a '.', this is a static path.  make the
      // toRoot the default root.
      if (path.indexOf('.') === 0) {
        path = path.slice(1);
        if (!root) root = this._toRoot;

      // if the first character is a '*', then setup a tuple since this is a
      // chained path.
      } else if (path.indexOf('*') === 0) {
        path = [this._fromRoot || this._toRoot, path.slice(1)];
        root = null;
      }
    }
    this._fromObserverData = [path, this, this.fromPropertyDidChange, root];
    SC.Observers.addObserver.apply(SC.Observers, this._fromObserverData);

    // try to connect the to side
    if (!this._oneWay) {
      path = this._toPropertyPath;
      root = this._toRoot;
      this._toObserverData = [path, this, this.toPropertyDidChange, root];
      SC.Observers.addObserver.apply(SC.Observers, this._toObserverData);
    }

    


    // now try to sync if needed
    if (this._syncOnConnect) {
      this._syncOnConnect = NO;
      

      this.sync();
      

    }
  },

  /**
    Disconnects the binding instance.  Changes will no longer be relayed.  You
    will not usually need to call this method.

    @returns {SC.Binding} this
  */
  disconnect: function () {
    if (!this.isConnected) return this; // nothing to do.

    // if connection is still pending, just cancel
    if (this._connectionPending) {
      this._connectionPending = NO;

      SC.Binding._connectQueue.remove(this);
    // connection is completed, disconnect.
    } else {
      SC.Observers.removeObserver.apply(SC.Observers, this._fromObserverData);
      if (!this._oneWay) {
        SC.Observers.removeObserver.apply(SC.Observers, this._toObserverData);
      }

      // Remove ourselves from the change queue (if we are in it).
      SC.Binding._changeQueue.remove(this);
    }

    this.isConnected = NO;
    return this;
  },

  /** @private
    Indicates when the binding has been destroyed.

    @type Boolean
    @default NO
  */
  isDestroyed: NO,

  /** @private
    Disconnects the binding and removes all properties and external references. Called by
    either binding target object when destroyed.

    @private
  */
  destroy: function () {
    // If we're already destroyed, there's nothing to do.
    if (this.isDestroyed) return;

    // Mark it destroyed.
    this.isDestroyed = YES;

    // Clean up the mix adapter, if any. (See adapter methods.)
    if (this._mixAdapter) {
      this._mixAdapter.destroy();
      this._mixAdapter = null;
      this._MixAdapter = null;
      this._mixAdapterHash = null;
    }

    // Disconnect the binding.
    this.disconnect();

    // Aggressively null out internal properties.
    this._bindingSource = null;
    this._toRoot = this._toTarget = null;
    this._fromRoot = this._fromTarget = null;
    this._toObserverData = this._fromObserverData = null;
  },

  /** @private
    Invoked whenever the value of the "from" property changes.  This will mark
    the binding as dirty if the value has changed.

    @param {Object} target The object that contains the key
    @param {String} key The name of the property which changed
  */
  fromPropertyDidChange: function (target, key) {
    var v = target ? target.get(key) : null;

    // In rare circumstances, getting a property can result in observers firing,
    // which may in turn run code that disconnects the binding. The cause of
    // this pattern has been difficult to determine and so until a concrete test
    // scenario and a lower level fix can be found, show a warning and ignore
    // the update.
    if (!this.isConnected) {
      


      // Break early.
      return;
    }

    // if the new value is different from the current binding value, then
    // schedule to register an update.
    if (v !== this._bindingValue || key === '[]') {

      this._setBindingValue(target, key);
      SC.Binding._changeQueue.add(this); // save for later.

      this._scheduleSync();
    }
  },

  /** @private
    Invoked whenever the value of the "to" property changes.  This will mark the
    binding as dirty only if:

    - the binding is not one way
    - the value does not match the stored transformedBindingValue

    if the value does not match the transformedBindingValue, then it will
    become the new bindingValue.

    @param {Object} target The object that contains the key
    @param {String} key The name of the property which changed
  */
  toPropertyDidChange: function (target, key) {
    if (this._oneWay) return; // nothing to do

    var v = target.get(key);

    // In rare circumstances, getting a property can result in observers firing,
    // which may in turn run code that disconnects the binding. The cause of
    // this pattern has been difficult to determine and so until a concrete test
    // scenario and a lower level fix can be found, show a warning and ignore
    // the update.
    if (!this.isConnected) {
      


      // Break early.
      return;
    }

    // if the new value is different from the current binding value, then
    // schedule to register an update.
    if (v !== this._transformedBindingValue) {
      this._setBindingValue(target, key);
      SC.Binding._changeQueue.add(this); // save for later.

      this._scheduleSync();
    }
  },

  /** @private */
  _scheduleSync: function () {
    if (SC.RunLoop.isRunLoopInProgress() || SC.Binding._syncScheduled) { return; }
    SC.Binding._syncScheduled = YES;
    setTimeout(function () { SC.run(); SC.Binding._syncScheduled = NO; }, 1);
  },

  /** @private
    Saves the source location for the binding value.  This will be used later
    to actually update the binding value.
  */
  _setBindingValue: function (source, key) {
    this._bindingSource = source;
    this._bindingKey    = key;
  },

  /** @private
    Updates the binding value from the current binding source if needed.  This
    should be called just before using this._bindingValue.
  */
  _computeBindingValue: function () {
    var source = this._bindingSource,
        key    = this._bindingKey,
        v;

    this._bindingValue = v = (source ? source.getPath(key) : null);
    this._transformedBindingValue = this._computeTransformedValue(v);
  },

  /** @private
    Applies transforms to the value and returns the transfomed value.
    @param {*} value Binding value to transform
    @returns {*} Transformed value
  */
  _computeTransformedValue: function (value) {
    var transforms = this._transforms,
        idx,
        len,
        transform;

    if (transforms) {
      len = transforms.length;
      for (idx = 0; idx < len; idx++) {
        transform = transforms[idx];
        value = transform(value, this);
      }
    }

    // if error objects are not allowed, and the value is an error, then
    // change it to null.
    if (this._noError && SC.typeOf(value) === SC.T_ERROR) { value = null; }

    return value;
  },

  _connectQueue: SC.CoreSet.create(),
  _alternateConnectQueue: SC.CoreSet.create(),
  _changeQueue: SC.CoreSet.create(),
  _alternateChangeQueue: SC.CoreSet.create(),

  /** @private
    Call this method on SC.Binding to flush all bindings with changes pending.

    @returns {Boolean} YES if changes were flushed.
  */
  flushPendingChanges: function () {

    // don't allow flushing more than one at a time
    if (this._isFlushing) return NO;
    this._isFlushing = YES;
    SC.Observers.suspendPropertyObserving();

    var didFlush = NO,
        // connect any bindings
        queue, binding;

    while ((queue = this._connectQueue).length > 0) {
      this._connectQueue = this._alternateConnectQueue;
      this._alternateConnectQueue = queue;
      while ((binding = queue.pop())) { binding._connect(); }
    }

    // loop through the changed queue...
    while ((queue = this._changeQueue).length > 0) {
      


      didFlush = YES;

      // first, swap the change queues.  This way any binding changes that
      // happen while we flush the current queue can be queued up.
      this._changeQueue = this._alternateChangeQueue;
      this._alternateChangeQueue = queue;

      // next, apply any bindings in the current queue.  This may cause
      // additional bindings to trigger, which will end up in the new active
      // queue.
      while ((binding = queue.pop())) { binding.applyBindingValue(); }

      // now loop back and see if there are additional changes pending in the
      // active queue.  Repeat this until all bindings that need to trigger
      // have triggered.
      

    }

    // clean up
    this._isFlushing = NO;
    SC.Observers.resumePropertyObserving();

    return didFlush;
  },

  /** @private
    This method is called at the end of the Run Loop to relay the changed
    binding value from one side to the other.
  */
  applyBindingValue: function () {
    // compute the binding targets if needed.
    this._computeBindingTargets();
    this._computeBindingValue();

    var v = this._bindingValue,
        tv = this._transformedBindingValue;

    


    // the from property value will always be the binding value, update if
    // needed.
    if (!this._oneWay && this._fromTarget) {
      


      this._fromTarget.setPathIfChanged(this._fromPropertyKey, v);

      

    }

    // update the to value with the transformed value if needed.
    if (this._toTarget) {

      


      this._toTarget.setPathIfChanged(this._toPropertyKey, tv);

      

    }
  },

  /**
    Calling this method on a binding will cause it to check the value of the
    from side of the binding matches the current expected value of the
    binding. If not, it will relay the change as if the from side's value has
    just changed.

    This method is useful when you are dynamically connecting bindings to a
    network of objects that may have already been initialized. Otherwise you
    should not need to call this method.
  */
  sync: function () {
    var target,
        key,
        v,
        tv;

    // do nothing if not connected
    if (!this.isConnected) return this;

    // connection is pending, just note that we should sync also
    if (this._connectionPending) {
      this._syncOnConnect = YES;

    // we are connected, go ahead and sync
    } else {
      this._computeBindingTargets();
      target = this._fromTarget;
      key = this._fromPropertyKey;
      if (!target || !key) return this; // nothing to do

      // Let's check for whether target is a valid observable with getPath.
      // Common cases might have it be a Window or a DOM object.
      //
      // If we have a target, it is ready, but if it is invalid, that is WRONG.
      if (!target.isObservable) {
        

        return this;
      }

      // get the new value
      v = target.getPath(key);
      tv = this._computeTransformedValue(v);

      // if the new value is different from the current binding value, then
      // schedule to register an update.
      if (v !== this._bindingValue || tv !== this._transformedBindingValue || key === '[]') {
        this._setBindingValue(target, key);
        SC.Binding._changeQueue.add(this); // save for later.
      }
    }

    return this;
  },

  /** @private
    set if you call sync() when the binding connection is still pending.
   */
  _syncOnConnect: NO,

  /** @private */
  _computeBindingTargets: function () {
    var path, root, tuple;

    if (!this._fromTarget) {
      // if the fromPropertyPath begins with a . or * then we may use the
      // toRoot as the root object.  Similar code exists in connect() so if
      // you make a change to one be sure to update the other.
      path = this._fromPropertyPath;
      root = this._fromRoot;
      if (typeof path === "string") {

        // static path beginning with the toRoot
        if (path.indexOf('.') === 0) {
          path = path.slice(1); // remove the .
          if (!root) root = this._toRoot; // use the toRoot optionally

        // chained path beginning with toRoot.  Setup a tuple
        } else if (path.indexOf('*') === 0) {
          path = [root || this._toRoot, path.slice(1)];
          root = null;
        }
      }

      tuple = SC.tupleForPropertyPath(path, root);
      if (tuple) {
        this._fromTarget = tuple[0];
        this._fromPropertyKey = tuple[1];
      }
    }

    if (!this._toTarget) {
      path = this._toPropertyPath;
      root = this._toRoot;
      tuple = SC.tupleForPropertyPath(path, root);
      if (tuple) {
        this._toTarget = tuple[0];
        this._toPropertyKey = tuple[1];
        // Hook up _mixAdapter if needed (see adapter methods).
        if (this._mixAdapter) {
          this._mixAdapter.set('localObject', this._toTarget);
        }
      }
    }
  },

  // -------------------------------
  // Helper Methods
  //

  /**
    Configures the binding as one way.  A one-way binding will relay changes
    on the "from" side to the "to" side, but not the other way around.  This
    means that if you change the "to" side directly, the "from" side will not
    be updated, and may have a different value.

    @param {String} [fromPath] from path to connect.
    @param {Boolean} [aFlag] Pass NO to set the binding back to two-way
    @returns {SC.Binding} this
  */
  oneWay: function (fromPath, aFlag) {

    // If fromPath is a bool but aFlag is undefined, swap.
    if ((aFlag === undefined) && (SC.typeOf(fromPath) === SC.T_BOOL)) {
      aFlag = fromPath;
      fromPath = null;
    }

    // beget if needed.
    var binding = this.from(fromPath);
    if (binding === SC.Binding) binding = binding.beget();
    binding._oneWay = (aFlag === undefined) ? YES : aFlag;

    return binding;
  },

  /**
    Adds the specified transform function to the array of transform functions.

    The function you pass must have the following signature:

          function (value) {};

    or:

          function (value, binding) {};

    It must return either the transformed value or an error object.

    Transform functions are chained, so they are called in order.  If you are
    extending a binding and want to reset its transforms, you can call
    resetTransform() first.

    @param {Function} transformFunc the transform function.
    @returns {SC.Binding} this
  */
  transform: function (transformFunc) {
    var binding = (this === SC.Binding) ? this.beget() : this;
    var t = binding._transforms;

    // clone the transform array if this comes from the parent
    if (t && (t === binding.parentBinding._transforms)) {
      t = binding._transforms = t.slice();
    }

    // create the transform array if needed.
    if (!t) t = binding._transforms = [];

    // add the transform function
    t.push(transformFunc);
    return binding;
  },

  /**
    Resets the transforms for the binding.  After calling this method the
    binding will no longer transform values.  You can then add new transforms
    as needed.

    @returns {SC.Binding} this
  */
  resetTransforms: function () {
    var binding = (this === SC.Binding) ? this.beget() : this;
    binding._transforms = null;
    return binding;
  },

  /**
    Adds a transform to convert the value to a bool value.  If the value is
    an array it will return YES if array is not empty.  If the value is a string
    it will return YES if the string is not empty.

    @param {String} [fromPath]
    @returns {SC.Binding} this
  */
  bool: function (fromPath) {
    return this.from(fromPath).transform(function (v) {
      var t = SC.typeOf(v);
      if (t === SC.T_ERROR) return v;
      return (t == SC.T_ARRAY) ? (v.length > 0) : (v === '') ? NO : !!v;
    });
  },

  /**
    Adds a transform that will *always* return an integer Number value. Null and undefined values will
    return 0 while String values will be transformed using the parseInt method (according to the
    radix) and Boolean values will be 1 or 0 if true or false accordingly. Other edge cases like NaN
    or other non-Numbers will also return 0.

    Example results:

      * null => 0
      * undefined => 0
      * '123' => 123
      * true => 1
      * {} => 0

    @param {String} fromPathOrRadix from path or the radix for the parsing or null for 10
    @param {String} radix the radix for the parsing or null for 10
    @returns {SC.Binding} this
  */
  integer: function (fromPathOrRadix, radix) {
    // Normalize arguments.
    if (radix === undefined) {
      radix = fromPathOrRadix;
      fromPathOrRadix = null;
    }

    // Use base 10 by default.
    if (radix === undefined) radix = 10;

    return this.from(fromPathOrRadix).transform(function (value) {

      // Null or undefined will be converted to 0.
      if (SC.none(value)) {
        value = 0;

      // String values will be converted to integer Numbers using parseInt with the given radix.
      } else if (typeof value === SC.T_STRING) {
        value = window.parseInt(value, radix);

      // Boolean values will be converted to 0 or 1 accordingly.
      } else if (typeof value === SC.T_BOOL) {
        value = value ? 1 : 0;
      }

      // All other non-Number values will be converted to 0 (this includes bad String parses above).
      if (typeof value !== SC.T_NUMBER || isNaN(value)) {
        value = 0;
      }

      return value;
    });
  },

  /**
    Adds a transform that will return YES if the value is null or undefined, NO otherwise.

    @param {String} [fromPath]
    @returns {SC.Binding} this
  */
  isNull: function (fromPath) {
    return this.from(fromPath).transform(function (v) {
      var t = SC.typeOf(v);
      return (t === SC.T_ERROR) ? v : SC.none(v);
    });
  },

  /**
    Specifies that the binding should not return error objects.  If the value
    of a binding is an Error object, it will be transformed to a null value
    instead.

    Note that this is not a transform function since it will be called at the
    end of the transform chain.

    @param {String} [fromPath] from path to connect.
    @param {Boolean} [aFlag] Pass NO to allow error objects again.
    @returns {SC.Binding} this
  */
  noError: function (fromPath, aFlag) {
    // If fromPath is a bool but aFlag is undefined, swap.
    if ((aFlag === undefined) && (SC.typeOf(fromPath) === SC.T_BOOL)) {
      aFlag = fromPath;
      fromPath = null;
    }

    // beget if needed.
    var binding = this.from(fromPath);
    if (binding === SC.Binding) binding = binding.beget();
    binding._noError = (aFlag === undefined) ? YES : aFlag;

    return binding;
  },

  /**
    Adds a transform to convert the value to the inverse of a bool value.  This
    uses the same transform as bool() but inverts it.

    @param {String} [fromPath]
    @returns {SC.Binding} this
  */
  not: function (fromPath) {
    return this.from(fromPath).transform(function (v) {
      var t = SC.typeOf(v);
      if (t === SC.T_ERROR) return v;
      return !((t == SC.T_ARRAY) ? (v.length > 0) : (v === '') ? NO : !!v);
    });
  },

  /**
    Adds a transform that will convert the passed value to an array.  If
    the value is null or undefined, it will be converted to an empty array.

    @param {String} [fromPath]
    @returns {SC.Binding} this
  */
  multiple: function (fromPath) {
    return this.from(fromPath).transform(function (value) {
      /*jshint eqnull:true*/
      if (!SC.isArray(value)) value = (value == null) ? [] : [value];
      return value;
    });
  },

  /**
    Adds a transform that will return the placeholder value if the value is
    null, undefined, an empty array or an empty string.  See also notNull().

    @param {String} fromPath from path or null
    @param {Object} [placeholder]
    @returns {SC.Binding} this
  */
  notEmpty: function (fromPath, placeholder) {
    if (placeholder === undefined) placeholder = SC.EMPTY_PLACEHOLDER;
    return this.from(fromPath).transform(function (value, isForward) {
      if (SC.none(value) || (value === '') || (SC.isArray(value) && (value.get ? value.get('length') : value.length) === 0)) {
        value = placeholder;
      }
      return value;
    });
  },

  /**
    Adds a transform that will return the placeholder value if the value is
    null or undefined.  Otherwise it will pass through untouched.  See also notEmpty().

    @param {String} fromPath from path or null
    @param {Object} [placeholder]
    @returns {SC.Binding} this
  */
  notNull: function (fromPath, placeholder) {
    if (placeholder === undefined) placeholder = SC.EMPTY_PLACEHOLDER;
    return this.from(fromPath).transform(function (value, isForward) {
      if (SC.none(value)) value = placeholder;
      return value;
    });
  },

  /**
    Adds a transform to the chain that will allow only single values to pass.
    This will allow single values, nulls, and error values to pass through.  If
    you pass an array, it will be mapped as so:

          [] => null
          [a] => a
          [a,b,c] => Multiple Placeholder

    You can pass in an optional multiple placeholder or it will use the
    default.

    Note that this transform will only happen on forwarded valued.  Reverse
    values are send unchanged.

    @param {String} fromPath from path or null
    @param {Object} [placeholder] placeholder value.
    @returns {SC.Binding} this
  */
  single: function (fromPath, placeholder) {
    if (placeholder === undefined) {
      placeholder = SC.MULTIPLE_PLACEHOLDER;
    }
    return this.from(fromPath).transform(function (value, isForward) {
      if (value && value.isEnumerable) {
        var len = value.get('length');
        value = (len > 1) ? placeholder : (len <= 0) ? null : value.firstObject();
      }
      return value;
    });
  },

  /**
    Adds a transform that will *always* return a String value. Null and undefined values will return
    an empty string while all other non-String values will be transformed using the toString method.

    Example results:

      * null => ''
      * undefined => ''
      * 123 => '123'
      * true => 'true'
      * {} => '[object Object]' (i.e. x = {}; return x.toString())

    @param {String} fromPath from path or null
    @returns {SC.Binding} this
  */
  string: function (fromPath) {
    return this.from(fromPath).transform(function (value) {

      // Null or undefined will be converted to an empty string.
      if (SC.none(value)) {
        value = '';

      // Non-string values will be converted to strings using `toString`.
      } else if (typeof value !== SC.T_STRING && value.toString) {
        value = value.toString();
      }

      return value;
    });
  },

  /* @private Used by mix adapter bindings. */
  _sc_mixAdapterBinding: function (adapterClass) {
    var paths = [];

    


    // If either path is local, remove any * chains and append the localObject path to it.
    for (var i = 1; i < arguments.length; i++) {
      var path = arguments[i];

      if (path.indexOf('*') === 0 || path.indexOf('.') === 0) {
        path = path.slice(1).replace(/\*/g, '.');
        path = '*localObject.' + path;
      }
      paths.push( path );
    }

    // Gets the adapter class and instantiates a nice copy.
    var adapterHash = {
      localObject: null,
    };

    // create the oneWay bindings pointing to the real data sources.
    // for naming use a hardcoded convention 'value' + index of the property/path.
    // of course, these properties are internal so we are not concerned by the naming convention
    for (i = 0; i < paths.length; ++i) {
      var key = 'value' + i;
      adapterHash[key + 'Binding'] = SC.Binding.oneWay(paths[i]);
    }

    var adapter = adapterClass.create(adapterHash);

    // Creates and populates the return binding.
    var ret = this.from('aggregateProperty', adapter).oneWay();

    // This is all needed later on by beget, which must create a new adapter instance
    // or risk bad behavior.
    ret._MixAdapter = adapterClass;
    ret._mixAdapterHash = adapterHash;
    ret._mixAdapter = adapter;

    // On our way.
    return ret;
  },

  /** @private */
  _sc_mixImpl: function(paths, mixFunction) {
    var len = paths.length,
        properties = [];

    


    // Create the adapter class that eventually will contain bindings pointing to all values that will be processed
    // by mixFunction. The effective aggregation is done by another property that depends on all these local properties
    // and is invalidated whenever they change.
    // First of all, create the list of the property names that the aggregate property depends on.
    // The names of these dynamically created properties are matching the pattern
    // mentioned above (into _sc_mixAdapterBinding): 'value' + index of the property/path
    for (var i = 0; i < len; ++i) {
      properties.push('value' + i);
    }

    // Create a proxy SC.Object which will be bound to the each of the paths and contain a computed
    // property that will be dependent on all of the bound properties. The computed property will
    // return the result of the mix function.
    var adapter = SC.Object.extend({
      // Use SC.Function.property to be able to pass an array as arguments to .property
      aggregateProperty: SC.Function.property(function() {
        // Get an array of current values that will be passed to the mix function.
        var values = properties.map(function (name) {
                                      return this.get(name);
                                    }, this);

        // Call the mixFunction providing an array containing all current source property values.
        return mixFunction.apply(null, values);
      }, properties).cacheable()
    });

    return this._sc_mixAdapterBinding.apply(this, [adapter].concat(paths));
  },

  /**
    Adds a transform that returns the logical 'AND' of all the values at the provided paths. This is
    a quick and useful way to bind a `Boolean` property to two or more other `Boolean` properties.

    For example, imagine that we wanted to only enable a deletion button when an item in a list
    is selected *and* the current user is allowed to delete items. If these two values are set
    on controllers respectively at `MyApp.itemsController.hasSelection` and
    `MyApp.userController.canDelete`. We could do the following,

        deleteButton: SC.ButtonView.design({

          // Action & target for the button.
          action: 'deleteSelectedItem',
          target: MyApp.statechart,

          // Whether the list has a selection or not.
          listHasSelectionBinding: SC.Binding.oneWay('MyApp.itemsController.hasSelection'),

          // Whether the user can delete items or not.
          userCanDeleteBinding: SC.Binding.oneWay('MyApp.userController.canDelete'),

          // Note: Only enable when the list has a selection and the user is allowed!
          isEnabled: function () {
            return this.get('listHasSelection') && this.get('userCanDelete');
          }.property('listHasSelection', 'userCanDelete').cacheable()

        })

    However, this would be much simpler to write by using the `and` binding transform like so,

        deleteButton: SC.ButtonView.design({

          // Action & target for the button.
          action: 'deleteSelectedItem',
          target: MyApp.statechart,

          // Note: Only enable when the list has a selection and the user is allowed!
          isEnabledBinding: SC.Binding.and('MyApp.itemsController.hasSelection', 'MyApp.userController.canDelete')

        })

    *Note:* the transform acts strictly as a one-way binding, working only in the one direction.

    @param {String...} the property paths of source values that will be provided to the AND transform.
  */
  and: function () {
    // Fast copy.
    var len = arguments.length,
        paths = new Array(len);
    for (var i = 0; i < len; i++) { paths[i] = arguments[i]; }

    // Create a new mix implementation for the AND function.
    return this._sc_mixImpl(paths, function() {
      var result = true;

      for (i = 0; result && (i < arguments.length); i++) { // Bails early if any value is false.
        result = result && arguments[i];
      }

      return result;
    });
  },

  /**
    Adds a transform that returns the logical 'OR' of all the values at the provided paths. This is
    a quick and useful way to bind a `Boolean` property to two or more other `Boolean` properties.

    For example, imagine that we wanted to show a button when one or both of two values are present.
    If these two values are set on controllers respectively at `MyApp.profileController.hasDisplayName` and
    `MyApp.profileController.hasFullName`. We could do the following,

        saveButton: SC.ButtonView.design({

          // Action & target for the button.
          action: 'saveProfile',
          target: MyApp.statechart,

          // Whether the profile has a displayName or not.
          profileHasDisplayNameBinding: SC.Binding.oneWay('MyApp.profileController.hasDisplayName'),

          // Whether the profile has a fullName or not.
          profileHasFullNameBinding: SC.Binding.oneWay('MyApp.profileController.hasFullName'),

          // Note: Only show when the profile has a displayName or a fullName or both!
          isVisible: function () {
            return this.get('profileHasDisplayName') || this.get('profileHasFullName');
          }.property('profileHasDisplayName', 'profileHasFullName').cacheable()

        })

    However, this would be much simpler to write by using the `or` binding transform like so,

        saveButton: SC.ButtonView.design({

          // Action & target for the button.
          action: 'saveProfile',
          target: MyApp.statechart,

          // Note: Only show when the profile has a displayName or a fullName or both!
          isVisibleBinding: SC.Binding.or('MyApp.profileController.hasDisplayName', 'MyApp.profileController.hasFullName')

        })

    *Note:* the transform acts strictly as a one-way binding, working only in the one direction.

    @param {String...} the paths of source values that will be provided to the OR sequence.
  */
  or: function () {
    // Fast copy.
    var len = arguments.length,
        paths = new Array(len);
    for (var i = 0; i < len; i++) { paths[i] = arguments[i]; }

    // Create a new mix implementation for the OR function.
    return this._sc_mixImpl( paths, function() {
      var result = false;
      for (i = 0; !result && (i < arguments.length); i++) { // Bails early if any value is true.
        result = result || arguments[i];
      }

      return result;
    });
  },

  /**
    Adds a transform that aggregates through a given function the values at the provided paths. The
    given function is called whenever any of the values are updated. This is a quick way to
    aggregate multiple properties into a single property value.

    For example, to concatenate two properties 'MyApp.groupController.name' and
    'MyApp.userController.fullName', we could do the following,

        currentGroupUserLabel: SC.LabelView.extend({

          // The group name (may be null).
          groupNameBinding: SC.Binding.oneWay('MyApp.groupController.name'),

          // The user full name (may be null).
          userFullNameBinding: SC.Binding.oneWay('MyApp.userController.fullName'),

          // Ex. Returns one of "", "Selected Group", or "Selected Group: Selected User"
          value: function () {
            var groupName = this.get('groupName'),
                userFullName = this.get('userFullName');

            if (SC.none(userFullName)) {
              if (SC.none(groupName)) {
                return ''; // No group and no user.
              } else {
                return groupName; // Just a group.
              }
            } else {
              return '%@: %@'.fmt(groupName, userFullName); // Group and user.
            }
          }.property('groupName', 'userFullName').cacheable()

        })

    However, this is simpler (ex. 86 fewer characters) to write by using the `mix` binding transform like so,

        currentGroupUserLabel: SC.LabelView.extend({

          // Ex. Returns one of "", "Selected Group", or "Selected Group: Selected User"
          valueBinding: SC.Binding.mix(
            'MyApp.groupController.name', // The group name (may be null).
            'MyApp.userController.fullName', // The user full name (may be null).

            // Aggregate function. The arguments match the bound property values above.
            function (groupName, userFullName) {
              if (SC.none(userFullName)) {
                if (SC.none(groupName)) {
                  return ''; // No group and no user.
                } else {
                  return groupName; // Just a group.
                }
              } else {
                return '%@: %@'.fmt(groupName, userFullName); // Group and user.
              }
            })

        })

    *Note:* the number of parameters of `mixFunction` should match the number of paths provided.
    *Note:* the transform acts strictly as a one-way binding, working only in the one direction.

    @param {String...} the paths of source values that will be provided to the aggregate function.
    @param {Function} mixFunction the function that aggregates the values
  */
  mix: function() {
    var len = arguments.length - 1,
        paths = new Array(len);

    // Fast copy. The function is the last argument.
    for (var i = 0; i < len; i++) { paths[i] = arguments[i]; }

    return this._sc_mixImpl(paths, arguments[len]);
  },

  /**
    Adds a transform that will return YES if the value is equal to equalValue, NO otherwise.

      isVisibleBinding: SC.Binding.oneWay("MyApp.someController.title").equalTo(comparisonValue)

    Or:

      isVisibleBinding: SC.Binding.equalTo("MyApp.someController.title", comparisonValue)

    @param {String} fromPath from path or null
    @param {Object} equalValue the value to compare with
    @returns {SC.Binding} this
  */
  equalTo: function(fromPath, equalValue) {
    // Normalize arguments.
    if (equalValue === undefined) {
      equalValue = fromPath;
      fromPath = null;
    }

    return this.from(fromPath).transform(function(value, binding) {
       return value === equalValue;
     });
  },

  /** @private */
  toString: function () {
    var from = this._fromRoot ? "<%@>:%@".fmt(this._fromRoot, this._fromPropertyPath) : this._fromPropertyPath;

    var to = this._toRoot ? "<%@>:%@".fmt(this._toRoot, this._toPropertyPath) : this._toPropertyPath;

    var oneWay = this._oneWay ? '[oneWay]' : '';
    return "SC.Binding%@(%@ -> %@)%@".fmt(SC.guidFor(this), from, to, oneWay);
  }
};

/**
  Shorthand method to define a binding.  This is the same as calling:

        SC.binding(path) = SC.Binding.from(path)
*/
SC.binding = function (path, root) { return SC.Binding.from(path, root); };

/* >>>>>>>>>> BEGIN source/system/error.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
// @global SC

sc_require('ext/function');

/**
  @class

  An error, used to represent an error state.

  Many API's within SproutCore will return an instance of this object whenever
  they have an error occur.  An error includes an error code, description,
  and optional human readable label that indicates the item that failed.

  Depending on the error, other properties may also be added to the object
  to help you recover from the failure.

  You can pass error objects to various UI elements to display the error in
  the interface. You can easily determine if the value returned by some API is
  an error or not using the helper SC.ok(value).

  Faking Error Objects
  ---

  You can actually make any object you want to be treated like an Error object
  by simply implementing two properties: isError and errorValue.  If you
  set isError to YES, then calling SC.ok(obj) on your object will return NO.
  If isError is YES, then SC.val(obj) will return your errorValue property
  instead of the receiver.

  When using SC.typeOf(obj), SC.T_ERROR will only be returned if the obj
  is an instance of SC.Error

  @extends SC.Object
  @since SproutCore 1.0
*/
SC.Error = SC.Object.extend(
/** @scope SC.Error.prototype */ {

  /**
    error code.  Used to designate the error type.

    @type Number
  */
  code: -1,

  /**
    Human readable description of the error.  This can also be a non-localized
    key.

    @type String
  */
  message: '',

  /**
    The value the error represents.  This is used when wrapping a value inside
    of an error to represent the validation failure.

    @type Object
  */
  errorValue: null,

  /**
    The original error object.  Normally this will return the receiver.
    However, sometimes another object will masquerade as an error; this gives
    you a way to get at the underlying error.

    @type SC.Error
  */
  errorObject: function() {
    return this;
  }.property().cacheable(),

  /**
    Throw the error.

    @type SC.Error
  */
  'throw': function() {
    var error = this.toString();
    SC.Logger.error(error);

    throw new Error(error);
  },

  /**
    The error stacktrace.

    @type SC.Error
  */
  trace: function() {
    return (new Error()).trace;
  }.property().cacheable(),

  /**
    Human readable name of the item with the error.

    @type String
  */
  label: null,

  /** @private */
  toString: function() {
    return "SC.Error:%@:%@ (%@)".fmt(SC.guidFor(this), this.get('message'), this.get('code'));
  },

  /**
    Walk like a duck.

    @type Boolean
  */
  isError: YES
});

SC.Error.mixin({

  /**
    Creates a new SC.Error instance with the passed description, label, and
    code.  All parameters are optional.

    @param description {String} human readable description of the error
    @param label {String} human readable name of the item with the error
    @param code {Number} an error code to use for testing.
    @returns {SC.Error} new error instance.
  */
  desc: function(description, label, value, code) {
    var opts = { message: description } ;
    if (label !== undefined) opts.label = label ;
    if (code !== undefined) opts.code = code ;
    if (value !== undefined) opts.errorValue = value ;
    return this.create(opts) ;
  },

  /**
    Throw a new SC.Error instance with the passed description, label, and
    code.  All parameters are optional.

    @param description {String} human readable description of the error
    @param label {String} human readable name of the item with the error
    @param code {Number} an error code to use for testing.
    @returns {SC.Error} new error instance.
  */
  'throw': function(description, label, value, code) {
    this.desc.apply(this, arguments).throw();
  }

});

/**
  Shorthand form of the SC.Error.desc method.

  @param description {String} human readable description of the error
  @param label {String} human readable name of the item with the error
  @param code {Number} an error code to use for testing.
  @returns {SC.Error} new error instance.
*/
SC.$error = function(description, label, value, c) {
  return SC.Error.desc(description, label, value, c);
};

/**
  Shorthand form of the SC.Error.throw method.

  @param description {String} human readable description of the error
  @param label {String} human readable name of the item with the error
  @param code {Number} an error code to use for testing.
  @returns {SC.Error} new error instance.
*/
SC.throw = function(description, label, value, c) {
  SC.Error.throw(description, label, value, c);
};

/** @private */
SC.$throw = SC.throw;

/**
  Returns NO if the passed value is an error object or false.

  @param {Object} ret object value
  @returns {Boolean}
*/
SC.ok = function(ret) {
  return (ret !== false) && !(ret && ret.isError);
};

/** @private */
SC.$ok = SC.ok;

/**
  Returns the value of an object.  If the passed object is an error, returns
  the value associated with the error; otherwise returns the receiver itself.

  @param {Object} obj the object
  @returns {Object} value
*/
SC.val = function(obj) {
  if (obj && obj.isError) {
    return obj.get ? obj.get('errorValue') : null ; // Error has no value
  } else return obj ;
};

/** @private */
SC.$val = SC.val;

// STANDARD ERROR OBJECTS

/**
  Standard error code for errors that do not support multiple values.

  @type Number
*/
SC.Error.HAS_MULTIPLE_VALUES = -100 ;

/* >>>>>>>>>> BEGIN source/system/index_set.js */
// ==========================================================================
// Project:   SproutCore Costello - Property Observing Library
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('mixins/enumerable');
sc_require('mixins/observable');
sc_require('mixins/freezable');
sc_require('mixins/copyable');

/**
  @class

  A collection of ranges.  You can use an IndexSet to keep track of non-
  continuous ranges of items in a parent array.  IndexSet's are used for
  selection, for managing invalidation ranges and other data-propagation.

  Examples
  ---

        var set = SC.IndexSet.create(ranges);
        set.contains(index);
        set.add(index, length);
        set.remove(index, length);

        // uses a backing SC.Array object to return each index
        set.forEach(function (object) { .. })

        // returns ranges
        set.forEachRange(function (start, length) { .. });

  Implementation Notes
  ---

  An IndexSet stores indices on the object.  A positive value great than the
  index tells you the end of an occupied range.  A negative values tells you
  the end of an empty range.  A value less than the index is a search
  accelerator.  It tells you the start of the nearest range.

  @extends SC.Enumerable
  @extends SC.Observable
  @extends SC.Copyable
  @extends SC.Freezable
  @since SproutCore 1.0
*/
SC.IndexSet = SC.mixin({},
  SC.Observable, SC.Enumerable, SC.Freezable, SC.Copyable,
/** @scope SC.IndexSet.prototype */ {

  /** @private
    Walks a content array and copies its contents to a new array.  For large
    content arrays this is faster than using slice()
  */
  _sc_sliceContent: function (c) {
    if (c.length < 1000) return c.slice(); // use native when faster
    var cur = 0, ret = [], next = c[0];
    while(next !== 0) {
      ret[cur] = next;
      cur = (next<0) ? (0-next) : next;
      next = c[cur];
    }
    ret[cur] = 0;

    this._hint(0, cur, ret); // hints are not copied manually - add them
    return ret;
  },

  


  /**
    To create an empty IndexSet, call `create` with no arguments. To create a set with one index, call `create` with one
    argument: the index to add. To create a fuller set, call create with two arguments: the start index and the length to
    add.

    To create a more complicated set of indices, create an index set and populate individual ranges using `.add()`.

    @param {Number|SC.IndexSet} start The start of the range or an index set.
    @param {Number} [length] The length of the range (by default set to 1 if start is a Number)
    @returns {SC.IndexSet}
  */
  create: function (start, length) {
    


    var ret = SC.beget(this);
    ret.initObservable();
    ret.registerDependentKey('min', '[]');

    // optimized method to clone an index set.
    if (start && start.isIndexSet) {
      ret._content = this._sc_sliceContent(start._content);
      ret.max = start.max;
      ret.length = start.length;
      ret.source = start.source;

    // otherwise just do a regular add
    } else {
      ret._content = [0];
      if (start !== undefined) ret.add(start, length);
    }
    return ret;
  },

  /**
    Walk like a duck.

    @type Boolean
  */
  isIndexSet: YES,

  /**  @private
    Internal setting determines the preferred skip size for hinting sets.

    @type Number
  */
  HINT_SIZE: 256,

  /**
    Total number of indexes contained in the set

    @type Number
  */
  length: 0,

  /**
    One greater than the largest index currently stored in the set.  This
    is sometimes useful when determining the total range of items covering
    the index set.

    @type Number
  */
  max: 0,

  /**
    The first index included in the set or -1.

    @type Number
  */
  min: function () {
    var content = this._content,
        cur = content[0];
    return (cur === 0) ? -1 : (cur>0) ? 0 : Math.abs(cur);

  }.property('[]').cacheable(),

  /**
    Returns the first index in the set .

    @type Number
  */
  firstObject: function () {
    return (this.get('length')>0) ? this.get('min') : undefined;
  }.property(),

  /**
    Returns the starting index of the nearest range for the specified
    index.

    @param {Number} index
    @returns {Number} starting index
  */
  rangeStartForIndex: function (index) {
    var content = this._content,
        max     = this.get('max'),
        ret, next, accel;

    // fast cases
    if (index >= max) return max;
    if (Math.abs(content[index]) > index) return index; // we hit a border

    // use accelerator to find nearest content range
    accel = index - (index % SC.IndexSet.HINT_SIZE);
    ret = content[accel];

    // If there are no hints, we are in the infinite range.
    if (SC.none(ret)) { ret = this._infRange; }

    if (ret<0 || ret>index) ret = accel;
    next = content[ret];

    // the accelerator pointed to the middle of a range
    if (next === undefined) {
      next = this.rangeStartForIndex(ret);
    } else {
      next = Math.abs(next);
    }

    // now step forward through ranges until we find one that includes the
    // index.
    while (next < index) {
      ret = next;
      next = Math.abs(content[ret]);
    }
    return ret;
  },

  /**
    Returns YES if the passed index set contains the exact same indexes as
    the receiver.  If you pass any object other than an index set, returns NO.

    @param {Object} obj another object.
    @returns {Boolean}
  */
  isEqual: function (obj) {

    // optimize for some special cases
    if (obj === this) return YES;
    if (!obj || !obj.isIndexSet || (obj.max !== this.max) || (obj.length !== this.length)) return NO;

    // ok, now we need to actually compare the ranges of the two.
    var lcontent = this._content,
        rcontent = obj._content,
        cur      = 0,
        next     = lcontent[cur];

    do {
      if (rcontent[cur] !== next) return NO;
      cur = Math.abs(next);
      next = lcontent[cur];
    } while (cur !== 0);
    return YES;
  },

  /**
    Returns the first index in the set before the passed index or null if
    there are no previous indexes in the set.

    @param {Number} index index to check
    @returns {Number} index or -1
  */
  indexBefore: function (index) {

    if (index === 0) return -1; // fast path
    index--; // start with previous index

    var content = this._content,
        max     = this.get('max'),
        start   = this.rangeStartForIndex(index);
    if (!content) return null;

    if (!isFinite(start)) return index; // fast path

    // loop backwards until we find a range that is in the set.
    while((start===max) || (content[start]<0)) {
      if (start === 0) return -1; // nothing before; just quit
      index = start - 1;
      start = this.rangeStartForIndex(index);
    }

    return index;
  },

  /**
    Returns the first index in the set after the passed index or null if
    there are no additional indexes in the set.

    @param {Number} index index to check
    @returns {Number} index or -1
  */
  indexAfter: function (index) {
    var content = this._content,
        max     = this.get('max'),
        start, next;

    if (!content || (index >= max)) return -1; // fast path
    index++; // start with next index

    // loop forwards until we find a range that is in the set.
    start = this.rangeStartForIndex(index);
    next  = content[start];
    while(next<0) {
      if (next === 0) return -1; //nothing after; just quit
      index = start = Math.abs(next);
      next  = content[start];
    }

    return index;
  },

  /**
    Returns YES if the index set contains the named index

    @param {Number} start index or range
    @param {Number} length optional range length
    @returns {Boolean}
  */
  contains: function (start, length) {
    


    var content, cur, next, rstart, rnext;

    // normalize input
    if (length === undefined) {
      if (start === null || start === undefined) return NO;

      if (typeof start === SC.T_NUMBER) {
        length = 1;

      // if passed an index set, check each receiver range
      } else if (start && start.isIndexSet) {
        if (start === this) return YES; // optimization

        content = start._content;
        cur = 0;
        next = content[cur];
        while (next !== 0) {
          if ((next>0) && !this.contains(cur, next-cur)) return NO;
          cur = Math.abs(next);
          next = content[cur];
        }
        return YES;

      } else {
        length = start.length;
        start = start.start;
      }
    }

    rstart = this.rangeStartForIndex(start);
    if (isFinite(rstart)) {
      rnext  = this._content[rstart];

      return (rnext>0) && (rstart <= start) && (rnext >= (start+length));
    } else {
      return true;
    }
  },

  /**
    Returns YES if the index set contains any of the passed indexes.  You
    can pass a single index, a range or an index set.

    @param {Number} start index, range, or IndexSet
    @param {Number} length optional range length
    @returns {Boolean}
  */
  intersects: function (start, length) {
    


    var content, cur, next, lim;

    // normalize input
    if (length === undefined) {
      if (typeof start === SC.T_NUMBER) {
        length = 1;

      // if passed an index set, check each receiver range
      } else if (start && start.isIndexSet) {
        if (start === this) return YES; // optimization

        content = start._content;
        cur = 0;
        next = content[cur];
        while (next !== 0) {
          if ((next>0) && this.intersects(cur, next-cur)) return YES;
          cur = Math.abs(next);
          next = content[cur];
        }
        return NO;

      } else {
        length = start.length;
        start = start.start;
      }
    }

    cur     = this.rangeStartForIndex(start);
    content = this._content;
    next    = content[cur];
    lim     = start + length;
    while (cur < lim) {
      if (next === 0) return NO; // no match and at end!
      if ((next > 0) && (next > start)) return YES; // found a match
      cur = Math.abs(next);
      next = content[cur];
    }
    return NO; // no match
  },

  /**
    Returns a new IndexSet without the passed range or indexes.   This is a
    convenience over simply cloning and removing.  Does some optimizations.

    @param {Number} start index, range, or IndexSet
    @param {Number} length optional range length
    @returns {SC.IndexSet} new index set
  */
  without: function (start, length) {
    if (start === this) return SC.IndexSet.create(); // just need empty set
    return this.clone().remove(start, length);
  },

  /**
    Replace the index set's current content with the passed index set.  This
    is faster than clearing the index set adding the values again.

    @param {Number} start index, Range, or another IndexSet
    @param {Number} length optional length of range.
    @returns {SC.IndexSet} receiver
  */
  replace: function (start, length) {
    


    if (length === undefined) {
      if (typeof start === SC.T_NUMBER) {
        length = 1;
      } else if (start && start.isIndexSet) {
        this._content = this._sc_sliceContent(start._content);
        this.beginPropertyChanges()
          .set('max', start.max)
          .set('length', start.length)
          .set('source', start.source)
          .enumerableContentDidChange();
        this.endPropertyChanges();
        return this;

      } else {
        length = start.length;
        start  = start.start;
      }
    }

    this._content.length=1;
    this._content[0] = 0;
    this.length = this.max = 0; // reset without notifying since add()
    return this.add(start, length);
  },

  /**
    Adds the specified range of indexes to the set.  You can also pass another
    IndexSet to union the contents of the index set with the receiver.

    @param {Number} start Start index, Range, or another IndexSet
    @param {Number} [length=1] The length of range.
    @returns {SC.IndexSet} receiver
  */
  add: function (start, length) {
    


    if (this.isFrozen) throw new Error(SC.FROZEN_ERROR);

    var content, cur, next;

    // normalize IndexSet input
    if (start && start.isIndexSet) {

      content = start._content;

      if (!content) return this; // nothing to do

      cur = 0;
      next = content[0];
      while(next !== 0) {
        if (next>0) this.add(cur, next-cur);
        cur = next<0 ? 0-next : next;
        next = content[cur];
      }
      return this;

    } else if (length === undefined) {

      if (start === null || start === undefined) {
        return this; // nothing to do
      } else if (typeof start === SC.T_NUMBER) {
        length = 1;
      } else {
        length = start.length;
        start = start.start;
      }
    } else if (length === null) length = 1;

    // if no length - do nothing.
    if (length <= 0) return this;

    // special case - appending to end of set
    var max     = this.get('max'),
        oldmax  = max,
        delta, value;

    content = this._content;

    if (start === max) {

      // if adding to the end and the end is in set, merge.
      if (start > 0) {
        cur = this.rangeStartForIndex(start-1);
        next = content[cur];

        // just extend range at end
        if (next > 0) {
          delete content[max]; // no 0
          content[cur] = max = start + length;
          start = cur;

        // previous range was not in set, just tack onto the end
        } else {
          content[max] = max = start + length;
        }
      } else {
        content[start] = max = length;
      }

      content[max] = 0;
      this.set('max', max);
      this.set('length', this.length + length);
      length = max - start;

    } else if (start > max) {
      content[max] = 0-start; // empty!
      content[start] = start+length;
      content[start+length] = 0; // set end
      this.set('max', start + length);
      this.set('length', this.length + length);

      // affected range goes from starting range to end of content.
      length = start + length - max;
      start = max;

    // otherwise, merge into existing range
    } else {

      // find nearest starting range.  split or join that range
      cur   = this.rangeStartForIndex(start);
      next  = content[cur];
      max   = start + length;
      delta = 0;

      // we are right on a boundary and we had a range or were the end, then
      // go back one more.
      if ((start>0) && (cur === start) && (next <= 0)) {
        cur = this.rangeStartForIndex(start-1);
        next = content[cur];
      }

      // previous range is not in set.  splice it here
      if (next < 0) {
        content[cur] = 0-start;

        // if previous range extends beyond this range, splice afterwards also
        if (Math.abs(next) > max) {
          content[start] = 0-max;
          content[max] = next;
        } else content[start] = next;

      // previous range is in set.  merge the ranges
      } else {
        start = cur;
        if (next > max) {
          // delta -= next - max;
          max = next;
        }
      }

      // at this point there should be clean starting point for the range.
      // just walk the ranges, adding up the length delta and then removing
      // the range until we find a range that passes last
      cur = start;
      while (cur < max) {
        // get next boundary.  splice if needed - if value is 0, we are at end
        // just skip to last
        value = content[cur];
        if (value === 0) {
          content[max] = 0;
          next = max;
          delta += max - cur;
        } else {
          next  = Math.abs(value);
          if (next > max) {
            content[max] = value;
            next = max;
          }

          // ok, cur range is entirely inside top range.
          // add to delta if needed
          if (value < 0) delta += next - cur;
        }

        delete content[cur]; // and remove range
        cur = next;
      }

      // cur should always === last now.  if the following range is in set,
      // merge in also - don't adjust delta because these aren't new indexes
      if ((cur = content[max]) > 0) {
        delete content[max];
        max = cur;
      }

      // finally set my own range.
      content[start] = max;
      if (max > oldmax) this.set('max', max);

      // adjust length
      this.set('length', this.get('length') + delta);

      // compute hint range
      length = max - start;
    }

    this._hint(start, length);
    if (delta !== 0) this.enumerableContentDidChange();
    return this;
  },

  /**
    Removes the specified range of indexes from the set

    @param {Number} start index, Range, or IndexSet
    @param {Number} length optional length of range.
    @returns {SC.IndexSet} receiver
  */
  remove: function (start, length) {
    


    if (this.isFrozen) throw new Error(SC.FROZEN_ERROR);

    // normalize input
    if (length === undefined) {
      if (start === null || start === undefined) {
        return this; // nothing to do

      } else if (typeof start === SC.T_NUMBER) {
        length = 1;

      // if passed an index set, just add each range in the index set.
      } else if (start.isIndexSet) {
        start.forEachRange(this.remove, this);
        return this;

      } else {
        length = start.length;
        start = start.start;
      }
    }

    if (length <= 0) return this; // nothing to do

    // special case - appending to end of set
    var max     = this.get('max'),
        content = this._content,
        cur, next, delta, value, last;

    // if we're past the end, do nothing.
    if (start >= max) return this;

    // find nearest starting range.  split or join that range
    cur   = this.rangeStartForIndex(start);
    next  = content[cur];
    last  = start + length;
    delta = 0;

    // we are right on a boundary and we had a range or were the end, then
    // go back one more.
    if ((start > 0) && (cur === start) && (next > 0)) {
      cur = this.rangeStartForIndex(start-1);
      next = content[cur];
    }

    // previous range is in set.  splice it here
    if (next > 0) {
      content[cur] = start;

      // if previous range extends beyond this range, splice afterwards also
      if (next > last) {
        content[start] = last;
        content[last] = next;
      } else content[start] = next;

    // previous range is not in set.  merge the ranges
    } else {
      start = cur;
      next  = Math.abs(next);
      if (next > last) {
        last = next;
      }
    }

    // If splicing into the infinite range, we have to add hints up to the start
    // of the splice and adjust our pointer to the start of the infinite range.
    if (!isFinite(next)) {
      this._hint(cur, start - cur);

      // Infinite range
      this._infRange = last;
    }

    // at this point there should be clean starting point for the range.
    // just walk the ranges, adding up the length delta and then removing
    // the range until we find a range that passes last
    cur = start;
    while (cur < last) {
      // get next boundary.  splice if needed - if value is 0, we are at end
      // just skip to last
      value = content[cur];
      if (value === 0) {
        content[last] = 0;
        next = last;

      } else {
        next  = Math.abs(value);
        if (next > last) {
          content[last] = value;
          next = last;
        }

        // ok, cur range is entirely inside top range.
        // add to delta if needed
        if (value > 0) delta += next - cur;
      }

      delete content[cur]; // and remove range
      cur = next;
    }

    // cur should always === last now.  if the following range is not in set,
    // merge in also - don't adjust delta because these aren't new indexes
    if ((cur = content[last]) < 0) {
      delete content[last];
      last = Math.abs(cur);
    }

    // set my own range - if the next item is 0, then clear it.
    if (content[last] === 0) {
      delete content[last];
      content[start] = 0;
      this.set('max', start); //max has changed

    } else {
      content[start] = 0-last;
    }

    // adjust length
    if (isFinite(delta)) {
      this.set('length', this.get('length') - delta);
    } else {
      this.set('length', 0);
    }

    // compute hint range.  Constrain it to the length of the content.
    length = Math.min(content.length, last - start);

    this._hint(start, length);
    if (delta !== 0) this.enumerableContentDidChange();
    return this;
  },

  /** @private
    iterates through a named range, setting hints every HINT_SIZE indexes
    pointing to the nearest range start.  The passed range must start on a
    range boundary.  It can end anywhere.
  */
  _hint: function (start, length, content) {
    if (content === undefined) content = this._content;

    var skip    = SC.IndexSet.HINT_SIZE,
        next    = Math.abs(content[start]), // start of next range
        loc     = start - (start % skip) + skip, // next hint loc
        lim     = start + length; // stop

    while (loc < lim) {
      // make sure we are in current range
      while ((next !== 0) && (next <= loc)) {
        start = next;
        next  = Math.abs(content[start]);
      }

      // past end
      if (next === 0) {
        delete content[loc];

      } else if (!isFinite(next)) {
        // We can't hint the infinite range the normal way.  Instead we have a
        // single pointer to the start of the infinite range that we use when
        // no hints exist.
        this._infRange = start;
        loc = Infinity;

      // do not change if on actual boundary
      } else if (loc !== start) {
        content[loc] = start;  // set hint
      }

      loc += skip;
    }
  },

  /**
    Clears the set
  */
  clear: function () {
    if (this.isFrozen) throw new Error(SC.FROZEN_ERROR);

    var oldlen = this.length;
    this._content.length = 1;
    this._content[0] = 0;
    this._infRange = null;
    this.set('length', 0).set('max', 0);
    if (oldlen > 0) this.enumerableContentDidChange();
  },

  /**
    Add all the ranges in the passed array.

    @param {Enumerable} objects The list of ranges you want to add
  */
  addEach: function (objects) {
    if (this.isFrozen) throw new Error(SC.FROZEN_ERROR);

    this.beginPropertyChanges();
    var idx = objects.get('length');
    if (objects.isSCArray) {
      while(--idx >= 0) this.add(objects.objectAt(idx));
    } else if (objects.isEnumerable) {
      objects.forEach(function (idx) { this.add(idx); }, this);
    }
    this.endPropertyChanges();

    return this;
  },

  /**
    Removes all the ranges in the passed array.

    @param {Object...} objects The list of objects you want to remove
  */
  removeEach: function (objects) {
    if (this.isFrozen) throw new Error(SC.FROZEN_ERROR);

    this.beginPropertyChanges();

    var idx = objects.get('length');
    if (objects.isSCArray) {
      while(--idx >= 0) this.remove(objects.objectAt(idx));
    } else if (objects.isEnumerable) {
      objects.forEach(function (idx) { this.remove(idx); }, this);
    }

    this.endPropertyChanges();

    return this;
  },

  /**
   Clones the set into a new set.
  */
  clone: function () {
    return SC.IndexSet.create(this);
  },

  /**
    Returns a string describing the internal range structure.  Useful for
    debugging.

    @returns {String}
  */
  inspect: function () {
    var content = this._content,
        len     = content.length,
        idx     = 0,
        ret     = [],
        item;

    for(idx=0;idx<len;idx++) {
      item = content[idx];
      if (item !== undefined) ret.push("%@:%@".fmt(idx,item));
    }
    return "SC.IndexSet<%@>".fmt(ret.join(' , '));
  },

  /**
    Invoke the callback, passing each occupied range instead of each
    index.  This can be a more efficient way to iterate in some cases.  The
    callback should have the signature:

          callback(start, length, indexSet, source) { ... }

    If you pass a target as a second option, the callback will be called in
    the target context.

    @param {Function} callback The method to run on each iteration
    @param {Object} target the object to call the callback on
    @returns {SC.IndexSet} receiver
  */
  forEachRange: function (callback, target) {
    var content = this._content,
        cur     = 0,
        next    = content[cur],
        source  = this.source;

    if (target === undefined) target = null;
    while (next !== 0) {
      if (next > 0) callback.call(target, cur, next - cur, this, source);
      cur  = Math.abs(next);
      next = content[cur];
    }

    return this;
  },

  /**
    Invokes the callback for each index within the passed start/length range.
    Otherwise works just like regular forEach().

    @param {Number} start starting index
    @param {Number} length length of range
    @param {Function} callback
    @param {Object} target
    @returns {SC.IndexSet} receiver
  */
  forEachIn: function (start, length, callback, target) {
    var content = this._content,
        cur     = 0,
        idx     = 0,
        lim     = start + length,
        source  = this.source,
        next    = content[cur];

    if (target === undefined) target = null;
    while (next !== 0) {
      if (cur < start) cur = start; // skip forward
      while((cur < next) && (cur < lim)) {
        callback.call(target, cur++, idx++, this, source);
      }

      if (cur >= lim) {
        cur = next = 0;
      } else {
        cur  = Math.abs(next);
        next = content[cur];
      }
    }
    return this;
  },

  /**
    Total number of indexes within the specified range.

    @param {Number|SC.IndexSet} start index, range object or IndexSet
    @param {Number} length optional range length
    @returns {Number} count of indexes
  */
  lengthIn: function (start, length) {
    


    var ret = 0;

    // normalize input
    if (length === undefined) {
      if (start === null || start === undefined) {
        return 0; // nothing to do

      } else if (typeof start === SC.T_NUMBER) {
        length = 1;

      // if passed an index set, just add each range in the index set.
      } else if (start.isIndexSet) {
        start.forEachRange(function (start, length) {
          ret += this.lengthIn(start, length);
        }, this);
        return ret;

      } else {
        length = start.length;
        start = start.start;
      }
    }

    // fast path
    if (this.get('length') === 0) return 0;

    var content = this._content,
        cur     = 0,
        next    = content[cur],
        lim     = start + length;

    while (cur<lim && next !== 0) {
      if (next>0) {
        ret += (next>lim) ? lim-cur : next-cur;
      }
      cur  = Math.abs(next);
      next = content[cur];
    }

    return ret;
  },

  // ..........................................................
  // OBJECT API
  //

  /**
    Optionally set the source property on an index set and then you can
    iterate over the actual object values referenced by the index set.  See
    indexOf(), lastIndexOf(), forEachObject(), addObject() and removeObject().
  */
  source: null,

  /**
    Returns the first index in the set that matches the passed object.  You
    must have a source property on the set for this to work.

    @param {Object} object the object to check
    @param {Number} startAt optional starting point
    @returns {Number} found index or -1 if not in set
  */
  indexOf: function (object, startAt) {
    var source  = this.source;
    if (!source) throw new Error("%@.indexOf() requires source".fmt(this));

    var len     = source.get('length'),

        // start with the first index in the set
        content = this._content,
        cur     = content[0]<0 ? Math.abs(content[0]) : 0,
        idx;

    while(cur>=0 && cur<len) {
      idx = source.indexOf(object, cur);
      if (idx<0) return -1; // not found in source
      if (this.contains(idx)) return idx; // found in source and in set.
      cur = idx+1;
    }

    return -1; // not found
  },

  /**
    Returns the last index in the set that matches the passed object.  You
    must have a source property on the set for this to work.

    @param {Object} object the object to check
    @param {Number} startAt optional starting point
    @returns {Number} found index or -1 if not in set
  */
  lastIndexOf: function (object, startAt) {
    var source  = this.source;
    if (!source) throw new Error("%@.lastIndexOf() requires source".fmt(this));

    // start with the last index in the set
    var len     = source.get('length'),
        cur     = this.max-1,
        idx;

    if (cur >= len) cur = len-1;
    while (cur>=0) {
      idx = source.lastIndexOf(object, cur);
      if (idx<0) return -1; // not found in source
      if (this.contains(idx)) return idx; // found in source and in set.
      cur = idx+1;
    }

    return -1; // not found
  },

  /**
    Iterates through the objects at each index location in the set.  You must
    have a source property on the set for this to work.  The callback you pass
    will be invoked for each object in the set with the following signature:

          function callback(object, index, source, indexSet) { ... }

    If you pass a target, it will be used when the callback is called.

    @param {Function} callback function to invoke.
    @param {Object} target optional content. otherwise uses window
    @returns {SC.IndexSet} receiver
  */
  forEachObject: function (callback, target) {
    var source  = this.source;
    if (!source) throw new Error("%@.forEachObject() requires source".fmt(this));

    var content = this._content,
        cur     = 0,
        next    = content[cur];

    if (target === undefined) target = null;
    while (next !== 0) {

      while(cur < next) {
        callback.call(target, source.objectAt(cur), cur, source, this);
        cur++;
      }

      cur  = Math.abs(next);
      next = content[cur];
    }
    return this;
  },

  /**
    Adds all indexes where the object appears to the set.  If firstOnly is
    passed, then it will find only the first index and add it.  If  you know
    the object only appears in the source array one time, firstOnly may make
    this method faster.

    Requires source to work.

    @param {Object} object the object to add
    @param {Boolean} firstOnly Set to true if you can assume that the first
       match is the only one
    @returns {SC.IndexSet} receiver
  */
  addObject: function (object, firstOnly) {
    var source  = this.source;
    if (!source) throw new Error("%@.addObject() requires source".fmt(this));

    var len = source.get('length'),
        cur = 0, idx;

    while(cur>=0 && cur<len) {
      idx = source.indexOf(object, cur);
      if (idx >= 0) {
        this.add(idx);
        if (firstOnly) return this;
        cur = idx++;
      } else return this;
    }
    return this;
  },

  /**
    Adds any indexes matching the passed objects.  If firstOnly is passed,
    then only finds the first index for each object.

    @param {SC.Enumerable} objects the objects to add
    @param {Boolean} firstOnly Set to true if you can assume that the first
       match is the only one
    @returns {SC.IndexSet} receiver
  */
  addObjects: function (objects, firstOnly) {
    objects.forEach(function (object) {
      this.addObject(object, firstOnly);
    }, this);
    return this;
  },

  /**
    Removes all indexes where the object appears to the set.  If firstOnly is
    passed, then it will find only the first index and add it.  If  you know
    the object only appears in the source array one time, firstOnly may make
    this method faster.

    Requires source to work.

    @param {Object} object the object to add
    @param {Boolean} firstOnly Set to true if you can assume that the first
       match is the only one
    @returns {SC.IndexSet} receiver
  */
  removeObject: function (object, firstOnly) {
    var source  = this.source;
    if (!source) throw new Error("%@.removeObject() requires source".fmt(this));

    var len = source.get('length'),
        cur = 0, idx;

    while(cur>=0 && cur<len) {
      idx = source.indexOf(object, cur);
      if (idx >= 0) {
        this.remove(idx);
        if (firstOnly) return this;
        cur = idx+1;
      } else return this;
    }
    return this;
  },

  /**
    Removes any indexes matching the passed objects.  If firstOnly is passed,
    then only finds the first index for each object.

    @param {SC.Enumerable} objects the objects to add
    @param {Boolean} firstOnly Set to true if you can assume that the first
       match is the only one
    @returns {SC.IndexSet} receiver
  */
  removeObjects: function (objects, firstOnly) {
    objects.forEach(function (object) {
      this.removeObject(object, firstOnly);
    }, this);
    return this;
  },


  // .......................................
  // PRIVATE
  //

  /**
    Usually observing notifications from IndexSet are not useful, so
    suppress them by default.

    @type Boolean
  */
  LOG_OBSERVING: NO,

  /** @private - optimized call to forEach() */
  forEach: function (callback, target) {
    var content = this._content,
        cur     = 0,
        idx     = 0,
        source  = this.source,
        next    = content[cur];

    if (target === undefined) target = null;
    while (next !== 0) {
      if (isFinite(next)) {
        while(cur < next) {
          callback.call(target, cur++, idx++, this, source);
        }
        cur  = Math.abs(next);
        next = content[cur];
      } else {
        throw new Error("Developer Error: You may not iterate an infinite range in SC.IndexSet.");
      }
    }
    return this;
  },

  /** @private - support iterators */
  nextObject: function (ignore, idx, context) {
    var content = this._content,
        next    = context.next,
        max     = this.get('max'); // next boundary

    // seed.
    if (idx === null) {
      idx = next = 0;

    } else if (idx >= max) {
      delete context.next; // cleanup context
      return null; // nothing left to do

    } else idx++; // look on next index

    // look for next non-empty range if needed.
    if (idx === next) {
      do {
        idx = Math.abs(next);
        next = content[idx];
      } while(next < 0);
      context.next = next;
    }

    return idx;
  },

  toString: function () {
    var str = [];
    this.forEachRange(function (start, length) {
      str.push(length === 1 ? start : "%@..%@".fmt(start, start + length - 1));
    }, this);
    return "SC.IndexSet<%@>".fmt(str.join(','));
  }

});

SC.IndexSet.slice = SC.IndexSet.copy = SC.IndexSet.clone;
SC.IndexSet.EMPTY = SC.IndexSet.create().freeze();

/* >>>>>>>>>> BEGIN source/system/json.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

SC.json = {
  
  /**
    Encodes an object graph to a JSON output.  Beware that JSON cannot deal
    with circular references.  If you try to encode an object graph with
    references it could hang your browser.
    
    @param {Object} root object graph
    @returns {String} encode JSON
  */
  encode: function(root) {
    return JSON.stringify(root) ;
  },
  
  /**
    Decodes a JSON file in a safe way, returning the generated object graph.
  
    @param {String} encoded JSON
    @returns {Object} object graph or Error if there was a problem.
  */
  decode: function(root) {
    return JSON.parse(root) ;
  }

} ;

/*
    http://www.JSON.org/json2.js
    2010-03-20

    Public Domain.

    NO WARRANTY EXPRESSED OR IMPLIED. USE AT YOUR OWN RISK.

    See http://www.JSON.org/js.html


    This code should be minified before deployment.
    See http://javascript.crockford.com/jsmin.html

    USE YOUR OWN COPY. IT IS EXTREMELY UNWISE TO LOAD CODE FROM SERVERS YOU DO
    NOT CONTROL.


    This file creates a global JSON object containing two methods: stringify
    and parse.

        JSON.stringify(value, replacer, space)
            value       any JavaScript value, usually an object or array.

            replacer    an optional parameter that determines how object
                        values are stringified for objects. It can be a
                        function or an array of strings.

            space       an optional parameter that specifies the indentation
                        of nested structures. If it is omitted, the text will
                        be packed without extra whitespace. If it is a number,
                        it will specify the number of spaces to indent at each
                        level. If it is a string (such as '\t' or '&nbsp;'),
                        it contains the characters used to indent at each level.

            This method produces a JSON text from a JavaScript value.

            When an object value is found, if the object contains a toJSON
            method, its toJSON method will be called and the result will be
            stringified. A toJSON method does not serialize: it returns the
            value represented by the name/value pair that should be serialized,
            or undefined if nothing should be serialized. The toJSON method
            will be passed the key associated with the value, and this will be
            bound to the value

            For example, this would serialize Dates as ISO strings.

                Date.prototype.toJSON = function (key) {
                    function f(n) {
                        // Format integers to have at least two digits.
                        return n < 10 ? '0' + n : n;
                    }

                    return this.getUTCFullYear()   + '-' +
                         f(this.getUTCMonth() + 1) + '-' +
                         f(this.getUTCDate())      + 'T' +
                         f(this.getUTCHours())     + ':' +
                         f(this.getUTCMinutes())   + ':' +
                         f(this.getUTCSeconds())   + 'Z';
                };

            You can provide an optional replacer method. It will be passed the
            key and value of each member, with this bound to the containing
            object. The value that is returned from your method will be
            serialized. If your method returns undefined, then the member will
            be excluded from the serialization.

            If the replacer parameter is an array of strings, then it will be
            used to select the members to be serialized. It filters the results
            such that only members with keys listed in the replacer array are
            stringified.

            Values that do not have JSON representations, such as undefined or
            functions, will not be serialized. Such values in objects will be
            dropped; in arrays they will be replaced with null. You can use
            a replacer function to replace those with JSON values.
            JSON.stringify(undefined) returns undefined.

            The optional space parameter produces a stringification of the
            value that is filled with line breaks and indentation to make it
            easier to read.

            If the space parameter is a non-empty string, then that string will
            be used for indentation. If the space parameter is a number, then
            the indentation will be that many spaces.

            Example:

            text = JSON.stringify(['e', {pluribus: 'unum'}]);
            // text is '["e",{"pluribus":"unum"}]'


            text = JSON.stringify(['e', {pluribus: 'unum'}], null, '\t');
            // text is '[\n\t"e",\n\t{\n\t\t"pluribus": "unum"\n\t}\n]'

            text = JSON.stringify([new Date()], function (key, value) {
                return this[key] instanceof Date ?
                    'Date(' + this[key] + ')' : value;
            });
            // text is '["Date(---current time---)"]'


        JSON.parse(text, reviver)
            This method parses a JSON text to produce an object or array.
            It can throw a SyntaxError exception.

            The optional reviver parameter is a function that can filter and
            transform the results. It receives each of the keys and values,
            and its return value is used instead of the original value.
            If it returns what it received, then the structure is not modified.
            If it returns undefined then the member is deleted.

            Example:

            // Parse the text. Values that look like ISO date strings will
            // be converted to Date objects.

            myData = JSON.parse(text, function (key, value) {
                var a;
                if (typeof value === 'string') {
                    a =
/^(\d{4})-(\d{2})-(\d{2})T(\d{2}):(\d{2}):(\d{2}(?:\.\d*)?)Z$/.exec(value);
                    if (a) {
                        return new Date(Date.UTC(+a[1], +a[2] - 1, +a[3], +a[4],
                            +a[5], +a[6]));
                    }
                }
                return value;
            });

            myData = JSON.parse('["Date(09/09/2001)"]', function (key, value) {
                var d;
                if (typeof value === 'string' &&
                        value.slice(0, 5) === 'Date(' &&
                        value.slice(-1) === ')') {
                    d = new Date(value.slice(5, -1));
                    if (d) {
                        return d;
                    }
                }
                return value;
            });


    This is a reference implementation. You are free to copy, modify, or
    redistribute.
*/

/*jslint evil: true, strict: false */

/*members "", "\b", "\t", "\n", "\f", "\r", "\"", JSON, "\\", apply,
    call, charCodeAt, getUTCDate, getUTCFullYear, getUTCHours,
    getUTCMinutes, getUTCMonth, getUTCSeconds, hasOwnProperty, join,
    lastIndex, length, parse, prototype, push, replace, slice, stringify,
    test, toJSON, toString, valueOf
*/


// Create a JSON object only if one does not already exist. We create the
// methods in a closure to avoid creating global variables.

if (!this.JSON) {
    this.JSON = {};
}

(function () {

    function f(n) {
        // Format integers to have at least two digits.
        return n < 10 ? '0' + n : n;
    }

    if (typeof Date.prototype.toJSON !== 'function') {

        Date.prototype.toJSON = function (key) {

            return isFinite(this.valueOf()) ?
                   this.getUTCFullYear()   + '-' +
                 f(this.getUTCMonth() + 1) + '-' +
                 f(this.getUTCDate())      + 'T' +
                 f(this.getUTCHours())     + ':' +
                 f(this.getUTCMinutes())   + ':' +
                 f(this.getUTCSeconds())   + 'Z' : null;
        };

        String.prototype.toJSON =
        Number.prototype.toJSON =
        Boolean.prototype.toJSON = function (key) {
            return this.valueOf();
        };
    }

    var cx = /[\u0000\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,
        escapable = /[\\\"\x00-\x1f\x7f-\x9f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,
        gap,
        indent,
        meta = {    // table of character substitutions
            '\b': '\\b',
            '\t': '\\t',
            '\n': '\\n',
            '\f': '\\f',
            '\r': '\\r',
            '"' : '\\"',
            '\\': '\\\\'
        },
        rep;


    function quote(string) {

// If the string contains no control characters, no quote characters, and no
// backslash characters, then we can safely slap some quotes around it.
// Otherwise we must also replace the offending characters with safe escape
// sequences.

        escapable.lastIndex = 0;
        return escapable.test(string) ?
            '"' + string.replace(escapable, function (a) {
                var c = meta[a];
                return typeof c === 'string' ? c :
                    '\\u' + ('0000' + a.charCodeAt(0).toString(16)).slice(-4);
            }) + '"' :
            '"' + string + '"';
    }


    function str(key, holder) {

// Produce a string from holder[key].

        var i,          // The loop counter.
            k,          // The member key.
            v,          // The member value.
            length,
            mind = gap,
            partial,
            value = holder[key];

// If the value has a toJSON method, call it to obtain a replacement value.

        if (value && typeof value === 'object' &&
                typeof value.toJSON === 'function') {
            value = value.toJSON(key);
        }

// If we were called with a replacer function, then call the replacer to
// obtain a replacement value.

        if (typeof rep === 'function') {
            value = rep.call(holder, key, value);
        }

// What happens next depends on the value's type.

        switch (typeof value) {
        case 'string':
            return quote(value);

        case 'number':

// JSON numbers must be finite. Encode non-finite numbers as null.

            return isFinite(value) ? String(value) : 'null';

        case 'boolean':
        case 'null':

// If the value is a boolean or null, convert it to a string. Note:
// typeof null does not produce 'null'. The case is included here in
// the remote chance that this gets fixed someday.

            return String(value);

// If the type is 'object', we might be dealing with an object or an array or
// null.

        case 'object':

// Due to a specification blunder in ECMAScript, typeof null is 'object',
// so watch out for that case.

            if (!value) {
                return 'null';
            }

// Make an array to hold the partial results of stringifying this object value.

            gap += indent;
            partial = [];

// Is the value an array?

            if (Object.prototype.toString.apply(value) === '[object Array]') {

// The value is an array. Stringify every element. Use null as a placeholder
// for non-JSON values.

                length = value.length;
                for (i = 0; i < length; i += 1) {
                    partial[i] = str(i, value) || 'null';
                }

// Join all of the elements together, separated with commas, and wrap them in
// brackets.

                v = partial.length === 0 ? '[]' :
                    gap ? '[\n' + gap +
                            partial.join(',\n' + gap) + '\n' +
                                mind + ']' :
                          '[' + partial.join(',') + ']';
                gap = mind;
                return v;
            }

// If the replacer is an array, use it to select the members to be stringified.

            if (rep && typeof rep === 'object') {
                length = rep.length;
                for (i = 0; i < length; i += 1) {
                    k = rep[i];
                    if (typeof k === 'string') {
                        v = str(k, value);
                        if (v) {
                            partial.push(quote(k) + (gap ? ': ' : ':') + v);
                        }
                    }
                }
            } else {

// Otherwise, iterate through all of the keys in the object.

                for (k in value) {
                    if (Object.hasOwnProperty.call(value, k)) {
                        v = str(k, value);
                        if (v) {
                            partial.push(quote(k) + (gap ? ': ' : ':') + v);
                        }
                    }
                }
            }

// Join all of the member texts together, separated with commas,
// and wrap them in braces.

            v = partial.length === 0 ? '{}' :
                gap ? '{\n' + gap + partial.join(',\n' + gap) + '\n' +
                        mind + '}' : '{' + partial.join(',') + '}';
            gap = mind;
            return v;
        }
    }

// If the JSON object does not yet have a stringify method, give it one.

    if (typeof JSON.stringify !== 'function') {
        JSON.stringify = function (value, replacer, space) {

// The stringify method takes a value and an optional replacer, and an optional
// space parameter, and returns a JSON text. The replacer can be a function
// that can replace values, or an array of strings that will select the keys.
// A default replacer method can be provided. Use of the space parameter can
// produce text that is more easily readable.

            var i;
            gap = '';
            indent = '';

// If the space parameter is a number, make an indent string containing that
// many spaces.

            if (typeof space === 'number') {
                for (i = 0; i < space; i += 1) {
                    indent += ' ';
                }

// If the space parameter is a string, it will be used as the indent string.

            } else if (typeof space === 'string') {
                indent = space;
            }

// If there is a replacer, it must be a function or an array.
// Otherwise, throw an error.

            rep = replacer;
            if (replacer && typeof replacer !== 'function' &&
                    (typeof replacer !== 'object' ||
                     typeof replacer.length !== 'number')) {
                throw new Error('JSON.stringify');
            }

// Make a fake root object containing our value under the key of ''.
// Return the result of stringifying the value.

            return str('', {'': value});
        };
    }


// If the JSON object does not yet have a parse method, give it one.

    if (typeof JSON.parse !== 'function') {
        JSON.parse = function (text, reviver) {

// The parse method takes a text and an optional reviver function, and returns
// a JavaScript value if the text is a valid JSON text.

            var j;

            function walk(holder, key) {

// The walk method is used to recursively walk the resulting structure so
// that modifications can be made.

                var k, v, value = holder[key];
                if (value && typeof value === 'object') {
                    for (k in value) {
                        if (Object.hasOwnProperty.call(value, k)) {
                            v = walk(value, k);
                            if (v !== undefined) {
                                value[k] = v;
                            } else {
                                delete value[k];
                            }
                        }
                    }
                }
                return reviver.call(holder, key, value);
            }


// Parsing happens in four stages. In the first stage, we replace certain
// Unicode characters with escape sequences. JavaScript handles many characters
// incorrectly, either silently deleting them, or treating them as line endings.

            text = String(text);
            cx.lastIndex = 0;
            if (cx.test(text)) {
                text = text.replace(cx, function (a) {
                    return '\\u' +
                        ('0000' + a.charCodeAt(0).toString(16)).slice(-4);
                });
            }

// In the second stage, we run the text against regular expressions that look
// for non-JSON patterns. We are especially concerned with '()' and 'new'
// because they can cause invocation, and '=' because it can cause mutation.
// But just to be safe, we want to reject all unexpected forms.

// We split the second stage into 4 regexp operations in order to work around
// crippling inefficiencies in IE's and Safari's regexp engines. First we
// replace the JSON backslash pairs with '@' (a non-JSON character). Second, we
// replace all simple value tokens with ']' characters. Third, we delete all
// open brackets that follow a colon or comma or that begin the text. Finally,
// we look to see that the remaining characters are only whitespace or ']' or
// ',' or ':' or '{' or '}'. If that is so, then the text is safe for eval.

            if (/^[\],:{}\s]*$/.
test(text.replace(/\\(?:["\\\/bfnrt]|u[0-9a-fA-F]{4})/g, '@').
replace(/"[^"\\\n\r]*"|true|false|null|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?/g, ']').
replace(/(?:^|:|,)(?:\s*\[)+/g, ''))) {

// In the third stage we use the eval function to compile the text into a
// JavaScript structure. The '{' operator is subject to a syntactic ambiguity
// in JavaScript: it can begin a block or an object literal. We wrap the text
// in parens to eliminate the ambiguity.

                j = eval('(' + text + ')');

// In the optional fourth stage, we recursively walk the new structure, passing
// each name/value pair to a reviver function for possible transformation.

                return typeof reviver === 'function' ?
                    walk({'': j}, '') : j;
            }

// If the text is not JSON parseable, then a SyntaxError is thrown.

            throw new SyntaxError('JSON.parse');
        };
    }
}());

/* >>>>>>>>>> BEGIN source/system/logger.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('ext/function');

// ..........................................................
// CONSTANTS
//

// Implementation note:  We use two spaces after four-letter prefixes and one
// after five-letter prefixes so things align in monospaced consoles.

/**
  If {@link SC.Logger.format} is true, this delimiter will be put between arguments.

  @type String
*/
SC.LOGGER_LOG_DELIMITER = ", ";

/**
  If {@link SC.Logger.error} falls back onto {@link SC.Logger.log}, this will be
  prepended to the output.

  @type String
*/
SC.LOGGER_LOG_ERROR = "ERROR: ";

/**
  If {@link SC.Logger.info} falls back onto {@link SC.Logger.log}, this will be
  prepended to the output.

  @type String
*/
SC.LOGGER_LOG_INFO = "INFO:  ";

/**
  If {@link SC.Logger.warn} falls back onto {@link SC.Logger.log}, this will be
  prepended to the output.

  @type String
*/
SC.LOGGER_LOG_WARN = "WARN:  ";

/**
  If {@link SC.Logger.debug} falls back onto {@link SC.Logger.log}, this will be
  prepended to the output.

  @type String
*/
SC.LOGGER_LOG_DEBUG = "DEBUG: ";

/**
  If {@link SC.Logger.group} falls back onto {@link SC.Logger.log}, this will
  be prepended to the output.

  @type String
*/
SC.LOGGER_LOG_GROUP_HEADER = "** %@";       // The variable is the group title

/**
  If the reporter does not support group(), then we’ll add our own indentation
  to our output.  This constant represents one level of indentation.

  @type String
*/
SC.LOGGER_LOG_GROUP_INDENTATION = "    ";

/**
  When reporting recorded log messages, the timestamp is included with this
  prefix.

  @type String
*/
SC.LOGGER_RECORDED_LOG_TIMESTAMP_PREFIX = "%@:  ";


SC.LOGGER_LEVEL_DEBUG = 'debug';
SC.LOGGER_LEVEL_INFO  = 'info';
SC.LOGGER_LEVEL_WARN  = 'warn';
SC.LOGGER_LEVEL_ERROR = 'error';
SC.LOGGER_LEVEL_NONE  = 'none';



/** @class

  Object to allow for safe logging actions, such as using the browser console.
  In addition to being output to the console, logs can be optionally recorded
  in memory, to be accessed by your application as appropriate.

  This class also adds in the concept of a “current log level”, which allows
  your application to potentially determine a subset of logging messages to
  output and/or record.  The order of levels is:

    -  debug        SC.LOGGER_LEVEL_DEBUG
    -  info         SC.LOGGER_LEVEL_INFO
    -  warn         SC.LOGGER_LEVEL_WARN
    -  error        SC.LOGGER_LEVEL_ERROR

  All messages at the level or “above” will be output/recorded.  So, for
  example, if you set the level to 'info', all 'info', 'warn', and 'error'
  messages will be output/recorded, but no 'debug' messages will be.  Also,
  there are two separate log levels:  one for output, and one for recording.
  You may wish to only output, say, 'warn' and above, but record everything
  from 'debug' on up.  (You can also limit the number log messages to record.)

  This mechanism allows your application to avoid needless output (which has a
  non-zero cost in many browsers) in the general case, but turning up the log
  level when necessary for debugging.  Note that there can still be a
  performance cost for preparing log messages (calling {@link String.fmt},
  etc.), so it’s still a good idea to be selective about what log messages are
  output even to 'debug', especially in hot code.

  Similarly, you should be aware that if you wish to log objects without
  stringification — using the {@link SC.Logger.debugWithoutFmt} variants — and
  you enable recording, the “recorded messages” array will hold onto a
  reference to the arguments, potentially increasing the amount of memory
  used.

  As a convenience, this class also adds some shorthand methods to SC:

    -  SC.debug()   ==>   SC.Logger.debug()
    -  SC.info()    ==>   SC.Logger.info()
    -  SC.warn()    ==>   SC.Logger.warn()
    -  SC.error()   ==>   SC.Logger.error()

  …although note that no shorthand versions exist for the less-common
  functions, such as defining groups.

  The FireFox plugin Firebug was used as a function reference. Please see
  [Firebug Logging Reference](http://getfirebug.com/logging.html)
  for further information.

  @author Colin Campbell
  @author Benedikt Böhm
  @author William Kakes
  @extends SC.Object
  @since SproutCore 1.0
  @see <a href="http://getfirebug.com/logging.html">Firebug Logging Reference</a>
*/
SC.Logger = SC.Object.create(
	/** @scope SC.Logger.prototype */{

  // ..........................................................
  // PROPERTIES
  //

  /**
    An optional prefix that will be prepended to all log messages, but not any
    group titles.

    @type String
  */
  messagePrefix: null,


  /**
    An optional prefix that will be prepended to all log messages that are
    output to the browser console, but not those that are recorded.  If you
    specify both this and a 'messagePrefix', both will be output, and only the
    'messagePrefix' will be recorded.

    @type String
  */
  outputMessagePrefix: null,


  /**
    An optional prefix that will be prepended to all log messages that are
    recorded, but not those that are output to the browser console.  If you
    specify both this and a 'messagePrefix', both will be recorded, and only the
    'messagePrefix' will be output to the browser console.

    @type String
  */
  recordedMessagePrefix: null,


  /**
    The current log level determining what is output to the reporter object
    (usually your browser’s console).  Valid values are:

      -  SC.LOGGER_LEVEL_DEBUG
      -  SC.LOGGER_LEVEL_INFO
      -  SC.LOGGER_LEVEL_WARN
      -  SC.LOGGER_LEVEL_ERROR
      -  SC.LOGGER_LEVEL_NONE

    If you do not specify this value, it will default to SC.LOGGER_LEVEL_DEBUG
    when running in development mode and SC.LOGGER_LEVEL_INFO when running in
    production mode.

    @property: {Constant}
  */
  logOutputLevel: null,        // If null, set appropriately during init()


  /**
    The current log level determining what is recorded to the
    'recordedLogMessages' buffer.  Valid values are the same as with
    'logOutputLevel':

      -  SC.LOGGER_LEVEL_DEBUG
      -  SC.LOGGER_LEVEL_INFO
      -  SC.LOGGER_LEVEL_WARN
      -  SC.LOGGER_LEVEL_ERROR
      -  SC.LOGGER_LEVEL_NONE

    If you do not specify this value, it will default to SC.LOGGER_LEVEL_NONE.

    @type Constant
  */
  logRecordingLevel: SC.LOGGER_LEVEL_NONE,


  /**
    All recorded log messages.  You generally should not need to interact with
    this array, as most commonly-used functionality can be achieved via the
    {@link SC.Logger.outputRecordedLogMessages} and
    {@link SC.Logger.stringifyRecordedLogMessages} methods.

    This array will be lazily created when the first message is recorded.

    Format:

    For efficiency, each entry in the array is a simple hash rather than a
    full SC.Object instance.  Furthermore, to minimize memory usage, niceties
    like “type of entry: message” are avoided; if you need to parse this
    structure, you can determine which type of entry you’re looking at by
    checking for the 'message' and 'indentation' fields.
<pre>
    Log entry:
    {
      type:               {Constant}     (SC.LOGGER_LEVEL_DEBUG, etc.)
      message:            {String | Boolean}
      originalArguments:  {Arguments}    // optional
      timestamp:          {Date}
    }

    Group entry (either beginning or end of):
    {
      type:         {Constant}     SC.LOGGER_LEVEL_DEBUG, etc.
      indentation:  {Number}       The value is the new group indentation level
      beginGroup:   {Boolean}      Whether this entry is the beginning of a new group (as opposed to the end)
      title:        {String}       Optional for new groups, and never present for end-of-group
      timestamp:    {Date}
    }
</pre>

    @type Array
  */
  recordedLogMessages: null,


  /**
    If the recording level is set such that messages will be recorded, this is
    the maximum number of messages that will be saved in the
    'recordedLogMessages' array.  Any further recorded messages will push
    older messages out of the array, so the most recent messages will be
    saved.

    @type Number
  */
  recordedLogMessagesMaximumLength: 500,


  /**
    If the recording level is set such that messages will be recorded, this is
    the minimum number of messages that will be saved whenever the recordings
    are pruned.  (They are pruned whenever you hit the maximum length, as
    specified via the 'recordedLogMessagesMaximumLength' property.  This
    mechanism avoids thrashing the array for each log message once the
    maximum is reached.)  When pruning, the most recent messages will be saved.

    @type Number
  */
  recordedLogMessagesPruningMinimumLength: 100,


  /**
    Whether or not to enable debug logging.  This property exists for
    backwards compatibility with previous versions of SC.Logger.  In newer
    code, you should instead set the appropriate output/recording log levels.

    If this property is set to YES, it will set 'logOutputLevel' to
    SC.LOGGER_LEVEL_DEBUG.  Otherwise, it will have no effect.

    @deprecated Set the log level instead.
    @property: {Boolean}
  */
  debugEnabled: NO,


  /**
    Computed property that checks for the existence of the reporter object.

    @type Boolean
  */
  exists: function() {
    return !SC.none(this.get('reporter'));
  }.property('reporter').cacheable(),


  /**
    If console.log does not exist, SC.Logger will use window.alert instead
    when {@link SC.Logger.log} is invoked.

    Note that this property has no effect for messages initiated via the
    debug/info/warn/error methods, on the assumption that it is better to
    simply utilize the message recording mechanism than put up a bunch of
    alerts when there is no browser console.

    @type Boolean
  */
  fallBackOnAlert: NO,


  /**
    The reporter is the object which implements the actual logging functions.

    @default The browser’s console
    @type Object
  */
  reporter: console,




  // ..........................................................
  // METHODS
  //

  /**
    Logs a debug message to the console and potentially to the recorded
    array, provided the respective log levels are set appropriately.

    The first argument must be a string, and if there are any additional
    arguments, it is assumed to be a format string.  Thus, you can (and
    should) use it like:

        SC.Logger.debug("%@:  My debug message", this);       // good

    …and not:

        SC.Logger.debug("%@:  My debug message".fmt(this));        // bad

    The former method can be more efficient because if the log levels are set
    in such a way that the debug() invocation will be ignored, then the
    String.fmt() call will never actually be performed.

    @param {String}              A message or a format string
    @param {…}       (optional)  Other arguments to pass to String.fmt() when using a format string
  */
  debug: function(message, optionalFormatArgs) {
    // Implementation note:  To avoid having to put the SC.debug() shorthand
    // variant inside a function wrapper, we'll avoid 'this'.
    SC.Logger._handleMessage(SC.LOGGER_LEVEL_DEBUG, YES, message, arguments);
  },


  /**
    Logs a debug message to the console and potentially to the recorded
    array, provided the respective log levels are set appropriately.

    Unlike simply debug(), this method does not try to apply String.fmt() to
    the arguments, and instead passes them directly to the reporter (and
    stringifies them if recording).  This can be useful if the browser formats
    a type in a manner more useful to you than you can achieve with
    String.fmt().

    @param {String|Array|Function|Object}
  */
  debugWithoutFmt: function() {
    this._handleMessage(SC.LOGGER_LEVEL_DEBUG, NO, null, arguments);
  },


  /**
    Begins a new group in the console and/or in the recorded array provided
    the respective log levels are set to output/record 'debug' messages.
    Every message after this call (at any log level) will be indented for
    readability until a matching {@link SC.Logger.debugGroupEnd} is invoked,
    and you can create as many levels as you want.

    Assuming you are using 'debug' messages elsewhere, it is preferable to
    group them using this method over simply {@link SC.Logger.group} — the log
    levels could be set such that the 'debug' messages are never seen, and you
    wouldn’t want an empty/needless group!

    You can optionally provide a title for the group.  If there are any
    additional arguments, the first argument is assumed to be a format string.
    Thus, you can (and should) use it like:

          SC.Logger.debugGroup("%@:  My debug group", this);       // good

    …and not:

          SC.Logger.debugGroup("%@:  My debug group".fmt(this));   // bad

    The former method can be more efficient because if the log levels are set
    in such a way that the debug() invocation will be ignored, then the
    String.fmt() call will never actually be performed.

    @param {String}  (optional)  A title or format string to display above the group
    @param {…}       (optional)  Other arguments to pass to String.fmt() when using a format string as the title
  */
  debugGroup: function(message, optionalFormatArgs) {
    // Implementation note:  To avoid having to put the SC.debugGroup()
    // shorthand variant inside a function wrapper, we'll avoid 'this'.
    SC.Logger._handleGroup(SC.LOGGER_LEVEL_DEBUG, message, arguments);
  },


  /**
    Ends a group initiated with {@link SC.Logger.debugGroup}, provided the
    respective output/recording log levels are set appropriately.

    @see SC.Logger.debugGroup
  */
  debugGroupEnd: function() {
    // Implementation note:  To avoid having to put the SC.debugGroupEnd()
    // shorthand variant inside a function wrapper, we'll avoid 'this'.
    SC.Logger._handleGroupEnd(SC.LOGGER_LEVEL_DEBUG);
  },



  /**
    Logs an informational message to the console and potentially to the
    recorded array, provided the respective log levels are set appropriately.

    The first argument must be a string, and if there are any additional
    arguments, it is assumed to be a format string.  Thus, you can (and
    should) use it like:

          SC.Logger.info("%@:  My info message", this);       // good

    …and not:

          SC.Logger.info("%@:  My info message".fmt(this));   // bad

    The former method can be more efficient because if the log levels are set
    in such a way that the info() invocation will be ignored, then the
    String.fmt() call will never actually be performed.

    @param {String}              A message or a format string
    @param {…}       (optional)  Other arguments to pass to String.fmt() when using a format string
  */
  info: function(message, optionalFormatArgs) {
    // Implementation note:  To avoid having to put the SC.info() shorthand
    // variant inside a function wrapper, we'll avoid 'this'.
    SC.Logger._handleMessage(SC.LOGGER_LEVEL_INFO, YES, message, arguments);
  },


  /**
    Logs an information message to the console and potentially to the recorded
    array, provided the respective log levels are set appropriately.

    Unlike simply info(), this method does not try to apply String.fmt() to
    the arguments, and instead passes them directly to the reporter (and
    stringifies them if recording).  This can be useful if the browser formats
    a type in a manner more useful to you than you can achieve with
    String.fmt().

    @param {String|Array|Function|Object}
  */
  infoWithoutFmt: function() {
    this._handleMessage(SC.LOGGER_LEVEL_INFO, NO, null, arguments);
  },


  /**
    Begins a new group in the console and/or in the recorded array provided
    the respective log levels are set to output/record 'info' messages.
    Every message after this call (at any log level) will be indented for
    readability until a matching {@link SC.Logger.infoGroupEnd} is invoked,
    and you can create as many levels as you want.

    Assuming you are using 'info' messages elsewhere, it is preferable to
    group them using this method over simply {@link SC.Logger.group} — the log
    levels could be set such that the 'info' messages are never seen, and you
    wouldn’t want an empty/needless group!

    You can optionally provide a title for the group.  If there are any
    additional arguments, the first argument is assumed to be a format string.
    Thus, you can (and should) use it like:

          SC.Logger.infoGroup("%@:  My info group", this);       // good

    …and not:

          SC.Logger.infoGroup("%@:  My info group".fmt(this));   // bad

    The former method can be more efficient because if the log levels are set
    in such a way that the info() invocation will be ignored, then the
    String.fmt() call will never actually be performed.

    @param {String}  (optional)  A title or format string to display above the group
    @param {…}       (optional)  Other arguments to pass to String.fmt() when using a format string as the title
  */
  infoGroup: function(message, optionalFormatArgs) {
    // Implementation note:  To avoid having to put the SC.infoGroup()
    // shorthand variant inside a function wrapper, we'll avoid 'this'.
    SC.Logger._handleGroup(SC.LOGGER_LEVEL_INFO, message, arguments);
  },


  /**
    Ends a group initiated with {@link SC.Logger.infoGroup}, provided the
    respective output/recording log levels are set appropriately.

    @see SC.Logger.infoGroup
  */
  infoGroupEnd: function() {
    // Implementation note:  To avoid having to put the SC.infoGroupEnd()
    // shorthand variant inside a function wrapper, we'll avoid 'this'.
    SC.Logger._handleGroupEnd(SC.LOGGER_LEVEL_INFO);
  },



  /**
    Logs a warning message to the console and potentially to the recorded
    array, provided the respective log levels are set appropriately.

    The first argument must be a string, and if there are any additional
    arguments, it is assumed to be a format string.  Thus, you can (and
    should) use it like:

          SC.Logger.warn("%@:  My warning message", this);       // good

    …and not:

          SC.Logger.warn("%@:  My warning message".fmt(this));   // bad

    The former method can be more efficient because if the log levels are set
    in such a way that the warn() invocation will be ignored, then the
    String.fmt() call will never actually be performed.

    @param {String}              A message or a format string
    @param {…}       (optional)  Other arguments to pass to String.fmt() when using a format string
  */
  warn: function(message, optionalFormatArgs) {
    // Implementation note:  To avoid having to put the SC.warn() shorthand
    // variant inside a function wrapper, we'll avoid 'this'.
    SC.Logger._handleMessage(SC.LOGGER_LEVEL_WARN, YES, message, arguments);

  },


  /**
    Logs a warning message to the console and potentially to the recorded
    array, provided the respective log levels are set appropriately.

    Unlike simply warn(), this method does not try to apply String.fmt() to
    the arguments, and instead passes them directly to the reporter (and
    stringifies them if recording).  This can be useful if the browser formats
    a type in a manner more useful to you than you can achieve with
    String.fmt().

    @param {String|Array|Function|Object}
  */
  warnWithoutFmt: function() {
    this._handleMessage(SC.LOGGER_LEVEL_WARN, NO, null, arguments);
  },


  /**
    Begins a new group in the console and/or in the recorded array provided
    the respective log levels are set to output/record 'warn' messages.
    Every message after this call (at any log level) will be indented for
    readability until a matching {@link SC.Logger.warnGroupEnd} is invoked,
    and you can create as many levels as you want.

    Assuming you are using 'warn' messages elsewhere, it is preferable to
    group them using this method over simply {@link SC.Logger.group} — the log
    levels could be set such that the 'warn' messages are never seen, and you
    wouldn’t want an empty/needless group!

    You can optionally provide a title for the group.  If there are any
    additional arguments, the first argument is assumed to be a format string.
    Thus, you can (and should) use it like:

          SC.Logger.warnGroup("%@:  My warn group", this);       // good

    …and not:

          SC.Logger.warnGroup("%@:  My warn group".fmt(this));   // bad

    The former method can be more efficient because if the log levels are set
    in such a way that the warn() invocation will be ignored, then the
    String.fmt() call will never actually be performed.

    @param {String}  (optional)  A title or format string to display above the group
    @param {…}       (optional)  Other arguments to pass to String.fmt() when using a format string as the title
  */
  warnGroup: function(message, optionalFormatArgs) {
    // Implementation note:  To avoid having to put the SC.warnGroup()
    // shorthand variant inside a function wrapper, we'll avoid 'this'.
    SC.Logger._handleGroup(SC.LOGGER_LEVEL_WARN, message, arguments);
  },


  /**
    Ends a group initiated with {@link SC.Logger.warnGroup}, provided the
    respective output/recording log levels are set appropriately.

    @see SC.Logger.warnGroup
  */
  warnGroupEnd: function() {
    // Implementation note:  To avoid having to put the SC.warnGroupEnd()
    // shorthand variant inside a function wrapper, we'll avoid 'this'.
    SC.Logger._handleGroupEnd(SC.LOGGER_LEVEL_WARN);
  },


  /**
    Logs an error message to the console and potentially to the recorded
    array, provided the respective log levels are set appropriately.

    The first argument must be a string, and if there are any additional
    arguments, it is assumed to be a format string.  Thus, you can (and
    should) use it like:

          SC.Logger.error("%@:  My error message", this);       // good

    …and not:

          SC.Logger.warn("%@:  My error message".fmt(this));    // bad

    The former method can be more efficient because if the log levels are set
    in such a way that the warn() invocation will be ignored, then the
    String.fmt() call will never actually be performed.

    @param {String}              A message or a format string
    @param {…}       (optional)  Other arguments to pass to String.fmt() when using a format string
  */
  error: function(message, optionalFormatArgs) {
    // Implementation note:  To avoid having to put the SC.error() shorthand
    // variant inside a function wrapper, we'll avoid 'this'.
    SC.Logger._handleMessage(SC.LOGGER_LEVEL_ERROR, YES, message, arguments);
  },


  /**
    Logs an error message to the console and potentially to the recorded
    array, provided the respective log levels are set appropriately.

    Unlike simply error(), this method does not try to apply String.fmt() to
    the arguments, and instead passes them directly to the reporter (and
    stringifies them if recording).  This can be useful if the browser formats
    a type in a manner more useful to you than you can achieve with
    String.fmt().

    @param {String|Array|Function|Object}
  */
  errorWithoutFmt: function() {
    this._handleMessage(SC.LOGGER_LEVEL_ERROR, NO, null, arguments);
  },


  /**
    Begins a new group in the console and/or in the recorded array provided
    the respective log levels are set to output/record 'error' messages.
    Every message after this call (at any log level) will be indented for
    readability until a matching {@link SC.Logger.errorGroupEnd} is invoked,
    and you can create as many levels as you want.

    Assuming you are using 'error' messages elsewhere, it is preferable to
    group them using this method over simply {@link SC.Logger.group} — the log
    levels could be set such that the 'error' messages are never seen, and you
    wouldn’t want an empty/needless group!

    You can optionally provide a title for the group.  If there are any
    additional arguments, the first argument is assumed to be a format string.
    Thus, you can (and should) use it like:

          SC.Logger.errorGroup("%@:  My error group", this);       // good

    …and not:

          SC.Logger.errorGroup("%@:  My error group".fmt(this));   // bad

    The former method can be more efficient because if the log levels are set
    in such a way that the error() invocation will be ignored, then the
    String.fmt() call will never actually be performed.

    @param {String}  (optional)  A title or format string to display above the group
    @param {…}       (optional)  Other arguments to pass to String.fmt() when using a format string as the title
  */
  errorGroup: function(message, optionalFormatArgs) {
    // Implementation note:  To avoid having to put the SC.errorGroup()
    // shorthand variant inside a function wrapper, we'll avoid 'this'.
    SC.Logger._handleGroup(SC.LOGGER_LEVEL_ERROR, message, arguments);
  },


  /**
    Ends a group initiated with {@link SC.Logger.errorGroup}, provided the
    respective output/recording log levels are set appropriately.

    @see SC.Logger.errorGroup
  */
  errorGroupEnd: function() {
    // Implementation note:  To avoid having to put the SC.errorGroupEnd()
    // shorthand variant inside a function wrapper, we'll avoid 'this'.
    SC.Logger._handleGroupEnd(SC.LOGGER_LEVEL_ERROR);
  },



  /**
    This method will output all recorded log messages to the reporter.  This
    provides a convenient way to see the messages “on-demand” without having
    to have them always output.  The timestamp of each message will be
    included as a prefix if you specify 'includeTimestamps' as YES, although
    in some browsers the native group indenting can make the timestamp
    formatting less than ideal.

    @param {Boolean}  (optional)  Whether to include timestamps in the output
  */
  outputRecordedLogMessages: function(includeTimestamps) {
    // If we have no reporter, there's nothing we can do.
    if (!this.get('exists')) return;

    var reporter        = this.get('reporter'),
        entries         = this.get('recordedLogMessages'),
        indentation     = 0,
        timestampFormat = SC.LOGGER_RECORDED_LOG_TIMESTAMP_PREFIX,
        i, iLen, entry, type, timestampStr, message, originalArguments,
        output, title, newIndentation, disparity, j, jLen;

    if (entries) {
      for (i = 0, iLen = entries.length;  i < iLen;  ++i) {
        entry        = entries[i];
        type         = entry.type;

        if (includeTimestamps) {
          timestampStr = timestampFormat.fmt(entry.timestamp.toUTCString());
        }

        // Is this a message or a group directive?
        message = entry.message;
        if (message) {
          // It's a message entry.  Were the original arguments stored?  If
          // so, we need to use those instead of the message.
          originalArguments = entry.originalArguments;
          this._outputMessage(type, timestampStr, indentation, message, originalArguments);
        }
        else {
          // It's a group directive.  Update our indentation appropriately.
          newIndentation = entry.indentation;
          title          = entry.title;
          disparity      = newIndentation - indentation;

          // If the reporter implements group() and the indentation level
          // changes by more than 1, that implies that some earlier “begin
          // group” / “end group” directives were pruned from the beginning of
          // the buffer and we need to insert empty groups to compensate.
          if (reporter.group) {
            if (Math.abs(disparity) > 1) {
              for (j = 0, jLen = (disparity - 1);  j < jLen;  ++j) {
                if (disparity > 0) {
                  reporter.group();
                }
                else {
                  reporter.groupEnd();
                }
              }
            }

            if (disparity > 0) {
              output = timestampStr ? timestampStr : "";
              output += title;
              reporter.group(output);
            }
            else {
              reporter.groupEnd();
            }
          }
          else {
            // The reporter doesn't implement group()?  Then simulate it using
            // log(), assuming it implements that.
            if (disparity > 0) {
              // We're beginning a group.  Output the header at an indentation
              // that is one smaller.
              this._outputGroup(type, timestampStr, newIndentation - 1, title);
            }
            // else {}  (There is no need to simulate a group ending.)
          }

          // Update our indentation.
          indentation = newIndentation;
        }
      }
    }
  },


  /**
    This method will return a string representation of all recorded log
    messages to the reporter, which can be convenient for saving logs and so
    forth.  The timestamp of each message will be included in the string.

    If there are no recorded log messages, an empty string will be returned
    (as opposed to null).

    @returns {String}
  */
  stringifyRecordedLogMessages: function() {
    var ret           = "",
        entries       = this.get('recordedLogMessages'),
        indentation   = 0,
        timestampFormat = SC.LOGGER_RECORDED_LOG_TIMESTAMP_PREFIX,
        prefixMapping = this._LOG_FALLBACK_PREFIX_MAPPING,
        groupHeader   = SC.LOGGER_LOG_GROUP_HEADER,
        i, iLen, entry, type, message, originalArguments, prefix, line,
        title, newIndentation, disparity;

    if (entries) {
      for (i = 0, iLen = entries.length;  i < iLen;  ++i) {
        entry = entries[i];
        type  = entry.type;

        // First determine the prefix.
        prefix = timestampFormat.fmt(entry.timestamp.toUTCString());
        prefix += prefixMapping[type] || "";

        // Is this a message or a group directive?
        message = entry.message;
        if (message) {
          // It's a message entry.  Were arguments used, or did we format a
          // message?  If arguments were used, we need to stringify those
          // instead of using the message.
          originalArguments = entry.originalArguments;
          line =  prefix + this._indentation(indentation);
          line += originalArguments ? this._argumentsToString(originalArguments) : message;
        }
        else {
          // It's a group directive, so we need to update our indentation
          // appropriately.  Also, if it's the beginning of the group and it
          // has a title, then we need to include an appropriate header.
          newIndentation = entry.indentation;
          title          = entry.title;
          disparity      = newIndentation - indentation;
          if (disparity > 0) {
            // We're beginning a group.  Output the header at an indentation
            // that is one smaller.
            line = prefix + this._indentation(indentation) + groupHeader.fmt(title);
          }

          // Update our indentation.
          indentation = newIndentation;
        }

        // Add the line to our string.
        ret += line + "\n";
      }
    }
    return ret;
  },



  /**
    Log output to the console, but only if it exists.

    IMPORTANT:  Unlike debug(), info(), warn(), and error(), messages sent to
    this method do not consult the log level and will always be output.
    Similarly, they will never be recorded.

    In general, you should avoid this method and instead choose the
    appropriate categorization for your message, choosing the appropriate
    method.

    @param {String|Array|Function|Object}
    @returns {Boolean} Whether or not anything was logged
  */
  log: function() {
    var reporter     = this.get('reporter'),
        message      = arguments[0],
        prefix       = this.get('messagePrefix'),
        outputPrefix = this.get('outputMessagePrefix'),
        ret          = NO;

    // If the first argument is a string and a prefix was specified, use it.
    if (message  &&  SC.typeOf(message) === SC.T_STRING) {
      if (prefix  ||  outputPrefix) {
        if (prefix)       message = prefix       + message;
        if (outputPrefix) message = outputPrefix + message;
        arguments[0] = message;
      }
    }

    // Log through the reporter.
    if (this.get('exists')) {
      if (typeof reporter.log === "function") {
        reporter.log.apply(reporter, arguments);
        ret = YES;
      }
      else if (reporter.log) {
        // IE8 implements console.log but reports the type of console.log as
        // "object", so we cannot use apply().  Because of this, the best we
        // can do is call it directly with an array of our arguments.
        reporter.log(this._argumentsToArray(arguments));
        ret = YES;
      }
    }

    // log through alert
    if (!ret  &&  this.get('fallBackOnAlert')) {
      // include support for overriding the alert through the reporter
      // if it has come this far, it's likely this will fail
      if (this.get('exists')  &&  (typeof reporter.alert === "function")) {
        reporter.alert(arguments);
        ret = YES;
      }
      else {
        alert(arguments);
        ret = YES;
      }
    }
    return ret;
  },


  /**
    Every log after this call until {@link SC.Logger.groupEnd} is called
    will be indented for readability.  You can create as many levels
    as you want.

    IMPORTANT:  Unlike debugGroup(), infoGroup(), warnGroup(), and
    errorGroup(), this method do not consult the log level and will always
    result in output when the reporter supports it.  Similarly, group messages
    logged via this method will never be recorded.

    @param {String}  (optional)  An optional title to display above the group
  */
  group: function(title) {
    var reporter = this.get('reporter');

    if (this.get('exists')  &&  (typeof reporter.group === "function")) {
      reporter.group(title);
    }
  },

  /**
    Ends a group declared with {@link SC.Logger.group}.

    @see SC.Logger.group
  */
  groupEnd: function() {
    var reporter = this.get('reporter');

    if (this.get('exists')  &&  (typeof reporter.groupEnd === "function")) {
      reporter.groupEnd();
    }
  },



  /**
    Outputs the properties of an object.

    Logs the object using {@link SC.Logger.log} if the reporter.dir function
    does not exist.

    @param {Object}
  */
  dir: function() {
    var reporter = this.get('reporter');

    if (this.get('exists')  &&  (typeof reporter.dir === "function")) {
      // Firebug's console.dir doesn't support multiple objects here
      // but maybe custom reporters will
      reporter.dir.apply(reporter, arguments);
    }
    else {
      this.log.apply(this, arguments);
    }
  },


  /**
    Prints an XML outline for any HTML or XML object.

    Logs the object using {@link SC.Logger.log} if reporter.dirxml function
    does not exist.

    @param {Object}
  */
  dirxml: function() {
    var reporter = this.get('reporter');

    if (this.get('exists')  &&  (typeof reporter.dirxml === "function")) {
      // Firebug's console.dirxml doesn't support multiple objects here
      // but maybe custom reporters will
      reporter.dirxml.apply(reporter, arguments);
    }
    else {
      this.log.apply(this, arguments);
    }
  },



  /**
    Begins the JavaScript profiler, if it exists. Call {@link SC.Logger.profileEnd}
    to end the profiling process and receive a report.

    @param {String}     (optional)  A title to associate with the profile
    @returns {Boolean} YES if reporter.profile exists, NO otherwise
  */
  profile: function(title) {
    var reporter = this.get('reporter');

    if (this.get('exists')  &&  (typeof reporter.profile === "function")) {
      reporter.profile(title);
      return YES;
    }
    return NO;
  },

  /**
    Ends the JavaScript profiler, if it exists.  If you specify a title, the
    profile with that title will be ended.

    @param {String}     (optional)  A title to associate with the profile
    @returns {Boolean} YES if reporter.profileEnd exists, NO otherwise
    @see SC.Logger.profile
  */
  profileEnd: function(title) {
    var reporter = this.get('reporter');

    if (this.get('exists')  &&  (typeof reporter.profileEnd === "function")) {
      reporter.profileEnd(title);
      return YES;
    }
    return NO;
  },


  /**
    Measure the time between when this function is called and
    {@link SC.Logger.timeEnd} is called.

    @param {String}     The name of the profile to begin
    @returns {Boolean} YES if reporter.time exists, NO otherwise
    @see SC.Logger.timeEnd
  */
  time: function(name) {
    var reporter = this.get('reporter');

    if (this.get('exists')  &&  (typeof reporter.time === "function")) {
      reporter.time(name);
      return YES;
    }
    return NO;
  },

  /**
    Ends the profile specified.

    @param {String}     The name of the profile to end
    @returns {Boolean}  YES if reporter.timeEnd exists, NO otherwise
    @see SC.Logger.time
  */
  timeEnd: function(name) {
    var reporter = this.get('reporter');

    if (this.get('exists')  &&  (typeof reporter.timeEnd === "function")) {
      reporter.timeEnd(name);
      return YES;
    }
    return NO;
  },


  /**
    Prints a stack-trace.

    @returns {Boolean} YES if reporter.trace exists, NO otherwise
  */
  trace: function() {
    var reporter = this.get('reporter');

    if (this.get('exists')  &&  (typeof reporter.trace === "function")) {
      reporter.trace();
      return YES;
    }
    return NO;
  },




  // ..........................................................
  // INTERNAL SUPPORT
  //

  init: function() {
    arguments.callee.base.apply(this,arguments);

    // Set a reasonable default value if none has been set.
    if (!this.get('logOutputLevel')) {
      if (SC.buildMode === "debug") {
        this.set('logOutputLevel', SC.LOGGER_LEVEL_DEBUG);
      }
      else {
        this.set('logOutputLevel', SC.LOGGER_LEVEL_INFO);
      }
    }

    this.debugEnabledDidChange();
  },


  /** @private
    For backwards compatibility with the older 'debugEnabled' property, set
    our log output level to SC.LOGGER_LEVEL_DEBUG if 'debugEnabled' is set to
    YES.
  */
  debugEnabledDidChange: function() {
    if (this.get('debugEnabled')) {
      this.set('logOutputLevel', SC.LOGGER_LEVEL_DEBUG);
    }
  }.observes('debugEnabled'),



  /** @private
    Outputs and/or records the specified message of the specified type if the
    respective current log levels allow for it.  Assuming
    'automaticallyFormat' is specified, then String.fmt() will be called
    automatically on the message, but only if at least one of the log levels
    is such that the result will be used.

    @param {String}               type                 Expected to be SC.LOGGER_LEVEL_DEBUG, etc.
    @param {Boolean}              automaticallyFormat  Whether or not to treat 'message' as a format string if there are additional arguments
    @param {String}               message              Expected to a string format (for String.fmt()) if there are other arguments
    @param {String}   (optional)  originalArguments    All arguments passed into debug(), etc. (which includes 'message'; for efficiency, we don’t copy it)
  */
  _handleMessage: function(type, automaticallyFormat, message, originalArguments) {
    // Are we configured to show this type?
    var shouldOutput = this._shouldOutputType(type),
        shouldRecord = this._shouldRecordType(type),
        hasOtherArguments, i, len, args, output, entry, prefix,
        outputPrefix, recordedPrefix;

    // If we're neither going to output nor record the message, then stop now.
    if (!(shouldOutput || shouldRecord)) return;

    // Do we have arguments other than 'message'?  (Remember that
    // 'originalArguments' contains the message here, too, hence the > 1.)
    hasOtherArguments = (originalArguments  &&  originalArguments.length > 1);

    // If we're automatically formatting and there is no message (or it is
    // not a string), then don't automatically format after all.
    if (automaticallyFormat  &&  (SC.none(message)  ||  (typeof message !== "string"))) {
      automaticallyFormat = NO;
    }

    // If we should automatically format, and the client specified other
    // arguments in addition to the message, then we'll call .fmt() assuming
    // that the message is a format string.
    if (automaticallyFormat) {
      if (hasOtherArguments) {
        args = [];
        for (i = 1, len = originalArguments.length;  i < len;  ++i) {
          args.push(originalArguments[i]);
        }
        message = message.fmt.apply(message, args);
      }
    }

    // If a message prefix was specified, use it.
    prefix = this.get('messagePrefix');
    if (prefix) message = prefix + message;

    if (shouldOutput) {
      outputPrefix = this.get('outputMessagePrefix');

      // We only want to pass the original arguments to _outputMessage() if we
      // didn't format the message ourselves.
      args = automaticallyFormat ? null : originalArguments;
      this._outputMessage(type, null, this._outputIndentationLevel, (outputPrefix ? outputPrefix + message : message), args);
    }

    // If we're recording the log, append the message now.
    if (shouldRecord) {
      recordedPrefix = this.get('recordedMessagePrefix');

      entry = {
        type:      type,
        message:   message ? (recordedPrefix ? recordedPrefix + message : message) : YES,
        timestamp: new Date()
      };

      // If we didn't automatically format, and we have other arguments, then
      // be sure to record them, too.
      if (!automaticallyFormat  &&  hasOtherArguments) {
        entry.originalArguments = originalArguments;
      }

      this._addRecordedMessageEntry(entry);
    }
  },


  /** @private
    Outputs and/or records a group with the (optional) specified title
    assuming the respective current log levels allow for it.  This will output
    the title (if there is one) and indent all further messages (of any type)
    until _handleGroupEnd() is invoked.

    If additional arguments beyond a title are passed in, then String.fmt()
    will be called automatically on the title, but only if at least one of the
    log levels is such that the result will be used.

    @param {String}              type                 Expected to be SC.LOGGER_LEVEL_DEBUG, etc.
    @param {String}  (optional)  title                Expected to a string format (for String.fmt()) if there are other arguments
    @param {String}  (optional)  originalArguments    All arguments passed into debug(), etc. (which includes 'title'; for efficiency, we don’t copy it)
  */
  _handleGroup: function(type, title, originalArguments) {
    // Are we configured to show this type?
    var shouldOutput = this._shouldOutputType(type),
        shouldRecord = this._shouldRecordType(type),
        hasOtherArguments, i, len, args, arg, reporter, func, header, output,
        indentation, entry;

    // If we're neither going to output nor record the group, then stop now.
    if (!(shouldOutput || shouldRecord)) return;

    // Do we have arguments other than 'title'?  (Remember that
    // 'originalArguments' contains the title here, too, hence the > 1.)
    hasOtherArguments = (originalArguments  &&  originalArguments.length > 1);

    // If the client specified a title as well other arguments, then we'll
    // call .fmt() assuming that the title is a format string.
    if (title  &&  hasOtherArguments) {
      args = [];
      for (i = 1, len = originalArguments.length;  i < len;  ++i) {
        args.push(originalArguments[i]);
      }
      title = title.fmt.apply(title, args);
    }

    if (shouldOutput) {
      this._outputGroup(type, null, this._outputIndentationLevel, title);

      // Increase our indentation level to accommodate the group.
      this._outputIndentationLevel++;
    }

    // If we're recording the group, append the entry now.
    if (shouldRecord) {
      // Increase our indentation level to accommodate the group.
      indentation = ++this._recordingIndentationLevel;

      entry = {
        type:         type,
        indentation:  indentation,
        beginGroup:   YES,
        title:        title,
        timestamp:    new Date()
      };

      this._addRecordedMessageEntry(entry);
    }
  },


  /** @private
    Outputs and/or records a “group end” assuming the respective current log
    levels allow for it.  This will remove one level of indentation from all
    further messages (of any type).

    @param {String}              type                 Expected to be SC.LOGGER_LEVEL_DEBUG, etc.
  */
  _handleGroupEnd: function(type) {
    // Are we configured to show this type?
    var shouldOutput = this._shouldOutputType(type),
        shouldRecord = this._shouldRecordType(type),
        reporter, func, indentation, entry;

    // If we're neither going to output nor record the "group end", then stop
    // now.
    if (!(shouldOutput || shouldRecord)) return;

    if (shouldOutput) {
      // Decrease our indentation level to accommodate the group.
      this._outputIndentationLevel--;

      if (this.get('exists')) {
        // Do we have reporter.groupEnd defined as a function?  If not, we
        // simply won't output anything.
        reporter = this.get('reporter');
        func     = reporter.groupEnd;
        if (func) {
          func.call(reporter);
        }
      }
    }

    // If we're recording the “group end”, append the entry now.
    if (shouldRecord) {
      // Decrease our indentation level to accommodate the group.
      indentation = --this._recordingIndentationLevel;

      entry = {
        type:         type,
        indentation:  indentation,
        timestamp:    new Date()
      };

      this._addRecordedMessageEntry(entry);
    }
  },


  /** @private
    Returns whether a message of the specified type ('debug', etc.) should be
    output to the reporter based on the current value of 'logOutputLevel'.

    @param {Constant}  type
    @returns {Boolean}
  */
  _shouldOutputType: function(type) {
    var logLevelMapping = this._LOG_LEVEL_MAPPING,
        level           = logLevelMapping[type]                        ||  0,
        currentLevel    = logLevelMapping[this.get('logOutputLevel')]  ||  0;

    return (level <= currentLevel);
  },


  /** @private
    Returns whether a message of the specified type ('debug', etc.) should be
    recorded based on the current value of 'logRecordingLevel'.

    @param {Constant}  type
    @returns {Boolean}
  */
  _shouldRecordType: function(type) {
    // This is the same code as in _shouldOutputType(), but inlined to
    // avoid yet another function call.
    var logLevelMapping = this._LOG_LEVEL_MAPPING,
        level           = logLevelMapping[type]                           ||  0,
        currentLevel  = logLevelMapping[this.get('logRecordingLevel')]  ||  0;

    return (level <= currentLevel);
  },


  /** @private
    Outputs the specified message to the current reporter.  If the reporter
    does not handle the specified type of message, it will fall back to using
    log() if possible.

    @param {Constant}               type
    @param {String}                 timestampStr       An optional timestamp prefix for the line, or null for none
    @param {Number}                 indentation        The current indentation level
    @param {String}                 message
    @param {Arguments}  (optional)  originalArguments  If specified, the assumption is that the message was not automatically formatted
  */
  _outputMessage: function(type, timestampStr, indentation, message, originalArguments) {
    if (!this.get('exists')) return;

    // Do we have reporter[type] defined as a function?  If not, we'll fall
    // back to reporter.log if that exists.
    var reporter = this.get('reporter'),
        output, shouldIndent, func, prefix, args, arg;

    // If the reporter doesn't support group(), then we need to manually
    // include indentation for the group.  (It it does, we'll assume that
    // we're currently at the correct group level.)
    shouldIndent = !reporter.group;

    // Note:  Normally we wouldn't do the hash dereference twice, but
    //        storing the result like this:
    //
    //          var nativeFunction = console[type];
    //          nativeFunction(output);
    //
    //        …doesn't work in Safari 4, and:
    //
    //          nativeFunction.call(console, output);
    //
    //        …doesn't work in IE8 because the console.* methods are
    //       reported as being objects.
    func = reporter[type];
    if (func) {
      // If we formatted, just include the message.  Otherwise, include all
      // the original arguments.
      if (!originalArguments) {
        output = timestampStr ? timestampStr : "";
        if (shouldIndent) output += this._indentation(indentation);
        output += message;
        reporter[type](output);
      }
      else {
        // We have arguments?  Then pass them along to the reporter function
        // so that it can format them appropriately.  We'll use the timestamp
        // string (if there is one) and the indentation as the first
        // arguments.
        args = this._argumentsToArray(originalArguments);
        prefix = "";
        if (timestampStr) prefix = timestampStr;
        if (shouldIndent) prefix += this._indentation(indentation);
        if (prefix) args.splice(0, 0, prefix);

        if (func.apply) {
          func.apply(reporter, args);
        }
        else {
          // In IE8, passing the arguments as an array isn't ideal, but it's
          // pretty much all we can do because we can't call apply().
          reporter[type](args);
        }
      }
    }
    else {
      // The reporter doesn't support the requested function?  If it at least
      // support log(), fall back to that.
      if (reporter.log) {
        prefix = "";
        if (timestampStr) prefix = timestampStr;
        prefix += this._LOG_FALLBACK_PREFIX_MAPPING[type] || "";
        if (shouldIndent) prefix += this._indentation(indentation);

        // If we formatted, just include the message.  Otherwise, include
        // all the original arguments.
        if (!originalArguments) {
          reporter.log(prefix + message);
        }
        else {
          args = this._argumentsToArray(originalArguments);
          if (prefix) args.splice(0, 0, prefix);
          reporter.log(args);
        }
      }
    }
  },


  /** @private
    Outputs the specified “begin group” directive to the current reporter.  If
    the reporter does not handle the group() method, it will fall back to
    simulating using log() if possible.

    @param {Constant}               type
    @param {String}                 timestampStr  An optional timestamp prefix for the line, or null for none
    @param {Number}                 indentation   The current indentation level, not including what the group will set it to
    @param {String}     (optional)  title
  */
  _outputGroup: function(type, timestampStr, indentation, title) {
    if (!this.get('exists')) return;

    // Do we have reporter.group defined as a function?  If not, we'll fall
    // back to reporter.log if that exists.  (Thankfully, we can avoid the IE8
    // special-casing we have in _outputMessage() because IE8 doesn't support
    // console.group(), anyway.)
    var reporter = this.get('reporter'),
        func     = reporter.group,
        output;

    if (func) {
      output = timestampStr ? timestampStr : "";
      output += title;
      func.call(reporter, output);
    }
    else if (reporter.log) {
      // The reporter doesn't support group()?  Then simulate with log().
      // (We'll live with the duplicitous dereference rather than using
      // apply() to work around the IE8 issue described in _outputMessage().)
      output = "";
      if (timestampStr) output = timestampStr;
      output += this._LOG_FALLBACK_PREFIX_MAPPING[type] || "";
      output += this._indentation(indentation);
      output += SC.LOGGER_LOG_GROUP_HEADER.fmt(title);
      reporter.log(output);
    }
  },


  /** @private
    This method will add the specified entry to the recorded log messages
    array and also prune array as necessary according to the current values of
    'recordedLogMessagesMaximumLength' and
    'recordedLogMessagesPruningMinimumLength'.
  */
  _addRecordedMessageEntry: function(entry) {
    var recordedMessages = this.get('recordedLogMessages'),
        len;

    // Lazily create the array.
    if (!recordedMessages) {
      recordedMessages = [];
      this.set('recordedLogMessages', recordedMessages);
    }

    recordedMessages.push(entry);

    // Have we exceeded the maximum size?  If so, do some pruning.
    len = recordedMessages.length;
    if (len > this.get('recordedLogMessagesMaximumLength')) {
      recordedMessages.splice(0, (len - this.get('recordedLogMessagesPruningMinimumLength')));
    }

    // Notify that the array content changed.
    recordedMessages.enumerableContentDidChange();
  },



  /** @private
    The arguments function property doesn't support Array#unshift. This helper
    copies the elements of arguments to a blank array.

    @param {Array} arguments The arguments property of a function
    @returns {Array} An array containing the elements of arguments parameter
  */
  _argumentsToArray: function(args) {
    var ret = [],
        i, len;

    if (args) {
      for (i = 0, len = args.length;  i < len;  ++i) {
        ret[i] = args[i];
      }
    }
    return ret;
  },


  /** @private
    Formats the arguments array of a function by creating a string with
    SC.LOGGER_LOG_DELIMITER between the elements.
  */
  _argumentsToString: function() {
    var ret       = "",
        delimiter = SC.LOGGER_LOG_DELIMITER,
        i, len;

    for (i = 0, len = (arguments.length - 1);  i < len;  ++i) {
      ret += arguments[i] + delimiter;
    }
    ret += arguments[len];
    return ret;
  },


  /** @private
    Returns a string containing the appropriate indentation for the specified
    indentation level.

    @param {Number}  The indentation level
    @returns {String}
  */
  _indentation: function(level) {
    if (!level  ||  level < 0) {
      level = 0;
    }

    var ret    = "",
        indent = SC.LOGGER_LOG_GROUP_INDENTATION,
        i;

    for (i = 0;  i < level;  ++i) {
      ret += indent;
    }
    return ret;
  },



  /** @private
    The current “for output” indentation level.  The reporter (browser
    console) is expected to keep track of this for us for output, but we need
    to do our own bookkeeping if the browser doesn’t support console.group.
    This is incremented by _debugGroup() and friends, and decremented by
    _debugGroupEnd() and friends.
  */
  _outputIndentationLevel: 0,


  /** @private
    The current “for recording” indentation level.  This can be different than
    the “for output” indentation level if the respective log levels are set
    differently.  This is incremented by _debugGroup() and friends, and
    decremented by _debugGroupEnd() and friends.
  */
  _recordingIndentationLevel: 0,


  /** @private
    A mapping of the log level constants (SC.LOGGER_LEVEL_DEBUG, etc.) to
    their priority.  This makes it easy to determine which levels are “higher”
    than the current level.

    Implementation note:  We’re hardcoding the values of the constants defined
    earlier here for a tiny bit of efficiency (we can create the hash all at
    once rather than having to push in keys).
  */
  _LOG_LEVEL_MAPPING: { debug: 4, info: 3, warn: 2, error: 1, none: 0 },


  /** @private
    If the current reporter does not support a particular type of log message
    (for example, some older browsers’ consoles support console.log but not
    console.debug), we’ll use the specified prefixes.

    Implementation note:  We’re hardcoding the values of the constants defined
    earlier here for a tiny bit of efficiency (we can create the hash all at
    once rather than having to push in keys).
  */
  _LOG_FALLBACK_PREFIX_MAPPING: {
    debug:  SC.LOGGER_LOG_DEBUG,
    info:   SC.LOGGER_LOG_INFO,
    warn:   SC.LOGGER_LOG_WARN,
    error:  SC.LOGGER_LOG_ERROR
  }

});


// Add convenient shorthands methods to SC.
SC.debug = SC.Logger.debug;
SC.info  = SC.Logger.info;
SC.warn  = SC.Logger.warn;
SC.error = SC.Logger.error;

/* >>>>>>>>>> BEGIN source/system/run_loop.js */
// ==========================================================================
// Project:   SproutCore Costello - Property Observing Library
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('ext/function');
sc_require('private/observer_set');





/**
  @class

  The run loop provides a universal system for coordinating events within
  your application.  The run loop processes timers as well as pending
  observer notifications within your application.

  To use a RunLoop within your application, you should make sure your event
  handlers always begin and end with SC.RunLoop.begin() and SC.RunLoop.end()

  The RunLoop is important because bindings do not fire until the end of
  your run loop is reached.  This improves the performance of your
  application.

  Example:

  This is how you could write your mouseup handler in jQuery:

        $('#okButton').on('click', function () {
          SC.run(function () {

            // handle click event...

          }); // allows bindings to trigger...
        });

  @extends SC.Object
  @since SproutCore 1.0
*/
SC.RunLoop = SC.Object.extend(
  /** @scope SC.RunLoop.prototype */ {

  /**
    Call this method whenver you begin executing code.

    This is typically invoked automatically for you from event handlers and
    the timeout handler.  If you call setTimeout() or setInterval() yourself,
    you may need to invoke this yourself.

    @returns {SC.RunLoop} receiver
  */
  beginRunLoop: function () {
    this._start = new Date().getTime(); // can't use Date.now() in runtime

    


    this._runLoopInProgress = YES;
    this._flushinvokeNextQueue();
    return this;
  },

  /**
    YES when a run loop is in progress

    @property
    @type Boolean
  */
  isRunLoopInProgress: function () {
    return this._runLoopInProgress;
  }.property(),

  /**
    Call this method whenever you are done executing code.

    This is typically invoked automatically for you from event handlers and
    the timeout handler.  If you call setTimeout() or setInterval() yourself
    you may need to invoke this yourself.

    @returns {SC.RunLoop} receiver
  */
  endRunLoop: function () {
    // at the end of a runloop, flush all the delayed actions we may have
    // stored up.  Note that if any of these queues actually run, we will
    // step through all of them again.  This way any changes get flushed
    // out completely.

    


    this.flushAllPending();

    this._start = null;

    


    SC.RunLoop.lastRunLoopEnd = Date.now();
    this._runLoopInProgress = NO;

    // If there are members in the invokeNextQueue, be sure to schedule another
    // run of the run loop.
    var queue = this._invokeNextQueue;
    if (queue && queue.getMembers().length) {
      this._invokeNextTimeout = this.scheduleRunLoop(SC.RunLoop.lastRunLoopEnd);
    }

    return this;
  },

  /**
    Repeatedly flushes all bindings, observers, and other queued functions until all queues are empty.
  */
  flushAllPending: function () {
    var didChange;

    do {
      didChange = this.flushApplicationQueues();
      if (!didChange) didChange = this._flushinvokeLastQueue();
    } while (didChange);
  },


  /**
    Invokes the passed target/method pair once at the end of the runloop.
    You can call this method as many times as you like and the method will
    only be invoked once.

    Usually you will not call this method directly but use invokeOnce()
    defined on SC.Object.

    Note that in development mode only, the object and method that call this
    method will be recorded, for help in debugging scheduled code.

    @param {Object} target
    @param {Function} method
    @returns {SC.RunLoop} receiver
  */
  invokeOnce: function (target, method) {
    

    // normalize
    if (method === undefined) {
      method = target;
      target = this;
    }

    var deferredCallLoggingInfo;      // Used only in debug mode

    


    if (typeof method === "string") method = target[method];
    if (!this._invokeQueue) this._invokeQueue = SC.ObserverSet.create();
    if (method) this._invokeQueue.add(target, method, undefined, deferredCallLoggingInfo);
    return this;
  },

  /**
    Invokes the passed target/method pair at the very end of the run loop,
    once all other delayed invoke queues have been flushed.  Use this to
    schedule cleanup methods at the end of the run loop once all other work
    (including rendering) has finished.

    If you call this with the same target/method pair multiple times it will
    only invoke the pair only once at the end of the runloop.

    Usually you will not call this method directly but use invokeLast()
    defined on SC.Object.

    Note that in development mode only, the object and method that call this
    method will be recorded, for help in debugging scheduled code.

    @param {Object} target
    @param {Function} method
    @returns {SC.RunLoop} receiver
  */
  invokeLast: function (target, method) {
    


    // normalize
    if (method === undefined) {
      method = target;
      target = this;
    }

    var deferredCallLoggingInfo;      // Used only in debug mode

    



    if (typeof method === "string") method = target[method];
    if (!this._invokeLastQueue) this._invokeLastQueue = SC.ObserverSet.create();
    this._invokeLastQueue.add(target, method, undefined, deferredCallLoggingInfo);
    return this;
  },

  /**
    Invokes the passed target/method pair once at the beginning of the next
    run of the run loop, before any other methods (including events) are
    processed.  Use this to defer painting to make views more responsive.

    If you call this with the same target/method pair multiple times it will
    only invoke the pair only once at the beginning of the next runloop.

    Usually you will not call this method directly but use invokeNext()
    defined on SC.Object.

    @param {Object} target
    @param {Function} method
    @returns {SC.RunLoop} receiver
  */
  invokeNext: function (target, method) {
    // normalize
    if (method === undefined) {
      method = target;
      target = this;
    }

    if (typeof method === "string") method = target[method];
    if (!this._invokeNextQueue) this._invokeNextQueue = SC.ObserverSet.create();
    this._invokeNextQueue.add(target, method);
    return this;
  },

  /**
    Executes any pending events at the end of the run loop.  This method is
    called automatically at the end of a run loop to flush any pending
    queue changes.

    The default method will invoke any one time methods and then sync any
    bindings that might have changed.  You can override this method in a
    subclass if you like to handle additional cleanup.

    This method must return YES if it found any items pending in its queues
    to take action on.  endRunLoop will invoke this method repeatedly until
    the method returns NO.  This way if any if your final executing code
    causes additional queues to trigger, then can be flushed again.

    @returns {Boolean} YES if items were found in any queue, NO otherwise
  */
  flushApplicationQueues: function () {
    var hadContent = NO,
        // execute any methods in the invokeQueue.
        queue = this._invokeQueue;
    if (queue && queue.getMembers().length) {
      this._invokeQueue = null; // reset so that a new queue will be created
      hadContent = YES; // needs to execute again
      queue.invokeMethods();
    }

    // flush any pending changed bindings.  This could actually trigger a
    // lot of code to execute.
    return SC.Binding.flushPendingChanges() || hadContent;
  },

  _flushinvokeLastQueue: function () {
    var queue = this._invokeLastQueue, hadContent = NO;
    if (queue && queue.getMembers().length) {
      this._invokeLastQueue = null; // reset queue.
      hadContent = YES; // has targets!
      if (hadContent) queue.invokeMethods();
    }
    return hadContent;
  },

  _flushinvokeNextQueue: function () {
    var queue = this._invokeNextQueue, hadContent = NO;
    if (queue && queue.getMembers().length) {
      this._invokeNextQueue = null; // reset queue.
      hadContent = YES; // has targets!
      if (hadContent) queue.invokeMethods();
    }
    return hadContent;
  },

  /** @private
    Schedules the run loop to run at the given time.  If the run loop is
    already scheduled to run earlier nothing will change, but if the run loop
    is not scheduled or it is scheduled later, then it will be rescheduled
    to the value of nextTimeoutAt.

    @returns timeoutID {Number} The ID of the timeout to start the next run of the run loop
  */
  scheduleRunLoop: function (nextTimeoutAt) {
    /*jshint eqnull:true*/
    // If there is no run loop scheduled or if the scheduled run loop is later, reschedule.
    if (this._timeoutAt == null || this._timeoutAt > nextTimeoutAt) {
      // clear existing...
      if (this._timeout) { clearTimeout(this._timeout); }

      // reschedule
      var delay = Math.max(0, nextTimeoutAt - Date.now());
      this._timeout = setTimeout(this._timeoutDidFire, delay);
      this._timeoutAt = nextTimeoutAt;
    }

    return this._timeout;
  },

  /** @private
    Invoked when a timeout actually fires.  Simply cleanup, then begin and end
    a runloop. Note that this function will be called with 'this' set to the
    global context, hence the need to lookup the current run loop.
  */
  _timeoutDidFire: function () {
    var rl = SC.RunLoop.currentRunLoop;
    rl._timeout = rl._timeoutAt = rl._invokeNextTimeout = null; // cleanup
    SC.run();  // begin/end runloop to trigger timers.
  },

  /** @private Unschedule the run loop that is scheduled for the given timeoutID */
  unscheduleRunLoop: function () {
    // Don't unschedule if the timeout is shared with an invokeNext timeout.
    if (!this._invokeNextTimeout) {
      clearTimeout(this._timeout);
      this._timeout = this._timeoutAt = null; // cleanup
    }
  }

});







/**
  The current run loop.  This is created automatically the first time you
  call begin().

  @type SC.RunLoop
*/
SC.RunLoop.currentRunLoop = null;

/**
  The default RunLoop class.  If you choose to extend the RunLoop, you can
  set this property to make sure your class is used instead.

  @type Class
*/
SC.RunLoop.runLoopClass = SC.RunLoop;

/**
  Begins a new run loop on the currentRunLoop.  If you are already in a
  runloop, this method has no effect.

  @returns {SC.RunLoop} receiver
*/
SC.RunLoop.begin = function () {
  var runLoop = this.currentRunLoop;
  if (!runLoop) runLoop = this.currentRunLoop = this.runLoopClass.create();
  runLoop.beginRunLoop();
  return this;
};

/**
  Ends the run loop on the currentRunLoop.  This will deliver any final
  pending notifications and schedule any additional necessary cleanup.

  @returns {SC.RunLoop} receiver
*/
SC.RunLoop.end = function () {
  var runLoop = this.currentRunLoop;
  if (!runLoop) {
    throw new Error("SC.RunLoop.end() called outside of a runloop!");
  }
  runLoop.endRunLoop();
  return this;
};


/**
  Call this to kill the current run loop--stopping all propagation of bindings
  and observers and clearing all timers.

  This is useful if you are popping up an error catcher: you need a run loop
  for the error catcher, but you don't want the app itself to continue
  running.
*/
SC.RunLoop.kill = function () {
  this.currentRunLoop = this.runLoopClass.create();
  return this;
};

/**
  Returns YES when a run loop is in progress

  @return {Boolean}
*/
SC.RunLoop.isRunLoopInProgress = function () {
  if (this.currentRunLoop) return this.currentRunLoop.get('isRunLoopInProgress');
  return NO;
};

/**
  Executes a passed function in the context of a run loop. If called outside a
  runloop, starts and ends one. If called inside an existing runloop, is
  simply executes the function unless you force it to create a nested runloop.

  If an exception is thrown during execution, we give an error catcher the
  opportunity to handle it before allowing the exception to bubble again.

  @param {Function} callback callback to execute
  @param {Object} target context for callback
  @param {Boolean} forceNested if YES, starts/ends a new runloop even if one is already running
*/
SC.run = function (callback, target, forceNested) {
  var alreadyRunning = SC.RunLoop.isRunLoopInProgress();

  // BEGIN CODAP Fix: we intercept exceptions to make sure we at least attempt
  // to close the runloop. If we do not close the run loop we are dead in
  // the water. In CODAP's case we have an installed exception handler. We
  // put up an alert, and suggest the user restart.
  try {
    try {
      if (forceNested || !alreadyRunning) SC.RunLoop.begin();
      if (callback) callback.call(target);
    }
    finally {
        if (forceNested || !alreadyRunning) SC.RunLoop.end();
    }
  }
  catch (e) {
    var handled = false;
    if (SC.ExceptionHandler && SC.ExceptionHandler.enabled) {
      handled = SC.ExceptionHandler.handleException(e);
    }

    if (SC.RunLoop.isRunLoopInProgress()) {
      SC.RunLoop.kill();
    }

    // If the exception was not handled, throw it again so the browser
    // can deal with it (and potentially use it for debugging).
    // (We don't throw it in IE because the user will see two errors)
    if (!handled && !SC.browser.isIE) {
      throw e;
    }
  }
  // END CODAP fix.
};

/**
  Wraps the passed function in code that ensures a run loop will
  surround it when run.
*/
SC.RunLoop.wrapFunction = function (func) {
  var ret = function () {
    var alreadyRunning = SC.RunLoop.isRunLoopInProgress();
    if (!alreadyRunning) SC.RunLoop.begin();
    var ret = arguments.callee.wrapped.apply(this, arguments);
    if (!alreadyRunning) SC.RunLoop.end();
    return ret;
  };
  ret.wrapped = func;
  return ret;
};


/* >>>>>>>>>> BEGIN javascript.js */
/* >>>>>>>>>> BEGIN source/core.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  Indicates that the collection view expects to accept a drop ON the specified
  item.

  @type Number
*/
SC.DROP_ON = 0x01 ;

/**
  Indicates that the collection view expects to accept a drop BEFORE the
  specified item.

  @type Number
*/
SC.DROP_BEFORE = 0x02 ;

/**
  Indicates that the collection view expects to accept a drop AFTER the
  specified item.  This is treated just like SC.DROP_BEFORE is most views
  except for tree lists.

  @type Number
*/
SC.DROP_AFTER = 0x04 ;

/**
  Indicates that the collection view want's to know which operations would
  be allowed for either drop operation.

  @type Number
*/
SC.DROP_ANY = 0x07 ;

/**
  Indicates that the content should be aligned to the left.
*/
SC.ALIGN_LEFT = 'left';

/**
  Indicates that the content should be aligned to the right.
*/
SC.ALIGN_RIGHT = 'right';

/**
  Indicates that the content should be aligned to the center.
*/
SC.ALIGN_CENTER = 'center';

/**
  Indicates that the content should be aligned to the top.
*/
SC.ALIGN_TOP = 'top';

/**
  Indicates that the content should be aligned to the middle.
*/
SC.ALIGN_MIDDLE = 'middle';

/**
  Indicates that the content should be aligned to the bottom.
*/
SC.ALIGN_BOTTOM = 'bottom';

/**
  Indicates that the content should be aligned to the top and left.
*/
SC.ALIGN_TOP_LEFT = 'top-left';

/**
  Indicates that the content should be aligned to the top and right.
*/
SC.ALIGN_TOP_RIGHT = 'top-right';

/**
  Indicates that the content should be aligned to the bottom and left.
*/
SC.ALIGN_BOTTOM_LEFT = 'bottom-left';

/**
  Indicates that the content should be aligned to the bottom and right.
*/
SC.ALIGN_BOTTOM_RIGHT = 'bottom-right';

/**
  Indicates that the content does not specify its own alignment.
*/
SC.ALIGN_DEFAULT = 'default';

/**
  Indicates that the content should be positioned to the right.
*/
SC.POSITION_RIGHT = 0;

/**
  Indicates that the content should be positioned to the left.
*/
SC.POSITION_LEFT = 1;

/**
  Indicates that the content should be positioned above.
*/
SC.POSITION_TOP = 2;

/**
  Indicates that the content should be positioned below.
*/
SC.POSITION_BOTTOM = 3;


SC.mixin(/** @lends SC */ {

  /**
    Reads or writes data from a global cache.  You can use this facility to
    store information about an object without actually adding properties to
    the object itself.  This is needed especially when working with DOM,
    which can leak easily in IE.

    To read data, simply pass in the reference element (used as a key) and
    the name of the value to read.  To write, also include the data.

    You can also just pass an object to retrieve the entire cache.

    @param elem {Object} An object or Element to use as scope
    @param name {String} Optional name of the value to read/write
    @param data {Object} Optional data.  If passed, write.
    @returns {Object} the value of the named data
  */
  data: $.data,

  /**
    Removes data from the global cache.  This is used throughout the
    framework to hold data without creating memory leaks.

    You can remove either a single item on the cache or all of the cached
    data for an object.

    @param elem {Object} An object or Element to use as scope
    @param name {String} optional name to remove.
    @returns {Object} the value or cache that was removed
  */
  removeData: $.removeData,

  // ..........................................................
  // LOCALIZATION SUPPORT
  //

  /**
    Known loc strings

    @type Hash
  */
  STRINGS: {},

  /**
    This is a simplified handler for installing a bunch of strings.  This
    ignores the language name and simply applies the passed strings hash.

    @param {String} lang the language the strings are for
    @param {Hash} strings hash of strings
    @returns {SC} The receiver, useful for chaining calls to the same object.
  */
  stringsFor: function(lang, strings) {
    SC.mixin(SC.STRINGS, strings);
    return this ;
  },

  /**
    Returns the SC.View instance managing the given element.

    If no instance is found, returns `null`.

    @param {DOMElement} element The element to check.
    @returns {SC.View} The view managing the element or null if none found.
  */
  viewFor: function (element) {
    


    // CODAP change to prevent exception in Firefox
    if (!(element instanceof Element)) {
      SC.error("Developer Error: Attempt to retrieve the SC.View instance for a non-element in SC.viewFor(): %@".fmt(element));
      return null;
    }
    // end CODAP change

    // Search for the view for the given element.
    var viewCache = SC.View.views,
      view = viewCache[element.getAttribute('id')];

    // If the element itself is not managed by an SC.View, walk up its element chain searching for an
    // element that is.
    if (!view) {
      var parentNode;

      while (!view && (parentNode = element.parentNode) && (parentNode !== document)) {
        var id;

        // Ensure that the parent node is an Element and not some other type of Node.
        // Note: while `instanceOf Element` is the most accurate determiner, performance tests show
        // that it's much quicker to check for the existence of either the `nodeType` property or
        // the `querySelector` method.
        // See http://jsperf.com/nodetype-1-vs-instanceof-htmlelement/4
        // if (parentNode.querySelector && (id = parentNode.getAttribute('id'))) {
        if ((id = parentNode.getAttribute('id'))) {
          view = viewCache[id];
        }

        // Check the parent node.
        element = parentNode;
      }

      // Avoid memory leaks (i.e. IE).
      element = parentNode = null;
    }

    // If view isn't found, return null rather than undefined.
    return view || null;
  }

});

/* >>>>>>>>>> BEGIN source/system/browser.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


SC.mixin(SC.browser,
/** @scope SC.browser */ {

  /* @private Internal property for the cache of pre-determined experimental names. */
  _cachedNames: null,

  /* @private Internal property for the test element used for style testing. */
  _testEl: null,

  /** @private */
  _testSupportFor: function (target, propertyName, testValue) {
    /*jshint eqnull:true*/
    var ret = target[propertyName] != null,
      originalValue;

    if (testValue != null) {
      originalValue = target[propertyName];
      target[propertyName] = testValue;
      ret = target[propertyName] === testValue;
      target[propertyName] = originalValue;
    }

    return ret;
  },

  /**
    Version Strings should not be compared against Numbers.  For example,
    the version "1.20" is greater than "1.2" and less than "1.200", but as
    Numbers, they are all 1.2.

    Pass in one of the browser versions: SC.browser.version,
    SC.browser.engineVersion or SC.browser.osVersion and a String to compare
    against.  The function will split each version on the decimals and compare
    the parts numerically.

    Examples:

      SC.browser.compare('1.20', '1.2') == 18
      SC.browser.compare('1.08', '1.8') == 0
      SC.browser.compare('1.1.1', '1.1.004') == -3

    @param {String} version One of SC.browser.version, SC.browser.engineVersion or SC.browser.osVersion
    @param {String} other The version to compare against.
    @returns {Number} The difference between the versions at the first difference.
  */
  compare: function (version, other) {
    var coerce,
        parts,
        tests;

    // Ensure that the versions are Strings.
    if (typeof version === 'number' || typeof other === 'number') {
      

      version = String(version);
      other = String(other);
    }

    // This function transforms the String to a Number or NaN
    coerce = function (part) {
      return Number(part.match(/^[0-9]+/));
    };

    parts = SC.A(version.split('.')).map(coerce);
    tests = SC.A(other.split('.')).map(coerce);

    // Test each part stopping when there is a difference.
    for (var i = 0; i < tests.length; i++) {
      var check = parts[i] - tests[i];
      if (isNaN(check)) return 0;
      if (check !== 0) return check;
    }

    return 0;
  },

  /**
    This simple method allows you to more safely use experimental properties and
    methods in current and future browsers.

    Using browser specific methods and properties is a risky coding practice.
    With sufficient testing, you may be able to match prefixes to today's
    browsers, but this is prone to error and not future proof.  For instance,
    if a property becomes standard and the browser drops the prefix, your code
    could suddenly stop working.

    Instead, use SC.browser.experimentalNameFor(target, standardName), which
    will check the existence of the standard name on the target and if not found
    will try different camel-cased versions of the name with the current
    browser's prefix appended.

    If it is still not found, SC.UNSUPPORTED will be returned, allowing
    you a chance to recover from the lack of browser support.

    Note that `experimentalNameFor` is not really meant for determining browser
    support, only to ensure that using browser prefixed properties and methods
    is safe.  Instead, SC.platform provides several properties that can be used
    to determine support for a certain platform feature, which should be
    used before calling `experimentalNameFor` to safely use the feature.

    For example,

        // Checks for IndexedDB support first on the current platform.
        if (SC.platform.supportsIndexedDB) {
          var db = window.indexedDB,
            // Example return values: 'getDatabaseNames', 'webkitGetDatabaseNames', 'MozGetDatabaseNames', SC.UNSUPPORTED.
            getNamesMethod = SC.browser.experimentalNameFor(db, 'getDatabaseNames'),
            names;

            if (getNamesMethod === SC.UNSUPPORTED) {
              // Work without it.
            } else {
              names = db[getNamesMethod](...);
            }
        } else {
          // Work without it.
        }

    ## Improving deduction
    Occasionally a target will appear to support a property, but will fail to
    actually accept a value.  In order to ensure that the property doesn't just
    exist but is also usable, you can provide an optional `testValue` that will
    be temporarily assigned to the target to verify that the detected property
    is usable.

    @param {Object} target The target for the method.
    @param {String} standardName The standard name of the property or method we wish to check on the target.
    @param {String} [testValue] A value to temporarily assign to the property.
    @returns {string} The name of the property or method on the target or SC.UNSUPPORTED if no method found.
  */
  experimentalNameFor: function (target, standardName, testValue) {
    // Test the property name.
    var ret = standardName;

    // ex. window.indexedDB.getDatabaseNames
    if (!this._testSupportFor(target, ret, testValue)) {
      // ex. window.WebKitCSSMatrix
      ret = SC.browser.classPrefix + standardName.capitalize();
      if (!this._testSupportFor(target, ret, testValue)) {
        // No need to check if the prefix is the same for properties and classes
        if (SC.browser.domPrefix === SC.browser.classPrefix) {
          // Always show a warning so that production usage information has a
          // better chance of filtering back to the developer(s).
          SC.warn("SC.browser.experimentalNameFor(): target, %@, does not have property `%@` or `%@`.".fmt(target, standardName, ret));
          ret = SC.UNSUPPORTED;
        } else {
          // ex. window.indexedDB.webkitGetDatabaseNames
          ret = SC.browser.domPrefix + standardName.capitalize();
          if (!this._testSupportFor(target, ret, testValue)) {
            // Always show a warning so that production usage information has a
            // better chance of filtering back to the developer(s).
            SC.warn("SC.browser.experimentalNameFor(): target, %@, does not have property `%@`, '%@' or `%@`.".fmt(target, standardName, SC.browser.classPrefix + standardName.capitalize(), ret));
            ret = SC.UNSUPPORTED;
          }
        }
      }
    }

    return ret;
  },

  /**
    This method returns safe style names for current and future browsers.

    Using browser specific style prefixes is a risky coding practice.  With
    sufficient testing, you may be able to match styles across today's most
    popular browsers, but this is a lot of work and not future proof.  For
    instance, if a browser drops the prefix and supports the standard style
    name, your code will suddenly stop working.  This happens ALL the time!

    Instead, use SC.browser.experimentalStyleNameFor(standardStyleName), which
    will test support for the standard style name and if not found will try the
    prefixed version with the current browser's prefix appended.

    Note: the proper style name is only determined once per standard style
    name tested and then cached.  Therefore, calling experimentalStyleNameFor
    repeatedly has no performance detriment.

    For example,

        var boxShadowName = SC.browser.experimentalStyleNameFor('boxShadow'),
          el = document.createElement('div');

        // `boxShadowName` may be "boxShadow", "WebkitBoxShadow", "msBoxShadow", etc. depending on the browser support.
        el.style[boxShadowName] = "rgb(0,0,0) 0px 3px 5px";

    ## Improving deduction
    Occasionally a browser will appear to support a style, but will fail to
    actually accept a value.  In order to ensure that the style doesn't just
    exist but is also usable, you can provide an optional `testValue` that will
    be used to verify that the detected style is usable.

    @param {string} standardStyleName The standard name of the experimental style as it should be un-prefixed.  This is the DOM property name, which is camel-cased (ex. boxShadow)
    @param {String} [testValue] A value to temporarily assign to the style to ensure support.
    @returns {string} Future-proof style name for use in the current browser or SC.UNSUPPORTED if no style support found.
  */
  experimentalStyleNameFor: function (standardStyleName, testValue) {
    var cachedNames = this._sc_experimentalStyleNames,
        ret;

    // Fast path & cache initialization.
    if (!cachedNames) {
      cachedNames = this._sc_experimentalStyleNames = {};
    }

    if (cachedNames[standardStyleName]) {
      ret = cachedNames[standardStyleName];
    } else {
      // Test the style name.
      var el = this._testEl;

      // Create a test element and cache it for repeated use.
      if (!el) { el = this._testEl = document.createElement("div"); }

      // Cache the experimental style name (even SC.UNSUPPORTED) for quick repeat access.
      ret = cachedNames[standardStyleName] = this.experimentalNameFor(el.style, standardStyleName, testValue);
    }

    return ret;
  },

  /**
    This method returns safe CSS attribute names for current and future browsers.

    Using browser specific CSS prefixes is a risky coding practice.  With
    sufficient testing, you may be able to match attributes across today's most
    popular browsers, but this is a lot of work and not future proof.  For
    instance, if a browser drops the prefix and supports the standard CSS
    name, your code will suddenly stop working.  This happens ALL the time!

    Instead, use SC.browser.experimentalCSSNameFor(standardCSSName), which
    will test support for the standard CSS name and if not found will try the
    prefixed version with the current browser's prefix appended.

    Note: the proper CSS name is only determined once per standard CSS
    name tested and then cached.  Therefore, calling experimentalCSSNameFor
    repeatedly has no performance detriment.

    For example,

        var boxShadowCSS = SC.browser.experimentalCSSNameFor('box-shadow'),
          el = document.createElement('div');

        // `boxShadowCSS` may be "box-shadow", "-webkit-box-shadow", "-ms-box-shadow", etc. depending on the current browser.
        el.style.cssText = boxShadowCSS + " rgb(0,0,0) 0px 3px 5px";

    ## Improving deduction
    Occasionally a browser will appear to support a style, but will fail to
    actually accept a value.  In order to ensure that the style doesn't just
    exist but is also usable, you can provide an optional `testValue` that will
    be used to verify that the detected style is usable.

    @param {string} standardCSSName The standard name of the experimental CSS attribute as it should be un-prefixed (ex. box-shadow).
    @param {String} [testValue] A value to temporarily assign to the style to ensure support.
    @returns {string} Future-proof CSS name for use in the current browser or SC.UNSUPPORTED if no style support found.
  */
  experimentalCSSNameFor: function (standardCSSName, testValue) {
    var ret = standardCSSName,
      standardStyleName = standardCSSName.camelize(),
      styleName = this.experimentalStyleNameFor(standardStyleName, testValue);

    if (styleName === SC.UNSUPPORTED) {
      ret = SC.UNSUPPORTED;
    } else if (styleName !== standardStyleName) {
      // If the DOM property is prefixed, then the CSS name should be prefixed.
      ret = SC.browser.cssPrefix + standardCSSName;
    }

    return ret;
  }

});

/* >>>>>>>>>> BEGIN source/system/builder.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/** @class

  The Builder class makes it easy to create new chained-builder API's such as
  those provided by CoreQuery or jQuery.  Usually you will not create a new
  builder yourself, but you will often use instances of the Builder object to
  configure parts of the UI such as menus and views.
  
  # Anatomy of a Builder
  
  You can create a new Builder much like you would any other class in 
  SproutCore.  For example, you could create a new CoreQuery-type object with
  the following:
  
      SC.$ = SC.Builder.create({
        // methods you can call go here.
      });
  
  Unlike most classes in SproutCore, Builder objects are actually functions 
  that you can call to create new instances.  In the example above, to use 
  the builder, you must call it like a function:
  
      buildit = SC.$();
  
  If you define an init() method on a builder, it will be invoked wheneve the
  builder is called as a function, including any passed params.  Your init()
  method MUST return this, unlike regular SC objects.  i.e.
  
      SC.$ = SC.Builder.create({
        init: function(args) { 
          this.args = SC.A(args);
          return this;
        }
      });
      
      buildit = SC.$('a', 'b');
      buildit.args => ['a','b']
  
  In addition to defining a function like this, all builder objects also have
  an 'fn' property that contains a hash of all of the helper methods defined
  on the builder function.  Once a builder has been created, you can add 
  addition "plugins" for the builder by simply adding new methods to the
  fn property.
  
  # Writing Builder Functions
  
  All builders share a few things in common:
  
   * when a new builder is created, it's init() method will be called.  The default version of this method simply copies the passed parameters into the builder as content, but you can override this with anything you want.
   * the content the builder works on is stored as indexed properties (i.e. 0,1,2,3, like an array).  The builder should also have a length property if you want it treated like an array.
   *- Builders also maintain a stack of previous builder instances which you can pop off at any time.
  
  To get content back out of a builder once you are ready with it, you can
  call the method done().  This will return an array or a single object, if 
  the builder only works on a single item.
  
  You should write your methods using the getEach() iterator to work on your
  member objects.  All builders implement SC.Enumerable in the fn() method.

      CoreQuery = SC.Builder.create({
        ...
      }) ;
      
      CoreQuery = new SC.Builder(properties) {
        ...
      } ;
      
      CoreQuery2 = CoreQuery.extend() {
      }
  
  @constructor
*/
SC.Builder = function (props) { return SC.Builder.create(props); };

/** 
  Create a new builder object, applying the passed properties to the 
  builder's fn property hash.
  
  @param {Hash} properties
  @returns {SC.Builder}
*/
SC.Builder.create = function create(props) { 
  
  // generate new fn with built-in properties and copy props
  var fn = SC.mixin(SC.beget(this.fn), props||{}) ;
  if (props.hasOwnProperty('toString')) fn.toString = props.toString;
  
  // generate new constructor and hook in the fn
  var construct = function() {
    var ret = SC.beget(fn); // NOTE: using closure here...
    
    // the defaultClass is usually this for this constructor. 
    // e.g. SC.View.build() -> this = SC.View
    ret.defaultClass = this ;
    ret.constructor = construct ;

    // now init the builder object.
    return ret.init.apply(ret, arguments) ;
  } ;
  construct.fn = construct.prototype = fn ;

  // the create() method can be used to extend a new builder.
  // eg. SC.View.buildCustom = SC.View.build.extend({ ...props... })
  construct.extend = SC.Builder.create ;
  construct.mixin = SC.Builder.mixin ;
  
  return construct; // return new constructor
} ;

SC.Builder.mixin = function() {
  var len = arguments.length, idx;
  for(idx=0;idx<len;idx++) SC.mixin(this, arguments[idx]);
  return this ;
};

/** This is the default set of helper methods defined for new builders. */
SC.Builder.fn = {

  /** 
    Default init method for builders.  This method accepts either a single
    content object or an array of content objects and copies them onto the 
    receiver.  You can override this to provide any kind of init behavior 
    that you want.  Any parameters passed to the builder method will be 
    forwarded to your init method.
    
    @returns {SC.Builder} receiver
  */
  init: function(content) {
    if (content !== undefined) {
      if (SC.typeOf(content) === SC.T_ARRAY) {
        var loc=content.length;
        while(--loc >= 0) {
          this[loc] = content.objectAt ? content.objectAt(loc) : content[loc];
        }
        this.length = content.length ;
      } else {
        this[0] = content; this.length=1;
      }
    }
    return this ;
  },
  
  /** Return the number of elements in the matched set. */
  size: function() { return this.length; },
  
  /** 
    Take an array of elements and push it onto the stack (making it the
    new matched set.)  The receiver will be saved so it can be popped later.
    
    @param {Object|Array} content
    @returns {SC.Builder} new instance
  */
  pushStack: function() {
    // Build a new CoreQuery matched element set
    var ret = this.constructor.apply(this,arguments);

    // Add the old object onto the stack (as a reference)
    ret.prevObject = this;

    // Return the newly-formed element set
    return ret;
  },

  /**
    Returns the previous object on the stack so you can continue with that
    transform.  If there is no previous item on the stack, an empty set will
    be returned.
  */
  end: function() { 
    return this.prevObject || this.constructor(); 
  },
  
  // toString describes the builder
  toString: function() { 
    return "%@$(%@)".fmt(this.defaultClass.toString(), 
      SC.A(this).invoke('toString').join(',')); 
  },
  
  /** You can enhance the fn using this mixin method. */
  mixin: SC.Builder.mixin
  
};

// Apply SC.Enumerable.  Whenever possible we want to use the Array version
// because it might be native code.
(function() {
  var enumerable = SC.Enumerable, fn = SC.Builder.fn, key, value ;
  for(key in enumerable) {
    if (!enumerable.hasOwnProperty(key)) continue ;
    value = Array.prototype[key] || enumerable[key];
    fn[key] = value ;
  }
})();




/* >>>>>>>>>> BEGIN source/system/core_query.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
/*global jQuery*/
sc_require('system/builder');

// Alias jQuery as SC.$ and SC.CoreQuery for compatibility
SC.$ = SC.CoreQuery = jQuery;

// Add some plugins to SC.$. jQuery will get these also. -- test in system/core_query/additions
SC.mixin(SC.$.fn,
  /** @scope SC.$.prototype */ {

  isCoreQuery: YES, // walk like a duck

  /** @private - better loggin */
  toString: function () {
    var values = [],
      len = this.length,
      idx = 0;

    for (idx = 0; idx < len; idx++) {
      values[idx] = '%@: %@'.fmt(idx, this[idx] ? this[idx].toString() : '(null)');
    }
    return "<$:%@>(%@)".fmt(SC.guidFor(this), values.join(' , '));
  },

  /**
    Returns YES if all member elements are visible.  This is provided as a
    common test since CoreQuery does not support filtering by
    psuedo-selector.

    @deprecated Version 1.10
  */
  isVisible: function () {
    return Array.prototype.every.call(this, function (elem) {
      return SC.$.isVisible(elem);
    });
  },

  /**
    Attempts to find the views managing the passed DOM elements and returns
    them.   This will start with the matched element and walk up the DOM until
    it finds an element managed by a view.

    @returns {Array} array of views or null.
    @deprecated Version 1.10
  */
  view: function () {
    


    return SC.viewFor(this[0]);
  },

  /**
    Returns YES if any of the matched elements have the passed element or CQ object as a child element.
  */
  within: function (el) {
    if (this.filter(el).length) { return true; }
    return !!this.has(el).length;
  }

});

/**
  Make CoreQuery enumerable.  Since some methods need to be disambiguated,
  we will implement some wrapper functions here.

  Note that SC.Enumerable is implemented on SC.Builder, which means the
  CoreQuery object inherits this automatically.  jQuery does not extend from
  SC.Builder though, so we reapply SC.Enumerable just to be safe.
*/
(function () {
  var original = {},
      wrappers = {

    // if you call find with a selector, then use the jQuery way.  If you
    // call with a function/target, use Enumerable way
    find: function (callback, target) {
      return (target !== undefined) ? SC.Enumerable.find.call(this, callback, target) : original.find.call(this, callback);
    },

    // ditto for filter - execute SC.Enumerable style if a target is passed.
    filter: function (callback, target) {
      return (target !== undefined) ?
        this.pushStack(SC.Enumerable.filter.call(this, callback, target)) :
        original.filter.call(this, callback);
    },

    // filterProperty is an SC.Enumerable thing, but it needs to be wrapped
    // in a CoreQuery object.
    filterProperty: function (key, value) {
      return this.pushStack(
        SC.Enumerable.filterProperty.call(this, key, value));
    },

    // indexOf() is best implemented using the jQuery index()
    indexOf: SC.$.index,

    // map() is a little tricky because jQuery is non-standard.  If you pass
    // a context object, we will treat it like SC.Enumerable.  Otherwise use
    // jQuery.
    map: function (callback, target) {
      return (target !== undefined) ?
        SC.Enumerable.map.call(this, callback, target) :
        original.map.call(this, callback);
    }
  };

  // loop through an update some enumerable methods.
  var fn = SC.$.fn,
    enumerable = SC.Enumerable,
    value;

  for (var key in enumerable) {
    if (enumerable.hasOwnProperty(key)) {
      value = enumerable[key];

      if (key in wrappers) {
        original[key] = fn[key];
        value = wrappers[key];
      }

      fn[key] = value;
    }
  }
})();

// Add some global helper methods.
SC.mixin(SC.$, {

  /** @private helper method to determine if an element is visible.  Exposed
   for use in testing.

    @deprecated Version 1.10
  */
  isVisible: function (elem) {
    

    var CQ = SC.$;
    return ("hidden" != elem.type) && (CQ.css(elem, "display") != "none") && (CQ.css(elem, "visibility") != "hidden");
  }

});



/* >>>>>>>>>> BEGIN source/system/event.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('system/core_query') ;

/**
  The event class provides a simple cross-platform library for capturing and
  delivering events on DOM elements and other objects.  While this library
  is based on code from both jQuery and Prototype.js, it includes a number of
  additional features including support for handler objects and event
  delegation.

  Since native events are implemented very unevenly across browsers,
  SproutCore will convert all native events into a standardized instance of
  this special event class.

  SproutCore events implement the standard W3C event API as well as some
  additional helper methods.

  @constructor
  @param {Event} originalEvent
  @returns {SC.Event} event instance

  @since SproutCore 1.0
*/
SC.Event = function(originalEvent) {
  this._sc_updateNormalizedEvent(originalEvent);

  return this;
};

SC.mixin(SC.Event, /** @scope SC.Event */ {

  /**
    We need this because some browsers deliver different values
    for mouse wheel deltas. Once the first mouse wheel event has
    been run, this value will get set.

    @field
    @type Number
    @default 1
  */
  MOUSE_WHEEL_MULTIPLIER: function() {
    var deltaMultiplier = 1,
        version = SC.browser.engineVersion;

    if (SC.browser.name === SC.BROWSER.safari) {
      deltaMultiplier = 0.4;
      // Safari 5.0.1 and up
      if (SC.browser.compare(version, '533.17') > 0 && SC.browser.compare(version, '534') < 0) {
        deltaMultiplier = 0.004;
      } else if (SC.browser.compare(version, '533') < 0) {
        // Scrolling in Safari 5.0
        deltaMultiplier = 40;
      }
    }else if(SC.browser.name === SC.BROWSER.ie){
      deltaMultiplier = 0.3;
    }else if(SC.browser.name === SC.BROWSER.chrome){
      deltaMultiplier = 0.4;
    }
    return deltaMultiplier;
  }(),

  /**
    This represents the limit in the delta before a different multiplier
    will be applied. Because we can't generated an accurate mouse
    wheel event ahead of time, and browsers deliver differing values
    for mouse wheel deltas, this is necessary to ensure that
    browsers that scale their values largely are dealt with correctly
    in the future.

    @type Number
    @default 1000
  */
  MOUSE_WHEEL_DELTA_LIMIT: 1000,

  /** @private
    We only want to invalidate once
  */
  _MOUSE_WHEEL_LIMIT_INVALIDATED: NO,

  /**
    Standard method to create a new event.  Pass the native browser event you
    wish to wrap if needed.
  */
  create: function(e) { return new SC.Event(e); },

  // the code below was borrowed from jQuery, Dean Edwards, and Prototype.js

  /**
    Bind an event to an element.

    This method will cause the passed handler to be executed whenever a
    relevant event occurs on the named element.  This method supports a
    variety of handler types, depending on the kind of support you need.

    ## Simple Function Handlers

        SC.Event.add(anElement, "click", myClickHandler) ;

    The most basic type of handler you can pass is a function.  This function
    will be executed every time an event of the type you specify occurs on the
    named element.  You can optionally pass an additional context object which
    will be included on the event in the event.data property.

    When your handler function is called, the function's "this" property
    will point to the element the event occurred on.

    The click handler for this method must have a method signature like:

        function(event) { return YES|NO; }

    ## Method Invocations

        SC.Event.add(anElement, "click", myObject, myObject.aMethod) ;

    Optionally you can specify a target object and a method on the object to
    be invoked when the event occurs.  This will invoke the method function
    with the target object you pass as "this".  The method should have a
    signature like:

        function(event, targetElement) { return YES|NO; }

    Like function handlers, you can pass an additional context data paramater
    that will be included on the event in the event.data property.

    ## Handler Return Values

    Both handler functions should return YES if you want the event to
    continue to propagate and NO if you want it to stop.  Returning NO will
    both stop bubbling of the event and will prevent any default action
    taken by the browser.  You can also control these two behaviors separately
    by calling the stopPropagation() or preventDefault() methods on the event
    itself, returning YES from your method.

    ## Limitations

    Although SproutCore's event implementation is based on jQuery, it is
    much simpler in design.  Notably, it does not support namespaced events
    and you can only pass a single type at a time.

    If you need more advanced event handling, consider the SC.ClassicResponder
    functionality provided by SproutCore or use your favorite DOM library.

    @param {Element} elem a DOM element, window, or document object
    @param {String} eventType the event type you want to respond to
    @param {Object} target The target object for a method call or a function.
    @param {Object} method optional method or method name if target passed
    @param {Object} context optional context to pass to the handler as event.data
    @returns {Object} receiver
  */
  add: function(elem, eventType, target, method, context, useCapture) {

    // if a CQ object is passed in, either call add on each item in the
    // matched set, or simply get the first element and use that.
    if (elem && elem.isCoreQuery) {
      if (elem.length > 0) {
        elem.forEach(function(e) {
          this.add(e, eventType, target, method, context);
        }, this);
        return this;
      } else elem = elem[0];
    }
    if (!elem) return this; // nothing to do

		if (!useCapture) {
			useCapture = NO;
		}

    // cannot register events on text nodes, etc.
    if ( elem.nodeType === 3 || elem.nodeType === 8 ) return SC.Event;

    // For whatever reason, IE has trouble passing the window object
    // around, causing it to be cloned in the process
    if (SC.browser.name === SC.BROWSER.ie && elem.setInterval) elem = window;

    // if target is a function, treat it as the method, with optional context
    if (SC.typeOf(target) === SC.T_FUNCTION) {
      context = method;
      method = target;
      target = null;

    // handle case where passed method is a key on the target.
    } else if (target && SC.typeOf(method) === SC.T_STRING) {
      method = target[method];
    }

    // Get the handlers queue for this element/eventType.  If the queue does
    // not exist yet, create it and also setup the shared listener for this
    // eventType.
    var events = SC.data(elem, "sc_events") || SC.data(elem, "sc_events", {}),
        handlers = events[eventType];

    if (!handlers) {
      handlers = events[eventType] = {};
      this._addEventListener(elem, eventType, useCapture);
    }

    // Build the handler array and add to queue
    handlers[SC.hashFor(target, method)] = [target, method, context];
    SC.Event._global[eventType] = YES ; // optimization for global triggers

    // Nullify elem to prevent memory leaks in IE
    elem = events = handlers = null ;
    return this ;
  },

  /**
    Removes a specific handler or all handlers for an event or event+type.

    To remove a specific handler, you must pass in the same function or the
    same target and method as you passed into SC.Event.add().  See that method
    for full documentation on the parameters you can pass in.

    If you omit a specific handler but provide both an element and eventType,
    then all handlers for that element will be removed.  If you provide only
    and element, then all handlers for all events on that element will be
    removed.

    ## Limitations

    Although SproutCore's event implementation is based on jQuery, it is
    much simpler in design.  Notably, it does not support namespaced events
    and you can only pass a single type at a time.

    If you need more advanced event handling, consider the SC.ClassicResponder
    functionality provided by SproutCore or use your favorite DOM library.

    @param {Element} elem a DOM element, window, or document object
    @param {String} eventType the event type to remove
    @param {Object} target The target object for a method call.  Or a function.
    @param {Object} method optional name of method
    @returns {Object} receiver
  */
  remove: function(elem, eventType, target, method) {

    // if a CQ object is passed in, either call add on each item in the
    // matched set, or simply get the first element and use that.
    if (elem && elem.isCoreQuery) {
      if (elem.length > 0) {
        elem.forEach(function(e) {
          this.remove(e, eventType, target, method);
        }, this);
        return this;
      } else elem = elem[0];
    }
    if (!elem) return this; // nothing to do

    // don't do events on text and comment nodes
    if ( elem.nodeType === 3 || elem.nodeType === 8 ) return SC.Event;

    var handlers, key, events = SC.data(elem, "sc_events") ;
    if (!events) return this ; // nothing to do if no events are registered

    // if no type is provided, remove all types for this element.
    if (eventType === undefined) {
      for (var anEventType in events) this.remove(elem, anEventType) ;

    // otherwise, remove the handler for this specific eventType if found
    } else if ((handlers = events[eventType])) {

      var cleanupHandlers = NO ;

      // if a target/method is provided, remove only that one
      if (target || method) {

        // normalize the target/method
        if (SC.typeOf(target) === SC.T_FUNCTION) {
          method = target; target = null ;
        } else if (SC.typeOf(method) === SC.T_STRING) {
          method = target[method] ;
        }

        delete handlers[SC.hashFor(target, method)];

        // check to see if there are handlers left on this event/eventType.
        // if not, then cleanup the handlers.
        key = null ;
        for(key in handlers) break ;
        if (key===null) cleanupHandlers = YES ;

      // otherwise, just cleanup all handlers
      } else cleanupHandlers = YES ;

      // If there are no more handlers left on this event type, remove
      // eventType hash from queue.
      if (cleanupHandlers) {
        delete events[eventType] ;
        this._removeEventListener(elem, eventType) ;
      }

      // verify that there are still events registered on this element.  If
      // there aren't, cleanup the element completely to avoid memory leaks.
      key = null ;
      for (key in events) break;
      if (!key) {
        SC.removeData(elem, "sc_events") ;
        delete this._elements[SC.guidFor(elem)]; // important to avoid leaks

        // Clean up the cached listener to prevent a memory leak.
        SC.removeData(elem, 'listener');
      }

    }

    elem = events = handlers = null ; // avoid memory leaks
    return this ;
  },

  NO_BUBBLE: ['blur', 'focus', 'change'],

  /**
    Generates a simulated event object.  This is mostly useful for unit
    testing.  You can pass the return value of this property into the
    trigger() method to actually send the event.

    @param {Element} elem the element the event targets
    @param {String} eventType event type.  mousedown, mouseup, etc
    @param {Hash} attrs optional additional attributes to apply to event.
    @returns {Hash} simulated event object
  */
  simulateEvent: function(elem, eventType, attrs) {
    var ret = SC.Event.create({
      type: eventType,
      target: elem,
      preventDefault: function(){ this.cancelled = YES; },
      stopPropagation: function(){ this.bubbles = NO; },
      allowDefault: function() { this.hasCustomEventHandling = YES; },
      timeStamp: Date.now(),
      bubbles: (this.NO_BUBBLE.indexOf(eventType)<0),
      cancelled: NO,
      normalized: YES,
      simulated: true
    });
    if (attrs) SC.mixin(ret, attrs) ;
    return ret ;
  },

  /**
    Trigger an event execution immediately.  You can use this method to
    simulate arbitrary events on arbitrary elements.

    ## Limitations

    Note that although this is based on the jQuery implementation, it is
    much simpler.  Notably namespaced events are not supported and you cannot
    trigger events globally.

    If you need more advanced event handling, consider the SC.Responder
    functionality provided by SproutCore or use your favorite DOM library.

    ## Example

        SC.Event.trigger(view.get('layer'), 'mousedown');

    @param elem {Element} the target element
    @param eventType {String} the event type
    @param event {SC.Event} [event] pre-normalized event to pass to handler
    @param donative ??
    @returns {Boolean} Return value of trigger or undefined if not fired
  */
  trigger: function(elem, eventType, event, donative) {

    // if a CQ object is passed in, either call add on each item in the
    // matched set, or simply get the first element and use that.
    if (elem && elem.isCoreQuery) {
      if (elem.length > 0) {
        elem.forEach(function(e) {
          this.trigger(e, eventType, event, donative);
        }, this);
        return this;
      } else elem = elem[0];
    }
    if (!elem) return this; // nothing to do

    // don't do events on text and comment nodes
    if ( elem.nodeType === 3 || elem.nodeType === 8 ) return undefined;

    // Backwards-compatibility. Normalize from an Array.
    if (SC.typeOf(event) === SC.T_ARRAY) { event = event[0]; }

    var ret, fn = SC.typeOf(elem[eventType] || null) === SC.T_FUNCTION ,
        current, onfoo, isClick;

    // Get the event to pass, creating a fake one if necessary
    if (!event || !event.preventDefault) {
      event = this.simulateEvent(elem, eventType);
    }

    event.type = eventType;

    // Trigger the event - bubble if enabled
    current = elem;
    do {
      ret = SC.Event.handle.call(current, event);
      current = (current===document) ? null : (current.parentNode || document);
    } while(!ret && event.bubbles && current);
    current = null ;

    // Handle triggering native .onfoo handlers
    onfoo = elem["on" + eventType] ;
    isClick = SC.$.nodeName(elem, 'a') && eventType === 'click';
    if ((!fn || isClick) && onfoo && onfoo.call(elem, event) === NO) ret = NO;

    // Trigger the native events (except for clicks on links)
    if (fn && donative !== NO && ret !== NO && !isClick) {
      this.triggered = YES;
      try {
        elem[ eventType ]();
      // prevent IE from throwing an error for some hidden elements
      } catch (e) {}
    }

    this.triggered = NO;

    return ret;
  },

  /**
    This method will handle the passed event, finding any registered listeners
    and executing them.  If you have an event you want handled, you can
    manually invoke this method.  This function expects it's "this" value to
    be the element the event occurred on, so you should always call this
    method like:

        SC.Event.handle.call(element, event) ;

    Note that like other parts of this library, the handle function does not
    support namespaces.

    @param event {DOMEvent} the event to handle
    @returns {Boolean}
  */
  handle: function (event) {

    // ignore events triggered after window is unloaded or if double-called
    // from within a trigger.
    if ((typeof SC === "undefined") || SC.Event.triggered) return true;

    // returned undefined or false
    var val, ret, handlers, method, target;

    // get the handlers for this event type
    handlers = (SC.data(this, "sc_events") || {})[event.type];

    // no handlers for the event
    if (!handlers) {
      val = false; // nothing to do

    } else {
      // normalize event across browsers.  The new event will actually wrap the real event with a normalized API.
      event = SC.Event.normalizeEvent(event || window.event);

      // invoke all handlers
      for (var key in handlers) {
        var handler = handlers[key];

        method = handler[1];

        // Pass in a reference to the handler function itself so that we can remove it later.
        event.handler = method;
        event.data = event.context = handler[2];

        target = handler[0] || this;
        ret = method.call(target, event);

        if (val !== false) val = ret;

        // if method returned NO, do not continue.  Stop propagation and
        // return default.  Note that we test explicitly for NO since
        // if the handler returns no specific value, we do not want to stop.
        if ( ret === false ) {
          event.preventDefault();
          event.stopPropagation();
        }
      }

      // Clean up the cached normalized SC.Event so that it's not holding onto extra memory.
      if (event.originalEvent && !event.originalEvent.simulated) { event._sc_clearNormalizedEvent(); }
    }

    return val;
  },

  /**
    This method is called just before the window unloads to unhook all
    registered events.
  */
  unload: function() {
    var key, elements = this._elements ;
    for(key in elements) this.remove(elements[key]) ;

    // just in case some book-keeping was screwed up.  avoid memory leaks
    for(key in elements) delete elements[key] ;
    delete this._elements ;
  },

  /**
    This hash contains handlers for special or custom events.  You can add
    your own handlers for custom events here by simply naming the event and
    including a hash with the following properties:

     - setup: this function should setup the handler or return NO
     - teardown: this function should remove the event listener

  */
  special: {

    ready: {
      setup: function() {
        // Make sure the ready event is setup
        SC._bindReady() ;
        return;
      },

      teardown: function() { return; }

    },

    /** @private
        Implement support for mouseenter on browsers other than IE */
    mouseenter: {
      setup: function() {
        if ( SC.browser.name === SC.BROWSER.ie ) return NO;
        SC.Event.add(this, 'mouseover', SC.Event.special.mouseenter.handler);
        return YES;
      },

      teardown: function() {
        if ( SC.browser.name === SC.BROWSER.ie ) return NO;
        SC.Event.remove(this, 'mouseover', SC.Event.special.mouseenter.handler);
        return YES;
      },

      handler: function (event) {
        // If we actually just moused on to a sub-element, ignore it
        if ( SC.Event._withinElement(event, this) ) return YES;
        // Execute the right handlers by setting the event type to mouseenter
        event.type = "mouseenter";

        return SC.Event.handle.call(this, event);
      }
    },

    /** @private
        Implement support for mouseleave on browsers other than IE */
    mouseleave: {
      setup: function() {
        if ( SC.browser.name === SC.BROWSER.ie ) return NO;
        SC.Event.add(this, "mouseout", SC.Event.special.mouseleave.handler);
        return YES;
      },

      teardown: function() {
        if ( SC.browser.name === SC.BROWSER.ie ) return NO;
        SC.Event.remove(this, "mouseout", SC.Event.special.mouseleave.handler);
        return YES;
      },

      handler: function (event) {
        // If we actually just moused on to a sub-element, ignore it
        if ( SC.Event._withinElement(event, this) ) return YES;
        // Execute the right handlers by setting the event type to mouseleave
        event.type = "mouseleave";
        return SC.Event.handle.call(this, event);
      }
    }
  },

  KEY_BACKSPACE: 8,
  KEY_TAB:       9,
  KEY_RETURN:   13,
  KEY_ESC:      27,
  KEY_SPACE:    32,
  KEY_LEFT:     37,
  KEY_UP:       38,
  KEY_RIGHT:    39,
  KEY_DOWN:     40,
  KEY_DELETE:   46,
  KEY_HOME:     36,
  KEY_END:      35,
  KEY_PAGEUP:   33,
  KEY_PAGEDOWN: 34,
  KEY_INSERT:   45,

  _withinElement: function(event, elem) {
    // Check if mouse(over|out) are still within the same parent element
    var parent = event.relatedTarget;

    // Traverse up the tree
    while ( parent && parent !== elem ) {
      try { parent = parent.parentNode; } catch(error) { parent = elem; }
    }

    // Return YES if we actually just moused on to a sub-element
    return parent === elem;
  },

  /** @private
    Adds the primary event listener for the named type on the element.

    If the event type has a special handler defined in SC.Event.special,
    then that handler will be used.  Otherwise the normal browser method will
    be used.

    @param elem {Element} the target element
    @param eventType {String} the event type
  */
  _addEventListener: function(elem, eventType, useCapture) {
    var listener,
        special = this.special[eventType] ;

		if (!useCapture) {
			useCapture = false;
		}

    // Check for a special event handler
    // Only use addEventListener/attachEvent if the special
    // events handler returns false
    if ( !special || special.setup.call(elem) === false) {

      // Save element in cache.  This must be removed later to avoid
      // memory leaks.
      var guid = SC.guidFor(elem) ;
      this._elements[guid] = elem;

      // Either retrieve the previously cached listener or cache a new one.
      listener = SC.data(elem, "listener") || SC.data(elem, "listener",
        function handle_event (event) {
          return SC.Event.handle.call(SC.Event._elements[guid], event);
        });

      // Bind the global event handler to the element
      if (elem.addEventListener) {
        elem.addEventListener(eventType, listener, useCapture);
      } else if (elem.attachEvent) {
        // attachEvent is not working for IE8 and xhr objects
        // there is currently a hack in request , but it needs to fixed here.
        elem.attachEvent("on" + eventType, listener);
      }
    }

    elem = special = listener = null; // avoid memory leak
  },

  /** @private
    Removes the primary event listener for the named type on the element.

    If the event type has a special handler defined in SC.Event.special,
    then that handler will be used.  Otherwise the normal browser method will
    be used.

    Note that this will not clear the _elements hash from the element.  You
    must call SC.Event.unload() on unload to make sure that is cleared.

    @param elem {Element} the target element
    @param eventType {String} the event type
  */
  _removeEventListener: function(elem, eventType) {
    var listener, special = SC.Event.special[eventType] ;
    if (!special || (special.teardown.call(elem)===NO)) {
      // Retrieve the cached listener.
      listener = SC.data(elem, "listener") ;
      if (listener) {
        if (elem.removeEventListener) {
          elem.removeEventListener(eventType, listener, NO);
        } else if (elem.detachEvent) {
          elem.detachEvent("on" + eventType, listener);
        }
      }
    }

    elem = special = listener = null ;
  },

  _elements: {},

  _sc_normalizedEvents: null,

  // implement preventDefault() in a cross platform way

  /** @private Take an incoming event and convert it to a normalized event. */
  normalizeEvent: function (event) {
    var ret;

    // Create the cache the first time.
    if (!this._sc_normalizedEvents) { this._sc_normalizedEvents = {}; }
    ret = this._sc_normalizedEvents[event.type];

    // Create a new normalized SC.Event.
    if (!ret) {
      if (event === window.event) {
        // IE can't do event.normalized on an Event object
        ret = SC.Event.create(event) ;
      } else {
        ret = event.normalized ? event : SC.Event.create(event) ;
      }

    // When passed an SC.Event, don't re-normalize it.
    // TODO: This is hacky nonsense left over from a whole pile of bad decisions in SC.Event—
    } else if (event.normalized) {
      ret = event;

    // Update the cached normalized SC.Event with the new DOM event.
    } else {
      ret._sc_updateNormalizedEvent(event);
    }

    // Cache the normalized event object for this type of event. This allows us to avoid recreating
    // SC.Event objects constantly for noisy events such as 'mousemove' or 'mousewheel'.
    this._sc_normalizedEvents[event.type] = ret;

    return ret;
  },

  _global: {},

  /** @private properties to copy from native event onto the event */
  // TODO: Remove this needless copy.
  _props: ['altKey', 'attrChange', 'attrName', 'bubbles', 'button', 'cancelable', 'charCode', 'clientX', 'clientY', 'ctrlKey', 'currentTarget', 'data', 'detail', 'fromElement', 'handler', 'keyCode', 'metaKey', 'newValue', 'originalTarget', 'pageX', 'pageY', 'prevValue', 'relatedNode', 'relatedTarget', 'screenX', 'screenY', 'shiftKey', 'srcElement', 'target', 'timeStamp', 'toElement', 'type', 'view', 'which', 'touches', 'targetTouches', 'changedTouches', 'animationName', 'elapsedTime', 'dataTransfer']

});

SC.Event.prototype = {

  /**
    Set to YES if you have called either preventDefault() or stopPropagation().
    This allows a generic event handler to notice if you want to provide
    detailed control over how the browser handles the real event.

    @type Boolean
  */
  hasCustomEventHandling: false,

  /** @private Clear out the originalEvent from the SC.Event instance. */
  _sc_clearNormalizedEvent: function () {
    // Remove the original event.
    this.originalEvent = null;

    // Reset the custom event handling and normalized flag.
    this.hasCustomEventHandling = false;
    this.normalized = false;

    // Remove non-primitive properties copied over from the original event. While these will
    // be overwritten, it's best to quickly null them out to avoid any issues.
    var props = SC.Event._props,
      idx;

    idx = props.length;
    while(--idx >= 0) {
      var key = props[idx];
      this[key] = null;
    }

    // Remove the custom properties associated with the previous original event. While these will
    // be overwritten, it's best to quickly null them out to avoid any issues.
    this.timeStamp = null;
    this.target = null;
    this.relatedTarget = null;
    this.pageX = null;
    this.pageY = null;
    this.which = null;
    this.metaKey = null;
    this.wheelDelta = null;
    this.wheelDeltaY = null;
    this.wheelDeltaX = null;
  },

  /** @private Update the SC.Event instance with the new originalEvent. */
  _sc_updateNormalizedEvent: function (originalEvent) {
    var idx, len;

    // Flag.
    this.normalized = true;

    // copy properties from original event, if passed in.
    if (originalEvent) {
      this.originalEvent = originalEvent ;
      var props = SC.Event._props,
        key;

      len = props.length;
      idx = len;
      while(--idx >= 0) {
        key = props[idx] ;
        this[key] = originalEvent[key] ;
      }
    }

    // Fix timeStamp
    this.timeStamp = this.timeStamp || Date.now();

    // Fix target property, if necessary
    // Fixes #1925 where srcElement might not be defined either
    if (!this.target) this.target = this.srcElement || document;

    // check if target is a textnode (safari)
    if (this.target.nodeType === 3 ) this.target = this.target.parentNode;

    // Add relatedTarget, if necessary
    if (!this.relatedTarget && this.fromElement) {
      this.relatedTarget = (this.fromElement === this.target) ? this.toElement : this.fromElement;
    }

    // Calculate pageX/Y if missing and clientX/Y available
    if (SC.none(this.pageX) && !SC.none(this.clientX)) {
      var doc = document.documentElement, body = document.body;
      this.pageX = this.clientX + (doc && doc.scrollLeft || body && body.scrollLeft || 0) - (doc.clientLeft || 0);
      this.pageY = this.clientY + (doc && doc.scrollTop || body && body.scrollTop || 0) - (doc.clientTop || 0);
    }

    // Add which for key events
    if (!this.which && ((this.charCode || originalEvent.charCode === 0) ? this.charCode : this.keyCode)) {
      this.which = this.charCode || this.keyCode;
    }

    // Add metaKey to non-Mac browsers (use ctrl for PC's and Meta for Macs)
    if (!this.metaKey && this.ctrlKey) this.metaKey = this.ctrlKey;

    // Add which for click: 1 == left; 2 == middle; 3 == right
    // Note: button is not normalized, so don't use it
    if (!this.which && this.button) {
      this.which = ((this.button & 1) ? 1 : ((this.button & 2) ? 3 : ( (this.button & 4) ? 2 : 0 ) ));
    }

    // Normalize wheel delta values for mousewheel events.
    /*
      Taken from https://developer.mozilla.org/en-US/docs/Web/Events/mousewheel
      IE and Opera (Presto) only support wheelDelta attribute and do not support horizontal scroll.

      The wheelDeltaX attribute value indicates the wheelDelta attribute value along the horizontal axis. When a user operates the device for scrolling to right, the value is negative. Otherwise, i.e., if it's to left, the value is positive.

      The wheelDeltaY attribute value indicates the wheelDelta attribute value along the vertical axis. The sign of the value is the same as the wheelDelta attribute value.

      IE

      The value is the same as the delta value of WM_MOUSEWHEEL or WM_MOUSEHWHEEL. It means that if the mouse wheel doesn't support high resolution scroll, the value is 120 per notch. The value isn't changed even if the scroll amount of system settings is page scroll.

      ## Chrome

      On Windows, the value is the same as the delta value of WM_MOUSEWHEEL or WM_MOUSEHWHEEL. And also, the value isn't changed even if the scroll amount of system settings is page scroll, i.e., the value is the same as IE on Windows.

      On Linux, the value is 120 or -120 per native wheel event. This makes the same behavior as IE and Chrome for Windows.

      On Mac, the value is complicated. The value is changed if the device that causes the native wheel event supports continuous scroll.

      If the device supports continuous scroll (e.g., trackpad of MacBook or mouse wheel which can be turned smoothly), the value is computed from accelerated scroll amount. In this case, the value is the same as Safari.

      If the device does not support continuous scroll (typically, old mouse wheel which cannot be turned smoothly), the value is computed from non-accelerated scroll amount (120 per notch). In this case, the value is different from Safari.

      This difference makes a serious issue for web application developers. That is, web developers cannot know if mousewheel event is caused by which device.

      See WebInputEventFactory::mouseWheelEvent of the Chromium's source code for the detail.

      ## Safari

      The value is always computed from accelerated scroll amount. This is really different from other browsers except Chrome with continuous scroll supported device.

      Note: tested with the Windows package, the earliest available version was Safari 3.0 from 2007. It could be that earlier versions (on Mac) support the properties too.

      ## Opera (Presto)

      The value is always the detail attribute value ✕ 40.

      On Windows, since the detail attribute value is computed from actual scroll amount, the value is different from other browsers except the scroll amount per notch is 3 lines in system settings or a page.

      On Linux, the value is 80 or -80 per native wheel event. This is different from other browsers.

      On Mac, the detail attribute value is computed from accelerated scroll amout of native event. The value is usually much bigger than Safari's or Chrome's value.
    */
    if (this.type === 'mousewheel' || this.type === 'DOMMouseScroll' || this.type === 'MozMousePixelScroll') {
      var deltaMultiplier = SC.Event.MOUSE_WHEEL_MULTIPLIER;

      // normalize wheelDelta, wheelDeltaX, & wheelDeltaY for Safari
      if (SC.browser.isWebkit && originalEvent.wheelDelta !== undefined) {
        this.wheelDelta = 0 - (originalEvent.wheelDeltaY || originalEvent.wheelDeltaX);
        this.wheelDeltaY = 0 - (originalEvent.wheelDeltaY || 0);
        this.wheelDeltaX = 0 - (originalEvent.wheelDeltaX || 0);

      // normalize wheelDelta for Firefox (all Mozilla browsers)
      // note that we multiple the delta on FF to make it's acceleration more natural.
      } else if (!SC.none(originalEvent.detail) && SC.browser.isMozilla) {
        if (originalEvent.axis && (originalEvent.axis === originalEvent.HORIZONTAL_AXIS)) {
          this.wheelDeltaX = originalEvent.detail;
          this.wheelDelta = this.wheelDeltaY = 0;
        } else {
          this.wheelDelta = this.wheelDeltaY = originalEvent.detail;
          this.wheelDeltaX = 0;
        }

      // handle all other legacy browser
      } else {
        this.wheelDelta = this.wheelDeltaY = SC.browser.isIE || SC.browser.isOpera ? 0 - originalEvent.wheelDelta : originalEvent.wheelDelta;
        this.wheelDeltaX = 0;
      }

      this.wheelDelta *= deltaMultiplier;
      this.wheelDeltaX *= deltaMultiplier;
      this.wheelDeltaY *= deltaMultiplier;
    }
  },

  /**
    Returns the touches owned by the supplied view.

    @param {SC.View}
    @returns {Array} touches an array of SC.Touch objects
  */
  touchesForView: function(view) {
    if (this.touchContext) return this.touchContext.touchesForView(view);
  },

  /**
    Same as touchesForView, but sounds better for responders.

    @param {SC.RootResponder}
    @returns {Array} touches an array of SC.Touch objects
  */
  touchesForResponder: function(responder) {
    if (this.touchContext) return this.touchContext.touchesForView(responder);
  },

  /**
    Returns average data--x, y, and d (distance)--for the touches owned by the
    supplied view.

    @param {SC.View}
    @returns {Array} touches an array of SC.Touch objects
  */
  averagedTouchesForView: function(view) {
    if (this.touchContext) return this.touchContext.averagedTouchesForView(view);
    return null;
  },

  /**
    Indicates that you want to allow the normal default behavior.  Sets
    the hasCustomEventHandling property to YES but does not cancel the event.

    @returns {SC.Event} receiver
  */
  allowDefault: function() {
    this.hasCustomEventHandling = YES ;
    return this ;
  },

  /**
    Implements W3C standard.  Will prevent the browser from performing its
    default action on this event.

    @returns {SC.Event} receiver
  */
  preventDefault: function() {
    var evt = this.originalEvent ;
    if (evt && evt.type !== 'mousewheel') {
      if (evt.preventDefault) evt.preventDefault() ;
      else evt.returnValue = NO ; // IE8
    }
    this.hasCustomEventHandling = YES ;
    return this ;
  },

  /**
    Implements W3C standard.  Prevents further bubbling of the event.

    @returns {SC.Event} receiver
  */
  stopPropagation: function() {
    var evt = this.originalEvent ;
    if (evt) {
      if (evt.stopPropagation) evt.stopPropagation() ;
      evt.cancelBubble = YES ; // IE
    }
    this.hasCustomEventHandling = YES ;
    return this ;
  },

  /**
    Stops both the default action and further propagation.  This is more
    convenient than calling both.

    @returns {SC.Event} receiver
  */
  stop: function() {
    return this.preventDefault().stopPropagation();
  },

  /**
    Always YES to indicate the event was normalized.

    @type Boolean
  */
  normalized: YES,

  /**
    Returns the pressed character as a String.

    @returns {String}
  */
  // Warning.
  // Older versions of IE don't support charCode, but on keypress return the
  // ASCII value in keyCode instead of the key code.  Therefore, if this code is
  // used on keyDown in IE versions prior to 9.0, it will fail.
  // Since SproutCore passes the keydown and keypress events as a keyDown
  // method, it's most likely that this code will cause unexpected problems
  // in IE 7 & IE 8.
  //
  // Reference: http://unixpapa.com/js/key.html
  getCharString: function() {
    if(SC.browser.name === SC.BROWSER.ie &&
        SC.browser.compare(SC.browser.version, '9.0') < 0) {
      // Return an empty String for backspace, tab, left, right, up or down.
      if(this.keyCode === 8 || this.keyCode === 9 ||
          (this.keyCode >= 37 && this.keyCode <= 40)) {
        return String.fromCharCode(0);
      } else {
        // This will only be accurate if the event is a keypress event.
        return (this.keyCode>0) ? String.fromCharCode(this.keyCode) : null;
      }
    } else {
      return (this.charCode>0) ? String.fromCharCode(this.charCode) : null;
    }
  },

  /**
    Returns characters with command codes for the event.

    The first value is a normalized command code identifying the modifier keys that are pressed in
    combination with a character key. Command codes can be used to map key combinations to an action
    in the application. A basic example of a normalized command code would be `ctrl_x`, which
    corresponds to the combination of the `command` key with the `x` key being pressed on OS X or
    the `ctrl` key with the `x` key in Windows.

    The second value is the character string by itself. So for `ctrl_x`, this would be simply `x`. However,
    for `alt_x` it would be `≈` and for `alt_shift_x`, it would be `˛`.

    ## Considerations for Different OS's

    At this time, the meta (command) key in OS X is mapped to the `ctrl_` command code prefix. This
    means that on OS X, command + s, and on Windows, ctrl + s, both become the same command code, `ctrl_s`.

    Note that the order of command code prefixes is important and goes in the order: `ctrl_`, `alt_`,
    `shift_`. The following are examples of command codes:

    * ctrl_x
    * alt_x
    * ctrl_shift_x
    * ctrl_alt_shift_x
    * alt_shift_x

    @returns {Array}
  */
  commandCodes: function () {
    var charCode = this.charCode,
      keyCode = this.keyCode,
      charString = null,
      commandCode = null,
      baseKeyName;

    // WebKit browsers have equal values for `keyCode` and `charCode` on the keypress event. For example,
    // the letter `r` and the function `f3` both have a `keyCode` of 114. But the `r` also has a `charCode`
    // of 114.
    // If there is a keyCode and no matching charCode it is a function key.
    if (keyCode && keyCode !== charCode) {
      commandCode = SC.FUNCTION_KEYS[keyCode];
    }

    // Use the function name as the key name in the command code (ex. `down` could become `shift_down`).
    if (commandCode) {
      baseKeyName = commandCode;

    // Find the base character for the key (i.e. `alt` + `a` becomes `å`, but we really want the key name, `a`).
    } else {
      baseKeyName = SC.PRINTABLE_KEYS[keyCode];
    }

    // If there is a base key name, append any modifiers to generate the command code.
    if (baseKeyName) {
      var modifiers = '';

      // Append the pressed modifier keys into a name used to identify command codes.
      // For example, holding the keys: shift, command & x, will map to the name "ctrl_shift_x".
      if (this.ctrlKey || this.metaKey) modifiers += 'ctrl_';
      // UNUSED. In a future version we should scrap ctrl vs. meta for the proper intent depending on the current OS.
      // if (this.ctrlKey) modifiers += 'ctrl_';
      // In OS X at least, when the ctrl key is pressed, both ctrlKey & metaKey are true. This makes it impossible to identify
      // ctrl + meta vs. just ctrl. We can identify just meta though.
      // else if (this.metaKey) modifiers += 'meta_';

      if (this.altKey) modifiers += 'alt_';
      if (this.shiftKey) modifiers += 'shift_';

      commandCode = modifiers + baseKeyName;
    }

    charString = this.getCharString();  // A character string or null.

    return [commandCode, charString];
  }

};

// Also provide a Prototype-like API so that people can use either one.

/** Alias for add() method.  This provides a Prototype-like API. */
SC.Event.observe = SC.Event.add ;

/** Alias for remove() method.  This provides a Prototype-like API */
SC.Event.stopObserving = SC.Event.remove ;

/** Alias for trigger() method.  This provides a Prototype-like API */
SC.Event.fire = SC.Event.trigger;

// Register unload handler to eliminate any registered handlers
// This avoids leaks in IE and issues with mouseout or other handlers on
// other browsers.

if(SC.browser.name === SC.BROWSER.ie) SC.Event.add(window, 'unload', SC.Event.prototype, SC.Event.unload) ;

SC.MODIFIER_KEYS = {
  16:'shift', 17:'ctrl', 18: 'alt'
};

SC.FUNCTION_KEYS = {
  8: 'backspace',  9: 'tab',  13: 'return',  19: 'pause',  27: 'escape',
  33: 'pageup', 34: 'pagedown', 35: 'end', 36: 'home',
  37: 'left', 38: 'up', 39: 'right', 40: 'down', 44: 'printscreen',
  45: 'insert', 46: 'delete', 112: 'f1', 113: 'f2', 114: 'f3', 115: 'f4',
  116: 'f5', 117: 'f7', 119: 'f8', 120: 'f9', 121: 'f10', 122: 'f11',
  123: 'f12', 144: 'numlock', 145: 'scrolllock'
} ;

SC.PRINTABLE_KEYS = {
  32: ' ', 48:"0", 49:"1", 50:"2", 51:"3", 52:"4", 53:"5", 54:"6", 55:"7",
  56:"8", 57:"9", 59:";", 61:"=", 65:"a", 66:"b", 67:"c", 68:"d", 69:"e",
  70:"f", 71:"g", 72:"h", 73:"i", 74:"j", 75:"k", 76:"l", 77:"m", 78:"n",
  79:"o", 80:"p", 81:"q", 82:"r", 83:"s", 84:"t", 85:"u", 86:"v", 87:"w",
  88:"x", 89:"y", 90:"z", 107:"+", 109:"-", 110:".", 188:",", 190:".",
  191:"/", 192:"`", 219:"[", 220:"\\", 221:"]", 222:"\""
} ;

/* >>>>>>>>>> BEGIN source/system/cursor.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

// standard browser cursor definitions
// TODO: remove extra constants in next version
// TODO: consider adding theme cursors for custom behaviors like drag & drop
SC.SYSTEM_CURSOR = SC.DEFAULT_CURSOR = 'default';
SC.AUTO_CURSOR = 'auto';
SC.CROSSHAIR_CURSOR = 'crosshair';
SC.HAND_CURSOR = SC.POINTER_CURSOR = 'pointer';
SC.MOVE_CURSOR = 'move';
SC.E_RESIZE_CURSOR = 'e-resize';
SC.NE_RESIZE_CURSOR = 'ne-resize';
SC.NW_RESIZE_CURSOR = 'nw-resize';
SC.N_RESIZE_CURSOR = 'n-resize';
SC.SE_RESIZE_CURSOR = 'se-resize';
SC.SW_RESIZE_CURSOR = 'sw-resize';
SC.S_RESIZE_CURSOR = 's-resize';
SC.W_RESIZE_CURSOR = 'w-resize';
SC.IBEAM_CURSOR = SC.TEXT_CURSOR = 'text';
SC.WAIT_CURSOR = 'wait';
SC.HELP_CURSOR = 'help';

/**
  @class SC.Cursor

  A Cursor object is used to synchronize the cursor used by multiple views at
  the same time. For example, thumb views within a split view acquire a cursor
  instance from the split view and set it as their cursor. The split view is
  able to update its cursor object to reflect the state of the split view.
  Because cursor objects are implemented internally with CSS, this is a very
  efficient way to update the same cursor for a group of view objects.

  Note: This object creates an anonymous CSS class to represent the cursor.
  The anonymous CSS class is automatically added by SproutCore to views that
  have the cursor object set as "their" cursor. Thus, all objects attached to
  the same cursor object will have their cursors updated simultaneously with a
  single DOM call.

  @extends SC.Object
*/
SC.Cursor = SC.Object.extend(
/** @scope SC.Cursor.prototype */ {

  /** @private */
  init: function () {
    arguments.callee.base.apply(this,arguments);

    // create a unique style rule and add it to the shared cursor style sheet
    var cursorStyle = this.get('cursorStyle') || SC.DEFAULT_CURSOR,
      ss = this.constructor.sharedStyleSheet(),
      guid = SC.guidFor(this);

    if (ss.insertRule) { // WC3
      ss.insertRule(
        '.' + guid + ' {cursor: ' + cursorStyle + ';}',
        ss.cssRules ? ss.cssRules.length : 0
      );
    } else if (ss.addRule) { // IE
      ss.addRule('.' + guid, 'cursor: ' + cursorStyle);
    }

    this.cursorStyle = cursorStyle;
    this.className = guid; // used by cursor clients...
    return this;
  },

  /**
    This property is the connection between cursors and views. The default
    SC.View behavior is to add this className to a view's layer if it has
    its cursor property defined.

    @readOnly
    @type String the css class name updated by this cursor
  */
  className: null,

  /**
    @type String the cursor value, can be 'url("path/to/cursor")'
  */
  cursorStyle: SC.DEFAULT_CURSOR,

  /** @private */
  cursorStyleDidChange: function () {
    var cursorStyle, rule, selector, ss, rules, idx, len;
    cursorStyle = this.get('cursorStyle') || SC.DEFAULT_CURSOR;
    rule = this._rule;
    if (rule) {
      rule.style.cursor = cursorStyle; // fast path
      return;
    }

    // slow path, taken only once
    selector = '.' + this.get('className');
    ss = this.constructor.sharedStyleSheet();
    rules = (ss.cssRules ? ss.cssRules : ss.rules) || [];

    // find our rule, cache it, and update the cursor style property
    for (idx = 0, len = rules.length; idx < len; ++idx) {
      rule = rules[idx];
      if (rule.selectorText === selector) {
        this._rule = rule; // cache for next time
        rule.style.cursor = cursorStyle; // update the cursor
        break;
      }
    }
  }.observes('cursorStyle')

  // TODO implement destroy

});


/** @private */
SC.Cursor.sharedStyleSheet = function () {
  var ssEl,
    head,
    ss = this._styleSheet;

  if (!ss) {
    // create the stylesheet object the hard way (works everywhere)
    ssEl = document.createElement('style');
    head = document.getElementsByTagName('head')[0];
    if (!head) head = document.documentElement; // fix for Opera
    head.appendChild(ssEl);

    // Get the actual stylesheet object, not the DOM element.  We expect it to
    // be the last stylesheet in the document, but test to make sure no other
    // stylesheet has appeared.
    for (var i = document.styleSheets.length - 1; i >= 0; i--) {
      ss = document.styleSheets[i];

      if (ss.ownerNode === ssEl) {
        // We've found the proper stylesheet.
        this._styleSheet = ss;
        break;
      }
    }
  }

  return ss;
};

/* >>>>>>>>>> BEGIN source/system/responder.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/** @class

  Provides common methods for sending events down a responder chain.
  Responder chains are used most often to deliver events to user interface
  elements in your application, but you can also use them to deliver generic
  events to any part of your application, including controllers.

  @extends SC.Object
  @since SproutCore 1.0
*/
SC.Responder = SC.Object.extend( /** @scope SC.Responder.prototype */ {

  isResponder: YES,

  /** @property
    The pane this responder belongs to.  This is used to determine where you
    belong to in the responder chain.  Normally you should leave this property
    set to null.
  */
  pane: null,

  /** @property
    The app this responder belongs to.  For non-user-interface responder
    chains, this is used to determine the context.  Usually this
    is the property you will want to work with.
  */
  responderContext: null,

  /** @property
    This is the nextResponder in the responder chain.  If the receiver does
    not implement a particular event handler, it will bubble to the next
    responder.

    This can point to an object directly or it can be a string, in which case
    the path will be resolved from the responderContext root.
  */
  nextResponder: null,

  /** @property
    YES if the view is currently first responder.  This property is always
    edited by the pane during its makeFirstResponder() method.
  */
  isFirstResponder: NO,

  /** @property

    YES the responder is somewhere in the responder chain.  This currently
    only works when used with a ResponderContext.

    @type {Boolean}
  */
  hasFirstResponder: NO,

  /** @property
    Set to YES if your view is willing to accept first responder status.  This is used when calculating key responder loop.
  */
  acceptsFirstResponder: YES,

  becomingFirstResponder: NO,

  /**
    Call this method on your view or responder to make it become first
    responder.

    @returns {SC.Responder} receiver
  */
  becomeFirstResponder: function () {
    var pane = this.get('pane') || this.get('responderContext') ||
              this.pane();
    if (pane && this.get('acceptsFirstResponder')) {
      if (pane.get('firstResponder') !== this) pane.makeFirstResponder(this);
    }
    return this;
  },

  /**
    Call this method on your view or responder to resign your first responder
    status. Normally this is not necessary since you will lose first responder
    status automatically when another view becomes first responder.

    @param {Event} the original event that caused this method to be called
    @returns {SC.Responder} receiver
  */
  resignFirstResponder: function (evt) {
    var pane = this.get('pane') || this.get('responderContext');
    if (pane && (pane.get('firstResponder') === this)) {
      pane.makeFirstResponder(null, evt);
    }
    return YES;
  },

  /**
    Called just before the responder or any of its subresponder's are about to
    lose their first responder status.  The passed responder is the responder
    that is about to lose its status.

    Override this method to provide any standard teardown when the first
    responder changes.

    @param {SC.Responder} responder the responder that is about to change
    @returns {void}
  */
  willLoseFirstResponder: function (responder) {},

  /**
    Called just after the responder or any of its subresponder's becomes a
    first responder.

    Override this method to provide any standard setup when the first
    responder changes.

    @param {SC.Responder} responder the responder that changed
    @returns {void}
  */
  didBecomeFirstResponder: function (responder) {},

  /** SC.Object.prototype.destroy */
  destroy: function () {
    this.resignFirstResponder();

    arguments.callee.base.apply(this,arguments);
  }

});

/* >>>>>>>>>> BEGIN source/system/theme.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/** @class
  Represents a theme, and is also the core theme in which SC looks for
  other themes.

  If an SC.View has a theme of "ace", it will look in its parent's theme
  for the theme "ace". If there is no parent--that is, if the view is a
  frame--it will look in SC.Theme for the named theme. To find a theme,
  it calls find(themeName) on the theme.

  To be located, themes must be registered either as a root theme (by
  calling SC.Theme.addTheme) or as a child theme of another theme (by
  calling theTheme.addTheme).

  All themes are instances. However, new instances based on the current
  instance can always be created: just call .create(). This method is used
  by SC.View when you name a theme that doesn't actually exist: it creates
  a theme based on the parent theme.

  Locating Child Themes
  ----------------------------
  Locating child themes is relatively simple for the most part: it looks in
  its own "themes" property, which is an object inheriting from its parent's
  "themes" set, so it includes all parent themes.

  However, it does _not_ include global themes. This is because, when find()
  is called, it wants to ensure any child theme is specialized. That is, the
  child theme should include all class names of the base class theme. This only
  makes sense if the theme really is a child theme of the theme or one of its
  base classes; if the theme is a global theme, those class names should not
  be included.

  This makes sense logically as well, because when searching for a render delegate,
  it will locate it in any base theme that has it, but that doesn't mean
  class names from the derived theme shouldn't be included.

  @extends SC.Object
  @since SproutCore 1.1
  @author Alex Iskander
*/
SC.Theme = {
  /**
    Walks like a duck.
  */
  isTheme: YES,

  /**
    Class names for the theme.

    These class names include the name of the theme and the names
    of all parent themes. You can also add your own.
   */
  classNames: [],

  /**
    @private
    A helper to extend class names with another set of classnames. The
    other set of class names can be a hash, an array, a Set, or a space-
    delimited string.
  */
  _extend_class_names: function(classNames) {
    // class names may be a CoreSet, array, string, or hash
    if (classNames) {
      if (SC.typeOf(classNames) === SC.T_HASH && !classNames.isSet) {
        for (var className in classNames) {
          var index = this.classNames.indexOf(className);
          if (classNames[className] && index < 0) {
            this.classNames.push(className)
          } else if (index >= 0) {
            this.classNames.removeAt(index);
          }
        }
      } else {
        if (typeof classNames === "string") {
          

          classNames = classNames.split(' ');
        }

        


        // it must be an array or a CoreSet...
        classNames.forEach(function (className) {
          if (!this.classNames.contains(className)) {
            this.classNames.push(className)
          }
        }, this);
      }
    }
  },

  /**
    @private
    Helper method that extends this theme with some extra properties.

    Used during Theme.create();
   */
  _extend_self: function(ext) {
    if (ext.classNames) this._extend_class_names(ext.classNames);

    // mixin while enabling arguments.callee.base.apply(this,arguments);
    var key, value, cur;
    for (key in ext) {
      if (key === 'classNames') continue; // already handled.
      if (!ext.hasOwnProperty(key)) continue;

      value = ext[key];
      if (value instanceof Function && !value.base && (value !== (cur=this[key]))) {
        value.base = cur;
      }

      this[key] = value;
    }
  },

  /**
    Creates a new theme based on this one. The name of the new theme will
    be added to the classNames set.
  */
  create: function() {
    var result = SC.beget(this);
    result.baseTheme = this;

    // if we don't beget themes, the same instance would be shared between
    // all themes. this would be bad: imagine that we have two themes:
    // "Ace" and "Other." Each one has a "capsule" child theme. If they
    // didn't have their own child themes hash, the two capsule themes
    // would conflict.
    if (this.themes === SC.Theme.themes) {
      result.themes = {};
    } else {
      result.themes = SC.beget(this.themes);
    }

    // we also have private ("invisible") child themes; look at invisibleSubtheme
    // method.
    result._privateThemes = {};

    // also, the theme specializes all child themes as they are created
    // to ensure that all of the class names on this theme are included.
    result._specializedThemes = {};

    // we could put this in _extend_self, but we don't want to clone
    // it for each and every argument passed to create().
    result.classNames = SC.clone(this.classNames);

    var args = arguments, len = args.length, idx, mixin;
    for (idx = 0; idx < len; idx++) {
      result._extend_self(args[idx]);
    }

    if (result.name && !result.classNames.contains(result.name)) result.classNames.push(result.name);

    return result;
  },

  /**
    Creates a child theme based on this theme, with the given name,
    and automatically registers it as a child theme.
  */
  subtheme: function(name) {
    // extend the theme
    var t = this.create({ name: name });

    // add to our set of themes
    this.addTheme(t);

    // and return the theme class
    return t;
  },

  /**
    Semi-private, only used by SC.View to create "invisible" subthemes. You
    should never need to call this directly, nor even worry about.

    Invisible subthemes are only available when find is called _on this theme_;
    if find() is called on a child theme, it will _not_ locate this theme.

    The reason for "invisible" subthemes is that SC.View will create a subtheme
    when it finds a theme name that doesn't exist. For example, imagine that you
    have a parent view with theme "base", and a child view with theme "popup".
    If no "popup" theme can be found inside "base", SC.View will call
    base.subtheme. This will create a new theme with the name "popup",
    derived from "base". Everyone is happy.

    But what happens if you then change the parent theme to "ace"? The view
    will try again to find "popup", and it will find it-- but it will still be
    a child theme of "base"; SC.View _needs_ to re-subtheme it, but it won't
    know it needs to, because it has been found.
  */
  invisibleSubtheme: function(name) {
    // extend the theme
    var t = this.create({ name: name });

    // add to our set of themes
    this._privateThemes[name] = t;

    // and return the theme class
    return t;
  },

  //
  // THEME MANAGEMENT
  //

  themes: {},

  /**
    Finds a theme by name within this theme (the theme must have
    previously been added to this theme or a base theme by using addTheme, or
    been registered as a root theme).

    If the theme found is not a root theme, this will specialize the theme so
    that it includes all class names for this theme.
  */
  find: function(themeName) {
    if (this === SC.Theme) return this.themes[themeName];
    var theme;

    // if there is a private theme (invisible subtheme) by that name, use it
    theme = this._privateThemes[themeName];
    if (theme) return theme;

    // if there is a specialized version (the theme extended with our class names)
    // return that one
    theme = this._specializedThemes[themeName];
    if (theme) return theme;

    // otherwise, we may need to specialize one.
    theme = this.themes[themeName];
    if (theme && !this._specializedThemes[themeName]) {
      return (this._specializedThemes[themeName] = theme.create({ classNames: this.classNames }));
    }

    // and finally, if it is a root theme, we do nothing to it.
    theme = SC.Theme.themes[themeName];
    if (theme) return theme;

    return null;
  },

  /**
    Adds a child theme to the theme. This allows the theme to be located
    by SproutCore views and such later.

    Each theme is registered in the "themes" property by name. Calling
    find(name) will return the theme with the given name.

    Because the themes property is an object begetted from (based on) any
    parent theme's "themes" property, if the theme cannot be found in this
    theme, it will be found in any parent themes.
  */
  addTheme: function(theme) {
    this.themes[theme.name] = theme;
  }
};

// SproutCore _always_ has its base theme. This is not quite
// optimal, but the reasoning is because of test running: the
// test runner, when running foundation unit tests, cannot load
// the theme. As such, foundation must include default versions of
// all of its render delegates, and it does so in BaseTheme. All SproutCore
// controls have render delegates in BaseTheme.
SC.BaseTheme = SC.Theme.create({
  name: '' // it is a base class, and doesn't need a class name or such
});

// however, SproutCore does need a default theme, even if no
// actual theme is loaded.
SC.Theme.themes['sc-base'] = SC.BaseTheme;
SC.defaultTheme = 'sc-base';

/* >>>>>>>>>> BEGIN source/system/locale.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  The Locale defined information about a specific locale, including date and
  number formatting conventions, and localization strings.  You can define
  various locales by adding them to the SC.locales hash, keyed by language
  and/or country code.

  On page load, the default locale will be chosen based on the current
  languages and saved at SC.Locale.current.  This locale is used for
  localization, etc.

  ## Creating a new locale

  You can create a locale by simply extending the SC.Locale class and adding
  it to the locales hash:

      SC.Locale.locales['en'] = SC.Locale.extend({ .. config .. }) ;

  Alternatively, you could choose to base your locale on another locale by
  extending that locale:

      SC.Locale.locales['en-US'] = SC.Locale.locales['en'].extend({ ... }) ;

  Note that if you do not define your own strings property, then your locale
  will inherit any strings added to the parent locale.  Otherwise you must
  implement your own strings instead.

  @extends SC.Object
  @since SproutCore 1.0
*/
SC.Locale = SC.Object.extend({

  init: function() {
    // make sure we know the name of our own locale.
    if (!this.language) SC.Locale._assignLocales();

    // Make sure we have strings that were set using the new API.  To do this
    // we check to a bool that is set by one of the string helpers.  This
    // indicates that the new API was used. If the new API was not used, we
    // check to see if the old API was used (which places strings on the
    // String class).
    if (!this.hasStrings) {
      var langs = this._deprecatedLanguageCodes || [] ;
      langs.push(this.language);
      var idx = langs.length ;
      var strings = null ;
      while(!strings && --idx >= 0) {
        strings = String[langs[idx]];
      }
      if (strings) {
        this.hasStrings = YES;
        this.strings = strings ;
      }
    }
  },

  /** Set to YES when strings have been added to this locale. */
  hasStrings: NO,

  /** The strings hash for this locale. */
  strings: {},

  /**
    The metrics for this locale.  A metric is a singular value that is usually
    used in a user interface layout, such as "width of the OK button".
  */
  metrics: {},

  /**
    The inflection constants for this locale.
  */
  inflectionConstants: null,

  /**
    The method used to compute the ordinal of a number for this locale.
  */
  ordinalForNumber: function(number) { 
    return '';
  },


  toString: function() {
    if (!this.language) SC.Locale._assignLocales() ;
    return "SC.Locale["+this.language+"]"+SC.guidFor(this) ;
  },

  /**
    Returns the localized version of the string or the string if no match
    was found.

    @param {String} string
    @param {String} optional default string to return instead
    @returns {String}
  */
  locWithDefault: function(string, def) {
    var ret = this.strings[string];

    // strings may be blank, so test with typeOf.
    if (SC.typeOf(ret) === SC.T_STRING) return ret;
    else if (SC.typeOf(def) === SC.T_STRING) return def;
    return string;
  },

  /**
    Returns the localized value of the metric for the specified key, or
    undefined if no match is found.

    @param {String} key
    @returns {Number} ret
  */
  locMetric: function(key) {
    var ret = this.metrics[key];
    if (SC.typeOf(ret) === SC.T_NUMBER) {
      return ret;
    }
    else if (ret === undefined) {
      SC.warn("No localized metric found for key \"" + key + "\"");
      return undefined;
    }
    else {
      SC.warn("Unexpected metric type for key \"" + key + "\"");
      return undefined;
    }
  },

  /**
    Creates and returns a new hash suitable for use as an SC.View’s 'layout'
    hash.  This hash will be created by looking for localized metrics following
    a pattern based on the “base key” you specify.

    For example, if you specify "Button.Confirm", the following metrics will be
    used if they are defined:

      Button.Confirm.left
      Button.Confirm.top
      Button.Confirm.right
      Button.Confirm.bottom
      Button.Confirm.width
      Button.Confirm.height
      Button.Confirm.midWidth
      Button.Confirm.minHeight
      Button.Confirm.centerX
      Button.Confirm.centerY

    Additionally, you can optionally specify a hash which will be merged on top
    of the returned hash.  For example, if you wish to allow a button’s width
    to be configurable per-locale, but always wish for it to be centered
    vertically and horizontally, you can call:

      locLayout("Button.Confirm", {centerX:0, centerY:0})

    …so that you can combine both localized and non-localized elements in the
    returned hash.  (An exception will be thrown if there is a locale-specific
    key that matches a key specific in this hash.)

    @param {String} baseKey
    @param {String} (optional) additionalHash
    @returns {Hash}
  */
  locLayout: function(baseKey, additionalHash) {
    // Note:  In this method we'll directly access this.metrics rather than
    //        going through locMetric() for performance and to avoid
    //        locMetric()'s sanity checks.

    var i, len, layoutKey, key, value,
        layoutKeys = SC.Locale.layoutKeys,
        metrics    = this.metrics,

        // Cache, to avoid repeated lookups
        typeOfFunc = SC.typeOf,
        numberType = SC.T_NUMBER,

        ret        = {};


    // Start off by mixing in the additionalHash; we'll look for collisions with
    // the localized values in the loop below.
    if (additionalHash) SC.mixin(ret, additionalHash);


    // For each possible key that can be included in a layout hash, see whether
    // we have a localized value.
    for (i = 0, len = layoutKeys.length;  i < len;  ++i) {
      layoutKey = layoutKeys[i];
      key       = baseKey + "." + layoutKey;
      value     = metrics[key];

      if (typeOfFunc(value) === numberType) {
        // We have a localized value!  As a sanity check, if the caller
        // specified an additional hash and it has the same key, we'll throw an
        // error.
        if (additionalHash  &&  additionalHash[layoutKey]) {
          throw new Error("locLayout():  There is a localized value for the key '" + key + "' but a value for '" + layoutKey + "' was also specified in the non-localized hash");
        }

        ret[layoutKey] = value;
      }
    }

    return ret;
  }

}) ;

SC.Locale.mixin(/** @scope SC.Locale */ {

  /**
    If YES, localization will favor the detected language instead of the
    preferred one.
  */
  useAutodetectedLanguage: NO,

  /**
    This property is set by the build tools to the current build language.
  */
  preferredLanguage: null,

  /**
    This property holds all attributes name which can be used for a layout hash
    (for an SC.View).  These are what we support inside the layoutFor() method.
  */
  layoutKeys: ['left', 'top', 'right', 'bottom', 'width', 'height',
               'minWidth', 'minHeight', 'centerX', 'centerY'],

  /**
    Invoked at the start of SproutCore's document onready handler to setup
    the currentLocale.  This will use the language properties you have set on
    the locale to make a decision.
  */
  createCurrentLocale: function() {
    // get values from String if defined for compatibility with < 1.0 build
    // tools.
    var autodetect = (String.useAutodetectedLanguage !== undefined) ? String.useAutodetectedLanguage : this.useAutodetectedLanguage;
    var preferred = (String.preferredLanguage !== undefined) ? String.preferredLanguage : this.preferredLanguage ;


    // determine the language
    var lang = ((autodetect) ? SC.browser.language : null) || preferred || SC.browser.language || 'en';
    lang = SC.Locale.normalizeLanguage(lang) ;
    // get the locale class.  If a class cannot be found, fall back to generic
    // language then to english.
    var klass = this.localeClassFor(lang) ;

    // if the detected language does not match the current language (or there
    // is none) then set it up.
    if (lang != this.currentLanguage) {
      this.currentLanguage = lang ; // save language
      this.currentLocale = klass.create(); // setup locale
    }
    return this.currentLocale ;
  },

  /**
    Finds the locale class for the names language code or creates on based on
    its most likely parent.
  */
  localeClassFor: function(lang) {
    lang = SC.Locale.normalizeLanguage(lang) ;
    var parent, klass = this.locales[lang];

    // if locale class was not found and there is a broader-based locale
    // present, create a new locale based on that.
    if (!klass && ((parent = lang.split('-')[0]) !== lang) && (klass = this.locales[parent])) {
      klass = this.locales[lang] = klass.extend() ;
    }

    // otherwise, try to create a new locale based on english.
    if (!klass) klass = this.locales[lang] = this.locales.en.extend();

    return klass;
  },

  /**
    Shorthand method to define the settings for a particular locale.
    The settings you pass here will be applied directly to the locale you
    designate.

    If you are already holding a reference to a locale definition, you can
    also use this method to operate on the receiver.

    If the locale you name does not exist yet, this method will create the
    locale for you, based on the most closely related locale or english.  For
    example, if you name the locale 'fr-CA', you will be creating a locale for
    French as it is used in Canada.  This will be based on the general French
    locale (fr), since that is more generic.  On the other hand, if you create
    a locale for mandarin (cn), it will be based on generic english (en)
    since there is no broader language code to match against.

    @param {String} localeName
    @param {Hash} options
    @returns {SC.Locale} the defined locale
  */
  define: function(localeName, options) {
    var locale ;
    if (options===undefined && (SC.typeOf(localeName) !== SC.T_STRING)) {
      locale = this; options = localeName ;
    } else locale = SC.Locale.localeClassFor(localeName) ;
    SC.mixin(locale.prototype, options) ;
    return locale ;
  },

  /**
    Gets the current options for the receiver locale.  This is useful for
    inspecting registered locales that have not been instantiated.

    @returns {Hash} options + instance methods
  */
  options: function() { return this.prototype; },

  /**
    Adds the passed hash to the locale's given property name.  Note that
    if the receiver locale inherits its hashes from its parent, then the
    property table will be cloned first.

    @param {String} name
    @param {Hash} hash
    @returns {Object} receiver
  */
  addHashes: function(name, hash) {
    // make sure the target hash exists and belongs to the locale
    var currentHash = this.prototype[name];
    if (currentHash) {
      if (!this.prototype.hasOwnProperty(currentHash)) {
        currentHash = this.prototype[name] = SC.clone(currentHash);
      }
    }
    else {
      currentHash = this.prototype[name] = {};
    }

    // add hash
    if (hash) this.prototype[name] = SC.mixin(currentHash, hash);

    return this;
  },

  /**
    Adds the passed method to the locale's given property name. 

    @param {String} name
    @param {Function} method
    @returns {Object} receiver
  */
  addMethod: function(name, method) {
    this.prototype[name] = method;
    return this;
  },

  /**
    Adds the passed hash of strings to the locale's strings table.  Note that
    if the receiver locale inherits its strings from its parent, then the
    strings table will be cloned first.

    @returns {Object} receiver
  */
  addStrings: function(stringsHash) {
    var ret = this.addHashes('strings', stringsHash);

    // Note:  We don't need the equivalent of this.hasStrings here, because we
    //        are not burdened by an older API to look for like the strings
    //        support is.
    this.prototype.hasStrings = YES;

    return ret;
  },

  /**
    Adds the passed hash of metrics to the locale's metrics table, much as
    addStrings() is used to add in strings.   Note that if the receiver locale
    inherits its metrics from its parent, then the metrics table will be cloned
    first.

    @returns {Object} receiver
  */
  addMetrics: function(metricsHash) {
    return this.addHashes('metrics', metricsHash);
  },

  _map: { english: 'en', french: 'fr', german: 'de', japanese: 'ja', jp: 'ja', spanish: 'es' },

  /**
    Normalizes the passed language into a two-character language code.
    This method allows you to specify common languages in their full english
    name (i.e. English, French, etc). and it will be treated like their two
    letter code equivalent.

    @param {String} languageCode
    @returns {String} normalized code
  */
  normalizeLanguage: function(languageCode) {
    if (!languageCode) return 'en' ;
    return SC.Locale._map[languageCode.toLowerCase()] || languageCode ;
  },

  // this method is called once during init to walk the installed locales
  // and make sure they know their own names.
  _assignLocales: function() {
    for(var key in this.locales) this.locales[key].prototype.language = key;
  },

  toString: function() {
    if (!this.prototype.language) SC.Locale._assignLocales() ;
    return "SC.Locale["+this.prototype.language+"]" ;
  },

  // make sure important properties are copied to new class.
  extend: function() {
    var ret= SC.Object.extend.apply(this, arguments) ;
    ret.addStrings= SC.Locale.addStrings;
    ret.define = SC.Locale.define ;
    ret.options = SC.Locale.options ;
    ret.toString = SC.Locale.toString ;
    return ret ;
  }

}) ;

/**
  This locales hash contains all of the locales defined by SproutCore and
  by your own application.  See the SC.Locale class definition for the
  various properties you can set on your own locales.

  @type Hash
*/
SC.Locale.locales = {
  en: SC.Locale.extend({ _deprecatedLanguageCodes: ['English'] }),
  fr: SC.Locale.extend({ _deprecatedLanguageCodes: ['French'] }),
  de: SC.Locale.extend({ _deprecatedLanguageCodes: ['German'] }),
  ja: SC.Locale.extend({ _deprecatedLanguageCodes: ['Japanese', 'jp'] }),
  es: SC.Locale.extend({ _deprecatedLanguageCodes: ['Spanish'] })
};

/**
  This special helper will store the propertyName / hashes pair you pass 
  in the locale matching the language code.  If a locale is not defined 
  from the language code you specify, then one will be created for you 
  with the english locale as the parent.

  @param {String} languageCode
  @param {String} propertyName
  @param {Hash} hashes
  @returns {void}
*/
SC.hashesForLocale = function(languageCode, propertyName, hashes) {
  var locale = SC.Locale.localeClassFor(languageCode);
  locale.addHashes(propertyName, hashes);
};

/**
  Just like SC.hashesForLocale, but for methods.

  @param {String} languageCode
  @param {String} propertyName
  @param {Function} method
  @returns {void}
*/
SC.methodForLocale = function(languageCode, propertyName, method) {
  var locale = SC.Locale.localeClassFor(languageCode);
  locale.addMethod(propertyName, method);
};

/**
  This special helper will store the strings you pass in the locale matching
  the language code.  If a locale is not defined from the language code you
  specify, then one will be created for you with the english locale as the
  parent.

  @param {String} languageCode
  @param {Hash} strings
  @returns {Object} receiver
*/
SC.stringsFor = function(languageCode, strings) {
  // get the locale, creating one if needed.
  var locale = SC.Locale.localeClassFor(languageCode);
  locale.addStrings(strings);
  return this ;
};

/**
  Just like SC.stringsFor, but for metrics.

  @param {String} languageCode
  @param {Hash} metrics
  @returns {Object} receiver
*/
SC.metricsFor = function(languageCode, metrics) {
  var locale = SC.Locale.localeClassFor(languageCode);
  locale.addMetrics(metrics);
  return this;
};

/* >>>>>>>>>> BEGIN source/system/string.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('system/locale');

// These are basic enhancements to the string class used throughout
// SproutCore.
/** @private */
SC.STRING_TITLEIZE_REGEXP = (/([\s|\-|\_|\n])([^\s|\-|\_|\n]?)/g);
SC.STRING_DECAMELIZE_REGEXP = (/([a-z])([A-Z])/g);
SC.STRING_DASHERIZE_REGEXP = (/[ _]/g);
SC.STRING_DASHERIZE_CACHE = {};
SC.STRING_TRIM_LEFT_REGEXP = (/^\s+/g);
SC.STRING_TRIM_RIGHT_REGEXP = (/\s+$/g);
SC.STRING_CSS_ESCAPED_REGEXP = (/(:|\.|\[|\])/g);

/**
  @namespace

  SproutCore implements a variety of enhancements to the built-in String
  object that make it easy to perform common substitutions and conversions.

  Most of the utility methods defined here mirror those found in Prototype
  1.6.

  @since SproutCore 1.0
  @lends String.prototype
*/
SC.mixin(SC.String, {

  /**
    Capitalizes a string.

    ## Examples

        capitalize('my favorite items') // 'My favorite items'
        capitalize('css-class-name')    // 'Css-class-name'
        capitalize('action_name')       // 'Action_name'
        capitalize('innerHTML')         // 'InnerHTML'

    @return {String} capitalized string
  */
  capitalize: function(str) {
    return str.charAt(0).toUpperCase() + str.slice(1);
  },

  /**
    Camelizes a string.  This will take any words separated by spaces, dashes
    or underscores and convert them into camelCase.

    ## Examples

        camelize('my favorite items') // 'myFavoriteItems'
        camelize('css-class-name')    // 'cssClassName'
        camelize('action_name')       // 'actionName'
        camelize('innerHTML')         // 'innerHTML'

    @returns {String} camelized string
  */
  camelize: function(str) {
    var ret = str.replace(SC.STRING_TITLEIZE_REGEXP, function(str, separater, character) {
      return character ? character.toUpperCase() : '';
    });

    var first = ret.charAt(0),
        lower = first.toLowerCase();

    return first !== lower ? lower + ret.slice(1) : ret;
  },

  /**
    Converts a camelized string into all lower case separated by underscores.

    ## Examples

    decamelize('my favorite items') // 'my favorite items'
    decamelize('css-class-name')    // 'css-class-name'
    decamelize('action_name')       // 'action_name'
    decamelize('innerHTML')         // 'inner_html'

    @returns {String} the decamelized string.
  */
  decamelize: function(str) {
    return str.replace(SC.STRING_DECAMELIZE_REGEXP, '$1_$2').toLowerCase();
  },

  /**
    Converts a camelized string or a string with spaces or underscores into
    a string with components separated by dashes.

    ## Examples

    | *Input String* | *Output String* |
    dasherize('my favorite items') // 'my-favorite-items'
    dasherize('css-class-name')    // 'css-class-name'
    dasherize('action_name')       // 'action-name'
    dasherize('innerHTML')         // 'inner-html'

    @returns {String} the dasherized string.
  */
  dasherize: function(str) {
    var cache = SC.STRING_DASHERIZE_CACHE,
        ret   = cache[str];

    if (ret) {
      return ret;
    } else {
      ret = SC.String.decamelize(str).replace(SC.STRING_DASHERIZE_REGEXP,'-');
      cache[str] = ret;
    }

    return ret;
  },

  /**
    Escapes the given string to make it safe to use as a jQuery selector.
    jQuery will interpret '.' and ':' as class and pseudo-class indicators.

    @see http://learn.jquery.com/using-jquery-core/faq/how-do-i-select-an-element-by-an-id-that-has-characters-used-in-css-notation/

    @param {String} str the string to escape
    @returns {String} the escaped string
  */
  escapeCssIdForSelector: function (str) {
    return str.replace(SC.STRING_CSS_ESCAPED_REGEXP, '\\$1');
  },

  /**
    Localizes the string.  This will look up the receiver string as a key
    in the current Strings hash.  If the key matches, the loc'd value will be
    used.  The resulting string will also be passed through fmt() to insert
    any variables.

    @param str {String} String to localize
    @param args {Object...} optional arguments to interpolate also
    @returns {String} the localized and formatted string.
  */
  loc: function(str) {
    // NB: This could be implemented as a wrapper to locWithDefault() but
    // it would add some overhead to deal with the arguments and adds stack
    // frames, so we are keeping the implementation separate.
    if (!SC.Locale.currentLocale) { SC.Locale.createCurrentLocale(); }

    var localized = SC.Locale.currentLocale.locWithDefault(str);
    if (SC.typeOf(localized) !== SC.T_STRING) { localized = str; }

    var args = SC.$A(arguments);
    args.shift(); // remove str param
    //to extend String.prototype
    if (args.length > 0 && args[0] && args[0].isSCArray) { args = args[0]; }

    // I looked up the performance of try/catch. IE and FF do not care so
    // long as the catch never happens. Safari and Chrome are affected rather
    // severely (10x), but this is a one-time cost per loc (the code being
    // executed is likely as expensive as this try/catch cost).
    //
    // Also, .loc() is not called SO much to begin with. So, the error handling
    // that this gives us is worth it.
    try {
      return SC.String.fmt(localized, args);      
    } catch (e) {
      SC.error("Error processing string with key: " + str);
      SC.error("Localized String: " + localized);
      SC.error("Error: " + e);
    }

  },

  /**
    Returns the localized metric value for the specified key.  A metric is a
    single value intended to be used in your interface’s layout, such as
    "Button.Confirm.Width" = 100.

    If you would like to return a set of metrics for use in a layout hash, you
    may prefer to use the locLayout() method instead.

    @param str {String} key
    @returns {Number} the localized metric
  */
  locMetric: function(key) {
    var K             = SC.Locale,
        currentLocale = K.currentLocale;

    if (!currentLocale) {
      K.createCurrentLocale();
      currentLocale = K.currentLocale;
    }
    return currentLocale.locMetric(key);
  },

  /**
    Creates and returns a new hash suitable for use as an SC.View’s 'layout'
    hash.  This hash will be created by looking for localized metrics following
    a pattern based on the “base key” you specify.

    For example, if you specify "Button.Confirm", the following metrics will be
    used if they are defined:

      Button.Confirm.left
      Button.Confirm.top
      Button.Confirm.right
      Button.Confirm.bottom
      Button.Confirm.width
      Button.Confirm.height
      Button.Confirm.midWidth
      Button.Confirm.minHeight
      Button.Confirm.centerX
      Button.Confirm.centerY

    Additionally, you can optionally specify a hash which will be merged on top
    of the returned hash.  For example, if you wish to allow a button’s width
    to be configurable per-locale, but always wish for it to be centered
    vertically and horizontally, you can call:

      locLayout("Button.Confirm", {centerX:0, centerY:0})

    …so that you can combine both localized and non-localized elements in the
    returned hash.  (An exception will be thrown if there is a locale-specific
    key that matches a key specific in this hash.)


    For example, if your locale defines:

      Button.Confirm.left
      Button.Confirm.top
      Button.Confirm.right
      Button.Confirm.bottom


    …then these two code snippets will produce the same result:

      layout: {
        left:   "Button.Confirm.left".locMetric(),
        top:    "Button.Confirm.top".locMetric(),
        right:  "Button.Confirm.right".locMetric(),
        bottom: "Button.Confirm.bottom".locMetric()
      }

      layout: "Button.Confirm".locLayout()

    The former is slightly more efficient because it doesn’t have to iterate
    through the possible localized layout keys, but in virtually all situations
    you will likely wish to use the latter.

    @param str {String} key
    @param {str} (optional) additionalHash
    @param {String} (optional) additionalHash
    @returns {Number} the localized metric
  */
  locLayout: function(key, additionalHash) {
    var K             = SC.Locale,
        currentLocale = K.currentLocale;

    if (!currentLocale) {
      K.createCurrentLocale();
      currentLocale = K.currentLocale;
    }
    return currentLocale.locLayout(key, additionalHash);
  },

  /**
    Works just like loc() except that it will return the passed default
    string if a matching key is not found.

    @param {String} str the string to localize
    @param {String} def the default to return
    @param {Object...} args optional formatting arguments
    @returns {String} localized and formatted string
  */
  locWithDefault: function(str, def) {
    if (!SC.Locale.currentLocale) { SC.Locale.createCurrentLocale(); }

    var localized = SC.Locale.currentLocale.locWithDefault(str, def);
    if (SC.typeOf(localized) !== SC.T_STRING) { localized = str; }

    var args = SC.$A(arguments);
    args.shift(); // remove str param
    args.shift(); // remove def param

    return SC.String.fmt(localized, args);
  },

  /**
   Removes any extra whitespace from the edges of the string. This method is
   also aliased as strip().

   @returns {String} the trimmed string
  */
  trim: jQuery.trim,

  /**
   Removes any extra whitespace from the left edge of the string.

   @returns {String} the trimmed string
  */
  trimLeft: function (str) {
    return str.replace(SC.STRING_TRIM_LEFT_REGEXP,"");
  },

  /**
   Removes any extra whitespace from the right edge of the string.

   @returns {String} the trimmed string
  */
  trimRight: function (str) {
    return str.replace(SC.STRING_TRIM_RIGHT_REGEXP,"");
  },
  
  /**
    Mulitplies a given string. For instance if you have a string "xyz"
    and multiply it by 2 the result is "xyzxyz".
    
    @param {String} str the string to multiply
    @param {Number} value the number of times to multiply the string
    @returns {String} the mulitiplied string
  */
  mult: function(str, value) {
    if (SC.typeOf(value) !== SC.T_NUMBER || value < 1) return null;
    
    var ret = "";
    for (var i = 0; i < value; i += 1) {
      ret += str;
    }
    
    return ret;
  }
  
});


// IE doesn't support string trimming
if(String.prototype.trim) {
  SC.supplement(String.prototype,
  /** @scope String.prototype */ {

    trim: function() {
      return SC.String.trim(this, arguments);
    },

    trimLeft: function() {
      return SC.String.trimLeft(this, arguments);
    },

    trimRight: function() {
      return SC.String.trimRight(this, arguments);
    }
  });
}

// We want the version defined here, not in Runtime
SC.mixin(String.prototype,
/** @scope String.prototype */ {

  loc: function() {
    return SC.String.loc(this.toString(), SC.$A(arguments));
  },

  locMetric: function() {
    return SC.String.locMetric(this.toString());
  },

  locLayout: function(additionalHash) {
    return SC.String.locLayout(this.toString(), additionalHash);
  }

});


/* >>>>>>>>>> BEGIN source/mixins/delegate_support.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @namespace

  Support methods for the Delegate design pattern.

  The Delegate design pattern makes it easy to delegate a portion of your
  application logic to another object.  This is most often used in views to
  delegate various application-logic decisions to controllers in order to
  avoid having to bake application-logic directly into the view itself.

  The methods provided by this mixin make it easier to implement this pattern
  but they are not required to support delegates.

  ## The Pattern

  The delegate design pattern typically means that you provide a property,
  usually ending in "delegate", that can be set to another object in the
  system.

  When events occur or logic decisions need to be made that you would prefer
  to delegate, you can call methods on the delegate if it is set.  If the
  delegate is not set, you should provide some default functionality instead.

  Note that typically delegates are not observable, hence it is not necessary
  to use get() to retrieve the value of the delegate.

  @since SproutCore 1.0

*/
SC.DelegateSupport = {

  /**
    Selects the delegate that implements the specified method name.  Pass one
    or more delegates.  The receiver is automatically included as a default.

    This can be more efficient than using invokeDelegateMethod() which has
    to marshall arguments into a delegate call.

    @param {String} methodName
    @param {Object...} delegate one or more delegate arguments
    @returns {Object} delegate or null
  */
  delegateFor: function(methodName) {
    var idx = 1,
        len = arguments.length,
        ret ;

    while(idx<len) {
      ret = arguments[idx];
      if (ret && ret[methodName] !== undefined) return ret ;
      idx++;
    }

    return (this[methodName] !== undefined) ? this : null;
  },

  /**
    Invokes the named method on the delegate that you pass.  If no delegate
    is defined or if the delegate does not implement the method, then a
    method of the same name on the receiver will be called instead.

    You can pass any arguments you want to pass onto the delegate after the
    delegate and methodName.

    @param {Object} delegate a delegate object.  May be null.
    @param {String} methodName a method name
    @param {Object...} [args...] any additional arguments

    @returns {Object} value returned by delegate
  */
  invokeDelegateMethod: function(delegate, methodName) {
    // Fast arguments access.
    // Accessing `arguments.length` is just a Number and doesn't materialize the `arguments` object, which is costly.
    var args = new Array(arguments.length - 2); //  SC.A(arguments).slice(2)
    for (var i = 0, len = args.length; i < len; i++) { args[i] = arguments[i + 2]; }

    if (!delegate || !delegate[methodName]) delegate = this ;

    var method = delegate[methodName];
    return method ? method.apply(delegate, args) : null;
  },

  /**
    Search the named delegates for the passed property.  If one is found,
    gets the property value and returns it.  If none of the passed delegates
    implement the property, search the receiver for the property as well.

    @param {String} key the property to get.
    @param {Object} delegate one or more delegate
    @returns {Object} property value or undefined
  */
  getDelegateProperty: function(key, delegate) {
    var idx = 1,
        len = arguments.length,
        ret ;

    while(idx<len) {
      ret = arguments[idx++];
      if (ret && ret[key] != undefined) {
        return ret.get ? ret.get(key) : ret[key] ;
      }
    }

    return (this[key] != undefined) ? this.get(key) : undefined ;
  }

};

/* >>>>>>>>>> BEGIN source/views/view/base.js */
sc_require('mixins/delegate_support');

/** @class */
SC.CoreView = SC.Responder.extend(SC.DelegateSupport);

/* >>>>>>>>>> BEGIN source/views/view/statechart.js */
sc_require("views/view/base");

// When in debug mode, core developers can log the view state.




SC.CoreView.mixin(
  /** @scope SC.CoreView */ {

  // State bit masks

  // Logically always present, so not necessary, but here for logical ordering.
  // IS_CREATED: 0x0200, // 10 0000 0000, 512

  /**
    The view has been rendered.

    Use a logical AND (single `&`) to test rendered status.  For example,

        view.get('viewState') & SC.CoreView.IS_RENDERED

    @static
    @constant
  */
  IS_RENDERED: 0x0100, // 01 0000 0000, 256

  /**
    The view has been attached.

    Use a logical AND (single `&`) to test attached status.  For example,

        view.get('viewState') & SC.CoreView.IS_ATTACHED

    @static
    @constant
  */
  IS_ATTACHED: 0x0080, // 00 1000 0000, 128

  /**
    The view is visible in the display.

    Use a logical AND (single `&`) to test shown status.  For example,

        view.get('viewState') & SC.CoreView.IS_SHOWN

    @static
    @constant
  */
  IS_SHOWN: 0x0040, // 00 0100 0000, 64

  /**
    The view is invisible in the display.

    Use a logical AND (single `&`) to test hidden status.  For example,

        view.get('viewState') & SC.CoreView.IS_HIDDEN

    @static
    @constant
  */
  IS_HIDDEN: 0x0020, // 00 0010 0000, 32

  // Main states

  /**
    The view has been created, but has not been rendered or attached.

    @static
    @constant
  */
  UNRENDERED: 0x0200, // 10 0000 0000, 512 (IS_CREATED)

  /**
    The view has been created and rendered, but has not been attached
    (i.e. appended to the document).

    @static
    @constant
  */
  UNATTACHED: 0x0300, // 11 0000 0000, 768 (IS_CREATED + IS_RENDERED)

  /**
    The view has been created and rendered and attached to a parent, but an ancestor is not
    attached.

    @static
    @constant
  */
  ATTACHED_PARTIAL: 0x0380, // 11 1000 0000, 896 (IS_CREATED + IS_RENDERED + IS_ATTACHED)

  /**
    The view has been created, rendered and attached, but is not visible in the
    display.

    Test with & SC.CoreView.IS_HIDDEN
    @static
    @constant
  */
  ATTACHED_HIDDEN: 0x03A0, // 11 1010 0000, 928 (IS_CREATED + IS_RENDERED + IS_ATTACHED + IS_HIDDEN)

  /**
    The view has been created, rendered and attached and is visible in the
    display.

    @static
    @constant
  */
  ATTACHED_SHOWN: 0x03C0, // 11 1100 0000, 960 (IS_CREATED + IS_RENDERED + IS_ATTACHED + IS_SHOWN)

  // Minor states

  /**
    The view has been created, rendered and attached, but is not visible in the
    display due to being hidden by a parent view.

    @static
    @constant
  */
  ATTACHED_HIDDEN_BY_PARENT: 0x03A1, // 929  (IS_CREATED + IS_RENDERED + IS_ATTACHED + IS_HIDDEN +)

  /**
    The view has been created, rendered and attached and is visible in the
    display.  It is currently transitioning according to the transitionIn
    property before being fully shown (i.e ATTACHED_SHOWN).

    @static
    @constant
  */
  ATTACHED_BUILDING_IN: 0x03C1, // 961 (IS_CREATED + IS_RENDERED + IS_ATTACHED + IS_SHOWN +)

  /**
    The view has been created, rendered and attached.  It is currently
    transitioning according to the transitionOut property before being
    detached (i.e. removed from the document).

    @static
    @constant
  */
  ATTACHED_BUILDING_OUT: 0x03C4, // 964 (IS_CREATED + IS_RENDERED + IS_ATTACHED + IS_SHOWN +)

  /**
    The view has been created, rendered and attached.  It is currently
    transitioning according to the transitionOut property before being
    detached (i.e. removed from the document) because a parent view is
    being detached.

    @static
    @constant
  */
  ATTACHED_BUILDING_OUT_BY_PARENT: 0x03C5, // 965 (IS_CREATED + IS_RENDERED + IS_ATTACHED + IS_SHOWN +)

  /**
    The view has been created, rendered and attached and is visible in the
    display.  It is currently transitioning according to the transitionShow
    property before being fully shown (i.e ATTACHED_SHOWN).

    @static
    @constant
  */
  ATTACHED_SHOWING: 0x03C2, // 962 (IS_CREATED + IS_RENDERED + IS_ATTACHED + IS_SHOWN +)

  /**
    The view has been created, rendered and attached.  It is currently
    transitioning according to the transitionHide property before being fully
    hidden.

    @static
    @constant
  */
  ATTACHED_HIDING: 0x03C3, // 963 (IS_CREATED + IS_RENDERED + IS_ATTACHED + IS_SHOWN +)

  /**
    The view has been created, rendered and attached, is visible in the
    display and is being animated via a call to `animate()`.

    @static
    @constant
  */
  ATTACHED_SHOWN_ANIMATING: 0x03C6 // 966 (IS_CREATED + IS_RENDERED + IS_ATTACHED + IS_SHOWN +)

});


SC.CoreView.reopen(
  /** @scope SC.CoreView.prototype */ {

  


  // ------------------------------------------------------------------------
  // Properties
  //

  /* @private Internal variable used to store the number of children building out while we wait to be detached. */
  _sc_buildOutCount: null,

  /* @private Internal variable used to track the original view being detached that we are delaying so that we can build out. */
  _owningView: null,

  /* @private Internal variable used to store the original layout before running an automatic transition. */
  _preTransitionLayout: null,

  /* @private Internal variable used to store the original frame before running an automatic transition. */
  _preTransitionFrame: null,

  /* @private Internal variable used to cache layout properties which must be reset after the transition. */
  _transitionLayoutCache: null,

  /**
    The current state of the view as managed by its internal statechart.

    In order to optimize the behavior of SC.View, such as only observing display
    properties when in a rendered state or queueing updates when in a non-shown
    state, SC.View includes a simple internal statechart that maintains the
    current state of the view.

    Views have several possible states:

    * SC.CoreView.UNRENDERED
    * SC.CoreView.UNATTACHED
    * SC.CoreView.ATTACHED_PARTIAL
    * SC.CoreView.ATTACHED_SHOWING
    * SC.CoreView.ATTACHED_SHOWN
    * SC.CoreView.ATTACHED_SHOWN_ANIMATING
    * SC.CoreView.ATTACHED_HIDING
    * SC.CoreView.ATTACHED_HIDDEN
    * SC.CoreView.ATTACHED_HIDDEN_BY_PARENT
    * SC.CoreView.ATTACHED_BUILDING_IN
    * SC.CoreView.ATTACHED_BUILDING_OUT
    * SC.CoreView.ATTACHED_BUILDING_OUT_BY_PARENT

    @type String
    @default SC.CoreView.UNRENDERED
    @readonly
  */
  viewState: SC.CoreView.UNRENDERED,

  /**
    Whether the view's layer is attached to a parent or not.

    When the view's layer is attached to a parent view, this value will be true.

    @field
    @type Boolean
    @default false
    @readonly
  */
  isAttached: function () {
    return (this.get('viewState') & SC.CoreView.IS_ATTACHED) > 0;
  }.property('viewState').cacheable(),

  /** @private
    Whether the view's layer exists or not.

    When the view's layer is created, this value will be true.  This includes
    the unattached view state and all of the attached states.

    @field
    @type Boolean
    @default false
    @readonly
  */
  // NOTE: This property is of little value, so it's private in case we decide to toss it.
  _isRendered: function () {
    return (this.get('viewState') & SC.CoreView.IS_RENDERED) > 0;
  }.property('viewState').cacheable(),

  /**
    Whether the view is fully or becoming shown or not.

    When the view is shown in the window, this value will be true.  Note that
    if the view is transitioning out or hiding, this value will still be true.

    This is not necessarily the same as `isVisible` although the two properties
    are related.  For instance, it's possible to set `isVisible` to `true` and
    still have `isVisibleInWindow` be `false` or vice versa due to the
    `isVisibleInWindow` state of the view's parent view.  Therefore,
    `isVisibleInWindow` represents the actual visible state of the view and
    `isVisible` is used to attempt to alter that state.

    @field
    @type Boolean
    @default false
    @readonly
  */
  isVisibleInWindow: function () {
    return( this.get('viewState') & SC.CoreView.IS_SHOWN) > 0;
  }.property('viewState').cacheable(),


  // ------------------------------------------------------------------------
  // Actions (Locked down to the proper state)
  //

  /** @private Adopt this view action. */
  _doAdopt: function (parentView, beforeView) {
    var curParentView = this.get('parentView'),
      handled = true,
      state = this.get('viewState');

    


    if (curParentView && curParentView !== parentView) {
      


      // Force orphaning the view.
      this._doOrphan();
      curParentView = false;
    }

    // You can adopt childViews that have you set as their parent (i.e. created
    // with createChildView()), but have not yet been fully adopted.
    var siblings = parentView.get('childViews');
    if (!curParentView || siblings.indexOf(this) < 0) {
      var idx,
        parentViewState = parentView.get('viewState'),
        parentNode, nextNode, nextView;

      // Notify that the child view will be added to the parent view.
      if (parentView.willAddChild) { parentView.willAddChild(this, beforeView); }
      if (this.willAddToParent) { this.willAddToParent(parentView, beforeView); }

      // Set the parentView.
      this.set('parentView', parentView);

      // Add to the new parent's childViews array.
      if (siblings.needsClone) { parentView.set('childViews', []); }
      idx = (beforeView) ? siblings.indexOf(beforeView) : siblings.length;
      if (idx < 0) { idx = siblings.length; }
      siblings.insertAt(idx, this);

      // Pass the current designMode to the view (and its children).
      this.updateDesignMode(this.get('designMode'), parentView.get('designMode'));

      // Notify adopted.
      this._adopted(beforeView);

      // When a view is adopted, it should go to the same state as its new parent.
      switch (state) {
      case SC.CoreView.UNRENDERED:
        switch (parentViewState) {
        case SC.CoreView.UNRENDERED:
          break;
        default:
          // Bypass the unrendered state for adopted views.
          this._doRender();
        }
        break;
      case SC.CoreView.UNATTACHED:
        switch (parentViewState) {
        case SC.CoreView.UNRENDERED:
          // Bring the child view down to the state of the parent.
          this._doDestroyLayer();
          break;
        default:
          parentNode = parentView.get('containerLayer');
          nextView = siblings.objectAt(siblings.indexOf(this) + 1);
          nextNode = (nextView) ? nextView.get('layer') : null;

          this._doAttach(parentNode, nextNode);
        }
        break;
      default: // ATTACHED_X
        switch (parentViewState) {
        case SC.CoreView.UNRENDERED:
          // Bring the child view down to the state of the parent.
          this._doDestroyLayer();
          break;
        default:
          parentNode = parentView.get('containerLayer');
          nextView = siblings.objectAt(siblings.indexOf(this) + 1);
          nextNode = (nextView) ? nextView.get('layer') : null;

          this._doAttach(parentNode, nextNode);
        }
      }

    // Adopting a view that is building out.
    } else if (state === SC.CoreView.ATTACHED_BUILDING_OUT) {
      this._doAttach();

    // Can't do anything.
    } else {
      handled = false;
    }

    return handled;
  },

  /** @private Attach this view action. */
  _doAttach: function (parentNode, nextNode) {
    var state = this.get('viewState'),
      transitionIn = this.get('transitionIn'),
      parentView,
      isHandled = false;

    


    switch (state) {

    // Normal case: view is not attached and is being attached.
    case SC.CoreView.UNATTACHED:
      var node = this.get('layer');

      this._executeQueuedUpdates();

      // Attach to parentNode.
      // IE doesn't support insertBefore(blah, undefined) in version IE9.
      parentNode.insertBefore(node, nextNode || null);

      parentView = this.get('parentView');
      if (!parentView || (parentView && parentView.get('isAttached'))) {
        // Attach the view.
        this._executeDoAttach();

        // If there is a transition in, run it.
        if (transitionIn) {
          this._transitionIn(false);
        }
      } else {
        // Attaching an unattached view to an unattached view, simply moves it to unattached by
        // parent state. Don't do any notifications.
        this._gotoAttachedPartialState();
      }

      isHandled = true;
      break;

    // Special case: view switched from building out to building in.
    case SC.CoreView.ATTACHED_BUILDING_OUT:
      // If already building out, we need to cancel and possibly build in. Top-down so that any
      // children that are hidden or building out on their own allow us to bail out early.
      this._callOnChildViews('_parentDidCancelBuildOut');

      // Remove the shared building out count if it exists.
      this._sc_buildOutCount = null;

      // Note: We can be in ATTACHED_BUILDING_OUT state without a transition out while we wait for child views.
      if (this.get('transitionOut')) {
        // Cancel the building out transition (in place if we are going to switch to transitioning back in).
        // this.cancelAnimation(transitionIn ? SC.LayoutState.CURRENT : undefined);
        this.cancelAnimation();

        


        // Set the proper state.
        this._gotoAttachedShownState();

        if (transitionIn) {
          this._transitionIn(true);
        }

      // Waiting for child view transition outs.
      } else {

        // Set the proper state.
        this._gotoAttachedShownState();
      }

      isHandled = true;
      break;

    // Invalid states that have no effect.
    case SC.CoreView.ATTACHED_HIDING:
    case SC.CoreView.ATTACHED_HIDDEN:
    case SC.CoreView.ATTACHED_HIDDEN_BY_PARENT:
    case SC.CoreView.ATTACHED_BUILDING_IN:
    case SC.CoreView.ATTACHED_BUILDING_OUT_BY_PARENT:
    case SC.CoreView.ATTACHED_SHOWING:
    case SC.CoreView.UNRENDERED:
      break;

    // Improper states that have no effect, but should be discouraged.
    case SC.CoreView.ATTACHED_SHOWN:
    case SC.CoreView.ATTACHED_SHOWN_ANIMATING:
      

      break;
    case SC.CoreView.ATTACHED_PARTIAL:
      

      break;
    }

    return isHandled;
  },

  /** @private Destroy the layer of this view action. */
  _doDestroyLayer: function () {
    var state = this.get('viewState'),
      isHandled = false;

    


    switch (state) {

    // Invalid states that have no effect.
    case SC.CoreView.UNRENDERED:
    case SC.CoreView.ATTACHED_HIDING:
    case SC.CoreView.ATTACHED_HIDDEN:
    case SC.CoreView.ATTACHED_HIDDEN_BY_PARENT:
    case SC.CoreView.ATTACHED_BUILDING_IN:
    case SC.CoreView.ATTACHED_BUILDING_OUT_BY_PARENT:
    case SC.CoreView.ATTACHED_SHOWING:
    case SC.CoreView.ATTACHED_SHOWN:
    case SC.CoreView.ATTACHED_SHOWN_ANIMATING:
    case SC.CoreView.ATTACHED_BUILDING_OUT:
    case SC.CoreView.ATTACHED_PARTIAL:
      break;

    // Normal case (SC.CoreView.UNATTACHED): view is rendered and its layer is being destroyed.
    default:
      // Notify that the layer will be destroyed. Bottom-up so that each child is in the proper
      // state before its parent potentially alters its state. For example, a parent could modify
      // children in `willDestroyLayer`.
      this._callOnChildViews('_teardownLayer', false);
      this._teardownLayer();

      isHandled = true;
    }

    return isHandled;
  },

  /** @private Detach this view action. */
  _doDetach: function (immediately) {
    var state = this.get('viewState'),
      transitionOut = this.get('transitionOut'),
      shouldHandle = true;

    


    // Handle all 12 possible view states.
    switch (state) {

    // Scenario: The view is shown.
    // Result: Allow the view and/or any of its child views to build out or else execute the detach.
    case SC.CoreView.ATTACHED_SHOWN:
      this._executeDoBuildOut(immediately);

      break;

    // Scenario: The view is attached but isn't visible (possibly because an ancestor is detached or hidden).
    // Result: Detach the view immediately.
    case SC.CoreView.ATTACHED_PARTIAL:
    case SC.CoreView.ATTACHED_HIDDEN:
    case SC.CoreView.ATTACHED_HIDDEN_BY_PARENT:
      // Detach immediately.
      this._executeDoDetach();

      break;

    // Scenario: The view is in the middle of a hiding transition.
    // Result: Cancel the animation and then run as normal.
    case SC.CoreView.ATTACHED_HIDING:
      // Cancel the animation (in the future we will be able to let it run out while building out).
      this.cancelAnimation();

      // Set the proper state.
      this._gotoAttachedHiddenState();

      // Detach immediately.
      this._executeDoDetach();

      break;

    // Scenario: The view is in the middle of an animation or showing transition.
    // Result: Cancel the animation and then run as normal.
    case SC.CoreView.ATTACHED_SHOWING:
    case SC.CoreView.ATTACHED_SHOWN_ANIMATING: // TODO: We need concurrent states!
      // Cancel the animation (in the future we will be able to let it run out while building out).
      this.cancelAnimation();

      // Set the proper state.
      this._gotoAttachedShownState();

      this._executeDoBuildOut(immediately);

      break;

    // Scenario: The view is building in.
    // Result: If it has a build out transition, swap to it. Otherwise, cancel.
    case SC.CoreView.ATTACHED_BUILDING_IN:
      // Cancel the build in transition.
      // if (transitionOut) {
      //   


      //   this.cancelAnimation(SC.LayoutState.CURRENT);
      // } else {
        


        this.cancelAnimation();
      // }

      // Set the proper state.
      this._gotoAttachedShownState();

      // Build out in place.
      this._executeDoBuildOut(immediately, true);
      break;

    // Scenario: View is already building out because of an ancestor.
    // Result: Stop the transition so that it can continue in place on its own.
    case SC.CoreView.ATTACHED_BUILDING_OUT_BY_PARENT:
      // Cancel the build out transition.
      this.cancelAnimation(SC.LayoutState.CURRENT); // Fires didTransitionOut callback (necessary to clean up parent view build out wait)

      // Set the proper state. (the view should only have been able to get to ATTACHED_BUILDING_OUT_BY_PARENT from ATTACHED_SHOWN).
      this._gotoAttachedShownState();

      // TODO: Grab the build out count for all child views of this view. What a nightmare for an edge case!

      // Build out in place.
      this._executeDoBuildOut(immediately, true);

      break;

    // Scenario: View is already building out.
    // Result: Stop if forced to.
    case SC.CoreView.ATTACHED_BUILDING_OUT:
      // If immediately is passed, cancel the build out prematurely.
      if (immediately) {
        // Note: *will* detach notice already sent.
        this.cancelAnimation(); // Fires didTransitionOut callback (state changes to UNATTACHED/notifications sent).

        // Detach immediately.
        this._executeDoDetach();
      }

      break;

    // Invalid states.
    default:
      


      shouldHandle = false;
    }

    return shouldHandle;
  },

  /** @private Hide this view action. */
  _doHide: function () {
    var state = this.get('viewState'),
      transitionHide = this.get('transitionHide'),
      shouldHandle = true;

    


    // Handle all 12 possible view states.
    switch (state) {

    // Scenario: The view is shown.
    // Result: Notify that the view will hide and then either hide or run hide transition.
    case SC.CoreView.ATTACHED_SHOWN:
    case SC.CoreView.ATTACHED_BUILDING_IN:
    case SC.CoreView.ATTACHED_BUILDING_OUT:
    case SC.CoreView.ATTACHED_BUILDING_OUT_BY_PARENT:
    case SC.CoreView.ATTACHED_SHOWN_ANIMATING:
    // ATTACHED_HIDDEN_BY_PARENT, ATTACHED_BUILDING_IN, ATTACHED_BUILDING_OUT_BY_PARENT, ATTACHED_BUILDING_OUT

      // TODO: How do we check for conflicts in the hide transition against other concurrent transitions/animations?
      if (transitionHide) {
        // this.invokeNext(function () {
        this._transitionHide();
        // });
      } else {
        // Hide the view.
        this._executeDoHide();
      }

      break;

    // Scenario: The view was showing at the time it was told to hide.
    // Result: Cancel the animation.
    case SC.CoreView.ATTACHED_SHOWING:
      // Cancel the showing transition.
      if (transitionHide) {
        this.cancelAnimation(SC.LayoutState.CURRENT);
      } else {
        this.cancelAnimation();
      }

      // Set the proper state.
      this._gotoAttachedShownState();

      // Hide the view.
      if (transitionHide) {
        this._transitionHide(true);
      } else {
        this._executeDoHide();
      }

      break;

    // Scenario: The view is rendered but is not attached.
    // Result: Queue an update to the visibility style.
    case SC.CoreView.UNATTACHED:
    case SC.CoreView.ATTACHED_PARTIAL:
      // Queue the visibility update for the next time we display.
      this._visibleStyleNeedsUpdate = true;

      break;

    // Scenario: The view is not even rendered.
    // Result: Nothing is required.
    case SC.CoreView.UNRENDERED:
      shouldHandle = false;
      break;

    case SC.CoreView.ATTACHED_HIDDEN: // FAST PATH!
    case SC.CoreView.ATTACHED_HIDING: // FAST PATH!
      return false;
    case SC.CoreView.ATTACHED_HIDDEN_BY_PARENT: // FAST PATH!
      // Note that visibility update is NOT conditional for this state.
      this._doUpdateVisibleStyle();

      // Update states after *will* and before *did* notifications!
      this._gotoAttachedHiddenState();

      return true;

    // Invalid states.
    default:
      


      shouldHandle = false;
    }

    return shouldHandle;
  },

  /** @private Orphan this view action. */
  _doOrphan: function () {
    var parentView = this.get('parentView'),
      handled = true;

    


    if (parentView) {
      var childViews = parentView.get('childViews'),
        idx = childViews.indexOf(this);

      // Completely remove the view from its parent.
      this.set('parentView', null);

      // Remove view from old parent's childViews array.
      if (idx >= 0) { childViews.removeAt(idx); }

      // Notify orphaned.
      this._orphaned(parentView);
    } else {
      handled = false;
    }

    return handled;
  },

  /** @private Render this view action. */
  _doRender: function () {
    var state = this.get('viewState'),
        shouldHandle = true;

    


    // Handle all 12 possible view states.
    switch (state) {

    // Scenario: The view is not rendered.
    // Result: Render the layer and then notify.
    case SC.CoreView.UNRENDERED:
      // Render the view.
      this._executeDoRender();

      // Bypass the unattached state for adopted views.
      var parentView = this.get('parentView');
      if (parentView && parentView.get('_isRendered')) {
        var parentNode = parentView.get('containerLayer'),
          siblings = parentView.get('childViews'),
          nextView = siblings.objectAt(siblings.indexOf(this) + 1),
          nextNode = (nextView) ? nextView.get('layer') : null;

        // Attach to parentNode
        // IE doesn't support insertBefore(blah, undefined) in version IE9.
        // parentNode.insertBefore(node, nextNode || null);
        this._doAttach(parentNode, nextNode);
      }

      break;

    // Invalid states.
    default:
      

      shouldHandle = false;
    }

    return shouldHandle;
  },

  /** @private Show this view action. */
  _doShow: function () {
    var state = this.get('viewState'),
        transitionShow = this.get('transitionShow'),
        shouldHandle = true;

    


    // Handle all 12 possible view states.
    switch (state) {

    // Scenario: The view is hidden.
    // Result: Depends on whether the parent view is shown or hidden by an ancestor.
    case SC.CoreView.ATTACHED_HIDDEN:
      var parentView = this.get('parentView'),
          // Views without a parent are not limited by a parent's current state.
          isParentShown = parentView ? parentView.get('viewState') & SC.CoreView.IS_SHOWN : true;

      // Scenario: The view is hidden and its ancestors are all visible.
      // Result: Notify that the view and relevant child views will be shown.
      if (isParentShown) {
        var notifyStack = []; // Only those views that changed state get added to the stack.

        // Run any queued updates.
        this._executeQueuedUpdates();

        // The children are updated top-down so that hidden or unattached children allow us to bail out early.
        this._callOnChildViews('_parentWillShowInDocument', true, notifyStack);

        // Notify for each child (that will change state) in reverse so that each child is in the proper
        // state before its parent potentially alters its state. For example, a parent could modify
        // children in `willShowInDocument`.
        for (var i = notifyStack.length - 1; i >= 0; i--) {
          var childView = notifyStack[i];

          childView._notifyWillShowInDocument();
        }
        this._notifyWillShowInDocument();

        // Show the view.
        this._executeDoShow();
        if (transitionShow) {
          this._transitionShow(false);
        }

      // Scenario: The view is hidden, but one of its ancestors is also hidden.
      // Result: Track that the visible style needs update and go to hidden by parent state.
      } else {
        // Queue the visibility update for the next time we display.
        this._visibleStyleNeedsUpdate = true;

        // Set the proper state.
        this._gotoAttachedHiddenByParentState();
      }

      break;

    // Scenario: The view was hiding at the time it was told to show.
    // Result: Revert or reverse the hiding transition.
    case SC.CoreView.ATTACHED_HIDING:
      // Cancel the hiding transition (in place if we are going to switch to transitioning back in).
      this.cancelAnimation(transitionShow ? SC.LayoutState.CURRENT : SC.LayoutState.START);

      // Set the proper state.
      this._gotoAttachedShownState();

      if (transitionShow) {
        this._transitionShow(true);
      }

      break;

    // Scenario: The view is rendered but is not attached.
    // Result: Queue an update to the visibility style.
    case SC.CoreView.UNATTACHED:
    case SC.CoreView.ATTACHED_PARTIAL:
      // Queue the visibility update for the next time we display.
      this._visibleStyleNeedsUpdate = true;

      break;

    // Scenario: The view is not even rendered.
    // Result: Nothing is required.
    case SC.CoreView.UNRENDERED:
      shouldHandle = false;
      break;

    // Invalid states.
    default:
      


      shouldHandle = false;
    }

    return shouldHandle;
  },

  /** @private Update this view's contents action. */
  _doUpdateContent: function (force) {
    var isVisibleInWindow = this.get('isVisibleInWindow'),
      handled = true;

    


    if (this.get('_isRendered')) {
      if (isVisibleInWindow || force) {
        // Only in the visible states do we allow updates without being forced.
        this._executeDoUpdateContent();
      } else {
        // Otherwise mark the view as needing an update when we enter a shown state again.
        this._contentNeedsUpdate = true;
      }
    } else {
      handled = false;
    }

    return handled;
  },

  // ------------------------------------------------------------------------
  // Events
  //

  /**
    This method is called by transition plugins when the incoming or showing
    transition completes.  You should only use this method if implementing a
    custom transition plugin.

    @param {SC.ViewTransitionProtocol} transition The transition plugin used.
    @param {Object} options The original options used.  One of transitionShowOptions or transitionInOptions.
  */
  didTransitionIn: function () {
    var state = this.get('viewState');

    


    if (state === SC.CoreView.ATTACHED_SHOWING ||
      state === SC.CoreView.ATTACHED_BUILDING_IN) {
      this._teardownTransition();

      // Set the proper state.
      this._gotoAttachedShownState();
    }
  },

  /**
    This method is called by transition plugins when the outgoing or hiding
    transition completes.  You should only use this method if implementing a
    custom transition plugin.

    @param {SC.ViewTransitionProtocol} transition The transition plugin used.
    @param {Object} options The original options used.  One of transitionHideOptions or transitionOutOptions.
  */
  didTransitionOut: function () {
    var state = this.get('viewState');

    


    if (state === SC.CoreView.ATTACHED_BUILDING_OUT) {
      this._teardownTransition();

      this._executeDoDetach();
    } else if (state === SC.CoreView.ATTACHED_BUILDING_OUT_BY_PARENT) {
      var owningView = this._owningView;
      // We can't clean up the transition until the parent is done.  For
      // example, a fast child build out inside of a slow parent build out.
      owningView._sc_buildOutCount--;

      if (owningView._sc_buildOutCount === 0) {
        owningView._executeDoDetach();

        // Clean up.
        this._owningView = null;
      }
    } else if (state === SC.CoreView.ATTACHED_HIDING) {
      this._teardownTransition();

      // Hide immediately.
      this._executeDoHide();
    }
  },

  /** @private The 'adopted' event. */
  _adopted: function (beforeView) {
    // Notify all of our descendents that our parent has changed. They will update their `pane` value
    // for one. Bottom-up in case a parent view modifies children when its pane changes for any
    // reason.
    this._callOnChildViews('_ancestorDidChangeParent', false);

    // Notify that the child view has been added to the parent view.
    var parentView = this.get('parentView');
    if (this.didAddToParent) { this.didAddToParent(parentView, beforeView); }
    if (parentView.didAddChild) { parentView.didAddChild(this, beforeView); }
  },

  /** @private The 'orphaned' event. */
  _orphaned: function (oldParentView) {
    // It's not necessary to send notice to destroyed views.
    if (!this.isDestroyed) {
      // Notify all of our descendents that our parent has changed. They will update their `pane` value
      // for one. Bottom-up in case a parent view modifies children when its pane changes for any
      // reason.
      this._callOnChildViews('_ancestorDidChangeParent', false);

      if (oldParentView.didRemoveChild) { oldParentView.didRemoveChild(this); }
      if (this.didRemoveFromParent) { this.didRemoveFromParent(oldParentView); }
    }
  },

  // ------------------------------------------------------------------------
  // States
  //

  /** @private */
  _gotoAttachedBuildingInState: function () {
    this.set('viewState', SC.CoreView.ATTACHED_BUILDING_IN);
  },

  /** @private */
  _gotoAttachedBuildingOutState: function () {
    this.set('viewState', SC.CoreView.ATTACHED_BUILDING_OUT);
  },

  /** @private */
  _gotoAttachedBuildingOutByParentState: function () {
    this.set('viewState', SC.CoreView.ATTACHED_BUILDING_OUT_BY_PARENT);
  },

  /** @private */
  _gotoAttachedHiddenState: function () {
    this.set('viewState', SC.CoreView.ATTACHED_HIDDEN);
  },

  /** @private */
  _gotoAttachedHiddenByParentState: function () {
    this.set('viewState', SC.CoreView.ATTACHED_HIDDEN_BY_PARENT);
  },

  /** @private */
  _gotoAttachedHidingState: function () {
    this.set('viewState', SC.CoreView.ATTACHED_HIDING);
  },

  /** @private */
  _gotoAttachedShowingState: function () {
    this.set('viewState', SC.CoreView.ATTACHED_SHOWING);
  },

  /** @private */
  _gotoAttachedShownState: function () {
    this.set('viewState', SC.CoreView.ATTACHED_SHOWN);
  },

  /** @private */
  _gotoUnattachedState: function () {
    this.set('viewState', SC.CoreView.UNATTACHED);
  },

  /** @private */
  _gotoAttachedPartialState: function () {
    this.set('viewState', SC.CoreView.ATTACHED_PARTIAL);
  },

  /** @private */
  _gotoUnrenderedState: function () {
    this.set('viewState', SC.CoreView.UNRENDERED);
  },

  // ------------------------------------------------------------------------
  // Methods
  //

  /** @private Adds observers once a view has a layer. */
  _sc_addRenderedStateObservers: function () {
    var displayProperties,
      len, idx;

    // Register display property observers.
    displayProperties = this.get('displayProperties');
    for (idx = 0, len = displayProperties.length; idx < len; idx++) {
      this.addObserver(displayProperties[idx], this, this.displayDidChange);
    }

    // Begin observing isVisible & isFirstResponder.
    this.addObserver('isVisible', this, this._isVisibleDidChange);
    this.addObserver('isFirstResponder', this, this._isFirstResponderDidChange);
  },

  /** @private Called when an ancestor's parent changed. */
  _ancestorDidChangeParent: function () {
    // When an ancestor changes, the pane may have changed.
    this.notifyPropertyChange('pane');
  },

  /** @private Clear building in transition. */
  _cancelTransition: function () {
    // Cancel conflicting transitions. This causes the animation callback to fire.
    this.cancelAnimation();
    // this._teardownTransition();
  },

  /** @private */
  _doUpdateVisibleStyle: function () {
    var isVisible = this.get('isVisible');

    this.$().toggleClass('sc-hidden', !isVisible);
    this.$().attr('aria-hidden', isVisible ? null : true);

    // Reset that an update is required.
    this._visibleStyleNeedsUpdate = false;
  },

  /** @private Destroys the layer and updates the state. */
  _teardownLayer: function () {
    this._notifyWillDestroyLayer();

    var displayProperties,
      idx, len;

    // Unregister display property observers.
    displayProperties = this.get('displayProperties');
    for (idx = 0, len = displayProperties.length; idx < len; idx++) {
      this.removeObserver(displayProperties[idx], this, this.displayDidChange);
    }

    // Stop observing isVisible & isFirstResponder.
    this.removeObserver('isVisible', this, this._isVisibleDidChange);
    this.removeObserver('isFirstResponder', this, this._isFirstResponderDidChange);

    // Remove the layer reference.
    this.set('layer', null);

    // Update states after *will* and before *did* notifications!
    this._gotoUnrenderedState();
  },

  /** @private Attaches the view. */
  _executeDoAttach: function () {
    var notifyStack = []; // Only those views that changed state get added to the stack.

    // Run any queued updates.
    this._executeQueuedUpdates();

    // Update the state and children state. The children are updated top-down so that hidden or
    // unattached children allow us to bail out early.
    this._gotoSomeAttachedState();
    this._callOnChildViews('_parentDidAttach', true, notifyStack);

    // Notify for each child (that changed state) in reverse so that each child is in the proper
    // state before its parent potentially alters its state. For example, a parent could modify
    // children in `didAppendToDocument`.
    for (var i = notifyStack.length - 1; i >= 0; i--) {
      var childView = notifyStack[i];

      childView._notifyDidAttach();
    }
    this._notifyDidAttach();
  },

  /** @private Builds out the view. */
  _executeDoBuildOut: function (immediately, inPlace) {
    if (immediately) {
      // Detach immediately.
      this._executeDoDetach();
    } else {
      // In order to allow the removal of a parent to be delayed by its children's transitions, we
      // track which views are building out and finish only when they're all done.
      this._sc_buildOutCount = 0;

      // Tell all the child views so that any with a transitionOut may run it. Top-down so that
      // any hidden or already building out child views allow us to bail out early.
      this._callOnChildViews('_parentWillBuildOutFromDocument', true, this);

      var transitionOut = this.get('transitionOut');
      if (transitionOut) {
        inPlace = inPlace || false;
        this._transitionOut(inPlace, this);

      } else if (this._sc_buildOutCount > 0) {
        // Some children are building out, we will have to wait for them.
        this._gotoAttachedBuildingOutState();
      } else {
        this._sc_buildOutCount = null;

        // Detach immediately.
        this._executeDoDetach();
      }
    }
  },

  /** @private Detaches the view and updates the state. */
  _executeDoDetach: function () {
    var notifyStack = []; // Only those views that changed state get added to the stack.

    // The children are updated top-down so that hidden or unattached children allow us to bail out early.
    this._callOnChildViews('_parentWillDetach', true, notifyStack);

    // Notify for each child (that will change state) in reverse so that each child is in the proper
    // state before its parent potentially alters its state. For example, a parent could modify
    // children in `willRemoveFromDocument`.
    for (var i = notifyStack.length - 1; i >= 0; i--) {
      var childView = notifyStack[i];

      childView._notifyWillDetach();
    }
    this._notifyWillDetach();

    // Cancel any remaining animations (e.g. a concurrent hide).
    var viewState = this.get('viewState');
    switch (viewState) {
    case SC.CoreView.ATTACHED_HIDING:
    case SC.CoreView.ATTACHED_SHOWN_ANIMATING:
      this.cancelAnimation();
      break;
    }

    // Detach the layer.
    var node = this.get('layer');
    node.parentNode.removeChild(node);

    // Update the state and children state. The children are updated top-down so that unattached
    // children allow us to bail out early.
    this._gotoUnattachedState();
    this._callOnChildViews('_parentDidDetach', true);
  },

  /** @private Hides the view. */
  _executeDoHide: function () {
    var notifyStack = []; // Only those views that changed state get added to the stack.

    // The children are updated top-down so that hidden or unattached children allow us to bail out early.
    this._callOnChildViews('_parentWillHideInDocument', true, notifyStack);

    // Notify for each child (that will change state) in reverse so that each child is in the proper
    // state before its parent potentially alters its state. For example, a parent could modify
    // children in `willHideInDocument`.
    for (var i = notifyStack.length - 1; i >= 0; i--) {
      var childView = notifyStack[i];

      childView._notifyWillHideInDocument();
    }
    this._notifyWillHideInDocument();

    // Cancel any remaining animations (e.g. a concurrent build in or build out).
    var viewState = this.get('viewState');
    switch (viewState) {
    case SC.CoreView.ATTACHED_BUILDING_IN:
    case SC.CoreView.ATTACHED_BUILDING_OUT:
    case SC.CoreView.ATTACHED_BUILDING_OUT_BY_PARENT:
    case SC.CoreView.ATTACHED_SHOWN_ANIMATING:
      this.cancelAnimation();
      break;
    }

    // Update the visible style.
    this._doUpdateVisibleStyle();

    // Update the state and children state. The children are updated top-down so that hidden or
    // unattached children allow us to bail out early.
    this._gotoAttachedHiddenState();
    this._callOnChildViews('_parentDidHideInDocument', true); // , notifyStack

    // Notify for each child (that changed state) in reverse so that each child is in the proper
    // state before its parent potentially alters its state. For example, a parent could modify
    // children in `didHideInDocument`.
    // for (var i = notifyStack.length - 1; i >= 0; i--) {
    //   var childView = notifyStack[i];

    //   childView._notifyDidHideInDocument();
    // }
    this._notifyDidHideInDocument();
  },

  /** @private Render the view's layer. */
  _executeDoRender: function () {
    var notifyStack = []; // Only those views that changed state get added to the stack.

    // Render the layer.
    var context = this.renderContext(this.get('tagName'));

    this.renderToContext(context);
    this.set('layer', context.element());

    // Update the state and children state. The children are updated top-down so that invalid state
    // children allow us to bail out early.
    // if (this.get('parentView')) {
    //   this._gotoAttachedPartialState();
      this._gotoUnattachedState();
    // }

    this._callOnChildViews('_parentDidRender', true, notifyStack);

    this._sc_addRenderedStateObservers();

    // Notify for each child (that changed state) in reverse so that each child is in the proper
    // state before its parent potentially alters its state. For example, a parent could modify
    // children in `didCreateLayer`.
    for (var i = notifyStack.length - 1; i >= 0; i--) {
      var childView = notifyStack[i];

      childView._notifyDidRender();
    }
    this._notifyDidRender();
  },

  /** @private Shows the view. */
  _executeDoShow: function () {
    // var notifyStack = []; // Only those views that changed state get added to the stack.

    // Update the visible style.
    this._doUpdateVisibleStyle();

    // Update the state and children state. The children are updated top-down so that hidden or
    // unattached children allow us to bail out early. This view's state is going to be transitioning,
    // but all child views are now considered shown.
    this._gotoAttachedShownState();
    this._callOnChildViews('_parentDidShowInDocument', true); // , notifyStack

    // Notify for each child (that changed state) in reverse so that each child is in the proper
    // state before its parent potentially alters its state. For example, a parent could modify
    // children in `didShowInDocument`.
    // for (var i = notifyStack.length - 1; i >= 0; i--) {
    //   var childView = notifyStack[i];

    //   childView._notifyDidShowInDocument();
    // }
    this._notifyDidShowInDocument();
  },

  /** @private Updates the layer. */
  _executeDoUpdateContent: function () {
    var mixins = this.renderMixin,
      context = this.renderContext(this.get('layer'));

    // If there is no update method, fallback to calling render with extra
    // firstTime argument set to false.
    if (!this.update) {
      this.render(context, false);
    } else {
      this.update(context.$());
    }

    // Call renderMixin methods.
    if (mixins) {
      var len = mixins.length;
      for (var idx = 0; idx < len; ++idx) {
        mixins[idx].call(this, context, false);
      }
    }

    // Call applyAttributesToContext so that subclasses that override it can
    // insert further attributes.
    this.applyAttributesToContext(context);

    context.update();

    // Legacy.
    this.set('layerNeedsUpdate', false);

    // Reset that an update is required.
    this._contentNeedsUpdate = false;

    // Notify.
    this.notifyPropertyChange('layer');
    if (this.didUpdateLayer) { this.didUpdateLayer(); }

    if (this.designer && this.designer.viewDidUpdateLayer) {
      this.designer.viewDidUpdateLayer(); //let the designer know
    }
  },

  /** @private */
  _executeQueuedUpdates: function () {

    // Update visibility style if necessary.
    if (this._visibleStyleNeedsUpdate) {
      this._doUpdateVisibleStyle();
    }

    // Update the content of the layer if necessary.
    if (this._contentNeedsUpdate) {
      this._executeDoUpdateContent();
    }
  },

  /** @private
    Marks the view as needing a visibility update if the isVisible property
    changes.

    This observer is connected when the view is attached and is disconnected
    when the view is detached.
  */
  _isVisibleDidChange: function () {
    if (this.get('isVisible')) {
      this._doShow();
    } else {
      this._doHide();
    }
  },

  /** @private
    Adds the 'focus' class to the view.

    This observer is connected when the view is attached and is disconnected
    when the view is detached.
  */
  _isFirstResponderDidChange: function () {
    var isFirstResponder = this.get('isFirstResponder');

    this.$().toggleClass('focus', isFirstResponder);
  },

  /** @private Attempts to call `didAppendToDocument` on the view. */
  _notifyDidAttach: function () {
    // If we don't have the layout module then we don't know the frame until appended to the document.
    this.notifyPropertyChange('frame');

    // Notify.
    if (this.didAppendToDocument) { this.didAppendToDocument(); }
  },

  /** @private Attempts to call `didHideInDocument` on the view. */
  _notifyDidHideInDocument: function () {
    if (this.didHideInDocument) { this.didHideInDocument(); }
  },

  /** @private Attempts to call `didCreateLayer` on the view. */
  _notifyDidRender: function () {
    var mixins = this.didCreateLayerMixin,
      idx, len;

    // Send notice that the layer was created.
    if (this.didCreateLayer) { this.didCreateLayer(); }
    if (mixins) {
      len = mixins.length;
      for (idx = 0; idx < len; ++idx) {
        mixins[idx].call(this);
      }
    }
  },

  /** @private Attempts to call `didShowInDocument` on the view. */
  _notifyDidShowInDocument: function () {
    if (this.didShowInDocument) { this.didShowInDocument(); }
  },

  /** @private Attempts to call `willDestroyLayer` on the view. */
  _notifyWillDestroyLayer: function () {
    var idx, len,
      mixins;

    mixins = this.willDestroyLayerMixin;
    if (mixins) {
      len = mixins.length;
      for (idx = 0; idx < len; ++idx) {
        mixins[idx].call(this);
      }
    }

    if (this.willDestroyLayer) { this.willDestroyLayer(); }
  },

  /** @private Attempts to call `willRemoveFromDocument` on the view. */
  _notifyWillDetach: function () {
    if (this.willRemoveFromDocument) { this.willRemoveFromDocument(); }
  },

  /** @private Attempts to call `willHideInDocument` on the view. */
  _notifyWillHideInDocument: function () {
    if (this.willHideInDocument) { this.willHideInDocument(); }
  },

  /** @private Attempts to call `willShowInDocument` on the view. */
  _notifyWillShowInDocument: function () {
    if (this.willShowInDocument) { this.willShowInDocument(); }
  },

  /** @private Routes according to parent did append. */
  _parentDidAttach: function (notifyStack) {
    var state = this.get('viewState'),
        shouldContinue = true;

    // Handle all 12 possible view states.
    switch (state) {

    // Scenario: The child view was attached to the parent, which was unattached.
    // Result: Update the child and then move it to the proper attached state.
    case SC.CoreView.ATTACHED_PARTIAL:
      // Run any queued updates.
      this._executeQueuedUpdates();

      // Go to the proper state.
      this._gotoSomeAttachedState();

      // If there is a transition in, run it. TODO: Check state here?
      var transitionIn = this.get('transitionIn');
      if (transitionIn) {
        this._transitionIn(false);
      }

      break;

    // Scenario: The child is unrendered or unattached.
    // Result: The child would need to be forced into this state by its parent (otherwise it should
    //         be in an ATTACHED_PARTIAL state), so just leave it alone and don't notify.
    case SC.CoreView.UNRENDERED: // Render + attach?
    case SC.CoreView.UNATTACHED: // Attach?
      // There's no need to continue to further child views.
      shouldContinue = false;
      break;

    // Invalid states.
    default:
      


      // There's no need to continue to further child views.
      shouldContinue = false;
    }

    if (shouldContinue) {
      // Allow children that have changed state to notify that they have been attached.
      notifyStack.push(this);
    }

    return shouldContinue;
  },

  /** @private Updates according to parent did cancel build out. */
  _parentDidCancelBuildOut: function () {
    var state = this.get('viewState');

    // If the view was building out because its parent was building out, attempt to reverse or
    // revert the transition.
    if (state === SC.CoreView.ATTACHED_BUILDING_OUT_BY_PARENT) {
      var transitionIn = this.get('transitionIn');

      // Cancel the building out transition (in place if we are going to switch to transitioning back in).
      this.cancelAnimation(transitionIn ? SC.LayoutState.CURRENT : undefined);

      // Set the proper state.
      this._gotoAttachedShownState();

      if (transitionIn) {
        this._transitionIn(true);
      }

    // If the view was building out on its own or is hidden we can ignore it.
    } else if (state === SC.CoreView.ATTACHED_BUILDING_OUT || state &
      SC.CoreView.IS_HIDDEN) {
      // There's no need to continue to further child views.
      return false;
    }
  },

  /** @private Update child view states when the parent hides. Top-down! */
  _parentDidHideInDocument: function () { // notifyStack
    var state = this.get('viewState'),
        shouldContinue = false;

    // Handle all 12 possible view states.
    switch (state) {

    // Scenario: The child view was shown.
    // Result: Go to hidden by parent state.
    case SC.CoreView.ATTACHED_SHOWN:
      // Go to the proper state.
      this._gotoAttachedHiddenByParentState();

      shouldContinue = true;
      break;

    // Scenario: The child view was hidden or forced to unrendered or unattached state.
    // Result: Do nothing.
    case SC.CoreView.UNRENDERED:
    case SC.CoreView.UNATTACHED:
    case SC.CoreView.ATTACHED_HIDDEN:
      break;

    // Invalid states.
    default:
      

    }

    // if (shouldContinue) {
    //   // Allow children that have changed state to notify that they have been hidden.
    //   notifyStack.push(this);
    // }

    return shouldContinue;
  },

  /** @private Routes according to parent did detach. */
  _parentDidDetach: function () {
    var state = this.get('viewState');

    if (state & SC.CoreView.IS_ATTACHED) {
      // Update states after *will* and before *did* notifications!
      this._gotoAttachedPartialState();
    } else {
      // There's no need to continue to further child views.
      return false;
    }
  },

  /** @private Configure child views when parent did render. */
  _parentDidRender: function (notifyStack) {
    var state = this.get('viewState'),
        shouldContinue = true;

    // Handle all 12 possible view states.
    switch (state) {

    // Scenario: The child view was unrendered and now is rendered.
    // Result: Add rendered state observers and move it to the proper rendered state.
    case SC.CoreView.UNRENDERED:
      this._sc_addRenderedStateObservers();

      // Go to the proper state.
      this._gotoAttachedPartialState();
      break;

    // Invalid states.
    default:
      


      // There's no need to continue to further child views.
      shouldContinue = false;
    }

    if (shouldContinue) {
      // Allow children that have changed state to notify that they have been rendered.
      notifyStack.push(this);
    }

    return shouldContinue;
  },

  /** @private Update child view states when the parent shows. Top-down! */
  _parentDidShowInDocument: function () { // notifyStack
    var state = this.get('viewState'),
        shouldContinue = true;

    // Handle all 12 possible view states.
    switch (state) {

    // Scenario: The child view is only hidden because of the parent.
    // Result: Go to shown state. This will notify.
    case SC.CoreView.ATTACHED_HIDDEN_BY_PARENT:
      this._gotoAttachedShownState();

      break;

    // Scenario: The child view is hidden on its own or has been forced to an unrendered or unattached state.
    // Result: Do nothing and don't notify.
    case SC.CoreView.UNRENDERED:
    case SC.CoreView.UNATTACHED:
    case SC.CoreView.ATTACHED_HIDDEN:
      // There's no need to continue to further child views.
      shouldContinue = false;
      break;

    // Invalid states.
    default:
      

      // There's no need to continue to further child views.
      shouldContinue = false;
    }

    // if (shouldContinue) {
    //   // Allow children that have changed state to notify that they have been made visible.
    //   notifyStack.push(this);
    // }

    return shouldContinue;
  },

  /** @private Starts building out view if appropriate. */
  _parentWillBuildOutFromDocument: function (owningView) {
    var state = this.get('viewState'),
      transitionOut = this.get('transitionOut'),
      shouldContinue = true;

    switch (state) {
    case SC.CoreView.UNRENDERED:
    case SC.CoreView.UNATTACHED:
    case SC.CoreView.ATTACHED_BUILDING_OUT:
    case SC.CoreView.ATTACHED_HIDDEN:
      // There's no need to continue to further child views.
      shouldContinue = false;
      break;

    // Scenario: The child view is building in at the same time that its ancestor wants to detach.
    // Result: If the child wants to build out, switch to building out by parent, otherwise let the build in run for as long as it can.
    case SC.CoreView.ATTACHED_BUILDING_IN:

      // Cancel the build in transition.
      if (transitionOut) {
        this.cancelAnimation(SC.LayoutState.CURRENT);
      } else {
        this.cancelAnimation();
      }

      // Set the proper state.
      this._gotoAttachedShownState();

      // Build out the view by parent.
      if (transitionOut) {
        this._transitionOut(true, owningView);
      }

      break;

    // Scenario: The view is shown and possibly transitioning.
    // Result: Allow any transitions to continue concurrent with build out transition (may be conflicts).
    case SC.CoreView.ATTACHED_HIDING:
    case SC.CoreView.ATTACHED_SHOWN_ANIMATING:
    case SC.CoreView.ATTACHED_SHOWING:
    case SC.CoreView.ATTACHED_SHOWN:

      // Build out the view by parent.
      if (transitionOut) {
        this._transitionOut(false, owningView);
      }
      break;

    // Invalid states.
    default:
      

      // There's no need to continue to further child views.
      shouldContinue = false;
    }

    return shouldContinue;
  },

  /** @private Prepares according to parent will hide. This is called before the parent view hides
    completely, which may be after a hide transition completes. */
  _parentWillHideInDocument: function () { // notifyStack
    var state = this.get('viewState'),
        shouldContinue = true;

    // Handle all 12 possible view states.
    switch (state) {

    // Scenario: The child view is visible.
    // Result: Do nothing and continue.
    case SC.CoreView.ATTACHED_SHOWN:
      break;

    // Scenario: The child view is animating.
    // Result: Complete its animation immediately and continue.
    case SC.CoreView.ATTACHED_SHOWN_ANIMATING:
    case SC.CoreView.ATTACHED_SHOWING:
    case SC.CoreView.ATTACHED_BUILDING_IN:
    case SC.CoreView.ATTACHED_BUILDING_OUT:
    case SC.CoreView.ATTACHED_BUILDING_OUT_BY_PARENT:
    case SC.CoreView.ATTACHED_HIDING:
      this.cancelAnimation();
      break;

    // Scenario: The child view is hidden or has been forced to an unrendered or unattached state.
    // Result: Do nothing and don't notify.
    case SC.CoreView.UNRENDERED:
    case SC.CoreView.UNATTACHED:
    case SC.CoreView.ATTACHED_HIDDEN:
      // There's no need to continue to further child views.
      break;

    // Invalid states.
    default:
      

      // There's no need to continue to further child views.
      shouldContinue = false;
    }

    // if (shouldContinue) {
    //   // Allow children that have changed state to notify that they will be shown.
    //   notifyStack.push(this);
    // }

    return shouldContinue;
  },

  /** @private Clean up before parent is detached. */
  _parentWillDetach: function (notifyStack) {
    var state = this.get('viewState'),
        shouldContinue = true;

    // Handle all 12 possible view states.
    switch (state) {

    // Scenario: The child view is visible.
    // Result: Do nothing and continue.
    case SC.CoreView.ATTACHED_SHOWN:
      break;

    // Scenario: The child view is animating.
    // Result: Complete its animation immediately and continue.
    case SC.CoreView.ATTACHED_SHOWN_ANIMATING: // TODO: We need concurrent states!
    case SC.CoreView.ATTACHED_SHOWING:
    case SC.CoreView.ATTACHED_BUILDING_IN: // Was building in and didn't have a build out.
    case SC.CoreView.ATTACHED_BUILDING_OUT: // Was building out on its own at the same time.
    case SC.CoreView.ATTACHED_HIDING:
      this.cancelAnimation();
      break;

    // Scenario: The child view has forced to unattached or unrendered state, or it's hidden.
    // Result: Don't continue.
    case SC.CoreView.UNRENDERED:
    case SC.CoreView.UNATTACHED:
    case SC.CoreView.ATTACHED_HIDDEN:
    case SC.CoreView.ATTACHED_HIDDEN_BY_PARENT:
      shouldContinue = false;
      break;

    // Invalid states.
    default:
      

      // There's no need to continue to further child views.
      shouldContinue = false;
    }

    if (shouldContinue) {
      // Allow children that have changed state to notify that they will be shown.
      notifyStack.push(this);
    }

    return shouldContinue;
  },

  /** @private Prepares according to parent will show. */
  _parentWillShowInDocument: function (notifyStack) {
    var state = this.get('viewState'),
        shouldContinue = true;

    // Handle all 12 possible view states.
    switch (state) {

    // Scenario: The child view is only hidden because of the parent.
    // Result: Run queued updates. This will notify.
    case SC.CoreView.ATTACHED_HIDDEN_BY_PARENT:
      this._executeQueuedUpdates();

      break;

    // Scenario: The child view is hidden on its own or has been forced to an unrendered or unattached state.
    // Result: Do nothing and don't notify.
    case SC.CoreView.UNRENDERED:
    case SC.CoreView.UNATTACHED:
    case SC.CoreView.ATTACHED_HIDDEN:
      // There's no need to continue to further child views.
      shouldContinue = false;
      break;

    // Invalid states.
    default:
      

      // There's no need to continue to further child views.
      shouldContinue = false;
    }

    if (shouldContinue) {
      // Allow children that have changed state to notify that they will be shown.
      notifyStack.push(this);
    }

    return shouldContinue;
  },

  /** @private */
  _setupTransition: function (transition) {
    // Get a copy of the layout.
    var layout = SC.clone(this.get('layout'));
    // Prepare for a transition.
    this._preTransitionLayout = layout;
    this._preTransitionFrame = this.get('borderFrame');
    // Cache appropriate layout values.
    var layoutProperties = SC.get(transition, 'layoutProperties');
    // If the transition specifies any layouts, cache them.
    if (layoutProperties && layoutProperties.length) {
      this._transitionLayoutCache = {};
      var i, prop, len = layoutProperties.length;
      for (i = 0; i < len; i++) {
        prop = layoutProperties[i];
        this._transitionLayoutCache[prop] = layout[prop] === undefined ? null : layout[prop];
      }
    }
  },

  /** @private */
  _teardownTransition: function () {
    // Make sure this isn't being called twice for the same transition. For example,
    // some transition plugins will send a didTransitionIn/Out event even if the
    // transition was cancelled.

    // If we have a hash of cached layout properties, adjust back to it.
    if (this._transitionLayoutCache) {
      this.adjust(this._transitionLayoutCache);
    }
    // Otherwise, just set the layout back to what it was.
    else if (this._preTransitionLayout) {
      this.set('layout', this._preTransitionLayout);
    }
    // Clean up.
    this._preTransitionLayout = null;
    this._preTransitionFrame = null;
    this._transitionLayoutCache = null;
  },

  /** @private Attempts to run a transition hide, ensuring any incoming transitions are stopped in place. */
  _transitionHide: function (inPlace) {
    var transitionHide = this.get('transitionHide'),
      options = this.get('transitionHideOptions') || {};

    


    // switch (state) {
    // case SC.CoreView.ATTACHED_SHOWING:
    // case SC.CoreView.ATTACHED_BUILDING_IN:
    //   this.cancelAnimation(SC.LayoutState.CURRENT);
    //   inPlace = true;
    //   break;
    // default:
    if (!inPlace) {
      this._setupTransition(transitionHide);
    }
    // }

    // Set up the hiding transition.
    if (transitionHide.setup) {
      transitionHide.setup(this, options, inPlace);
    }

    // Execute the hiding transition.
    transitionHide.run(this, options, this._preTransitionLayout, this._preTransitionFrame);

    // Set the proper state.
    this._gotoAttachedHidingState();
  },

  /** @private Attempts to run a transition in, ensuring any outgoing transitions are stopped in place. */
  _transitionIn: function (inPlace) {
    var transitionIn = this.get('transitionIn'),
      options = this.get('transitionInOptions') || {};

    


    if (!inPlace) {
      this._setupTransition(transitionIn);
    }

    // Set up the incoming transition.
    if (transitionIn.setup) {
      transitionIn.setup(this, options, inPlace);
    }

    // Execute the incoming transition.
    if (transitionIn.run) {
      transitionIn.run(this, options, this._preTransitionLayout, this._preTransitionFrame);
    }

    // Set the proper state.
    this._gotoAttachedBuildingInState();
  },

  /** @private Attempts to run a transition out, ensuring any incoming transitions are stopped in place. */
  _transitionOut: function (inPlace, owningView) {
    var transitionOut = this.get('transitionOut'),
      options = this.get('transitionOutOptions') || {};

    if (!inPlace) {
      this._setupTransition(transitionOut);
    }

    // Increment the shared building out count.
    owningView._sc_buildOutCount++;

    // Set up the outgoing transition.
    if (transitionOut.setup) {
      transitionOut.setup(this, options, inPlace);
    }

    // Execute the outgoing transition.
    transitionOut.run(this, options, this._preTransitionLayout, this._preTransitionFrame);

    // Set the proper state.
    if (owningView === this) {
      this._gotoAttachedBuildingOutState();
    } else {
      this._gotoAttachedBuildingOutByParentState();
    }
  },

  /** @private Attempts to run a transition show, ensuring any hiding transitions are stopped in place. */
  _transitionShow: function (inPlace) {
    var transitionShow = this.get('transitionShow'),
      options = this.get('transitionShowOptions') || {};

    


    if (!inPlace) {
      this._setupTransition(transitionShow);
    }

    // Set up the showing transition.
    if (transitionShow.setup) {
      transitionShow.setup(this, options, inPlace);
    }

    // Execute the showing transition.
    transitionShow.run(this, options, this._preTransitionLayout, this._preTransitionFrame);

    // Set the proper state.
    this._gotoAttachedShowingState();
  },

  /** @private Goes to the proper attached state depending on its parents state*/
  _gotoSomeAttachedState: function () {
    var parentView = this.get('parentView'),
      isParentHidden = parentView ? parentView.get('viewState') & SC.CoreView.IS_HIDDEN : false,
      // Views without a parent are not limited by a parent's current state.
      isParentShown = parentView ? parentView.get('viewState') & SC.CoreView.IS_SHOWN : true;

    // Set the proper state.
    if (isParentShown) {
      if (this.get('isVisible')) {
        this._gotoAttachedShownState();
      } else {
        this._gotoAttachedHiddenState();
      }
    } else if (isParentHidden) {
      this._gotoAttachedHiddenByParentState();
    } else {
      this._gotoAttachedPartialState();
    }
  }

});

/* >>>>>>>>>> BEGIN source/views/view.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
/*global jQuery*/

sc_require('system/browser');
sc_require('system/event');
sc_require('system/cursor');
sc_require('system/responder');
sc_require('system/theme');

sc_require('system/string');
sc_require('views/view/statechart');


/**
  Default property to disable or enable by default the contextMenu
*/
SC.CONTEXT_MENU_ENABLED = YES;

/**
  Default property to disable or enable if the focus can jump to the address
  bar or not.
*/
SC.TABBING_ONLY_INSIDE_DOCUMENT = NO;

/**
  Tells the property (when fetched with themed()) to get its value from the renderer (if any).
*/
SC.FROM_THEME = "__FROM_THEME__"; // doesn't really matter what it is, so long as it is unique. Readability is a plus.

/** @private - custom array used for child views */
SC.EMPTY_CHILD_VIEWS_ARRAY = [];
SC.EMPTY_CHILD_VIEWS_ARRAY.needsClone = YES;

/**
  @class

*/
SC.CoreView.reopen(
/** @scope SC.View.prototype */ {

  /**
    An array of the properties of this class that will be concatenated when
    also present on subclasses.

    @type Array
    @default ['outlets', 'displayProperties', 'classNames', 'renderMixin', 'didCreateLayerMixin', 'willDestroyLayerMixin', 'classNameBindings', 'attributeBindings']
  */
  concatenatedProperties: ['outlets', 'displayProperties', 'classNames', 'renderMixin', 'didCreateLayerMixin', 'willDestroyLayerMixin', 'classNameBindings', 'attributeBindings'],

  /**
    The WAI-ARIA role of the control represented by this view. For example, a
    button may have a role of type 'button', or a pane may have a role of
    type 'alertdialog'. This property is used by assistive software to help
    visually challenged users navigate rich web applications.

    The full list of valid WAI-ARIA roles is available at:
    http://www.w3.org/TR/wai-aria/roles#roles_categorization

    @type String
    @default null
  */
  ariaRole: null,

  /**
    The aria-hidden role is managed appropriately by the internal view's
    statechart.  When the view is not currently displayed the aria-hidden
    attribute will be set to true.

    @type String
    @default null
    @deprecated Version 1.10
  */
  ariaHidden: null,

  /**
    Whether this view was created by its parent view or not.

    Several views are given child view classes or instances to automatically
    append and remove.  In the case that the view was provided an instance,
    when it removes the instance and no longer needs it, it should not destroy
    the instance because it was created by someone else.

    On the other hand if the view was given a class that it creates internal
    instances from, then it should destroy those instances properly to avoid
    memory leaks.

    This property should be set by any view that is creating internal child
    views so that it can properly remove them later.  Note that if you use
    `createChildView`, this property is set automatically for you.

    @type Boolean
    @see SC.View#createChildView
    @default false
  */
  createdByParent: false,

  /** @deprecated Version 1.11.0 Please use parentView instead. */
  owner: function () {
    

    return this.get('parentView');
  }.property('parentView').cacheable(),

  /**
    The current pane.

    @field
    @type SC.Pane
    @default null
  */
  pane: function () {
    var view = this;

    while (view && !view.isPane) { view = view.get('parentView'); }

    return view;
  }.property('parentView').cacheable(),

  /**
    The page this view was instantiated from.  This is set by the page object
    during instantiation.

    @type SC.Page
    @default null
  */
  page: null,

  /**
    If the view is currently inserted into the DOM of a parent view, this
    property will point to the parent of the view.

    @type SC.View
    @default null
  */
  parentView: null,

  /**
    The isVisible property determines if the view should be displayed or not.

    If you also set a transitionShow or transitionHide plugin, then when
    isVisible changes, the appropriate transition will execute as the view's
    visibility changes.

    Note that isVisible can be set to true and the view may still not be
    "visible" in the window.  This can occur if:

      1. the view is not attached to the document.
      2. the view has a view ancestor with isVisible set to false.

    @type Boolean
    @see SC.View#viewState
    @default true
  */
  isVisible: true,
  isVisibleBindingDefault: SC.Binding.bool(),

  // ..........................................................
  // CHILD VIEW SUPPORT
  //

  /**
    Array of child views.  You should never edit this array directly unless
    you are implementing createChildViews().  Most of the time, you should
    use the accessor methods such as appendChild(), insertBefore() and
    removeChild().

    @type Array
    @default []
  */
  childViews: SC.EMPTY_CHILD_VIEWS_ARRAY,

  /**
    Use this property to automatically mix in a collection of mixins into all
    child views created by the view. This collection is applied during createChildView
    @property

    @type Array
    @default null
  */
  autoMixins: null,

  // ..........................................................
  // LAYER SUPPORT
  //

  /**
    Returns the current layer for the view.  The layer for a view is only
    generated when the view first becomes visible in the window and even
    then it will not be computed until you request this layer property.

    If the layer is not actually set on the view itself, then the layer will
    be found by calling this.findLayerInParentLayer().

    You can also set the layer by calling set on this property.

    @type DOMElement the layer
  */
  layer: function (key, value) {
    if (value !== undefined) {
      this._view_layer = value;

    // no layer...attempt to discover it...
    } else {
      value = this._view_layer;
      if (!value) {
        var parent = this.get('parentView');
        if (parent) { parent = parent.get('layer'); }
        this._view_layer = value = this.findLayerInParentLayer(parent);
      }
    }
    return value;
  }.property('isVisibleInWindow').cacheable(),

  /**
    Get a CoreQuery object for this view's layer, or pass in a selector string
    to get a CoreQuery object for a DOM node nested within this layer.

    @param {String} sel a CoreQuery-compatible selector string
    @returns {SC.CoreQuery} the CoreQuery object for the DOM node
  */
  $: function (sel) {
    var layer = this.get('layer');

    if (!layer) { return SC.$(); }
    else if (sel === undefined) { return SC.$(layer); }
    else { return SC.$(sel, layer); }
  },

  /**
    Returns the DOM element that should be used to hold child views when they
    are added/remove via DOM manipulation.  The default implementation simply
    returns the layer itself.  You can override this to return a DOM element
    within the layer.

    @type DOMElement the container layer
  */
  containerLayer: function () {
    return this.get('layer');
  }.property('layer').cacheable(),

  /**
    The ID to use when trying to locate the layer in the DOM.  If you do not
    set the layerId explicitly, then the view's GUID will be used instead.
    This ID must be set at the time the view is created.

    @type String
    @readOnly
  */
  layerId: function (key, value) {
    if (value) { this._layerId = value; }
    if (this._layerId) { return this._layerId; }
    return SC.guidFor(this);
  }.property().cacheable(),

  /**
    Attempts to discover the layer in the parent layer.  The default
    implementation looks for an element with an ID of layerId (or the view's
    guid if layerId is null).  You can override this method to provide your
    own form of lookup.  For example, if you want to discover your layer using
    a CSS class name instead of an ID.

    @param {DOMElement} parentLayer the parent's DOM layer
    @returns {DOMElement} the discovered layer
  */
  findLayerInParentLayer: function (parentLayer) {
    var id = "#" + this.get('layerId').escapeCssIdForSelector();
    return jQuery(id, parentLayer)[0] || jQuery(id)[0];
  },

  /**
    Returns YES if the receiver is a subview of a given view or if it's
    identical to that view. Otherwise, it returns NO.

    @property {SC.View} view
  */
  isDescendantOf: function (view) {
    var parentView = this.get('parentView');

    if (this === view) { return YES; }
    else if (parentView) { return parentView.isDescendantOf(view); }
    else { return NO; }
  },

  /**
    This method is invoked whenever a display property changes and updates
    the view's content once at the end of the run loop before any invokeLast
    functions run.

    To cause the view to be updated you can call this method directly and
    if you need to perform additional setup whenever the display changes, you
    can override this method as well.

    @returns {SC.View} receiver
  */
  displayDidChange: function () {
    


    // Don't run _doUpdateContent needlessly, because the view may render
    // before it is invoked, which would result in a needless update.
    if (this.get('_isRendered')) {
      // Legacy.
      this.set('layerNeedsUpdate', true);

      this.invokeOnce(this._doUpdateContent);
    }

    return this;
  },

  /**
    This property has no effect and is deprecated.

    To cause a view to update immediately, you should just call updateLayer or
    updateLayerIfNeeded.  To cause a view to update at the end of the run loop
    before any invokeLast functions run, you should call displayDidChange.

    @deprecated Version 1.10
    @type Boolean
    @test in updateLayer
  */
  layerNeedsUpdate: NO,

  /**
    Updates the view's layer if the view is in a shown state.  Otherwise, the
    view will be updated the next time it enters a shown state.

    This is the same behavior as `displayDidChange` except that calling
    `updateLayerIfNeeded` will attempt to update each time it is called,
    while `displayDidChange` will only attempt to update the layer once per run
    loop.

    @returns {SC.View} receiver
    @test in updateLayer
  */
  updateLayerIfNeeded: function (skipIsVisibleInWindowCheck) {
    

    this._doUpdateContent(false);

    return this;
  },

  /**
    This is the core method invoked to update a view layer whenever it has
    changed.  This method simply creates a render context focused on the
    layer element and then calls your render() method.

    You will not usually call or override this method directly.  Instead you
    should set the layerNeedsUpdate property to YES to cause this method to
    run at the end of the run loop, or you can call updateLayerIfNeeded()
    to force the layer to update immediately.

    Instead of overriding this method, consider overriding the render() method
    instead, which is called both when creating and updating a layer.  If you
    do not want your render() method called when updating a layer, then you
    should override this method instead.

    @returns {SC.View} receiver
  */
  updateLayer: function () {
    this._doUpdateContent(true);

    return this;
  },

  /** @private */
  parentViewDidResize: function () {
    if (!this.get('hasLayout')) { this.notifyPropertyChange('frame'); }
    this.viewDidResize();
  },

  /**
    Override this in a child class to define behavior that should be invoked
    when a parent's view was resized.
   */
  viewDidResize: function () {},

  /**
    Creates a new renderContext with the passed tagName or element.  You
    can override this method to provide further customization to the context
    if needed.  Normally you will not need to call or override this method.

    @returns {SC.RenderContext}
  */
  renderContext: function (tagNameOrElement) {
    return SC.RenderContext(tagNameOrElement);
  },

  /**
    Creates the layer by creating a renderContext and invoking the view's
    render() method.  This will only create the layer if the layer does not
    already exist.

    When you create a layer, it is expected that your render() method will
    also render the HTML for all child views as well.  This method will
    notify the view along with any of its childViews that its layer has been
    created.

    @returns {SC.View} receiver
  */
  createLayer: function () {
    if (!this.get('_isRendered')) {
      this._doRender();
    }

    return this;
  },

  /**
    Destroys any existing layer along with the layer for any child views as
    well.  If the view does not currently have a layer, then this method will
    do nothing.

    If you implement willDestroyLayer() on your view or if any mixins
    implement willDestroLayerMixin(), then this method will be invoked on your
    view before your layer is destroyed to give you a chance to clean up any
    event handlers, etc.

    If you write a willDestroyLayer() handler, you can assume that your
    didCreateLayer() handler was called earlier for the same layer.

    Normally you will not call or override this method yourself, but you may
    want to implement the above callbacks when it is run.

    @returns {SC.View} receiver
  */
  destroyLayer: function () {
    // We allow you to call destroy layer, but you should really detach first.
    if (this.get('isAttached')) {
      this._doDetach();
    }

    if (this.get('_isRendered')) {
      this._doDestroyLayer();
    }

    return this;
  },

  /**
    Destroys and recreates the current layer.  Doing this on a parent view can
    be more efficient than modifying individual child views independently.

    @returns {SC.View} receiver
  */
  replaceLayer: function () {
    var layer, parentNode;

    // If attached, detach and track our parent node so we can re-attach.
    if (this.get('isAttached')) {
      layer = this.get('layer');
      parentNode = layer.parentNode;

      this._doDetach();
    }

    this.destroyLayer().createLayer();

    // Reattach our layer (if we have a parentView this is done automatically).
    if (parentNode && !this.get('isAttached')) { this._doAttach(parentNode); }

    return this;
  },

  /**
    If the parent view has changed, we need to insert this
    view's layer into the layer of the new parent view.
  */
  parentViewDidChange: function () {
    

  },

  /**
    Set to YES when the view's layer location is dirty.  You can call
    updateLayerLocationIfNeeded() to clear this flag if it is set.

    @deprecated Version 1.10
    @type Boolean
  */
  layerLocationNeedsUpdate: NO,

  /**
    Calls updateLayerLocation(), but only if the view's layer location
    currently needs to be updated.

    @deprecated Version 1.10
    @returns {SC.View} receiver
    @test in updateLayerLocation
  */
  updateLayerLocationIfNeeded: function () {
    


    return this;
  },

  /**
    This method is called when a view changes its location in the view
    hierarchy.  This method will update the underlying DOM-location of the
    layer so that it reflects the new location.

    @deprecated Version 1.10
    @returns {SC.View} receiver
  */
  updateLayerLocation: function () {
    


    return this;
  },

  /**
    @private

    Renders to a context.
    Rendering only happens for the initial rendering. Further updates happen in updateLayer,
    and are not done to contexts, but to layers.
    Note: You should not generally override nor directly call this method. This method is only
    called by createLayer to set up the layer initially, and by renderChildViews, to write to
    a context.

    @param {SC.RenderContext} context the render context.
  */
  renderToContext: function (context) {
    var mixins, idx, len;

    this.beginPropertyChanges();

    context.id(this.get('layerId'));
    context.setAttr('role', this.get('ariaRole'));

    // Set up the classNameBindings and attributeBindings observers.
    // TODO: CLEAN UP!!
    this._applyClassNameBindings();
    this._applyAttributeBindings(context);

    context.addClass(this.get('classNames'));

    if (this.get('isTextSelectable')) { context.addClass('allow-select'); }

    if (!this.get('isVisible')) {
      context.addClass('sc-hidden');
      context.setAttr('aria-hidden', 'true');
    }

    // Call applyAttributesToContext so that subclasses that override it can
    // insert further attributes.
    this.applyAttributesToContext(context);

    // We pass true for the second argument to support the old style of render.
    this.render(context, true);

    // If we've made it this far and renderChildViews() was never called,
    // render any child views now.
    if (!this._didRenderChildViews) { this.renderChildViews(context); }
    // Reset the flag so that if the layer is recreated we re-render the child views.
    this._didRenderChildViews = false;

    if (mixins = this.renderMixin) {
      len = mixins.length;
      for (idx = 0; idx < len; ++idx) { mixins[idx].call(this, context, true); }
    }

    this.endPropertyChanges();
  },

  /** Apply the attributes to the context. */
  applyAttributesToContext: function (context) {

  },

  /**
    @private

    Iterates over the view's `classNameBindings` array, inserts the value
    of the specified property into the `classNames` array, then creates an
    observer to update the view's element if the bound property ever changes
    in the future.
  */
  _applyClassNameBindings: function () {
    var classBindings = this.get('classNameBindings'),
        classNames = this.get('classNames'),
        dasherizedClass;

    if (!classBindings) { return; }

    // Loop through all of the configured bindings. These will be either
    // property names ('isUrgent') or property paths relative to the view
    // ('content.isUrgent')
    classBindings.forEach(function (property) {

      // Variable in which the old class value is saved. The observer function
      // closes over this variable, so it knows which string to remove when
      // the property changes.
      var oldClass;

      // Set up an observer on the context. If the property changes, toggle the
      // class name.
      var observer = function () {
        // Get the current value of the property
        var newClass = this._classStringForProperty(property);
        var elem = this.$();

        // If we had previously added a class to the element, remove it.
        if (oldClass) {
          elem.removeClass(oldClass);
          classNames.removeObject(oldClass);
        }

        // If necessary, add a new class. Make sure we keep track of it so
        // it can be removed in the future.
        if (newClass) {
          elem.addClass(newClass);
          classNames.push(newClass);
          oldClass = newClass;
        } else {
          oldClass = null;
        }
      };

      this.addObserver(property.split(':')[0], this, observer);

      // Get the class name for the property at its current value
      dasherizedClass = this._classStringForProperty(property);

      if (dasherizedClass) {
        // Ensure that it gets into the classNames array
        // so it is displayed when we render.
        classNames.push(dasherizedClass);

        // Save a reference to the class name so we can remove it
        // if the observer fires. Remember that this variable has
        // been closed over by the observer.
        oldClass = dasherizedClass;
      }

    }, this);
  },

  /**
    Iterates through the view's attribute bindings, sets up observers for each,
    then applies the current value of the attributes to the passed render buffer.

    @param {SC.RenderBuffer} buffer
  */
  _applyAttributeBindings: function (context) {
    var attributeBindings = this.get('attributeBindings'),
        attributeValue, elem, type;

    if (!attributeBindings) { return; }

    attributeBindings.forEach(function (attribute) {
      // Create an observer to add/remove/change the attribute if the
      // JavaScript property changes.
      var observer = function () {
        elem = this.$();
        var currentValue = elem.attr(attribute);
        attributeValue = this.get(attribute);

        type = typeof attributeValue;

        if ((type === 'string' || type === 'number') && attributeValue !== currentValue) {
          elem.attr(attribute, attributeValue);
        } else if (attributeValue && type === 'boolean') {
          elem.attr(attribute, attribute);
        } else if (attributeValue === NO) {
          elem.removeAttr(attribute);
        }
      };

      this.addObserver(attribute, this, observer);

      // Determine the current value and add it to the render buffer
      // if necessary.
      attributeValue = this.get(attribute);
      type = typeof attributeValue;

      if (type === 'string' || type === 'number') {
        context.setAttr(attribute, attributeValue);
      } else if (attributeValue && type === 'boolean') {
        // Apply boolean attributes in the form attribute="attribute"
        context.setAttr(attribute, attribute);
      }
    }, this);
  },

  /**
    @private

    Given a property name, returns a dasherized version of that
    property name if the property evaluates to a non-falsy value.

    For example, if the view has property `isUrgent` that evaluates to true,
    passing `isUrgent` to this method will return `"is-urgent"`.
  */
  _classStringForProperty: function (property) {
    var split = property.split(':'), className = split[1];
    property = split[0];

    var val = SC.getPath(this, property);

    // If value is a Boolean and true, return the dasherized property
    // name.
    if (val === YES) {
      if (className) { return className; }

      // Normalize property path to be suitable for use
      // as a class name. For exaple, content.foo.barBaz
      // becomes bar-baz.
      return SC.String.dasherize(property.split('.').get('lastObject'));

    // If the value is not NO, undefined, or null, return the current
    // value of the property.
    } else if (val !== NO && val !== undefined && val !== null) {
      return val;

    // Nothing to display. Return null so that the old class is removed
    // but no new class is added.
    } else {
      return null;
    }
  },

  /**
    Your render method should invoke this method to render any child views,
    especially if this is the first time the view will be rendered.  This will
    walk down the childView chain, rendering all of the children in a nested
    way.

    @param {SC.RenderContext} context the context
    @returns {SC.RenderContext} the render context
    @test in render
  */
  renderChildViews: function (context) {
    var cv = this.get('childViews'), len = cv.length, idx, view;
    for (idx = 0; idx < len; ++idx) {
      view = cv[idx];
      if (!view) { continue; }
      context = context.begin(view.get('tagName'));
      view.renderToContext(context);
      context = context.end();
    }

    // Track that renderChildViews was called in case it was called directly
    // in a render method.
    this._didRenderChildViews = true;

    return context;
  },

  /** @private -
    override to add support for theming or in your view
  */
  render: function () { },

  // ..........................................................
  // STANDARD RENDER PROPERTIES
  //

  /**
    A list of properties on the view to translate dynamically into attributes on
    the view's layer (element).

    When the view is rendered, the value of each property listed in
    attributeBindings will be inserted in the element.  If the value is a
    Boolean, the attribute name itself will be inserted.  As well, as the
    value of any of these properties changes, the layer will update itself
    automatically.

    This is an easy way to set custom attributes on the View without
    implementing it through a render or update function.

    For example,

        // ...  MyApp.MyView

        attributeBindings: ['aria-valuenow', 'disabled'],

        'aria-valuenow': function () {
          return this.get('value');
        }.property('value').cacheable(), // adds 'aria-valuenow="{value}"' attribute

        disabled: YES, // adds 'disabled="disabled"' attribute

        // ...

    @type Array
    @default null
  */
  attributeBindings: null,


  /**
    Tag name for the view's outer element.  The tag name is only used when
    a layer is first created.  If you change the tagName for an element, you
    must destroy and recreate the view layer.

    @type String
    @default 'div'
  */
  tagName: 'div',

  /**
    Standard CSS class names to apply to the view's outer element.  These class
    names are used in addition to any defined on the view's superclass.

    @type Array
    @default []
  */
  classNames: [],

  /**
    A list of local property names to translate dynamically into standard
    CSS class names on your view's layer (element).

    Each entry in the array should take the form "propertyName:css-class".
    For example, "isRed:my-red-view" will cause the class "my-red-view" to
    be appended if the property "isRed" is (or becomes) true, and removed
    if it later becomes false (or null/undefined).

    Optionally, you may provide just the property name, in which case it will
    be dasherized and used as the class name.  For example, including
    "isUpsideDown" will cause the view's isUpsideDown property to mediate the
    class "is-upside-down".

    Instead of a boolean value, your property may return a string, which will
    be used as the class name for that entry.  Use caution when returning other
    values; numbers will be appended verbatim and objects will be stringified,
    leading to unintended results such as class="4" or class="Object object".

    Class names mediated by these bindings are used in addition to any that
    you've listed in the classNames property.

    @type Array
  */
  classNameBindings: null,

  /**
    Tool tip property that will be set to the title attribute on the HTML
    rendered element.

    @type String
  */
  toolTip: null,

  /**
    The computed tooltip.  This is generated by localizing the toolTip
    property if necessary.

    @type String
  */
  displayToolTip: function () {
    var ret = this.get('toolTip');
    return (ret && this.get('localize')) ? SC.String.loc(ret) : (ret || '');
  }.property('toolTip', 'localize').cacheable(),

  /**
    Determines if the user can select text within the view.  Normally this is
    set to NO to disable text selection.  You should set this to YES if you
    are creating a view that includes editable text.  Otherwise, settings this
    to YES will probably make your controls harder to use and it is not
    recommended.

    @type Boolean
    @readOnly
  */
  isTextSelectable: NO,

  /**
    You can set this array to include any properties that should immediately
    invalidate the display.  The display will be automatically invalidated
    when one of these properties change.

    These are the properties that will be visible to any Render Delegate.
    When the RenderDelegate asks for a property it needs, the view checks the
    displayProperties array. It first looks for the property name prefixed
    by 'display'; for instance, if the render delegate needs a 'title',
    the view will attempt to find 'displayTitle'. If there is no 'displayTitle'
    in displayProperties, the view will then try 'title'. If 'title' is not
    in displayProperties either, an error will be thrown.

    This allows you to avoid collisions between your view's API and the Render
    Delegate's API.

    Implementation note:  'isVisible' is also effectively a display property,
    but it is not declared as such because it is observed separately in
    order to manage the view's internal state.

    @type Array
    @readOnly
  */
  displayProperties: [],

  // .......................................................
  // SC.RESPONDER SUPPORT
  //

  /** @property
    The nextResponder is usually the parentView.
  */
  nextResponder: function () {
    return this.get('parentView');
  }.property('parentView').cacheable(),


  /** @property
    Set to YES if your view is willing to accept first responder status.  This
    is used when calculating key responder loop.
  */
  acceptsFirstResponder: NO,

  // .......................................................
  // CORE DISPLAY METHODS
  //

  /** @private
    Caches the layerId to detect when it changes.
    */
  _lastLayerId: null,

  /** @private
    Setup a view, but do not finish waking it up.

     - configure childViews
     - Determine the view's theme
     - Fetch a render delegate from the theme, if necessary
     - register the view with the global views hash, which is used for event
       dispatch
  */
  init: function () {
    var childViews, layerId;

    arguments.callee.base.apply(this,arguments);

    layerId = this._lastLayerId = this.get('layerId');

    // Register the view for event handling. This hash is used by
    // SC.RootResponder to dispatch incoming events.
    

    SC.View.views[layerId] = this;

    // setup classNames
    this.classNames = this.get('classNames').slice();

    // setup child views.  be sure to clone the child views array first
    childViews = this.childViews = this.get('childViews').slice();
    this.createChildViews(); // setup child Views
  },

  /**
    Frame describes this view's current bounding rect, relative to its parent view. You
    can use this, for example, to reliably access a width for a view whose layout is
    defined with left and right. (Note that width and height values are calculated in
    the parent view's frame of reference as well, which has consequences for scaled
    views.)

    @type Rect
    @test in layoutStyle
  */
  frame: function () {
    return this.computeFrameWithParentFrame(null);
  }.property('useStaticLayout').cacheable(),    // We depend on the layout, but layoutDidChange will call viewDidResize to check the frame for us

  /**
    Computes the frame of the view by examining the view's DOM representation.
    If no representation exists, returns null.

    If the view has a parent view, the parent's bounds will be taken into account when
    calculating the frame.

    @returns {Rect} the computed frame
  */
  computeFrameWithParentFrame: function () {
    var layer,                            // The view's layer
        pv = this.get('parentView'),      // The view's parent view (if it exists)
        f;                                // The layer's coordinates in the document

    // need layer to be able to compute rect
    if (layer = this.get('layer')) {
      f = SC.offset(layer); // x,y
      if (pv) { f = pv.convertFrameFromView(f, null); }

      /*
        TODO Can probably have some better width/height values - CC
        FIXME This will probably not work right with borders - PW
      */
      f.width = layer.offsetWidth;
      f.height = layer.offsetHeight;

      return f;
    }

    // Unable to compute yet
    if (this.get('hasLayout')) {
      return null;
    } else {
      return { x: 0, y: 0, width: 0, height: 0 };
    }
  },

  /** @private Call the method recursively on all child views. */
  _callOnChildViews: function (methodName, isTopDown, context) {
    var childView,
      childViews = this.get('childViews'),
      method,
      shouldContinue;

    for (var i = childViews.length - 1; i >= 0; i--) {
      childView = childViews[i];

      // We allow missing childViews in the array so ignore them.
      if (!childView) { continue; }

      // Look up the method on the child.
      method = childView[methodName];

      // Call the method on this view *before* its children.
      if (isTopDown === undefined || isTopDown) {
        shouldContinue = method.call(childView, context);
      }

      // Recurse.
      if (shouldContinue === undefined || shouldContinue) {
        childView._callOnChildViews(methodName, isTopDown, context);
      }

      // Call the method on this view *after* its children.
      if (isTopDown === false) {
        method.call(childView, context);
      }
    }
  },

  /**
    The clipping frame returns the visible portion of the view, taking into
    account the clippingFrame of the parent view.  (Note that, in contrast
    to `frame`, `clippingFrame` is in the context of the view itself, not
    its parent view.)

    Normally this will be calculated based on the intersection of your own
    clippingFrame and your parentView's clippingFrame.

    @type Rect
  */
  clippingFrame: function () {
    var f = this.get('frame');

    // FAST PATH: No frame, no clipping frame.
    if (!f) return null;

    /*jshint eqnull:true */
    var scale = (f.scale == null) ? 1 : f.scale,
        pv = this.get('parentView'),
        pcf = pv ? pv.get('clippingFrame') : null,
        ret;

    // FAST PATH: No parent clipping frame, no change. (The origin and scale are reset from parent view's
    // context to our own.)
    if (!pcf) return { x: 0, y: 0, width: f.width / scale, height: f.height / scale};

    // Get the intersection.
    ret = SC.intersectRects(pcf, f);

    // Reorient the top-left from the parent's origin to ours.
    ret.x -= f.x;
    ret.y -= f.y;

    // If we're scaled, we have to scale the intersected rectangle from our parent's frame of reference
    // to our own.
    if (scale !== 1) {
      var scaleX, scaleY;
      // We're scaling from parent space into our space, so the scale is reversed. (Layout scale may be an array.)
      if (SC.typeOf(scale) === SC.T_ARRAY) {
        scaleX = 1 / scale[0];
        scaleY = 1 / scale[1];
      } else {
        scaleX = scaleY = 1 / scale;
      }

      // Convert the entire rectangle into our scale.
      ret.x *= scaleX;
      ret.width *= scaleX;
      ret.y *= scaleY;
      ret.height *= scaleY;
    }

    return ret;
  }.property('parentView', 'frame').cacheable(),

  /** @private
    This method is invoked whenever the clippingFrame changes, notifying
    each child view that its clippingFrame has also changed.
  */
  _sc_clippingFrameDidChange: function () {
    this.notifyPropertyChange('clippingFrame');
  },

  /**
    Removes the child view from the parent view *and* detaches it from the
    document.

    This does *not* remove the child view's layer (i.e. the node still exists,
    but is no longer in the document) and does *not* destroy the child view
    (i.e. it can still be re-attached to the document).

    Note that if the child view uses a transitionOut plugin, it will not be
    fully detached until the transition completes.  To force the view to detach
    immediately you can pass true for the optional `immediately` argument.

    If you wish to remove the child and discard it, use `removeChildAndDestroy`.

    @param {SC.View} view The view to remove as a child view.
    @param {Boolean} [immediately=false] Forces the child view to be removed immediately regardless if it uses a transitionOut plugin.
    @see SC.View#removeChildAndDestroy
    @returns {SC.View} receiver
  */
  removeChild: function (view, immediately) {
    if (view.get('isAttached')) {
      view._doDetach(immediately);
    }

    // If the view will transition out, wait for the transition to complete
    // before orphaning the view entirely.
    if (!immediately && view.get('viewState') === SC.CoreView.ATTACHED_BUILDING_OUT) {
      view.addObserver('isAttached', this, this._orphanChildView);
    } else {
      view._doOrphan();
    }

    return this;
  },

  /**
    Removes the child view from the parent view, detaches it from the document
    *and* destroys the view and its layer.

    Note that if the child view uses a transitionOut plugin, it will not be
    fully detached and destroyed until the transition completes.  To force the
    view to detach immediately you can pass true for the optional `immediately`
    argument.

    If you wish to remove the child and keep it for further re-use, use
    `removeChild`.

    @param {SC.View} view The view to remove as a child view and destroy.
    @param {Boolean} [immediately=false] Forces the child view to be removed and destroyed immediately regardless if it uses a transitionOut plugin.
    @see SC.View#removeChild
    @returns {SC.View} receiver
  */
  removeChildAndDestroy: function (view, immediately) {
    if (view.get('isAttached')) {
      view._doDetach(immediately);
    }

    // If the view will transition out, wait for the transition to complete
    // before destroying the view entirely.
    if (view.get('isAttached') && view.get('transitionOut') && !immediately) {
      view.addObserver('isAttached', this, this._destroyChildView);
    } else {
      view.destroy(); // Destroys the layer and the view.
    }

    return this;
  },

  /**
    Removes all children from the parentView *and* destroys them and their
    layers.

    Note that if any child view uses a transitionOut plugin, it will not be
    fully removed until the transition completes.  To force all child views to
    remove immediately you can pass true as the optional `immediately` argument.

    Tip: If you know that there are no transitions for the child views,
    you should pass true to optimize the document removal.

    @param {Boolean} [immediately=false] Forces all child views to be removed immediately regardless if any uses a transitionOut plugin.
    @returns {SC.View} receiver
  */
  removeAllChildren: function (immediately) {
    var childViews = this.get('childViews'),
      len = childViews.get('length'),
      i;

    // OPTIMIZATION!
    // If we know that we're removing all children and we are rendered, lets do the document cleanup in one sweep.
    // if (immediately && this.get('_isRendered')) {
    //   var layer,
    //     parentNode;

    //   // If attached, detach and track our parent node so we can re-attach.
    //   if (this.get('isAttached')) {
    //     layer = this.get('layer');
    //     parentNode = layer.parentNode;

    //     this._doDetach();
    //   }

    //   // Destroy our layer and thus all the children's layers in one move.
    //   this.destroyLayer();

    //   // Remove all the children.
    //   for (i = len - 1; i >= 0; i--) {
    //     this.removeChildAndDestroy(childViews.objectAt(i), immediately);
    //   }

    //   // Recreate our layer (now empty).
    //   this.createLayer();

    //   // Reattach our layer.
    //   if (parentNode && !this.get('isAttached')) { this._doAttach(parentNode); }
    // } else {
      for (i = len - 1; i >= 0; i--) {
        this.removeChildAndDestroy(childViews.objectAt(i), immediately);
      }
    // }

    return this;
  },

  /**
    Removes the view from its parentView, if one is found.  Otherwise
    does nothing.

    @returns {SC.View} receiver
  */
  removeFromParent: function () {
    var parent = this.get('parentView');
    if (parent) { parent.removeChild(this); }

    return this;
  },

  /** @private Observer for child views that are being discarded after transitioning out. */
  _destroyChildView: function (view) {
    // Commence destroying of the view once it is detached.
    if (!view.get('isAttached')) {
      view.removeObserver('isAttached', this, this._destroyChildView);
      view.destroy();
    }
  },

  /** @private Observer for child views that are being orphaned after transitioning out. */
  _orphanChildView: function (view) {
    // Commence orphaning of the view once it is detached.
    if (!view.get('isAttached')) {
      view.removeObserver('isAttached', this, this._orphanChildView);
      view._doOrphan();
    }
  },

  /**
    Completely destroys a view instance so that it may be garbage collected.

    You must call this method on a view to destroy the view (and all of its
    child views). This will remove the view from any parent, detach the
    view's layer from the DOM if it is attached and clear the view's layer
    if it is rendered.

    Once a view is destroyed it can *not* be reused.

    @returns {SC.View} receiver
  */
  destroy: function () {
    // Fast path!
    if (this.get('isDestroyed')) { return this; }

    // Do generic destroy. It takes care of mixins and sets isDestroyed to YES.
    // Do this first, since it cleans up bindings that may apply to parentView
    // (which we will soon null out).
    var ret = arguments.callee.base.apply(this,arguments);

    // If our parent is already destroyed, then we can defer destroying ourself
    // and our own child views momentarily.
    if (this.getPath('parentView.isDestroyed')) {
      // Complete the destroy in a bit.
      this.invokeNext(this._destroy);
    } else {
      // Immediately remove the layer if attached (ignores transitionOut). This
      // will detach the layer for all child views as well.
      if (this.get('isAttached')) {
        this._doDetach(true);
      }

      // Clear the layer if rendered.  This will clear all child views layer
      // references as well.
      if (this.get('_isRendered')) {
        this._doDestroyLayer();
      }

      // Complete the destroy.
      this._destroy();
    }

    // Remove the view from the global hash.
    delete SC.View.views[this.get('layerId')];

    // Destroy any children.  Loop backwards since childViews will shrink.
    var childViews = this.get('childViews');
    for (var i = childViews.length - 1; i >= 0; i--) {
      childViews[i].destroy();
    }

    return ret;
  },

  /** @private */
  _destroy: function () {
    // Orphan the view if adopted.
    this._doOrphan();

    delete this.page;
  },

  /**
    This method is called when your view is first created to setup any  child
    views that are already defined on your class.  If any are found, it will
    instantiate them for you.

    The default implementation of this method simply steps through your
    childViews array, which is expects to either be empty or to contain View
    designs that can be instantiated

    Alternatively, you can implement this method yourself in your own
    subclasses to look for views defined on specific properties and then build
     a childViews array yourself.

    Note that when you implement this method yourself, you should never
    instantiate views directly.  Instead, you should use
    this.createChildView() method instead.  This method can be much faster in
    a production environment than creating views yourself.

    @returns {SC.View} receiver
  */
  createChildViews: function () {
    var childViews = this.get('childViews'),
        len        = childViews.length,
        isNoLongerValid = false,
        idx, key, view;

    this.beginPropertyChanges();

    // swap the array
    for (idx = 0; idx < len; ++idx) {
      key = view = childViews[idx];

      // is this is a key name, lookup view class
      if (typeof key === SC.T_STRING) {
        view = this[key];
      } else {
        key = null;
      }

      if (!view) {
        


        // skip this one.
        isNoLongerValid = true;
        childViews[idx] = null;
        continue;
      }

      // createChildView creates the view if necessary, but also sets
      // important properties, such as parentView
      view = this.createChildView(view);
      if (key) { this[key] = view; } // save on key name if passed

      childViews[idx] = view;
    }

    // Set childViews to be only the valid array.
    if (isNoLongerValid) { this.set('childViews', childViews.compact()); }

    this.endPropertyChanges();
    return this;
  },

  /**
    Instantiates a view to be added to the childViews array during view
    initialization. You generally will not call this method directly unless
    you are overriding createChildViews(). Note that this method will
    automatically configure the correct settings on the new view instance to
    act as a child of the parent.

    If the given view is a class, then createdByParent will be set to true on
    the returned instance.

    @param {Class} view A view class to create or view instance to prepare.
    @param {Object} [attrs={}] attributes to add
    @returns {SC.View} new instance
    @test in createChildViews
  */
  createChildView: function (view, attrs) {
    // Create the view if it is a class.
    if (view.isClass) {
      // attrs should always exist...
      if (!attrs) { attrs = {}; }

      // clone the hash that was given so we do not pollute it if it's being reused
      else { attrs = SC.clone(attrs); }

      // Assign the parentView & page to ourself.
      attrs.parentView = this;
      if (!attrs.page) { attrs.page = this.page; }

      // Track that we created this view.
      attrs.createdByParent = true;

      // Insert the autoMixins if defined
      var applyMixins = this.autoMixins;
      if (!!applyMixins) {
        applyMixins = SC.clone(applyMixins);
        applyMixins.push(attrs);
        view = view.create.apply(view, applyMixins);
      } else {
        view = view.create(attrs);
      }
    // Assign the parentView if the view is an instance.
    // TODO: This should not be accepting view instances, for the purpose of lazy code elsewhere in the framework.
    //       We should ensure users of `createChildViews` are using appendChild and other manipulation methods.
    } else {
      view.set('parentView', this);
      view._adopted();

      if (!view.get('page')) { view.set('page', this.page); }
    }

    return view;
  },

  /** walk like a duck */
  isView: YES,

  /**
    Default method called when a selectstart event is triggered. This event is
    only supported by IE. Used in sproutcore to disable text selection and
    IE8 accelerators. The accelerators will be enabled only in
    text selectable views. In FF and Safari we use the css style 'allow-select'.

    If you want to enable text selection in certain controls is recommended
    to override this function to always return YES , instead of setting
    isTextSelectable to true.

    For example in textfield you do not want to enable textSelection on the text
    hint only on the actual text you are entering. You can achieve that by
    only overriding this method.

    @param evt {SC.Event} the selectstart event
    @returns YES if selectable
  */
  selectStart: function (evt) {
    return this.get('isTextSelectable');
  },

  /**
    Used to block the contextMenu per view.

    @param evt {SC.Event} the contextmenu event
    @returns YES if the contextmenu will be allowed to show up
  */
  contextMenu: function (evt) {
    if (this.get('isContextMenuEnabled')) {
      evt.allowDefault();
      return YES;
    }
  },

  // ------------------------------------------------------------------------
  // Transitions
  //

  /**
    The transition plugin to use when this view is appended to the DOM.

    SC.CoreView uses a pluggable transition architecture where the transition
    setup, execution and cleanup can be handled by a specified transition
    plugin.

    There are a number of pre-built transition plugins available in the
    foundation framework:

      SC.View.BOUNCE_IN
      SC.View.FADE_IN
      SC.View.SLIDE_IN
      SC.View.SCALE_IN
      SC.View.SPRING_IN

    You can even provide your own custom transition plugins.  Just create a
    transition object that conforms to the SC.ViewTransitionProtocol protocol.

    @type Object (SC.ViewTransitionProtocol)
    @default null
    @since Version 1.10
  */
  transitionIn: null,

  /**
    The options for the given transition in plugin.

    These options are specific to the current transition plugin used and are
    used to modify the transition animation.  To determine what options
    may be used for a given plugin and to see what the default options are,
    see the documentation for the transition plugin being used.

    Most transitions will accept a duration and timing option, but may
    also use other options.  For example, SC.View.SLIDE_IN accepts options
    like:

        transitionInOptions: {
          direction: 'left',
          duration: 0.25,
          timing: 'ease-in-out'
        }

    @type Object
    @default null
    @since Version 1.10
  */
  transitionInOptions: null,

  /**
    The transition plugin to use when this view is removed from the DOM.

    SC.View uses a pluggable transition architecture where the transition setup,
    execution and cleanup can be handled by a specified transition plugin.

    There are a number of pre-built transition plugins available in the
    foundation framework:

      SC.View.BOUNCE_OUT
      SC.View.FADE_OUT
      SC.View.SLIDE_OUT
      SC.View.SCALE_OUT
      SC.View.SPRING_OUT

    You can even provide your own custom transition plugins.  Just create a
    transition object that conforms to the SC.ViewTransitionProtocol protocol.

    @type Object (SC.ViewTransitionProtocol)
    @default null
    @since Version 1.10
  */
  transitionOut: null,

  /**
    The options for the given transition out plugin.

    These options are specific to the current transition plugin used and are
    used to modify the transition animation.  To determine what options
    may be used for a given plugin and to see what the default options are,
    see the documentation for the transition plugin being used.

    Most transitions will accept a duration and timing option, but may
    also use other options.  For example, SC.View.SLIDE accepts options
    like:

        transitionOutOptions: {
          direction: 'right',
          duration: 0.15,
          timing: 'ease-in'
        }

    @type Object
    @default null
    @since Version 1.10
  */
  transitionOutOptions: null,

  /**
    The transition plugin to use when this view is made shown from being
    hidden.

    SC.CoreView uses a pluggable transition architecture where the transition setup,
    execution and cleanup can be handled by a specified transition plugin.

    There are a number of pre-built transition plugins available in the
    foundation framework:

      SC.View.BOUNCE_IN
      SC.View.FADE_IN
      SC.View.SLIDE_IN
      SC.View.SCALE_IN
      SC.View.SPRING_IN

    You can even provide your own custom transition plugins.  Just create a
    transition object that conforms to the SC.ViewTransitionProtocol protocol.

    @type Object (SC.ViewTransitionProtocol)
    @default null
    @since Version 1.10
  */
  transitionShow: null,

  /**
    The options for the given transition show plugin.

    These options are specific to the current transition plugin used and are
    used to modify the transition animation.  To determine what options
    may be used for a given plugin and to see what the default options are,
    see the documentation for the transition plugin being used.

    Most transitions will accept a duration and timing option, but may
    also use other options.  For example, SC.View.SLIDE accepts options
    like:

        transitionShowOptions: {
          direction: 'left',
          duration: 0.25,
          timing: 'ease-in-out'
        }

    @type Object
    @default null
    @since Version 1.10
  */
  transitionShowOptions: null,

  /**
    The transition plugin to use when this view is hidden after being shown.

    SC.View uses a pluggable transition architecture where the transition setup,
    execution and cleanup can be handled by a specified transition plugin.

    There are a number of pre-built transition plugins available in the
    foundation framework:

      SC.View.BOUNCE_OUT
      SC.View.FADE_OUT
      SC.View.SLIDE_OUT
      SC.View.SCALE_OUT
      SC.View.SPRING_OUT

    You can even provide your own custom transition plugins.  Just create a
    transition object that conforms to the SC.ViewTransitionProtocol protocol.

    @type Object (SC.ViewTransitionProtocol)
    @default null
    @since Version 1.10
  */
  transitionHide: null,

  /**
    The options for the given transition hide plugin.

    These options are specific to the current transition plugin used and are
    used to modify the transition animation.  To determine what options
    may be used for a given plugin and to see what the default options are,
    see the documentation for the transition plugin being used.

    Most transitions will accept a duration and timing option, but may
    also use other options.  For example, SC.View.SLIDE accepts options
    like:

        transitionHideOptions: {
          direction: 'right',
          duration: 0.15,
          timing: 'ease-in'
        }

    @type Object
    @default null
    @since Version 1.10
  */
  transitionHideOptions: null,

  // ............................................
  // Patches
  //

  /** @private
    Override this method to apply design modes to this view and
    its children.
    @see SC.View
  */
  updateDesignMode: function (lastDesignMode, designMode) {}
});

SC.CoreView.mixin(
  /** @scope SC.CoreView */ {

  /** @private walk like a duck -- used by SC.Page */
  isViewClass: YES,

  /**
    This method works just like extend() except that it will also preserve
    the passed attributes in case you want to use a view builder later, if
    needed.

    @param {Hash} attrs Attributes to add to view
    @returns {Class} SC.View subclass to create
    @function
  */
  design: function () {
    if (this.isDesign) {
      

      return this;
    }

    var ret = this.extend.apply(this, arguments);
    ret.isDesign = YES;
    if (SC.ViewDesigner) {
      SC.ViewDesigner.didLoadDesign(ret, this, SC.A(arguments));
    }
    return ret;
  },

  extend: function () {
    var last = arguments[arguments.length - 1];

    if (last && !SC.none(last.theme)) {
      last.themeName = last.theme;
      delete last.theme;
    }

    return SC.Object.extend.apply(this, arguments);
  },

  /**
    Helper applies the layout to the prototype.
  */
  layout: function (layout) {
    this.prototype.layout = layout;
    return this;
  },

  /**
    Helper applies the classNames to the prototype
  */
  classNames: function (sc) {
    sc = (this.prototype.classNames || []).concat(sc);
    this.prototype.classNames = sc;
    return this;
  },

  /**
    Help applies the tagName
  */
  tagName: function (tg) {
    this.prototype.tagName = tg;
    return this;
  },

  /**
    Helper adds the childView
  */
  childView: function (cv) {
    var childViews = this.prototype.childViews || [];
    if (childViews === this.superclass.prototype.childViews) {
      childViews = childViews.slice();
    }
    childViews.push(cv);
    this.prototype.childViews = childViews;
    return this;
  },

  /**
    Helper adds a binding to a design
  */
  bind: function (keyName, path) {
    var p = this.prototype, s = this.superclass.prototype;
    var bindings = p._bindings;
    if (!bindings || bindings === s._bindings) {
      bindings = p._bindings = (bindings || []).slice();
    }

    keyName = keyName + "Binding";
    p[keyName] = path;
    bindings.push(keyName);

    return this;
  },

  /**
    Helper sets a generic property on a design.
  */
  prop: function (keyName, value) {
    this.prototype[keyName] = value;
    return this;
  },

  /**
    Used to construct a localization for a view.  The default implementation
    will simply return the passed attributes.
  */
  localization: function (attrs, rootElement) {
    // add rootElement
    if (rootElement) attrs.rootElement = SC.$(rootElement)[0];
    return attrs;
  },

  /**
    Creates a view instance, first finding the DOM element you name and then
    using that as the root element.  You should not use this method very
    often, but it is sometimes useful if you want to attach to already
    existing HTML.

    @param {String|Element} element
    @param {Hash} attrs
    @returns {SC.View} instance
  */
  viewFor: function (element, attrs) {
    var args = SC.$A(arguments); // prepare to edit
    if (SC.none(element)) {
      args.shift(); // remove if no element passed
    } else args[0] = { rootElement: SC.$(element)[0] };
    var ret = this.create.apply(this, arguments);
    args = args[0] = null;
    return ret;
  },

  /**
    Create a new view with the passed attributes hash.  If you have the
    Designer module loaded, this will also create a peer designer if needed.
  */
  create: function () {
    var last = arguments[arguments.length - 1];

    if (last && last.theme) {
      last.themeName = last.theme;
      delete last.theme;
    }

    var C = this, ret = new C(arguments);
    if (SC.ViewDesigner) {
      SC.ViewDesigner.didCreateView(ret, SC.$A(arguments));
    }
    return ret;
  },

  /**
    Applies the passed localization hash to the component views.  Call this
    method before you call create().  Returns the receiver.  Typically you
    will do something like this:

    view = SC.View.design({...}).loc(localizationHash).create();

    @param {Hash} loc
    @param rootElement {String} optional rootElement with prepped HTML
    @returns {SC.View} receiver
  */
  loc: function (loc) {
    var childLocs = loc.childViews;
    delete loc.childViews; // clear out child views before applying to attrs

    this.applyLocalizedAttributes(loc);
    if (SC.ViewDesigner) {
      SC.ViewDesigner.didLoadLocalization(this, SC.$A(arguments));
    }

    // apply localization recursively to childViews
    var childViews = this.prototype.childViews, idx = childViews.length,
      viewClass;
    while (--idx >= 0) {
      viewClass = childViews[idx];
      loc = childLocs[idx];
      if (loc && viewClass && typeof viewClass === SC.T_STRING) SC.String.loc(viewClass, loc);
    }

    return this; // done!
  },

  /**
    Internal method actually updates the localized attributes on the view
    class.  This is overloaded in design mode to also save the attributes.
  */
  applyLocalizedAttributes: function (loc) {
    SC.mixin(this.prototype, loc);
  },

  views: {}

});

// .......................................................
// OUTLET BUILDER
//

/**
  Generates a computed property that will look up the passed property path
  the first time you try to get the value.  Use this whenever you want to
  define an outlet that points to another view or object.  The root object
  used for the path will be the receiver.
*/
SC.outlet = function (path, root) {
  return function (key) {
    return (this[key] = SC.objectForPropertyPath(path, (root !== undefined) ? root : this));
  }.property();
};

/** @private on unload clear cached divs. */
SC.CoreView.unload = function () {
  // delete view items this way to ensure the views are cleared.  The hash
  // itself may be owned by multiple view subclasses.
  var views = SC.View.views;
  if (views) {
    for (var key in views) {
      if (!views.hasOwnProperty(key)) continue;
      delete views[key];
    }
  }
};

/**
  @class

  Base class for managing a view.  Views provide two functions:

   1. They display – translating your application's state into drawing
     instructions for the web browser, and
   2. They react – acting as responders for incoming keyboard, mouse, and touch
     events.

  View Basics
  ====

  SproutCore's view layer is made up of a tree of SC.View instances, nested
  using the `childViews` list – usually an array of local property names. You
  position each view by specifying a set of layout keys, like 'left', 'right',
  'width', or 'centerX', in a hash on the layout property. (See the 'layout'
  documentation for more.)

  Other than positioning, SproutCore relies on CSS for all your styling needs.
  Set an array of CSS classes on the `classNames` property, then style them with
  standard CSS. (SproutCore's build tools come with Sass support built in, too.)
  If you have a class that you want automatically added and removed as another
  property changes, take a look at `classNameBindings`.

  Different view classes do different things. The so-called "Big Five" view
  classes are SC.LabelView, for displaying (optionally editable, optionally
  localizable) text; SC.ButtonView, for the user to poke; SC.CollectionView
  (most often as its subclass SC.ListView) for displaying an array of content;
  SC.ContainerView, for easily swapping child views in and out; and SC.ScrollView,
  for containing larger views and allowing them to be scrolled.

  All views live in panes (subclasses of SC.Pane, like SC.MainPane and SC.PanelPane),
  which are parentless views that know how to append themselves directly to the document.
  Panes also serve as routers for events, like mouse, touch and keyboard events, that are
  bound for their views. (See "View Events" below for more.)

  For best performance, you should define your view and pane instances with `extend()`
  inside an SC.Page instance, getting them as needed with `get`. As its name suggests,
  SC.Page's only job is to instantiate views once when first requested, deferring the
  expensive view creation process until each view is needed. Correctly using SC.Page is
  considered an important best practice for high-performance applications.

  View Initialization
  ====

  When a view is setup, there are several methods you can override that
  will be called at different times depending on how your view is created.
  Here is a guide to which method you want to override and when:

   - `init` -- override this method for any general object setup (such as
     observers, starting timers and animations, etc) that you need to happen
     every time the view is created, regardless of whether or not its layer
     exists yet.
   - `render` -- override this method to generate or update your HTML to reflect
     the current state of your view.  This method is called both when your view
     is first created and later anytime it needs to be updated.
   - `update` -- Normally, when a view needs to update its content, it will
     re-render the view using the render() method.  If you would like to
     override this behavior with your own custom updating code, you can
     replace update() with your own implementation instead.
   - `didCreateLayer` -- the render() method is used to generate new HTML.
     Override this method to perform any additional setup on the DOM you might
     need to do after creating the view.  For example, if you need to listen
     for events.
   - `willDestroyLayer` -- if you implement didCreateLayer() to setup event
     listeners, you should implement this method as well to remove the same
     just before the DOM for your view is destroyed.
   - `didAppendToDocument` -- in theory all DOM setup could be done
     in didCreateLayer() as you already have a DOM element instantiated.
     However there is cases where the element has to be first appended to the
     Document because there is either a bug on the browser or you are using
     plugins which objects are not instantiated until you actually append the
     element to the DOM. This will allow you to do things like registering
     DOM events on flash or quicktime objects.
   - `willRemoveFromDocument` -- This method is called on the view immediately
     before its layer is removed from the DOM. You can use this to reverse any
     setup that is performed in `didAppendToDocument`.

  View Events
  ====

  One of SproutCore's optimizations is application-wide event delegation: SproutCore
  handles and standardizes events for you before sending them through your view layer's
  chain of responding views. You should never need to attach event listeners to elements;
  instead, just implement methods like `click`, `doubleClick`, `mouseEntered` and
  `dataDragHover` on your views.

  Note that events generally bubble up an event's responder chain, which is made up of the
  targeted view (i.e. the view whose DOM element received the event), and its chain of
  parentViews up to its pane. (In certain rare cases, you may wish to manipulate the responder
  chain to bypass certain views; you can do so by overriding a view's `nextResponder` property.)

  Simple mouse click events
  ----
  In many situations, all you need are clicks - in which case, just implement `click` or
  `doubleClick` on your views. Note that these events bubble up the responder chain until
  they encounter a view which implements the event method. For example, if a view and its
  parent both implement `click`, the parent will not be notified of the click. (If you want a
  view to handle the event AND allow the event to keep bubbling to its parent views, no
  problem: just be sure to return NO from the event method.)
  - `click` -- Called on a view when the user clicks the mouse on a view. (Note that the view
    on which the user lifts the mouse button will receive the `click` event, regardless of
    whether the user depressed the mouse button elsewhere. If you need finer-grained control
    than this, see "Granular mouse click events" below.)
  - `doubleClick` -- Called on a view when a user has double-clicked it. Double-clicks are
    triggered when two clicks of the same button happen within eight pixels and 250ms of each
    other. (If you need finer-grained control than this, see "Granular mouse click events"
    below.) The same view may receive both `click` and `doubleClick` events.

  Note that defining application behavior directly in event handlers is usually a bad idea; you
  should follow the target/action pattern when possible. See SC.ButtonView and SC.ActionSupport.
  Also note that you will not need to implement event handling yourself on most built-in
  SproutCore controls.

  Note that `click` and `doubleClick` event handlers on your views will not be notified of touch
  events; you must also implement touch handling. See "Touch events" below.

  Mouse movement events
  ----
  SproutCore normalizes (and brings sanity to) mouse movement events by calculating when
  the mouse has entered and exited views, and sending the correct event to each view in
  the responder chain. For example, if a mouse moves within a parent view but crosses from
  one child view to another, the parent view will receive a mouseMoved event while the child
  views will receive mouseEntered and mouseExit events.

  In contrast to mouse click events, mouse movement events are called on the entire responder
  chain regardless of how you handle it along the way - a view and its parent, both implementing
  event methods, will both be notified of the event.

  - `mouseEntered` -- Called when the cursor first enters a view. Called on every view that has
    just entered the responder chain.
  - `mouseMoved` -- Called when the cursor moves over a view.
  - `mouseExited` -- Called when the cursor leaves a view. Called on every view that has
    just exited the responder chain.

  Granular mouse click events
  ----
  If you need more granular handling of mouse click events than what is provided by `click`
  and `doubleClick`, you can handle their atomic components `mouseDown`, `mouseDrag` and
  `mouseUp`. Like the compound events, these events bubble up their responder chain towards
  the pane until they find an event which implements the event handler method. (Again, to
  handle an event but allow it to continue bubbling, just return NO.)

  It bears emphasizing that `mouseDrag` and `mouseUp` events for a given mouse click sequence
  are *only ever called* on the view which successfully responded to the `mouseDown` event. This
  gives `mouseDown` control over which view responder-chain is allowed to handle the entire
  click sequence.

  (Note that because of how events bubble up the responder chain, if a child view implements
  `mouseDown` but not `mouseDrag` or `mouseUp`, those events will bubble to its parent. This
  may cause unexpected behavior if similar events are handled at different parts of your view
  hierarchy, for example if you handle `mouseDown` in a child and a parent, and only handle
  `mouseUp` in the parent.)

  - `mouseDown` -- Called on the target view and responder chain when the user depresses a
    button. A view must implement `mouseDown` (and not return NO) in order to be notified
    of the subsequent drag and up events.
  - `mouseDrag` -- Called on the target view if it handled mouseDown. A view must implement
    mouseDown (and not return NO) in order to receive mouseDrag; only the view which handled a
    given click sequence's mouseDown will receive `mouseDrag` events (and will continue to
    receive them even if the user drags the mouse off of it).
  - `mouseUp` -- Called on the target view when the user lifts a mouse button. A view must
    implement mouseDown (and not return NO) in order to receive mouseUp.

  SproutCore implements a higher-level API for handling in-application dragging and dropping.
  See `SC.Drag`, `SC.DragSourceProtocol`, `SC.DragDataSourceProtocol`, and `SC.DropTargetProtocol`
  for more.

  Data-drag events
  ----
  Browsers implement a parallel system of events for drags which bring something with them: for
  example, dragging text, an image, a URL or (in modern browsers) a file. They behave differently,
  and require different responses from the developer, so SproutCore implements them as a separate
  set of "data drag" events. These behave much like mouse events; the data-drag movement events
  bubble indiscriminately, and the data-drag drop event bubbles until it finds a view which handles
  it (and doesn't return NO).

  By default, SproutCore cancels the default behavior of any data drag event which carries URLs
  or files, as by default these would quit the app and open the dragged item in the browser. If
  you wish to implement data drag-and-drop support in your application, you should set the event's
  dataTransfer.dropEffect property to 'copy' in a `dataDragHovered` event handler.

  - `dataDragEntered` -- Triggered when a data drag enters a view. You can use this handler to
    update the view to visually signal that a drop is possible.
  - `dataDragHovered` -- Triggered when the browser sends a dragover event to a view. If you want
    to support dropping data on your view, you must set the event's `dataTransfer.dropEffect`
    property to 'copy' (or related). Note that `dataDragHovered` is given access to dragenter
    events as well, so you do not need to worry about this in your `dataDragEntered` methods.
  - `dataDragDropped` -- If the last hover event's dropEffect was set correctly, this event will
    give the view access to the data that was dropped. This event bubbles up the responder chain
    until it finds a view which handles it (and doesn't return NO).
  - `dataDragExited` -- Triggered when a data drag leaves a view. You can use this handler to
    update the view to remove the visual drop signal. This event is fired regardless of whether
    a drop occurred.


  Touch events
  ----
  Touch events can be much more complicated than mouse events: multiple touches may be in flight
  at once, and views may wish to handle average touches rather than individual touches.

  Basic support for touch events is required to make your application touch-aware. (You will not
  need to implement touch support for built-in SproutCore controls, which are touch-aware out of
  the box.) The basic touch event handlers are `touchStart` and `touchEnd`; if all you need is
  basic support then you can simply proxy these events to their mouse counterparts.

  The counterpart to `mouseDragged` is `touchesDragged`, which is passed two arguments: a special
  multitouch event object which includes methods for accessing information about all currently
  in-flight touches, and a list of touches active on the current view. If you need to check the
  status of touches currently being handled by other views, the special multitouch event object
  exposes the `touchesForView` method. It also exposes the convenient `averagedTouchesForView`
  method, which gives you easy access to an average touch center and distance. Unlike `mouseDragged`,
  `touchesDragged` does not bubble, being only called on views whic handled `touchStart` for touches
  which have moved.

  To facilitate intuitive behavior in situations like scroll views with touch handlers inside them,
  you may capture a touch from part way up its responder chain before it has a chance to bubble
  up from the target. To capture a touch, expose a method on your view called `captureTouch` which
  accepts the touch as its only argument, and which returns YES if you would like to capture that
  touch. A captured touch will not bubble as normal, instead bubbling up from the capture point. Any
  child views will not have the opportunity to handle the captured event unless you implement custom
  responder swapping yourself.

  Touch events bubble differently than mouse and keyboard events. The initial reverse `captureTouch`
  bubbling is followed by regular `touchStart` bubbling; however, once this process has found a view
  that's willing to respond to the touch, further events are applied only to that view. If a view
  wishes to assign respondership for a touch to a different view, it can call one of several methods
  on the touch object. For a fuller discussion of touch events, touch responder behavior, and the touch
  object itself, see the documentation for SC.Touch.

  Keyboard events
  ----
  The basic key events are `keyDown` and `keyUp`. In order to be notified of keyboard events,
  a view must set `acceptsFirstResponder` to `YES`, and be on an active pane with
  `acceptsKeyPane` set to YES. (You may also need to call `becomeFirstResponder` on your view
  on a `mouseDown`, for example, to focus it. You can verify whether your view has successfully
  received first responder status by checking `isFirstResponder`.)

  Note that key events bubble similarly to mouse click events: they will stop bubbling if they
  encounter a view which handles the event and does not return NO.

  SproutCore implements a set of very convenient, higher-level keyboard events for action keys
  such as *tab*, *enter*, and the arrow keys. These are not triggered automatically, but you
  can gain access to them by proxying the keyboard event of your choice to `interpretKeyEvent`.
  For example:

        // Proxy the keyboard event to SC's built-in interpreter.
        keyDown: function(evt) {
          return this.interpretKeyEvents(evt);
        },
        // The interpreter will trigger the view's `cancel` event if the escape key was pressed.
        cancel: function(evt) {
          console.log('The escape key was pressed.'');
        }

  This will analyze the key press and fire an appropriate event. These events include, but are
  not limited to:

  - `moveUp`, `moveDown`, `moveLeft`, `moveRight` -- The arrow keys
  - `insertNewline` -- The enter key (note the lower-case 'line')
  - `cancel` -- The escape key
  - `insertTab` -- The tab key
  - `insertBacktab` -- Shift + the tab key
  - `moveToBeginningOfDocument` -- The *home* key
  - `moveToEndOfDocument` -- The *end* key
  - `pageUp` and `pageDown`
  - `moveLeftAndModifySelection` -- Shift + the left arrow
  - `selectAll` -- Ctrl + A / Cmd + A

  For a full list of available methods, see the key values on SC.BASE_KEY_BINDINGS and
  SC.MODIFIED_KEY_BINDINGS.

  @extends SC.Responder
  @extends SC.DelegateSupport
  @since SproutCore 1.0

*/
SC.View = SC.CoreView.extend(/** @scope SC.View.prototype */{
  classNames: ['sc-view'],

  displayProperties: [],

  /** @private Enhance. */
  _executeQueuedUpdates: function () {
    arguments.callee.base.apply(this,arguments);

    // Enabled
    // Update the layout style of the layer if necessary.
    if (this._enabledStyleNeedsUpdate) {
      this._doUpdateEnabledStyle();
    }

    // Layout
    // Update the layout style of the layer if necessary.
    if (this._layoutStyleNeedsUpdate) {
      this._doUpdateLayoutStyle();
    }
  },

  /** Apply the attributes to the context. */
  applyAttributesToContext: function (context) {
    // Cursor
    var cursor = this.get('cursor');
    if (cursor) { context.addClass(cursor.get('className')); }

    // Enabled
    if (!this.get('isEnabled')) {
      context.addClass('disabled');
      context.setAttr('aria-disabled', 'true');
    }

    // Layout
    // Have to pass 'true' for second argument for legacy.
    this.renderLayout(context, true);

    if (this.get('useStaticLayout')) { context.addClass('sc-static-layout'); }

    // Background color defaults to null; for performance reasons we should ignore it
    // unless it's ever been non-null.
    var backgroundColor = this.get('backgroundColor');
    if (!SC.none(backgroundColor) || this._scv_hasBackgroundColor) {
      this._scv_hasBackgroundColor = YES;
      if (backgroundColor) context.setStyle('backgroundColor', backgroundColor);
      else context.removeStyle('backgroundColor');
    }

    // Theming
    var theme = this.get('theme');
    var themeClassNames = theme.classNames, idx, len = themeClassNames.length;

    for (idx = 0; idx < len; idx++) {
      context.addClass(themeClassNames[idx]);
    }

    arguments.callee.base.apply(this,arguments);

    var renderDelegate = this.get('renderDelegate');
    if (renderDelegate && renderDelegate.className) {
      context.addClass(renderDelegate.className);
    }

    

  },

  /**
    Computes what the frame of this view would be if the parent were resized
    to the passed dimensions.  You can use this method to project the size of
    a frame based on the resize behavior of the parent.

    This method is used especially by the scroll view to automatically
    calculate when scrollviews should be visible.

    Passing null for the parent dimensions will use the actual current
    parent dimensions.  This is the same method used to calculate the current
    frame when it changes.

    @param {Rect} pdim the projected parent dimensions (optional)
    @returns {Rect} the computed frame
  */
  computeFrameWithParentFrame: function (pdim) {
    // Layout.
    var layout = this.get('layout'),
        f;

    // We can't predict the frame for static layout, so just return the view's
    // current frame (see original computeFrameWithParentFrame in views/view.js)
    if (this.get('useStaticLayout')) {
      f = arguments.callee.base.apply(this,arguments);
      f = f ? this._sc_adjustForBorder(f, layout) : null;
      f = f ? this._sc_adjustForScale(f, layout) : null;
      return f;
    }

    f = {};

    var error, layer, AUTO = SC.LAYOUT_AUTO,
        dH, dW, //shortHand for parentDimensions
        lR = layout.right,
        lL = layout.left,
        lT = layout.top,
        lB = layout.bottom,
        lW = layout.width,
        lH = layout.height,
        lcX = layout.centerX,
        lcY = layout.centerY;

    if (lW === AUTO) {
      SC.throw(("%@.layout() cannot use width:auto if staticLayout is disabled").fmt(this), "%@".fmt(this), -1);
    }

    if (lH === AUTO) {
      SC.throw(("%@.layout() cannot use height:auto if staticLayout is disabled").fmt(this), "%@".fmt(this), -1);
    }

    if (!pdim) { pdim = this.computeParentDimensions(layout); }
    dH = pdim.height;
    dW = pdim.width;

    // handle left aligned and left/right
    if (!SC.none(lL)) {
      if (SC.isPercentage(lL)) {
        f.x = dW * lL;
      } else {
        f.x = lL;
      }

      if (lW !== undefined) {
        if (lW === AUTO) { f.width = AUTO; }
        else if (SC.isPercentage(lW)) { f.width = dW * lW; }
        else { f.width = lW; }
      } else { // better have lR!
        f.width = dW - f.x;
        if (lR && SC.isPercentage(lR)) { f.width = f.width - (lR * dW); }
        else { f.width = f.width - (lR || 0); }
      }

    // handle right aligned
    } else if (!SC.none(lR)) {
      if (SC.none(lW)) {
        if (SC.isPercentage(lR)) {
          f.width = dW - (dW * lR);
        }
        else f.width = dW - lR;
        f.x = 0;
      } else {
        if (lW === AUTO) f.width = AUTO;
        else if (SC.isPercentage(lW)) f.width = dW * lW;
        else f.width = (lW || 0);
        if (SC.isPercentage(lW)) f.x = dW - (lR * dW) - f.width;
        else f.x = dW - lR - f.width;
      }

    // handle centered
    } else if (!SC.none(lcX)) {
      if (lW === AUTO) f.width = AUTO;
      else if (SC.isPercentage(lW)) f.width = lW * dW;
      else f.width = (lW || 0);
      if (SC.isPercentage(lcX)) f.x = (dW - f.width) / 2 + (lcX * dW);
      else f.x = (dW - f.width) / 2 + lcX;
    } else {
      f.x = 0; // fallback
      if (SC.none(lW)) {
        f.width = dW;
      } else {
        if (lW === AUTO) f.width = AUTO;
        if (SC.isPercentage(lW)) f.width = lW * dW;
        else f.width = (lW || 0);
      }
    }

    // handle top aligned and top/bottom
    if (!SC.none(lT)) {
      if (SC.isPercentage(lT)) f.y = lT * dH;
      else f.y = lT;
      if (lH !== undefined) {
        if (lH === AUTO) f.height = AUTO;
        else if (SC.isPercentage(lH)) f.height = lH * dH;
        else f.height = lH;
      } else { // better have lB!
        if (lB && SC.isPercentage(lB)) f.height = dH - f.y - (lB * dH);
        else f.height = dH - f.y - (lB || 0);
      }

    // handle bottom aligned
    } else if (!SC.none(lB)) {
      if (SC.none(lH)) {
        if (SC.isPercentage(lB)) f.height = dH - (lB * dH);
        else f.height = dH - lB;
        f.y = 0;
      } else {
        if (lH === AUTO) f.height = AUTO;
        if (lH && SC.isPercentage(lH)) f.height = lH * dH;
        else f.height = (lH || 0);
        if (SC.isPercentage(lB)) f.y = dH - (lB * dH) - f.height;
        else f.y = dH - lB - f.height;
      }

    // handle centered
    } else if (!SC.none(lcY)) {
      if (lH === AUTO) f.height = AUTO;
      if (lH && SC.isPercentage(lH)) f.height = lH * dH;
      else f.height = (lH || 0);
      if (SC.isPercentage(lcY)) f.y = (dH - f.height) / 2 + (lcY * dH);
      else f.y = (dH - f.height) / 2 + lcY;

    // fallback
    } else {
      f.y = 0; // fallback
      if (SC.none(lH)) {
        f.height = dH;
      } else {
        if (lH === AUTO) f.height = AUTO;
        if (SC.isPercentage(lH)) f.height = lH * dH;
        else f.height = lH || 0;
      }
    }

    f.x = Math.floor(f.x);
    f.y = Math.floor(f.y);
    if (f.height !== AUTO) f.height = Math.floor(f.height);
    if (f.width !== AUTO) f.width = Math.floor(f.width);

    // if width or height were set to auto and we have a layer, try lookup
    if (f.height === AUTO || f.width === AUTO) {
      layer = this.get('layer');
      if (f.height === AUTO) f.height = layer ? layer.clientHeight : 0;
      if (f.width === AUTO) f.width = layer ? layer.clientWidth : 0;
    }

    // Okay we have all our numbers. Let's adjust them for things.

    // First, adjust for border.
    f = this._sc_adjustForBorder(f, layout);

    // Make sure the width/height fix their min/max (note the inlining of SC.none for performance)...
    /*jshint eqnull:true */
    if ((layout.maxHeight != null) && (f.height > layout.maxHeight)) f.height = layout.maxHeight;
    if ((layout.minHeight != null) && (f.height < layout.minHeight)) f.height = layout.minHeight;
    if ((layout.maxWidth != null) && (f.width > layout.maxWidth)) f.width = layout.maxWidth;
    if ((layout.minWidth != null) && (f.width < layout.minWidth)) f.width = layout.minWidth;

    // Finally, adjust for scale.
    f = this._sc_adjustForScale(f, layout);

    return f;
  },

  init: function () {
    arguments.callee.base.apply(this,arguments);

    // Enabled.
    // If the view is pre-configured as disabled, then go to the proper initial state.
    if (!this.get('isEnabled')) { this._doDisable(); }

    // Layout
    this._previousLayout = this.get('layout');

    // Apply the automatic child view layout if it is defined.
    var childViewLayout = this.childViewLayout;
    if (childViewLayout) {
      // Layout the child views once.
      this.set('childViewsNeedLayout', true);
      this.layoutChildViewsIfNeeded();

      // If the child view layout is live, start observing affecting properties.
      if (this.get('isChildViewLayoutLive')) {
        this.addObserver('childViews.[]', this, this._cvl_childViewsDidChange);
        // DISABLED. this.addObserver('childViewLayout', this, this._cvl_childViewLayoutDidChange);
        this.addObserver('childViewLayoutOptions', this, this._cvl_childViewLayoutDidChange);

        // Initialize the child views.
        this._cvl_setupChildViewsLiveLayout();

        // Initialize our own frame observer.
        if (!this.get('isFixedSize') && childViewLayout.layoutDependsOnSize && childViewLayout.layoutDependsOnSize(this)) {
          this.addObserver('frame', this, this._cvl_childViewLayoutDidChange);
        }
      }
    }

    // Theming
    this._lastTheme = this.get('theme');

  },

  /** @private */
  destroy: function () {
    // Clean up.
    this._previousLayout = null;

    return arguments.callee.base.apply(this,arguments);
  },

  /** SC.CoreView.prototype. */
  removeChild: function(view) {
    // Manipulation
    if (!view) { return this; } // nothing to do
    if (view.parentView !== this) {
      throw new Error("%@.removeChild(%@) must belong to parent".fmt(this, view));
    }

    // notify views
    // TODO: Deprecate these notifications.
    if (view.willRemoveFromParent) { view.willRemoveFromParent() ; }
    if (this.willRemoveChild) { this.willRemoveChild(view) ; }

    arguments.callee.base.apply(this,arguments);

    return this;
  }

});

//unload views for IE, trying to collect memory.
if (SC.browser.isIE) SC.Event.add(window, 'unload', SC.View, SC.View.unload);



/* >>>>>>>>>> BEGIN source/child_view_layouts/stack_layout.js */
// ==========================================================================
// Project:   SproutCore
// Copyright: @2013 7x7 Software, Inc.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
sc_require('views/view');

/** @private Shared stack plugin (may be horizontal or vertical). */
function _SC_VIEW_STACK_PLUGIN (direction) {
  this.direction = direction;
}

/** @private Properties to observe on child views that affect the overall child view layout. */
_SC_VIEW_STACK_PLUGIN.prototype.childLayoutProperties = ['marginBefore', 'marginAfter', 'isVisible'];

/** @private When resizeToFit is false, then we need to know when the view's frame changes. */
_SC_VIEW_STACK_PLUGIN.prototype.layoutDependsOnSize = function (view) {
  var options = view.get('childViewLayoutOptions');

  if (options) {
    return SC.none(options.resizeToFit) ? false : !options.resizeToFit;
  } else {
    return false;
  }
};

/** @private */
_SC_VIEW_STACK_PLUGIN.prototype.layoutChildViews = function (view) {
  var childViews = view.get('childViews'),
    options = view.get('childViewLayoutOptions') || {},
    resizeToFit = SC.none(options.resizeToFit) ? true : options.resizeToFit,
    lastMargin = 0, // Used to avoid adding spacing to the final margin.
    marginAfter = options.paddingBefore || 0,
    paddingAfter = options.paddingAfter || 0,
    firstPosition = 0,
    provisionedSpace = 0,
    autoFillAvailableSpace = 0,
    totalAvailableSpace = 0,
    totalFillAvailableSpaceRatio = 0,
    spacing = options.spacing || 0,
    sizeDimension = this.direction === 'vertical' ? 'height' : 'width',
    minSizeDimension = this.direction === 'vertical' ? 'minHeight' : 'minWidth',
    startDimension =  this.direction === 'vertical' ? 'top' : 'left',
    childView,
    fillRatio,
    layout,
    marginBefore,
    i, len;

  // if the view is not configured to resize to fit content, then we give a chance to the children to fill the available space
  // we make a 1st pass to check the conditions, to evaluate the available space and the proportions between children
  if (!resizeToFit) {

    totalAvailableSpace = view.get('frame')[sizeDimension];

    // if the view is not configured to resize and it doesn't have yet a height/width, it doesn't make sense to layout children
    if (!totalAvailableSpace) {
      return;
    }

    for (i = 0, len = childViews.get('length'); i < len; i++) {
      childView = childViews.objectAt(i);

      // Ignore child views with useAbsoluteLayout true, useStaticLayout true or that are not visible.
      if (!childView.get('isVisible') ||
        childView.get('useAbsoluteLayout') ||
        childView.get('useStaticLayout')) {
        continue;
      }

      layout = childView.get('layout');

      // Determine the top/left margin.
      marginBefore = childView.get('marginBefore') || 0;
      provisionedSpace += Math.max(marginAfter, marginBefore);

      // if the height/width is not set, let's check if is possible to resize the view
      if (SC.none(layout[sizeDimension])) {
        fillRatio = childView.get('fillRatio');

        if (!SC.none(fillRatio)) {
          totalFillAvailableSpaceRatio += fillRatio;
        } else {
          // if none of the child views has fillRatio defined, allow the last one to stretch and fill the available space.
          if (i === len - 1 && totalFillAvailableSpaceRatio === 0) {
            totalFillAvailableSpaceRatio = 1;
          }
          

        }
      } else {
        provisionedSpace += childView.get('borderFrame')[sizeDimension];
      }

      // Determine the bottom/right margin.
      lastMargin = childView.get('marginAfter') || 0;
      marginAfter = lastMargin || spacing;
    }

    // consider the end padding when calculating the provisionedSpace
    if (provisionedSpace !== 0 || totalFillAvailableSpaceRatio !== 0) {
      provisionedSpace += Math.max(lastMargin, paddingAfter);
    }

    autoFillAvailableSpace = Math.max(0, totalAvailableSpace - provisionedSpace);
  }

  // reset the references for the effective layout
  lastMargin = 0;
  marginAfter = options.paddingBefore || 0;
  paddingAfter = options.paddingAfter || 0;

  for (i = 0, len = childViews.get('length'); i < len; i++) {
    var size,
      adjustStart,
      adjustEnd;

    childView = childViews.objectAt(i);

    // Ignore child views with useAbsoluteLayout true, useStaticLayout true or that are not visible.
    if (!childView.get('isVisible') ||
      childView.get('useAbsoluteLayout') ||
      childView.get('useStaticLayout')) {
      continue;
    }

    layout = childView.get('layout');

    


    // Determine the top/left margin.
    marginBefore = childView.get('marginBefore') || 0;
    firstPosition += Math.max(marginAfter, marginBefore);

    // Try to avoid useless adjustments to top/left or bottom/right or top/left then bottom/right.
    // The required adjustments will be merged into a single call
    adjustStart = layout[startDimension] !== firstPosition;

    childView.beginPropertyChanges();
    if (!resizeToFit && !layout[sizeDimension]) {
      var endDimension = this.direction === 'vertical' ? 'bottom' : 'right',
          endPosition;

      fillRatio = childView.get('fillRatio');

      // if the last child doesn't define fillRatio, default it to 1 as above during the 1st pass
      if (i === len - 1 && SC.none(fillRatio)) {
        fillRatio = 1;
      }

      // we should get here only in two cases: 1. child defines fillRatio, 2. child defines a minHeight
      // if both defined, we prefer to handle fillRatio, the other case being handled below by the normal adjustment to top/left
      if (!SC.none(fillRatio)) {
        var currentAvailableSpaceRatio = (fillRatio / totalFillAvailableSpaceRatio);

        // calculate the height/width according to fillRatio and totalFillAvailableSpaceRatio
        // but set the bottom/right position so any subsequent layout is not considering the height/width as fixed
        size = Math.ceil(autoFillAvailableSpace * currentAvailableSpaceRatio);

        // INCOMPLETE: We need to flag this view as constrained and re-compute all the auto-fill amounts
        // Constrain the height/width to the maximum height/width allowed.
        // var maxHeight = layout.maxHeight;
        // if (!SC.none(maxHeight)) {
        //   // Constrain the height/width according to maxHeight/maxWidth. Which frees up additional available space for further child views.
        //   if (size > maxSize) {
        //     size = maxSize;
        //   }
        // }

        // Determine the bottom/right position. If the position overflows (i.e. goes negative) because of rounding up, stop at 0.
        endPosition = Math.max(0, totalAvailableSpace - firstPosition - size);
        adjustEnd = layout[endDimension] !== endPosition;

        if (adjustEnd) {
          childView.adjust(endDimension, endPosition);
        }
      }
    }

    if (adjustStart) {
      childView.adjust(startDimension, firstPosition);
    }
    childView.endPropertyChanges();

    firstPosition += childView.get('borderFrame')[sizeDimension];

    // Determine the bottom/right margin.
    lastMargin = childView.get('marginAfter') || 0;
    marginAfter = lastMargin || spacing;
  }

  // If the current size is 0 (all children are hidden), it doesn't make sense to add the padding
  if (firstPosition !== 0) {
    firstPosition += Math.max(lastMargin, paddingAfter);
  }

  // Adjust our frame to fit as well, this ensures that scrolling works.
  if (resizeToFit && view.get('layout')[sizeDimension] !== firstPosition) {
    view.adjust(sizeDimension, firstPosition);
  }
};


SC.mixin(SC.View,
  /** @scope SC.View */ {

  /**
    This child layout plugin automatically positions the view's child views in a
    horizontal stack and optionally adjusts the view's width to fit. It does this
    by checking the width of each child view and positioning the following child
    views accordingly. Afterwards, by default, any time that a child view's
    width or visibility changes, the view will use this plugin to re-adjust all
    following child views' positions and potentially its own width appropriately.

    This allows you to stack absolutely positioned views that dynamically change
    their width and/or visibility without having to resort to using browser
    flow layout.

    For example,

        MyApp.MyView = SC.View.extend({

          // Child views will be stacked in order horizontally.
          childViewLayout: SC.View.HORIZONTAL_STACK,

          // The order of child views is important!
          childViews: ['sectionA', 'sectionB', 'sectionC'],

          // The view will resize itself to fit its children.
          // i.e. We don't need to specify layout.width, this is automatic.
          // The actual layout will become { left: 10, bottom: 20, top: 20, width: 270 } initially.
          layout: { left: 10, bottom: 20, top: 20 },

          sectionA: SC.View.design({

            // We don't need to specify layout.left, this is automatic.
            // The actual layout will become { left: 0, bottom: 0, top: 0, width: 100 } initially.
            layout: { width: 100 }

          }),

          sectionB: SC.View.design({

            // We don't need to specify layout.left, this is automatic.
            // The actual layout will become { border: 1, left: 100, bottom: 0, top: 0, width: 50 } initially.
            layout: { border: 1, width: 50 }

          }),

          sectionC: SC.View.design({

            // We don't need to specify layout.left, this is automatic.
            // The actual layout will become { left: 150, bottom: 10, top: 10, width: 120 } initially.
            layout: { right: 10, top: 10, width: 120 }

          })

        });

    ## Modify the default behavior with `childViewLayoutOptions`

    To modify the plugin behavior for all child view layouts, you can set the
    following child view layout options in `childViewLayoutOptions` on the view:

      - paddingBefore - Adds padding before the first child view.  Default: 0
      - paddingAfter - Adds padding after the last child view.  Default: 0
      - spacing - Adds spacing between each child view.  Default: 0
      - resizeToFit - Whether to resize the view to fit the child views (requires that each child view has a layout width).  Default: true

    For example,

        MyApp.MyView = SC.View.extend({

          // Child views will be stacked in order horizontally.
          childViewLayout: SC.View.HORIZONTAL_STACK,

          // Change the behavior of the HORIZONTAL_STACK plugin
          childViewLayoutOptions: {
            paddingBefore: 10,
            paddingAfter: 20,
            spacing: 5
          },

          // The order of child views is important!
          childViews: ['sectionA', 'sectionB', 'sectionC'],

          // The view will resize itself to fit its children. The actual layout will become { left: 10, bottom: 20, top: 20, width: 310 }
          layout: { left: 10, bottom: 20, top: 20 }, // Don't need to specify layout.width, this is automatic.

          sectionA: SC.View.design({

            // Actual layout will become { left: 10, bottom: 0, top: 0, width: 100 }
            layout: { width: 100 } // Don't need to specify layout.left, this is automatic.

          }),

          sectionB: SC.View.design({

            // Actual layout will become { border: 1, left: 115, bottom: 0, top: 0, width: 50 }
            layout: { border: 1, width: 50 } // Don't need to specify layout.left, this is automatic.

          }),

          sectionC: SC.View.design({

            // Actual layout will become { left: 170, top: 10, bottom: 10, width: 120 }
            layout: { top: 10, bottom: 10, width: 120 } // Don't need to specify layout.left, this is automatic.

          })

        });

    If `resizeToFit` is set to `false`, the view will not adjust itself to fit
    its child views.  This means that when `resizeToFit` is false, the view should
    specify its width component in its layout. A direct effect of this is the
    possibility for the child views to automatically expand or shrink in order to
    fill the empty, unclaimed space of the view.

    This available space is shared between all children that don't specify a fixed width
    such that their final width is calculated proportionally to the value of the
    property `fillRatio`.

    For simplicity, when none of the children specifies `fillRatio`,
    you can ignore the last child view's layout width and the last child view
    will stretch to fill the parent view.

    For example,

        MyApp.MyView = SC.View.extend({

          // Child views will be stacked in order horizontally.
          childViewLayout: SC.View.HORIZONTAL_STACK,

          // Change the behavior of the HORIZONTAL_STACK plugin
          childViewLayoutOptions: {
            paddingBefore: 10,
            paddingAfter: 20,
            spacing: 5,
            resizeToFit: false // Setting this to false, so that the child views stretch/contract to fit the parent's size.
          },

          // The order of child views is important!
          childViews: ['sectionA', 'sectionB', 'sectionC'],

          // The parent view will not resize itself to fit its contents, so we specify the width.
          layout: { left: 10, bottom: 20, top: 20, width: 500 },

          sectionA: SC.View.design({

            // We don't need to specify layout.left, this is automatic. This child will not stretch, its width is set.
            // Actual layout will become { left: 10, bottom: 0, top: 0, width: 100 }
            layout: { width: 100 }

          }),

          sectionB: SC.View.design({

            // The unclaimed space so far is 500 - 10 - 100 - 5 - 5 - 20, or 360px. This space will be shared between
            // the two last sections, because we won't specity a width on them.
            // This view will get 1/3 of the available space, because the other flexibile view has a ratio of 2.
            fillRatio: 1,

            // This section will take 1/3 * 360px = 120px.
            // Actual layout will become { border: 1, left: 115, bottom: 0, top: 0, right: 265 }, in other words, width == 120
            // We don't need to specify layout.left, layout.right or layout.width, this is automatic.
            layout: { border: 1 }

          }),

          sectionC: SC.View.design({

            // This view will get 2/3 of the available space, because the other flexibile view has a ratio of 1.
            fillRatio: 2,

            // This section will take 2/3 * 360px = 240px.
            // Actual layout will become { left: 240, top: 10, bottom: 10, right: 20 }, in other words, width == 240
            // We don't need to specify layout.left, layout.right or layout.width, this is automatic.
            layout: { top: 10, bottom: 10 }

          })

        });

    ## Modify specific child view layouts

    To adjust the child layout on a granular level per child view, you can
    also set the following properties on each child view:

      - marginBefore - Specify the minimum spacing above the child view.
      - marginAfter - Specify the minimum spacing below the child view.
      - useAbsoluteLayout - Don't include this child view in automatic layout, use absolute positioning based on the child view's `layout` property.
      - useStaticLayout - Don't include this child view in automatic layout.  This child view uses relative positioning and is not eligible for automatic layout.
      - isVisible - Non-visible child views are not included in the stack.
      - fillRatio - When the parent view is configured with a fixed dimension, children not specifying a width but specifying fillRatio will be resized to fill the unclaimed space proportionally to this ratio.

      For example,

        MyApp.MyView = SC.View.extend({

          // Child views will be stacked in order horizontally.
          childViewLayout: SC.View.HORIZONTAL_STACK,

          // Actual layout will become { left: 10, right: 10, top: 20, width: 570 }
          layout: { left: 10, right: 10, top: 20 },

          // Keep the child views ordered!
          childViews: ['sectionA', 'float', 'sectionB', 'sectionC'],

          sectionA: SC.View.design({
            // Actual layout will become { left: 0, right: 50, top: 0, width: 100 }
            layout: { right: 50, width: 100 },
            // The following child view will be at least 50px further right.
            marginAfter: 50
          }),

          float: SC.View.design({
            // This view will not be included in automatic layout and will not effect the stack.
            layout: { top: 5, right: 5, height: 50, width: 50 },
            useAbsoluteLayout: true
          }),

          sectionB: SC.View.design({
            // Actual layout will become { left: 1500, right: 0, top: 0, width: 120 }
            layout: { width: 120 }
          }),

          sectionC: SC.View.design({
            // Actual layout will become { left: 470, bottom: 0, top: 0, width: 100 }
            layout: { width: 100 },
            // This child view will be at least 200px to the right of the previous.
            marginBefore: 200
          })

        });

    ### A Note About Spacing

    Note that the spacing attribute in `childViewLayoutOptions` becomes the
    _minimum margin between child views, without explicitly overriding it from
    both sides using `marginAfter` and `marginBefore`_.  For example, if `spacing`
    is 25, setting `marginAfter` to 10 on a child view will not result in the
    next child view being 10px to the right of it, unless the next child view also
    specified `marginBefore` as 10.

    What this means is that it takes less configuration if you set `spacing` to
    be the _smallest margin you wish to exist between child views_ and then use
    the overrides to grow the margin if necessary.  For example, if `spacing`
    is 5, setting `marginAfter` to 10 on a child view will result in the next
    child view being 10px to the right of it, without having to also specify
    `marginBefore` on that next child view.

    @extends SC.ChildViewLayoutProtocol
    @since Version 1.10
  */
  HORIZONTAL_STACK: new _SC_VIEW_STACK_PLUGIN('horizontal'),

  /**
    This child layout plugin automatically positions the view's child views in a
    vertical stack and optionally adjusts the view's height to fit.  It does this
    by checking the height of each child view and positioning the following child
    view accordingly.  Afterwards, by default, any time that a child view's
    height or visibility changes, the view will use this plugin to re-adjust all
    following child views' positions and potentially its own height appropriately.

    This allows you to stack absolutely positioned views that dynamically change
    their height and/or visibility without having to resort to using browser
    flow layout.

    A typical usage scenario is a long "form" made of multiple subsection
    views.  If we want to adjust the height of a subsection, to make space for
    an error label for example, it would be a lot of work to manually
    reposition all the following sections below it.  A much easier to code and
    cleaner solution is to just set the childViewLayout plugin on the wrapper
    view.

    For example,

        MyApp.MyView = SC.View.extend({

          // Child views will be stacked in order vertically.
          childViewLayout: SC.View.VERTICAL_STACK,

          // The order of child views is important!
          childViews: ['sectionA', 'sectionB', 'sectionC'],

          // The view will resize itself to fit its children.
          // i.e. We don't need to specify layout.height, this is automatic.
          // The actual layout will become { left: 10, right: 10, top: 20, height: 270 } initially.
          layout: { left: 10, right: 10, top: 20 },

          sectionA: SC.View.design({

            // We don't need to specify layout.top, this is automatic.
            // The actual layout will become { left: 0, right: 0, top: 0, height: 100 } initially.
            layout: { height: 100 }

          }),

          sectionB: SC.View.design({

            // We don't need to specify layout.top, this is automatic.
            // The actual layout will become { border: 1, left: 0, right: 0, top: 100, height: 50 } initially.
            layout: { border: 1, height: 50 }

          }),

          sectionC: SC.View.design({

            // We don't need to specify layout.top, this is automatic.
            // The actual layout will become { left: 10, right: 10, top: 150, height: 120 } initially.
            layout: { left: 10, right: 10, height: 120 }

          })

        });

    ## Modify the default behavior with `childViewLayoutOptions`

    To modify the plugin behavior for all child view layouts, you can set the
    following child view layout options in `childViewLayoutOptions` on the view:

      - paddingBefore - Adds padding before the first child view.  Default: 0
      - paddingAfter - Adds padding after the last child view.  Default: 0
      - spacing - Adds spacing between each child view.  Default: 0
      - resizeToFit - Whether to resize the view to fit the child views (requires that each child view has a layout height).  Default: true

    For example,

        MyApp.MyView = SC.View.extend({

          // Child views will be stacked in order vertically.
          childViewLayout: SC.View.VERTICAL_STACK,

          // Change the behavior of the VERTICAL_STACK plugin
          childViewLayoutOptions: {
            paddingBefore: 10,
            paddingAfter: 20,
            spacing: 5
          },

          // The order of child views is important!
          childViews: ['sectionA', 'sectionB', 'sectionC'],

          // The actual layout will become { left: 10, right: 10, top: 20, height: 310 } initially.
          layout: { left: 10, right: 10, top: 20 }, // Don't need to specify layout.height, this is automatic.

          sectionA: SC.View.design({

            // We don't need to specify layout.top, this is automatic.
            // The actual layout will become { left: 0, right: 0, top: 10, height: 100 } initially.
            layout: { height: 100 }

          }),

          sectionB: SC.View.design({

            // We don't need to specify layout.top, this is automatic.
            // The actual layout will become { border: 1, left: 0, right: 0, top: 115, height: 50 } initially.
            layout: { border: 1, height: 50 }

          }),

          sectionC: SC.View.design({

            // We don't need to specify layout.top, this is automatic.
            // The actual layout will become { left: 10, right: 10, top: 170, height: 120 } initially.
            layout: { left: 10, right: 10, height: 120 }

          })

        });

    If `resizeToFit` is set to `false`, the view will not adjust itself to fit
    its child views.  This means that when `resizeToFit` is false, the view should
    specify its height component in its layout. A direct effect is the possibility for
    the child views to automatically extend or shrink in order to fill the empty, unclaimed space.
    This available space is shared between the children not specifying a fixed height
    and their final dimension is calculated proportionally to the value of the
    property `fillRatio`.
    For simplicity, when none of the children specifies `fillRatio`,
    you can ignore the last child view's layout height if you want the last child view
    to stretch to fill the parent view.

    For example,

        MyApp.MyView = SC.View.extend({

          // Child views will be stacked in order vertically.
          childViewLayout: SC.View.VERTICAL_STACK,

          // Change the behavior of the VERTICAL_STACK plugin
          childViewLayoutOptions: {
            paddingBefore: 10,
            paddingAfter: 20,
            spacing: 5,
            resizeToFit: false
          },

          // The order of child views is important!
          childViews: ['sectionA', 'sectionB', 'sectionC'],

          // Actual layout will become { left: 10, right: 10, top: 20, height: 500 }
          layout: { left: 10, right: 10, top: 20, height: 500 }, // Need to specify layout.height.

          sectionA: SC.View.design({

            // We don't need to specify layout.top, this is automatic. This child will not stretch, its height is set.
            // The actual layout will become { left: 0, right: 0, top: 10, height: 100 } initially.
            layout: { height: 100 }

          }),

          sectionB: SC.View.design({

            // The unclaimed space so far is 500 - 10 - 100 - 5 - 5 - 20, or 360px. This space will be shared between
            // the two last sections, because we won't specity a height on them.
            // This view will get 1/3 of the available space, because the other flexibile view has a ratio of 2.
            fillRatio: 1,

            // This section will take 1/3 * 360px = 120px.
            // Actual layout will become { border: 1, left: 0, right: 0, top: 115, bottom: 265 }, in other words, height == 120
            // We don't need to specify layout.top, layout.bottom or layout.height, this is automatic.
            layout: { border: 1 }

          }),

          sectionC: SC.View.design({

            // This view will get 2/3 of the available space, because the other flexibile view has a ratio of 1.
            fillRatio: 2,

            // This section will take 2/3 * 360px = 240px.
            // Actual layout will become { left: 10, right: 10, top: 240, bottom: 20 }, in other words, height == 240
            // We don't need to specify layout.top, layout.bottom or layout.height, this is automatic.
            layout: { left: 10, right: 10 }

          })

        });

    ## Modify specific child view layouts

    To adjust the child layout on a granular level per child view, you can
    also set the following properties on each child view:

      - marginBefore - Specify the minimum spacing above the child view.
      - marginAfter - Specify the minimum spacing below the child view.
      - useAbsoluteLayout - Don't include this child view in automatic layout, use absolute positioning based on the child view's `layout` property.
      - useStaticLayout - Don't include this child view in automatic layout.  This child view uses relative positioning and is not eligible for automatic layout.
      - isVisible - Non-visible child views are not included in the stack.
      - fillRatio - When the parent view is configured with a fixed dimension, children not specifying a height but specifying fillRatio will be resized to fill the unclaimed space proportionally to this ratio.

    For example,

        MyApp.MyView = SC.View.extend({

          // Child views will be stacked in order vertically.
          childViewLayout: SC.View.VERTICAL_STACK,

          // Actual layout will become { left: 10, right: 10, top: 20, height: 570 }
          layout: { left: 10, right: 10, top: 20 },

          // Keep the child views ordered!
          childViews: ['sectionA', 'float', 'sectionB', 'sectionC'],

          sectionA: SC.View.design({
            // Actual layout will become { left: 0, right: 50, top: 0, height: 100 }
            layout: { right: 50, height: 100 },
            // The following child view will be at least 50px further down.
            marginAfter: 50
          }),

          float: SC.View.design({
            // This view will not be included in automatic layout and will not effect the stack.
            layout: { top: 5, right: 5, width: 50, height: 50 },
            useAbsoluteLayout: true
          }),

          sectionB: SC.View.design({
            // Actual layout will become { left: 0, right: 0, top: 150, height: 120 }
            layout: { height: 120 }
          }),

          sectionC: SC.View.design({
            // Actual layout will become { left: 0, bottom: 0, top: 470, height: 100 }
            layout: { height: 100 },
            // This child view will be at least 200px below the previous.
            marginBefore: 200
          })

        });

    ### A Note About Spacing

    Note that the spacing attribute in `childViewLayoutOptions` becomes the
    _minimum margin between child views, without explicitly overriding it from
    both sides using `marginAfter` and `marginBefore`_.  For example, if `spacing`
    is 25, setting `marginAfter` to 10 on a child view will not result in the
    next child view being 10px below it, unless the next child view also
    specified `marginBefore` as 10.

    What this means is that it takes less configuration if you set `spacing` to
    be the _smallest margin you wish to exist between child views_ and then use
    the overrides to grow the margin if necessary.  For example, if `spacing`
    is 5, setting `marginAfter` to 10 on a child view will result in the next
    child view being 10px below it, without having to also specify `marginBefore`
    on that next child view.

    @extends SC.ChildViewLayoutProtocol
    @since Version 1.10
  */
  VERTICAL_STACK: new _SC_VIEW_STACK_PLUGIN('vertical')

});

/* >>>>>>>>>> BEGIN source/controllers/controller.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @class

  The controller base class provides some common functions you will need
  for controllers in your applications, especially related to maintaining
  an editing context.

  In general you will not use this class, but you can use a subclass such
  as ObjectController, TreeController, or ArrayController.

  ## EDITING CONTEXTS

  One major function of a controller is to mediate between changes in the
  UI and changes in the model.  In particular, you usually do not want
  changes you make in the UI to be applied to a model object directly.
  Instead, you often will want to collect changes to an object and then
  apply them only when the user is ready to commit their changes.

  The editing contact support in the controller class will help you
  provide this capability.

  @extends SC.Object
  @since SproutCore 1.0
*/
SC.Controller = SC.Object.extend(
/** @scope SC.Controller.prototype */ {

  /**
    Makes a controller editable or not editable.  The SC.Controller class
    itself does not do anything with this property but subclasses will
    respect it when modifying content.

    @type Boolean
  */
  isEditable: YES,

  /**
   * Set this to YES if you are setting the controller content to a recordArray
   * or other content that needs to be cleaned up (with `.destroy()`) when
   * new content is set.
   */
  destroyContentOnReplace: NO,

  contentObjectDidChanged: function() {
    var oldContent, newContent;

    if (!this.get('destroyContentOnReplace')) return;

    oldContent = this._oldContent;
    newContent = this.get('content');
    if (oldContent && newContent !== oldContent && oldContent.destroy) {
      oldContent.destroy();
    }
    this._oldContent = newContent;
  }.observes('content')

});

/* >>>>>>>>>> BEGIN source/mixins/selection_support.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
/**
  @namespace

  Implements common selection management properties for controllers.

  Selection can be managed by any controller in your applications.  This
  mixin provides some common management features you might want such as
  disabling selection, or restricting empty or multiple selections.

  To use this mixin, simply add it to any controller you want to manage
  selection and call updateSelectionAfterContentChange()
  whenever your source content changes.  You can also override the properties
  defined below to configure how the selection management will treat your
  content.

  This mixin assumes the arrangedObjects property will return an SC.Array of
  content you want the selection to reflect.

  Add this mixin to any controller you want to manage selection.  It is
  already applied to SC.ArrayController.

  @since SproutCore 1.0
*/
SC.SelectionSupport = {

  // ..........................................................
  // PROPERTIES
  //
  /**
    Walk like a duck.

    @type Boolean
  */
  hasSelectionSupport: YES,

  /**
    If YES, selection is allowed. Default is YES.

    @type Boolean
  */
  allowsSelection: YES,

  /**
    If YES, multiple selection is allowed. Default is YES.

    @type Boolean
  */
  allowsMultipleSelection: YES,

  /**
    If YES, allow empty selection Default is YES.

    @type Boolean
  */
  allowsEmptySelection: YES,

  /**
    Override to return the first selectable object.  For example, if you
    have groups or want to otherwise limit the kinds of objects that can be
    selected.

    the default implementation returns firstObject property.

    @returns {Object} first selectable object
  */
  firstSelectableObject: function() {
    return this.get('firstObject');
  }.property(),

  /**
    This is the current selection.  You can make this selection and another
    controller's selection work in concert by binding them together. You
    generally have a master selection that relays changes TO all the others.

    @property {SC.SelectionSet}
  */
  selection: function(key, value) {
    var old = this._scsel_selection,
    oldlen = old ? old.get('length') : 0,
    empty,
    arrangedObjects = this.get('arrangedObjects'),
    len;

    // whenever we have to recompute selection, reapply all the conditions to
    // the selection.  This ensures that changing the conditions immediately
    // updates the selection.
    //
    // Note also if we don't allowSelection, we don't clear the old selection;
    // we just don't allow it to be changed.
    if ((value === undefined) || !this.get('allowsSelection')) { value = old; }

    len = (value && value.isEnumerable) ? value.get('length') : 0;

    // if we don't allow multiple selection
    if ((len > 1) && !this.get('allowsMultipleSelection')) {

      if (oldlen > 1) {
        value = SC.SelectionSet.create().addObject(old.get('firstObject')).freeze();
        len = 1;
      } else {
        value = old;
        len = oldlen;
      }
    }

    // if we don't allow empty selection, block that also, unless we
    // have nothing to select.  select first selectable item if necessary.
    if ((len === 0) && !this.get('allowsEmptySelection') && arrangedObjects && arrangedObjects.get('length') !== 0) {
      if (oldlen === 0) {
        value = this.get('firstSelectableObject');
        if (value) { value = SC.SelectionSet.create().addObject(value).freeze(); }
        else { value = SC.SelectionSet.EMPTY; }
        len = value.get('length');

      } else {
        value = old;
        len = oldlen;
      }
    }

    // if value is empty or is not enumerable, then use empty set
    if (len === 0) { value = SC.SelectionSet.EMPTY; }

    // always use a frozen copy...
    if(value !== old) value = value.frozenCopy();
    this._scsel_selection = value;

    return value;

  }.property('arrangedObjects', 'allowsEmptySelection', 'allowsMultipleSelection', 'allowsSelection').cacheable(),

  /**
    YES if the receiver currently has a non-zero selection.

    @type Boolean
  */
  hasSelection: function() {
    var sel = this.get('selection');
    return !! sel && (sel.get('length') > 0);
  }.property('selection').cacheable(),

  // ..........................................................
  // METHODS
  //
  /**
    Selects the passed objects in your content.  If you set "extend" to YES,
    then this will attempt to extend your selection as well.

    @param {SC.Enumerable} objects objects to select
    @param {Boolean} extend optionally set to YES to extend selection
    @returns {Object} receiver
  */
  selectObjects: function(objects, extend) {

    // handle passing an empty array
    if (!objects || objects.get('length') === 0) {
      if (!extend) { this.set('selection', SC.SelectionSet.EMPTY); }
      return this;
    }

    var sel = this.get('selection');
    if (extend && sel) { sel = sel.copy(); }
    else { sel = SC.SelectionSet.create(); }

    sel.addObjects(objects).freeze();
    this.set('selection', sel);
    return this;
  },

  /**
    Selects a single passed object in your content.  If you set "extend" to
    YES then this will attempt to extend your selection as well.

    @param {Object} object object to select
    @param {Boolean} extend optionally set to YES to extend selection
    @returns {Object} receiver
  */
  selectObject: function(object, extend) {
    if (object === null) {
      if (!extend) { this.set('selection', null); }
      return this;

    } else { return this.selectObjects([object], extend); }
  },

  /**
    Deselects the passed objects in your content.

    @param {SC.Enumerable} objects objects to select
    @returns {Object} receiver
  */
  deselectObjects: function(objects) {

    if (!objects || objects.get('length') === 0) { return this; } // nothing to do
    var sel = this.get('selection');
    if (!sel || sel.get('length') === 0) { return this; } // nothing to do
    // find index for each and remove it
    sel = sel.copy().removeObjects(objects).freeze();
    this.set('selection', sel.freeze());
    return this;
  },

  /**
    Deselects the passed object in your content.

    @param {SC.Object} object single object to select
    @returns {Object} receiver
  */
  deselectObject: function(object) {
    if (!object) { return this; } // nothing to do
    else { return this.deselectObjects([object]); }
  },

  /**
    Call this method whenever your source content changes to ensure the
    selection always remains up-to-date and valid.

    @returns {Object}
  */
  updateSelectionAfterContentChange: function() {
    var arrangedObjects = this.get('arrangedObjects');
    var selectionSet = this.get('selection');
    var allowsEmptySelection = this.get('allowsEmptySelection');
    var indexSet; // Selection index set for arranged objects

    // If we don't have any selection, there's nothing to update
    if (!selectionSet) { return this; }
    // Remove any selection set objects that are no longer in the content
    indexSet = selectionSet.indexSetForSource(arrangedObjects);
    if ((indexSet && (indexSet.get('length') !== selectionSet.get('length'))) || (!indexSet && (selectionSet.get('length') > 0))) { // then the selection content has changed
      if (arrangedObjects) {
        // Constrain the current selection set to matches in arrangedObjects.
        selectionSet = selectionSet.copy().constrain(arrangedObjects).freeze();
      } else {
        // No arrangedObjects, so clear the selection.
        selectionSet = SC.SelectionSet.EMPTY;
      }
      this.set('selection', selectionSet);
    }

    // Reselect an object if required (if content length > 0)
    if ((selectionSet.get('length') === 0) && arrangedObjects && (arrangedObjects.get('length') > 0) && !allowsEmptySelection) {
      this.selectObject(this.get('firstSelectableObject'), NO);
    }

    return this;
  }

};

/* >>>>>>>>>> BEGIN source/controllers/array.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('controllers/controller');
sc_require('mixins/selection_support');

/**
  @class

  An ArrayController provides a way for you to publish an array of objects
  for CollectionView or other controllers to work with.  To work with an
  ArrayController, set the content property to the array you want the
  controller to manage.  Then work directly with the controller object as if
  it were the array itself.

  When you want to display an array of objects in a CollectionView, bind the
  "arrangedObjects" of the array controller to the CollectionView's "content"
  property.  This will automatically display the array in the collection view.

  @extends SC.Controller
  @extends SC.Array
  @extends SC.SelectionSupport
  @author Charles Jolley
  @since SproutCore 1.0
*/
SC.ArrayController = SC.Controller.extend(SC.Array, SC.SelectionSupport,
/** @scope SC.ArrayController.prototype */ {

  


  // ..........................................................
  // PROPERTIES
  //

  /**
    The content array managed by this controller.

    You can set the content of the ArrayController to any object that
    implements SC.Array or SC.Enumerable.  If you set the content to an object
    that implements SC.Enumerable only, you must also set the orderBy property
    so that the ArrayController can order the enumerable for you.

    If you set the content to a non-enumerable and non-array object, then the
    ArrayController will wrap the item in an array in an attempt to normalize
    the result.

    @type SC.Array
  */
  content: null,

  /**
    Makes the array editable or not.  If this is set to NO, then any attempts
    at changing the array content itself will throw an exception.

    @type Boolean
  */
  isEditable: YES,

  /**
    Used to sort the array.

    If you set this property to a key name, array of key names, or a function,
    then then ArrayController will automatically reorder your content array
    to match the sort order.  When using key names, you may specify the
    direction of the sort by appending ASC or DESC to the key name.  By default
    sorting is done in ascending order.

    For example,

        myController.set('orderBy', 'title DESC');
        myController.set('orderBy', ['lastName ASC', 'firstName DESC']);

    Normally, you should only use this property if you set the content of the
    controller to an unordered enumerable such as SC.Set or SC.SelectionSet.
    In this case the orderBy property is required in order for the controller
    to property order the content for display.

    If you set the content to an array, it is usually best to maintain the
    array in the proper order that you want to display things rather than
    using this method to order the array since it requires an extra processing
    step.  You can use this orderBy property, however, for displaying smaller
    arrays of content.

    Note that you can only use addObject() to insert new objects into an
    array that is ordered.  You cannot manually reorder or insert new objects
    into specific locations because the order is managed by this property
    instead.

    If you pass a function, it should be suitable for use in compare().

    @type String|Array|Function
  */
  orderBy: null,

  /**
    Set to YES if you want the controller to wrap non-enumerable content
    in an array and publish it.  Otherwise, it will treat single content like
    null content.

    @type Boolean
  */
  allowsSingleContent: YES,

  /**
    Set to YES if you want objects removed from the array to also be
    deleted.  This is a convenient way to manage lists of items owned
    by a parent record object.

    Note that even if this is set to NO, calling destroyObject() instead of
    removeObject() will still destroy the object in question as well as
    removing it from the parent array.

    @type Boolean
  */
  destroyOnRemoval: NO,

  /**
    Returns an SC.Array object suitable for use in a CollectionView.
    Depending on how you have your ArrayController configured, this property
    may be one of several different values.

    @type SC.Array
  */
  arrangedObjects: function () {
    return this;
  }.property().cacheable(),

  /**
    Computed property indicates whether or not the array controller can
    remove content.  You can delete content only if the content is not single
    content and isEditable is YES.

    @type Boolean
  */
  canRemoveContent: function () {
    var content = this.get('content'), ret;
    ret = !!content && this.get('isEditable') && this.get('hasContent');
    if (ret) {
      return !content.isEnumerable ||
             (SC.typeOf(content.removeObject) === SC.T_FUNCTION);
    } else return NO;
  }.property('content', 'isEditable', 'hasContent'),

  /**
    Computed property indicates whether you can reorder content.  You can
    reorder content as long a the controller isEditable and the content is a
    real SC.Array-like object.  You cannot reorder content when orderBy is
    non-null.

    @type Boolean
  */
  canReorderContent: function () {
    var content = this.get('content'), ret;
    ret = !!content && this.get('isEditable') && !this.get('orderBy');
    return ret && !!content.isSCArray;
  }.property('content', 'isEditable', 'orderBy'),

  /**
    Computed property insides whether you can add content.  You can add
    content as long as the controller isEditable and the content is not a
    single object.

    Note that the only way to simply add object to an ArrayController is to
    use the addObject() or pushObject() methods.  All other methods imply
    reordering and will fail.

    @type Boolean
  */
  canAddContent: function () {
    var content = this.get('content'), ret;
    ret = content && this.get('isEditable') && content.isEnumerable;
    if (ret) {
      return (SC.typeOf(content.addObject) === SC.T_FUNCTION) ||
             (SC.typeOf(content.pushObject) === SC.T_FUNCTION);
    } else return NO;
  }.property('content', 'isEditable'),

  /**
    Set to YES if the controller has valid content that can be displayed,
    even an empty array.  Returns NO if the content is null or not enumerable
    and allowsSingleContent is NO.

    @type Boolean
  */
  hasContent: function () {
    var content = this.get('content');
    return !!content &&
           (!!content.isEnumerable || !!this.get('allowsSingleContent'));
  }.property('content', 'allowSingleContent'),

  /**
    Returns the current status property for the content.  If the content does
    not have a status property, returns SC.Record.READY.

    @type Number
  */
  status: function () {
    var content = this.get('content'),
        ret = content ? content.get('status') : null;
    return ret ? ret : SC.Record.READY;
  }.property().cacheable(),

  // ..........................................................
  // METHODS
  //

  /**
    Adds an object to the array.  If the content is ordered, this will add the
    object to the end of the content array.  The content is not ordered, the
    location depends on the implementation of the content.

    If the source content does not support adding an object, then this method
    will throw an exception.

    @param {Object} object The object to add to the array.
    @returns {SC.ArrayController} The receiver.
  */
  addObject: function (object) {
    if (!this.get('canAddContent')) { throw new Error("%@ cannot add content".fmt(this)); }

    var content = this.get('content');
    if (content.isSCArray) { content.pushObject(object); }
    else if (content.addObject) { content.addObject(object); }
    else { throw new Error("%@.content does not support addObject".fmt(this)); }

    return this;
  },

  /**
    Removes the passed object from the array.  If the underlying content
    is a single object, then this simply sets the content to null.  Otherwise
    it will call removeObject() on the content.

    Also, if destroyOnRemoval is YES, this will actually destroy the object.

    @param {Object} object the object to remove
    @returns {SC.ArrayController} receiver
  */
  removeObject: function (object) {
    if (!this.get('canRemoveContent')) {
      throw new Error("%@ cannot remove content".fmt(this));
    }

    var content = this.get('content');
    if (content.isEnumerable) {
      content.removeObject(object);
    } else {
      this.set('content', null);
    }

    if (this.get('destroyOnRemoval') && object.destroy) { object.destroy(); }
    return this;
  },

  // ..........................................................
  // SC.ARRAY SUPPORT
  //

  /**
    Compute the length of the array based on the observable content

    @type Number
  */
  length: function () {
    var content = this._scac_observableContent();
    return content ? content.get('length') : 0;
  }.property().cacheable(),

  /** @private
    Returns the object at the specified index based on the observable content
  */
  objectAt: function (idx) {
    var content = this._scac_observableContent();
    return content ? content.objectAt(idx) : undefined;
  },

  /** @private
    Forwards a replace on to the content, but only if reordering is allowed.
  */
  replace: function (start, amt, objects) {
    // check for various conditions before a replace is allowed
    if (!objects || objects.get('length') === 0) {
      if (!this.get('canRemoveContent')) {
        throw new Error("%@ cannot remove objects from the current content".fmt(this));
      }
    } else if (!this.get('canReorderContent')) {
      throw new Error("%@ cannot add or reorder the current content".fmt(this));
    }

    // if we can do this, then just forward the change.  This should fire
    // updates back up the stack, updating rangeObservers, etc.
    var content = this.get('content'); // note: use content, not observable
    var objsToDestroy = [], i, objsLen;

    if (this.get('destroyOnRemoval')) {
      for (i = 0; i < amt; i++) {
        objsToDestroy.push(content.objectAt(i + start));
      }
    }

    if (content) { content.replace(start, amt, objects); }

    for (i = 0, objsLen = objsToDestroy.length; i < objsLen; i++) {

      objsToDestroy[i].destroy();
    }
    objsToDestroy = null;

    return this;
  },

  indexOf: function (object, startAt) {
    var content = this._scac_observableContent();
    return content ? content.indexOf(object, startAt) : -1;
  },

  // ..........................................................
  // INTERNAL SUPPORT
  //

  /** @private */
  init: function () {
    arguments.callee.base.apply(this,arguments);
    this._scac_contentDidChange();
  },

  /** @private
    Cached observable content property.  Set to NO to indicate cache is
    invalid.
  */
  _scac_cached: NO,

  /**
    @private

    Returns the current array this controller is actually managing.  Usually
    this should be the same as the content property, but sometimes we need to
    generate something different because the content is not a regular array.

    @returns {SC.Array} observable or null
  */
  _scac_observableContent: function () {
    var ret = this._scac_cached;
    if (ret) { return ret; }

    var content = this.get('content'), func, order;

    // empty content
    if (SC.none(content)) { return (this._scac_cached = []); }

    // wrap non-enumerables
    if (!content.isEnumerable) {
      ret = this.get('allowsSingleContent') ? [content] : [];
      return (this._scac_cached = ret);
    }

    // no-wrap
    var orderBy = this.get('orderBy');
    if (!orderBy) {
      if (content.isSCArray) { return (this._scac_cached = content); }
      else { throw new Error("%@.orderBy is required for unordered content".fmt(this)); }
    }

    // all remaining enumerables must be sorted.

    // build array - then sort it
    var type = SC.typeOf(orderBy);

    if (type === SC.T_STRING) {
      orderBy = [orderBy];
    } else if (type === SC.T_FUNCTION) {
      func = orderBy;
    } else if (type !== SC.T_ARRAY) {
      throw new Error("%@.orderBy must be Array, String, or Function".fmt(this));
    }

    // generate comparison function if needed - use orderBy
    func = func || function (a, b) {
      var status, key, match, valueA, valueB;

      for (var i = 0, l = orderBy.get('length'); i < l && !status; i++) {
        key = orderBy.objectAt(i);

        if (key.search(/(ASC|DESC)/) === 0) {
          

          match = key.match(/^(ASC )?(DESC )?(.*)$/);
          key = match[3];
        } else {
          match = key.match(/^(\S*)\s*(DESC)?(?:ASC)?$/);
          key = match[1];
        }
        order = match[2] ? -1 : 1;

        if (a) { valueA = a.isObservable ? a.get(key) : a[key]; }
        if (b) { valueB = b.isObservable ? b.get(key) : b[key]; }

        status = SC.compare(valueA, valueB) * order;
      }

      return status;
    };

    return (this._scac_cached = content.toArray().sort(func));
  },

  propertyWillChange: function (key) {
    if (key === 'content') {
      this.arrayContentWillChange(0, this.get('length'), 0);
    } else {
      return arguments.callee.base.apply(this,arguments);
    }
  },

  _scac_arrayContentWillChange: function (start, removed, added) {
    // Repoint arguments if orderBy is present. (If orderBy is present, we can't be sure how any content change
    // translates into an arrangedObject change without calculating the order, which is a complex, potentially
    // expensive operation, so we simply invalidate everything.)
    if (this.get('orderBy')) {
      var len = this.get('length');
      start = 0;
      added = len + added - removed;
      removed = len;
    }

    // Continue.
    this.arrayContentWillChange(start, removed, added);
    if (this._kvo_enumerable_property_chains) {
      var removedObjects = this.slice(start, start + removed);
      this.teardownEnumerablePropertyChains(removedObjects);
    }
  },

  _scac_arrayContentDidChange: function (start, removed, added) {
    this._scac_cached = NO;

    // Repoint arguments if orderBy is present. (If orderBy is present, we can't be sure how any content change
    // translates into an arrangedObject change without calculating the order, which is a complex, potentially
    // expensive operation, so we simply invalidate everything.)
    if (this.get('orderBy')) {
      var len = this.get('length');
      start = 0;
      added = len + added - removed;
      removed = len;
    }

    // Notify range, firstObject, lastObject and '[]' observers.
    this.arrayContentDidChange(start, removed, added);

    if (this._kvo_enumerable_property_chains) {
      var addedObjects = this.slice(start, start + added);
      this.setupEnumerablePropertyChains(addedObjects);
    }
    this.updateSelectionAfterContentChange();
  },

  /** @private
    Whenever content changes, setup and teardown observers on the content
    as needed.
  */
  _scac_contentDidChange: function () {
    this._scac_cached = NO; // invalidate observable content
    var content     = this.get('content'),
        lastContent = this._scac_content,
        didChange   = this._scac_arrayContentDidChange,
        willChange  = this._scac_arrayContentWillChange,
        sfunc       = this._scac_contentStatusDidChange,
        efunc       = this._scac_enumerableDidChange,
        newlen;

    if (content === lastContent) { return this; } // nothing to do

    // teardown old observer
    if (lastContent) {
      if (lastContent.isSCArray) {
        lastContent.removeArrayObservers({
          target: this,
          didChange: didChange,
          willChange: willChange
        });
      } else if (lastContent.isEnumerable) {
        lastContent.removeObserver('[]', this, efunc);
      }

      lastContent.removeObserver('status', this, sfunc);

      this.teardownEnumerablePropertyChains(lastContent);
    }

    // save new cached values
    this._scac_cached = NO;
    this._scac_content = content;

    // setup new observer
    // also, calculate new length.  do it manually instead of using
    // get(length) because we want to avoid computed an ordered array.
    if (content) {
      // Content is an enumerable, so listen for changes to its
      // content, and get its length.
      if (content.isSCArray) {
        content.addArrayObservers({
          target: this,
          didChange: didChange,
          willChange: willChange
        });

        newlen = content.get('length');
      } else if (content.isEnumerable) {
        content.addObserver('[]', this, efunc);
        newlen = content.get('length');
      } else {
        // Assume that someone has set a non-enumerable as the content, and
        // treat it as the sole member of an array.
        newlen = 1;
      }

      // Observer for changes to the status property, in case this is an
      // SC.Record or SC.RecordArray.
      content.addObserver('status', this, sfunc);

      this.setupEnumerablePropertyChains(content);
    } else {
      newlen = SC.none(content) ? 0 : 1;
    }

    // finally, notify enumerable content has changed.
    this._scac_length = newlen;
    this._scac_contentStatusDidChange();

    this.arrayContentDidChange(0, 0, newlen);
    this.updateSelectionAfterContentChange();
  }.observes('content'),

  /** @private
    Whenever enumerable content changes, need to regenerate the
    observableContent and notify that the range has changed.

    This is called whenever the content enumerable changes or whenever orderBy
    changes.
  */
  _scac_enumerableDidChange: function () {
    var content = this.get('content'), // use content directly
        newlen  = content ? content.get('length') : 0,
        oldlen  = this._scac_length;

    this._scac_length = newlen;
    this._scac_cached = NO; // invalidate
    // If this is an unordered enumerable, we have no way
    // of knowing which indices changed. Instead, we just
    // invalidate the whole array.
    this.arrayContentWillChange(0, oldlen, newlen);
    this.arrayContentDidChange(0, oldlen, newlen);
    this.updateSelectionAfterContentChange();
  }.observes('orderBy'),

  /** @private
    Whenever the content "status" property changes, relay out.
  */
  _scac_contentStatusDidChange: function () {
    this.notifyPropertyChange('status');
  }

});

/* >>>>>>>>>> BEGIN source/controllers/object.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('controllers/controller') ;

/** @class

  An ObjectController gives you a simple way to manage the editing state of
  an object.  You can use an ObjectController instance as a "proxy" for your
  model objects.

  Any properties you get or set on the object controller, will be passed
  through to its content object.  This allows you to setup bindings to your
  object controller one time for all of your views and then swap out the
  content as needed.

  ## Working with Arrays

  An ObjectController can accept both arrays and single objects as content.
  If the content is an array, the ObjectController will do its best to treat
  the array as a single object.  For example, if you set the content of an
  ObjectController to an array of Contact records and then call:

      contactController.get('name');

  The controller will check the name property of each Contact in the array.
  If the value of the property for each Contact is the same, that value will
  be returned.  If the any values are different, then an array will be
  returned with the values from each Contact in them.

  Most SproutCore views can work with both arrays and single content, which
  means that most of the time, you can simply hook up your views and this will
  work.

  If you would prefer to make sure that your ObjectController is always
  working with a single object and you are using bindings, you can always
  setup your bindings so that they will convert the content to a single object
  like so:

      contentBinding: SC.Binding.single('MyApp.listController.selection') ;

  This will ensure that your content property is always a single object
  instead of an array.

  @extends SC.Controller
  @since SproutCore 1.0
*/
SC.ObjectController = SC.Controller.extend(
/** @scope SC.ObjectController.prototype */ {

  


  // ..........................................................
  // PROPERTIES
  //

  /**
    Set to the object you want this controller to manage.  The object should
    usually be a single value; not an array or enumerable.  If you do supply
    an array or enumerable with a single item in it, the ObjectController
    will manage that single item.

    Usually your content object should implement the SC.Observable mixin, but
    this is not required.  All SC.Object-based objects support SC.Observable

    @type Object
  */
  content: null,

  /**
    If YES, then setting the content to an enumerable or an array with more
    than one item will cause the Controller to attempt to treat the array as
    a single object.  Use of get(), for example, will get every property on
    the enumerable and return it.  set() will set the property on every item
    in the enumerable.

    If NO, then setting content to an enumerable with multiple items will be
    treated like setting a null value.  hasContent will be NO.

    @type Boolean
  */
  allowsMultipleContent: NO,

  /**
    Becomes YES whenever this object is managing content.  Usually this means
    the content property contains a single object or an array or enumerable
    with a single item.  Array's or enumerables with multiple items will
    normally make this property NO unless allowsMultipleContent is YES.

    @type Boolean
  */
  hasContent: function() {
    return !SC.none(this.get('observableContent'));
  }.property('observableContent'),

  /**
    Makes a controller editable or not editable.  The SC.Controller class
    itself does not do anything with this property but subclasses will
    respect it when modifying content.

    @type Boolean
  */
  isEditable: YES,

  /**
    Primarily for internal use.  Normally you should not access this property
    directly.

    Returns the actual observable object proxied by this controller.  Usually
    this property will mirror the content property.  In some cases - notably
    when setting content to an enumerable, this may return a different object.

    Note that if you set the content to an enumerable which itself contains
    enumerables and allowsMultipleContent is NO, this will become null.

    @type Object
  */
  observableContent: function() {
    var content = this.get('content'),
        len, allowsMultiple;

    // if enumerable, extract the first item or possibly become null
    if (content && content.isEnumerable) {
      len = content.get('length');
      allowsMultiple = this.get('allowsMultipleContent');

      if (len === 1) content = content.firstObject();
      else if (len===0 || !allowsMultiple) content = null;

      // if we got some new content, it better not be enum also...
      if (content && !allowsMultiple && content.isEnumerable) content=null;
    }

    return content;
  }.property('content', 'allowsMultipleContent').cacheable(),

  // ..........................................................
  // METHODS
  //

  /**
    Override this method to destroy the selected object.

    The default just passes this call onto the content object if it supports
    it, and then sets the content to null.

    Unlike most calls to destroy() this will not actually destroy the
    controller itself; only the the content.  You continue to use the
    controller by setting the content to a new value.

    @returns {SC.ObjectController} receiver
  */
  destroy: function() {
    var content = this.get('observableContent') ;
    if (content && SC.typeOf(content.destroy) === SC.T_FUNCTION) {
      content.destroy();
    }
    this.set('content', null) ;
    return this;
  },

  /**
    Invoked whenever any property on the content object changes.

    The default implementation will simply notify any observers that the
    property has changed.  You can override this method if you need to do
    some custom work when the content property changes.

    If you have set the content property to an enumerable with multiple
    objects and you set allowsMultipleContent to YES, this method will be
    called anytime any property in the set changes.

    If all properties have changed on the content or if the content itself
    has changed, this method will be called with a key of "*".

    @param {Object} target the content object
    @param {String} key the property that changes
    @returns {void}
  */
  contentPropertyDidChange: function(target, key) {
    if (key === '*') this.allPropertiesDidChange();
    else this.notifyPropertyChange(key);
  },

  /**
    Called whenver you try to get/set an unknown property.  The default
    implementation will pass through to the underlying content object but
    you can override this method to do some other kind of processing if
    needed.

    @param {String} key key being retrieved
    @param {Object} value value to set or undefined if reading only
    @returns {Object} property value
  */
  unknownProperty: function(key,value) {

    // avoid circular references
    if (key==='content') {
      if (value !== undefined) this.content = value;
      return this.content;
    }

    // for all other keys, just pass through to the observable object if
    // there is one.  Use getEach() and setEach() on enumerable objects.
    var content = this.get('observableContent'), loc, cur, isSame;
    if (content===null || content===undefined) return undefined; // empty

    // getter...
    if (value === undefined) {
      if (content.isEnumerable) {
        value = content.getEach(key);

        // iterate over array to see if all values are the same. if so, then
        // just return that value
        loc = value.get('length');
        if (loc>0) {
          isSame = YES;
          cur = value.objectAt(0);
          while((--loc > 0) && isSame) {
            if (cur !== value.objectAt(loc)) isSame = NO ;
          }
          if (isSame) value = cur;
        } else value = undefined; // empty array.

      } else value = (content.isObservable) ? content.get(key) : content[key];

    // setter
    } else {
      if (!this.get('isEditable')) {
        throw new Error("%@.%@ is not editable".fmt(this,key));
      }

      if (content.isEnumerable) content.setEach(key, value);
      else if (content.isObservable) content.set(key, value);
      else content[key] = value;
    }

    return value;
  },

  // ...............................
  // INTERNAL SUPPORT
  //

  /** @private - setup observer on init if needed. */
  init: function() {
    arguments.callee.base.apply(this,arguments);
    if (this.get('content')) this._scoc_contentDidChange();
    if (this.get('observableContent')) this._scoc_observableContentDidChange();
  },

  _scoc_contentDidChange: function () {
    var last = this._scoc_content,
        cur  = this.get('content');

    if (last !== cur) {
      this._scoc_content = cur;
      var func = this._scoc_enumerableContentDidChange;
      if (last && last.isEnumerable) {
        last.removeObserver('[]', this, func);
      }
      if (cur && cur.isEnumerable) {
        cur.addObserver('[]', this, func);
      }
    }
  }.observes("content"),

  /**  @private

    Called whenever the observable content property changes.  This will setup
    observers on the content if needed.
  */
  _scoc_observableContentDidChange: function() {
    var last = this._scoc_observableContent,
        cur  = this.get('observableContent'),
        func = this.contentPropertyDidChange,
        efunc= this._scoc_enumerableContentDidChange;

    if (last === cur) return this; // nothing to do
    //console.log('observableContentDidChange');

    this._scoc_observableContent = cur; // save old content

    // stop observing last item -- if enumerable stop observing set
    if (last) {
      if (last.isEnumerable) last.removeObserver('[]', this, efunc);
      else if (last.isObservable) last.removeObserver('*', this, func);
    }

    if (cur) {
      if (cur.isEnumerable) cur.addObserver('[]', this, efunc);
      else if (cur.isObservable) cur.addObserver('*', this, func);
    }

    // notify!
    if ((last && last.isEnumerable) || (cur && cur.isEnumerable)) {
      this._scoc_enumerableContentDidChange();
    } else {
      this.contentPropertyDidChange(cur, '*');
    }

  }.observes("observableContent"),

  /** @private
    Called when observed enumerable content has changed.  This will teardown
    and setup observers on the enumerable content items and then calls
    contentPropertyDidChange().  This method may be called even if the new
    'cur' is not enumerable but the last content was enumerable.
  */
  _scoc_enumerableContentDidChange: function() {
    var cur  = this.get('observableContent'),
        set  = this._scoc_observableContentItems,
        func = this.contentPropertyDidChange;

    // stop observing each old item
    if (set) {
      set.forEach(function(item) {
        if (item.isObservable) item.removeObserver('*', this, func);
      }, this);
      set.clear();
    }

    // start observing new items if needed
    if (cur && cur.isEnumerable) {
      if (!set) set = SC.Set.create();
      cur.forEach(function(item) {
        if (set.contains(item)) return ; // nothing to do
        set.add(item);
        if (item.isObservable) item.addObserver('*', this, func);
      }, this);
    } else set = null;

    this._scoc_observableContentItems = set; // save for later cleanup

    // notify
    this.contentPropertyDidChange(cur, '*');
    return this ;
  }

}) ;

/* >>>>>>>>>> BEGIN source/ext/function.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

SC.mixin(Function.prototype, /** @scope Function.prototype */ {

  /**
    Creates a timer that will execute the function after a specified 
    period of time.
    
    If you pass an optional set of arguments, the arguments will be passed
    to the function as well.  Otherwise the function should have the 
    signature:
    
        function functionName(timer)

    @param target {Object} optional target object to use as this
    @param interval {Number} the time to wait, in msec
    @returns {SC.Timer} scheduled timer
  */
  invokeLater: function(target, interval) {
    if (interval === undefined) interval = 1 ;
    var f = this;
    if (arguments.length > 2) {
      var args = SC.$A(arguments).slice(2,arguments.length);
      args.unshift(target);
      // f = f.bind.apply(f, args) ;
      var func = f ;
      // Use "this" in inner func because it get its scope by 
      // outer func f (=target). Could replace "this" with target for clarity.
      f = function() { return func.apply(this, args.slice(1)); } ;
    }
    return SC.Timer.schedule({ target: target, action: f, interval: interval });
  }

});

/* >>>>>>>>>> BEGIN source/ext/object.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

// Extensions to the core SC.Object class
SC.mixin(SC.Object.prototype, /** @scope SC.Object.prototype */ {

  /**
    Invokes the named method after the specified period of time.  This
    uses SC.Timer, which works properly with the Run Loop.

    Any additional arguments given to invokeOnce will be passed to the
    method.

    For example,

        var obj = SC.Object.create({
          myMethod: function(a, b, c) {
            alert('a: %@, b: %@, c: %@'.fmt(a, b, c));
          }
        });

        obj.invokeLater('myMethod', 200, 'x', 'y', 'z');

        // After 200 ms, alerts "a: x, b: y, c: z"

    @param method {String} method name to perform.
    @param interval {Number} period from current time to schedule.
    @returns {SC.Timer} scheduled timer.
  */
  invokeLater: function(method, interval) {
    var f, args;

    // Normalize the method and interval.
    if (SC.typeOf(method) === SC.T_STRING) { method = this[method]; }
    if (interval === undefined) { interval = 1 ; }

    // If extra arguments were passed - build a function binding.
    if (arguments.length > 2) {
      args = SC.$A(arguments).slice(2);
      f = function() { return method.apply(this, args); } ;
    } else {
      f = method;
    }

    // schedule the timer
    return SC.Timer.schedule({ target: this, action: f, interval: interval });
  },

  /**
    A convenience method which makes it easy to coalesce invocations to ensure
    that the method is only called once after the given period of time. This is
    useful if you need to schedule a call from multiple places, but only want
    it to run at most once.

    Any additional arguments given to invokeOnceLater will be passed to the
    method.

    For example,

        var obj = SC.Object.create({
          myMethod: function(a, b, c) {
            alert('a: %@, b: %@, c: %@'.fmt(a, b, c));
          }
        });

        obj.invokeOnceLater('myMethod', 200, 'x', 'y', 'z');

        // After 200 ms, alerts "a: x, b: y, c: z"

    @param {Function|String} method reference or method name
    @param {Number} interval
  */
  invokeOnceLater: function(method, interval) {
    var args, f,
        methodGuid,
        timers = this._sc_invokeOnceLaterTimers,
        existingTimer, newTimer;

    // Normalize the method, interval and timers cache.
    if (SC.typeOf(method) === SC.T_STRING) { method = this[method]; }
    if (interval === undefined) { interval = 1 ; }
    if (!timers) { timers = this._sc_invokeOnceLaterTimers = {}; }

    // If there's a timer outstanding for this method, invalidate it in favor of
    // the new timer.
    methodGuid = SC.guidFor(method);
    existingTimer = timers[methodGuid];
    if (existingTimer) existingTimer.invalidate();

    // If extra arguments were passed - apply them to the method.
    if (arguments.length > 2) {
      args = SC.$A(arguments).slice(2);
    } else {
      args = arguments;
    }

    // Create a function binding every time, so that the timers cache is properly cleaned out.
    f = function() {
      // GC assistance for IE
      delete timers[methodGuid];
      return method.apply(this, args);
    };

    // Schedule the new timer and track it.
    newTimer = SC.Timer.schedule({ target: this, action: f, interval: interval });
    timers[methodGuid] = newTimer;

    return newTimer;
  },

  /**
    Lookup the named property path and then invoke the passed function,
    passing the resulting value to the function.

    This method is a useful way to handle deferred loading of properties.
    If you want to defer loading a property, you can override this method.
    When the method is called, passing a deferred property, you can load the
    property before invoking the callback method.

    You can even swap out the receiver object.

    The callback method should have the signature:

    function callback(objectAtPath, sourceObject) { ... }

    You may pass either a function itself or a target/method pair.

    @param {String} pathName
    @param {Object} target target or method
    @param {Function|String} method
    @returns {SC.Object} receiver
  */
  invokeWith: function(pathName, target, method) {
    // normalize target/method
    if (method === undefined) {
      method = target; target = this;
    }
    if (!target) { target = this ; }
    if (SC.typeOf(method) === SC.T_STRING) { method = target[method]; }

    // get value
    var v = this.getPath(pathName);

    // invoke method
    method.call(target, v, this);
    return this ;
  }

});

/* >>>>>>>>>> BEGIN source/ext/run_loop.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

// Create anonymous subclass of SC.RunLoop to add support for processing
// view queues and Timers.
SC.RunLoop = SC.RunLoop.extend(
/** @scope SC.RunLoop.prototype */ {

  /**
    The time the current run loop began executing.

    All timers scheduled during this run loop will begin executing as if
    they were scheduled at this time.

    @type Number
  */
  startTime: function() {
    if (!this._start) { this._start = Date.now(); }
    return this._start ;
  }.property(),

  /*

    Override to fire and reschedule timers once per run loop.

    Note that timers should fire only once per run loop to avoid the
    situation where a timer might cause an infinite loop by constantly
    rescheduling itself every time it is fired.
  */
  endRunLoop: function() {
    this.fireExpiredTimers(); // fire them timers!
    var ret = arguments.callee.base.apply(this,arguments); // do everything else
    this.scheduleNextTimeout(); // schedule a timeout if timers remain
    return ret;
  },

  // ..........................................................
  // TIMER SUPPORT
  //

  /**
    Schedules a timer to execute at the specified runTime.  You will not
    usually call this method directly.  Instead you should work with SC.Timer,
    which will manage both creating the timer and scheduling it.

    Calling this method on a timer that is already scheduled will remove it
    from the existing schedule and reschedule it.

    @param {SC.Timer} timer the timer to schedule
    @param {Time} runTime the time offset when you want this to run
    @returns {SC.RunLoop} receiver
  */
  scheduleTimer: function(timer, runTime) {
    // if the timer is already in the schedule, remove it.
    this._timerQueue = timer.removeFromTimerQueue(this._timerQueue);

    // now, add the timer ot the timeout queue.  This will walk down the
    // chain of timers to find the right place to insert it.
    this._timerQueue = timer.scheduleInTimerQueue(this._timerQueue, runTime);
    return this ;
  },

  /**
    Removes the named timer from the timeout queue.  If the timer is not
    currently scheduled, this method will have no effect.

    @param {SC.Timer} timer the timer to schedule
    @returns {SC.RunLoop} receiver
  */
  cancelTimer: function(timer) {
    this._timerQueue = timer.removeFromTimerQueue(this._timerQueue) ;
    return this ;
  },

  /** @private - shared array used by fireExpiredTimers to avoid memory */
  TIMER_ARRAY: [],

  /**
    Invokes any timers that have expired since this method was last called.
    Usually you will not call this method directly, but it will be invoked
    automatically at the end of the run loop.

    @returns {Boolean} YES if timers were fired, NO otherwise
  */
  fireExpiredTimers: function() {
    if (!this._timerQueue || this._firing) { return NO; } // nothing to do

    // max time we are allowed to run timers
    var now = this.get('startTime'),
        timers = this.TIMER_ARRAY,
        idx, len, didFire;

    // avoid recursive calls
    this._firing = YES;

    // collect timers to fire.  we do this one time up front to avoid infinite
    // loops where firing a timer causes it to schedule itself again, causing
    // it to fire again, etc.
    this._timerQueue = this._timerQueue.collectExpiredTimers(timers, now);

    // now step through timers and fire them.
    len = timers.length;
    for(idx=0;idx<len;idx++) { timers[idx].fire(); }

    // cleanup
    didFire = timers.length > 0 ;
    timers.length = 0 ; // reset for later use...
    this._firing = NO ;
    return didFire;
  },

  /** @private
    Invoked at the end of a runloop, if there are pending timers, a timeout
    will be scheduled to fire when the next timer expires.  You will not
    usually call this method yourself.  It is invoked automatically at the
    end of a run loop.

    @returns {Boolean} YES if a timeout was scheduled
  */
  scheduleNextTimeout: function() {
    var ret = NO,
      timer = this._timerQueue;

    // if no timer, and there is an existing timeout, attempt to cancel it.
    // NOTE: if this happens to be an invokeNext based timer, it will not be
    // cancelled.
    if (!timer) {
      if (this._timerTimeout) { this.unscheduleRunLoop(); }
      this._timerTimeout = null;

    // otherwise, determine if the timeout needs to be rescheduled.
    } else {
      var nextTimeoutAt = timer._timerQueueRunTime ;
      this._timerTimeout = this.scheduleRunLoop(nextTimeoutAt);
      ret = YES;
    }

    return ret ;
  }

});

// Recreate the currentRunLoop with the new methods
SC.RunLoop.currentRunLoop = SC.RunLoop.create();
SC.RunLoop.runLoopClass = SC.RunLoop;

/* >>>>>>>>>> BEGIN source/ext/string.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('system/string');

SC.supplement(String.prototype,
/** @scope String.prototype */ {

  /**
    @see SC.String.capitalize
  */
  capitalize: function() {
    return SC.String.capitalize(this, arguments);
  },

  /**
    @see SC.String.camelize
  */
  camelize: function() {
    return SC.String.camelize(this, arguments);
  },

  /**
    @see SC.String.decamelize
  */
  decamelize: function() {
    return SC.String.decamelize(this, arguments);
  },

  /**
    @see SC.String.dasherize
  */
  dasherize: function() {
    return SC.String.dasherize(this, arguments);
  },

  /**
    @see SC.String.escapeCssIdForSelector
  */
  escapeCssIdForSelector: function () {
    return SC.String.escapeCssIdForSelector(this);
  },

  /**
    @see SC.String.loc
  */
  loc: function() {
    var args = SC.$A(arguments);
    args.unshift(this);
    return SC.String.loc.apply(SC.String, args);
  },

  /**
    @see SC.String.locWithDefault
  */
  locWithDefault: function(def) {
    var args = SC.$A(arguments);
    args.unshift(this);
    return SC.String.locWithDefault.apply(SC.String, args);
  },
  
  /**
    @see SC.String.mult
  */
  mult: function(value) {
    return SC.String.mult(this, value);
  }

});


/* >>>>>>>>>> BEGIN source/lproj/ordinal.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
 * Returns the ordinal associated for the current number.
 */
SC.methodForLocale('en', 'ordinalForNumber', function(number) {
  var d = number % 10;
  return (~~ (number % 100 / 10) === 1) ? 'th' :
         (d === 1) ? 'st' :
         (d === 2) ? 'nd' :
         (d === 3) ? 'rd' : 'th';
});
/* >>>>>>>>>> BEGIN source/mixins/action_support.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @class

  Implements basic target + action support for views. To use, simply set the `action` property on
  the view to the name of a method handled by an object in the current responder chain and call
  `fireAction`. If the `target` property is also set, the `action` will only be attempted on that
  target object. If not set, then the responder chain will be searched for an object that implements
  the named action.

  *Note* Because searching the responder chain is slower, it is recommended to specify an actual
  target whenever possible.

  ### Implementing Actions in a Target

  The method signature for target + action implementors is,

      methodName: function (sender, context) {
        return; // Optional: return a value to the sender.
      }

  For views implementing `SC.ActionSupport`, the `sender` will always be `this`, which can be useful
  when an action may be called by multiple views and the target needs to know from which view it was
  triggered. For example, here is an action that will hide the sender's (any sender's) pane,

      // Hides the pane of the current sender.
      hidePane: function (sender) {
        var pane = sender.get('pane');
        pane.set('isVisible', false);
      }

  In order to pass additional information to the target, the target's action method may accept a
  second argument, `context`. This argument will be the value of the same-named `context` argument
  passed to `fireAction()` of the view. Here is a simple example to help illustrate this,

      // Target
      var theTargetObject = SC.Object.create({

        theActionMethod: function (sender, context) {
          console.log("theActionMethod was called at: %@".fmt(context.calledAt))
        }

      });

      // View with SC.ActionSupport
      var view = SC.View.create(SC.ActionSupport, {
        action: 'theActionMethod',
        target: theTargetObject,

        someEvent: function () {
          var addedContext = {
            calledAt: new Date() // Calling specific information to pass to the target.
          };

          this.fireAction(addedContext);
        }

      });

  @since SproutCore 1.7
*/
SC.ActionSupport =
/** @scope SC.ActionSupport.prototype */ {

  


  /**
    The name of the method to call when `fireAction` is called.

    This property is used in conjunction with the `target` property to execute a method when
    `fireAction` is called. If you do not specify a target, then the responder chain will be
    searched for a view that implements the named action. If you do set a target, then the button
    will only try to call the method on that target.

    The action method of the target should implement the following signature:

        methodName: function (sender, context) {
          return; // Optional: return a value to the sender.
        }

    ### Supporting multiple actions

    The most correct way to handle variable properties in SproutCore is to use a computed property.
    For example, imagine if the action depended on a property, `isReady`. While we could set
    `action` accordingly each time prior to calling `fireAction()` like so,

        mouseUp: function () {
          var isReady = this.get('isReady');

          if (isReady) {
            this.set('action', 'doReadyAction');
          } else {
            this.set('action', 'doNotReadyAction');
          }

          this.fireAction();
        }

    This is a bit wasteful (imagine `isReady` doesn't change very often) and leaves `action` in
    an improper state (i.e. what if `isReady` changes without a call to mouseUp, then `action` is
    incorrect for any code that may reference it).

    The better approach is to make `action` a computed property dependent on `isReady`.

    For example, the previous example would be better as,

        action: function () {
          return this.get('isReady') ? 'doReadyAction' : 'doNotReadyAction';
        }.property('isReady'), // .cacheable() - optional to cache the result (consider memory used to cache result vs. computation time to compute result)

        mouseUp: function () {
          this.fireAction(); // Fires with current value of `action`.
        }

    @type String
    @default null
  */
  action: null,

  /** @deprecated Version 1.11.0. Please specify `context` argument when calling fireAction method.
    @type Object
    @default null
  */
  actionContext: null,

  /**
    The target to invoke the action on when `fireAction` is called.

    If you set this target, the action will be called on the target object directly when the button
    is clicked.  If you leave this property set to `null`, then the responder chain will be
    searched for a view that implements the action when the button is pressed.

    The action method of the target should implement the following signature:

        methodName: function (sender, context) {
          return; // Optional: return a value to the sender.
        }

    ### Supporting multiple targets

    The most correct way to handle variable properties in SproutCore is to use a computed property.
    For example, imagine if the target depended on a property, `isReady`. While we could set
    `target` accordingly each time prior to calling `fireAction()` like so,

        mouseUp: function () {
          var isReady = this.get('isReady');

          if (isReady) {
            this.set('target', MyApp.readyTarget);
          } else {
            this.set('target', MyApp.notReadyTarget);
          }

          this.fireAction();
        }

    This is a bit wasteful (imagine `isReady` doesn't change very often) and leaves `target` in
    an improper state (i.e. what if `isReady` changes without a call to mouseUp, then `target` is
    incorrect for any code that may reference it).

    The better approach is to make `target` a computed property dependent on `isReady`.

    For example, the previous example would be better as,

        target: function () {
          return this.get('isReady') ? MyApp.readyTarget : MyApp.notReadyTarget;
        }.property('isReady'), // .cacheable() - optional to cache the result (consider memory used to cache result vs. computation time to compute result)

        mouseUp: function () {
          this.fireAction(); // Fires with current value of `target`.
        }

    @type Object
    @default null
  */
  target: null,

   /**
     Perform the current action on the current target with the given context. If no target is set,
     then the responder chain will be searched for an object that implements the action.

     You can pass the `context` parameter, which is useful in order to provide additional
     information to the target, such as the current state of the sender when the action was
     triggered.

     @param {Object} [context] additional context information to pass to the target
     @returns {Boolean} true if successful; false otherwise
  */
  // TODO: remove backwards compatibility for `action` argument
  fireAction: function (actionOrContext) {
    var pane = this.get('pane'),
      rootResponder = pane.get('rootResponder'),
      action = this.get('action'),
      context;

    // Normalize arguments.
    // TODO: Fully deprecate action argument and actionContext property.

    // No argument, use action (above) and actionContext properties.
    if (actionOrContext === undefined) {
      context = this.get('actionContext');

    // String argument and no action (above) property, assume action method name. Use argument with actionContext property.
    } else if (typeof actionOrContext === SC.T_STRING && action == null) {
      

      action = actionOrContext;
      context = this.get('actionContext');

    // Something else, use action property (above) and context argument.
    } else {
      context = actionOrContext;
    }

    if (action && rootResponder) {
      return rootResponder.sendAction(action, this.get('target'), this, pane, context, this);
    }

    return false;
  }

};

/* >>>>>>>>>> BEGIN source/mixins/responder_context.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
sc_require('system/responder');

/** @namespace

  The root object for a responder chain.  A responder context can dispatch
  actions directly to a first responder; walking up the responder chain until
  it finds a responder that can handle the action.

  If no responder can be found to handle the action, it will attempt to send
  the action to the defaultResponder.

  You can have as many ResponderContext's as you want within your application.
  Every SC.Pane and SC.Application automatically implements this mixin.

  Note that to implement this, you should mix SC.ResponderContext into an
  SC.Responder or SC.Responder subclass.

  @since SproutCore 1.0
*/
SC.ResponderContext = {

  


  // ..........................................................
  // PROPERTIES
  //

  isResponderContext: YES,

  /** @property
    The default responder.  Set this to point to a responder object that can
    respond to events when no other view in the hierarchy handles them.

    @type SC.Responder
  */
  defaultResponder: null,

  /** @property
    The next responder for an app is always its defaultResponder.
  */
  nextResponder: function() {
    return this.get('defaultResponder');
  }.property('defaultResponder').cacheable(),

  /** @property
    The first responder.  This is the first responder that should receive
    actions.
  */
  firstResponder: null,

  // ..........................................................
  // METHODS
  //

  /**
    Finds the next responder for the passed responder based on the responder's
    nextResponder property.  If the property is a string, then lookup the path
    in the receiver.
  */
  nextResponderFor: function(responder) {
    var next = responder.get('nextResponder');
    if (typeof next === SC.T_STRING) {
      next = SC.objectForPropertyPath(next, this);
    } else if (!next && (responder !== this)) next = this ;
    return next ;
  },

  /**
    Finds the responder name by searching the responders one time.
  */
  responderNameFor: function(responder) {
    if (!responder) return "(No Responder)";
    else if (responder._scrc_name) return responder._scrc_name;

    // none found, let's go hunting...look three levels deep
    var n = this.NAMESPACE;
    this._findResponderNamesFor(this, 3, n ? [this.NAMESPACE] : []);

    return responder._scrc_name || responder.toString(); // try again
  },

  /** @private */
  _findResponderNamesFor: function(responder, level, path) {
    var key, value;

    for(key in responder) {
      if (key === 'nextResponder') continue ;
      value = responder[key];
      if (value && value.isResponder) {
        if (value._scrc_name) continue ;
        path.push(key);
        value._scrc_name = path.join('.');
        if (level>0) this._findResponderNamesFor(value, level-1, path);
        path.pop();
      }
    }
  },

  /**
    Makes the passed responder into the new firstResponder for this
    responder context.  This will cause the current first responder to lose
    its responder status and possibly keyResponder status as well.

    When you change the first responder, this will send callbacks to
    responders up the chain until you reach a shared responder, at which point
    it will stop notifying.

    @param {SC.Responder} responder
    @param {Event} evt that cause this to become first responder
    @returns {SC.ResponderContext} receiver
  */
  makeFirstResponder: function(responder, evt) {
    var current = this.get('firstResponder'),
        last    = this.get('nextResponder'),
        

        common ;

    if (this._locked) {
      


      this._pendingResponder = responder;
      return ;
    }

    


    if (responder) responder.set("becomingFirstResponder", YES);

    this._locked = YES;
    this._pendingResponder = null;

    // Find the nearest common responder in the responder chain for the new
    // responder.  If there are no common responders, use last responder.
    // Note: start at the responder itself: it could be the common responder.
    common = responder ? responder : null;
    while (common) {
      if (common.get('hasFirstResponder')) break;
      common = (common===last) ? null : this.nextResponderFor(common);
    }
    if (!common) common = last;

    // Cleanup old first responder
    this._notifyWillLoseFirstResponder(current, current, common, evt);
    if (current) current.set('isFirstResponder', NO);

    // Set new first responder.  If new firstResponder does not have its
    // responderContext property set, then set it.

    // but, don't tell anyone until we have _also_ updated the hasFirstResponder state.
    this.beginPropertyChanges();

    this.set('firstResponder', responder) ;
    if (responder) responder.set('isFirstResponder', YES);

    this._notifyDidBecomeFirstResponder(responder, responder, common);

    // now, tell everyone the good news!
    this.endPropertyChanges();

    this._locked = NO ;
    if (this._pendingResponder) {
      this.makeFirstResponder(this._pendingResponder);
      this._pendingResponder = null;
    }

    if (responder) responder.set("becomingFirstResponder", NO);

    return this ;
  },

  _notifyWillLoseFirstResponder: function(responder, cur, root, evt) {
    if (!cur || cur === root) return ; // nothing to do

    cur.willLoseFirstResponder(responder, evt);
    cur.set('hasFirstResponder', NO);

    var next = this.nextResponderFor(cur);
    if (next) this._notifyWillLoseFirstResponder(responder, next, root);
  },

  _notifyDidBecomeFirstResponder: function(responder, cur, root) {
    if (!cur || cur === root) return ; // nothing to do

    var next = this.nextResponderFor(cur);
    if (next) this._notifyDidBecomeFirstResponder(responder, next, root);

    cur.set('hasFirstResponder', YES);
    cur.didBecomeFirstResponder(responder);
  },

  /**
    Re-enters the current responder (calling willLoseFirstResponder and didBecomeFirstResponder).
  */
  resetFirstResponder: function() {
    var current = this.get('firstResponder');
    if (!current) return;
    current.willLoseFirstResponder();
    current.didBecomeFirstResponder();
  },

  /**
    Send the passed action down the responder chain, starting with the
    current first responder.  This will look for the first responder that
    actually implements the action method and returns YES or no value when
    called.

    @param {String} action name of action
    @param {Object} sender object sending the action
    @param {Object} [context] additional context info
    @returns {SC.Responder} the responder that handled it or null
  */
  sendAction: function(action, sender, context) {
    var working = this.get('firstResponder'),
        last    = this.get('nextResponder'),
        

        handled = NO,
        responder;

    this._locked = YES;

    


    if (!handled && !working && this.tryToPerform) {
      handled = this.tryToPerform(action, sender, context);
    }

    while (!handled && working) {
      if (working.tryToPerform) {
        handled = working.tryToPerform(action, sender, context);
      }

      if (!handled) {
        working = (working===last) ? null : this.nextResponderFor(working);
      }
    }

    


    this._locked = NO ;

    if (responder = this._pendingResponder) {
      this._pendingResponder= null ;
      this.makeFirstResponder(responder);
    }


    return working ;
  }

};

/* >>>>>>>>>> BEGIN source/panes/body_overflow.js */
/**
  SC.bodyOverflowArbitrator is a central object responsible for controlling the overflow on the body element.

  Use it from views that would otherwise set the body overflow style directly; call requestHidden to ask for
  the body to have overflow:hidden, and call requestVisible to ask for the body to be visible.

  Call withdrawRequest to register that you no longer have any interest in the body overflow setting. Don't
  forget to do this, or your object could be affecting the body overflow long after it's no longer relevant.

  When calling requestHidden, requestVisible, and withdrawRequest, pass your object as the first argument so
  that its request can be associated with its GUID.

  When calling requestHidden or requestVisible, you may optionally pass true as a second argument to signify
  that your desire for hidden or visible overflow is important. An important visible-request will override
  any other, but an important hidden-request will override a normal visible-request. A normal visible-request
  will in turn override a normal hidden-request.
*/
SC.bodyOverflowArbitrator = SC.Object.create(/**@scope SC.bodyOverflowArbitrator.prototype */{
  /** Request that the body be given overflow:hidden;. Pass your object, then (optionally) true to confer importance. */
  requestHidden: function (from, important) { this._makeRequest(from, -1 - 9 * !!important); },

  /** Request that the body be given overflow:visible;. Pass your object, then (optionally) true to confer importance. */
  requestVisible: function (from, important) { this._makeRequest(from, 1 + 9 * !!important); },

  /** State that your object no longer cares about the body overflow. */
  withdrawRequest: function (from) {
    // Fast path!
    if (!from) return;

    var guid = SC.guidFor(from),
      currentRequest = this._requests[guid];

    if (currentRequest) {
      delete this._requests[guid];
      this.setOverflow();
    }
  },

  /** Perform the action of setting the overflow depending on what requests are currently registered. Does nothing if there are no requests. */
  setOverflow: function () {
    var overflow = this._decideOverflow();

    if (overflow !== undefined) document.body.style.overflow = overflow ? "auto" : "hidden";
    // console.log("Body Overflow Arbitrator now decides "+(overflow===undefined?"that overflow is unimportant.":"to use overflow:"+(overflow===true?'visible':"hidden")+";")+" Requests are:",this._requests);
  },

  /** @private */
  _makeRequest: function (from, value) {
    // Fast path!
    if (!from) return;

    var guid = SC.guidFor(from),
      currentRequest = this._requests[guid];

    if (currentRequest != value) {
      this._requests[guid] = value;
      this.setOverflow();
    }
  },

  /** @private */
  _requests: {},

  /** @private */
  _decideOverflow: function () {
    var haveHidden, haveVisible, haveImportantHidden, haveImportantVisible,
        reqs = this._requests, req;

    for (var i in reqs) {
      if ((req = reqs[i]) < 0) haveHidden = YES;
      if (req < -1) haveImportantHidden = YES;
      if (req > 0) haveVisible = YES;
      if (req > 1) haveImportantVisible = YES;
    }
    if (haveImportantVisible) return YES;              //important-visible takes all.
    if (haveVisible && haveImportantHidden) return NO; //important-hidden beats regular-visible.
    if (haveVisible) return YES;                       //regular-visible beats regular-hidden
    if (haveHidden) return NO;                         //if there is a hidden, it can win now.

    return undefined;                                  //if nobody cared, return undefined to prevent work.
  }
});

/* >>>>>>>>>> BEGIN source/views/view/animation.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
sc_require("views/view");

/** @private
  Properties that can be animated
  (Hash for faster lookup)
*/
SC.ANIMATABLE_PROPERTIES = {
  top:     YES,
  left:    YES,
  bottom:  YES,
  right:   YES,
  width:   YES,
  height:  YES,
  centerX: YES,
  centerY: YES,
  opacity: YES,
  scale:   YES,
  rotate:  YES,
  rotateX: YES,
  rotateY: YES,
  rotateZ: YES
};


/**
  States that the view's layout can be set to if its animation is cancelled.

  ### START

  The previous layout of the view before calling animate.

  For example,

      myView.set('layout', { left: 0, top: 0, width: 100, bottom: 0 });
      myView.animate('left', 300, { duration: 1.5 });

      // later..
      myView.cancelAnimation(SC.LayoutState.START);

      myView.get('layout'); // => { left: 0, top: 0, width: 100, bottom: 0 }

  ### CURRENT

  The current layout of the view while it is animating.

  For example,

      myView.set('layout', { left: 0, top: 0, width: 100, bottom: 0 });
      myView.animate('left', 300, { duration: 1.5 });

      // later..
      myView.cancelAnimation(SC.LayoutState.CURRENT);
      myView.get('layout'); // => { left: 150, top: 0, width: 100, bottom: 0 }

  ### END

  The final layout of the view if the animation completed.

  For example,

      myView.set('layout', { left: 0, top: 0, width: 100, bottom: 0 });
      myView.animate('left', 300, { duration: 1.5 });

      // later..
      myView.cancelAnimation(SC.LayoutState.END);
      myView.get('layout'); // => { left: 300, top: 0, width: 100, bottom: 0 }

  @readonly
  @enum {Number}
*/
SC.LayoutState = {
  START: 1,
  CURRENT: 2,
  END: 3
};


SC.View.reopen(
  /** @scope SC.View.prototype */ {

  /** @private Shared object used to avoid continually initializing/destroying objects. */
  _SC_DECOMPOSED_TRANSFORM_MAP: null,

  /* @private Internal variable to store the active (i.e. applied) animations. */
  _activeAnimations: null,

  /* @private Internal variable to store the count of active animations. */
  _activeAnimationsLength: null,

  /* @private Internal variable to store the animation layout until the next run loop when it can be safely applied. */
  _animateLayout: null,

  /* @private Internal variable to store the pending (i.e. not yet applied) animations. */
  _pendingAnimations: null,

  /* @private Internal variable to store the previous layout for in case the animation is cancelled and meant to return to original point. */
  _prevLayout: null,

  /**
    Method protocol.

    The method you provide to SC.View.prototype.animate should accept the
    following parameter(s).

    @name AnimateCallback
    @function
    @param {object} animationResult The result of the animation.
    @param {boolean} animationResult.isCancelled Whether the animation was cancelled or not.
    @param {event} [animationResult.evt] The transitionend event if it exists.
    @param {SC.View} animationResult.view The animated view.
  */

  /**
    Animate a group of layout properties using CSS animations.

    On supported platforms, this will apply the proper CSS transition style
    in order to animate the view to the new layout.  The properties object
    should contain the names of the layout properties to animate with the new
    layout values as values.

    # Options

    To control the transition, you must provide an options object that contains
    at least the duration property and optionally the timing and delay
    properties.  The options properties are as follows:

    - duration: The duration of the transition in seconds.  The default value is 0.25.

    - timing: The transition timing function.  This may be a predefined CSS timing
      function (e.g. 'linear', 'ease', 'ease-in', 'ease-out', 'ease-in-out') or
      it may be an array of values to make a cubic bezier (e.g. [0, 0, 0.58, 1.0]).
      The default value is 'ease'.

      ** 'linear' - Specifies a transition effect with the same speed from start to end (equivalent to cubic-bezier(0,0,1,1))
      ** 'ease' -  Specifies a transition effect with a slow start, then fast, then end slowly (equivalent to cubic-bezier(0.25,0.1,0.25,1))
      ** 'ease-in' - Specifies a transition effect with a slow start (equivalent to cubic-bezier(0.42,0,1,1))
      ** 'ease-out' -  Specifies a transition effect with a slow end (equivalent to cubic-bezier(0,0,0.58,1))
      ** 'ease-in-out' - Specifies a transition effect with a slow start and end (equivalent to cubic-bezier(0.42,0,0.58,1))
      ** 'cubic-bezier(n,n,n,n)' - Define your own values in the cubic-bezier function. Possible values are numeric values from 0 to 1

    - delay: The transition delay in seconds.  The default value is 0.

    For example,

        var myView = SC.View.create({
          layout: { top: 10, left: 10, width: 200, height: 400 }
        });

        MyApp.mainPane.appendChild(myView);

        // The view will animate to the new top & left values.
        myView.animate(
          { top: 200, left: 200 },  // properties
          { duration: 0.75, timing: 'ease-out', delay: 0.5 } // options
        );

    # Callbacks

    To execute code when the transition completes, you may provide an optional
    target and/or method.  When the given group of transitions completes,
    the callback function will be called once and passed an animationResult object with
    properties containing the `event`, the `view` and a boolean `isCancelled` which
    indicates if the animation had been cancelled or not.  The format of the
    target and method follows the standard SproutCore format, where if the
    target is not given then the view itself will be the target.  The
    method can be a function or a property path to look up on the target.

    For example,

        // Passing a function for method.
        myView.animate(
          { top: 200, left: 200 },  // properties
          { duration: 0.75 }, // options
          function (animationResult) {  // method
            // `this` will be myView
          }
        );

        // Passing a target and method.
        myView.animate(
          { scale: 0, opacity: 0 },  // properties
          { duration: 1.5 }, // options
          MyApp.statechart, // target
          'myViewDidShrink' // method
        );

    The animate functions are intelligent in how they apply animations and
    calling animate in a manner that would affect an ongoing animation (i.e.
    animating left again while it is still in transition) will result in
    the ongoing animation callback firing immediately with isCancelled set to
    true and adjusting the transition to accomodate the new settings.

    Note: This may not work if you are not using SproutCore for view layout,
    which means you should not use `animate` if the view has `useStaticLayout`
    set to true.

    ## A note about Hardware Acceleration.

    If a view has a fixed layout (i.e. view.get('isFixedLayout') == true) then
    it will be eligible for hardware accelerated position transitions. Having a
    fixed layout, simply means that the view has a fixed size (width and height)
    and a fixed position (left and top).  If the view is eligible for hardware
    acceleration, it must also set wantsAcceleratedLayer to true for animate to
    use hardware accelerated transitions when animating its position.

    Occassionally, you may wish to animate a view with a non-fixed layout.  To
    do so with hardware acceleration, you should convert the view to a fixed
    layout temporarily and then set it back to a flexible layout after the
    transition is complete.

    For example,

        // Flexible layout.
        myView.set('layout', { left: 0, top: 10, right: 0, bottom: 10 });

        // Prepare to animate by converting to a fixed layout.
        frame = myView.get('frame');
        height = frame.height;
        width = frame.width;
        myView.adjust({ right: null, bottom: null, height: height, width: width });

        // Animate (will be hardware accelerated if myView.get('wantsAcceleratedLayout') is true).
        myView.animate('left', width, { duration: 1 }, function () {
          // Revert back to flexible layout.
          myView.adjust({ right: -width, bottom: 10 });
        });

    @param {Object|String} properties Hash of property names with new layout values or a single property name.
    @param {Number} [value] The new layout value for a single property (only provide if the first parameter is a String).
    @param {Number|Object} Duration or hash of transition options.
    @param {Object} [target=this] The target for the method.
    @param {AnimateCallback|String} [method] The method to run when the transition completes.  May be a function or a property path.
    @returns {SC.View} receiver
  */
  animate: function (key, value, options, target, method) {
    var cur, curAnim,
      valueDidChange = NO,
      optionsDidChange = NO,
      hash, layout,
      optionsType,
      pendingAnimations = this._pendingAnimations,
      timing;

    


    // Normalize arguments
    // TODO: Revisit .animate() arguments re: overloading.
    if (typeof key === SC.T_STRING) {
      hash = {};
      hash[key] = value;
    } else {
      method = target;
      target = options;
      options = value;
      hash = key;
    }

    optionsType = SC.typeOf(options);
    if (optionsType === SC.T_NUMBER) {
      options = { duration: options };
    } else if (optionsType !== SC.T_HASH) {
      throw new Error("Must provide options hash!");
    }

    if (options.callback) {
      method = options.callback;
      delete options.callback;
    }

    // Callback.  We need to keep the callback for each group of animations separate.
    if (method === undefined) {
      method = target;
      target = this;
    }

    // Support `null` being passed in for the target, rather than dropping the argument.
    if (!target) target = this;

    if (method) {
      if (typeof method === "string") method = target[method];
      options.target = target;
      options.method = method;
    }

    // In the case of zero duration, just adjust and call the callback.
    if (options.duration === 0) {
      this.invokeNext(function () {
        this.adjust(hash);
        this.runAnimationCallback(options, null, false);
      });
      return this;
    }

    // In the case that the view is not in the standard visible state, adjust instead of animate.
    if (!this.get('isVisibleInWindow')) {
      this.invokeNext(function () {
        this.adjust(hash);
        this.runAnimationCallback(options, null);
        // Note: we may need to find a way to alert the callback that the animation was successful
        // but instantaneous.
      });
      return this;
    }

    // Timing function
    timing = options.timing;
    if (timing) {
      if (typeof timing !== SC.T_STRING) {
        options.timing = "cubic-bezier(" + timing[0] + ", " + timing[1] + ", " +
                                         timing[2] + ", " + timing[3] + ")";
      } // else leave as is (assume proper CSS timing String)
    } else {
      options.timing = 'ease';
    }

    // Delay
    if (SC.none(options.delay)) { options.delay = 0; }

    // Get the layout (may be a previous layout already animating).
    if (!this._prevLayout) {
      this._prevLayout = SC.clone(this.get('explicitLayout'));
    }

    if (!pendingAnimations) { pendingAnimations = this._pendingAnimations = {}; }

    // Get the layout (may be a partially adjusted one already queued up).
    layout = this._animateLayout || SC.clone(this.get('explicitLayout'));

    // Handle old style rotation.
    if (!SC.none(hash.rotate)) {
      

      if (SC.none(hash.rotateZ)) {
        hash.rotateZ = hash.rotate;
      }
      delete hash.rotate;
    }

    // Go through the new animated properties and check for conflicts with
    // previous calls to animate and changes to the current layout.
    for (var property in hash) {
      // Fast path.
      if (!hash.hasOwnProperty(property) || !SC.ANIMATABLE_PROPERTIES[property]) {

        

        continue;
      }

      value = hash[property];
      cur = layout[property];
      curAnim = pendingAnimations[property];

      if (SC.none(value)) { throw new Error("Can only animate to an actual value!"); }

      // If the new adjustment changes the previous adjustment's options before
      // it has rendered, overwrite the previous adjustment.
      if (curAnim && (curAnim.duration !== options.duration ||
          curAnim.timing !== options.timing ||
          curAnim.delay !== options.delay)) {
        optionsDidChange = YES;
        this.runAnimationCallback(curAnim, null, YES);
      }

      if (cur !== value || optionsDidChange) {
        valueDidChange = YES;
        layout[property] = value;

        // Always update the animate hash to the newest options which may have been altered before this was applied.
        pendingAnimations[property] = options;
      }
    }

    // Only animate to new values.
    if (valueDidChange) {
      // When animating height or width with centerX or centerY, we need to animate the margin property also to get a smooth change.
      if (!SC.none(pendingAnimations.height) && !SC.none(layout.centerY) && SC.none(pendingAnimations.centerY)) {
        // Don't animate less than 2px difference b/c the margin-top value won't differ.
        if (Math.abs(hash.height - this.get('layout').height) >= 2) {
          pendingAnimations.centerY = options;
        }
      }

      if (!SC.none(pendingAnimations.width) && !SC.none(layout.centerX) && SC.none(pendingAnimations.centerX)) {
        // Don't animate less than 2px difference b/c the margin-left value won't differ.
        if (Math.abs(hash.width - this.get('layout').width) >= 2) {
          pendingAnimations.centerX = options;
        }
      }

      this._animateLayout = layout;

      // Always run the animation asynchronously so that the original layout is guaranteed to be applied to the DOM.
      this.invokeNext('_animate');
    } else if (!optionsDidChange) {
      this.invokeNext(function () {
        this.runAnimationCallback(options, null, false);
      });
    }

    return this;
  },

  /** @private */
  _animate: function () {
    // Check for _animateLayout.  If an invokeNext call to animate *this* occurs
    // while flushing the invokeNext queue *before* this method runs, an extra
    // call to _animate will run.  Has unit test.
    var animationLayout = this._animateLayout;
    if (animationLayout) {
      this.willRenderAnimations();

      // Clear the layout cache value first so that it is not present when layout changes next.
      this._animateLayout = null;

      // Apply the animation layout.
      this.set('layout', animationLayout);

      // Route.
      if (this.get('viewState') === SC.CoreView.ATTACHED_SHOWN) {
        this.set('viewState', SC.CoreView.ATTACHED_SHOWN_ANIMATING);
      }
    }
  },

  /** @private
    Animates through the given frames.

    @param {Array} frames The array of frame objects.
    @param {AnimateCallback} callback The callback function to call when the final frame is done animating.
    @param {Number} initialDelay The delay before the first frame begins animating.
    @returns {SC.View} receiver
  */
  // TODO: Do this using CSS animations instead.
  _animateFrames: function (frames, callback, initialDelay, _sc_frameCount) {
    // Normalize the private argument `_sc_frameCount`.
    if (SC.none(_sc_frameCount)) { _sc_frameCount = 0; }

    var frame = frames[_sc_frameCount];

    this.animate(frame.value, {
      delay: initialDelay,
      duration: frame.duration,
      timing: frame.timing
    }, function (data) {
      _sc_frameCount += 1;

      // Keep iterating while frames exist and the animations weren't cancelled.
      if (!data.isCancelled && _sc_frameCount < frames.length) {
        // Only delay on the first animation.  Increase count to the next frame.
        this._animateFrames(frames, callback, 0, _sc_frameCount);
      } else {
        // Done.
        if (callback) callback(data);
      }
    });

    return this;
  },

  /**
    Cancels the animation, adjusting the view's layout immediately to one of
    three values depending on the `layoutState` parameter.

    If no `layoutState` is given or if SC.LayoutState.END is given, the view
    will be adjusted to its final layout.  If SC.LayoutState.START is given,
    the view will be adjusted back to its initial layout and if
    SC.LayoutState.CURRENT is given, the view will stop at its current layout
    value, which will be some transient value between the start and end values.

    Note: The animation callbacks will be called with the animationResult object's
    isCancelled property set to YES.

    @param {SC.LayoutState} [layoutState=SC.LayoutState.END] The layout to immediately adjust the view to.
    @returns {SC.View} this
  */
  cancelAnimation: function (layoutState) {
    var activeAnimations = this._activeAnimations,
      pendingAnimations = this._pendingAnimations,
      animation,
      key,
      layout,
      didCancel = NO;

    switch (layoutState) {
    case SC.LayoutState.START:
      // Revert back to the start layout.
      layout = this._prevLayout;
      break;
    case SC.LayoutState.CURRENT:
      // Stop at the current layout.
      layout = this.get('liveAdjustments');
      break;
    default:
      layout = this._animateLayout;
    }

    // Route.
    if (this.get('viewState') === SC.CoreView.ATTACHED_SHOWN_ANIMATING) {
      this.set('viewState', SC.CoreView.ATTACHED_SHOWN);
    }

    // Immediately remove the pending animations while calling the callbacks.
    for (key in pendingAnimations) {
      animation = pendingAnimations[key];
      didCancel = YES;

      // Update the animation hash.  Do this first, so callbacks can check for active animations.
      delete pendingAnimations[key];

      // Run the callback.
      this.runAnimationCallback(animation, null, YES);
    }

    // Immediately remove the animation styles while calling the callbacks.
    for (key in activeAnimations) {
      animation = activeAnimations[key];
      didCancel = YES;

      // Update the animation hash.  Do this first, so callbacks can check for active animations.
      delete activeAnimations[key];

      // Remove the animation style without triggering a layout change.
      this.removeAnimationFromLayout(key, YES);

      // Run the callback.
      this.runAnimationCallback(animation, null, YES);
    }

    // Adjust to final position.
    if (didCancel && !!layout) {
      this.set('layout', layout);
    }

    // Clean up.
    this._prevLayout = this._activeAnimations = this._pendingAnimations = this._animateLayout = null;

    return this;
  },

  /** @private
    This method is called after the layout style is applied to the layer.  If
    the platform didn't support CSS transitions, the callbacks will be fired
    immediately and the animations removed from the queue.
  */
  didRenderAnimations: function () {
    // Transitions not supported or the document is not visible.
    if (!SC.platform.supportsCSSTransitions || document.hidden) {
      var pendingAnimations = this._pendingAnimations;

      for (var key in pendingAnimations) {
        this.removeAnimationFromLayout(key, NO);
        this.runAnimationCallback(pendingAnimations[key], null, NO);
      }

      // Route.
      if (this.get('viewState') === SC.CoreView.ATTACHED_SHOWN_ANIMATING) {
        this.set('viewState', SC.CoreView.ATTACHED_SHOWN);
      }

      // Reset the placeholder variables now that the layout style has been applied.
      this._activeAnimations = this._pendingAnimations = null;
    }
  },

  /** @private Decompose a transformation matrix. */
  // TODO: Add skew support
  _sc_decompose3DTransformMatrix: function (matrix, expectsScale) {
    var ret = SC.View._SC_DECOMPOSED_TRANSFORM_MAP,  // Shared object used to avoid continually initializing/destroying
      toDegrees = 180 / Math.PI;
      // determinant;

    // Create the decomposition map once. Note: This is a shared object, all properties must be overwritten each time.
    if (!ret) { ret = SC.View._SC_DECOMPOSED_TRANSFORM_MAP = {}; }

    // Calculate the scale.
    if (expectsScale) {
      ret.scaleX = Math.sqrt((matrix.m11 * matrix.m11) + (matrix.m12 * matrix.m12) + (matrix.m13 * matrix.m13));
      // if (matrix.m11 < 0) ret.scaleX = ret.scaleX * -1;
      ret.scaleY = Math.sqrt((matrix.m21 * matrix.m21) + (matrix.m22 * matrix.m22) + (matrix.m23 * matrix.m23));
      ret.scaleZ = Math.sqrt((matrix.m31 * matrix.m31) + (matrix.m32 * matrix.m32) + (matrix.m33 * matrix.m33));

      // Decompose scale from the matrix.
      matrix = matrix.scale(1 / ret.scaleX, 1 / ret.scaleY, 1 / ret.scaleZ);
    } else {
      ret.scaleX = 1;
      ret.scaleY = 1;
      ret.scaleZ = 1;
    }

    // console.log("scales: %@, %@, %@".fmt(ret.scaleX, ret.scaleY, ret.scaleZ));

    // Find the 3 Euler angles. Note the order applied using SC.CSS_TRANSFORM_NAMES in layout_style.js.
    ret.rotateZ = -Math.atan2(matrix.m21, matrix.m11) * toDegrees; // Between -180° and 180°
    // ret.rotateY = Math.atan2(-matrix.m31, Math.sqrt((matrix.m32 * matrix.m32) + (matrix.m33 * matrix.m33))) * toDegrees;  // Between -90° and 90°
    // ret.rotateX = Math.atan2(matrix.m32, matrix.m33) * toDegrees; // Between -180° and 180°

    // console.log("rotations: %@, %@, %@".fmt(ret.rotateX, ret.rotateY, ret.rotateZ));

    // if (ret.rotateX < 0) { ret.rotateX = 360 + ret.rotateX; } // Convert to 0° to 360°
    // if (ret.rotateY < 0) { ret.rotateY = 180 + ret.rotateY; } // Convert to 0° to 180°
    if (ret.rotateZ < 0) { ret.rotateZ = 360 + ret.rotateZ; } // Convert to 0° to 360°

    // Pull out the translate values directly.
    ret.translateX = matrix.m41;
    ret.translateY = matrix.m42;
    ret.translateZ = matrix.m43;

    // console.log("translations: %@, %@, %@".fmt(ret.translateX, ret.translateY, ret.translateZ));

    return ret;
  },

  /** @private Replace scientific E notation values with fixed decimal values. */
  _sc_removeENotationFromMatrixString: function (matrixString) {
    var components,
      numbers,
      ret;

    components = matrixString.split(/\(|\)/);
    numbers = components[1].split(',');
    for (var i = 0, len = numbers.length; i < len; i++) {
      var number = numbers[i];

      // Transform E notation into fixed decimal (20 is maximum allowed).
      if (number.indexOf('e') > 0) {
        numbers[i] = window.parseFloat(number).toFixed(20);
      }
    }

    ret = components[0] + '(' + numbers.join(', ') + ')';

    return ret;
  },

  /** @private
    Returns the live values of the properties being animated on a view while it
    is animating.  Getting the layout of the view after a call to animate will
    include the final values, some of which will not be the same as what they
    are while the animation is in progress.

    Depending on the property being animated, determining the actual value can
    be quite difficult.  For instance, accelerated views will animate certain
    properties using a browser specific CSS transition on a CSS transform and
    the current value may be a CSSMatrix that needs to be mapped back to a
    regular layout format.

    This property is used by cancelAnimation() to stop the animation in its
    current place.

    PRIVATE - because we may want to rename this function and change its output

    @returns {Object}
  */
  liveAdjustments: function () {
    var activeAnimations = this._activeAnimations,
      el = this.get('layer'),
      ret = {},
      transformKey = SC.browser.experimentalCSSNameFor('transform');

    if (activeAnimations) {
      for (var key in activeAnimations) {
        var value = document.defaultView.getComputedStyle(el)[key];

        // If a transform is being transitioned, decompose the matrices.
        if (key === transformKey) {
          var CSSMatrixClass = SC.browser.experimentalNameFor(window, 'CSSMatrix'),
            matrix;

          if (CSSMatrixClass !== SC.UNSUPPORTED) {

            // Convert scientific E number representations to fixed numbers.
            // In WebKit at least, these throw exceptions when used to generate the matrix. To test,
            // paste the following in a browser console:
            //    new WebKitCSSMatrix('matrix(-1, 1.22464679914735e-16, -1.22464679914735e-16, -1, 0, 0)')
            value = this._sc_removeENotationFromMatrixString(value);
            matrix = new window[CSSMatrixClass](value);

            /* jshint eqnull:true */
            var layout = this.get('layout'),
              scaleLayout = layout.scale,
              expectsScale = scaleLayout != null,
              decomposition = this._sc_decompose3DTransformMatrix(matrix, expectsScale);

            // The rotation decompositions aren't working properly, ignore them.
            // Set rotateX.
            // if (layout.rotateX != null) {
            //   ret.rotateX = decomposition.rotateX;
            // }

            // // Set rotateY.
            // if (layout.rotateY != null) {
            //   ret.rotateY = decomposition.rotateY;
            // }

            // Set rotateZ.
            if (layout.rotateZ != null) {
              ret.rotateZ = decomposition.rotateZ;
            }

            // Set scale.
            if (expectsScale) {
              // If the scale was set in the layout as an Array, return it as an Array.
              if (SC.typeOf(scaleLayout) === SC.T_ARRAY) {
                ret.scale = [decomposition.scaleX, decomposition.scaleY];

              // If the scale was set in the layout as an Object, return it as an Object.
              } else if (SC.typeOf(scaleLayout) === SC.T_HASH) {
                ret.scale = { x: decomposition.scaleX, y: decomposition.scaleY };

              // Return it as a single value.
              } else {
                ret.scale = decomposition.scaleX;
              }
            }

            // Set top & left.
            if (this.get('hasAcceleratedLayer')) {
              ret.left = decomposition.translateX;
              ret.top = decomposition.translateY;
            }
          } else {
            matrix = value.match(/^matrix\((.*)\)$/)[1].split(/,\s*/);
            // If the view has translated position, retrieve translateX & translateY.
            if (matrix && this.get('hasAcceleratedLayer')) {
              ret.left = parseInt(matrix[4], 10);
              ret.top = parseInt(matrix[5], 10);
            }
          }

        // Determine the current style.
        } else {
          value = window.parseFloat(value, 10);

          // Account for centerX & centerY animations (margin-left & margin-top).
          if (key === 'centerX') {
            value = value + parseInt(document.defaultView.getComputedStyle(el).width, 10) / 2; // Use the actual width.
          } else if (key === 'centerY') {
            value = value + parseInt(document.defaultView.getComputedStyle(el).height, 10) / 2; // Use the actual height.
          }

          ret[key] = value;
        }
      }
    }

    return ret;
  }.property(),

  /** @private Removes the animation CSS from the layer style. */
  removeAnimationFromLayout: function (propertyName, shouldUpdateStyle) {
    var activeAnimations = this._activeAnimations,
      layer = this.get('layer');

    if (!!layer && shouldUpdateStyle) {
      var updatedCSS = [];

      // Calculate the transition CSS that should remain.
      for (var key in activeAnimations) {
        if (key !== propertyName) {
          updatedCSS.push(activeAnimations[key].css);
        }
      }

      layer.style[SC.browser.experimentalStyleNameFor('transition')] = updatedCSS.join(', ');
    }
  },

  /** @deprecated
    Resets animation, stopping all existing animations.
  */
  resetAnimation: function () {
    


    return this.cancelAnimation();
  },

  /** @private */
  runAnimationCallback: function (animation, evt, cancelled) {
    var method = animation.method,
      target = animation.target;

    if (method) {
      // We're using invokeNext so we don't trigger any layout changes from
      // the callback until the current layout is updated.
      // this.invokeNext(function () {
        method.call(target, { event: evt, view: this, isCancelled: cancelled });
      // }, this);

      // Always clear the method from the hash to prevent it being called
      // multiple times for animations in the group.
      delete animation.method;
      delete animation.target;
    }
  },

  /** @private
    Called when animation ends, should not usually be called manually
  */
  transitionDidEnd: function (evt) {
    var propertyName = evt.originalEvent.propertyName,
      activeAnimations = this._activeAnimations,
      animation;

    // Fix up the centerX & centerY properties.
    if (propertyName === 'margin-left') { propertyName = 'centerX'; }
    if (propertyName === 'margin-top') { propertyName = 'centerY'; }
    animation = activeAnimations ? activeAnimations[propertyName] : null;

    if (animation) {
      // Update the animation hash.  Do this first, so callbacks can check for active animations.
      delete activeAnimations[propertyName];

      // Remove the animation style without triggering a layout change.
      this.removeAnimationFromLayout(propertyName, YES);

      // Clean up the internal hash.
      this._activeAnimationsLength -= 1;
      if (this._activeAnimationsLength === 0) {
        // Route.
        if (this.get('viewState') === SC.CoreView.ATTACHED_SHOWN_ANIMATING) {
          this.set('viewState', SC.CoreView.ATTACHED_SHOWN);
        }

        this._activeAnimations = this._prevLayout = null;
      }

      // Run the callback.
      this.runAnimationCallback(animation, evt, NO);
    }
  },

  /** @private
   This method is called before the layout style is applied to the layer.  If
   animations have been defined for the view, they will be included in
   this._pendingAnimations.  This method will clear out any conflicts between
   pending and active animations.
   */
  willRenderAnimations: function () {
    // Only apply the style if supported by the platform and the document is visible.
    if (SC.platform.supportsCSSTransitions && !document.hidden) {
      var pendingAnimations = this._pendingAnimations;

      if (pendingAnimations) {
        var activeAnimations = this._activeAnimations;

        if (!activeAnimations) {
          this._activeAnimationsLength = 0;
          activeAnimations = {};
        }

        for (var key in pendingAnimations) {
          if (!pendingAnimations.hasOwnProperty(key)) { continue; }

          var activeAnimation = activeAnimations[key],
            pendingAnimation = pendingAnimations[key];

          if (activeAnimation) {
            this.runAnimationCallback(activeAnimation, null, YES);
          }

          activeAnimations[key] = pendingAnimation;
          this._activeAnimationsLength += 1;
        }

        this._activeAnimations = activeAnimations;
        this._pendingAnimations = null;
      }
    }
  }

});

/* >>>>>>>>>> BEGIN source/views/view/layout_style.js */

sc_require('ext/string');
sc_require('views/view');
sc_require('views/view/animation');

/**
  Map to CSS Transforms
*/

// The scale transform must be last in order to decompose the transformation matrix.
SC.CSS_TRANSFORM_NAMES = ['rotateX', 'rotateY', 'rotateZ', 'scale'];

SC.CSS_TRANSFORM_MAP = {

  rotate: function (val) {
    if (SC.typeOf(val) === SC.T_NUMBER) { val += 'deg'; }
    return 'rotate(' + val + ')';
  },

  rotateX: function (val) {
    if (SC.typeOf(val) === SC.T_NUMBER) { val += 'deg'; }
    return 'rotateX(' + val + ')';
  },

  rotateY: function (val) {
    if (SC.typeOf(val) === SC.T_NUMBER) { val += 'deg'; }
    return 'rotateY(' + val + ')';
  },

  rotateZ: function (val) {
    if (SC.typeOf(val) === SC.T_NUMBER) { val += 'deg'; }
    return 'rotateZ(' + val + ')';
  },

  scale: function (val) {
    if (SC.typeOf(val) === SC.T_ARRAY) { val = val.join(', '); }
    return 'scale(' + val + ')';
  }
};


/** @private */
SC.View.LayoutStyleCalculator = {

  /** @private Shared object used to avoid continually initializing/destroying objects. */
  _SC_STATE_MAP: null,

  /** @private Shared object used to avoid continually initializing/destroying objects. */
  _SC_TRANSFORMS_ARRAY: null,

  /** @private Shared object used to avoid continually initializing/destroying objects. */
  _SC_TRANSITIONS_ARRAY: null,

  /** @private If the value is undefined, make it null. */
  _valueOrNull: function (value) {
    return value === undefined ? null : value;
  },

  /** @private */
  _prepareStyle: function (style, layout) {
    /*jshint eqnull:true */
    // It's important to provide null defaults to reset any previous style when
    // this is applied.
    var commonBorder = this._valueOrNull(layout.border);

    // Reset properties that might not be set from style to style.
    style.marginLeft = null;
    style.marginTop = null;

    // Position and size.
    style.bottom = layout.bottom;
    style.right = layout.right;
    style.left = layout.left;
    style.top = layout.top;
    style.centerX = layout.centerX;
    style.centerY = layout.centerY;
    style.height = layout.height;
    style.width = layout.width;

    // Borders.
    style.borderTopWidth = layout.borderTop !== undefined ? layout.borderTop : commonBorder;
    style.borderRightWidth = layout.borderRight !== undefined ? layout.borderRight : commonBorder;
    style.borderBottomWidth = layout.borderBottom !== undefined ? layout.borderBottom : commonBorder;
    style.borderLeftWidth = layout.borderLeft !== undefined ? layout.borderLeft : commonBorder;

    // Minimum and maximum size.
    style.maxHeight = this._valueOrNull(layout.maxHeight);
    style.maxWidth = this._valueOrNull(layout.maxWidth);
    style.minWidth = this._valueOrNull(layout.minWidth);
    style.minHeight = this._valueOrNull(layout.minHeight);

    // the toString here is to ensure that it doesn't get px added to it
    style.zIndex  = (layout.zIndex != null) ? layout.zIndex.toString() : null;
    style.opacity = (layout.opacity != null) ? layout.opacity.toString() : null;

    style.backgroundPosition = this._valueOrNull(layout.backgroundPosition);

    // Handle transforms (including reset).
    if (SC.platform.supportsCSSTransforms) {
      var transformAttribute = SC.browser.experimentalStyleNameFor('transform'),
        transforms = this._SC_TRANSFORMS_ARRAY, // Shared object used to avoid continually initializing/destroying objects.
        transformMap = SC.CSS_TRANSFORM_MAP;

      // Create the array once. Note: This is a shared array; it must be set to 0 length each time.
      if (!transforms) { transforms = this._SC_TRANSFORMS_ARRAY = []; }

      // The order of the transforms is important so that we can decompose them
      // from the transformation matrix later if necessary.
      for (var i = 0, len = SC.CSS_TRANSFORM_NAMES.length; i < len; i++) {
        var transformName = SC.CSS_TRANSFORM_NAMES[i],
          layoutTransform = layout[transformName];

        if (layoutTransform != null) {
          // normalizing transforms like rotateX: 5 to rotateX(5deg)
          transforms.push(transformMap[transformName](layoutTransform));
        }
      }

      // Set or reset the transform style.
      style[transformAttribute] = transforms.length > 0 ? transforms.join(' ') : null;

      // Transform origin.
      var transformOriginAttribute = SC.browser.experimentalStyleNameFor('transformOrigin'),
        originX = layout.transformOriginX,
        originY = layout.transformOriginY;
      if (originX == null && originY == null) {
        style[transformOriginAttribute] = null;
      } else {
        if (originX == null) originX = 0.5;
        if (originY == null) originY = 0.5;
        style[transformOriginAttribute] = (originX * 100) + '% ' + (originY * 100) + '%';
      }
    }

    // Reset any transitions.
    if (SC.platform.supportsCSSTransitions) {
      style[SC.browser.experimentalStyleNameFor('transition')] = null;
    }

    // Reset shared object!
    this._SC_TRANSFORMS_ARRAY.length = 0;
  },

  /** @private */
  _prepareState: function (state, style) {
    /*jshint eqnull:true */
    state.hasBottom = (style.bottom != null);
    state.hasRight = (style.right != null);
    state.hasLeft = (style.left != null);
    state.hasTop = (style.top != null);
    state.hasCenterX = (style.centerX != null);
    state.hasCenterY = (style.centerY != null);
    state.hasHeight = (style.height != null);
    state.hasWidth = (style.width != null);
    state.hasMaxWidth = (style.maxWidth != null);
    state.hasMaxHeight = (style.maxHeight != null);
  },


  // handles the case where you do width:auto or height:auto and are not using "staticLayout"
  _invalidAutoValue: function (view, property) {
    SC.throw("%@.layout() you cannot use %@:auto if staticLayout is disabled".fmt(view, property), "%@".fmt(view), -1);
  },

  /** @private */
  _calculatePosition: function (style, state, direction) {
    var start, finish, size,
      hasStart, hasFinish, hasSize, hasMaxSize,
      startBorder,
      finishBorder;

    if (direction === 'X') {
      start      = 'left';
      finish     = 'right';
      size       = 'width';
      startBorder  = 'borderLeftWidth';
      finishBorder = 'borderRightWidth';
      hasStart   = state.hasLeft;
      hasFinish  = state.hasRight;
      hasSize    = state.hasWidth;
      hasMaxSize = state.hasMaxWidth;
    } else {
      start      = 'top';
      finish     = 'bottom';
      size       = 'height';
      startBorder  = 'borderTopWidth';
      finishBorder = 'borderBottomWidth';
      hasStart   = state.hasTop;
      hasFinish  = state.hasBottom;
      hasSize    = state.hasHeight;
      hasMaxSize = state.hasMaxHeight;
    }

    style[start]  = this._cssNumber(style[start]);
    style[finish] = this._cssNumber(style[finish]);

    var startBorderVal = this._cssNumber(style[startBorder]),
      finishBorderVal = this._cssNumber(style[finishBorder]),
      sizeNum = style[size];

    style[startBorder] = startBorderVal;
    style[finishBorder] = finishBorderVal;

    // This is a normal number
    if (sizeNum >= 1) { sizeNum -= (startBorderVal + finishBorderVal); }
    style[size] = this._cssNumber(sizeNum);

    if (hasStart) {
      // top, bottom, height -> top, bottom
      if (hasFinish && hasSize)  { style[finish] = null; }
    } else {
      // bottom aligned
      if (!hasFinish || (hasFinish && !hasSize && !hasMaxSize)) {
        // no top, no bottom
        style[start] = 0;
      }
    }

    if (!hasSize && !hasFinish) { style[finish] = 0; }
  },


  /** @private */
  _calculateCenter: function (style, direction) {
    var size, center, start, finish, margin,
        startBorder,
        finishBorder;

    if (direction === 'X') {
      size   = 'width';
      center = 'centerX';
      start  = 'left';
      finish = 'right';
      margin = 'marginLeft';
      startBorder  = 'borderLeftWidth';
      finishBorder = 'borderRightWidth';
    } else {
      size   = 'height';
      center = 'centerY';
      start  = 'top';
      finish = 'bottom';
      margin = 'marginTop';
      startBorder  = 'borderTopWidth';
      finishBorder = 'borderBottomWidth';
    }

    style[start] = "50%";

    var startBorderVal = this._cssNumber(style[startBorder]),
      finishBorderVal = this._cssNumber(style[finishBorder]),
      sizeValue   = style[size],
      centerValue = style[center],
      sizeIsPercent = SC.isPercentage(sizeValue),
      value;

    style[startBorder] = startBorderVal;
    style[finishBorder] = finishBorderVal;

    // Calculate the margin offset used to center the value along this axis.
    if (SC.none(sizeValue)) {
      // Invalid!
      style[margin] = "50%";
    } else {
      value = centerValue - sizeValue / 2;
      style[margin] = (sizeIsPercent) ? Math.floor(value * 100) + "%" : Math.floor(value);
    }

    // If > 1 then it's a pixel value, in which case we shrink it to accommodate the borders.
    if (sizeValue > 1) { sizeValue -= (startBorderVal + finishBorderVal); }

    style[size] = this._cssNumber(sizeValue) || 0;
    style[finish] = style[center] = null;
  },

  /** @private */
  // return "auto" for "auto", null for null, converts 0.X into "X%".
  // otherwise returns the original number, rounded down
  _cssNumber: function (val) {
    /*jshint eqnull:true*/
    if (val == null) { return null; }
    else if (val === SC.LAYOUT_AUTO) { return SC.LAYOUT_AUTO; }
    else if (SC.isPercentage(val)) { return (val * 100) + "%"; }
    else { return Math.floor(val); }
  },

  /** @private
    Calculate the layout style for the given view, making adjustments to allow
    for flexible positioning, animation and accelerated transforms.

    @return {Object} Layout style hash.
  */
  calculate: function (view, style) {
    var layout = view.get('layout'),
      animations = view._activeAnimations,
      state = this._SC_STATE_MAP, // Shared object used to avoid continually initializing/destroying objects.
      useStaticLayout = view.get('useStaticLayout');

    // Fast path!
    // If the developer sets useStaticLayout and doesn't provide a unique `layout` property, we
    // should not insert the styles "left: 0px; right: 0px; top: 0px; bottom: 0px" as they could
    // conflict with the developer's intention.  However, if they do provide a unique `layout`,
    // use it.
    if (useStaticLayout && layout === SC.View.prototype.layout) { return {}; }

    // Reset and prep the style object.
    this._prepareStyle(style, layout);

    // Create the object once. Note: This is a shared object; all properties must be overwritten each time.
    if (!state) { state = this._SC_STATE_MAP = {}; }

    // Reset and prep the state object.
    this._prepareState(state, style);

    // handle invalid use of auto in absolute layouts
    if (!useStaticLayout) {
      if (style.width === SC.LAYOUT_AUTO) { this._invalidAutoValue(view, "width"); }
      if (style.height === SC.LAYOUT_AUTO) { this._invalidAutoValue(view, "height"); }
    }

    // X DIRECTION
    if (state.hasLeft || state.hasRight || !state.hasCenterX) {
      this._calculatePosition(style, state, "X");
    } else {
      this._calculateCenter(style, "X");
    }

    // Y DIRECTION
    if (state.hasTop || state.hasBottom || !state.hasCenterY) {
      this._calculatePosition(style, state, "Y");
    } else {
      this._calculateCenter(style, "Y");
    }

    this._calculateAnimations(style, animations, view.get('hasAcceleratedLayer'));

    // convert any numbers into a number + "px".
    for (var key in style) {
      var value = style[key];
      if (typeof value === SC.T_NUMBER) { style[key] = (value + "px"); }
    }

    return style;
  },

  /** @private Calculates animation styles. */
  _calculateAnimations: function (style, animations, hasAcceleratedLayer) {
    /*jshint eqnull:true*/
    var key,
      shouldTranslate;

    // Handle transforms
    if (hasAcceleratedLayer) {
      shouldTranslate = YES;

      // If we're animating other transforms at different speeds, don't use acceleratedLayer
      if (animations && (animations.top || animations.left)) {
        for (key in animations) {
          if (SC.CSS_TRANSFORM_MAP[key] &&
              ((animations.top &&
                animations.top.duration !== animations[key].duration) ||
               (animations.left &&
                animations.left.duration !== animations[key].duration))) {
            shouldTranslate = NO;
          }
        }
      }

      if (shouldTranslate) {
        var transformAttribute = SC.browser.experimentalStyleNameFor('transform'),
          curValue = style[transformAttribute],
          newValue;

        newValue = 'translateX(' + style.left + 'px) translateY(' + style.top + 'px)';

        // double check to make sure this is needed
        if (SC.platform.supportsCSS3DTransforms) { newValue += ' translateZ(0px)'; }

        // Append any current transforms.
        // NOTE: The order of transforms is important. If we scale before translate, our translations
        // will be scaled and incorrect.
        if (curValue) { newValue += ' ' + curValue; }
        style[transformAttribute] = newValue;

        // Set the absolute left & top style to 0,0 (will be translated from there).
        style.left = 0;
        style.top = 0;
      }
    }

    // Handle animations
    if (animations) {
      if (SC.platform.supportsCSSTransitions) {
        var transitions = this._SC_TRANSITIONS_ARRAY; // Shared object used to avoid continually initializing/destroying objects.

        // Create the array once. Note: This is a shared array; it must be set to 0 length each time.
        if (!transitions) { transitions = this._SC_TRANSITIONS_ARRAY = []; }

        for (key in animations) {
          var animation = animations[key],
            isTransformProperty = !!SC.CSS_TRANSFORM_MAP[key],
            isTurboProperty = shouldTranslate && (key === 'top' || key === 'left');

          if (SC.platform.supportsCSSTransforms && (isTurboProperty || isTransformProperty)) {
            // Untrack the un-transformed property name.
            delete animations[key];

            // The key will be either 'transform' or one of '-webkit-transform', '-ms-transform', '-moz-transform', '-o-transform'
            key = SC.browser.experimentalCSSNameFor('transform');

            var curTransformAnimation = animations[key];

            // Because multiple transforms actually share one CSS property, we can't animate multiple transforms
            // at different speeds. So, to handle that case, we just force them to all have the same length.
            if (curTransformAnimation) {
              

              animation = curTransformAnimation;
            } else {
              // Track the transformed property name.
              animations[key] = animation;
            }
          }

          // Fix up the centerX & centerY properties.
          if (key === 'centerX') { key = 'margin-left'; }
          if (key === 'centerY') { key = 'margin-top'; }

          // We're actually storing the css for the animation on layout.animate[key].css
          animation.css = key + " " + animation.duration + "s " + animation.timing + " " + animation.delay + "s";

          // If there are multiple transform properties, we only need to set this key once.
          // We already checked before to make sure they have the same duration.
          // if (!pendingAnimations[key]) {
          if (transitions.indexOf(animation.css) < 0) {
            transitions.push(animation.css);
          }
        }

        style[SC.browser.experimentalStyleNameFor('transition')] = transitions.join(", ");

        // Reset shared object!
        this._SC_TRANSITIONS_ARRAY.length = 0;
      } else {
        // TODO: Do it the JS way
      }
    }
  }

};



SC.View.reopen(
  /** @scope SC.View.prototype */ {

  /** @private Shared object used to avoid continually initializing/destroying objects. */
  _SC_STYLE_MAP: null,

  /**
    layoutStyle describes the current styles to be written to your element
    based on the layout you defined.  Both layoutStyle and frame reset when
    you edit the layout property.  Both are read only.

    Computes the layout style settings needed for the current anchor.

    @type Object
    @readOnly
  */
  layoutStyle: function () {
    var style = this._SC_STYLE_MAP; // Shared object used to avoid continually initializing/destroying objects.

    // Create the object once. Note: This is a shared object; all properties must be overwritten each time.
    if (!style) { style = this._SC_STYLE_MAP = {}; }

    return SC.View.LayoutStyleCalculator.calculate(this, style);

  // 'hasAcceleratedLayer' is dependent on 'layout' so we don't need 'layout' to be a dependency here
    // [CC] contrary to the comment above, we must add 'layout' to the dependencies [/CC]
  }.property('layout', 'hasAcceleratedLayer', 'useStaticLayout').cacheable()

});

/* >>>>>>>>>> BEGIN source/views/view/layout.js */
sc_require("views/view");
sc_require('views/view/layout_style');

/** Select a horizontal layout for various views.*/
SC.LAYOUT_HORIZONTAL = 'sc-layout-horizontal';

/** Select a vertical layout for various views.*/
SC.LAYOUT_VERTICAL = 'sc-layout-vertical';

/**
  Layout properties to take up the full width of a parent view.
*/
SC.FULL_WIDTH = { left: 0, right: 0 };

/**
  Layout properties to take up the full height of a parent view.
*/
SC.FULL_HEIGHT = { top: 0, bottom: 0 };

/**
  Layout properties to center.  Note that you must also specify a width and
  height for this to work.
*/
SC.ANCHOR_CENTER = { centerX: 0, centerY: 0 };

/**
  Layout property for width, height
*/

SC.LAYOUT_AUTO = 'auto';

// Regexes representating valid values for rotation and scale layout properties
SC._ROTATION_VALUE_REGEX = /^\-?\d+(\.\d*)?(rad|deg)$/;
SC._SCALE_VALUE_REGEX = /^\d+(,\d+){0,2}$/;
SC._PERCENT_VALUE_REGEX = /^\-?\d+(\.\d*)?%$/;  // [CC] allow percents [/CC]

SC.View.reopen(
  /** @scope SC.View.prototype */ {

  // ------------------------------------------------------------------------
  // Properties
  //

  /* @private Internal variable used to check for layout changes that resize. */
  _sc_previousLayout: null,

  /**
    The view's background color. Only recommended for use during prototyping and in views
    where the background color may change arbitrarily, for example in connection with an
    instance of `SC.Color`. Otherwise you should use CSS and `classNames` or
    `classNameBindings`.

    If set at create time, will be added to the view's layer. For dynamic background colors,
    you must add `backgroundColor` to the view's `displayProperties`.

    @type String
    @default null
  */
  backgroundColor: null,

  /**
    The frame of the view including the borders and scale
  */
  borderFrame: function () {
    var frame = this.get('frame'),
        ret = null;

    if (frame) {
      /*jshint eqnull:true */
      var layout = this.get('layout'),
        defaultValue = layout.border == null ? 0 : layout.border,
        borderTop = this._sc_explicitValueFor(layout.borderTop, defaultValue),
        borderRight = this._sc_explicitValueFor(layout.borderRight, defaultValue),
        borderBottom = this._sc_explicitValueFor(layout.borderBottom, defaultValue),
        borderLeft = this._sc_explicitValueFor(layout.borderLeft, defaultValue);

      ret = {
          x: frame.x,
          y: frame.y,
          width: frame.width,
          height: frame.height
        };

      var scale = frame.scale;
      /*jshint eqnull:true*/
      if (scale != null) {
        var scaledBorderTop = borderTop * scale,
            scaledBorderRight = borderRight * scale,
            scaledBorderBottom = borderBottom * scale,
            scaledBorderLeft = borderLeft * scale;

        ret.scale = scale;
        ret.x -= scaledBorderLeft;
        ret.y -= scaledBorderTop;
        ret.width += scaledBorderLeft + scaledBorderRight;
        ret.height += scaledBorderTop + scaledBorderBottom;
      } else {
        ret.x -= borderLeft;
        ret.y -= borderTop;
        ret.width += borderLeft + borderRight;
        ret.height += borderTop + borderBottom;
      }

      if (frame.transformOriginX != null) {
        ret.transformOriginX = frame.transformOriginX;
      }

      if (frame.transformOriginY != null) {
        ret.transformOriginY = frame.transformOriginY;
      }
    }

    return ret;
  }.property('frame').cacheable(),


  /**
    This this property to YES whenever the view needs to layout its child
    views.  Normally this property is set automatically whenever the layout
    property for a child view changes.

    @type Boolean
  */
  childViewsNeedLayout: NO,

  /**
    The child view layout plugin to use when laying out child views.

    You can set this property to a child layout plugin object to
    automatically set and adjust the layouts of this view's child views
    according to some specific layout style.  For instance, SproutCore includes
    two such plugins, SC.View.VERTICAL_STACK and SC.View.HORIZONTAL_STACK.

    SC.View.VERTICAL_STACK will arrange child views in order in a vertical
    stack, which only requires that the height of each child view be specified.
    Likewise, SC.View.HORIZONTAL_STACK does the same in the horizontal
    direction, which requires that the width of each child view be specified.

    Where child layout plugins are extremely useful, besides simplifying
    the amount of layout code you need to write, is that they can update the
    layouts automatically as things change.  For more details and examples,
    please see the documentation for SC.View.VERTICAL_STACK and
    SC.View.HORIZONTAL_STACK.

    To define your own child view layout plugin, simply create an object that
    conforms to the SC.ChildViewLayoutProtocol protocol.

    **Note** This should only be set once and is not bindable.

    @type Object
    @default null
   */
  childViewLayout: null,

  /**
    The options for the given child view layout plugin.

    These options are specific to the current child layout plugin being used and
    are used to modify the applied layouts.  For example, SC.View.VERTICAL_STACK
    accepts options like:

        childViewLayoutOptions: {
          paddingAfter: 20,
          paddingBefore: 20,
          spacing: 10
        }

    To determine what options may be used for a given plugin and to see what the
    default options are, please refer to the documentation for the child layout
    plugin being used.

    @type Object
    @default null
  */
  childViewLayoutOptions: null,

  /** @private The explicit layout of the view, computed from the layout using the explicit position. */
  explicitLayout: function () {
    var layout = this.get('layout'),
        ret = null;

    if (layout) {
      ret = this._sc_computeExplicitLayout(layout);
    }

    return ret;
  }.property('layout').cacheable(),

  /**
    Walks like a duck. Is `true` to indicate that a view has layout support.
  */
  hasLayout: true,

  /**
    Whether the view and its child views should be monitored for changes that
    affect the current child view layout.

    When `true` and using a childViewLayout plugin, the view and its child views
    will be observed for any changes that would affect the layout of all the
    child views.  For example, if `isChildViewLayout` is true and using
    SC.View.VERTICAL_STACK, if any child view's height or visibility changes
    all of the child views will be re-adjusted.

    If you only want to automatically layout the child views once, you can
    set this to `false` to improve performance.

    @type Boolean
    @default true
  */
  isChildViewLayoutLive: true,

  /**
    Returns whether the height is 'fixed' or not. A fixed height is defined on the layout
    as an integer number of pixels.  Fixed widths are therefore unaffected by changes
    to their parent view's height.

    @field
    @returns {Boolean} YES if fixed, NO otherwise
    @test in layout
  */
  isFixedHeight: function() {
    var layout = this.get('layout');

    // Height is fixed if it has a height and it isn't SC.LAYOUT_AUTO or a percent.
    return (layout.height !== undefined) &&
      !SC.isPercentage(layout.height) &&
      (layout.height !== SC.LAYOUT_AUTO);
  }.property('layout').cacheable(),

  /**
    Returns whether the layout is 'fixed' or not.  A fixed layout means a
    fixed left & top position and fixed width & height.  Fixed layouts are
    therefore unaffected by changes to their parent view's layout.

    @returns {Boolean} YES if fixed, NO otherwise
    @test in layoutStyle
  */
  isFixedLayout: function () {
    return this.get('isFixedPosition') && this.get('isFixedSize');
  }.property('isFixedPosition', 'isFixedSize').cacheable(),

  /**
    Returns whether the position is 'fixed' or not.  A fixed position means a
    fixed left & top position within its parent's frame.  Fixed positions are
    therefore unaffected by changes to their parent view's size.

    @field
    @returns {Boolean} YES if fixed, NO otherwise
    @test in layoutStyle
  */
  isFixedPosition: function () {
    var explicitLayout = this.get('explicitLayout'),
      left = explicitLayout.left,
      top = explicitLayout.top,
      hasFixedLeft,
      hasFixedTop;

    // Position is fixed if it has left + top, but not as percentages and not as SC.LAYOUT_AUTO.
    hasFixedLeft = left !== undefined && !SC.isPercentage(left) && left !== SC.LAYOUT_AUTO;
    hasFixedTop = top !== undefined && !SC.isPercentage(top) && top !== SC.LAYOUT_AUTO;

    return hasFixedLeft && hasFixedTop;
  }.property('explicitLayout').cacheable(),

  /**
    Returns whether the size is 'fixed' or not.  A fixed size means a fixed
    width and height.  Fixed sizes are therefore unaffected by changes to their
    parent view's size.

    @field
    @returns {Boolean} YES if fixed, NO otherwise
    @test in layout
  */
  isFixedSize: function () {
    return this.get('isFixedHeight') && this.get('isFixedWidth');
  }.property('isFixedWidth', 'isFixedHeight').cacheable(),

  /**
    Returns whether the width is 'fixed' or not. A fixed width is defined on the layout
    as an integer number of pixels.  Fixed widths are therefore unaffected by changes
    to their parent view's width.

    @field
    @returns {Boolean} YES if fixed, NO otherwise
    @test in layout
  */
  isFixedWidth: function() {
    var layout = this.get('layout');

    // Width is fixed if it has a width and it isn't SC.LAYOUT_AUTO or a percent.
    return (layout.width !== undefined) &&
      !SC.isPercentage(layout.width) &&
      (layout.width !== SC.LAYOUT_AUTO);
  }.property('layout').cacheable(),

  /**
    Set the layout to a hash of layout properties to describe in detail how your view
    should be positioned on screen. Like most application development environments,
    your views are laid out absolutely, relative to their parent view.

    You can define your layout using combinations of the following positional properties:

     - left
     - top
     - right
     - bottom
     - height
     - width
     - centerX: offset from center, horizontally
     - centerY: offset from center, vertically
     - minWidth
     - minHeight
     - maxWidth
     - maxHeight
     - scale: once positioned, scales the view in place.
     - transformOriginX, transformOriginY: defines the point (as a decimal percentage) around which
       your view will scale. (Also impacts rotation; see below.)

    They are processed by SproutCore's layout engine and used to position the view's element onscreen. They are
    also reliably and speedily processed into a scaled rectangle (with x, y, height, width, scale and origin
    values) available on the frame property. See documentation on it and the clippingFrame property for more.

    Most of these properties take integer numbers of pixels, for example { left: 10 }, or fractional
    percentages like { left 0.25 }. Exceptions include scale, which takes a scale factor (e.g. { scale:
    2 } doubles the view's size), and transformOriginX/Y which take a decimal percent, and default to 0.5
    (the center of the view).

    It's possible to define very sophisticated layouts with these properties alone. For example, you
    can define a view which takes up the full screen until it reaches a certain width, and aligns to
    the left thereafter, with { left: 0, right: 0, maxWidth: 400 }. (If you need the flexibility to
    assign entirely different layouts at different screen or window sizes, see the Design Modes
    documentation under SC.Application.)

    Certain layout combinations are nonsensical and of course should be avoided. For example, you
    can use left + right or left + width, but not left + right + width.

    If your view has a CSS border, it's important that you specify its thickness in the layout hash,
    using one or more of the following border properties, as well as in your CSS. This is an unfortunate
    bit of repetition, but it's necessary to allow SproutCore to adjust the layout to compensate. (HTML
    positions borders outside of the body of an element; SproutCore positions them inside their rectangles.)

     - border: border thickness on all sides
     - borderTop: top border thickness
     - borderRight: right border thickness
     - borderBottom: bottom border thickness
     - borderLeft: bottom left thickness

    You can also use the following layout properties, which don't impact your view's frame.

     - opacity: the opacity of the view
     - rotate: once positioned, rotates the view in place.
     - zIndex: position above or below other views (Not recommended. Control sibling view
       overlay with childView order (later views draw above earlier views) where possible.)

    To change a layout property, you should use the adjust method, which handles some particulars for you.

    @type Object
    @default { top: 0, left: 0, bottom: 0, right: 0 }
    @test in layoutStyle
  */
  layout: { top: 0, left: 0, bottom: 0, right: 0 },

  /**
    The view responsible for laying out this view.  The default version
    returns the current parent view.
  */
  layoutView: function () {
    return this.get('parentView');
  }.property('parentView').cacheable(),

  /**
    The transition plugin to use when this view is moved or resized by adjusting
    its layout.

    SC.CoreView uses a pluggable transition architecture where the transition
    setup, execution and cleanup can be handled by a plugin.  This allows you
    to create complex transition animations and share them across all your views
    with only a single line of code.

    There are a number of pre-built transition adjust plugins available in
    the SproutCore foundation framework:

      SC.View.SMOOTH_ADJUST
      SC.View.BOUNCE_ADJUST
      SC.View.SPRING_ADJUST

    To create a custom transition plugin simply create a regular JavaScript
    object that conforms to the SC.ViewTransitionProtocol protocol.

    NOTE: When creating custom transition adjust plugins, be aware that SC.View
    will not call the `setup` method of the plugin, only the `run` method.

    @type Object (SC.ViewTransitionProtocol)
    @default null
    @since Version 1.10
  */
  transitionAdjust: null,

  /**
    The options for the given `transitionAdjust` plugin.

    These options are specific to the current transition plugin used and are
    used to modify the transition animation.  To determine what options
    may be used for a given plugin and to see what the default options are,
    see the documentation for the transition plugin being used.

    Most transitions will accept a duration and timing option, but may
    also use other options.  For example, SC.View.BOUNCE_ADJUST accepts options
    like:

        transitionAdjustOptions: {
          bounciness: 0.5, // how much the adjustment should bounce back each time
          bounces: 4, // the number of bounces
          duration: 0.25,
          delay: 1
        }

    @type Object
    @default null
    @since Version 1.10
  */
  transitionAdjustOptions: null,

  /**
    Activates use of brower's static layout. To activate, set this property to YES.

    @type Boolean
    @default NO
  */
  useStaticLayout: NO,

  // ------------------------------------------------------------------------
  // Methods
  //

  /** @private */
  _sc_adjustForBorder: function (frame, layout) {
    /*jshint eqnull:true */
    var defaultValue = layout.border == null ? 0 : layout.border,
        borderTop = this._sc_explicitValueFor(layout.borderTop, defaultValue),
        borderLeft = this._sc_explicitValueFor(layout.borderLeft, defaultValue),
        borderBottom = this._sc_explicitValueFor(layout.borderBottom, defaultValue),
        borderRight = this._sc_explicitValueFor(layout.borderRight, defaultValue);

    frame.x += borderLeft; // The border on the left pushes the frame to the right
    frame.y += borderTop; // The border on the top pushes the frame down
    frame.width -= (borderLeft + borderRight); // Border takes up space
    frame.height -= (borderTop + borderBottom); // Border takes up space

    return frame;
  },

  /** @private */
  _sc_adjustForScale: function (frame, layout) {

    // Scale not supported on this platform, ignore the layout values.
    if (!SC.platform.supportsCSSTransforms) {
      frame.scale = 1;
      frame.transformOriginX = frame.transformOriginY = 0.5;

    // Use scale.
    } else {

      // Get the scale and transform origins, if not provided. (Note inlining of SC.none for performance)
      /*jshint eqnull:true*/
      var scale = layout.scale,
          oX = layout.transformOriginX,
          oY = layout.transformOriginY;

      // If the scale is set and isn't 1, do some calculations.
      if (scale != null && scale !== 1) {
        // Scale the rect.
        frame = SC.scaleRect(frame, scale, oX, oY);

        // Add the scale and original unscaled height and width.
        frame.scale = scale;
      }

      // If the origin is set and isn't 0.5, include it.
      if (oX != null && oX !== 0.5) {
        frame.transformOriginX = oX;
      }

      // If the origin is set and isn't 0.5, include it.
      if (oY != null && oY !== 0.5) {
        frame.transformOriginY = oY;
      }
    }

    // Make sure width/height are never < 0.
    if (frame.height < 0) frame.height = 0;
    if (frame.width < 0) frame.width = 0;

    return frame;
  },

  /** @private Apply the adjustment to a clone of the layout (cloned unless newLayout is passed in) */
  _sc_applyAdjustment: function (key, newValue, layout, newLayout) {
    var animateLayout = this._animateLayout;

    // If a call to animate occurs in the same run loop, the animation layout
    // would still be applied in the next run loop, potentially overriding this
    // adjustment. So we need to cancel the animation layout.
    if (animateLayout) {
      if (newValue === null) {
        delete animateLayout[key];
      } else {
        animateLayout[key] = newValue;
      }

      if (this._pendingAnimations && this._pendingAnimations[key]) {
        // Adjusting a value that was about to be animated cancels the animation.
        delete this._pendingAnimations[key];
      }

    }

    // Ignore undefined values or values equal to the current value.
    /*jshint eqeqeq:false*/
    if (newValue !== undefined && layout[key] != newValue) { // coerced so '100' == 100
      // Only clone the layout if it is not given.
      if (!newLayout) newLayout = SC.clone(this.get('layout'));

      if (newValue === null) {
        delete newLayout[key];
      } else {
        newLayout[key] = newValue;
      }
    }

    return newLayout;
  },

  /** @private */
  _sc_checkForResize: function (previousLayout, currentLayout) {
    // Did our layout change in a way that could cause us to have changed size?  If
    // not, then there's no need to invalidate the frames of our child views.
    var didResizeHeight = true,
        didResizeWidth = true,
        didResize = true;

    // We test the new layout to see if we believe it will affect the view's frame.
    // Since all the child view frames may depend on the parent's frame, it's
    // best only to notify a frame change when it actually happens.
    /*jshint eqnull:true*/

    // Simple test: Width is defined and hasn't changed.
    // Complex test: No defined width, left or right haven't changed.
    if (previousLayout != null &&
        ((previousLayout.width != null &&
          previousLayout.width === currentLayout.width) ||
         (previousLayout.width == null &&
           currentLayout.width == null &&
           previousLayout.left === currentLayout.left &&
           previousLayout.right === currentLayout.right))) {
      didResizeWidth = false;
    }

    // Simple test: Height is defined and hasn't changed.
    // Complex test: No defined height, top or bottom haven't changed.
    if (!didResizeWidth &&
        ((previousLayout.height != null &&
          previousLayout.height === currentLayout.height) ||
         (previousLayout.height == null &&
           currentLayout.height == null &&
           previousLayout.top === currentLayout.top &&
           previousLayout.bottom === currentLayout.bottom))) {
      didResizeHeight = false;
    }

    // Border test: Even if the width & height haven't changed, a change in a border would be a resize.
    if (!didResizeHeight && !didResizeWidth) {
      didResize = !(previousLayout.border === currentLayout.border &&
              previousLayout.borderTop === currentLayout.borderTop &&
              previousLayout.borderLeft === currentLayout.borderLeft &&
              previousLayout.borderBottom === currentLayout.borderBottom &&
              previousLayout.borderRight === currentLayout.borderRight);
    }

    return didResize;
  },

  /** @private Called when the child view layout plugin or options change. */
  _cvl_childViewLayoutDidChange: function () {
    this.set('childViewsNeedLayout', true);

    // Filter the input channel.
    this.invokeOnce(this.layoutChildViewsIfNeeded);
  },

  /** @private Called when the child views change. */
  _cvl_childViewsDidChange: function () {
    this._cvl_teardownChildViewsLiveLayout();
    this._cvl_setupChildViewsLiveLayout();

    this.set('childViewsNeedLayout', true);

    // Filter the input channel.
    this.invokeOnce(this.layoutChildViewsIfNeeded);
  },

  /** @private Add observers to the child views for automatic child view layout. */
  _cvl_setupChildViewsLiveLayout: function () {
    var childViewLayout = this.childViewLayout,
      childViews,
      childLayoutProperties = childViewLayout.childLayoutProperties || [];

    // Create a reference to the current child views so that we can clean them if they change.
    childViews = this._cvl_childViews = this.get('childViews');
    for (var i = 0, len = childLayoutProperties.length; i < len; i++) {
      var observedProperty = childLayoutProperties[i];

      for (var j = 0, jlen = childViews.get('length'); j < jlen; j++) {
        var childView = childViews.objectAt(j);
        if (!childView.get('useAbsoluteLayout') && !childView.get('useStaticLayout')) {
          childView.addObserver(observedProperty, this, this._cvl_childViewLayoutDidChange);
        }
      }
    }
  },

  /** @private Remove observers from the child views for automatic child view layout. */
  _cvl_teardownChildViewsLiveLayout: function () {
    var childViewLayout = this.childViewLayout,
      childViews = this._cvl_childViews || [],
      childLayoutProperties = childViewLayout.childLayoutProperties || [];

    for (var i = 0, len = childLayoutProperties.length; i < len; i++) {
      var observedProperty = childLayoutProperties[i];

      for (var j = 0, jlen = childViews.get('length'); j < jlen; j++) {
        var childView = childViews.objectAt(j);
        if (!childView.get('useAbsoluteLayout') && !childView.get('useStaticLayout')) {
          childView.removeObserver(observedProperty, this, this._cvl_childViewLayoutDidChange);
        }
      }
    }
  },

  /** @private Computes the explicit layout. */
  _sc_computeExplicitLayout: function (layout) {
    var ret = SC.copy(layout);

    /* jshint eqnull:true */
    var hasBottom = (layout.bottom != null);
    var hasRight = (layout.right != null);
    var hasLeft = (layout.left != null);
    var hasTop = (layout.top != null);
    var hasCenterX = (layout.centerX != null);
    var hasCenterY = (layout.centerY != null);
    var hasHeight = (layout.height != null); //  || (layout.maxHeight != null)
    var hasWidth = (layout.width != null); // || (layout.maxWidth != null)

    /*jshint eqnull:true */
    // Left + Top take precedence (left & right & width becomes left & width).
    delete ret.right; // Right will be set if needed below.
    delete ret.bottom; // Bottom will be set if needed below.

    if (hasLeft) {
      ret.left = layout.left;
    } else if (!hasCenterX && !(hasWidth && hasRight)) {
      ret.left = 0;
    }

    if (hasRight && !(hasLeft && hasWidth)) {
      ret.right = layout.right;
    } else if (!hasCenterX && !hasWidth) {
      ret.right = 0;
    }

    


    if (hasTop) {
      ret.top = layout.top;
    } else if (!hasCenterY && !(hasHeight && hasBottom)) {
      ret.top = 0;
    }

    if (hasBottom && !(hasTop && hasHeight)) {
      ret.bottom = layout.bottom;
    } else if (!hasCenterY && !hasHeight) {
      ret.bottom = 0;
    }

    


    // CENTERS
    if (hasCenterX) {
      ret.centerX = layout.centerX;

      

    }

    if (hasCenterY) {
      ret.centerY = layout.centerY;

      

    }

    // BORDERS
    // Apply border first, so that the more specific borderX values will override it next.
    var border = layout.border;
    if (border != null) {
      ret.borderTop = border;
      ret.borderRight = border;
      ret.borderBottom = border;
      ret.borderLeft = border;
      delete ret.border;
    }

    // Override generic border with more specific borderX.
    if (layout.borderTop != null) {
      ret.borderTop = layout.borderTop;
    }
    if (layout.borderRight != null) {
      ret.borderRight = layout.borderRight;
    }
    if (layout.borderBottom != null) {
      ret.borderBottom = layout.borderBottom;
    }
    if (layout.borderLeft != null) {
      ret.borderLeft = layout.borderLeft;
    }

    return ret;
  },

  /** @private */
  _sc_convertFrameFromViewHelper: function (frame, fromView, targetView) {
    var myX = frame.x, myY = frame.y, myWidth = frame.width, myHeight = frame.height, view, f;

    // first, walk up from the view of the frame, up to the top level
    if (fromView) {
      view = fromView;
      //Note: Intentional assignment of variable f
      while (view && (f = view.get('frame'))) {

        // if scale != 1, then multiple by the scale (going from view to parent)
        if (f.scale && f.scale !== 1) {
          myX *= f.scale;
          myY *= f.scale;
          myWidth *= f.scale;
          myHeight *= f.scale;
        }

        myX += f.x;
        myY += f.y;

        view = view.get('layoutView');
      }
    }

    // now, we'll walk down from the top level to the target view

    // construct an array of view ancestry, from
    // the top level view down to the target view
    if (targetView) {
      var viewAncestors = [];
      view = targetView;

      while (view && view.get('frame')) {
        viewAncestors.unshift(view);
        view = view.get('layoutView');
      }

      // now walk the frame from
      for (var i = 0; i < viewAncestors.length; i++ ) {
        view = viewAncestors[i];
        f = view.get('frame');

        myX -= f.x;
        myY -= f.y;

        if (f.scale && f.scale !== 1) {
          myX /= f.scale;
          myY /= f.scale;
          myWidth /= f.scale;
          myHeight /= f.scale;
        }
      }
    }

    return { x: myX, y: myY, width: myWidth, height: myHeight };
  },

  /** @private */
  _sc_explicitValueFor: function (givenValue, impliedValue) {
    return givenValue === undefined ? impliedValue : givenValue;
  },

  /** @private Attempts to run a transition adjust, ensuring any showing transitions are stopped in place. */
  _sc_transitionAdjust: function (layout) {
    var transitionAdjust = this.get('transitionAdjust'),
      options = this.get('transitionAdjustOptions') || {};

    // Execute the adjusting transition.
    transitionAdjust.run(this, options, layout);
  },

  /** @private
    Invoked by other views to notify this view that its frame has changed.

    This notifies the view that its frame property has changed,
    then notifies its child views that their clipping frames may have changed.
  */
  _sc_viewFrameDidChange: function () {
    this.notifyPropertyChange('frame');

    // Notify the children that their clipping frame may have changed. Top-down, because a child's
    // clippingFrame is dependent on its parent's frame.
    this._callOnChildViews('_sc_clippingFrameDidChange');
  },

  /**
    This convenience method will take the current layout, apply any changes
    you pass and set it again.  It is more convenient than having to do this
    yourself sometimes.

    You can pass just a key/value pair or a hash with several pairs.  You can
    also pass a null value to delete a property.

    This method will avoid actually setting the layout if the value you pass
    does not edit the layout.

    @param {String|Hash} key
    @param {Object} value
    @returns {SC.View} receiver
  */
  adjust: function (key, value) {
    if (key === undefined) { return this; } // FAST PATH! Nothing to do.

    var layout = this.get('layout'),
      newLayout;

    // Normalize arguments.
    if (SC.typeOf(key) === SC.T_STRING) {
      newLayout = this._sc_applyAdjustment(key, value, layout);
    } else {
      for (var aKey in key) {
        if (!key.hasOwnProperty(aKey)) { continue; }

        newLayout = this._sc_applyAdjustment(aKey, key[aKey], layout, newLayout);
      }
    }

    // now set adjusted layout
    if (newLayout) {
      var transitionAdjust = this.get('transitionAdjust');

      if (this.get('viewState') & SC.CoreView.IS_SHOWN && transitionAdjust) {
        // Run the adjust transition.
        this._sc_transitionAdjust(newLayout);
      } else {
        this.set('layout', newLayout);
      }
    }

    return this;
  },

  /** */
  computeParentDimensions: function (frame) {
    var parentView = this.get('parentView'),
        parentFrame = (parentView) ? parentView.get('frame') : null,
        ret;

    if (parentFrame) {
      ret = {
        width: parentFrame.width,
        height: parentFrame.height
      };
    } else if (frame) {
      ret = {
        width: (frame.left || 0) + (frame.width || 0) + (frame.right || 0),
        height: (frame.top || 0) + (frame.height || 0) + (frame.bottom || 0)
      };
    } else {
      ret = {
        width: 0,
        height: 0
      };
    }

    return ret;
  },

  /**
    Converts a frame from the receiver's offset to the target offset.  Both
    the receiver and the target must belong to the same pane.  If you pass
    null, the conversion will be to the pane level.

    Note that the context of a view's frame is the view's parent frame.  In
    other words, if you want to convert the frame of your view to the global
    frame, then you should do:

        var pv = this.get('parentView'), frame = this.get('frame');
        var newFrame = pv ? pv.convertFrameToView(frame, null) : frame;

    @param {Rect} frame the source frame
    @param {SC.View} targetView the target view to convert to
    @returns {Rect} converted frame
    @test in convertFrames
  */
  convertFrameToView: function (frame, targetView) {
    return this._sc_convertFrameFromViewHelper(frame, this, targetView);
  },

  /**
    Converts a frame offset in the coordinates of another view system to the
    receiver's view.

    Note that the convext of a view's frame is relative to the view's
    parentFrame.  For example, if you want to convert the frame of view that
    belongs to another view to the receiver's frame you would do:

        var frame = view.get('frame');
        var newFrame = this.convertFrameFromView(frame, view.get('parentView'));

    @param {Rect} frame the source frame
    @param {SC.View} targetView the target view to convert to
    @returns {Rect} converted frame
    @test in converFrames
  */
  convertFrameFromView: function (frame, targetView) {
    return this._sc_convertFrameFromViewHelper(frame, targetView, this);
  },

  /** @private */
  didTransitionAdjust: function () {},

  /**
    This method is called whenever a property changes that invalidates the
    layout of the view.  Changing the layout will do this automatically, but
    you can add others if you want.

    Implementation Note:  In a traditional setup, we would simply observe
    'layout' here, but as described above in the documentation for our custom
    implementation of propertyDidChange(), this method must always run
    immediately after 'layout' is updated to avoid the potential for stale
    (incorrect) cached 'frame' values.

    @returns {SC.View} receiver
  */
  layoutDidChange: function () {
    var currentLayout = this.get('layout');

    // Handle old style rotation.
    if (!SC.none(currentLayout.rotate)) {
      if (SC.none(currentLayout.rotateZ) && SC.platform.get('supportsCSS3DTransforms')) {
        currentLayout.rotateZ = currentLayout.rotate;
        delete currentLayout.rotate;
      }
    }

    // Optimize notifications depending on if we resized or just moved.
    var didResize = this._sc_checkForResize(this._sc_previousLayout, currentLayout);

    // Cache the last layout to fine-tune notifications when the layout changes.
    // NOTE: Do this before continuing so that any adjustments that occur in viewDidResize or from
    //  _sc_viewFrameDidChange (say to the position after a resize), don't result in _sc_checkForResize
    //  running against the old _sc_previousLayout.
    this._sc_previousLayout = currentLayout;

    if (didResize) {
      this.viewDidResize();
    } else {
      // Even if we didn't resize, our frame sould have changed.
      // TODO: consider checking for position changes by testing the resulting frame against the cached frame. This is difficult to do.
      this._sc_viewFrameDidChange();
    }

    // Notify layoutView/parentView, unless we are transitioning.
    var layoutView = this.get('layoutView');
    if (layoutView) {
      layoutView.set('childViewsNeedLayout', YES);
      layoutView.layoutDidChangeFor(this);

      // Check if childViewsNeedLayout is still true.
      if (layoutView.get('childViewsNeedLayout')) {
        layoutView.invokeOnce(layoutView.layoutChildViewsIfNeeded);
      }
    } else {
      this.invokeOnce(this.updateLayout);
    }

    return this;
  },

  /**
    One of two methods that are invoked whenever one of your childViews
    layout changes.  This method is invoked every time a child view's layout
    changes to give you a chance to record the information about the view.

    Since this method may be called many times during a single run loop, you
    should keep this method pretty short.  The other method called when layout
    changes, layoutChildViews(), is invoked only once at the end of
    the run loop.  You should do any expensive operations (including changing
    a childView's actual layer) in this other method.

    Note that if as a result of running this method you decide that you do not
    need your layoutChildViews() method run later, you can set the
    childViewsNeedsLayout property to NO from this method and the layout
    method will not be called layer.

    @param {SC.View} childView the view whose layout has changed.
    @returns {void}
  */
  layoutDidChangeFor: function (childView) {
    var set = this._needLayoutViews;

    // Track this view.
    if (!set) set = this._needLayoutViews = SC.CoreSet.create();
    set.add(childView);
  },

  /**
    Called your layout method if the view currently needs to layout some
    child views.

    @param {Boolean} force if true assume view is visible even if it is not.
    @returns {SC.View} receiver
    @test in layoutChildViews
  */
  layoutChildViewsIfNeeded: function (force) {
    if (this.get('childViewsNeedLayout')) {
      this.layoutChildViews(force);

      this.set('childViewsNeedLayout', NO);
    }

    return this;
  },

  /**
    Applies the current layout to the layer.  This method is usually only
    called once per runloop.  You can override this method to provide your
    own layout updating method if you want, though usually the better option
    is to override the layout method from the parent view.

    The default implementation of this method simply calls the updateLayout()
    method on the views that need layout.

    @param {Boolean} force Force the update to the layer's layout style immediately even if the view is not in a shown state.  Otherwise the style will be updated when the view returns to a shown state.
    @returns {void}
  */
  layoutChildViews: function (force) {
    var childViewLayout = this.childViewLayout,
      set, len, i;

    // Allow the child view layout plugin to layout all child views.
    if (childViewLayout) {
      // Adjust all other child views right now.
      // Note: this will add the affected child views to the set so they will be updated only once in this run loop
      childViewLayout.layoutChildViews(this);
    }

    // Retreive these values after they may have been updated by adjustments by
    // the childViewLayout plugin.
    set = this._needLayoutViews;
    if (set) {
      for (i = 0, len = set.length; i < len; ++i) {
        set[i].updateLayout(force);
      }

      set.clear(); // reset & reuse
    }
  },

  /**
    This method may be called on your view whenever the parent view resizes.

    The default version of this method will reset the frame and then call
    viewDidResize() if its size may have changed.  You will not usually override
    this method, but you may override the viewDidResize() method.

    @param {Frame} parentFrame the parent view's current frame.
    @returns {void}
    @test in viewDidResize
  */
  parentViewDidResize: function (parentFrame) {
    // Determine if our position may have changed.
    var positionMayHaveChanged = !this.get('isFixedPosition');

    // Figure out if our size may have changed.
    var isStatic = this.get('useStaticLayout'),
        // Figure out whether our height may have changed.
        parentHeight = parentFrame ? parentFrame.height : 0,
        parentHeightDidChange = parentHeight !== this._scv_parentHeight,
        isFixedHeight = this.get('isFixedHeight'),
        heightMayHaveChanged = isStatic || (parentHeightDidChange && !isFixedHeight),
        // Figure out whether our width may have changed.
        parentWidth = parentFrame ? parentFrame.width : 0,
        parentWidthDidChange = parentWidth !== this._scv_parentWidth,
        isFixedWidth = this.get('isFixedWidth'),
        widthMayHaveChanged = isStatic || (parentWidthDidChange && !isFixedWidth);

    // Update the cached parent frame.
    this._scv_parentHeight = parentHeight;
    this._scv_parentWidth = parentWidth;

    // If our height or width changed, our resulting frame change may impact our child views.
    if (heightMayHaveChanged || widthMayHaveChanged) {
      this.viewDidResize();
    }
    // If our size didn't change but our position did, our frame will change, but it won't impact our child
    // views' frames. (Note that the _sc_viewFrameDidChange call is made by viewDidResize above.)
    else if (positionMayHaveChanged) {
      this._sc_viewFrameDidChange();
    }
  },

  /**
    The 'frame' property depends on the 'layout' property as well as the
    parent view's frame.  In order to properly invalidate any cached values,
    we need to invalidate the cache whenever 'layout' changes.  However,
    observing 'layout' does not guarantee that; the observer might not be run
    before all other observers.

    In order to avoid any window of opportunity where the cached frame could
    be invalid, we need to force layoutDidChange() to immediately run
    whenever 'layout' is set.
  */
  propertyDidChange: function (key, value, _keepCache) {
    


    // To allow layout to be a computed property, we check if any property has
    // changed and if layout is dependent on the property.
    var layoutChange = false;
    if (typeof this.layout === "function" && this._kvo_dependents) {
      var dependents = this._kvo_dependents[key];
      if (dependents && dependents.indexOf('layout') !== -1) { layoutChange = true; }
    }

    // If the key is 'layout', we need to call layoutDidChange() immediately
    // so that if the frame has changed any cached values (for both this view
    // and any child views) can be appropriately invalidated.
    if (key === 'layout' || layoutChange) {
      this.layoutDidChange();
    }

    // Resume notification as usual.
    return arguments.callee.base.apply(this,arguments);
  },

  /**
  */
  // propertyWillChange: function (key) {
  //   // To allow layout to be a computed property, we check if any property has
  //   // changed and if layout is dependent on the property.
  //   var layoutChange = false;
  //   if (typeof this.layout === "function" && this._kvo_dependents) {
  //     var dependents = this._kvo_dependents[key];
  //     if (dependents && dependents.indexOf('layout') !== -1) { layoutChange = true; }
  //   }

  //   if (key === 'layout' || layoutChange) {
  //     this._sc_previousLayout = this.get('layout');
  //   }

  //   return arguments.callee.base.apply(this,arguments);
  // },

  /**
    Attempt to scroll the view to visible.  This will walk up the parent
    view hierarchy looking looking for a scrollable view.  It will then
    call scrollToVisible() on it.

    Returns YES if an actual scroll took place, no otherwise.

    @returns {Boolean}
  */
  scrollToVisible: function () {
    var pv = this.get('parentView');
    while (pv && !pv.get('isScrollable')) { pv = pv.get('parentView'); }

    // found view, first make it scroll itself visible then scroll this.
    if (pv) {
      pv.scrollToVisible();
      return pv.scrollToVisible(this);
    } else {
      return NO;
    }
  },

  /**
    This method is invoked on your view when the view resizes due to a layout
    change or potentially due to the parent view resizing (if your view’s size
    depends on the size of your parent view).  You can override this method
    to implement your own layout if you like, such as performing a grid
    layout.

    The default implementation simply notifies about the change to 'frame' and
    then calls parentViewDidResize on all of your children.

    @returns {void}
  */
  viewDidResize: function () {
    this._sc_viewFrameDidChange();

    // Also notify our children.
    var cv = this.childViews,
        frame = this.get('frame'),
        len, idx, view;
    for (idx = 0; idx < (len = cv.length); ++idx) {
      view = cv[idx];
      view.tryToPerform('parentViewDidResize', frame);
    }
  },

  // Implementation note: As a general rule, paired method calls, such as
  // beginLiveResize/endLiveResize that are called recursively on the tree
  // should reverse the order when doing the final half of the call. This
  // ensures that the calls are propertly nested for any cleanup routines.
  //
  // -> View A.beginXXX()
  //   -> View B.beginXXX()
  //     -> View C.beginXXX()
  //   -> View D.beginXXX()
  //
  // ...later on, endXXX methods are called in reverse order of beginXXX...
  //
  //   <- View D.endXXX()
  //     <- View C.endXXX()
  //   <- View B.endXXX()
  // <- View A.endXXX()
  //
  // See the two methods below for an example implementation.

  /**
    Call this method when you plan to begin a live resize.  This will
    notify the receiver view and any of its children that are interested
    that the resize is about to begin.

    @returns {SC.View} receiver
    @test in viewDidResize
  */
  beginLiveResize: function () {
    // call before children have been notified...
    if (this.willBeginLiveResize) this.willBeginLiveResize();

    // notify children in order
    var ary = this.get('childViews'), len = ary.length, idx, view;
    for (idx = 0; idx < len; ++idx) {
      view = ary[idx];
      if (view.beginLiveResize) view.beginLiveResize();
    }
    return this;
  },

  /**
    Call this method when you are finished with a live resize.  This will
    notify the receiver view and any of its children that are interested
    that the live resize has ended.

    @returns {SC.View} receiver
    @test in viewDidResize
  */
  endLiveResize: function () {
    // notify children in *reverse* order
    var ary = this.get('childViews'), len = ary.length, idx, view;
    for (idx = len - 1; idx >= 0; --idx) { // loop backwards
      view = ary[idx];
      if (view.endLiveResize) view.endLiveResize();
    }

    // call *after* all children have been notified...
    if (this.didEndLiveResize) this.didEndLiveResize();
    return this;
  },

  /**
    Invoked by the layoutChildViews method to update the layout on a
    particular view.  This method creates a render context and calls the
    renderLayout() method, which is probably what you want to override instead
    of this.

    You will not usually override this method, but you may call it if you
    implement layoutChildViews() in a view yourself.

    @param {Boolean} force Force the update to the layer's layout style immediately even if the view is not in a shown state.  Otherwise the style will be updated when the view returns to a shown state.
    @returns {SC.View} receiver
    @test in layoutChildViews
  */
  updateLayout: function (force) {
    this._doUpdateLayout(force);

    return this;
  },

  /**
    Default method called by the layout view to actually apply the current
    layout to the layer.  The default implementation simply assigns the
    current layoutStyle to the layer.  This method is also called whenever
    the layer is first created.

    @param {SC.RenderContext} the render context
    @returns {void}
    @test in layoutChildViews
  */
  renderLayout: function (context) {
    context.setStyle(this.get('layoutStyle'));
  },

  // ------------------------------------------------------------------------
  // Statechart
  //

  /** @private Update this view's layout action. */
  _doUpdateLayout: function (force) {
    var isRendered = this.get('_isRendered'),
      isVisibleInWindow = this.get('isVisibleInWindow'),
      handled = true;

    if (isRendered) {
      if (isVisibleInWindow || force) {
        // Only in the visible states do we allow updates without being forced.
        this._doUpdateLayoutStyle();
      } else {
        // Otherwise mark the view as needing an update when we enter a shown state again.
        this._layoutStyleNeedsUpdate = true;
      }
    } else {
      handled = false;
    }

    return handled;
  },

  /** @private */
  _doUpdateLayoutStyle: function () {
    var layer = this.get('layer'),
      layoutStyle = this.get('layoutStyle');

    for (var styleName in layoutStyle) {
      layer.style[styleName] = layoutStyle[styleName];
    }

    // Reset that an update is required.
    this._layoutStyleNeedsUpdate = false;

    // Notify updated.
    this._updatedLayout();
  },

  /** @private Override: Notify on attached (avoids notify of frame changed). */
  _notifyDidAttach: function () {
    // If we are using static layout then we don't know the frame until appended to the document.
    if (this.get('useStaticLayout')) {
      // We call viewDidResize so that it calls parentViewDidResize on all child views.
      this.viewDidResize();
    }

    // Notify.
    if (this.didAppendToDocument) { this.didAppendToDocument(); }
  },

  /** @private Override: The 'adopted' event (uses isFixedSize so our childViews are notified if our frame changes). */
  _adopted: function (beforeView) {
    // If our size depends on our parent, it will have changed on adoption.
    var isFixedSize = this.get('isFixedSize');
    if (isFixedSize) {
      // Even if our size is fixed, our frame may have changed (in particular if the anchor is not top/left)
      this._sc_viewFrameDidChange();
    } else {
      this.viewDidResize();
    }

    arguments.callee.base.apply(this,arguments);
  },

  /** @private Extension: The 'orphaned' event (uses isFixedSize so our childViews are notified if our frame changes). */
  _orphaned: function () {
    arguments.callee.base.apply(this,arguments);

    if (!this.isDestroyed) {
      // If our size depends on our parent, it will have changed on orphaning.
      var isFixedSize = this.get('isFixedSize');
      if (isFixedSize) {
      // Even if our size is fixed, our frame may have changed (in particular if the anchor is not top/left)
      this._sc_viewFrameDidChange();
      } else {
        this.viewDidResize();
      }
    }
  },

  /** @private Extension: The 'updatedContent' event. */
  _updatedContent: function () {
    arguments.callee.base.apply(this,arguments);

    // If this view uses static layout, then notify that the frame (likely)
    // changed.
    if (this.get('useStaticLayout')) { this.viewDidResize(); }
  },

  /** @private The 'updatedLayout' event. */
  _updatedLayout: function () {
    // Notify.
    this.didRenderAnimations();
  }

});

SC.View.mixin(
  /** @scope SC.View */ {

  /**
    Convert any layout to a Top, Left, Width, Height layout
  */
  convertLayoutToAnchoredLayout: function (layout, parentFrame) {
    var ret = {top: 0, left: 0, width: parentFrame.width, height: parentFrame.height},
        pFW = parentFrame.width, pFH = parentFrame.height, //shortHand for parentDimensions
        lR = layout.right,
        lL = layout.left,
        lT = layout.top,
        lB = layout.bottom,
        lW = layout.width,
        lH = layout.height,
        lcX = layout.centerX,
        lcY = layout.centerY;

    // X Conversion
    // handle left aligned and left/right
    if (!SC.none(lL)) {
      if (SC.isPercentage(lL)) ret.left = lL * pFW;
      else ret.left = lL;
      if (lW !== undefined) {
        if (lW === SC.LAYOUT_AUTO) ret.width = SC.LAYOUT_AUTO;
        else if (SC.isPercentage(lW)) ret.width = lW * pFW;
        else ret.width = lW;
      } else {
        if (lR && SC.isPercentage(lR)) ret.width = pFW - ret.left - (lR * pFW);
        else ret.width = pFW - ret.left - (lR || 0);
      }

    // handle right aligned
    } else if (!SC.none(lR)) {

      // if no width, calculate it from the parent frame
      if (SC.none(lW)) {
        ret.left = 0;
        if (lR && SC.isPercentage(lR)) ret.width = pFW - (lR * pFW);
        else ret.width = pFW - (lR || 0);

      // If has width, calculate the left anchor from the width and right and parent frame
      } else {
        if (lW === SC.LAYOUT_AUTO) ret.width = SC.LAYOUT_AUTO;
        else {
          if (SC.isPercentage(lW)) ret.width = lW * pFW;
          else ret.width = lW;
          if (SC.isPercentage(lR)) ret.left = pFW - (ret.width + lR);
          else ret.left = pFW - (ret.width + lR);
        }
      }

    // handle centered
    } else if (!SC.none(lcX)) {
      if (lW && SC.isPercentage(lW)) ret.width = (lW * pFW);
      else ret.width = (lW || 0);
      ret.left = ((pFW - ret.width) / 2);
      if (SC.isPercentage(lcX)) ret.left = ret.left + lcX * pFW;
      else ret.left = ret.left + lcX;

    // if width defined, assume left of zero
    } else if (!SC.none(lW)) {
      ret.left =  0;
      if (lW === SC.LAYOUT_AUTO) ret.width = SC.LAYOUT_AUTO;
      else {
        if (SC.isPercentage(lW)) ret.width = lW * pFW;
        else ret.width = lW;
      }

    // fallback, full width.
    } else {
      ret.left = 0;
      ret.width = 0;
    }

    // handle min/max
    if (layout.minWidth !== undefined) ret.minWidth = layout.minWidth;
    if (layout.maxWidth !== undefined) ret.maxWidth = layout.maxWidth;

    // Y Conversion
    // handle left aligned and top/bottom
    if (!SC.none(lT)) {
      if (SC.isPercentage(lT)) ret.top = lT * pFH;
      else ret.top = lT;
      if (lH !== undefined) {
        if (lH === SC.LAYOUT_AUTO) ret.height = SC.LAYOUT_AUTO;
        else if (SC.isPercentage(lH)) ret.height = lH * pFH;
        else ret.height = lH;
      } else {
        ret.height = pFH - ret.top;
        if (lB && SC.isPercentage(lB)) ret.height = ret.height - (lB * pFH);
        else ret.height = ret.height - (lB || 0);
      }

    // handle bottom aligned
    } else if (!SC.none(lB)) {

      // if no height, calculate it from the parent frame
      if (SC.none(lH)) {
        ret.top = 0;
        if (lB && SC.isPercentage(lB)) ret.height = pFH - (lB * pFH);
        else ret.height = pFH - (lB || 0);

      // If has height, calculate the top anchor from the height and bottom and parent frame
      } else {
        if (lH === SC.LAYOUT_AUTO) ret.height = SC.LAYOUT_AUTO;
        else {
          if (SC.isPercentage(lH)) ret.height = lH * pFH;
          else ret.height = lH;
          ret.top = pFH - ret.height;
          if (SC.isPercentage(lB)) ret.top = ret.top - (lB * pFH);
          else ret.top = ret.top - lB;
        }
      }

    // handle centered
    } else if (!SC.none(lcY)) {
      if (lH && SC.isPercentage(lH)) ret.height = (lH * pFH);
      else ret.height = (lH || 0);
      ret.top = ((pFH - ret.height) / 2);
      if (SC.isPercentage(lcY)) ret.top = ret.top + lcY * pFH;
      else ret.top = ret.top + lcY;

    // if height defined, assume top of zero
    } else if (!SC.none(lH)) {
      ret.top =  0;
      if (lH === SC.LAYOUT_AUTO) ret.height = SC.LAYOUT_AUTO;
      else if (SC.isPercentage(lH)) ret.height = lH * pFH;
      else ret.height = lH;

    // fallback, full height.
    } else {
      ret.top = 0;
      ret.height = 0;
    }

    if (ret.top) ret.top = Math.floor(ret.top);
    if (ret.bottom) ret.bottom = Math.floor(ret.bottom);
    if (ret.left) ret.left = Math.floor(ret.left);
    if (ret.right) ret.right = Math.floor(ret.right);
    if (ret.width !== SC.LAYOUT_AUTO) ret.width = Math.floor(ret.width);
    if (ret.height !== SC.LAYOUT_AUTO) ret.height = Math.floor(ret.height);

    // handle min/max
    if (layout.minHeight !== undefined) ret.minHeight = layout.minHeight;
    if (layout.maxHeight !== undefined) ret.maxHeight = layout.maxHeight;

    return ret;
  },

  /**
    For now can only convert Top/Left/Width/Height to a Custom Layout
  */
  convertLayoutToCustomLayout: function (layout, layoutParams, parentFrame) {
    // TODO: [EG] Create Top/Left/Width/Height to a Custom Layout conversion
  }

});

/* >>>>>>>>>> BEGIN source/views/view/acceleration.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require("views/view");
sc_require("views/view/layout");
sc_require("views/view/layout_style");

SC.View.reopen({

  /**
    Setting wantsAcceleratedLayer to YES will use transforms to move the
    layer when available. On some platforms transforms are hardware accelerated.
  */
  wantsAcceleratedLayer: NO,

  /**
    Specifies whether transforms can be used to move the layer.
  */
  hasAcceleratedLayer: function () {
    return (SC.platform.supportsCSSTransforms && this.get('wantsAcceleratedLayer') && this.get('isFixedLayout'));
  }.property('wantsAcceleratedLayer', 'isFixedLayout').cacheable()

});

/* >>>>>>>>>> BEGIN source/views/view/cursor.js */
sc_require("views/view");

SC.View.reopen(
  /** @scope SC.View.prototype */ {

  /**
    You can set this to an SC.Cursor instance; whenever that SC.Cursor's
    'cursorStyle' changes, the cursor for this view will automatically
    be updated to match. This allows you to coordinate the cursors of
    many views by making them all share the same cursor instance.

    For example, SC.SplitView uses this ensure that it and all of its
    children have the same cursor while dragging, so that whether you are
    hovering over the divider or another child of the split view, the
    proper cursor is visible.

    @property {SC.Cursor String}
  */
  cursor: function(key, value) {
    var parent;

    if (value) { this._setCursor = value; }
    if (this._setCursor !== undefined) { return this._setCursor; }

    parent = this.get('parentView');
    if (this.get('shouldInheritCursor') && parent) {
      return parent.get('cursor');
    }

    return null;
  }.property('parentView', 'shouldInheritCursor').cacheable(),

  /**
    A child view without a cursor of its own inherits its parent's cursor by
    default.  Set this to NO to prevent this behavior.

    @type Boolean
  */
  shouldInheritCursor: YES

});

/* >>>>>>>>>> BEGIN source/views/view/enabled.js */
sc_require("views/view");

SC.CoreView.mixin(
  /** @scope SC.CoreView */ {

  /**
    The view is enabled.

    @static
    @constant
  */
  ENABLED: 0x08, // 8

  /**
    The view has been disabled.

    @static
    @constant
  */
  IS_DISABLED: 0x10, // 16

  /**
    The view is disabled.

    @static
    @constant
  */
  DISABLED: 0x11, // 17

  /**
    The view is enabled itself, but is effectively disabled in the pane due to
    a disabled ancestor.

    @static
    @constant
  */
  DISABLED_BY_PARENT: 0x12, // 18

  /**
    The view is disabled itself and is also disabled in the pane due to
    a disabled ancestor.

    @static
    @constant
  */
  DISABLED_AND_BY_PARENT: 0x13 // 19

});


SC.View.reopen(
  /** @scope SC.View.prototype */ {

  // ------------------------------------------------------------------------
  // Properties
  //

  /**
    The current enabled state of the view.

    Views have a few possible enabled states:

    * SC.CoreView.ENABLED
    * SC.CoreView.DISABLED
    * SC.CoreView.DISABLED_BY_PARENT

    @type String
    @default SC.CoreView.ENABLED
    @readonly
  */
  enabledState: SC.CoreView.ENABLED,

  /**
    Set to true when the item is enabled.   Note that changing this value
    will alter the `isEnabledInPane` property for this view and any
    child views as well as to automatically add or remove a 'disabled' CSS
    class name.

    This property is observable and bindable.

    @type Boolean
  */
  isEnabled: YES,
  isEnabledBindingDefault: SC.Binding.oneWay().bool(),

  /**
    Computed property returns YES if the view and all of its parent views
    are enabled in the pane.  You should use this property when deciding
    whether to respond to an incoming event or not.

    @type Boolean
  */
  // The previous version used a lazy upward search method.  This has better
  // performance, but made isEnabledInPane non-bindable.
  // isEnabledInPane: function() {
  //   var ret = this.get('isEnabled'), pv ;
  //   if (ret && (pv = this.get('parentView'))) { ret = pv.get('isEnabledInPane'); }
  //   return ret ;
  // }.property('parentView', 'isEnabled'),
  isEnabledInPane: function () {
    return this.get('enabledState') === SC.CoreView.ENABLED;
  }.property('enabledState').cacheable(),

  /**
    By default, setting isEnabled to false on a view will place all of its
    child views in a disabled state.  To block this from happening to a
    specific child view and its children, you can set `shouldInheritEnabled`
    to false.

    In this way you can set `isEnabled` to false on a main pane to disable all
    buttons, collections and other controls within it, but can still keep a
    section of it editable using `shouldInheritEnabled: false`.

    @type Boolean
  */
  shouldInheritEnabled: true,

  // ------------------------------------------------------------------------
  // Actions & Events
  //

  /** @private */
  _doEnable: function () {
    var handled = true,
      enabledState = this.get('enabledState');

    // If the view itself is disabled, then we can enable it.
    if (enabledState === SC.CoreView.DISABLED) {
      // Update the enabled state of all children. Top-down, because if a child is disabled on its own it
      // won't affect its childrens' state and we can bail out early.
      this._callOnChildViews('_parentDidEnableInPane');
      this._gotoEnabledState();

    // If the view is disabled and has a disabled parent, we can enable it, but it will be disabled by the parent.
    } else if (enabledState === SC.CoreView.DISABLED_AND_BY_PARENT) {
      // The view is no longer disabled itself, but still disabled by an ancestor.
      this._gotoDisabledByParentState();

    // If the view is not disabled, we can't enable it.
    } else {
      handled = false;
    }

    return handled;
  },

  /** @private */
  _doDisable: function () {
    var handled = true,
      enabledState = this.get('enabledState');

    // If the view is not itself disabled, then we can disable it.
    if (enabledState === SC.CoreView.ENABLED) {
      // Update the disabled state of all children. Top-down, because if a child is disabled on its own it
      // won't affect its childrens' state and we can bail out early.
      this._callOnChildViews('_parentDidDisableInPane');
      this._gotoDisabledState();

      // Ensure that first responder status is given up.
      if (this.get('isFirstResponder')) {
        this.resignFirstResponder();
      }

    // If the view is disabled because of a disabled parent, we can disable the view itself too.
    } else if (enabledState === SC.CoreView.DISABLED_BY_PARENT) {
      // The view is now disabled itself and disabled by an ancestor.
      this._gotoDisabledAndByParentState();

    // If the view is not enabled, we can't disable it.
    } else {
      handled = false;
    }

    return handled;
  },

  // ------------------------------------------------------------------------
  // Methods
  //

  /** @private
    Observes the isEnabled property and resigns first responder if set to NO.
    This will avoid cases where, for example, a disabled text field retains
    its focus rings.

    @observes isEnabled
  */
  _sc_view_isEnabledDidChange: function () {
    // Filter the input channel.
    this.invokeOnce(this._doUpdateEnabled);
  }.observes('isEnabled'),

  /** @private */
  _doUpdateEnabled: function () {
    var state = this.get('viewState');

    // Call the proper action.
    if (this.get('isEnabled')) {
      this._doEnable();
    } else {
      this._doDisable();
    }

    // Update the display if in a visible state.
    switch (state) {
    case SC.CoreView.ATTACHED_SHOWN:
    case SC.CoreView.ATTACHED_SHOWING:
    case SC.CoreView.ATTACHED_BUILDING_IN:
      // Update the display.
      this._doUpdateEnabledStyle();
      break;
    default:
      // Indicate that a display update is required the next time we are visible.
      this._enabledStyleNeedsUpdate = true;
    }
  },

  /** @private */
  _doUpdateEnabledStyle: function () {
    var isEnabled = this.get('isEnabled');

    this.$().toggleClass('disabled', !isEnabled);
    this.$().attr('aria-disabled', !isEnabled ? true : null);

    // Reset that an update is required.
    this._enabledStyleNeedsUpdate = false;
  },

  /** @private */
  _parentDidEnableInPane: function () {
    var enabledState = this.get('enabledState');

    if (this.get('shouldInheritEnabled')) {

      if (enabledState === SC.CoreView.DISABLED_BY_PARENT) { // Was enabled before.
        this._gotoEnabledState();
      } else if (enabledState === SC.CoreView.DISABLED_AND_BY_PARENT) { // Was disabled before.
        this._gotoDisabledState();

        // There's no need to continue to further child views.
        return false;
      }
    } else {
      // There's no need to continue to further child views.
      return false;
    }
  },

  /** @private */
  _parentDidDisableInPane: function () {
    var enabledState = this.get('enabledState');

    if (this.get('shouldInheritEnabled')) {

      if (enabledState === SC.CoreView.ENABLED) { // Was enabled.
        this._gotoDisabledByParentState();
      } else if (enabledState === SC.CoreView.DISABLED) { // Was disabled.
        this._gotoDisabledAndByParentState();
      } else { // Was already disabled by ancestor.

        // There's no need to continue to further child views.
        return false;
      }
    } else {
      // There's no need to continue to further child views.
      return false;
    }
  },

  /** @private */
  _gotoEnabledState: function () {
    this.set('enabledState', SC.CoreView.ENABLED);
  },

  /** @private */
  _gotoDisabledState: function () {
    this.set('enabledState', SC.CoreView.DISABLED);
  },

  /** @private */
  _gotoDisabledAndByParentState: function () {
    this.set('enabledState', SC.CoreView.DISABLED_AND_BY_PARENT);
  },

  /** @private */
  _gotoDisabledByParentState: function () {
    this.set('enabledState', SC.CoreView.DISABLED_BY_PARENT);
  }

});

/* >>>>>>>>>> BEGIN source/views/view/keyboard.js */
sc_require("views/view");

SC.View.reopen(
  /** @scope SC.View.prototype */ {
  // ..........................................................
  // KEY RESPONDER
  //

  /** @property
    YES if the view is currently first responder and the pane the view belongs
    to is also key pane.  While this property is set, you should expect to
    receive keyboard events.
  */
  isKeyResponder: NO,

  /**
    This method is invoked just before you lost the key responder status.
    The passed view is the view that is about to gain keyResponder status.
    This gives you a chance to do any early setup. Remember that you can
    gain/lose key responder status either because another view in the same
    pane is becoming first responder or because another pane is about to
    become key.

    @param {SC.Responder} responder
  */
  willLoseKeyResponderTo: function(responder) {},

  /**
    This method is invoked just before you become the key responder.  The
    passed view is the view that is about to lose keyResponder status.  You
    can use this to do any setup before the view changes.
    Remember that you can gain/lose key responder status either because
    another view in the same pane is becoming first responder or because
    another pane is about to become key.

    @param {SC.Responder} responder
  */
  willBecomeKeyResponderFrom: function(responder) {},

  /**
    Invokved just after the responder loses key responder status.
    @param {SC.Responder} responder
  */
  didLoseKeyResponderTo: function(responder) {},

  /**
    Invoked just after the responder gains key responder status.
    By default, it calls focus on the view root element. For accessibility 
    purposes.
  
    @param {SC.Responder} responder
  */
  didBecomeKeyResponderFrom: function(responder) {},

  /**
    This method will process a key input event, attempting to convert it to
    an appropriate action method and sending it up the responder chain.  The
    event is converted using the key bindings hashes, (SC.BASE_KEY_BINDINGS
    and SC.MODIFIED_KEY_BINDINGS) which map key events to method names. If
    no key binding method is found, then the key event will be passed along
    to any insertText() method found.

    @param {SC.Event} event
    @returns {Object} object that handled event, if any
  */
  interpretKeyEvents: function(event) {
    var codes = event.commandCodes(),
        cmd = codes[0],
        chr = codes[1],
        ret,
        match,
        methodName,
        target,
        pane,
        handler;

    if (!cmd && !chr) { return null ; } //nothing to do.

    // if this is a command key, try to do something about it.
    if (cmd) {
      match = cmd.match(/[^_]+$/);
      methodName = SC.MODIFIED_KEY_BINDINGS[cmd];
      if (!methodName && match && match.length > 0) {
        methodName = SC.BASE_KEY_BINDINGS[match[0]];
      }
      if (methodName) {
        target = this;
        pane = this.get('pane');
        handler = null;
        while(target && !(handler = target.tryToPerform(methodName, event))){
          target = (target===pane)? null: target.get('nextResponder') ;
        }
        return handler ;
      }
    }

    if (chr && this.respondsTo('insertText')) {
      // if we haven't returned yet and there is plain text, then do an insert
      // of the text.  Since this is not an action, do not send it up the
      // responder chain.
      ret = this.insertText(chr, event);
      return ret ? (ret===YES ? this : ret) : null ; // map YES|NO => this|nil
    }

    return null ; //nothing to do.
  },

  /**
    This method is invoked by interpretKeyEvents() when you receive a key
    event matching some plain text.  You can use this to actually insert the
    text into your application, if needed.

    @param {SC.Event} event
    @returns {Object} receiver or object that handled event
  */
  insertText: function(chr) {
    return NO ;
  },

  /**
    Recursively travels down the view hierarchy looking for a view that
    implements the key equivalent (returning to YES to indicate it handled
    the event).  You can override this method to handle specific key
    equivalents yourself.

    The keystring is a string description of the key combination pressed.
    The evt is the event itself. If you handle the equivalent, return YES.
    Otherwise, you should just return sc_super.

    @param {String} keystring
    @param {SC.Event} evt
    @returns {Boolean}
  */
  performKeyEquivalent: function(keystring, evt) {
    var ret = NO,
        childViews = this.get('childViews'),
        len = childViews.length,
        idx = -1, view ;
    while (!ret && (++idx < len)) {
      view = childViews[idx];

      ret = view.tryToPerform('performKeyEquivalent', keystring, evt);
    }

    return ret ;
  },

  /**
    The first child of this view for the purposes of tab ordering. If not
    provided, the first element of childViews is used. Override this if
    your view displays its child views in an order different from that
    given in childViews.

    @type SC.View
    @default null
  */
  firstKeyView: null,

  /**
    @private

    Actually calculates the firstKeyView as described in firstKeyView.

    @returns {SC.View}
  */
  _getFirstKeyView: function() {
    // if first was given, just return it
    var firstKeyView = this.get('firstKeyView');
    if(firstKeyView) return firstKeyView;

    // otherwise return the first childView
    var childViews = this.get('childViews');
    if(childViews) return childViews[0];
  },

  /**
    The last child of this view for the purposes of tab ordering. If not set, can be generated two different ways:
    1. If firstKeyView is provided, it will be generated by starting from firstKeyView and traversing the childViews nextKeyView properties.
    2. If firstKeyView is not provided, it will simply return the last element of childViews.

    The first way is not very efficient, so if you provide firstKeyView you should also provide lastKeyView.

    @type SC.View
    @default null
  */
  lastKeyView: null,

  /**
    @private

    Actually calculates the lastKeyView as described in lastKeyView.

    @returns {SC.View}
  */
  _getLastKeyView: function() {
    // if last was given, just return it
    var lastKeyView = this.get('lastKeyView');
    if(lastKeyView) return lastKeyView;

    var view,
    prev = this.get('firstKeyView');

    // if first was given but not last, build by starting from first and
    // traversing until we hit the end. this is obviously the least efficient
    // way
    if(prev) {
      while(view = prev._getNextKeyView()) {
        prev = view;
      }

      return prev;
    }

    // if neither was given, it's more efficient to just return the last
    // childView
    else {
      var childViews = this.get('childViews');

      if(childViews) return childViews[childViews.length - 1];
    }
  },

  /**
    Optionally points to the next key view that should gain focus when tabbing
    through an interface.  If this is not set, then the next key view will
    be set automatically to the next sibling as defined by its parent's
    childViews property.

    If any views define this, all of their siblings should define it as well,
    otherwise undefined behavior may occur. Their parent view should also define
    a firstKeyView.

    This may also be set to a view that is not a sibling, but once again all
    views in the chain must define it or undefined behavior will occur.

    Likewise, any view that sets nextKeyView should also set previousKeyView.

    @type SC.View
    @default null
  */

  nextKeyView: undefined,

  /**
    @private

    Gets the next key view by checking if the user set it and otherwise just
    getting the next by index in childViews.

    @return {SC.View}
  */
  _getNextKeyView: function() {
    var pv = this.get('parentView'),
    nextKeyView = this.get('nextKeyView');

    // if the parent defines lastKeyView, it takes priority over this views
    // nextKeyView
    if(pv && pv.get('lastKeyView') === this) return null;

    // if this view defines a nextKeyView, use it
    if(nextKeyView !== undefined) return nextKeyView;

    // otherwise generate one based on parent view's childViews
    if(pv) {
      var childViews = pv.get('childViews');
      return childViews[childViews.indexOf(this) + 1];
    }
  },

  /**
    Computes the next valid key view. This is the next key view that
    acceptsFirstResponder. Computed using depth first search. If the current view
    is not valid, it will first traverse its children before trying siblings. If
    the current view is the only valid view, the current view will be returned. Will
    return null if no valid view can be found.

    @property
    @type SC.View
  */
  nextValidKeyView: function() {
    var cur = this, next;
    while(next !== this) {
      next = null;

      // only bother to check children if we are visible
      if(cur.get('isVisibleInWindow')) next = cur._getFirstKeyView();

      // if we have no children, check our sibling
      if(!next) next = cur._getNextKeyView();

      // if we have no children or siblings, unroll up closest parent that has a
      // next sibling
      if(!next) {
        while(cur = cur.get('parentView')) {
          if(next = cur._getNextKeyView()) break;
        }
      }

      // if no parents have a next sibling, start over from the beginning
      if(!next) {
        if(!SC.TABBING_ONLY_INSIDE_DOCUMENT) break;
        else next = this.get('pane');
      }

      // if it's a valid firstResponder, we're done!
      if(next.get('isVisibleInWindow') && next.get('acceptsFirstResponder')) {
        return next;
      }
      // otherwise keep looking
      cur = next;
    }
    // this will only happen if no views are visible and accept first responder
    return null;
  }.property('nextKeyView'),

  /**
    Optionally points to the previous key view that should gain focus when tabbing
    through an interface.  If this is not set, then the previous key view will
    be set automatically to the previous sibling as defined by its parent's
    childViews property.

    If any views define this, all of their siblings should define it as well,
    otherwise undefined behavior may occur. Their parent view should also define
    a lastKeyView.

    This may also be set to a view that is not a sibling, but once again all
    views in the chain must define it or undefined behavior will occur.

    Likewise, any view that sets previousKeyView should also set nextKeyView.

    @type SC.View
    @default null
  */
  previousKeyView: undefined,

  /**
    @private

    Gets the previous key view by checking if the user set it and otherwise just
    getting the previous by index in childViews.

    @return {SC.View}
  */
  _getPreviousKeyView: function() {
    var pv = this.get('parentView'),
    previousKeyView = this.get('previousKeyView');

    // if the parent defines firstKeyView, it takes priority over this views
    // previousKeyView
    if(pv && pv.get('firstKeyView') === this) return null;

    // if this view defines a previousKeyView, use it
    if(previousKeyView !== undefined) return previousKeyView;

    // otherwise generate one based on parent view's childViews
    if(pv) {
      var childViews = pv.get('childViews');
      return childViews[childViews.indexOf(this) - 1];
    }
  },

  /**
    Computes the previous valid key view. This is the previous key view that
    acceptsFirstResponder. Traverse views in the opposite order from
    nextValidKeyView. If the current view is the pane, tries deepest child. If the
    current view has a previous view, tries its last child. If this view is the
    first child, tries the parent. Will return null if no valid view can be
    found.

    @property
    @type SC.View
  */
  // TODO: clean this up
  previousValidKeyView: function() {
    var cur = this, prev;

    while(prev !== this) {
      // normally, just try to get previous view's last child
      if(cur.get('parentView')) prev = cur._getPreviousKeyView();

      // if we are the pane and address bar tabbing is enabled, trigger it now
      else if(!SC.TABBING_ONLY_INSIDE_DOCUMENT) break;

      // if we are the pane, get our own last child
      else prev = cur;

      // loop down to the last valid child
      if(prev) {
        do {
          cur = prev;
          prev = prev._getLastKeyView();
        } while(prev && prev.get('isVisibleInWindow'));

        // if we ended on a null, unroll to the last one
        // we don't unroll if we ended on a hidden view because we need
        // to traverse to its previous view next iteration
        if(!prev) prev = cur;
      }

      // if there is no previous view, traverse to the parent
      else prev = cur.get('parentView');

      // if the view is valid, return it
      if(prev.get('isVisibleInWindow') && prev.get('acceptsFirstResponder')) return prev;

      // otherwise, try to find its previous valid keyview
      cur = prev;
    }

    // if none of the views accept first responder and we make it back to where
    // we started, just return null
    return null;
  }.property('previousKeyView')
});


/* >>>>>>>>>> BEGIN source/views/view/manipulation.js */
sc_require("views/view");

SC.View.reopen(
  /** @scope SC.View.prototype */{

  /**
    Handles changes in the layer id.
  */
  layerIdDidChange: function() {
    var layer  = this.get('layer'),
        lid    = this.get('layerId'),
        lastId = this._lastLayerId;

    if (lid !== lastId) {
      // if we had an earlier one, remove from view hash.
      if (lastId && SC.View.views[lastId] === this) {
        delete SC.View.views[lastId];
      }

      // set the current one as the new old one
      this._lastLayerId = lid;

      // and add the new one
      SC.View.views[lid] = this;

      // and finally, set the actual layer id.
      if (layer) { layer.id = lid; }
    }
  }.observes("layerId"),

  // ------------------------------------------------------------------------
  // LAYER LOCATION
  //

  /**
    Insert the view into the the receiver's childNodes array.

    The view will be added to the childNodes array before the beforeView.  If
    beforeView is null, then the view will be added to the end of the array.
    This will also add the view's rootElement DOM node to the receivers
    containerElement DOM node as a child.

    If the specified view already belongs to another parent, it will be
    removed from that view first.

    @param {SC.View} view
    @param {SC.View} beforeView
    @returns {SC.View} the receiver
  */
  insertBefore: function(view, beforeView) {
    view.beginPropertyChanges(); // limit notifications

    // Reset any views that are already building in or out.
    if (view.resetBuildState) { view.resetBuildState(); }
    view._doAdopt(this, beforeView);

    view.endPropertyChanges();

    return this ;
  },

  /**
    Replace the oldView with the specified view in the receivers childNodes
    array. This will also replace the DOM node of the oldView with the DOM
    node of the new view in the receivers DOM.

    If the specified view already belongs to another parent, it will be
    removed from that view first.

    @param view {SC.View} the view to insert in the DOM
    @param view {SC.View} the view to remove from the DOM.
    @returns {SC.View} the receiver
  */
  replaceChild: function(view, oldView) {
    // suspend notifications
    view.beginPropertyChanges();
    oldView.beginPropertyChanges();
    this.beginPropertyChanges();

    this.insertBefore(view,oldView).removeChild(oldView) ;

    // resume notifications
    this.endPropertyChanges();
    oldView.endPropertyChanges();
    view.endPropertyChanges();

    return this;
  },

  /**
    Replaces the current array of child views with the new array of child
    views.

    This will remove *and* destroy all of the existing child views and their
    layers.

    Warning: The new array must be made of *child* views (i.e. created using
    this.createChildView() on the parent).

    @param {Array} newChildViews Child views you want to add
    @returns {SC.View} receiver
  */
  replaceAllChildren: function (newChildViews) {
    this.beginPropertyChanges();

    // If rendered, destroy our layer so we can re-render.
    // if (this.get('_isRendered')) {
    //   var layer = this.get('layer');

    //   // If attached, detach and track our parent node so we can re-attach.
    //   if (this.get('isAttached')) {
    //     // We don't allow for transitioning out at this time.
    //     // TODO: support transition out of child views.
    //     this._doDetach(true);
    //   }

    //   // Destroy our layer in one move.
    //   this.destroyLayer();
    // }

    // Remove the current child views.
    // We aren't rendered at this point so it bypasses the optimization in
    // removeAllChildren that would recreate the layer.  We would rather add the
    // new childViews before recreating the layer.
    this.removeAllChildren(true);

    // Add the new children.
    for (var i = 0, len = newChildViews.get('length'); i < len; i++) {
      this.appendChild(newChildViews.objectAt(i));
    }

    // We were rendered previously.
    // if (layer) {
    //   // Recreate our layer (now empty).
    //   this.createLayer();
    // }
    this.endPropertyChanges();

    return this ;
  },

  /**
    Appends the specified view to the end of the receivers childViews array.
    This is equivalent to calling insertBefore(view, null);

    @param view {SC.View} the view to insert
    @returns {SC.View} the receiver
  */
  appendChild: function(view) {
    return this.insertBefore(view, null);
  },

  // ------------------------------------------------------------------------
  // BUILDING IN/OUT
  //

  /**
    Call this to append a child while building it in. If the child is not
    buildable, this is the same as calling appendChild.

    @deprecated Version 1.10
  */
  buildInChild: function(view) {
    view.willBuildInToView(this);
    this.appendChild(view);
    view.buildInToView(this);
  },

  /**
    Call to remove a child after building it out. If the child is not buildable,
    this will simply call removeChild.

    @deprecated Version 1.10
  */
  buildOutChild: function(view) {
    view.buildOutFromView(this);
  },

  /**
    Called by child view when build in finishes. By default, does nothing.

    @deprecated Version 1.10
  */
  buildInDidFinishFor: function(child) {
  },

  /**
    @private
    Called by child view when build out finishes. By default removes the child view.
  */
  buildOutDidFinishFor: function(child) {
    this.removeChild(child);
  },

  /**
    Whether the view is currently building in.

    @deprecated Version 1.10
  */
  isBuildingIn: NO,

  /**
    Whether the view is currently building out.

    @deprecated Version 1.10
  */
  isBuildingOut: NO,

  /**
    Implement this, and call didFinishBuildIn when you are done.

    @deprecated Version 1.10
  */
  buildIn: function() {
    

    this.buildInDidFinish();
  },

  /**
    Implement this, and call didFinishBuildOut when you are done.

    @deprecated Version 1.10
  */
  buildOut: function() {
    

    this.buildOutDidFinish();
  },

  /**
    This should reset (without animation) any internal states; sometimes called before.

    It is usually called before a build in, by the parent view.
    @deprecated Version 1.10
  */
  resetBuild: function() {

  },

  /**
    Implement this if you need to do anything special when cancelling build out;
    note that buildIn will subsequently be called, so you usually won't need to do
    anything.

    This is basically called whenever build in happens.

    @deprecated Version 1.10
  */
  buildOutDidCancel: function() {

  },

  /**
    Implement this if you need to do anything special when cancelling build in.
    You probably won't be able to do anything. I mean, what are you gonna do?

    If build in was cancelled, it means build out is probably happening.
    So, any timers or anything you had going, you can cancel.
    Then buildOut will happen.

    @deprecated Version 1.10
  */
  buildInDidCancel: function() {

  },

  /**
    Call this when you have built in.

    @deprecated Version 1.10
  */
  buildInDidFinish: function() {
    this.isBuildingIn = NO;
    this._buildingInTo.buildInDidFinishFor(this);
    this._buildingInTo = null;
  },

  /**
    Call this when you have finished building out.

    @deprecated Version 1.10
  */
  buildOutDidFinish: function() {
    this.isBuildingOut = NO;
    this._buildingOutFrom.buildOutDidFinishFor(this);
    this._buildingOutFrom = null;
  },

  /**
    Usually called by parentViewDidChange, this resets the build state (calling resetBuild in the process).

    @deprecated Version 1.10
  */
  resetBuildState: function() {
    if (this.isBuildingIn) {
      this.buildInDidCancel();
      this.isBuildingIn = NO;
    }
    if (this.isBuildingOut) {
      this.buildOutDidCancel();
      this.isBuildingOut = NO;
    }

    // finish cleaning up
    this.buildingInTo = null;
    this.buildingOutFrom = null;

    this.resetBuild();
  },

  /**
    @private (semi)
    Called by building parent view's buildInChild method. This prepares
    to build in, but unlike buildInToView, this is called _before_ the child
    is appended.

    Mostly, this cancels any build out _before_ the view is removed through parent change.
  */
  willBuildInToView: function(view) {
    // stop any current build outs (and if we need to, we also need to build in again)
    if (this.isBuildingOut) {
      this.buildOutDidCancel();
    }
  },

  /**
    @private (semi)
    Called by building parent view's buildInChild method.
  */
  buildInToView: function(view) {
    // if we are already building in, do nothing.
    if (this.isBuildingIn) { return; }

    this._buildingInTo = view;
    this.isBuildingOut = NO;
    this.isBuildingIn = YES;
    this.buildIn();
  },

  /**
    @private (semi)
    Called by building parent view's buildOutChild method.

    The supplied view should always be the parent view.
  */
  buildOutFromView: function(view) {
    // if we are already building out, do nothing.
    if (this.isBuildingOut) { return; }

    // cancel any build ins
    if (this.isBuildingIn) {
      this.buildInDidCancel();
    }

    // in any case, we need to build out
    this.isBuildingOut = YES;
    this.isBuildingIn = NO;
    this._buildingOutFrom = view;
    this.buildOut();
  }
});

/* >>>>>>>>>> BEGIN source/views/view/theming.js */
sc_require("views/view");

SC.View.reopen(
  /** @scope SC.View.prototype */ {

  // ..........................................................
  // THEME SUPPORT
  //

  /**
    Names which theme this view should use; the theme named by this property
    will be set to the view's 'theme' property.

    Themes are identified by their name. In addition to looking for the
    theme globally, SproutCore will look for the theme inside 'baseTheme',
    which is almost always the parent view's theme.

    If null (the default), the view will set its 'theme' property to
    be equal to 'baseTheme'.

    Example: themeName: 'ace'

    @type String
  */
  themeName: null,

  /**
    Selects which theme to use as a 'base theme'. If null, the 'baseTheme'
    property will be set to the parent's theme. If there is no parent, the theme
    named by SC.defaultTheme is used.

    This property is private for the time being.

    @private
    @type String
  */
  baseThemeName: null,

  /**
    The SC.Theme instance which this view should use to render.

    Note: the actual code for this function is in _themeProperty for backwards-compatibility:
    some older views specify a string value for 'theme', which would override this property,
    breaking it.

    @property {SC.Theme}
  */
  theme: function() {
    var base = this.get('baseTheme'), themeName = this.get('themeName');

    // find theme, if possible
    if (themeName) {
      // Note: theme instance "find" function will search every parent
      // _except_ global (which is not a parent)
      var theme;
      if (base) {
        theme = base.find(themeName);
        if (theme) { return theme; }
      }

      theme = SC.Theme.find(themeName);
      if (theme) { return theme; }

      // Create a new invisible subtheme. This will cause the themeName to
      // be applied as a class name.
      return base.invisibleSubtheme(themeName);
    }

    // can't find anything, return base.
    return base;
  }.property('baseTheme', 'themeName').cacheable(),

  /**
    Detects when the theme changes. Replaces the layer if necessary.

    Also, because
  */
  _sc_view_themeDidChange: function() {
    var curTheme = this.get('theme');
    if (this._lastTheme === curTheme) { return; }
    this._lastTheme = curTheme;

    // invalidate child view base themes, if present
    var childViews = this.childViews, len = childViews.length, idx;
    for (idx = 0; idx < len; idx++) {
      childViews[idx].notifyPropertyChange('baseTheme');
    }

    if (this.get('layer')) { this.replaceLayer(); }
  }.observes('theme'),

  /**
    The SC.Theme instance in which the 'theme' property should look for the theme
    named by 'themeName'.

    For example, if 'baseTheme' is SC.AceTheme, and 'themeName' is 'popover',
    it will look to see if SC.AceTheme has a child theme named 'popover',
    and _then_, if it is not found, look globally.

    @private
    @property {SC.Theme}
  */
  baseTheme: function() {
    var parent;
    var baseThemeName = this.get('baseThemeName');
    if (baseThemeName) {
      return SC.Theme.find(baseThemeName);
    } else {
      parent = this.get('parentView');
      var theme  = parent && parent.get('theme');
      return   theme || SC.Theme.find(SC.defaultTheme);
    }
  }.property('baseThemeName', 'parentView').cacheable(),

  /**
    The object to which rendering and updating the HTML representation of this
    view should be delegated.

    By default, views are responsible for creating their own HTML
    representation. In some cases, however, you may want to create an object
    that is responsible for rendering all views of a certain type. For example,
    you may want rendering of SC.ButtonView to be controlled by an object that
    is specific to the current theme.

    By setting a render delegate, the render and update methods will be called
    on that object instead of the view itself.

    For your convenience, the view will provide its displayProperties to the
    RenderDelegate. In some cases, you may have a conflict between the RenderDelegate's
    API and your view's. For instance, you may have a 'value' property that is
    any number, but the render delegate expects a percentage. Make a 'displayValue'
    property, add _it_ to displayProperties instead of 'value', and the Render Delegate
    will automatically use that when it wants to find 'value.'

    You can also set the render delegate by using the 'renderDelegateName' property.

    @type Object
  */
  renderDelegate: function(key, value) {
    if (value) { this._setRenderDelegate = value; }
    if (this._setRenderDelegate) { return this._setRenderDelegate; }

    // If this view does not have a render delegate but has
    // renderDelegateName set, try to retrieve the render delegate from the
    // theme.
    var renderDelegateName = this.get('renderDelegateName'), renderDelegate;

    if (renderDelegateName) {
      renderDelegate = this.get('theme')[renderDelegateName];
      if (!renderDelegate) {
        throw new Error("%@: Unable to locate render delegate \"%@\" in theme.".fmt(this, renderDelegateName));
      }

      return renderDelegate;
    }

    return null;
  }.property('renderDelegateName', 'theme'),

  /**
    The name of the property of the current theme that contains the render
    delegate to use for this view.

    By default, views are responsible for creating their own HTML
    representation. You can tell the view to instead delegate rendering to the
    theme by setting this property to the name of the corresponding property
    of the theme.

    For example, to tell the view that it should render using the
    SC.ButtonView render delegate, set this property to
    'buttonRenderDelegate'. When the view is created, it will retrieve the
    buttonRenderDelegate property from its theme and set the renderDelegate
    property to that object.
  */
  renderDelegateName: null,

  /**
    [RO] Pass this object as the data source for render delegates. This proxy object
    for the view relays requests for properties like 'title' to 'displayTitle'
    as necessary.

    If you ever communicate with your view's render delegate, you should pass this
    object as the data source.

    The proxy that forwards RenderDelegate requests for properties to the view,
    handling display*, keeps track of the delegate's state, etc.
  */
  renderDelegateProxy: function() {
    return SC.View._RenderDelegateProxy.createForView(this);
  }.property('renderDelegate').cacheable(),

  /**
    Invoked whenever your view needs to create its HTML representation.

    You will normally override this method in your subclassed views to
    provide whatever drawing functionality you will need in order to
    render your content.

    This method is usually only called once per view. After that, the update
    method will be called to allow you to update the existing HTML
    representation.


    The default implementation of this method calls renderChildViews().

    For backwards compatibility, this method will also call the appropriate
    method on a render delegate object, if your view has one.

    @param {SC.RenderContext} context the render context
    @returns {void}
  */
  render: function(context, firstTime) {
    var renderDelegate = this.get('renderDelegate');

    if (renderDelegate) {
      if (firstTime) {
        renderDelegate.render(this.get('renderDelegateProxy'), context);
      } else {
        renderDelegate.update(this.get('renderDelegateProxy'), context.$());
      }
    }
  },

  /**
    Invokes a method on the render delegate, if one is present and it implements
    that method.

    @param {String} method The name of the method to call.
    @param arg One or more arguments.
  */
  invokeRenderDelegateMethod: function(method, args) {
    var renderDelegate = this.get('renderDelegate');
    if (!renderDelegate) return undefined;

    if (SC.typeOf(renderDelegate[method]) !== SC.T_FUNCTION) return undefined;

    args = SC.$A(arguments);
    args.shift();
    args.unshift(this.get('renderDelegateProxy'));
    return renderDelegate[method].apply(renderDelegate, args);
  }
});

/**
  @class
  @private
  View Render Delegate Proxies are tool SC.Views use to:

  - look up 'display*' ('displayTitle' instead of 'title') to help deal with
    differences between the render delegate's API and the view's.

  RenderDelegateProxies are fully valid data sources for render delegates. They
  act as proxies to the view, interpreting the .get and .didChangeFor commands
  based on the view's displayProperties.

  This tool is not useful outside of SC.View itself, and as such, is private.
*/
SC.View._RenderDelegateProxy = {

  


  /**
    Creates a View Render Delegate Proxy for the specified view.

    Implementation note: this creates a hash of the view's displayProperties
    array so that the proxy may quickly determine whether a property is a
    displayProperty or not. This could cause issues if the view's displayProperties
    array is modified after instantiation.

    @param {SC.View} view The view this proxy should proxy to.
    @returns SC.View._RenderDelegateProxy
  */
  createForView: function(view) {
    var ret = SC.beget(this);

    // set up displayProperty lookup for performance
    var dp = view.get('displayProperties'), lookup = {};
    for (var idx = 0, len = dp.length; idx < len; idx++) {
      lookup[dp[idx]] = YES;
    }

    // also allow the few special properties through
    lookup.theme = YES;

    ret._displayPropertiesLookup = lookup;
    ret.renderState = {};

    ret._view = view;
    return ret;
  },


  /**
    Provides the render delegate with any property it needs.

    This first looks up whether the property exists in the view's
    displayProperties, and whether it exists prefixed with 'display';
    for instance, if the render delegate asks for 'title', this will
    look for 'displayTitle' in the view's displayProperties array.

   @param {String} property The name of the property the render delegate needs.
   @returns The value.
  */
  get: function(property) {
    if (this[property] !== undefined) { return this[property]; }

    var displayProperty = 'display' + property.capitalize();

    if (this._displayPropertiesLookup[displayProperty]) {
      return this._view.get(displayProperty);
    } else {
      return this._view.get(property);
    }
  },

  /**
   Checks if any of the specified properties have changed.

   For each property passed, this first determines whether to use the
   'display' prefix. Then, it calls view.didChangeFor with context and that
   property name.
  */
  didChangeFor: function(context) {
    var len = arguments.length, idx;
    for (idx = 1; idx < len; idx++) {
      var property = arguments[idx],
          displayProperty = 'display' + property.capitalize();

      if (this._displayPropertiesLookup[displayProperty]) {
        if (this._view.didChangeFor(context, displayProperty)) { return YES; }
      } else {
        if (this._view.didChangeFor(context, property)) { return YES; }
      }
    }

    return NO;
  }
};

/**
  Generates a computed property that will look up the specified property from
  the view's render delegate, if present. You may specify a default value to
  return if there is no such property or is no render delegate.

  The generated property is read+write, so it may be overridden.

  @param {String} propertyName The name of the property to get from the render delegate..
  @param {Value} def The default value to use if the property is not present.
*/
SC.propertyFromRenderDelegate = function(propertyName, def) {
  return function(key, value) {
    // first, handle set() case
    if (value !== undefined) {
      this['_set_rd_' + key] = value;
    }

    // use any value set manually via set()  -- two lines ago.
    var ret = this['_set_rd_' + key];
    if (ret !== undefined) return ret;

    // finally, try to get it from the render delegate
    var renderDelegate = this.get('renderDelegate');
    if (renderDelegate && renderDelegate.get) {
      var proxy = this.get('renderDelegateProxy');
      ret = renderDelegate.getPropertyFor(proxy, propertyName);
    }

    if (ret !== undefined) return ret;

    return def;
  }.property('renderDelegate').cacheable();
};



/* >>>>>>>>>> BEGIN source/views/view/touch.js */
sc_require("views/view");

SC.View.reopen(
  /** @scope SC.View.prototype */ {

  // ..........................................................
  // MULTITOUCH SUPPORT
  //
  /**
    Set to YES if you want to receive touch events for each distinct touch
    (rather than only the first touch start and last touch end).
  */
  acceptsMultitouch: NO,

  /**
    Is YES if the view is currently being touched. NO otherwise.
  */
  hasTouch: NO,

  /**
    A boundary set of distances outside which the touch will no longer be
    considered "inside" the view anymore.  This is useful when we want to allow
    a bit of touch drag outside of the view before we consider that the User's
    finger has completely left the view.  For example, a User might touch down
    on a button, but because of the wide surface of a finger, the touch might
    slip outside of the button's frame as the person lifts up.  If the button
    uses touchIsInBoundary it can make it easier for the User to hit it.

    By default, up to 25px on each side.
  */
  touchBoundary: { left: 25, right: 25, top: 25, bottom: 25 },

  /** @private
    A computed property based on frame.
  */
  _touchBoundaryFrame: function () {
    var boundary = this.get("touchBoundary"),
      ret;

    // Determine the frame of the View in screen coordinates
    ret = this.get("parentView").convertFrameToView(this.get('frame'), null);

    // Expand the frame to the acceptable boundary.
    ret.x -= boundary.left;
    ret.y -= boundary.top;
    ret.width += boundary.left + boundary.right;
    ret.height += boundary.top + boundary.bottom;

    return ret;
  }.property('touchBoundary', 'clippingFrame').cacheable(),

  /**
    Returns YES if the provided touch is within the boundary set by
    touchBoundary.
  */
  touchIsInBoundary: function(touch) {
    return SC.pointInRect({x: touch.pageX, y: touch.pageY},
      this.get("_touchBoundaryFrame"));
  }
});

/* >>>>>>>>>> BEGIN source/views/view/visibility.js */
sc_require("views/view");

SC.View.reopen(
  /** @scope SC.View.prototype */ {

  /**
    Set to YES to indicate the view has visibility support added.

    @deprecated Version 1.10
  */
  hasVisibility: YES,

  /**
   By default we don't disable the context menu. Overriding this property
   can enable/disable the context menu per view.
  */
  isContextMenuEnabled: function () {
    return SC.CONTEXT_MENU_ENABLED;
  }.property(),

  /**
    The visibility of the view does not need to be computed any longer as it
    is maintained by the internal SC.View statechart.

    @deprecated Version 1.10
    @returns {SC.View} receiver
  */
  recomputeIsVisibleInWindow: function () {
    


    return this;
  }

});

/* >>>>>>>>>> BEGIN source/panes/pane.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('views/view');
sc_require('views/view/acceleration');
sc_require('views/view/cursor');
sc_require('views/view/enabled');
sc_require('views/view/keyboard');
sc_require('views/view/layout');
sc_require('views/view/manipulation');
sc_require('views/view/theming');
sc_require('views/view/touch');
sc_require('views/view/visibility');
sc_require('mixins/responder_context');


/**
  Indicates a value has a mixed state of both on and off.

  @type String
*/
SC.MIXED_STATE = '__MIXED__' ;

/** @class
  A Pane is like a regular view except that it does not need to live within a
  parent view.  You usually use a Pane to form the root of a view hierarchy in
  your application, such as your main application view or for floating
  palettes, popups, menus, etc.

  Usually you will not work directly with the SC.Pane class, but with one of
  its subclasses such as SC.MainPane, SC.Panel, or SC.PopupPane.

  ## Showing a Pane

  To make a pane visible, you need to add it to your HTML document.  The
  simplest way to do this is to call the append() method:

      myPane = SC.Pane.create();
      myPane.append(); // adds the pane to the document

  This will insert your pane into the end of your HTML document body, causing
  it to display on screen.  It will also register your pane with the
  SC.RootResponder for the document so you can start to receive keyboard,
  mouse, and touch events.

  If you need more specific control for where you pane appears in the
  document, you can use several other insertion methods such as appendTo(),
  prependTo(), before() and after().  These methods all take a an element to
  indicate where in your HTML document you would like you pane to be inserted.

  Once a pane is inserted into the document, it will be sized and positioned
  according to the layout you have specified.  It will then automatically
  resize with the window if needed, relaying resize notifications to children
  as well.

  ## Hiding a Pane

  When you are finished with a pane, you can hide the pane by calling the
  remove() method.  This method will actually remove the Pane from the
  document body, as well as deregistering it from the RootResponder so that it
  no longer receives events.

  The isVisibleInWindow method will also change to NO for the Pane and all of
  its childViews and the views will no longer have their updateDisplay methods
  called.

  You can readd a pane to the document again any time in the future by using
  any of the insertion methods defined in the previous section.

  ## Receiving Events

  Your pane and its child views will automatically receive any mouse or touch
  events as long as it is on the screen.  To receive keyboard events, however,
  you must focus the keyboard on your pane by calling makeKeyPane() on the
  pane itself.  This will cause the RootResponder to route keyboard events to
  your pane.  The pane, in turn, will route those events to its current
  keyView, if there is any.

  Note that all SC.Views (anything that implements SC.ClassicResponder,
  really) will be notified when it is about or gain or lose keyboard focus.
  These notifications are sent both when the view is made keyView of a
  particular pane and when the pane is made keyPane for the entire
  application.

  You can prevent your Pane from becoming key by setting the acceptsKeyPane
  to NO on the pane.  This is useful when creating palettes and other popups
  that should not steal keyboard control from another view.

  @extends SC.View
  @extends SC.ResponderContext
  @since SproutCore 1.0
*/
SC.Pane = SC.View.extend(SC.ResponderContext,
/** @scope SC.Pane.prototype */ {

  /**
    Returns YES for easy detection of when you reached the pane.
    @type Boolean
  */
  isPane: YES,

  /**
    Set to the current page when the pane is instantiated from a page object.
    @property {SC.Page}
  */
  page: null,

  // .......................................................
  // ROOT RESPONDER SUPPORT
  //

  /**
    The rootResponder for this pane.  Whenever you add a pane to a document,
    this property will be set to the rootResponder that is now forwarding
    events to the pane.

    @property {SC.Responder}
  */
  rootResponder: null,

  /**
    Attempts to send the specified event up the responder chain for this pane. This
    method is used by the RootResponder to correctly delegate mouse, touch and keyboard
    events. You can also use it to send your own events to the pane's responders, though
    you will usually not do this.

    A responder chain is a linked list of responders - mostly views - which are each
    sequentially given an opportunity to handle the event. The responder chain begins with
    the event's `target` view, and proceeds up the chain of parentViews (via the customizable
    nextResponder property) until it reaches the pane and its defaultResponder. You can
    specify the `target` responder; by default, it is the pane's current `firstResponder`
    (see SC.View keyboard event documentation for more on the first responder).

    Beginning with the target, each responder is given the chance to handle the named event.
    In order to handle an event, a responder must implement a method with the name of the
    event. For example, to handle the mouseDown event, expose a `mouseDown` method. If a
    responder handles a method, then the event will stop bubbling up the responder chain.
    (If your responder exposes a handler method but you do not always want to handle that
    method, you can signal that the method should continue bubbling up the responder chain by
    returning NO from your handler.)

    In some rare cases, you may want to only alert part of the responder chain. For example,
    SC.ScrollView uses this to capture a touch to give the user a moment to begin scrolling
    on otherwise-tappable controls. To accomplish this, pass a view (or responder) as the
    `untilResponder` argument. If the responder chain includes this view, it will break the
    chain there and not proceed. (Note that the `untilResponder` object will not be given a
    chance to respond to the event.)

    @param {String} action The name of the event (i.e. method name) to invoke.
    @param {SC.Event} evt The optional event object.
    @param {SC.Responder} target The responder chain's first member. If not specified, will
      use the pane's current firstResponder instead.
    @param {SC.Responder} untilResponder If specified, the responder chain will break when
      this object is reached, preventing it and subsequent responders from receiving
      the event.
    @returns {Object} object that handled the event
  */
  sendEvent: function(action, evt, target, untilResponder) {
    // Until there's time for a refactor of this method, note the early return for untilResponder, marked
    // below with "FAST PATH".

    // walk up the responder chain looking for a method to handle the event
    if (!target) target = this.get('firstResponder') ;
    while(target) {
      if (action === 'touchStart') {
        // first, we must check that the target is not already touch responder
        // if it is, we don't want to have "found" it; that kind of recursion is sure to
        // cause really severe, and even worse, really odd bugs.
        if (evt.touchResponder === target) {
          target = null;
          break;
        }

        // now, only pass along if the target does not already have any touches, or is
        // capable of accepting multitouch.
        if (!target.get("hasTouch") || target.get("acceptsMultitouch")) {
          if (target.tryToPerform("touchStart", evt)) break;
        }
      } else if (action === 'touchEnd' && !target.get("acceptsMultitouch")) {
        if (!target.get("hasTouch")) {
          if (target.tryToPerform("touchEnd", evt)) break;
        }
      } else {
        if (target.tryToPerform(action, evt)) break;
      }

      // If we've reached the pane, we're at the end of the chain.
      target = (target === this) ? null : target.get('nextResponder');
      // FAST PATH: If we've reached untilResponder, break the chain. (TODO: refactor out this early return. The
      // point is to avoid pinging defaultResponder if we ran into the untilResponder.)
      if (target === untilResponder) {
        return (evt && evt.mouseHandler) || null;
      }
    }

    // if no handler was found in the responder chain, try the default
    if (!target && (target = this.get('defaultResponder'))) {
      if (typeof target === SC.T_STRING) {
        target = SC.objectForPropertyPath(target);
      }

      if (!target) target = null;
      else target = target.tryToPerform(action, evt) ? target : null ;
    }

    // if we don't have a default responder or no responders in the responder
    // chain handled the event, see if the pane itself implements the event
    else if (!target && !(target = this.get('defaultResponder'))) {
      target = this.tryToPerform(action, evt) ? this : null ;
    }

    return (evt && evt.mouseHandler) || target;
  },

  // .......................................................
  // RESPONDER CONTEXT
  //

  /**
    Pane's never have a next responder.

    @property {SC.Responder}
    @readOnly
  */
  nextResponder: function() {
    return null;
  }.property().cacheable(),

  /**
    The first responder.  This is the first view that should receive action
    events.  Whenever you click on a view, it will usually become
    firstResponder.

    @property {SC.Responder}
  */
  firstResponder: null,

  /**
    If YES, this pane can become the key pane.  You may want to set this to NO
    for certain types of panes.  For example, a palette may never want to
    become key.  The default value is YES.

    @type Boolean
  */
  acceptsKeyPane: YES,

  /**
    This is set to YES when your pane is currently the target of key events.

    @type Boolean
  */
  isKeyPane: NO,

  /**
    Make the pane receive key events.  Until you call this method, the
    keyView set for this pane will not receive key events.

    @returns {SC.Pane} receiver
  */
  becomeKeyPane: function() {
    if (this.get('isKeyPane')) return this ;
    if (this.rootResponder) this.rootResponder.makeKeyPane(this) ;

    return this ;
  },

  /**
    Remove the pane view status from the pane.  This will simply set the
    keyPane on the rootResponder to null.

    @returns {SC.Pane} receiver
  */
  resignKeyPane: function() {
    if (!this.get('isKeyPane')) return this ;
    if (this.rootResponder) this.rootResponder.makeKeyPane(null);

    return this ;
  },

  /**
    Makes the passed view (or any object that implements SC.Responder) into
    the new firstResponder for this pane.  This will cause the current first
    responder to lose its responder status and possibly keyResponder status as
    well.

    @param {SC.View} view
    @param {Event} evt that cause this to become first responder
    @returns {SC.Pane} receiver
  */
  makeFirstResponder: function(original, view, evt) {
    // firstResponder should never be null
    if(!view) view = this;

    var current = this.get('firstResponder'),
      isKeyPane = this.get('isKeyPane');

    if (current === view) return this ; // nothing to do

    // if we are currently key pane, then notify key views of change also
    if (isKeyPane) {
      if (current) { current.tryToPerform('willLoseKeyResponderTo', view); }
      if (view) {
        view.tryToPerform('willBecomeKeyResponderFrom', current);
      }
    }

    if (current) {
      current.beginPropertyChanges();
      current.set('isKeyResponder', NO);
    }

    if (view) {
      view.beginPropertyChanges();
      view.set('isKeyResponder', isKeyPane);
    }

    original(view, evt);

    if(current) current.endPropertyChanges();
    if(view) view.endPropertyChanges();

    // and notify again if needed.
    if (isKeyPane) {
      if (view) {
        view.tryToPerform('didBecomeKeyResponderFrom', current);
      }
      if (current) {
        current.tryToPerform('didLoseKeyResponderTo', view);
      }
    }

    return this ;
  }.enhance(),

  /**
    Called just before the pane loses it's keyPane status.  This will notify
    the current keyView, if there is one, that it is about to lose focus,
    giving it one last opportunity to save its state.

    @param {SC.Pane} pane
    @returns {SC.Pane} receiver
  */
  willLoseKeyPaneTo: function(pane) {
    this._forwardKeyChange(this.get('isKeyPane'), 'willLoseKeyResponderTo', pane, NO);
    return this ;
  },

  /**
    Called just before the pane becomes keyPane.  Notifies the current keyView
    that it is about to gain focus.  The keyView can use this opportunity to
    prepare itself, possibly stealing any value it might need to steal from
    the current key view.

    @param {SC.Pane} pane
    @returns {SC.Pane} receiver
  */
  willBecomeKeyPaneFrom: function(pane) {
    this._forwardKeyChange(!this.get('isKeyPane'), 'willBecomeKeyResponderFrom', pane, YES);
    return this ;
  },


  didBecomeKeyResponderFrom: function(responder) {},

  /**
    Called just after the pane has lost its keyPane status.  Notifies the
    current keyView of the change.  The keyView can use this method to do any
    final cleanup and changes its own display value if needed.

    @param {SC.Pane} pane
    @returns {SC.Pane} receiver
  */
  didLoseKeyPaneTo: function(pane) {
    var isKeyPane = this.get('isKeyPane');
    this.set('isKeyPane', NO);
    this._forwardKeyChange(isKeyPane, 'didLoseKeyResponderTo', pane);
    return this ;
  },

  /**
    Called just after the keyPane focus has changed to the receiver.  Notifies
    the keyView of its new status.  The keyView should use this method to
    update its display and actually set focus on itself at the browser level
    if needed.

    @param {SC.Pane} pane
    @returns {SC.Pane} receiver

  */
  didBecomeKeyPaneFrom: function(pane) {
    var isKeyPane = this.get('isKeyPane');
    this.set('isKeyPane', YES);
    this._forwardKeyChange(!isKeyPane, 'didBecomeKeyResponderFrom', pane, YES);
    return this ;
  },

  // .......................................................
  // MAIN PANE SUPPORT
  //

  /**
    Returns YES whenever the pane has been set as the main pane for the
    application.

    @type Boolean
  */
  isMainPane: NO,

  /**
    Invoked when the pane is about to become the focused pane.  Override to
    implement your own custom handling.

    @param {SC.Pane} pane the pane that currently have focus
    @returns {void}
  */
  focusFrom: function(pane) {},

  /**
    Invoked when the the pane is about to lose its focused pane status.
    Override to implement your own custom handling

    @param {SC.Pane} pane the pane that will receive focus next
    @returns {void}
  */
  blurTo: function(pane) {},

  /**
    Invoked when the view is about to lose its mainPane status.  The default
    implementation will also remove the pane from the document since you can't
    have more than one mainPane in the document at a time.

    @param {SC.Pane} pane
    @returns {void}
  */
  blurMainTo: function(pane) {
    this.set('isMainPane', NO) ;
  },

  /**
    Invokes when the view is about to become the new mainPane.  The default
    implementation simply updates the isMainPane property.  In your subclass,
    you should make sure your pane has been added to the document before
    trying to make it the mainPane.  See SC.MainPane for more information.

    @param {SC.Pane} pane
    @returns {void}
  */
  focusMainFrom: function(pane) {
    this.set('isMainPane', YES);
  },

  // .......................................................
  // ADDING/REMOVE PANES TO SCREEN
  //

  /**
    Inserts the pane at the end of the document.  This will also add the pane
    to the rootResponder.

    @param {SC.RootResponder} rootResponder
    @returns {SC.Pane} receiver
  */
  append: function() {
    return this.appendTo(document.body) ;
  },

  /**
    Removes the pane from the document.

    This will *not* destroy the pane's layer or destroy the pane itself.

    @returns {SC.Pane} receiver
  */
  remove: function() {
    if (this.get('isAttached')) {
      this._doDetach();
    }

    return this ;
  },

  /**
    Inserts the current pane into the page. The actual DOM insertion is done
    by a function passed into `insert`, which receives the layer as a
    parameter. This function is responsible for making sure a layer exists,
    is not already attached, and for calling `paneDidAttach` when done.

        pane = SC.Pane.create();
        pane.insert(function(layer) {
          jQuery(layer).insertBefore("#otherElement");
        });

    @param {Function} fn function which performs the actual DOM manipulation
      necessary in order to insert the pane's layer into the DOM.
    @returns {SC.Pane} receiver
   */
  insert: function(fn) {
    // Render the layer.
    this.createLayer();

    // Pass the layer to the callback (TODO: why?)
    var layer = this.get('layer');
    fn(layer);

    return this;
  },

  /**
    Inserts the pane into the DOM.

    @param {DOMElement|jQuery|String} elem the element to append the pane's layer to.
      This is passed to `jQuery()`, so any value supported by `jQuery()` will work.
    @returns {SC.Pane} receiver
  */
  appendTo: function(elem) {
    var self = this;

    return this.insert(function () {
      self._doAttach(jQuery(elem)[0]);
    });
  },

  /**
    This has been deprecated and may cause issues when used.  Please use
    didAppendToDocument instead, which is not defined by SC.Pane (i.e. you
    don't need to call sc_super when implementing didAppendToDocument in direct
    subclasses of SC.Pane).

    @deprecated Version 1.10
  */
  paneDidAttach: function() {
    // Does nothing.  Left here so that subclasses that implement the method
    // and call arguments.callee.base.apply(this,arguments) won't fail.
  },

  /**
    This method is called after the pane is attached and before child views
    are notified that they were appended to the document. Override this
    method to recompute properties that depend on the pane's existence
    in the document but must be run prior to child view notification.
   */
  recomputeDependentProperties: function () {
    // Does nothing.  Left here so that subclasses that implement the method
    // and call arguments.callee.base.apply(this,arguments) won't fail.
  },

  /** @deprecated Version 1.11. Use `isAttached` instead. */
  isPaneAttached: function () {

    


    return this.get('isAttached');
  }.property('isAttached').cacheable(),

  /**
    If YES, a touch intercept pane will be added above this pane when on
    touch platforms.
  */
  wantsTouchIntercept: NO,

  /**
    Returns YES if wantsTouchIntercept and this is a touch platform.
  */
  hasTouchIntercept: function(){
    return this.get('wantsTouchIntercept') && SC.platform.touch;
  }.property('wantsTouchIntercept').cacheable(),

  /**
    The Z-Index of the pane. Currently, you have to match this in CSS.
    TODO: ALLOW THIS TO AUTOMATICALLY SET THE Z-INDEX OF THE PANE (as an option).
    ACTUAL TODO: Remove this because z-index is evil.
  */
  zIndex: 0,

  /**
    The amount over the pane's z-index that the touch intercept should be.
  */
  touchZ: 99,

  /** @private */
  _addIntercept: function() {
    if (this.get('hasTouchIntercept')) {
      var div = document.createElement("div");
      var divStyle = div.style;
      divStyle.position = "absolute";
      divStyle.left = "0px";
      divStyle.top = "0px";
      divStyle.right = "0px";
      divStyle.bottom = "0px";
      divStyle[SC.browser.experimentalStyleNameFor('transform')] = "translateZ(0px)";
      divStyle.zIndex = this.get("zIndex") + this.get("touchZ");
      div.className = "touch-intercept";
      div.id = "touch-intercept-" + SC.guidFor(this);
      this._touchIntercept = div;
      document.body.appendChild(div);
    }
  },

  /** @private */
  _removeIntercept: function() {
    if (this._touchIntercept) {
      document.body.removeChild(this._touchIntercept);
      this._touchIntercept = null;
    }
  },

  /** @private */
  hideTouchIntercept: function() {
    if (this._touchIntercept) this._touchIntercept.style.display = "none";
  },

  /** @private */
  showTouchIntercept: function() {
    if (this._touchIntercept) this._touchIntercept.style.display = "block";
  },

  /** @private */
  // updateLayerLocation: function () {
  //   if(this.get('designer') && SC.suppressMain) return arguments.callee.base.apply(this,arguments);
  //   // note: the normal code here to update node location is removed
  //   // because we don't need it for panes.
  //   return this;
  // },

  /** @private */
  init: function() {
    // Backwards compatibility
    


    // if a layer was set manually then we will just attach to existing HTML.
    var hasLayer = !!this.get('layer');

    arguments.callee.base.apply(this,arguments);

    if (hasLayer) {
      this._attached();
    }
  },

  /** @private */
  classNames: ['sc-pane']

}) ;

/* >>>>>>>>>> BEGIN source/panes/keyboard.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
sc_require("panes/pane");

SC.Pane.reopen(
  /** @scope SC.Pane.prototype */ {

  performKeyEquivalent: function(keystring, evt) {
    var ret = arguments.callee.base.apply(this,arguments) ; // try normal view behavior first
    if (!ret) {
      var defaultResponder = this.get('defaultResponder') ;
      if (defaultResponder) {
        // try default responder's own performKeyEquivalent method,
        // if it has one...
        if (defaultResponder.performKeyEquivalent) {
          ret = defaultResponder.performKeyEquivalent(keystring, evt) ;
        }

        // even if it does have one, if it doesn't handle the event, give
        // methodName-style key equivalent handling a try
        if (!ret && defaultResponder.tryToPerform) {
          ret = defaultResponder.tryToPerform(keystring, evt) ;
        }
      }
    }
    return ret ;
  },

  /** @private
    If the user presses the tab key and the pane does not have a first
    responder, try to give it to the next eligible responder.

    If the keyDown event reaches the pane, we can assume that no responders in
    the responder chain, nor the default responder, handled the event.
  */
  keyDown: function(evt) {
    var nextValidKeyView;

    // Handle tab key presses if we don't have a first responder already
    if (evt.keyCode === 9 && !this.get('firstResponder')) {
      // Cycle forwards by default, backwards if the shift key is held
      if (evt.shiftKey) {
        nextValidKeyView = this.get('previousValidKeyView');
      } else {
        nextValidKeyView = this.get('nextValidKeyView');
      }

      if (nextValidKeyView) {
        this.makeFirstResponder(nextValidKeyView);
        return YES;
      }else if(!SC.TABBING_ONLY_INSIDE_DOCUMENT){
        evt.allowDefault();
      }
    }

    return NO;
  },

  /** @private method forwards status changes in a generic way. */
  _forwardKeyChange: function(shouldForward, methodName, pane, isKey) {
    var keyView, responder, newKeyView;
    if (shouldForward && (responder = this.get('firstResponder'))) {
      newKeyView = (pane) ? pane.get('firstResponder') : null ;
      keyView = this.get('firstResponder') ;
      if (keyView && keyView[methodName]) { keyView[methodName](newKeyView); }

      if ((isKey !== undefined) && responder) {
        responder.set('isKeyResponder', isKey);
      }
    }
  }
});

/* >>>>>>>>>> BEGIN source/panes/layout.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
sc_require("panes/pane");
SC.Pane.reopen(
  /** @scope SC.Pane.prototype */ {

  /**
    Last known window size.

    @type Rect
  */
  currentWindowSize: null,

  /**
    The parent dimensions are always the last known window size.

    @returns {Rect} current window size
  */
  computeParentDimensions: function (frame) {
    if (this.get('designer') && SC.suppressMain) { return arguments.callee.base.apply(this,arguments); }

    var wDim = {x: 0, y: 0, width: 1000, height: 1000},
        layout = this.get('layout');

    // There used to be a whole bunch of code right here to calculate
    // based first on a stored window size, then on root responder, then
    // from document... but a) it is incorrect because we don't care about
    // the window size, but instead, the clientWidth/Height of the body, and
    // b) the performance benefits are not worth complicating the code that much.
    if (document && document.body) {
      wDim.width = document.body.clientWidth;
      wDim.height = document.body.clientHeight;

      // IE7 is the only browser which reports clientHeight _including_ scrollbar.
      if (SC.browser.name === SC.BROWSER.ie &&
          SC.browser.compare(SC.browser.version, "7") === 0) {

        var scrollbarSize = SC.platform.get('scrollbarSize');
        if (document.body.scrollWidth > wDim.width) {
          wDim.width -= scrollbarSize;
        }
        if (document.body.scrollHeight > wDim.height) {
          wDim.height -= scrollbarSize;
        }
      }
    }

    // If there is a minWidth or minHeight set on the pane, take that
    // into account when calculating dimensions.

    if (layout.minHeight || layout.minWidth) {
      if (layout.minHeight) {
        wDim.height = Math.max(wDim.height, layout.minHeight);
      }
      if (layout.minWidth) {
        wDim.width = Math.max(wDim.width, layout.minWidth);
      }
    }
    return wDim;
  },

  /**
    Invoked by the root responder whenever the window resizes.  This should
    simply begin the process of notifying children that the view size has
    changed, if needed.

    @param {Rect} oldSize the old window size
    @param {Rect} newSize the new window size
    @returns {SC.Pane} receiver
  */
  windowSizeDidChange: function (oldSize, newSize) {
    this.set('currentWindowSize', newSize);
    this.setBodyOverflowIfNeeded();
    this.parentViewDidResize(newSize); // start notifications.
    return this;
  },

  /**
    Changes the body overflow according to whether minWidth or minHeight
    are present in the layout hash. If there are no minimums, nothing
    is done unless true is passed as the first argument. If so, then
    overflow:hidden; will be used.

    It's possible to call this manually and pass YES to remove overflow
    if setting layout to a hash without minWidth and minHeight, but it's
    probably not a good idea to do so unless you're doing it from the main
    pane. There's only one body tag, after all, and if this is called from
    multiple different panes, the panes could fight over whether it gets
    an overflow if care isn't taken!

    @param {Boolean} [force=false] force a style to be set even if there are no minimums.
    @returns {void}
  */
  setBodyOverflowIfNeeded: function (force) {
    //Code to get rid of Lion rubberbanding.
    var layout = this.get('layout'),
        size = this.get('currentWindowSize');

    if (!layout || !size || !size.width || !size.height) return;

    var minW = layout.minWidth,
      minH = layout.minHeight;

    if (force === true || minW || minH) {
      if ((minH && size.height < minH) || (minW && size.width < minW)) {
        SC.bodyOverflowArbitrator.requestVisible(this);
      } else {
        SC.bodyOverflowArbitrator.requestHidden(this);
      }
    }
  },

  /**
    Stops controlling the body overflow according to the needs of this pane.

    @returns {void}
  */
  unsetBodyOverflowIfNeeded: function () {
    SC.bodyOverflowArbitrator.withdrawRequest(this);
  }

});

/* >>>>>>>>>> BEGIN source/panes/manipulation.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
sc_require("panes/pane");

SC.Pane.reopen(
  /** @scope SC.Pane.prototype */ {

  /**
    Inserts the pane's layer as the first child of the passed element.

    @param {DOMElement|jQuery|String} elem the element to prepend the pane's layer to.
      This is passed to `jQuery()`, so any value supported by `jQuery()` will work.
    @returns {SC.Pane} receiver
  */
  prependTo: function(elem) {
    var self = this;

    return this.insert(function () {
      var el = jQuery(elem)[0];
      self._doAttach(el, el.firstChild);
    });
  },

  /**
    This method has no effect in the pane.  Instead use remove().

    @returns {void}
  */
  removeFromParent: function() {
    SC.throw("SC.Pane cannot be removed from its parent, since it's the root. Did you mean remove()?");
  }
});

/* >>>>>>>>>> BEGIN source/panes/pane_statechart.js */
sc_require("panes/pane");

/**
  Adds SC.Pane specific processes.

  While it would be a little nicer to use didAppendToDocument,
  willRemoveFromDocument and other functions, we cannot because they are public
  callbacks and if a developer overrides them without knowing to call arguments.callee.base.apply(this,arguments)
  everything will fail.  Instead, it's better to keep our static setup/remove
  code private.
  */
SC.Pane.reopen({

  /** @private */
  _executeDoAttach: function () {
    // hook into root responder
    var responder = (this.rootResponder = SC.RootResponder.responder);
    responder.panes.add(this);

    // Update the currentWindowSize cache.
    this.set('currentWindowSize', responder.currentWindowSize);

    // Set the initial design mode.  The responder will update this if it changes.
    this.updateDesignMode(this.get('designMode'), responder.get('currentDesignMode'));

    arguments.callee.base.apply(this,arguments);

    // Legacy.
    this.paneDidAttach();

    // Legacy?
    this.recomputeDependentProperties();

    // handle intercept if needed
    this._addIntercept();

    // If the layout is flexible (dependent on the window size), then the view
    // will resize when appended.
    if (!this.get('isFixedSize')) {
      // We call viewDidResize so that it calls parentViewDidResize on all child views.
      this.viewDidResize();
    }
  },

  /** @private */
  _executeDoDetach: function () {
    arguments.callee.base.apply(this,arguments);

    // remove intercept
    this._removeIntercept();

    // remove the pane
    var rootResponder = this.rootResponder;
    rootResponder.panes.remove(this);
    this.rootResponder = null;
  }

});

/* >>>>>>>>>> BEGIN source/system/ready.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


SC.BENCHMARK_LOG_READY = YES;

sc_require('system/event');

SC.mixin({
  isReady: NO,

  /**
    Allows apps to avoid automatically attach the ready handlers if they
    want to by setting this flag to YES

    @type Boolean
  */
  suppressOnReady: SC.suppressOnReady ? YES : NO,

  /**
    Allows apps to avoid automatically invoking main() when onReady is called

    @type Boolean
  */
  suppressMain: SC.suppressMain ? YES : NO,

  /**
    Add the passed target and method to the queue of methods to invoke when
    the document is ready.  These methods will be called after the document
    has loaded and parsed, but before the main() function is called.

    Methods are called in the order they are added.

    If you add a ready handler when the main document is already ready, then
    your handler will be called immediately.

    @param target {Object} optional target object
    @param method {Function} method name or function to execute
    @returns {SC}
  */
  ready: function (target, method) {
    var queue = SC._readyQueue;

    // normalize
    if (method === undefined) {
      method = target;
      target = null;
    } else if (SC.typeOf(method) === SC.T_STRING) {
      method = target[method];
    }

    if (SC.isReady) {
      jQuery(document).ready(function () { method.call(target); });
    } else {
      if (!queue) SC._readyQueue = [];
      SC._readyQueue.push(function () { method.call(target); });
    }

    return this;
  },

  onReady: {
    done: function () {
      if (SC.isReady) return;

      SC.isReady = true;

      SC.RunLoop.begin();

      SC.Locale.createCurrentLocale();
      var loc = SC.Locale.currentLanguage.toLowerCase();
      jQuery("body").addClass(loc);

      jQuery("html").attr("lang", loc);

      jQuery("#loading").remove();

      var queue = SC._readyQueue, idx, len;

      if (queue) {
        for (idx = 0, len = queue.length; idx < len; idx++) {
          queue[idx].call();
        }
        SC._readyQueue = null;
      }

      if (window.main && !SC.suppressMain && (SC.mode === SC.APP_MODE)) { window.main(); }
      SC.RunLoop.end();
    }
  }

});

// let apps ignore the regular onReady handling if they need to
if (!SC.suppressOnReady) {
  $(document).ready(SC.onReady.done);
}

// default to app mode.  When loading unit tests, this will run in test mode
SC.APP_MODE = "APP_MODE";
SC.TEST_MODE = "TEST_MODE";
SC.mode = SC.APP_MODE;

/* >>>>>>>>>> BEGIN source/system/platform.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


/**
  A constant indicating an unsupported method, property or other.

  @static
  @constant
*/
SC.UNSUPPORTED = '_sc_unsupported';


/** @class

  This platform object allows you to conditionally support certain HTML5
  features.

  Rather than relying on the user agent, it detects whether the given elements
  and events are supported by the browser, allowing you to create much more
  robust apps.
*/
SC.platform = SC.Object.create({
  /**
    The size of scrollbars in this browser.

    @type Number
  */
  scrollbarSize: function () {
    var tester = document.createElement("DIV"),
        child;
    tester.innerHTML = "<div style='height:1px;'></div>";
    tester.style.cssText = "position:absolute;width:100px;height:100px;overflow-y:visible;";

    child = tester.childNodes[0];
    document.body.appendChild(tester);
    var noScroller = child.innerWidth || child.clientWidth;
    tester.style.overflowY = 'scroll';
    var withScroller = child.innerWidth || child.clientWidth;
    document.body.removeChild(tester);

    return noScroller - withScroller;

  }.property().cacheable(),


  /*
    NOTES
     - Chrome would incorrectly indicate support for touch events.  This has been fixed:
       http://code.google.com/p/chromium/issues/detail?id=36415
     - Android is assumed to support touch, but incorrectly reports that it does not.
     - See: https://github.com/Modernizr/Modernizr/issues/84 for a discussion on detecting
       touch capability.
     - See: https://github.com/highslide-software/highcharts.com/issues/1331 for a discussion
       about why we need to check if ontouchstart is null in addition to check if it's defined
     - The test for window._phantom provides support for phantomjs, the headless WebKit browser
       used in Travis-CI, and which incorredtly (see above) identifies itself as a touch browser.
       For more information on CI see https://github.com/sproutcore/sproutcore/pull/1025
       For discussion of the phantomjs touch issue see https://github.com/ariya/phantomjs/issues/10375
  */
  /**
    YES if the current device supports touch events, NO otherwise.

    You can simulate touch events in environments that don't support them by
    calling SC.platform.simulateTouchEvents() from your browser's console.

    Note! The support for "touch" is a browser property and can't be relied on
    to determine if the device is actually a "touch" device or if the device
    actually uses touch events.  There are instances where "touch" devices will
    not send touch events or will send touch and mouse events together and
    there are instances where "non-touch" devices will support touch events.

    It is recommended that you do not use this property at this time.

    @type Boolean
  */
  touch: (!SC.none(window.ontouchstart) || SC.browser.name === SC.BROWSER.android || 'ontouchstart' in document.documentElement) && SC.none(window._phantom),

  /**
    True if bouncing on scroll is expected in the current platform.

    @type Boolean
  */
  bounceOnScroll: SC.browser.os === SC.OS.ios,

  /**
    True if pinch-to-zoom is expected in the current platform.

    @type Boolean
  */
  pinchToZoom: SC.browser.os === SC.OS.ios,

  /**
    A hash that contains properties that indicate support for new HTML5
    a attributes.

    For example, to test to see if the `download` attribute is supported,
    you would verify that `SC.platform.a.download` is true.

    @type Array
  */
  a: function () {
    var elem = document.createElement('a');

    return {
      download: !!('download' in elem),
      media: !!('media' in elem),
      ping: !!('ping' in elem),
    };
  }(),

  /**
    A hash that contains properties that indicate support for new HTML5
    input attributes.

    For example, to test to see if the `placeholder` attribute is supported,
    you would verify that `SC.platform.input.placeholder` is true.

    @type Array
  */
  input: function (attributes) {
    var ret = {},
        len = attributes.length,
        elem = document.createElement('input'),
        attr, idx;

    for (idx = 0; idx < len; idx++) {
      attr = attributes[idx];

      ret[attr] = !!(attr in elem);
    }

    return ret;
  }(['autocomplete', 'readonly', 'list', 'size', 'required', 'multiple', 'maxlength',
        'pattern', 'min', 'max', 'step', 'placeholder',
        'selectionStart', 'selectionEnd', 'selectionDirection']),

  /**
    YES if the application is currently running as a standalone application.

    For example, if the user has saved your web application to their home
    screen on an iPhone OS-based device, this property will be true.

    @type Boolean
  */
  standalone: !!navigator.standalone,


  /** @deprecated Since version 1.10. Use SC.browser.cssPrefix.
    Prefix for browser specific CSS attributes.
  */
  cssPrefix: SC.browser.cssPrefix,

  /** @deprecated Since version 1.10. Use SC.browser.domPrefix.
    Prefix for browser specific CSS attributes when used in the DOM.
  */
  domCSSPrefix: SC.browser.domPrefix,

  /**
    Call this method to swap out the default mouse handlers with proxy methods
    that will translate mouse events to touch events.

    This is useful if you are debugging touch functionality on the desktop.
  */
  simulateTouchEvents: function () {
    // Touch events are supported natively, no need for this.
    if (this.touch) {
      

      return;
    }

    SC.Logger.log("Simulating touch events");

    // Tell the app that we now "speak" touch
    SC.platform.touch = YES;
    SC.platform.bounceOnScroll = YES;

    // CSS selectors may depend on the touch class name being present
    document.body.className = document.body.className + ' touch';

    // Initialize a counter, which we will use to generate unique ids for each
    // fake touch.
    this._simtouch_counter = 1;

    // Remove events that don't exist in touch environments
    this.removeEvents(['click', 'dblclick', 'mouseout', 'mouseover', 'mousewheel']);

    // Replace mouse events with our translation methods
    this.replaceEvent('mousemove', this._simtouch_mousemove);
    this.replaceEvent('mousedown', this._simtouch_mousedown);
    this.replaceEvent('mouseup', this._simtouch_mouseup);

    // fix orientation handling
    SC.platform.windowSizeDeterminesOrientation = YES;
    SC.device.orientationHandlingShouldChange();
  },

  /** @private
    Removes event listeners from the document.

    @param {Array} events Array of strings representing the events to remove
  */
  removeEvents: function (events) {
    var idx, len = events.length, key;
    for (idx = 0; idx < len; idx++) {
      key = events[idx];
      SC.Event.remove(document, key, SC.RootResponder.responder, SC.RootResponder.responder[key]);
    }
  },

  /** @private
    Replaces an event listener with another.

    @param {String} evt The event to replace
    @param {Function} replacement The method that should be called instead
  */
  replaceEvent: function (evt, replacement) {
    SC.Event.remove(document, evt, SC.RootResponder.responder, SC.RootResponder.responder[evt]);
    SC.Event.add(document, evt, this, replacement);
  },

  /** @private
    When simulating touch events, this method is called when mousemove events
    are received.

    If the altKey is depressed and pinch center not yet established, we will capture the mouse position.
  */
  _simtouch_mousemove: function (evt) {
    if (!this._mousedown) {
      /*
        we need to capture when was the first spot that the altKey was pressed and use it as
        the center point of a pinch
       */
      if (evt.altKey && this._pinchCenter === null) {
        this._pinchCenter = {
          pageX: evt.pageX,
          pageY: evt.pageY,
          screenX: evt.screenX,
          screenY: evt.screenY,
          clientX: evt.clientX,
          clientY: evt.clientY
        };
      } else if (!evt.altKey && this._pinchCenter !== null) {
        this._pinchCenter = null;
      }
      return NO;
    }

    var manufacturedEvt = this.manufactureTouchEvent(evt, 'touchmove');
    return SC.RootResponder.responder.touchmove(manufacturedEvt);
  },

  /** @private
    When simulating touch events, this method is called when mousedown events
    are received.
  */
  _simtouch_mousedown: function (evt) {
    this._mousedown = YES;

    var manufacturedEvt = this.manufactureTouchEvent(evt, 'touchstart');
    return SC.RootResponder.responder.touchstart(manufacturedEvt);
  },

  /** @private
    When simulating touch events, this method is called when mouseup events
    are received.
  */
  _simtouch_mouseup: function (evt) {
    var manufacturedEvt = this.manufactureTouchEvent(evt, 'touchend'),
        ret = SC.RootResponder.responder.touchend(manufacturedEvt);

    this._mousedown = NO;
    this._simtouch_counter++;
    return ret;
  },

  /** @private
    Converts a mouse-style event to a touch-style event.

    Note that this method edits the passed event in place, and returns
    that same instance instead of a new, modified version.

    If altKey is depressed and we have previously captured a position for the center of
    the pivot point for the virtual second touch, we will manufacture an additional touch.
    The position of the virtual touch will be the reflection of the mouse position,
    relative to the pinch center.

    @param {Event} evt the mouse event to modify
    @param {String} type the type of event (e.g., touchstart)
    @returns {Event} the mouse event with an added changedTouches array
  */
  manufactureTouchEvent: function (evt, type) {
    var realTouch, virtualTouch, realTouchIdentifier = this._simtouch_counter;

    realTouch = {
      type: type,
      target: evt.target,
      identifier: realTouchIdentifier,
      pageX: evt.pageX,
      pageY: evt.pageY,
      screenX: evt.screenX,
      screenY: evt.screenY,
      clientX: evt.clientX,
      clientY: evt.clientY
    };
    evt.touches = [ realTouch ];

    /*
      simulate pinch gesture
     */
    if (evt.altKey && this._pinchCenter !== null) {
      //calculate the mirror position of the virtual touch
      var pageX = this._pinchCenter.pageX + this._pinchCenter.pageX - evt.pageX,
          pageY = this._pinchCenter.pageY + this._pinchCenter.pageY - evt.pageY,
          screenX = this._pinchCenter.screenX + this._pinchCenter.screenX - evt.screenX,
          screenY = this._pinchCenter.screenY + this._pinchCenter.screenY - evt.screenY,
          clientX = this._pinchCenter.clientX + this._pinchCenter.clientX - evt.clientX,
          clientY = this._pinchCenter.clientY + this._pinchCenter.clientY - evt.clientY,
          virtualTouchIdentifier = this._simtouch_counter + 1;

      virtualTouch = {
        type: type,
        target: evt.target,
        identifier: virtualTouchIdentifier,
        pageX: pageX,
        pageY: pageY,
        screenX: screenX,
        screenY: screenY,
        clientX: clientX,
        clientY: clientY
      };

      evt.touches = [realTouch, virtualTouch];
    }
    evt.changedTouches = evt.touches;

    return evt;
  },

  /**
    Whether the browser supports CSS animations.

    @type Boolean
  */
  supportsCSSAnimations: SC.browser.experimentalStyleNameFor('animation') !== SC.UNSUPPORTED,

  /**
    Whether the browser supports CSS transitions.

    @type Boolean
  */
  supportsCSSTransitions: SC.browser.experimentalStyleNameFor('transition') !== SC.UNSUPPORTED,

  /**
    Whether the browser supports 2D CSS transforms.

    @type Boolean
  */
  supportsCSSTransforms: SC.browser.experimentalStyleNameFor('transform') !== SC.UNSUPPORTED,

  /**
    Whether the browser can properly handle 3D CSS transforms.

    @type Boolean
  */
  supportsCSS3DTransforms: SC.browser.experimentalStyleNameFor('perspective') !== SC.UNSUPPORTED,

  /**
    Whether the browser supports the application cache.

    @type Boolean
  */
  supportsApplicationCache: ('applicationCache' in window),

  /**
    Whether the browser supports the hashchange event.

    @type Boolean
  */
  supportsHashChange: function () {
    // Code copied from Modernizr which copied code from YUI (MIT licenses)
    // documentMode logic from YUI to filter out IE8 Compat Mode which false positives
    return ('onhashchange' in window) && (document.documentMode === undefined || document.documentMode > 7);
  }(),

  /**
    Whether the browser supports HTML5 history.

    @type Boolean
  */
  supportsHistory: function () {
    return !!(window.history && window.history.pushState);
  }(),

  /**
    Whether the browser supports IndexedDB.

    @type Boolean
  */
  supportsIndexedDB: function () {
    return !!(window.indexedDB || window[SC.browser.domPrefix + 'IndexedDB']);
  }(),

  /**
    Whether the browser supports the canvas element.

    @type Boolean
  */
  supportsCanvas: function () {
    return !!document.createElement('canvas').getContext;
  }(),

  /**
    Whether the browser supports the XHR2 ProgressEvent specification. This
    reliably implies support for XMLHttpRequest 'loadstart' and 'progress'
    events, as well as the terminal 'load', 'error' and 'abort' events. Support
    for 'loadend', which fires no matter how the request terminats, is a bit
    spottier and should be verified separately using `supportsXHR2LoadEndEvent`.

    @type Boolean
  */
  supportsXHR2ProgressEvent: ('ProgressEvent' in window),

  /**
    Whether the browser supports the XHR2 FormData specification.

    @type Boolean
  */
  supportsXHR2FormData: ('FormData' in window),

  /**
    Whether the browser supports the XHR2 ProgressEvent's loadend event. If not
    supported, you should handle 'load', 'error' and 'abort' events instead.

    @type Boolean
   */
  supportsXHR2LoadEndEvent: function () {
    return (new XMLHttpRequest).onloadend === null;
  } (),

  /**
    Whether the browser supports the orientationchange event.

    @type Boolean
  */
  supportsOrientationChange: ('onorientationchange' in window),

  /**
    Whether the browser supports WebSQL.

    @type Boolean
  */
  supportsWebSQL: ('openDatabase' in window),

  /**
    Because iOS is slow to dispatch the window.onorientationchange event,
    we use the window size to determine the orientation on iOS devices
    and desktop environments when SC.platform.touch is YES (ie. when
    SC.platform.simulateTouchEvents has been called)

    @type Boolean
  */
  windowSizeDeterminesOrientation: SC.browser.os === SC.OS.ios || !('onorientationchange' in window),

  /**
    Does this browser support the Apache Cordova (formerly phonegap) runtime?

    This requires that you (the engineer) manually include the cordova
    javascript library for the appropriate platform (Android, iOS, etc)
    in your code. There are various methods of doing this; creating your own
    platform-specific index.rhtml is probably the easiest option.

    WARNING: Using the javascript_libs Buildfile option for the cordova include
    will NOT work. The library will be included after your application code,
    by which time this property will already have been evaluated.

    @type Boolean
    @see http://incubator.apache.org/cordova/
  */
  // Check for the global cordova property.
  cordova: (typeof window.cordova !== "undefined")

});

/** @private
  Test the transition and animation event names of this platform.  We could hard
  code event names into the framework, but at some point things would change and
  we would get it wrong.  Instead we perform actual tests to find out the proper
  names and only add the proper listeners.

  Once the tests are completed the RootResponder is notified in order to clean up
  unnecessary transition and animation event listeners.
*/
SC.ready(function () {
  // This will add 4 different variations of the named event listener and clean
  // them up again.
  // Note: we pass in capitalizedEventName, because we can't just capitalize
  // the standard event name.  For example, in WebKit the standard transitionend
  // event is named webkitTransitionEnd, not webkitTransitionend.
  var executeTest = function (el, standardEventName, capitalizedEventName, cleanUpFunc) {
    var domPrefix = SC.browser.domPrefix,
      lowerDomPrefix = domPrefix.toLowerCase(),
      eventNameKey = standardEventName + 'EventName',
      callback = function (evt) {
        var domPrefix = SC.browser.domPrefix,
          lowerDomPrefix = domPrefix.toLowerCase(),
          eventNameKey = standardEventName + 'EventName';

        // Remove all the event listeners.
        el.removeEventListener(standardEventName, callback, NO);
        el.removeEventListener(lowerDomPrefix + standardEventName, callback, NO);
        el.removeEventListener(lowerDomPrefix + capitalizedEventName, callback, NO);
        el.removeEventListener(domPrefix + capitalizedEventName, callback, NO);

        // The cleanup timer re-uses this function and doesn't pass evt.
        if (evt) {
          SC.platform[eventNameKey] = evt.type;

          // Don't allow the event to bubble, because SC.RootResponder will be
          // adding event listeners as soon as the testing is complete.  It is
          // important that SC.RootResponder's listeners don't catch the last
          // test event.
          evt.stopPropagation();
        }

        // Call the clean up function, pass in success state.
        if (cleanUpFunc) { cleanUpFunc(!!evt); }
      };

    // Set the initial value as unsupported.
    SC.platform[eventNameKey] = SC.UNSUPPORTED;

    // Try the various implementations.
    // ex. transitionend, webkittransitionend, webkitTransitionEnd, WebkitTransitionEnd
    el.addEventListener(standardEventName, callback, NO);
    el.addEventListener(lowerDomPrefix + standardEventName, callback, NO);
    el.addEventListener(lowerDomPrefix + capitalizedEventName, callback, NO);
    el.addEventListener(domPrefix + capitalizedEventName, callback, NO);
  };

  // Set up and execute the transition event test.
  if (SC.platform.supportsCSSTransitions) {
    var transitionEl = document.createElement('div'),
      transitionStyleName = SC.browser.experimentalStyleNameFor('transition', 'all 1ms linear');

    transitionEl.style[transitionStyleName] = 'all 1ms linear';

    // Test transition events.
    executeTest(transitionEl, 'transitionend', 'TransitionEnd', function (success) {
      // If an end event never fired, we can't really support CSS transitions in SproutCore.
      if (success) {
        // Set up the SC transition event listener.
        SC.RootResponder.responder.cleanUpTransitionListeners();
      } else {
        SC.platform.supportsCSSTransitions = NO;
      }

      transitionEl.parentNode.removeChild(transitionEl);
      transitionEl = null;
    });

    // Append the test element.
    document.documentElement.appendChild(transitionEl);

    // Break execution to allow the browser to update the DOM before altering the style.
    setTimeout(function () {
      transitionEl.style.opacity = '0';
    });

    // Set up and execute the animation event test.
    if (SC.platform.supportsCSSAnimations) {
      var animationEl = document.createElement('div'),
        keyframes,
        prefixedKeyframes;

      // Generate both the regular and prefixed version of the style.
      keyframes = '@keyframes _sc_animation_test { from { opacity: 1; } to { opacity: 0; } }';
      prefixedKeyframes = '@' + SC.browser.cssPrefix + 'keyframes _sc_prefixed_animation_test { from { opacity: 1; } to { opacity: 0; } }';

      // Add test animation styles.
      animationEl.innerHTML = '<style>' + keyframes + '\n' + prefixedKeyframes + '</style>';

      // Set up and execute the animation event test.
      animationEl.style.animation = '_sc_animation_test 1ms linear';
      animationEl.style[SC.browser.domPrefix + 'Animation'] = '_sc_prefixed_animation_test 5ms linear';

      // NOTE: We could test start, but it's extra work and easier just to test the end
      // and infer the start event name from it.  Keeping this code for example.
      // executeTest(animationEl, 'animationstart', 'AnimationStart', function (success) {
      //   // If an iteration start never fired, we can't really support CSS transitions in SproutCore.
      //   if (!success) {
      //     SC.platform.supportsCSSAnimations = NO;
      //   }
      // });

      // NOTE: Testing iteration event support proves very problematic.  Many
      // browsers can't iterate less than several milliseconds which means we
      // have to wait too long to find out this event name.  Instead we test
      // the end only and infer the iteration event name from it. Keeping this
      // code for example, but it wont' work reliably unless the animation style
      // is something like '_sc_animation_test 30ms linear' (i.e. ~60ms wait time)
      // executeTest(animationEl, 'animationiteration', 'AnimationIteration', function (success) {
      //   // If an iteration event never fired, we can't really support CSS transitions in SproutCore.
      //   if (!success) {
      //     SC.platform.supportsCSSAnimations = NO;
      //   }
      // });

      // Test animation events.
      executeTest(animationEl, 'animationend', 'AnimationEnd', function (success) {
        // If an end event never fired, we can't really support CSS animations in SproutCore.
        if (success) {
          // Infer the start and iteration event names based on the success of the end event.
          var domPrefix = SC.browser.domPrefix,
            lowerDomPrefix = domPrefix.toLowerCase(),
            endEventName = SC.platform.animationendEventName;

          switch (endEventName) {
          case lowerDomPrefix + 'animationend':
            SC.platform.animationstartEventName = lowerDomPrefix + 'animationstart';
            SC.platform.animationiterationEventName = lowerDomPrefix + 'animationiteration';
            break;
          case lowerDomPrefix + 'AnimationEnd':
            SC.platform.animationstartEventName = lowerDomPrefix + 'AnimationStart';
            SC.platform.animationiterationEventName = lowerDomPrefix + 'AnimationIteration';
            break;
          case domPrefix + 'AnimationEnd':
            SC.platform.animationstartEventName = domPrefix + 'AnimationStart';
            SC.platform.animationiterationEventName = domPrefix + 'AnimationIteration';
            break;
          default:
            SC.platform.animationstartEventName = 'animationstart';
            SC.platform.animationiterationEventName = 'animationiteration';
          }

          // Set up the SC animation event listeners.
          SC.RootResponder.responder.cleanUpAnimationListeners();
        } else {
          SC.platform.supportsCSSAnimations = NO;
        }

        // Clean up.
        animationEl.parentNode.removeChild(animationEl);
        animationEl = null;
      });

      // Break execution to allow the browser to update the DOM before altering the style.
      document.documentElement.appendChild(animationEl);
    }
  }
});

/* >>>>>>>>>> BEGIN source/system/touch.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/** @class SC.Touch
  Represents a touch. Single touch objects are passed to `touchStart`, `touchEnd` and `touchCancelled` event handlers;
  a specialized multitouch event object is sent to `touchesDragged`, which include access to all in-flight touches
  (see "The touchesDragged Multitouch Event Object" below).

  SC.Touch exposes a number of properties, including pageX/Y, clientX/Y, screenX/Y, and startX/Y (the values that
  pageX/Y had when the touch began, useful for calculating how far the touch has moved). It also exposes the touch's
  target element at `target`, its target SC.View at `targetView`, and the touch's unique identifier at `identifier`,
  which may be relied upon to identify a particular touch for the duration of its lifecycle.

  A touch object exists for the duration of the touch – literally for as long as your finger is on the screen – and
  is sent to a number of touch events on your views. Touch events are sent to the touch's current responder, set initially
  by checking the responder chain for views which implement `touchStart` (or `captureTouch`, see "Touch Events" below),
  and can be passed to other views as needed (see "Touch Responders" below).

  Touch Events
  -----
  You can use the following methods on your views to capture and handle touch events:

  - `captureTouch` -- Sometimes, a touch responder part way up the chain may need to capture the touch and prevent it
    from being made available to its childViews. The canonical use case for this behavior is SC.ScrollView, which by
    default captures touches and holds onto them for 150ms to see if the user is scrolling, only passing them on to
    children if not. (See SC.ScrollView#delaysContentTouches for more.) In order to support this use case, `captureTouch`
    bubbles the opposite way as usual: beginning with the target's pane and bubbling *down* towards the target itself.
    `captureTouch` is passed a single instance of `SC.Touch`, and must return YES if it wishes to capture the touch and
    become its responder. (If your view doesn't want to immediately capture the touch, but instead wants to suggest itself
    as a fallback handler in case the child view resigns respondership, it can do so by passing itself to the touch's
    `stackCandidateTouchResponder` method.)
  - `touchStart` -- When a touch begins, or when a new view responder is first given access to it (see "Touch Responders"
    below), the touch is passed to this method.
  - `touchesDragged` -- Whenever any touches move, the `touchesDragged` method is called on the current view responder
    for any touches that have changed. The method is provided two arguments: a special multitouch event object (see "The
    touchesDragged Multitouch Event Object" below), and an array containing all of the touches on that view. (This is
    the same as calling `touch.touchesForView(this)`.)
  - `touchEnd` -- When a touch is complete, its current responder's `touchEnd` handler is invoked, if present, and passed
    the touch object which is ending.
  - `touchCancelled` -- This method is generally only called if you have changed the touch's responder. See "Touch
    Responders" below; in brief, if you pass the touch to another responder via `makeTouchResponder`, fully resigning
    your touch respondership, you will receive a `touchCancelled` call for the next event; if you pass the touch to another
    responder via `stackNextTouchResponder`, and never receive it back, you will receive a `touchCancelled` call when the
    touch finishes. (Note that because RootResponder must call touchStart to determine if a view will accept respondership,
    touchStart is called on a new responder before touchCancelled is called on the outgoing one.)

  The touchesDragged Multitouch Event Object
  -----
  The specialized event object sent to `touchesDragged` includes access to all touches currently in flight. You can
  access the touches for a specific view from the `touchesForView` method, or get an average position of the touches
  on a view from the convenient `averagedTouchesForView` method. For your convenience when dealing with the common
  single-touch view, the `touchesDragged` event object also exposes the positional page, client, screen and start X/Y
  values from the *first touch*. If you are interested in handling more than one touch, or in handling an average of
  in-flight touches, you should ignore these values. (Note that this event object exposes an array of touch events at
  `touches`. These are the browser's raw touch events, and should be avoided or used with care.)

  Touch Responders: Passing Touches Around
  -----
  The touch responder is the view which is currently handling events for that touch. A touch may only have one responder
  at a time, though a view with `acceptsMultitouch: YES` may respond to more than one touch at a time.

  A view becomes a touch responder by implementing touchStart (and not returning NO). (Out-of-order views can capture
  touch responder status by implementing captureTouch and returning YES.) Once a view is a touch responder, only that
  view will receive subsequent `touchesDragged` and `touchEnd` events; these events do not bubble like mouse events, and
  they do *not* automatically switch to other views if the touch moves outside of its initial responder.

  In some situations, you will want to pass control on to another view during the course of a touch, for example if
  it goes over another view. To permanently pass respondership to another view:

      if (shouldPassTouch) {
        touch.makeTouchResponder(nextView);
      }

  This will trigger `touchStart` on the new responder, and `touchCancel` on the outgoing one. The new responder will begin
  receiving `touchesDragged` events in place of the outgoing one.

  If you want to pass respondership to another view, but are likely to want it back – for example, when a ScrollView
  passes respondership to a child view but expects that the child view will pass it back if it moves more than a certain
  amount:

    if (shouldTemporarlyPassTouch) {
      touch.stackNextTouchResponder(nextView);
    }

  This will trigger `touchStart` on the new responder, and it will start receiving `touchesDragged` and `touchEnd` events.
  Note that the previous responder will not receive `touchCancelled` immediately, since the touch may return to it before
  the end; instead, it will only receive `touchCancelled` when the touch is ended.

  (If you would like to add a view as a fallback responder without triggering unnecessary calls to its `touchStart` and
  `touchCancelled` events, for example as an alternative to returning YES from `captureTouch`, you can call
  `stackCandidateTouchResponder` instead.)

  When the child view decides that the touch has moved enough to be a scroll, it should pass touch respondership back
  to the scroll view with:

    if (Math.abs(touch.pageX - touch.startX) > 4) {
      touch.restoreLastTouchResponder();
    }

  This will trigger `touchCancelled` on the second responder, and the first one will begin receiving `touchDragged` events
  again.
*/
SC.Touch = function(touch, touchContext) {
  // get the raw target view (we'll refine later)
  this.touchContext = touchContext;
  // Get the touch's unique ID.
  this.identifier = touch.identifier;

  var target = touch.target, targetView;

  // Special-case handling for TextFieldView's touch intercept overlays.
  if (target && SC.$(target).hasClass("touch-intercept")) {
    touch.target.style[SC.browser.experimentalStyleNameFor('transform')] = "translate3d(0px,-5000px,0px)";
    target = document.elementFromPoint(touch.pageX, touch.pageY);
    if (target) targetView = SC.viewFor(target);

    this.hidesTouchIntercept = NO;
    if (target.tagName === "INPUT") {
      this.hidesTouchIntercept = touch.target;
    } else {
      touch.target.style[SC.browser.experimentalStyleNameFor('transform')] = "translate3d(0px,0px,0px)";
    }
  } else {
    targetView = touch.target ? SC.viewFor(touch.target) : null;
  }

  this.targetView = targetView;
  this.target = target;
  this.type = touch.type;

  this.touchResponders = [];

  this.startX = this.pageX = touch.pageX;
  this.startY = this.pageY = touch.pageY;
  this.clientX = touch.clientX;
  this.clientY = touch.clientY;
  this.screenX = touch.screenX;
  this.screenY = touch.screenY;
};

SC.Touch.prototype = {
  


  /**@scope SC.Touch.prototype*/

  /** @private
    The responder that's responsible for the creation and management of this touch. Usually this will be
    your app's root responder. You must pass this on create, and should not change it afterwards.

    @type {SC.RootResponder}
  */
  touchContext: null,

  /**
    This touch's unique identifier. Provided by the browser and used to track touches through their lifetime.
    You will not usually need to use this, as SproutCore's touch objects themselves persist throughout the
    lifetime of a touch.

    @type {Number}
  */
  identifier: null,

  /**
    The touch's initial target element.

    @type: {Element}
  */
  target: null,

  /**
    The view for the touch's initial target element.

    @type {SC.View}
  */
  targetView: null,

  /**
    The touch's current view. (Usually this is the same as the current touchResponder.)

    @type {SC.View}
  */
  view: null,

  /**
    The touch's current responder, i.e. the view that is currently receiving events for this touch.

    You can use the following methods to pass respondership for this touch between views as needed:
    `makeTouchResponder`, `stackNextTouchResponder`, `restoreLastTouchResponder`, and `stackCandidateTouchResponder`.
    See each method's documentation, and "Touch Responders: Passing Touches Around" above, for more.

    @type {SC.Responder}
  */
  touchResponder: null,

  /**
    Whether the touch has ended yet. If you are caching touches outside of the RootResponder, it is your
    responsibility to check this property and handle ended touches appropriately.

    @type {Boolean}
  */
  hasEnded: NO,

  /**
    The touch's latest browser event's type, for example 'touchstart', 'touchmove', or 'touchend'.

    Note that SproutCore's event model differs from that of the browser, so it is not recommended that
    you use this property unless you know what you're doing.

    @type {String}
  */
  type: null,

  /** @private
    A faked mouse event property used to prevent unexpected behavior when proxying touch events to mouse
    event handlers.
  */
  clickCount: 1,

  /**
    The timestamp of the touch's most recent event. This is the time as of when all of the touch's
    positional values are accurate.

    @type {Number}
  */
  timeStamp: null,

  /**
    The touch's latest clientX position (relative to the viewport).

    @type {Number}
  */
  clientX: null,

  /**
    The touch's latest clientY position (relative to the viewport).

    @type {Number}
  */
  clientY: null,

  /**
    The touch's latest screenX position (relative to the screen).

    @type {Number}
  */
  screenX: null,

  /**
    The touch's latest screenY position (relative to the screen).

    @type {Number}
  */
  screenY: null,

  /**
    The touch's latest pageX position (relative to the document).

    @type {Number}
  */
  pageX: null,

  /**
    The touch's latest pageY position (relative to the document).

    @type {Number}
  */
  pageY: null,

  /**
    The touch's initial pageX value. Useful for tracking a touch's total relative movement.

    @type {Number}
  */
  startX: null,

  /**
    The touch's initial pageY value.

    @type {Number}
  */
  startY: null,

  /**
    The touch's horizontal velocity, in pixels per millisecond, at the time of its last event. (Positive
    velocities indicate movement leftward, negative velocities indicate movement rightward.)

    @type {Number}
  */
  velocityX: 0,

  /**
    The touch's vertical velocity, in pixels per millisecond, at the time of its last event. (Positive
    velocities indicate movement downward, negative velocities indicate movement upward.)

    @type {Number}
  */
  velocityY: 0,

  /** @private */
  unhideTouchIntercept: function() {
    var intercept = this.hidesTouchIntercept;
    if (intercept) {
      setTimeout(function() { intercept.style[SC.browser.experimentalStyleNameFor('transform')] = "translate3d(0px,0px,0px)"; }, 500);
    }
  },

  /**
    Indicates that you want to allow the normal default behavior.  Sets
    the hasCustomEventHandling property to YES but does not cancel the event.
  */
  allowDefault: function() {
    if (this.event) this.event.hasCustomEventHandling = YES ;
  },

  /**
    If the touch is associated with an event, prevents default action on the event. This is the
    default behavior in SproutCore, which handles events through the RootResponder instead of
    allowing native handling.
  */
  preventDefault: function() {
    if (this.event) this.event.preventDefault();
  },

  /**
    Calls the native event's stopPropagation method, which prevents the method from continuing to
    bubble. Usually, SproutCore will be handling the event via delegation at the `document` level,
    so this method will have no effect.
  */
  stopPropagation: function() {
    if (this.event) this.event.stopPropagation();
  },

  stop: function() {
    if (this.event) this.event.stop();
  },

  /**
    Removes from and calls touchEnd on the touch responder.
  */
  end: function() {
    this.touchContext.endTouch(this);
  },

  /** @private
    This property, contrary to its name, stores the last touch responder for possible use later in the touch's
    lifecycle. You will usually not use this property directly, instead calling `stackNextTouchResponder` to pass
    the touch to a different view, and `restoreLastTouchResponder` to pass it back to the previous one.

    @type {SC.Responder}
  */
  nextTouchResponder: null,

  /** @private
    An array of previous touch responders.

    @type {Array}
  */
  touchResponders: null,

  /** @private
    A lazily-created array of candidate touch responders. Use `stackCandidateTouchResponder` to add candidates;
    candidates are used as a fallback if the touch is out of previous touch responders.

    @type {Array}
  */
  candidateTouchResponders: null,

  /**
    A convenience method for making the passed view the touch's new responder, retaining the
    current responder for possible use later in the touch's lifecycle.

    For example, if the touch moves over a childView which implements its own touch handling,
    you may pass the touch to it with:

      touchesDragged: function(evt, viewTouches) {
        if ([touches should be passed to childView]) {
          this.viewTouches.forEach(function(touch) {
            touch.stackNextTouchResponder(this.someChildView);
          }, this);
        }
      }

    The child view may easily pass the touch back to this view with `touch.restoreLastTouchResponder`. In the
    mean time, this view will no longer receive `touchesDragged` events; if the touch is not returned to this
    view before ending, it will receive a `touchCancelled` event rather than `touchEnd`.

    @param {SC.Responder} view The view which should become this touch's new responder.
    @param {Boolean} upChain Whether or not a fallback responder should be sought up the responder chain if responder doesn't capture or handle the touch.
  */
  stackNextTouchResponder: function(view, upStack) {
    this.makeTouchResponder(view, YES, upStack);
  },

  /**
    A convenience method for returning touch respondership to the previous touch responder.

    For example, if your view is in a ScrollView and has captured the touch from it, your view
    will prevent scrolling until you return control of the touch to the ScrollView with:

        touchesDragged: function(evt, viewTouches) {
          if (Math.abs(evt.pageY - evt.startY) > this.MAX_SWIPE) {
            viewTouches.invoke('restoreLastTouchResponder');
          }
        }
  */
  restoreLastTouchResponder: function() {
    // If we have a previous touch responder, go back to it.
    if (this.nextTouchResponder) {
      this.makeTouchResponder(this.nextTouchResponder);
    }
    // Otherwise, check if we have a candidate responder queued up.
    else {
      var candidates = this.candidateTouchResponders,
          candidate = candidates ? candidates.pop() : null;
      if (candidate) {
        this.makeTouchResponder(candidate);
      }
    }
  },

  /**
    Changes the touch responder for the touch. If shouldStack is YES,
    the current responder will be saved so that the next responder may
    return to it.

    You will generally not call this method yourself, instead exposing on
    your view either a `touchStart` event handler method, or a `captureTouch`
    method which is passed a touch object and returns YES. This method
    is used in situations where touches need to be juggled between views,
    such as when being handled by a descendent of a ScrollView.

    When returning control of a touch to a previous handler, you should call
    `restoreLastTouchResponder` instead.

    @param {SC.Responder} responder The view to assign to the touch. (It, or if bubbling then an ancestor,
      must implement touchStart.)
    @param {Boolean} shouldStack Whether the new responder should replace the old one, or stack with it.
      Stacked responders are easy to revert via `SC.Touch#restoreLastTouchResponder`.
    @param {Boolean|SC.Responder} bubblesTo If YES, will attempt to find a `touchStart` responder up the
      responder chain. If NO or undefined, will only check the passed responder. If you pass a responder
      for this argument, the attempt will bubble until it reaches the passed responder, allowing you to
      restrict the bubbling to a portion of the responder chain. (Note that this responder will not be
      given an opportunity to respond to the event.)
    @returns {Boolean} Whether a valid touch responder was found and assigned.
  */
  makeTouchResponder: function(responder, shouldStack, bubblesTo) {
    return this.touchContext.makeTouchResponder(this, responder, shouldStack, bubblesTo);
  },

  /**
    You may want your view to insert itself into the responder chain as a fallback, but without
    having touchStart etc. called if it doesn't end up coming into play. For example, SC.ScrollView
    adds itself as a candidate responder (when delaysTouchResponder is NO) so that views can easily
    give it control, but without receiving unnecessary events if not.
  */
  stackCandidateTouchResponder: function(responder) {
    // Fast path: if we're the first one it's easy.
    if (!this.candidateTouchResponders) {
      this.candidateTouchResponders = [responder];
    }
    // Just make sure it's not at the top of the stack. There may be a weird case where a
    // view wants to be in a couple of spots in the stack, but it shouldn't want to be twice
    // in a row.
    else if (responder !== this.candidateTouchResponders[this.candidateTouchResponders.length - 1]) {
      this.candidateTouchResponders.push(responder);
    }
  },

  /**
    Captures, or recaptures, this touch. This works from the startingPoint's first child up to the
    touch's target view to find a view which implements `captureTouch` and returns YES. If the touch
    is captured, then this method will perform a standard `touchStart` event bubbling beginning with
    the view which captured the touch. If no view captures the touch, then this method returns NO,
    and you should call the `makeTouchResponder` method to trigger a standard `touchStart` bubbling
    from the initial target on down.

    You will generally not call this method yourself, instead exposing on
    your view either a `touchStart` event handler method, or a `captureTouch`
    method which is passed a touch object and returns YES. This method
    is used in situations where touches need to be juggled between views,
    such as when being handled by a descendent of a ScrollView.

    @param {?SC.Responder} startingPoint The view whose children should be given an opportunity
      to capture the event. (The starting point itself is not asked.)
    @param {Boolean} shouldStack Whether any capturing responder should stack with existing responders.
      Stacked responders are easy to revert via `SC.Touch#restoreLastTouchResponder`.

    @returns {Boolean} Whether the touch was captured. If it was not, you should pass it to
      `makeTouchResponder` for standard event bubbling.
  */
  captureTouch: function(startingPoint, shouldStack) {
    return this.touchContext.captureTouch(this, startingPoint, shouldStack);
  },

  /**
    Returns all touches for a specified view. Put as a convenience on the touch itself;
    this method is also available on the event.

    For example, to retrieve the list of touches impacting the current event handler:

        touchesDragged: function(evt) {
          var myTouches = evt.touchesForView(this);
        }

    @param {SC.Responder} view
  */
  touchesForView: function(view) {
    return this.touchContext.touchesForView(view);
  },

  /**
    A synonym for SC.Touch#touchesForView.
  */
  touchesForResponder: function(responder) {
    return this.touchContext.touchesForView(responder);
  },

  /**
    Returns average data--x, y, and d (distance)--for the touches owned by the supplied view.

    See notes on the addSelf argument for an important consideration when calling from `touchStart`.

    @param {SC.Responder} view
    @param {Boolean} addSelf Includes the receiver in calculations. Pass YES for this if calling
        from touchStart, as the touch will not yet be included by default.
  */
  averagedTouchesForView: function(view, addSelf) {
    return this.touchContext.averagedTouchesForView(view, (addSelf ? this : null));
  }
};

SC.mixin(SC.Touch, {

  create: function(touch, touchContext) {
    return new SC.Touch(touch, touchContext);
  },

  /**
    Returns the averaged touch for an array of given touches. The averaged touch includes the
    average position of all the touches (i.e. the center point), the averaged distance of all
    the touches (i.e. the average of each touch's distance to the center) and the average velocity
    of each touch.

    The returned Object has a signature like,

        {
          x: ...,
          y: ...,
          velocityX: ...,
          velocityY: ...,
          d: ...
        }

    @param {Array} touches An array of touches to average.
    @param {Object} objectRef An Object to assign the values to rather than creating a new Object. If you pass an Object to this method, that same Object will be returned with the values assigned to it. This is useful in order to only alloc memory once and hold it in order to avoid garbage collection. The trade-off is that more memory remains in use indefinitely.
    @returns {Object} The averaged touch.
  */
  averagedTouch: function (touches, objectRef) {
    var len = touches.length,
        ax = 0, ay = 0, avx = 0, avy = 0,
        idx, touch;

    // If no holder object is given, create a new one.
    if (objectRef === undefined) { objectRef = {}; }

    // Sum the positions and velocities of each touch.
    for (idx = 0; idx < len; idx++) {
      touch = touches[idx];
      ax += touch.pageX;
      ay += touch.pageY;
      avx += touch.velocityX;
      avy += touch.velocityY;
    }

    // Average each value.
    ax /= len;
    ay /= len;
    avx /= len;
    avy /= len;

    // Calculate average distance.
    var ad = 0;
    for (idx = 0; idx < len; idx++) {
      touch = touches[idx];

      // Get distance for each from average position.
      var dx = Math.abs(touch.pageX - ax);
      var dy = Math.abs(touch.pageY - ay);

      // Pythagoras was clever...
      ad += Math.pow(dx * dx + dy * dy, 0.5);
    }

    // Average value.
    ad /= len;

    objectRef.x = ax;
    objectRef.y = ay;
    objectRef.velocityX = avx;
    objectRef.velocityY = avy;
    objectRef.d = ad;

    return objectRef;
  }
});

/* >>>>>>>>>> BEGIN source/system/root_responder.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('system/ready');
sc_require('system/platform');
sc_require('system/touch');

/** Set to NO to leave the backspace key under the control of the browser.*/
SC.CAPTURE_BACKSPACE_KEY = NO ;

/** @class

  The RootResponder captures events coming from a web browser and routes them
  to the correct view in the view hierarchy.  Usually you do not work with a
  RootResponder directly.  Instead you will work with Pane objects, which
  register themselves with the RootResponder as needed to receive events.

  RootResponder and Platforms
  ---

  RootResponder contains core functionality common among the different web
  platforms. You will likely be working with a subclass of RootResponder that
  implements functionality unique to that platform.

  The correct instance of RootResponder is detected at runtime and loaded
  transparently.

  Event Types
  ---

  RootResponders can route four types of events:

   - Direct events, such as mouse and touch events.  These are routed to the
     nearest view managing the target DOM elment. RootResponder also handles
     multitouch events so that they are delegated to the correct views.
   - Keyboard events. These are sent to the keyPane, which will then send the
     event to the current firstResponder and up the responder chain.
   - Resize events. When the viewport resizes, these events will be sent to all
     panes.
   - Keyboard shortcuts. Shortcuts are sent to the keyPane first, which
     will go down its view hierarchy. Then they go to the mainPane, which will
     go down its view hierarchy.
   - Actions. Actions are generic messages that your application can send in
     response to user action or other events. You can either specify an
     explicit target, or allow the action to traverse the hierarchy until a
     view is found that handles it.
*/
SC.RootResponder = SC.Object.extend(
  /** @scope SC.RootResponder.prototype */{

  /**
    Contains a list of all panes currently visible on screen.  Every time a
    pane attaches or detaches, it will update itself in this array.
  */
  panes: null,

  init: function() {
    arguments.callee.base.apply(this,arguments);
    this.panes = SC.Set.create();
  },

  // .......................................................
  // MAIN PANE
  //

  /**
    The main pane.  This pane receives shortcuts and actions if the
    focusedPane does not respond to them.  There can be only one main pane.
    You can swap main panes by calling makeMainPane() here.

    Usually you will not need to edit the main pane directly.  Instead, you
    should use a MainPane subclass, which will automatically make itself main
    when you append it to the document.

    @type SC.MainPane
  */
  mainPane: null,

  /**
    Swaps the main pane.  If the current main pane is also the key pane, then
    the new main pane will also be made key view automatically.  In addition
    to simply updating the mainPane property, this method will also notify the
    panes themselves that they will lose/gain their mainView status.

    Note that this method does not actually change the Pane's place in the
    document body.  That will be handled by the Pane itself.

    @param {SC.Pane} pane
    @returns {SC.RootResponder}
  */
  makeMainPane: function(pane) {
    var currentMain = this.get('mainPane') ;
    if (currentMain === pane) return this ; // nothing to do

    this.beginPropertyChanges() ;

    // change key focus if needed.
    if (this.get('keyPane') === currentMain) this.makeKeyPane(pane) ;

    // change setting
    this.set('mainPane', pane) ;

    // notify panes.  This will allow them to remove themselves.
    if (currentMain) currentMain.blurMainTo(pane) ;
    if (pane) pane.focusMainFrom(currentMain) ;

    this.endPropertyChanges() ;
    return this ;
  },

  // ..........................................................
  // MENU PANE
  //

  /**
    The current menu pane. This pane receives keyboard events before all other
    panes, but tends to be transient, as it is only set when a pane is open.

    @type SC.MenuPane
  */
  menuPane: null,

  /**
    Sets a pane as the menu pane. All key events will be directed to this
    pane, but the current key pane will not lose focus.

    Usually you would not call this method directly, but allow instances of
    SC.MenuPane to manage the menu pane for you. If your pane does need to
    become menu pane, you should relinquish control by calling this method
    with a null parameter. Otherwise, key events will always be delivered to
    that pane.

    @param {SC.MenuPane} pane
    @returns {SC.RootResponder} receiver
  */
  makeMenuPane: function(pane) {
    // Does the specified pane accept being the menu pane?  If not, there's
    // nothing to do.
    if (pane  &&  !pane.get('acceptsMenuPane')) {
      return this;
    } else {
      var currentMenu = this.get('menuPane');
      if (currentMenu === pane) return this; // nothing to do

      this.set('menuPane', pane);
    }

    return this;
  },

  // .......................................................
  // KEY PANE
  //

  /**
    The current key pane. This pane receives keyboard events, shortcuts, and
    actions first, unless a menu is open. This pane is usually the highest
    ordered pane or the mainPane.

    @type SC.Pane
  */
  keyPane: null,

  /** @private
    A stack of previous key panes. Used to allow panes to resign key pane
    status without having to know who had it before them.

    NOTE: This property is not observable.
  */
  previousKeyPanes: [],

  /**
    Makes the passed pane the new key pane.  If you pass null or if the pane
    does not accept key focus, then key focus will transfer to the previous
    key pane (if it is still attached), and so on down the stack.  This will
    notify both the old pane and the new root View that key focus has changed.

    @param {SC.Pane} pane
    @returns {SC.RootResponder} receiver
  */
  makeKeyPane: function(pane) {
    // Quick note about previousKeyPanes: if a pane is destroyed while in the
    // previous panes stack, it will retain a reference to it here, causing a
    // brief leak. The reference will be removed as soon as the panes above it
    // in the stack resign, so it's rarely an issue, and fixing it would require
    // a dedicated method and some extra coordination that's probably not worth
    // it.

    // Was a pane specified?
    var newKeyPane, previousKeyPane, previousKeyPanes ;

    if (pane) {
      // Does the specified pane accept being the key pane?  If not, there's
      // nothing to do.
      if (!pane.get('acceptsKeyPane')) {
        return this ;
      }
      else {
        // It does accept key pane status?  Then push the current keyPane to
        // the top of the stack and make the specified pane the new keyPane.
        // First, though, do a sanity-check to make sure it's not already the
        // key pane, in which case we have nothing to do.
        previousKeyPane = this.get('keyPane') ;
        if (previousKeyPane === pane) {
          return this ;
        }
        else {
          if (previousKeyPane) {
            previousKeyPanes = this.get('previousKeyPanes') ;
            previousKeyPanes.push(previousKeyPane) ;
          }

          newKeyPane = pane ;
        }
      }
    } else {
      // No pane was specified?  Then pop the previous key pane off the top of
      // the stack and make it the new key pane, assuming that it's still
      // attached and accepts key pane (its value for acceptsKeyPane might
      // have changed in the meantime).  Otherwise, we'll keep going up the
      // stack.
      previousKeyPane = this.get('keyPane') ;
      previousKeyPanes = this.get('previousKeyPanes') ;

      newKeyPane = null ;
      var candidate;
      while (previousKeyPanes.length > 0) {
        candidate = previousKeyPanes.pop();
        if (candidate.get('isVisibleInWindow') && candidate.get('acceptsKeyPane')) {
          newKeyPane = candidate ;
          break ;
        }
      }
    }


    // If we found an appropriate candidate, make it the new key pane.
    // Otherwise, make the main pane the key pane (if it accepts it).
    if (!newKeyPane) {
      var mainPane = this.get('mainPane') ;
      if (mainPane && mainPane.get('acceptsKeyPane')) newKeyPane = mainPane ;
    }

    // now notify old and new key views of change after edit
    if (previousKeyPane) previousKeyPane.willLoseKeyPaneTo(newKeyPane) ;
    if (newKeyPane) newKeyPane.willBecomeKeyPaneFrom(previousKeyPane) ;

    this.set('keyPane', newKeyPane) ;

    if (newKeyPane) newKeyPane.didBecomeKeyPaneFrom(previousKeyPane) ;
    if (previousKeyPane) previousKeyPane.didLoseKeyPaneTo(newKeyPane) ;

    return this ;
  },

  // ..........................................................
  // VIEWPORT STATE
  //

  /**
    The last known window size.
    @type Rect
    @isReadOnly
  */
  currentWindowSize: null,

  /**
    Computes the window size from the DOM.

    @returns Rect
  */
  computeWindowSize: function() {
    var size, bod, docElement;
    if(!this._bod || !this._docElement){
      bod = document.body;
      docElement = document.documentElement;
      this._bod=bod;
      this._docElement=docElement;
    }else{
      bod = this._bod;
      docElement = this._docElement;
    }

    if (window.innerHeight) {
      size = {
        width: window.innerWidth,
        height: window.innerHeight
      } ;
    } else if (docElement && docElement.clientHeight) {
      size = {
        width: docElement.clientWidth,
        height: docElement.clientHeight
      };
    } else if (bod) {
      size = {
        width: bod.clientWidth,
        height: bod.clientHeight
      } ;
    }
    return size;
  },

  /**
    On window resize, notifies panes of the change.

    @returns {Boolean}
  */
  resize: function() {
    this._resize();
    this._assignDesignMode();

    return YES; //always allow normal processing to continue.
  },

  /** @private */
  _resize: function() {
    // calculate new window size...
    var newSize = this.computeWindowSize(), oldSize = this.get('currentWindowSize');
    this.set('currentWindowSize', newSize); // update size

    if (!SC.rectsEqual(newSize, oldSize)) {
      SC.run(function() {
        //Notify orientation change. This is faster than waiting for the orientation
        //change event.
        SC.device.windowSizeDidChange(newSize);

        // notify panes
        if (this.panes) {
            if (oldSize !== newSize) {
              this.panes.invoke('windowSizeDidChange', oldSize, newSize);
            }
        }
      }, this);
    }
  },

  /** @private */
  _assignDesignMode: function () {
    var newDesignMode = this.computeDesignMode(),
      oldDesignMode = this.get('currentDesignMode');

    if (oldDesignMode !== newDesignMode) {
      this.set('currentDesignMode', newDesignMode);

      if (this.panes) {
        SC.run(function() {
          this.panes.invoke('updateDesignMode', oldDesignMode, newDesignMode);
        }, this);
      }
    }
  },

  /**
    Indicates whether or not the window currently has focus.  If you need
    to do something based on whether or not the window is in focus, you can
    setup a binding or observer to this property.  Note that the SproutCore
    automatically adds an sc-focus or sc-blur CSS class to the body tag as
    appropriate.  If you only care about changing the appearance of your
    controls, you should use those classes in your CSS rules instead.
  */
  hasFocus: NO,

  /**
    Handle window focus.  Change hasFocus and add sc-focus CSS class
    (removing sc-blur).  Also notify panes.
  */
  focus: function(evt) {
    if (!this.get('hasFocus')) {
      SC.$('body').addClass('sc-focus').removeClass('sc-blur');

      SC.run(function () {
      // If the app is getting focus again set the first responder to the first
      // valid firstResponder view in the view's tree
      if(!SC.TABBING_ONLY_INSIDE_DOCUMENT && !SC.browser.isIE8OrLower){
        var keyPane = SC.RootResponder.responder.get('keyPane');
        if (keyPane) {
          var nextValidKeyView = keyPane.get('nextValidKeyView');
          if (nextValidKeyView) keyPane.makeFirstResponder(nextValidKeyView);
        }
      }

        this.set('hasFocus', YES);
      }, this);
    }

    return YES ; // allow default
  },

  /**
    Handle window focus event for IE. Listening to the focus event is not
    reliable as per every focus event you receive you immediately get a blur
    event (Only on IE of course ;)
  */
  focusin: function(evt) {
    if(this._focusTimeout) clearTimeout(this._focusTimeout);
    this.focus(evt);
  },

  /**
    Handle window blur event for IE. Listening to the focus event is not
    reliable as per every focus event you receive you immediately get a blur
    event (Only on IE of course ;)
  */
  focusout: function(evt) {
    var that = this;
    this._focusTimeout = setTimeout(function(){that.blur(evt);}, 300);
  },


  /**
    Handle window focus.  Change hasFocus and add sc-focus CSS class (removing
    sc-blur).  Also notify panes.
  */
  blur: function(evt) {
    if (this.get('hasFocus')) {
      SC.$('body').addClass('sc-blur').removeClass('sc-focus');

      SC.run(function() {
        this.set('hasFocus', NO);
      }, this);
    }
    return YES ; // allow default
  },

  dragDidStart: function(drag) {
    this._mouseDownView = drag ;
    this._drag = drag ;
  },

  // ------------------------------------------------------------------------
  // Design Modes
  //

  /** @private */
  currentDesignMode: null,

  /** @private Managed by SC.Application. */
  designModes: function (key, value) {
    if (SC.none(value)) {
      // Clear previous values.
      if (this._designModeNames) {
        delete this._designModeNames;
        delete this._designModeThresholds;
      }

      value = null;
    } else {
      this._prepOrderedArrays(value);
    }

    this._assignDesignMode();

    return value;
  }.property().cacheable(),

  /** @private Determine the design mode based on area and pixel density. */
  computeDesignMode: function () {
    var designMode = null,
      designModeNames = this._designModeNames,
      designModeThresholds = this._designModeThresholds,
      currentWindowSize,
      area;

    // Fast path!
    if (!designModeNames) { return null; }

    currentWindowSize = this.get('currentWindowSize');
    area = (currentWindowSize.width * currentWindowSize.height);
    var i, len;
    for (i = 0, len = designModeThresholds.get('length'); i < len; i++) {
      var layoutWidthThreshold = designModeThresholds.objectAt(i);
      if (area < layoutWidthThreshold) {
        designMode = designModeNames.objectAt(i);
        break;
      }
    }

    // If no smaller designMode was found, use the biggest designMode.
    if (SC.none(designMode) && designModeNames && designModeNames.get('length') > 0) {
      designMode = designModeNames.objectAt(i);
    }

    return SC.device.orientation === SC.PORTRAIT_ORIENTATION ? designMode + '_p' : designMode + '_l';
  },

  /** @private (semi-private)
    Returns the fallback design mode for the given design mode.  This is
    primarily used by SC.View for the case where an adjustment isn't found
    for the current design mode and we want to apply the next best design
    mode as a fallback.
  */
  fallbackDesignMode: function (designMode) {
    var designModeNames = this._designModeNames,
      index,
      ret = null;

    index = designModeNames.indexOf(designMode);
    if (index >= 0) {
      ret = designModeNames[index - 1];
    }

    return ret;
  },

  /** @private Prepares ordered design modes & widths arrays when designModes changes. */
  _prepOrderedArrays: function (designModes) {
    var designModeNames,
      designModeThresholds;

    // Order the design modes for easier access later.
    if (designModes) {
      designModeNames = this._designModeNames = [];
      designModeThresholds = this._designModeThresholds = [];

      var key;

      outer:
        for (key in designModes) {
          var i, value;

          // Assume that the keys will be ordered smallest to largest so run backwards.
          value = designModes[key];
          inner:
            for (i = designModeThresholds.length - 1; i >= 0; i--) {
              if (designModeThresholds[i] < value) {
                // Exit early!
                break inner;
              }
            }

          i += 1;
          designModeNames.splice(i, 0, key);
          designModeThresholds.splice(i, 0, value);
        }
    }
  },

  // .......................................................
  // ACTIONS
  //

  /**
    Set this to a delegate object that can respond to actions as they are sent
    down the responder chain.

    @type SC.Object
  */
  defaultResponder: null,

  /**
    Route an action message to the appropriate responder.  This method will
    walk the responder chain, attempting to find a responder that implements
    the action name you pass to this method.  Set 'target' to null to search
    the responder chain.

    **IMPORTANT**: This method's API and implementation will likely change
    significantly after SproutCore 1.0 to match the version found in
    SC.ResponderContext.

    You generally should not call or override this method in your own
    applications.

    @param {String} action The action to perform - this is a method name.
    @param {SC.Responder} target object to set method to (can be null)
    @param {Object} sender The sender of the action
    @param {SC.Pane} pane optional pane to start search with
    @param {Object} context optional. only passed to ResponderContexts
    @returns {Boolean} YES if action was performed, NO otherwise
    @test in targetForAction
  */
  sendAction: function( action, target, sender, pane, context, firstResponder) {
    target = this.targetForAction(action, target, sender, pane, firstResponder) ;

    if (target) {
      // HACK: If the target is a ResponderContext, forward the action.
      if (target.isResponderContext) {
        return !!target.sendAction(action, sender, context, firstResponder);
      } else {
        return target.tryToPerform(action, sender, context);
      }
    }
  },

  _responderFor: function(target, methodName, firstResponder) {
    var defaultResponder = target ? target.get('defaultResponder') : null;

    if (target) {
      target = firstResponder || target.get('firstResponder') || target;
      do {
        if (target.respondsTo(methodName)) return target ;
      } while ((target = target.get('nextResponder'))) ;
    }

    // HACK: Eventually we need to normalize the sendAction() method between
    // this and the ResponderContext, but for the moment just look for a
    // ResponderContext as the defaultResponder and return it if present.
    if (typeof defaultResponder === SC.T_STRING) {
      defaultResponder = SC.objectForPropertyPath(defaultResponder);
    }

    if (!defaultResponder) return null;
    else if (defaultResponder.isResponderContext) return defaultResponder;
    else if (defaultResponder.respondsTo(methodName)) return defaultResponder;
    else return null;
  },

  /**
    Attempts to determine the initial target for a given action/target/sender
    tuple.  This is the method used by sendAction() to try to determine the
    correct target starting point for an action before trickling up the
    responder chain.

    You send actions for user interface events and for menu actions.

    This method returns an object if a starting target was found or null if no
    object could be found that responds to the target action.

    Passing an explicit target or pane constrains the target lookup to just
    them; the defaultResponder and other panes are *not* searched.

    @param {Object|String} target or null if no target is specified
    @param {String} method name for target
    @param {Object} sender optional sender
    @param {SC.Pane} optional pane
    @param {firstResponder} a first responder to use
    @returns {Object} target object or null if none found
  */
  targetForAction: function(methodName, target, sender, pane, firstResponder) {

    // 1. no action, no target...
    if (!methodName || (SC.typeOf(methodName) !== SC.T_STRING)) {
      return null ;
    }

    // 2. an explicit target was passed...
    if (target) {
      // Normalize String targets to Objects
      if (SC.typeOf(target) === SC.T_STRING) {
        target = SC.objectForPropertyPath(target) ||
                 SC.objectForPropertyPath(target, sender);
      }

      // Ensure that the target responds to the method.
      if (target && !target.isResponderContext) {
        if (target.respondsTo && !target.respondsTo(methodName)) {
          target = null ;
        } else if (SC.typeOf(target[methodName]) !== SC.T_FUNCTION) {
          target = null ;
        }
      }

      return target ;
    }

    // 3. an explicit pane was passed...
    if (pane) {
      target = this._responderFor(pane, methodName, firstResponder);
      if (target) return target;
    }

    // 4. no target or pane passed... try to find target in the active panes
    // and the defaultResponder
    var keyPane = this.get('keyPane'), mainPane = this.get('mainPane') ;

    // ...check key and main panes first
    if (keyPane && (keyPane !== pane)) {
      target = this._responderFor(keyPane, methodName) ;
    }
    if (!target && mainPane && (mainPane !== keyPane)) {
      target = this._responderFor(mainPane, methodName) ;
    }

    // ...still no target? check the defaultResponder...
    if (!target && (target = this.get('defaultResponder'))) {
      if (SC.typeOf(target) === SC.T_STRING) {
        target = SC.objectForPropertyPath(target) ;
        if (target) this.set('defaultResponder', target) ; // cache if found
      }
      if (target && !target.isResponderContext) {
        if (target.respondsTo && !target.respondsTo(methodName)) {
          target = null ;
        } else if (SC.typeOf(target[methodName]) !== SC.T_FUNCTION) {
          target = null ;
        }
      }
    }

    return target ;
  },

  /**
    Finds the view that appears to be targeted by the passed event.  This only
    works on events with a valid target property.

    @param {SC.Event} evt
    @returns {SC.View} view instance or null
  */
  targetViewForEvent: function (evt) {
    var ret = null;
    if (evt.target) { ret = SC.viewFor(evt.target); }

    return ret;
  },

  /**
    Attempts to send an event down the responder chain.  This method will
    invoke the sendEvent() method on either the keyPane or on the pane owning
    the target view you pass in.  It will also automatically begin and end
    a new run loop.

    If you want to trap additional events, you should use this method to
    send the event down the responder chain.

    @param {String} action
    @param {SC.Event} evt
    @param {Object} target
    @returns {Object} object that handled the event or null if not handled
  */
  sendEvent: function(action, evt, target) {
    var pane, ret ;

    SC.run(function send_event() {
      // get the target pane
      if (target) pane = target.get('pane') ;
      else pane = this.get('menuPane') || this.get('keyPane') || this.get('mainPane') ;

      // if we found a valid pane, send the event to it
      ret = (pane) ? pane.sendEvent(action, evt, target) : null ;
    }, this);

    return ret ;
  },

  // .......................................................
  // EVENT LISTENER SETUP
  //

  /**
    Default method to add an event listener for the named event.  If you simply
    need to add listeners for a type of event, you can use this method as
    shorthand.  Pass an array of event types to listen for and the element to
    listen in.  A listener will only be added if a handler is actually installed
    on the RootResponder (or receiver) of the same name.

    @param {Array} keyNames
    @param {Element} target
    @param {Object} receiver - optional if you don't want 'this'
    @param {Boolean} useCapture
    @returns {SC.RootResponder} receiver
  */
  listenFor: function(keyNames, target, receiver, useCapture) {
    receiver = receiver ? receiver : this;
    keyNames.forEach( function(keyName) {
      var method = receiver[keyName] ;
      if (method) SC.Event.add(target, keyName, receiver, method, null, useCapture) ;
    },this) ;

    target = null ;

    return receiver ;
  },

  /**
    Called when the document is ready to begin handling events.  Setup event
    listeners in this method that you are interested in observing for your
    particular platform.  Be sure to call arguments.callee.base.apply(this,arguments).

    @returns {void}
  */
  setup: function() {
    // handle basic events
    this.listenFor(['touchstart', 'touchmove', 'touchend', 'touchcancel', 'keydown', 'keyup', 'beforedeactivate', 'mousedown', 'mouseup', 'dragenter', 'dragover', 'dragleave', 'drop', 'click', 'dblclick', 'mousemove', 'contextmenu'], document)
        .listenFor(['resize'], window);

    if(SC.browser.isIE8OrLower) this.listenFor(['focusin', 'focusout'], document);
    else this.listenFor(['focus', 'blur'], window);

    // handle special case for keypress- you can't use normal listener to block
    // the backspace key on Mozilla
    if (this.keypress) {
      if (SC.CAPTURE_BACKSPACE_KEY && SC.browser.isMozilla) {
        var responder = this ;
        document.onkeypress = function(e) {
          e = SC.Event.normalizeEvent(e);
          return responder.keypress.call(responder, e);
        };

      // Otherwise, just add a normal event handler.
      } else {
        SC.Event.add(document, 'keypress', this, this.keypress);
      }
    }

    // Add an array of transition listeners for immediate use (these will be cleaned up when actual testing completes).
    // Because the transition test happens asynchronously and because we don't want to
    // delay the launch of the application in order to a transition test (the app won't
    // load if the browser tab is not visible), we start off by listening to everything
    // and when the test is completed, we remove the extras to avoid double callbacks.
    if (SC.platform.supportsCSSTransitions) {
      var domPrefix = SC.browser.domPrefix,
        lowerDomPrefix = domPrefix.toLowerCase(),
        variation1 = lowerDomPrefix + 'transitionend',
        variation2 = lowerDomPrefix + 'TransitionEnd',
        variation3 = domPrefix + 'TransitionEnd';

      // Ensure that the callback name used maps to our implemented function name.
      this[variation1] = this[variation2] = this[variation3] = this.transitionend;

      // ex. transitionend, webkittransitionend, webkitTransitionEnd, WebkitTransitionEnd
      this.listenFor(['transitionend', variation1, variation2, variation3], document);

      if (SC.platform.supportsCSSAnimations) {
        variation1 = lowerDomPrefix + 'animationstart';
        variation2 = lowerDomPrefix + 'AnimationStart';
        variation3 = domPrefix + 'AnimationStart';

        // Ensure that the callback name used maps to our implemented function name.
        this[variation1] = this[variation2] = this[variation3] = this.animationstart;

        // ex. animationstart, webkitanimationstart, webkitAnimationStart, WebkitAnimationStart
        this.listenFor(['animationstart', variation1, variation2, variation3], document);

        variation1 = lowerDomPrefix + 'animationiteration';
        variation2 = lowerDomPrefix + 'AnimationIteration';
        variation3 = domPrefix + 'AnimationIteration';

        // Ensure that the callback name used maps to our implemented function name.
        this[variation1] = this[variation2] = this[variation3] = this.animationiteration;

        // ex. animationiteration, webkitanimationiteration, webkitAnimationIteration, WebkitAnimationIteration
        this.listenFor(['animationiteration', variation1, variation2, variation3], document);

        variation1 = lowerDomPrefix + 'animationend';
        variation2 = lowerDomPrefix + 'AnimationEnd';
        variation3 = domPrefix + 'AnimationEnd';

        // Ensure that the callback name used maps to our implemented function name.
        this[variation1] = this[variation2] = this[variation3] = this.animationend;

        // ex. animationend, webkitanimationend, webkitAnimationEnd, WebkitAnimationEnd
        this.listenFor(['animationend', variation1, variation2, variation3], document);
      }
    }

    // handle these two events specially in IE
    ['drag', 'selectstart'].forEach(function(keyName) {
      var method = this[keyName] ;
      if (method) {
        if (SC.browser.isIE) {
          var responder = this ;

          document.body['on' + keyName] = function(e) {
            return method.call(responder, SC.Event.normalizeEvent(event || window.event)); // this is IE :(
          };

          // be sure to cleanup memory leaks
           SC.Event.add(window, 'unload', this, function() {
            document.body['on' + keyName] = null;
          });

        } else {
          SC.Event.add(document, keyName, this, method);
        }
      }
    }, this);

    var mousewheel = 'mousewheel';

    // Firefox emits different mousewheel events than other browsers
    if (SC.browser.isMozilla) {
      // For Firefox < 3.5, subscribe to DOMMouseScroll events
      if (SC.browser.compare(SC.browser.engineVersion, '1.9.1') < 0) {
        mousewheel = 'DOMMouseScroll';

      // For Firefox 3.5 and greater, we can listen for MozMousePixelScroll,
      // which supports pixel-precision scrolling devices, like MacBook
      // trackpads.
      } else {
        mousewheel = 'MozMousePixelScroll';
      }
    }
    SC.Event.add(document, mousewheel, this, this.mousewheel);

    // Do some initial set up.
    this.set('currentWindowSize', this.computeWindowSize()) ;

    // TODO: Is this workaround still valid?
    if (SC.browser.os === SC.OS.ios && SC.browser.name === SC.BROWSER.safari) {

      // If the browser is identifying itself as a touch-enabled browser, but
      // touch events are not present, assume this is a desktop browser doing
      // user agent spoofing and simulate touch events automatically.
      if (SC.platform && !SC.platform.touch) {
        SC.platform.simulateTouchEvents();
      }

      // Monkey patch RunLoop if we're in MobileSafari
      var f = SC.RunLoop.prototype.endRunLoop, patch;

      patch = function() {
        // Call original endRunLoop implementation.
        if (f) f.apply(this, arguments);

        // This is a workaround for a bug in MobileSafari.
        // Specifically, if the target of a touchstart event is removed from the DOM,
        // you will not receive future touchmove or touchend events. What we do is, at the
        // end of every runloop, check to see if the target of any touches has been removed
        // from the DOM. If so, we re-append it to the DOM and hide it. We then mark the target
        // as having been moved, and it is de-allocated in the corresponding touchend event.
        var touches = SC.RootResponder.responder._touches, touch, elem, target, found = NO;
        if (touches) {
          // Iterate through the touches we're currently tracking
          for (touch in touches) {
            if (touches[touch]._rescuedElement) continue; // only do once

            target = elem = touches[touch].target;

            // Travel up the hierarchy looking for the document body
            while (elem && (elem = elem.parentNode) && !found) {
              found = (elem === document.body);
            }

            // If we aren't part of the body, move the element back
            // but make sure we hide it from display.
            if (!found && target) {

              // Actually clone this node and replace it in the original
              // layer if needed
              if (target.parentNode && target.cloneNode) {
                var clone = target.cloneNode(true);
                target.parentNode.replaceChild(clone, target);
                target.swapNode = clone; // save for restore later
              }

              // Create a holding pen if needed for these views...
              var pen = SC.touchHoldingPen;
              if (!pen) {
                pen = SC.touchHoldingPen = document.createElement('div');
                pen.style.display = 'none';
                document.body.appendChild(pen);
              }

              // move element back into document...
              pen.appendChild(target);

              // ...and save the element to be garbage collected on touchEnd.
              touches[touch]._rescuedElement = target;
            }
          }
        }
      };
      SC.RunLoop.prototype.endRunLoop = patch;
    }
  },

  /**
    Cleans up the additional transition event listeners.

    NOTE: requires that SC.RootResponser.responder.transitionendEventName
    has been determined.

    @returns {void}
  */
  cleanUpTransitionListeners: function () {
    var actualEventName = SC.platform.transitionendEventName,
      domPrefix = SC.browser.domPrefix,
      lowerDomPrefix = domPrefix.toLowerCase(),
      variation1 = lowerDomPrefix + 'transitionend',
      variation2 = lowerDomPrefix + 'TransitionEnd',
      variation3 = domPrefix + 'TransitionEnd';

    // Once the actual event name is determined, simply remove all the extras.
    // This should prevent any problems with browsers that fire multiple events.
    ['transitionend', variation1, variation2, variation3].forEach(function (keyName) {
      if (keyName !== actualEventName) {
        SC.Event.remove(document, keyName, this, this[keyName]);
        this[keyName] = null;
    }
    });
  },

  /**
    Cleans up the additional animation event listeners.

    NOTE: requires that SC.RootResponser.responder.animationstartEventName,
    SC.RootResponser.responder.animationendEventName and
    SC.RootResponser.responder.animationiterationEventName have been
    determined.

    @returns {void}
  */
  cleanUpAnimationListeners: function () {
    var domPrefix = SC.browser.domPrefix,
      lowerDomPrefix = domPrefix.toLowerCase(),
      actualEventName = SC.platform.animationendEventName,
      variation1 = lowerDomPrefix + 'animationend',
      variation2 = lowerDomPrefix + 'AnimationEnd',
      variation3 = domPrefix + 'AnimationEnd';

    // Once the actual event name is determined, simply remove all the extras.
    // This should prevent any problems with browsers that fire multiple events.
    ['animationend', variation1, variation2, variation3].forEach(function (keyName) {
      if (keyName !== actualEventName) {
        SC.Event.remove(document, keyName, this, this[keyName]);
        this[keyName] = null;
    }
    });

    actualEventName = SC.platform.animationiterationEventName;
    variation1 = lowerDomPrefix + 'animationiteration';
    variation2 = lowerDomPrefix + 'AnimationIteration';
    variation3 = domPrefix + 'AnimationIteration';
    ['animationiteration', variation1, variation2, variation3].forEach(function (keyName) {
      if (keyName !== actualEventName) {
        SC.Event.remove(document, keyName, this, this[keyName]);
        this[keyName] = null;
      }
    });

    actualEventName = SC.platform.animationstartEventName;
    variation1 = lowerDomPrefix + 'animationstart';
    variation2 = lowerDomPrefix + 'AnimationStart';
    variation3 = domPrefix + 'AnimationStart';
    ['animationstart', variation1, variation2, variation3].forEach(function (keyName) {
      if (keyName !== actualEventName) {
        SC.Event.remove(document, keyName, this, this[keyName]);
        this[keyName] = null;
      }
    });
  },

  // ...........................................................................
  // TOUCH SUPPORT
  //

  /**
    @private
    A map from views to internal touch entries.

    Note: the touch entries themselves also reference the views.
  */
  _touchedViews: {},

  /**
    @private
    A map from internal touch ids to the touch entries themselves.

    The touch entry ids currently come from the touch event's identifier.
  */
  _touches: {},

  /**
    Returns the touches that are registered to the specified view or responder; undefined if none.

    When views receive a touch event, they have the option to subscribe to it.
    They are then mapped to touch events and vice-versa. This returns touches mapped to the view.

    This method is also available on SC.Touch objects, and you will usually call it from there.
  */
  touchesForView: function(view) {
    if (this._touchedViews[SC.guidFor(view)]) {
      return this._touchedViews[SC.guidFor(view)].touches;
    }
  },

  /**
    Computes a hash with x, y, and d (distance) properties, containing the average position
    of all touches, and the average distance of all touches from that average. This is useful
    for implementing scaling.

    This method is also available on SC.Touch objects, and you will usually call it from there.

    @param {SC.View} view The view whose touches should be averaged.
    @param {SC.Touch} additionalTouch This method uses touchesForView; if you call it from
        touchStart, that touch will not yet be included in touchesForView. To accommodate this,
        you should pass the view to this method (or pass YES to SC.Touch#averagedTouchesForView's
        `addSelf` argument).
  */
  averagedTouchesForView: function(view, additionalTouch) {
    var t = this.touchesForView(view),
      len, averaged, additionalTouchIsDuplicate;

    // Each view gets its own cached average touches object for performance.
    averaged = view._scrr_averagedTouches || (view._scrr_averagedTouches = {});

    // FAST PATH: no touches to track.
    if ((!t || t.length === 0) && !additionalTouch) {
      averaged.x = 0;
      averaged.y = 0;
      averaged.d = 0;
      averaged.velocityX = 0;
      averaged.velocityY = 0;

    // Otherwise, average the touches.
    } else {
      // Cache the array object used by this method. (Cleared at the end to prevent memory leaks.)
      var touches = this._averagedTouches_touches || (this._averagedTouches_touches = []);

      // copy touches into array
      if (t) {
        var i;
        len = t.length;
        for(i = 0; i < len; i++) {
          touches.push(t[i]);
          if (additionalTouch && t[i] === additionalTouch) additionalTouchIsDuplicate = YES;
        }
      }

      // Add additionalTouch if present and not duplicated.
      if (additionalTouch && !additionalTouchIsDuplicate) touches.push(additionalTouch);

      // Calculate the average.
      SC.Touch.averagedTouch(touches, averaged);

      // Clear the touches array to prevent touch object leaks.
      touches.length = 0;
    }

    return averaged;
  },

  assignTouch: function(touch, view) {
    // sanity-check
    if (touch.hasEnded) throw new Error("Attempt to assign a touch that is already finished.");

    // Fast path, the touch is already assigned to the view.
    if (touch.view === view) return;

    // unassign from old view if necessary
    if (touch.view) {
      this.unassignTouch(touch);
    }

    // create view entry if needed
    if (!this._touchedViews[SC.guidFor(view)]) {
      this._touchedViews[SC.guidFor(view)] = {
        view: view,
        touches: SC.CoreSet.create([]),
        touchCount: 0
      };
      view.set("hasTouch", YES);
    }

    // add touch
    touch.view = view;
    this._touchedViews[SC.guidFor(view)].touches.add(touch);
    this._touchedViews[SC.guidFor(view)].touchCount++;
  },

  unassignTouch: function(touch) {
    // find view entry
    var view, viewEntry;

    // Fast path, the touch is not assigned to a view.
    if (!touch.view) return; // touch.view should===touch.touchResponder eventually :)

    // get view
    view = touch.view;

    // get view entry
    viewEntry = this._touchedViews[SC.guidFor(view)];
    viewEntry.touches.remove(touch);
    viewEntry.touchCount--;

    // remove view entry if needed
    if (viewEntry.touchCount < 1) {
      view.set("hasTouch", NO);
      viewEntry.view = null;
      delete this._touchedViews[SC.guidFor(view)];
    }

    // clear view
    touch.view = undefined;
  },

  _flushQueuedTouchResponder: function(){
    if (this._queuedTouchResponder) {
      var queued = this._queuedTouchResponder;
      this._queuedTouchResponder = null;
      this.makeTouchResponder.apply(this, queued);
    }
  },

  /**
    This method attempts to change the responder for a particular touch. The touch's responder is the
    view which will receive touch events for that touch.

    You will usually not call this method directly, instead calling one of the convenience methods on
    the touch itself. See documentation for SC.Touch for more.

    Possible gotchas:

    - Because this method must search for a view which implements touchStart (without returning NO),
      touchStart is called on the new responder before touchCancelled is called on the old one.
    - While a touch exposes its current responder at `touchResponder` and any previous stacked one at
      `nextTouchResponder`, their relationship is ad hoc and arbitrary, and so are not chained by
      `nextResponder` like in a standard responder chain. To query the touch's current responder stack
      (or, though it's not recommended, change it), check touch.touchResponders.

    @param {SC.Touch} touch
    @param {SC.Responder} responder The view to assign to the touch. (It, or if bubbling then an ancestor,
      must implement touchStart.)
    @param {Boolean} shouldStack Whether the new responder should replace the old one, or stack with it.
      Stacked responders are easy to revert via `SC.Touch#restoreLastTouchResponder`.
    @param {Boolean|SC.Responder} bubblesTo If YES, will attempt to find a `touchStart` responder up the
      responder chain. If NO or undefined, will only check the passed responder. If you pass a responder
      for this argument, the attempt will bubble until it reaches the passed responder, allowing you to
      restrict the bubbling to a portion of the responder chain. ((Note that this responder will not be
      given an opportunity to respond to the event.)
    @returns {Boolean} Whether a valid touch responder was found and assigned.
  */
  makeTouchResponder: function(touch, responder, shouldStack, bubblesTo) {
    // In certain cases (SC.Gesture being one), we have to call makeTouchResponder
    // from inside makeTouchResponder so we queue it up here.
    if (this._isMakingTouchResponder) {
      this._queuedTouchResponder = [touch, responder, shouldStack, bubblesTo];
      return YES; // um?
    }
    this._isMakingTouchResponder = YES;

    /*
    Concord Consortium (previously KCPTech) change.
    We introduced this change to handle an occurence of null touchResponders when processing an 'endTouch.'
    It came about because in DG.HierarchicalTableView we needed to override touchStart so that we could
    return false and have the event propagate up the view hierarchy and cause selection of the case table component.
    We note that when we get here it is through a patch for iOS having to do with touchStart.
    This change itself cannot harm anything, but we are concerned that the override in DG.HierarchicalTableView
    may have mucked things up somehow, requiring this change. We don't understand how that might be, however.
     */
    var stack = touch.touchResponders || [], touchesForView;

    // find the actual responder (if any, I suppose)
    // note that the pane's sendEvent function is slightly clever:
    // if the target is already touch responder, it will just return it without calling touchStart
    // we must do the same.
    if (touch.touchResponder === responder) {
      this._isMakingTouchResponder = NO;
      this._flushQueuedTouchResponder();
      return YES; // more um
    }

    // send touchStart
    // get the target pane
    var pane;
    if (responder) pane = responder.get('pane') ;
    else pane = this.get('keyPane') || this.get('mainPane') ;

    // if the responder is not already in the stack...
    if (stack.indexOf(responder) < 0) {

      // if we need to go up the view chain, do so via SC.Pane#sendEvent.
      if (bubblesTo) {
        // if we found a valid pane, send the event to it
        try {
          responder = pane ? pane.sendEvent("touchStart", touch, responder, bubblesTo) : null ;
        } catch (e) {
          SC.Logger.error("Error in touchStart: " + e);
          responder = null;
        }
      } else {
        // If the responder doesn't currently have a touch, or it does but it accepts multitouch, test it. Otherwise it's cool.
        if (responder && ((responder.get ? responder.get("acceptsMultitouch") : responder.acceptsMultitouch) || !responder.hasTouch)) {
          // If it doesn't respond to touchStart, it's no good.
          if (!responder.respondsTo("touchStart")) {
            responder = null;
          }
          // If it returns NO from touchStart, it's no good. Otherwise it's cool.
          else if (responder.touchStart(touch) === NO) {
            responder = null;
          }
        }
      }
    }

    // if the item is in the stack, we will go to it (whether shouldStack is true or not)
    // as it is already stacked
    if (!shouldStack || (stack.indexOf(responder) > -1 && stack[stack.length - 1] !== responder)) {
      // first, we should unassign the touch. Note that we only do this IF WE ARE removing
      // the current touch responder. Otherwise we cause all sorts of headaches; why? Because,
      // if we are not (suppose, for instance, that it is stacked), then the touch does not
      // get passed back to the touch responder-- even while it continues to get events because
      // the touchResponder is still set!
      this.unassignTouch(touch);

      // pop all other items
      var idx = stack.length - 1, last = stack[idx];
      while (last && last !== responder) {
        // unassign the touch
        touchesForView = this.touchesForView(last); // won't even exist if there are no touches

        // send touchCancelled (or, don't, if the view doesn't accept multitouch and it is not the last touch)
        if ((last.get ? last.get("acceptsMultitouch") : last.acceptsMultitouch) || !touchesForView) {
          if (last.touchCancelled) last.touchCancelled(touch);
        }

        // go to next (if < 0, it will be undefined, so lovely)
        idx--;
        last = stack[idx];

        // update responders (for consistency)
        stack.pop();

        touch.touchResponder = stack[idx];
        touch.nextTouchResponder = stack[idx - 1];
      }

    }

    // now that we've popped off, we can push on
    if (responder) {
      this.assignTouch(touch, responder);

      // keep in mind, it could be one we popped off _to_ above...
      if (responder !== touch.touchResponder) {
        stack.push(responder);

        // update responder helpers
        touch.touchResponder = responder;
        touch.nextTouchResponder = stack[stack.length - 2];
      }
    }

    // Unflag that this method is running, and flush the queue if any.
    this._isMakingTouchResponder = NO;
    this._flushQueuedTouchResponder(); // this may need to be &&'ed with the responder to give the correct return value...

    return !!responder;
  },

  /**
    Before the touchStart event is sent up the usual responder chain, the views along that same responder chain
    are given the opportunity to capture the touch event, preventing child views (including the target) from
    hearing about it. This of course proceeds in the opposite direction from a usual event bubbling, starting at
    the target's first ancestor and proceeding towards the target. This method implements the capture phase.

    If no view captures the touch, this method will return NO, and makeTouchResponder is then called for the
    target, proceeding with standard target-to-pane event bubbling for `touchStart`.

    For an example of captureTouch in action, see SC.ScrollView's touch handling, which by default captures the
    touch and holds it for 150ms to allow it to determine whether the user is tapping or scrolling.

    You will usually not call this method yourself, and if you do, you should call the corresponding convenience
    method on the touch itself.

    @param {SC.Touch} touch The touch to offer up for capture.
    @param {?SC.Responder} startingPoint The view whose children should be given an opportunity to capture
      the event. (The starting point itself is not asked.)
    @param {Boolean} shouldStack Whether any capturing responder should stack with existing responders.
      Stacked responders are easy to revert via `SC.Touch#restoreLastTouchResponder`.

    @returns {Boolean} Whether or not the touch was captured. If it was not, you should pass it to
      `makeTouchResponder` for standard event bubbling.
  */
  captureTouch: function(touch, startingPoint, shouldStack) {
    if (!startingPoint) startingPoint = this;

    var target = touch.targetView, view = target,
        chain = [], idx, len;

    

    // Generate the captureTouch responder chain by working backwards from the target
    // to the starting point. (Don't include the starting point.)
    while (view && (view !== startingPoint)) {
      chain.unshift(view);
      view = view.get('nextResponder');
    }

    // work down the chain
    for (len = chain.length, idx = 0; idx < len; idx++) {
      view = chain[idx];
      


      // see if it captured the touch
      if (view.tryToPerform('captureTouch', touch)) {
        


        // if so, make it the touch's responder
        this.makeTouchResponder(touch, view, shouldStack, startingPoint); // (touch, target, should stack, bubbles back to startingPoint, or all the way up.)
        return YES; // and that's all we need
      }
    }

    


    return NO;
  },

  


  _touchCount: 0,

  /** @private
    Ends a specific touch (for a bit, at least). This does not "finish" a touch; it merely calls
    touchEnd, touchCancelled, etc. A re-dispatch (through recapture or makeTouchResponder) will terminate
    the process; it would have to be restarted separately, through touch.end().
  */
  endTouch: function(touchEntry, action, evt) {
    if (!action) { action = "touchEnd"; }

    var responderIdx, responders, responder, originalResponder;

    // unassign
    this.unassignTouch(touchEntry);

    // call end for all items in chain
    if (touchEntry.touchResponder) {
      originalResponder = touchEntry.touchResponder;

      responders = touchEntry.touchResponders;
      responderIdx = responders.length - 1;
      responder = responders[responderIdx];
      while (responder) {
        if (responder[action]) { responder[action](touchEntry, evt); }

        // check to see if the responder changed, and stop immediately if so.
        if (touchEntry.touchResponder !== originalResponder) { break; }

        // next
        responderIdx--;
        responder = responders[responderIdx];
        action = "touchCancelled"; // any further ones receive cancelled
      }
    }
  },

  /**
    @private
    "Finishes" a touch. That is, it eradicates it from our touch entries and removes all responder, etc. properties.
  */
  finishTouch: function(touch) {
    // ensure the touch is indeed unassigned.
    this.unassignTouch(touch);

    // If we rescued this touch's initial element, we should remove it
    // from the DOM and garbage collect now. See setup() for an
    // explanation of this bug/workaround.
    var elem = touch._rescuedElement;
    if (elem) {
      if (elem.swapNode && elem.swapNode.parentNode) {
        elem.swapNode.parentNode.replaceChild(elem, elem.swapNode);
      } else if (elem.parentNode === SC.touchHoldingPen) {
        SC.touchHoldingPen.removeChild(elem);
      }
      delete touch._rescuedElement;
      elem.swapNode = null;
      elem = null;
    }

    // clear responders (just to be thorough)
    touch.touchResponders = null;
    touch.touchResponder = null;
    touch.nextTouchResponder = null;
    touch.hasEnded = YES;

    // and remove from our set
    if (this._touches[touch.identifier]) delete this._touches[touch.identifier];
  },

  /** @private
    Called when the user touches their finger to the screen. This method
    dispatches the touchstart event to the appropriate view.

    We may receive a touchstart event for each touch, or we may receive a
    single touchstart event with multiple touches, so we may have to dispatch
    events to multiple views.

    @param {Event} evt the event
    @returns {Boolean}
  */
  touchstart: function(evt) {
    // Starting iOS5 touch events are handled by textfields.
    // As a workaround just let the browser to use the default behavior.
    if(this.ignoreTouchHandle(evt)) return YES;

    var hidingTouchIntercept = NO;

    SC.run(function() {
      


      // loop through changed touches, calling touchStart, etc.
      var changedTouches = evt.changedTouches,
          len = changedTouches.length,
          idx,
          touch, touchEntry;

      // prepare event for touch mapping.
      evt.touchContext = this;

      // Loop through each touch we received in this event
      for (idx = 0; idx < len; idx++) {
        touch = changedTouches[idx];

        // Create an SC.Touch instance for every touch.
        touchEntry = SC.Touch.create(touch, this);

        // skip the touch if there was no target
        if (!touchEntry.targetView) continue;

        // account for hidden touch intercept (passing through touches, etc.)
        if (touchEntry.hidesTouchIntercept) hidingTouchIntercept = YES;

        // set timestamp
        touchEntry.timeStamp = evt.timeStamp;

        // Store the SC.Touch object. We use the identifier property (provided
        // by the browser) to disambiguate between touches. These will be used
        // later to determine if the touches have changed.
        this._touches[touch.identifier] = touchEntry;

        // set the event (so default action, etc. can be stopped)
        touchEntry.event = evt; // will be unset momentarily

        // First we allow any view in the responder chain to capture the touch, before triggering the standard touchStart
        // handler chain.
        var captured = this.captureTouch(touchEntry, this);
        if (!captured) this.makeTouchResponder(touchEntry, touchEntry.targetView, NO, YES); // (touch, target, shouldn't stack, bubbles all the way)

        // Unset the reference to the original event so we can garbage collect.
        touchEntry.event = null;
      }

      evt.touchContext = null;
    }, this);

    // hack for text fields
    if (hidingTouchIntercept) {
      return YES;
    }

    return evt.hasCustomEventHandling;
  },

  /**
    @private
    used to keep track of when a specific type of touch event was last handled, to see if it needs to be re-handled
  */
  touchmove: function(evt) {
    // Starting iOS5 touch events are handled by textfields.
    // As a workaround just let the browser to use the default behavior.
    if(this.ignoreTouchHandle(evt)) return YES;

    SC.run(function() {
      // pretty much all we gotta do is update touches, and figure out which views need updating.
      var touches = evt.changedTouches, touch, touchEntry,
          idx, len = touches.length, view, changedTouches, viewTouches, firstTouch,
          changedViews = {}, guid, hidingTouchIntercept = NO;

      if (this._drag) {
        touch = SC.Touch.create(evt.changedTouches[0], this);
        this._drag.tryToPerform('mouseDragged', touch);
      }

      // figure out what views had touches changed, and update our internal touch objects
      for (idx = 0; idx < len; idx++) {
        touch = touches[idx];

        // get our touch
        touchEntry = this._touches[touch.identifier];

        // we may have no touch entry; this can happen if somehow the touch came to a non-SC area.
        if (!touchEntry) {
          continue;
        }

        if (touchEntry.hidesTouchIntercept) hidingTouchIntercept = YES;

        // update touch velocity (moving average)
        var duration = evt.timeStamp - touchEntry.timeStamp,
          velocityLambda, latestXVelocity, latestYVelocity;
        // Given uneven timing between events, we should give less weight to shorter (less accurate)
        // events, with no consideration at all given zero-time events.
        if (duration !== 0) {
          // Lambda (how heavily we're weighting the latest number)
          velocityLambda = Math.min(1, duration / 80);
          // X
          latestXVelocity = (touch.pageX - touchEntry.pageX) / duration;
          touchEntry.velocityX = (1.0 - velocityLambda) * touchEntry.velocityX + velocityLambda * (latestXVelocity);
          // Y
          latestYVelocity = (touch.pageY - touchEntry.pageY) / duration;
          touchEntry.velocityY = (1.0 - velocityLambda) * touchEntry.velocityY + velocityLambda * (latestYVelocity);
        }

        // update touch position et al.
        touchEntry.pageX = touch.pageX;
        touchEntry.pageY = touch.pageY;
        touchEntry.clientX = touch.clientX;
        touchEntry.clientY = touch.clientY;
        touchEntry.screenX = touch.screenX;
        touchEntry.screenY = touch.screenY;
        touchEntry.timeStamp = evt.timeStamp;
        touchEntry.type = evt.type;
        touchEntry.event = evt;

        // if the touch entry has a view
        if (touchEntry.touchResponder) {
          view = touchEntry.touchResponder;

          guid = SC.guidFor(view);
          // create a view entry
          if (!changedViews[guid]) changedViews[guid] = { "view": view, "touches": [] };

          // add touch
          changedViews[guid].touches.push(touchEntry);
        }
      }

      // HACK: DISABLE OTHER TOUCH DRAGS WHILE MESSING WITH TEXT FIELDS
      if (hidingTouchIntercept) {
        evt.allowDefault();
        return YES;
      }

      // loop through changed views and send events
      for (idx in changedViews) {
        // get info
        view = changedViews[idx].view;
        changedTouches = changedViews[idx].touches;

        // prepare event; note that views often won't use this method anyway (they'll call touchesForView instead)
        evt.viewChangedTouches = changedTouches;

        // the first VIEW touch should be the touch info sent
        viewTouches = this.touchesForView(view);
        firstTouch = viewTouches.firstObject();

        // Load the event up with data from the first touch. THIS IS FOR CONVENIENCE ONLY in cases where the developer
        // only cares about one touch.
        evt.pageX = firstTouch.pageX;
        evt.pageY = firstTouch.pageY;
        evt.clientX = firstTouch.clientX;
        evt.clientY = firstTouch.clientY;
        evt.screenX = firstTouch.screenX;
        evt.screenY = firstTouch.screenY;
        evt.startX = firstTouch.startX;
        evt.startY = firstTouch.startY;
        evt.velocityX = firstTouch.velocityX;
        evt.velocityY = firstTouch.velocityY;
        evt.touchContext = this; // Injects the root responder so it can call e.g. `touchesForView`.

        // Give the view a chance to handle touchesDragged. (Don't bubble; viewTouches is view-specific.)
        view.tryToPerform("touchesDragged", evt, viewTouches);
      }

      // clear references to event
      touches = evt.changedTouches;
      len = touches.length;
      for (idx = 0; idx < len; idx++) {
        touch = touches[idx];
        touchEntry = this._touches[touch.identifier];
        if (touchEntry) touchEntry.event = null;
      }
      evt.touchContext = null;
      evt.viewChangedTouches = null;
    }, this);

    return evt.hasCustomEventHandling;
  },

  touchend: function(evt) {
    var hidesTouchIntercept = NO;

    // Starting iOS5 touch events are handled by textfields.
    // As a workaround just let the browser to use the default behavior.
    if(this.ignoreTouchHandle(evt)) return YES;

    SC.run(function() {
      var touches = evt.changedTouches, touch, touchEntry,
          idx, len = touches.length,
          action = evt.isCancel ? "touchCancelled" : "touchEnd";

      for (idx = 0; idx < len; idx++) {
        //get touch+entry
        touch = touches[idx];
        touch.type = 'touchend';
        touchEntry = this._touches[touch.identifier];

        // check if there is an entry
        if (!touchEntry) continue;

        // update touch velocity (moving average)
        var duration = evt.timeStamp - touchEntry.timeStamp,
          velocityLambda, latestXVelocity, latestYVelocity;
        // Given uneven timing between events, we should give less weight to shorter (less accurate)
        // events, with no consideration at all given zero-time events.
        if (duration !== 0) {
          // Lambda (how heavily we're weighting the latest number)
          velocityLambda = Math.min(1, duration / 80);
          // X
          latestXVelocity = (touch.pageX - touchEntry.pageX) / duration;
          touchEntry.velocityX = (1.0 - velocityLambda) * touchEntry.velocityX + velocityLambda * (latestXVelocity);
          // Y
          latestYVelocity = (touch.pageY - touchEntry.pageY) / duration;
          touchEntry.velocityY = (1.0 - velocityLambda) * touchEntry.velocityY + velocityLambda * (latestYVelocity);
        }

        // update touch position et al.
        touchEntry.timeStamp = evt.timeStamp;
        touchEntry.pageX = touch.pageX;
        touchEntry.pageY = touch.pageY;
        touchEntry.clientX = touch.clientX;
        touchEntry.clientY = touch.clientY;
        touchEntry.screenX = touch.screenX;
        touchEntry.screenY = touch.screenY;
        touchEntry.type = 'touchend';
        touchEntry.event = evt;

        

        if (touchEntry.hidesTouchIntercept) {
          touchEntry.unhideTouchIntercept();
          hidesTouchIntercept = YES;
        }

        if (this._drag) {
          this._drag.tryToPerform('mouseUp', touch) ;
          this._drag = null ;
          // [CC] _mouseDownView must also be cleared to properly end a drag
          this._mouseDownView = null;
          // [/CC]
        }

        // unassign
        this.endTouch(touchEntry, action, evt);
        this.finishTouch(touchEntry);
      }
    }, this);


    // for text fields
    if (hidesTouchIntercept) {
      return YES;
    }

    return evt.hasCustomEventHandling;
  },

  /** @private
    Handle touch cancel event.  Works just like cancelling a touch for any other reason.
    touchend handles it as a special case (sending cancel instead of end if needed).
  */
  touchcancel: function(evt) {
    evt.isCancel = YES;
    this.touchend(evt);
  },

  /** @private
     Ignore Touch events on textfields and links. starting iOS 5 textfields
     get touch events. Textfields just need to get the default focus action.
  */
  ignoreTouchHandle: function(evt) {
    if(SC.browser.isMobileSafari){
      var tag = evt.target.tagName;
      if(tag==="INPUT" || tag==="TEXTAREA" || tag==="A" || tag==="SELECT"){
        evt.allowDefault();
        return YES;
      }
    }
    return NO;
  },

  // ..........................................................
  // KEYBOARD HANDLING
  //

  // [CC]
  ignoreKeyHandle: function(evt) {
    return NO;
  },

  /**
    Invoked on a keyDown event that is not handled by any actual value.  This
    will get the key equivalent string and then walk down the keyPane, then
    the focusedPane, then the mainPane, looking for someone to handle it.
    Note that this will walk DOWN the view hierarchy, not up it like most.

    @returns {Object} Object that handled evet or null
  */
  attemptKeyEquivalent: function(evt) {
    var ret = null ;

    // keystring is a method name representing the keys pressed (i.e
    // 'alt_shift_escape')
    var keystring = evt.commandCodes()[0];

    // couldn't build a keystring for this key event, nothing to do
    if (!keystring) return NO;

    var menuPane = this.get('menuPane'),
        keyPane  = this.get('keyPane'),
        mainPane = this.get('mainPane');

    if (menuPane) {
      ret = menuPane.performKeyEquivalent(keystring, evt) ;
      if (ret) return ret;
    }

    // Try the keyPane.  If it's modal, then try the equivalent there but on
    // nobody else.
    if (keyPane) {
      ret = keyPane.performKeyEquivalent(keystring, evt) ;
      if (ret || keyPane.get('isModal')) return ret ;
    }

    // if not, then try the main pane
    if (!ret && mainPane && (mainPane!==keyPane)) {
      ret = mainPane.performKeyEquivalent(keystring, evt);
      if (ret || mainPane.get('isModal')) return ret ;
    }

    return ret ;
  },

  _lastModifiers: null,

  /** @private
    Modifier key changes are notified with a keydown event in most browsers.
    We turn this into a flagsChanged keyboard event.  Normally this does not
    stop the normal browser behavior.
  */
  _handleModifierChanges: function(evt) {
    // if the modifier keys have changed, then notify the first responder.
    var m;
    m = this._lastModifiers = (this._lastModifiers || { alt: false, ctrl: false, shift: false });

    var changed = false;
    if (evt.altKey !== m.alt) {
      m.alt = evt.altKey;
      changed = true;
    }

    if (evt.ctrlKey !== m.ctrl) {
      m.ctrl = evt.ctrlKey;
      changed = true;
    }

    if (evt.shiftKey !== m.shift) {
      m.shift = evt.shiftKey;
      changed = true;
    }
    evt.modifiers = m; // save on event

    return (changed) ? (this.sendEvent('flagsChanged', evt) ? evt.hasCustomEventHandling : YES) : YES ;
  },

  /** @private
    Determines if the keyDown event is a nonprintable or function key. These
    kinds of events are processed as keyboard shortcuts.  If no shortcut
    handles the event, then it will be sent as a regular keyDown event.
    This function is only valid when called with a keydown event.
  */
  _isFunctionOrNonPrintableKey: function(evt) {
    return !!(evt.altKey || evt.ctrlKey || evt.metaKey || SC.FUNCTION_KEYS[evt.which]);
  },

  /** @private
    Determines if the event simply reflects a modifier key change.  These
    events may generate a flagsChanged event, but are otherwise ignored.
  */
  _isModifierKey: function(evt) {
    return !!SC.MODIFIER_KEYS[evt.charCode];
  },

   /**
     @private
     Determines if the key is printable (and therefore should be dispatched from keypress).
     Some browsers send backspace, tab, enter, and escape on keypress, so we want to
     explicitly ignore those here.

     @param {KeyboardEvent} evt keypress event
     @returns {Boolean}
   */
  _isPrintableKey: function (evt) {
    return ((evt.originalEvent.which === undefined || evt.originalEvent.which > 0) &&
      !(evt.which === 8 || evt.which === 9 || evt.which === 13 || evt.which === 27));
  },

  /** @private
    The keydown event occurs whenever the physically depressed key changes.
    This event is used to deliver the flagsChanged event and to with function
    keys and keyboard shortcuts.

    All actions that might cause an actual insertion of text are handled in
    the keypress event.

    References:
        http://www.quirksmode.org/js/keys.html
        https://developer.mozilla.org/en/DOM/KeyboardEvent
        http://msdn.microsoft.com/library/ff974342.aspx
  */
  keydown: function(evt) {
    if (SC.none(evt)) return YES;
    if (this.ignoreKeyHandle(evt)) return YES;  // [CC]
    var keyCode = evt.keyCode;
    if (SC.browser.isMozilla && evt.keyCode===9) {
      this.keydownCounter = 1;
    }
    // Fix for IME input (japanese, mandarin).
    // If the KeyCode is 229 wait for the keyup and
    // trigger a keyDown if it is is enter onKeyup.
    if (keyCode===229){
      this._IMEInputON = YES;
      return this.sendEvent('keyDown', evt);
    }

    // If user presses the escape key while we are in the middle of a
    // drag operation, cancel the drag operation and handle the event.
    if (keyCode === 27 && this._drag) {
      this._drag.cancelDrag(evt);
      this._drag = null;
      this._mouseDownView = null;
      return YES;
    }

    // Firefox does NOT handle delete here...
    if (SC.browser.isMozilla && (evt.which === 8)) return true ;

    // modifier keys are handled separately by the 'flagsChanged' event
    // send event for modifier key changes, but only stop processing if this
    // is only a modifier change
    var ret = this._handleModifierChanges(evt),
        target = evt.target || evt.srcElement,
        forceBlock = (evt.which === 8) && !SC.allowsBackspaceToPreviousPage && (target === document.body);

    if (this._isModifierKey(evt)) return (forceBlock ? NO : ret);

    // if this is a function or non-printable key, try to use this as a key
    // equivalent.  Otherwise, send as a keyDown event so that the focused
    // responder can do something useful with the event.
    ret = YES ;
    if (this._isFunctionOrNonPrintableKey(evt)) {
      // otherwise, send as keyDown event.  If no one was interested in this
      // keyDown event (probably the case), just let the browser do its own
      // processing.

      // Arrow keys are handled in keypress for firefox
      if (keyCode>=37 && keyCode<=40 && SC.browser.isMozilla) return YES;

      ret = this.sendEvent('keyDown', evt) ;

      // attempt key equivalent if key not handled
      if (!ret) {
        SC.run(function () {
        ret = !this.attemptKeyEquivalent(evt) ;
        }, this);
      } else {
        ret = evt.hasCustomEventHandling ;
        if (ret) forceBlock = NO ; // code asked explicitly to let delete go
      }
    }

    return forceBlock ? NO : ret ;
  },

  /** @private
    The keypress event occurs after the user has typed something useful that
    the browser would like to insert.  Unlike keydown, the input codes here
    have been processed to reflect that actual text you might want to insert.

    Normally ignore any function or non-printable key events.  Otherwise, just
    trigger a keyDown.
  */
  keypress: function(evt) {
    if (this.ignoreKeyHandle(evt)) return YES;  // [CC]
    var ret,
        keyCode   = evt.keyCode,
        isFirefox = SC.browser.isMozilla;

    if (isFirefox && evt.keyCode===9) {
      this.keydownCounter++;
      if (this.keydownCounter === 2) return YES;
    }

    // delete is handled in keydown() for most browsers
    if (isFirefox && (evt.which === 8)) {
      //get the keycode and set it for which.
      evt.which = keyCode;
      ret = this.sendEvent('keyDown', evt);
      return ret ? (SC.allowsBackspaceToPreviousPage || evt.hasCustomEventHandling) : YES ;

    // normal processing.  send keyDown for printable keys...
    //there is a special case for arrow key repeating of events in FF.
    } else {
      var isFirefoxArrowKeys = (keyCode >= 37 && keyCode <= 40 && isFirefox),
          charCode           = evt.charCode;

      if ((charCode !== undefined && charCode === 0 && evt.keyCode!==9) && !isFirefoxArrowKeys) return YES;
      if (isFirefoxArrowKeys) evt.which = keyCode;
      // we only want to rethrow if this is a printable key so that we don't
      // duplicate the event sent in keydown when a modifier key is pressed.
      if (isFirefoxArrowKeys || this._isPrintableKey(evt)) {
        return this.sendEvent('keyDown', evt) ? evt.hasCustomEventHandling : YES;
    }
    }
  },

  keyup: function(evt) {
    if (this.ignoreKeyHandle(evt)) return YES;  // [CC]
    // to end the simulation of keypress in firefox set the _ffevt to null
    if(this._ffevt) this._ffevt=null;

    // modifier keys are handled separately by the 'flagsChanged' event
    // send event for modifier key changes, but only stop processing if this is only a modifier change
    var ret = this._handleModifierChanges(evt);
    if (this._isModifierKey(evt)) return ret;
    // Fix for IME input (japanese, mandarin).
    // If the KeyCode is 229 wait for the keyup and
    // trigger a keyDown if it is is enter onKeyup.
    if (this._IMEInputON && evt.keyCode===13){
      evt.isIMEInput = YES;
      this.sendEvent('keyDown', evt);
      this._IMEInputON = NO;
    }
    return this.sendEvent('keyUp', evt) ? evt.hasCustomEventHandling:YES;
  },

  /**
    IE's default behavior to blur textfields and other controls can only be
    blocked by returning NO to this event. However we don't want to block
    its default behavior otherwise textfields won't lose focus by clicking on
    an empty area as it's expected. If you want to block IE from blurring another
    control set blockIEDeactivate to true on the specific view in which you
    want to avoid this. Think of an autocomplete menu, you want to click on
    the menu but don't loose focus.
  */
  beforedeactivate: function(evt) {
    var toElement = evt.toElement;
    if (toElement && toElement.tagName && toElement.tagName!=="IFRAME") {
      var view = SC.viewFor(toElement);
      //The following line is necessary to allow/block text selection for IE,
      // in combination with the selectstart event.
      if (view && view.get('blocksIEDeactivate')) return NO;
    }
    return YES;
  },

  // ..........................................................
  // MOUSE HANDLING
  //

  mousedown: function(evt) {
    // If needed, let components handle mouse events
    if(this.ignoreMouseHandle(evt)) return YES;

    // First, save the click count. The click count resets if the mouse down
    // event occurs more than 250 ms later than the mouse up event or more
    // than 8 pixels away from the mouse down event or if the button used is different.
    this._clickCount += 1;

    var view = this.targetViewForEvent(evt);

    view = this._mouseDownView = this.sendEvent('mouseDown', evt, view) ;
    if (view && view.respondsTo('mouseDragged')) this._mouseCanDrag = YES ;

    // Determine if any views took responsibility for the event. If so, save that information so we
    // can prevent the next click event we receive from propagating to the browser.
    var ret = view ? evt.hasCustomEventHandling : YES;
    this._lastMouseDownCustomHandling = ret;

    // If it has been too long since the last click, the handler has changed or the mouse has moved
    // too far, reset the click count.
    if (!this._lastMouseUpAt || this._lastMouseDownView !== this._mouseDownView || ((Date.now() - this._lastMouseUpAt) > 250)) {
      this._clickCount = 1;
    } else {
      var deltaX = this._lastMouseDownX - evt.clientX,
          deltaY = this._lastMouseDownY - evt.clientY,
          distance = Math.sqrt(deltaX*deltaX + deltaY*deltaY) ;

      if (distance > 8.0) this._clickCount = 1;
    }
    evt.clickCount = this._clickCount;

    // Cache the handler and point of the last mouse down in order to determine whether a successive mouse down should
    // still increment the click count.
    this._lastMouseDownView = this._mouseDownView;
    this._lastMouseDownX = evt.clientX;
    this._lastMouseDownY = evt.clientY;

    return ret;
  },

  /**
    mouseUp only gets delivered to the view that handled the mouseDown evt.
    we also handle click and double click notifications through here to
    ensure consistant delivery.  Note that if mouseDownView is not
    implemented, then no mouseUp event will be sent, but a click will be
    sent.
  */
  mouseup: function(evt) {
    // If needed, let components handle mouse events
    if(this.ignoreMouseHandle(evt)) return YES;

    var clickOrDoubleClickDidTrigger = NO,
      dragView = this._drag,
      handler = null;

    if (dragView) {
      SC.run(function () {
        dragView.tryToPerform('mouseUp', evt);
      });
    } else {
      var view = this._mouseDownView,
        targetView = this.targetViewForEvent(evt);

      // record click count.
      evt.clickCount = this._clickCount ;

      // attempt the mouseup call only if there's a target.
      // don't want a mouseup going to anyone unless they handled the mousedown...
      if (view) {
        handler = this.sendEvent('mouseUp', evt, view) ;

        // try doubleClick
        if (!handler && this._clickCount === 2) {
          handler = this.sendEvent('doubleClick', evt, view) ;
          clickOrDoubleClickDidTrigger = YES;
        }

        // try single click
        if (!handler) {
          handler = this.sendEvent('click', evt, view) ;
          clickOrDoubleClickDidTrigger = YES;
        }
      }

      // try whoever's under the mouse if we haven't handle the mouse up yet
      if (!handler && !clickOrDoubleClickDidTrigger) {

        // try doubleClick
        if (this._clickCount === 2) {
          handler = this.sendEvent('doubleClick', evt, targetView);
        }

        // try singleClick
        if (!handler) {
          handler = this.sendEvent('click', evt, targetView) ;
        }
      }
    }

    // cleanup
    this._mouseCanDrag = NO;
    this._mouseDownView = this._drag = null;

    // Save timestamp of mouseup at last possible moment.
    // (This is used to calculate double click events)
    this._lastMouseUpAt = Date.now() ;

    // Determine if any views took responsibility for the
    // event. If so, save that information so we can prevent
    // the next click event we receive from propagating to the browser.
    var ret = handler ? evt.hasCustomEventHandling : YES;
    this._lastMouseUpCustomHandling = ret;

    return ret;
  },

  /**
    Certain browsers ignore us overriding mouseup and mousedown events and
    still allow default behavior (such as navigating away when the user clicks
    on a link). To block default behavior, we store whether or not the last
    mouseup or mousedown events resulted in us calling preventDefault() or
    stopPropagation(), in which case we make the same calls on the click event.

    @param {Event} evt the click event
    @returns {Boolean} whether the event should be propagated to the browser
  */
  click: function(evt) {
      // If needed, let components handle mouse events
    if(this.ignoreMouseHandle(evt)) return YES;

    if (!this._lastMouseUpCustomHandling || !this._lastMouseDownCustomHandling) {
      evt.preventDefault();
      evt.stopPropagation();
      return NO;
    }

    return YES;
  },

  dblclick: function(evt){
    // If needed, let components handle mouse events
    if(this.ignoreMouseHandle(evt)) return YES;

    if (SC.browser.isIE8OrLower) {
      this._clickCount = 2;
      // this._onmouseup(evt);
      this.mouseup(evt);
    }
  },

  mousewheel: function(evt) {
    // If needed, let components handle mouse events
    if(this.ignoreMouseHandle(evt)) return YES;

    var view = this.targetViewForEvent(evt) ,
        handler = this.sendEvent('mouseWheel', evt, view) ;

    return (handler) ? evt.hasCustomEventHandling : YES ;
  },

  _lastHovered: null,

  /**
   This will send mouseEntered, mouseExited, mousedDragged and mouseMoved
   to the views you hover over.  To receive these events, you must implement
   the method. If any subviews implement them and return true, then you won't
   receive any notices.

   If there is a target mouseDown view, then mouse moved events will also
   trigger calls to mouseDragged.
  */
  mousemove: function(evt) {
    // If needed, let components handle mouse events
    if(this.ignoreMouseHandle(evt)) return YES;

    if (SC.browser.isIE) {
      if (this._lastMoveX === evt.clientX && this._lastMoveY === evt.clientY) return;
    }

    // BEGIN CODAP change
    // On firefox v47 the event target can sometimes be the Document. This appears
    // to happen if the natural target is removed after the start of the mouse
    // action. Sproutcore assumes (in Core.viewFor) that the target is an element
    // and fails. We protect against this possibility by ignoring the event.
    // 6/21/2016
    if (!(evt.target instanceof Element)) {
      SC.warn('mousemove target not element: ' + (evt && evt.target && evt.target.constructor.name));
      return;
    }
    // END CODAP change

    // We'll record the last positions in all browsers, in case a special pane
    // or some such UI absolutely needs this information.
    this._lastMoveX = evt.clientX;
    this._lastMoveY = evt.clientY;

    SC.run(function() {
      var dragView = this._drag;

       // make sure the view gets focus no matter what.  FF is inconsistent
       // about this.
      // this.focus();
       // only do mouse[Moved|Entered|Exited|Dragged] if not in a drag session
       // drags send their own events, e.g. drag[Moved|Entered|Exited]
      if (dragView) {
         //IE triggers mousemove at the same time as mousedown
         if(SC.browser.isIE){
           if (this._lastMouseDownX !== evt.clientX || this._lastMouseDownY !== evt.clientY) {
            dragView.tryToPerform('mouseDragged', evt);
           }
        } else {
          dragView.tryToPerform('mouseDragged', evt);
         }
       } else {
        var lh = this._lastHovered || [], nh = [], loc, len,
             view = this.targetViewForEvent(evt) ;

         // first collect all the responding view starting with the
         // target view from the given mouse move event
         while (view && (view !== this)) {
           nh.push(view);
           view = view.get('nextResponder');
         }
         // next exit views that are no longer part of the
         // responding chain
         for (loc=0, len=lh.length; loc < len; loc++) {
           view = lh[loc] ;
          if (nh.indexOf(view) === -1 && !view.isDestroyed) { // Usually we don't want to have to manually check isDestroyed, but in this case we're explicitly checking an out-of-date cache.
             view.tryToPerform('mouseExited', evt);
           }
         }
         // finally, either perform mouse moved or mouse entered depending on
         // whether a responding view was or was not part of the last
         // hovered views
         for (loc=0, len=nh.length; loc < len; loc++) {
           view = nh[loc];
           if (lh.indexOf(view) !== -1) {
             view.tryToPerform('mouseMoved', evt);
           } else {
             view.tryToPerform('mouseEntered', evt);
           }
         }
         // Keep track of the view that were last hovered
         this._lastHovered = nh;
         // also, if a mouseDownView exists, call the mouseDragged action, if
         // it exists.
         if (this._mouseDownView) {
           if(SC.browser.isIE){
             if (this._lastMouseDownX !== evt.clientX && this._lastMouseDownY !== evt.clientY) {
               this._mouseDownView.tryToPerform('mouseDragged', evt);
             }
           }
           else {
             this._mouseDownView.tryToPerform('mouseDragged', evt);
           }
         }
       }
    }, this);
  },

  /** @private
     Ignore Mouse events.
  */
  ignoreMouseHandle: function(evt) {
    return NO;
  },

  // These event handlers prevent default file handling, and enable the dataDrag API.
  /** @private The dragenter event comes from the browser when a data-ful drag enters any element. */
  dragenter: function(evt) {
    SC.run(function() { this._dragenter(evt); }, this);
  },

  /** @private */
  _dragenter: function(evt) {
    if (!this._dragCounter) {
      this._dragCounter = 1;
    }
    else this._dragCounter++;
    return this._dragover(evt);
  },

  /** @private The dragleave event comes from the browser when a data-ful drag leaves any element. */
  dragleave: function(evt) {
    SC.run(function() { this._dragleave(evt); }, this);
  },

  /** @private */
  _dragleave: function(evt) {
    this._dragCounter--;
    var ret = this._dragover(evt);
    return ret;
  },
  /** @private
    Dragleave doesn't fire reliably in all browsers, so this method forces it (scheduled below). Note
    that, being scheduled via SC.Timer, this method is already in a run loop.
  */
  _forceDragLeave: function() {
    // Give it another runloop to ensure that we're not in the middle of a drag.
    this.invokeLast(function() {
      if (this._dragCounter === 0) return;
      this._dragCounter = 0;
      var evt = this._lastDraggedEvt;
      this._dragover(evt);
    });
  },

  /** @private This event fires continuously while the dataful drag is over the document. */
  dragover: function(evt) {
    SC.run(function() { this._dragover(evt); }, this);
  },

  /** @private */
  _dragover: function(evt) {
    // If it's a file being dragged, prevent the default (leaving the app and opening the file).
    // Begin Concord Consortium change: Use Array.includes instead of SC Array.contains
    // If the dataTransfer types is present, it was created by the browser and readonly.
    // The 'contains' method is not present.
    if (evt.dataTransfer && evt.dataTransfer.types &&
        (evt.dataTransfer.types.includes('Files') ||
            evt.dataTransfer.types.includes('text/uri-list'))) {
      // End Concord Consortium Change
      evt.preventDefault();
      evt.stopPropagation();
      // Set the default drag effect to 'none'. Views may reverse this if they wish.
      evt.dataTransfer.dropEffect = 'none';
    }

    // Walk the responder chain, alerting anyone that would like to know.
    var ld = this._lastDraggedOver || [], nd = [], loc, len,
        view = this.targetViewForEvent(evt);

    // Build the responder chain, starting with the view's target and (presumably) moving
    // up through parentViews to the pane.
    while (view && (view !== this)) {
      nd.push(view);
      view = view.get('nextResponder');
    }

    // Invalidate the force-drag-leave timer, if we have one set up.
    if (this._dragLeaveTimer) this._dragLeaveTimer.invalidate();

    // If this is our final drag event then we've left the document and everybody gets a
    // dataDragExited.
    if (this._dragCounter === 0) {
      for (loc = 0, len = nd.length; loc < len; loc++) {
        view = nd[loc];
        view.tryToPerform('dataDragExited', evt);
      }
      this._lastDraggedOver = this._lastDraggedEvt = this._dragLeaveTimer = null;
    }
    // Otherwise, we process the responder chain normally, ignoring dragleaves.
    // (We skip dragleave events because they are sent after the adjacent dragenter event; checking
    // through both stacks would result in views being exited, re-entered and re-exited each time.
    // As a consequence, views are left ignorant of a very small number of dragleave events; those
    // shouldn't end up being the crucial just-before-drop events, though, so they should be of no
    // consequence.)
    else if (evt.type !== 'dragleave') {
      // First, exit views that are no longer part of the responder chain, child to parent.
      for (loc = 0, len = ld.length; loc < len; loc++) {
        view = ld[loc];
        if (nd.indexOf(view) === -1) {
          view.tryToPerform('dataDragExited', evt);
        }
      }
      // Next, enter views that have just joined the responder chain, parent to child.
      for (loc = nd.length - 1; loc >= 0; loc--) {
        view = nd[loc];
        if (ld.indexOf(view) === -1) {
          view.tryToPerform('dataDragEntered', evt);
        }
      }
      // Finally, send hover events to everybody.
      for (loc = 0, len = nd.length; loc < len; loc++) {
        view = nd[loc];
        view.tryToPerform('dataDragHovered', evt);
      }
      this._lastDraggedOver = nd;
      // Begin Concord Consortium Change
      // clone event to protect it from modification during event processing.
      this._lastDraggedEvt = new SC.Event(evt.originalEvent || evt);
      // End Concord Consortium Change
      // For browsers that don't reliably call a dragleave for every dragenter, we have a timer fallback.
      // Begin Concord Consortium Change
      // Adjust timeout. On linux, including ChromeOS, dragover generated only
      // on mouse move, so, timeout of .3 seconds caused many false drag leaves.
      this._dragLeaveTimer = SC.Timer.schedule({ target: this, action: '_forceDragLeave', interval: 5000 });
      // End Concord Consortium Change
    }
  },

  /** @private This event is called if the most recent dragover event returned with a non-"none" dropEffect. */
  drop: function(evt) {
    SC.run(function() { this._drop(evt); }, this);
  },

  /** @private */
  _drop: function(evt) {
    // If it's a file being dragged, prevent the default (leaving the app and opening the file).
    // Begin Concord Consortium change: Use Array.includes instead of SC Array.contains
    // If the dataTransfer types is present, it was created by the browser and readonly.
    // The 'contains' method is not present.
    if (evt.dataTransfer && evt.dataTransfer.types &&
        (evt.dataTransfer.types.includes('Files') ||
            evt.dataTransfer.types.includes('text/uri-list'))) {
      // End Concord Consortium Change
      evt.preventDefault();
      evt.stopPropagation();
      // Set the default drag effect to 'none'. Views may reverse this if they wish.
      evt.dataTransfer.dropEffect = 'none';
    }

    // Bubble up the responder chain until we have a successful responder.
    var ld = this._lastDraggedOver || [], nd = [], loc, len,
        view = this.targetViewForEvent(evt);

    // First collect all the responding view starting with the target view from the given drag event.
    while (view && (view !== this)) {
      nd.push(view);
      view = view.get('nextResponder');
    }
    // Next, exit views that are no longer part of the responding chain. (This avoids the pixel-wide
    // edge case where a drop event fires on a new view without a final dragover event.)
    for (loc = 0, len = ld.length; loc < len; loc++) {
      view = ld[loc];
      if (nd.indexOf(view) === -1) {
        view.tryToPerform('dataDragExited', evt);
      }
    }
    // Next, bubble the drop event itself until we find someone that successfully responds.
    for (loc = 0, len = nd.length; loc < len; loc++) {
      view = nd[loc];
      if (view.tryToPerform('dataDragDropped', evt)) break;
    }
    // Finally, notify all interested views that the drag is dead and gone.
    for (loc = 0, len = nd.length; loc < len; loc++) {
      view = nd[loc];
      view.tryToPerform('dataDragExited', evt);
    }

    // Reset caches and counters.
    this._lastDraggedOver = null;
    this._lastDraggedAt = null;
    this._dragCounter = 0;
    if (this._dragLeaveTimer) this._dragLeaveTimer.invalidate();
    this._dragLeaveTimer = null;
  },


  // these methods are used to prevent unnecessary text-selection in IE,
  // there could be some more work to improve this behavior and make it
  // a bit more useful; right now it's just to prevent bugs when dragging
  // and dropping.

  _mouseCanDrag: YES,

  // [CC]
  ignoreSelectHandle: function(evt) {
    return NO;
  },

  selectstart: function(evt) {
    if (this.ignoreSelectHandle(evt)) return YES; // [CC]
    var targetView = this.targetViewForEvent(evt),
        result = this.sendEvent('selectStart', evt, targetView);

    // If the target view implements mouseDragged, then we want to ignore the
    // 'selectstart' event.
    if (targetView && targetView.respondsTo('mouseDragged')) {
      return (result !==null ? YES: NO) && !this._mouseCanDrag;
    } else {
      return (result !==null ? YES: NO);
    }
  },

  drag: function() { return false; },

  contextmenu: function(evt) {
    var view = this.targetViewForEvent(evt),
      ret;

    // Determine if any views took responsibility for the event.
    view = this.sendEvent('contextMenu', evt, view);
    ret = view ? evt.hasCustomEventHandling : YES;

    return ret;
  },

  // ..........................................................
  // ANIMATION HANDLING
  //

  /* @private Handler for animationstart events. */
  animationstart: function (evt) {
    var view = this.targetViewForEvent(evt);
    this.sendEvent('animationDidStart', evt, view);

    return view ? evt.hasCustomEventHandling : YES;
  },

  /* @private Handler for animationiteration events. */
  animationiteration: function (evt) {
    var view = this.targetViewForEvent(evt);
    this.sendEvent('animationDidIterate', evt, view);

    return view ? evt.hasCustomEventHandling : YES;
  },

  /* @private Handler for animationend events. */
  animationend: function (evt) {
    var view = this.targetViewForEvent(evt);
    this.sendEvent('animationDidEnd', evt, view);

    return view ? evt.hasCustomEventHandling : YES;
  },

  /* @private Handler for transitionend events. */
  transitionend: function (evt) {
    var view = this.targetViewForEvent(evt);
    this.sendEvent('transitionDidEnd', evt, view);

    return view ? evt.hasCustomEventHandling : YES;
  }

});

/*
  Invoked when the document is ready, but before main is called.  Creates
  an instance and sets up event listeners as needed.
*/
SC.ready(SC.RootResponder, SC.RootResponder.ready = function () {
  var r;

  r = SC.RootResponder.responder = SC.RootResponder.create();
  r.setup();
});

/* >>>>>>>>>> BEGIN source/system/application.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
sc_require('system/root_responder');


/** @class

  The root object for a SproutCore application. Usually you will create a
  single SC.Application instance as your root namespace. SC.Application is
  required if you intend to use SC.Responder to route events.

  ## Example

      Contacts = SC.Application.create({
        store: SC.Store.create(SC.Record.fixtures),

        // add other useful properties here
      });

  @extends SC.ResponderContext
  @since SproutCore 1.0
*/
SC.Application = SC.Responder.extend(SC.ResponderContext,
/** SC.Application.prototype */ {

  /** @private UNUSED
    The current design mode of the application and its views.

    If the application has designModes specified, this property will be set
    automatically as the window size changes across the design mode boundaries.

    @property {String}
    @default null
  */
  // designMode: null,

  /**
    A hash of the design mode thresholds for this application.

    While a "design" (the manner views are positioned, shaped and styled) may be
    flexible enough to stretch up for a large display and to compress down
    for a medium sized display, at a certain point it often makes more sense
    to stop stretching and compressing and just implement an additional new design
    specific to the much different display size. In order to make this possible
    and with as much ease as possible, SproutCore includes support for "design
    modes". Design modes are based on the current display size and orientation.

    SproutCore supports three size-based design modes by default: 's' for small,
    'm' for medium and 'l' for large. Smartphones and handheld devices like the
    iPod Touch fall within the small category, tablets and normal desktop displays
    fall within the medium category and retina desktops or 4K displays fall
    into the large category.

    When the display size crosses a threshold between one size category to
    another, SproutCore will update the design mode of each view in the
    application, giving you a chance to provide overrides for that specific
    size via the special `modeAdjust` property.

    For example, if you wanted to hide a view completely when in the small (s)
    mode you could add:

        //...

        mediumPlusView: SC.View.extend({

          // Design mode overrides.
          modeAdjust: { s: { isVisible: false } } // Hide the view in 's' or 'small' mode.

        }),

        //...

    As you can see, we simply indicate the property overrides that we want
    for the specific mode. To adjust the height for medium mode, you could add:

        //...

        myView: SC.View.extend({

          // The normal layout always applies.
          layout: { height: 24 },

          // Design mode overrides.
          modeAdjust: { m: { layout: { height: 30 } } // Adjust the height in 'm' or 'medium' mode.

        }),

        //...

    Note that the values in `modeAdjust` are overrides for that mode and the
    values will be *reset* to their original values when leaving that mode.

    The second component to design modes is orientation. Each of the size
    categories can have two different orientations: 'l' for landscape or 'p' for
    portrait. Therefore, you may want to alter the design to account for the
    device orientation as well using `modeAdjust`. To do this, you simply
    specify orientation specific designs with the `_l` or `_p` suffix
    accordingly.

    For example, you can provide a configuration for a size category with
    slight deviations for orientations of that size all in just a few lines
    of code,

        //...

        customView: SC.View.extend({

          // The default alignment for this custom view's contents.
          alignment: SC.ALIGN_LEFT,

          // The default line height for this custom view's contents.
          lineHeight: 40,

          // Design mode overrides.
          modeAdjust: {
            m: { lineHeight: 50 }, // Overrides for medium mode regardless of orientation.
            m_p: { alignment: SC.ALIGN_CENTER }, // Overrides for medium - portrait mode.
            m_l: { layout: { top: 20 } } // Overrides for medium - landscape mode.
          }

        }),

        //...

    ### A note on styling for design modes

    Class names are automatically applied to each view depending on the mode
    as found in the SC.DESIGN_MODE_CLASS_NAMES hash. By default, your
    views will have one of three class names added:

        > 'sc-small' in small mode
        > 'sc-medium' in medium mode
        > 'sc-large' in large mode

    As well, the `body` element is given an orientation class name that you
    can use as well:

        > 'sc-landscape' in landscape orientation
        > 'sc-portrait' in portrait orientation

    ### A note on overriding layouts

    Layout overrides work slightly differently than regular property overrides,
    because they are set via `adjust`. This means they apply on *top* of the
    default layout, they don't replace the default layout. For example,
    the default layout is `{ left: 0, right: 0, top: 0, bottom: 0 }` and if
    we provide a design mode like,

        modeAdjust: { l: { layout: { top: 50 } } }

    The layout becomes `{ left: 0, right: 0, top: 50, bottom: 0 }`. If we had
    a default layout like `{ centerX: 0, centerY: 0, height: 100, width: 100 }`
    and we wanted to change it to a left positioned layout, we would need to
    null out the centerX value like so,

        modeAdjust: { l: { layout: { centerX: null, left: 0 } } } // Convert to left positioned layout.

    ### A note on the medium category

    The medium category covers tablets *and* non-retina desktops and laptops.
    While we could try to further differentiate between these two categories,
    there is no safe way to do this and to do so would cause more harm than good.
    Tablets can be connected to mice and keyboards, desktops can have touch
    screens and there is no way to know whether a mouse, touch or pointer is
    going to be used from one event to the next. Therefore the message should
    be clear, *you should always design for touch*. This means that a medium
    sized design should be expected to work well on a laptop and a tablet.

    ### A note on customizing the design mode categories

    Design mode thresholds are determined by the area of the display divided by
    the device pixel ratio. In this manner a 1024 x 768 display on a
    handheld device can be differentiated from a 1024 x 768 display on a
    desktop. Through testing and research, the three categories of 'small',
    'medium' and 'large' were chosen with thresholds between them of
    500,000 sq.px and 2,000,000 sq.px.

    Therefore, any display area divided by device pixel ratio that is less
    than 500,000 will be considered 'small' and likewise a calculated area
    of over 2,000,000 will be considered 'large'. This should be sufficient
    for almost all device specific designs and as is mentioned earlier,
    trying to get even more fine-grained is a dangerous endeavor. However,
    you can set your own thresholds easily enough by overriding this property.

    @readonly
    @property {Object}
    @default { s: 500000, m: 2000000, l: Infinity }
  */
  designModes: {
    's': 500000, // ex. smart phone display
    'm': 2000000, // ex. tablet & non-retina desktop display
    'l': Infinity // ex. retina desktop display and TV
  },

  /** @private */
  init: function () {
    arguments.callee.base.apply(this,arguments);

    // Initialize the value on the RootResponder when it is ready.
    SC.ready(this, '_setDesignModes');
  },

  /** @private */
  _setDesignModes: function () {
    var designModes = this.get('designModes'),
      responder = SC.RootResponder.responder;

    if (designModes) {
      // All we do is pass the value to the root responder for convenience.
      responder.set('designModes', designModes);
      // UNUSED.
      // this.bind('designMode', SC.Binding.from('SC.RootResponder.responder.currentDesignMode'));
    }
  }

});

/* >>>>>>>>>> BEGIN source/system/bezier_curves.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2014 7x7 Software Inc. All rights reserved.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/** @private Kept private until fully fleshed out.
  A cubic bezier equation. Used by the SC.easingCurve function.
 */
SC.CubicBezierEquation = function (C1, C2, C3, C4) {

  var B1 = function (t) { return (1 - t) * (1 - t) * (1 - t); };
  var B2 = function (t) { return 3 * t * (1 - t) * (1 - t); };
  var B3 = function (t) { return 3 * t * t * (1 - t); };
  var B4 = function (t) { return t * t * t; };

  this.position = function (percent) {
    var pos = {};

    pos.x = C1.x * B1(percent) + C2.x * B2(percent) + C3.x * B3(percent) + C4.x * B4(percent);
    pos.y = C1.y * B1(percent) + C2.y * B2(percent) + C3.y * B3(percent) + C4.y * B4(percent);

    return pos;
  };

};

/** @private Kept private until fully fleshed out (name change?).
  A specialized bezier curve with fixed start at 0,0 and fixed end at 1,1.

  */
SC.easingCurve = function (C2x, C2y, C3x, C3y) {

  var C1 = { x: 0, y: 0 },
    C2 = { x: C2x, y: C2y },
    C3 = { x: C3x, y: C3y },
    C4 = { x: 1, y: 1 };

  var equation = new SC.CubicBezierEquation(C1, C2, C3, C4);

  equation.value = function (percent) {
    percent = Math.max(0, Math.min(percent, 1));
    return this.position(percent).y;
  };

  equation.toString = function () {
    return "cubic-bezier(%@, %@, %@, %@)".fmt(C2x, C2y, C3x, C3y);
  };

  return equation;
};

/* >>>>>>>>>> BEGIN source/system/color.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/** @class
  Represents a color, and provides methods for manipulating it. Maintains underlying
  rgba values, and includes support for colorspace conversions between rgb and hsl.

  For instructions on using SC.Color to color a view, see "SC.Color and SC.View"
  below.

  ### Basic Use

  You can create a color from red, green, blue and alpha values, with:

      SC.Color.create({
        r: 255,
        g: 255,
        b: 255,
        a: 0.5
      });

  All values are optional; the default is black. You can also create a color from any
  valid CSS string, with:

      SC.Color.from('rgba(255, 255, 255, 0.5)');

  The best CSS value for the given color in the current browser is available at the
  bindable property `cssText`. (This will provide deprecated ARGB values for older
  versions of IE; see "Edge Case: Supporting Alpha in IE" below.) (Calling
  `SC.Color.from` with an undefined or null value is equivalent to calling it with
  `'transparent'`.)

  Once created, you can manipulate a color by settings its a, r, g or b values,
  or setting its cssText value (though be careful of invalid values; see "Error
  State" below).

  ### Math

  `SC.Color` provides three methods for performing basic math: `sub` for subtraction,
  `add` for addition, and `mult` for scaling a number via multiplication.

  Note that these methods do not perform any validation to ensure that the underlying
  rgba values stay within the device's gamut (0 to 255 on a normal screen, and 0 to 1
  for alpha). For example, adding white to white will result in r, g and b values of
  510, a nonsensical value. (The `cssText` property will, however, correctly clamp the
  component values, and the color will output #FFFFFF.) This behavior is required
  for operations such as interpolating between colors (see "SC.Color and SC.View"
  below); it also gives SC.Color more predictable math, where A + B - B = A, even if
  the intermediate (A + B) operation results in underlying values outside of the normal
  gamut.

  (The class method `SC.Color.clampToDeviceGamut` is used to clamp r, g and b values to the
  standard 0 - 255 range. If your application is displaying on a screen with non-standard
  ranges, you may need to override this method.)

  ### SC.Color and SC.View

  Hooking up an instance of SC.Color to SC.View#backgroundColor is simple, but like all
  uses of backgroundColor, it comes with moderate performance implications, and should
  be avoided in cases where regular CSS is sufficient, or where bindings are unduly
  expensive, such as in rapidly-scrolling ListViews.

  Use the following code to tie a view's background color to an instance of SC.Color. Note
  that you must add backgroundColor to displayProperties in order for your view to update
  when the it changes; for performance reasons it is not included by default.

      SC.View.extend({
        color: SC.Color.from({'burlywood'}),
        backgroundColorBinding: SC.Binding.oneWay('*color.cssText'),
        displayProperties: ['backgroundColor']
      })

  You can use this to implement a simple cross-fade between two colors. Here's a basic
  example (again, note that when possible, pure CSS transitions will be substantially
  more performant):

      SC.View.extend({
        displayProperties: ['backgroundColor'],
        backgroundColor: 'cadetblue',
        fromColor: SC.Color.from('cadetblue'),
        toColor: SC.Color.from('springgreen'),
        click: function() {
          // Cancel previous timer.
          if (this._timer) this._timer.invalidate();
          // Figure out whether we're coming or going.
          this._forward = !this._forward;
          // Calculate the difference between the two colors.
          var fromColor = this._forward ? this.fromColor : this.toColor,
              toColor = this._forward ? this.toColor : this.fromColor;
          this._deltaColor = toColor.sub(fromColor);
          // Set the timer.
          this._timer = SC.Timer.schedule({
            target: this,
            action: '_tick',
            interval: 15,
            repeats: YES,
            until: Date.now() + 500
          });
        },
        _tick: function() {
          // Calculate percent of time elapsed.
          var started = this._timer.startTime,
              now = Date.now(),
              until = this._timer.until,
              pct = (now - started) / (until - started);
          // Constrain pct.
          pct = Math.min(pct, 1);
          // Calculate color.
          var fromColor = this._forward ? this.fromColor : this.toColor,
              toColor = this._forward ? this.toColor : this.fromColor,
              deltaColor = this._deltaColor,
              currentColor = fromColor.add(deltaColor.mult(pct));
          // Set.
          this.set('backgroundColor', currentColor.get('cssText'));
        }
      })

  ### Error State

  If you call `SC.Color.from` with an invalid value, or set `cssText` to an invalid
  value, the color object will go into error mode, with `isError` set to YES and
  `errorValue` containing the invalid value that triggered it. A color in error mode
  will become transparent, and you will be unable to modify its r, g, b or a values.

  To reset a color to its last-good values (or, if none, to black), call its `reset`
  method. Setting `cssText` to a valid value will also recover the color object to a
  non-error state.

  ### Edge Case: Supporting Alpha in IE

  Supporting the alpha channel in older versions of IE requires a little extra work.
  The bindable `cssText` property will return valid ARGB (e.g. #99FFFFFF) when it
  detects that it's in an older version of IE which requires it, but unfortunately you
  can't simply plug that value into `background-color`. The following code will detect
  this case and provide the correct CSS snippet:

      // This hack disables ClearType on IE!
      var color = SC.Color.from('rgba(0, 0, 0, .5)').get('cssText'),
          css;
      if (SC.Color.supportsARGB) {
        var gradient = "progid:DXImageTransform.Microsoft.gradient";
        css = ("-ms-filter:" + gradient + "(startColorstr=%@1,endColorstr=%@1);" +
               "filter:" + gradient + "(startColorstr=%@1,endColorstr=%@1)" +
               "zoom: 1").fmt(color);
      } else {
        css = "background-color:" + color;
      }

  @extends SC.Object
  @extends SC.Copyable
  @extends SC.Error
 */
SC.Color = SC.Object.extend(
  SC.Copyable,
  /** @scope SC.Color.prototype */{

  /**
    The original color string from which this object was created.

    For example, if your color was created via `SC.Color.from("burlywood")`,
    then this would be set to `"burlywood"`.

    @type String
    @default null
   */
  original: null,

  /**
    Whether the color is valid. Attempting to set `cssText` or call `from` with invalid input
    will put the color into an error state until updated with a valid string or reset.

    @type Boolean
    @default NO
    @see SC.Error
  */
  isError: NO,

  /**
    In the case of an invalid color, this contains the invalid string that was used to create or
    update it.

    @type String
    @default null
    @see SC.Error
  */
  errorValue: null,

  /**
    The alpha channel (opacity).
    `a` is a decimal value between 0 and 1.

    @type Number
    @default 1
   */
  a: function (key, value) {
    // Getter.
    if (value === undefined) {
      return this._a;
    }
    // Setter.
    else {
      if (this.get('isError')) value = this._a;
      this._a = value;
      return value;
    }
  }.property().cacheable(),

  /** @private */
  _a: 1,

  /**
    The red value.
    `r` is an integer between 0 and 255.

    @type Number
    @default 0
   */
  r: function (key, value) {
    // Getter.
    if (value === undefined) {
      return this._r;
    }
    // Setter.
    else {
      if (this.get('isError')) value = this._r;
      this._r = value;
      return value;
    }
  }.property().cacheable(),

  /** @private */
  _r: 0,

  /**
    The green value.
    `g` is an integer between 0 and 255.

    @type Number
    @default 0
   */
  g: function (key, value) {
    // Getter.
    if (value === undefined) {
      return this._g;
    }
    // Setter.
    else {
      if (this.get('isError')) value = this._g;
      this._g = value;
      return value;
    }
  }.property().cacheable(),

  /** @private */
  _g: 0,

  /**
    The blue value.
    `b` is an integer between 0 and 255.

    @type Number
    @default 0
   */
  b: function (key, value) {
    // Getter.
    if (value === undefined) {
      return this._b;
    }
    // Setter.
    else {
      if (this.get('isError')) value = this._b;
      this._b = value;
      return value;
    }
  }.property().cacheable(),

  /** @private */
  _b: 0,

  /**
    The current hue of this color.
    Hue is a float in degrees between 0° and 360°.

    @field
    @type Number
   */
  hue: function (key, deg) {
    var clamp = SC.Color.clampToDeviceGamut,
        hsl = SC.Color.rgbToHsl(clamp(this.get('r')),
                                clamp(this.get('g')),
                                clamp(this.get('b'))),
        rgb;

    if (deg !== undefined) {
      // Normalize the hue to be between 0 and 360
      hsl[0] = (deg % 360 + 360) % 360;

      rgb = SC.Color.hslToRgb(hsl[0], hsl[1], hsl[2]);
      this.beginPropertyChanges();
      this.set('r', rgb[0]);
      this.set('g', rgb[1]);
      this.set('b', rgb[2]);
      this.endPropertyChanges();
    }
    return hsl[0];
  }.property('r', 'g', 'b').cacheable(),

  /**
    The current saturation of this color.
    Saturation is a percent between 0 and 1.

    @field
    @type Number
   */
  saturation: function (key, value) {
    var clamp = SC.Color.clampToDeviceGamut,
        hsl = SC.Color.rgbToHsl(clamp(this.get('r')),
                                clamp(this.get('g')),
                                clamp(this.get('b'))),
        rgb;

    if (value !== undefined) {
      // Clamp the saturation between 0 and 100
      hsl[1] = SC.Color.clamp(value, 0, 1);

      rgb = SC.Color.hslToRgb(hsl[0], hsl[1], hsl[2]);
      this.beginPropertyChanges();
      this.set('r', rgb[0]);
      this.set('g', rgb[1]);
      this.set('b', rgb[2]);
      this.endPropertyChanges();
    }

    return hsl[1];
  }.property('r', 'g', 'b').cacheable(),

  /**
    The current lightness of this color.
    Saturation is a percent between 0 and 1.

    @field
    @type Number
   */
  luminosity: function (key, value) {
    var clamp = SC.Color.clampToDeviceGamut,
        hsl = SC.Color.rgbToHsl(clamp(this.get('r')),
                                clamp(this.get('g')),
                                clamp(this.get('b'))),
        rgb;

    if (value !== undefined) {
      // Clamp the lightness between 0 and 1
      hsl[2] = SC.Color.clamp(value, 0, 1);

      rgb = SC.Color.hslToRgb(hsl[0], hsl[1], hsl[2]);
      this.beginPropertyChanges();
      this.set('r', rgb[0]);
      this.set('g', rgb[1]);
      this.set('b', rgb[2]);
      this.endPropertyChanges();
    }
    return hsl[2];
  }.property('r', 'g', 'b').cacheable(),

  /**
    Whether two colors are equivalent.
    @param {SC.Color} color The color to compare this one to.
    @returns {Boolean} YES if the two colors are equivalent
   */
  isEqualTo: function (color) {
    return this.get('r') === color.get('r') &&
           this.get('g') === color.get('g') &&
           this.get('b') === color.get('b') &&
           this.get('a') === color.get('a');
  },

  /**
    Returns a CSS string of the color
    under the #aarrggbb scheme.

    This color is only valid for IE
    filters. This is here as a hack
    to support animating rgba values
    in older versions of IE by using
    filter gradients with no change in
    the actual gradient.

    @returns {String} The color in the rgba color space as an argb value.
   */
  toArgb: function () {
    var clamp = SC.Color.clampToDeviceGamut;

    return '#' + [clamp(255 * this.get('a')),
                  clamp(this.get('r')),
                  clamp(this.get('g')),
                  clamp(this.get('b'))].map(function (v) {
      v = v.toString(16);
      return v.length === 1 ? '0' + v : v;
    }).join('');
  },

  /**
    Returns a CSS string of the color
    under the #rrggbb scheme.

    @returns {String} The color in the rgb color space as a hex value.
   */
  toHex: function () {
    var clamp = SC.Color.clampToDeviceGamut;
    return '#' + [clamp(this.get('r')),
                  clamp(this.get('g')),
                  clamp(this.get('b'))].map(function (v) {
      v = v.toString(16);
      return v.length === 1 ? '0' + v : v;
    }).join('');
  },

  /**
    Returns a CSS string of the color
    under the rgb() scheme.

    @returns {String} The color in the rgb color space.
   */
  toRgb: function () {
    var clamp = SC.Color.clampToDeviceGamut;
    return 'rgb(' + clamp(this.get('r')) + ','
                  + clamp(this.get('g')) + ','
                  + clamp(this.get('b')) + ')';
  },

  /**
    Returns a CSS string of the color
    under the rgba() scheme.

    @returns {String} The color in the rgba color space.
   */
  toRgba: function () {
    var clamp = SC.Color.clampToDeviceGamut;
    return 'rgba(' + clamp(this.get('r')) + ','
                   + clamp(this.get('g')) + ','
                   + clamp(this.get('b')) + ','
                   + this.get('a') + ')';
  },

  /**
    Returns a CSS string of the color
    under the hsl() scheme.

    @returns {String} The color in the hsl color space.
   */
  toHsl: function () {
    var round = Math.round;
    return 'hsl(' + round(this.get('hue')) + ','
                  + round(this.get('saturation') * 100) + '%,'
                  + round(this.get('luminosity') * 100) + '%)';
  },

  /**
    Returns a CSS string of the color
    under the hsla() scheme.

    @returns {String} The color in the hsla color space.
   */
  toHsla: function () {
    var round = Math.round;
    return 'hsla(' + round(this.get('hue')) + ','
                   + round(this.get('saturation') * 100) + '%,'
                   + round(this.get('luminosity') * 100) + '%,'
                   + this.get('a') + ')';
  },

  /**
    The CSS string representation that will be
    best displayed by the browser.

    @field
    @type String
   */
  cssText: function (key, value) {
    // Getter.
    if (value === undefined) {
      // FAST PATH: Error.
      if (this.get('isError')) return this.get('errorValue');

      // FAST PATH: transparent.
      if (this.get('a') === 0) return 'transparent';

      var supportsAlphaChannel = SC.Color.supportsRgba ||
                                 SC.Color.supportsArgb;
      return (this.get('a') === 1 || !supportsAlphaChannel)
             ? this.toHex()
             : SC.Color.supportsRgba
             ? this.toRgba()
             : this.toArgb();
    }
    // Setter.
    else {
      var hash = SC.Color._parse(value);
      this.beginPropertyChanges();
      // Error state
      if (!hash) {
        // Cache current value for recovery.
        this._lastValidHash = { r: this._r, g: this._g, b: this._b, a: this._a };
        this.set('r', 0);
        this.set('g', 0);
        this.set('b', 0);
        this.set('a', 0);
        this.set('errorValue', value);
        this.set('isError', YES);
      }
      // Happy state
      else {
        this.setIfChanged('isError', NO);
        this.setIfChanged('errorValue', null);
        this.set('r', hash.r);
        this.set('g', hash.g);
        this.set('b', hash.b);
        this.set('a', hash.a);
      }
      this.endPropertyChanges();
      return value;
    }
  }.property('r', 'g', 'b', 'a').cacheable(),

  /**
    A read-only property which always returns a valid CSS property. If the color is in
    an error state, it returns 'transparent'.

    @field
    @type String
   */
  validCssText: function() {
    if (this.get('isError')) return 'transparent';
    else return this.get('cssText');
  }.property('cssText', 'isError').cacheable(),

  /**
    Resets an errored color to its last valid color. If the color has never been valid,
    it resets to black.

    @returns {SC.Color} receiver
   */
  reset: function() {
    // Gatekeep: not in error mode.
    if (!this.get('isError')) return this;
    // Reset the value to the last valid hash, or default black.
    var lastValidHash = this._lastValidHash || { r: 0, g: 0, b: 0, a: 1 };
    this.beginPropertyChanges();
    this.set('isError', NO);
    this.set('errorValue', null);
    this.set('r', lastValidHash.r);
    this.set('g', lastValidHash.g);
    this.set('b', lastValidHash.b);
    this.set('a', lastValidHash.a);
    this.endPropertyChanges();
    return this;
  },

  /**
    Returns a clone of this color.
    This will always a deep clone.

    @returns {SC.Color} The clone color.
   */
  copy: function () {
    return SC.Color.create({
      original: this.get('original'),
      r: this.get('r'),
      g: this.get('g'),
      b: this.get('b'),
      a: this.get('a'),
      isError: this.get('isError'),
      errorValue: this.get('errorValue')
    });
  },

  /**
    Returns a color that's the difference between two colors.

    Note that the result might not be a valid CSS color.

    @param {SC.Color} color The color to subtract from this one.
    @returns {SC.Color} The difference between the two colors.
   */
  sub: function (color) {
    return SC.Color.create({
      r: this.get('r') - color.get('r'),
      g: this.get('g') - color.get('g'),
      b: this.get('b') - color.get('b'),
      a: this.get('a') - color.get('a'),
      isError: this.get('isError') || color.get('isError')
    });
  },

  /**
    Returns a new color that's the addition of two colors.

    Note that the resulting a, r, g and b values are not clamped to within valid
    ranges.

    @param {SC.Color} color The color to add to this one.
    @returns {SC.Color} The addition of the two colors.
   */
  add: function (color) {
    return SC.Color.create({
      r: this.get('r') + color.get('r'),
      g: this.get('g') + color.get('g'),
      b: this.get('b') + color.get('b'),
      a: this.get('a') + color.get('a'),
      isError: this.get('isError')
    });
  },

  /**
    Returns a color that has it's units uniformly multiplied
    by a given multiplier.

    Note that the result might not be a valid CSS color.

    @param {Number} multipler How much to multiply rgba by.
    @returns {SC.Color} The adjusted color.
   */
  mult: function (multiplier) {
    var round = Math.round;
    return SC.Color.create({
      r: round(this.get('r') * multiplier),
      g: round(this.get('g') * multiplier),
      b: round(this.get('b') * multiplier),
      a: this.get('a') * multiplier,
      isError: this.get('isError')
    });
  }
});

SC.Color.mixin(
  /** @scope SC.Color */{

  /** @private Overrides create to support creation with {a, r, g, b} hash. */
  create: function() {
    var vals = {},
        hasVals = NO,
        keys = ['a', 'r', 'g', 'b'],
        args, len,
        hash, i, k, key;


    // Fast arguments access.
    // Accessing `arguments.length` is just a Number and doesn't materialize the `arguments` object, which is costly.
    args = new Array(arguments.length); // SC.A(arguments)
    len = args.length;

    // Loop through all arguments. If any of them contain numeric a, r, g or b arguments,
    // clone the hash and move the value from (e.g.) a to _a.
    for (i = 0; i < len; i++) {
      hash = arguments[i];
      if (SC.typeOf(hash.a) === SC.T_NUMBER
        || SC.typeOf(hash.r) === SC.T_NUMBER
        || SC.typeOf(hash.g) === SC.T_NUMBER
        || SC.typeOf(hash.b) === SC.T_NUMBER
      ) {
        hasVals = YES;
        hash = args[i] = SC.clone(hash);
        for (k = 0; k < 4; k++) {
          key = keys[k];
          if (SC.typeOf(hash[key]) === SC.T_NUMBER) {
            vals['_' + key] = hash[key];
            delete hash[key];
          }
        }
      } else {
        args[i] = hash;
      }
    }

    if (hasVals) args.push(vals);
    return SC.Object.create.apply(this, args);
  },

  /**
    Whether this browser supports the rgba color model.
    Check courtesy of Modernizr.
    @type Boolean
    @see https://github.com/Modernizr/Modernizr/blob/master/modernizr.js#L552
   */
  supportsRgba: (function () {
    var style = document.getElementsByTagName('script')[0].style,
        cssText = style.cssText,
        supported;

    style.cssText = 'background-color:rgba(5,2,1,.5)';
    supported = style.backgroundColor.indexOf('rgba') !== -1;
    style.cssText = cssText;
    return supported;
  }()),

  /**
    Whether this browser supports the argb color model.
    @type Boolean
   */
  supportsArgb: (function () {
    var style = document.getElementsByTagName('script')[0].style,
        cssText = style.cssText,
        supported;

    style.cssText = 'filter: progid:DXImageTransform.Microsoft.gradient(startColorstr="#55000000", endColorstr="#55000000");';
    supported = style.backgroundColor.indexOf('#55000000') !== -1;
    style.cssText = cssText;
    return supported;
  }()),

  /**
    Used to clamp a value in between a minimum
    value and a maximum value.

    @param {Number} value The value to clamp.
    @param {Number} min The minimum number the value can be.
    @param {Number} max The maximum number the value can be.
    @returns {Number} The value clamped between min and max.
   */
  clamp: function (value, min, max) {
    return Math.max(Math.min(value, max), min);
  },

  /**
    Clamps a number, then rounds it to the nearest integer.

    @param {Number} value The value to clamp.
    @param {Number} min The minimum number the value can be.
    @param {Number} max The maximum number the value can be.
    @returns {Number} The value clamped between min and max as an integer.
    @see SC.Color.clamp
   */
  clampInt: function (value, min, max) {
    return Math.round(SC.Color.clamp(value, min, max));
  },

  /**
    Clamps a number so it lies in the device gamut.
    For screens, this an integer between 0 and 255.

    @param {Number} value The value to clamp
    @returns {Number} The value clamped to the device gamut.
   */
  clampToDeviceGamut: function (value) {
    return SC.Color.clampInt(value, 0, 255);
  },

  /**
    Returns the RGB for a color defined in
    the HSV color space.

    @param {Number} h The hue of the color as a degree between 0° and 360°
    @param {Number} s The saturation of the color as a percent between 0 and 1.
    @param {Number} v The value of the color as a percent between 0 and 1.
    @returns {Number[]} A RGB triple in the form `(r, g, b)`
      where each of the values are integers between 0 and 255.
   */
  hsvToRgb: function (h, s, v) {
    h /= 360;
    var r, g, b,
        i = Math.floor(h * 6),
        f = h * 6 - i,
        p = v * (1 - s),
        q = v * (1 - (s * f)),
        t = v * (1 - (s * (1 - f))),
        rgb = [[v, t, p],
               [q, v, p],
               [p, v, t],
               [p, q, v],
               [t, p, v],
               [v, p, q]],
        clamp = SC.Color.clampToDeviceGamut;

    i = i % 6;
    r = clamp(rgb[i][0] * 255);
    g = clamp(rgb[i][1] * 255);
    b = clamp(rgb[i][2] * 255);

    return [r, g, b];
  },

  /**
    Returns an RGB color transformed into the
    HSV colorspace as triple `(h, s, v)`.

    @param {Number} r The red component as an integer between 0 and 255.
    @param {Number} g The green component as an integer between 0 and 255.
    @param {Number} b The blue component as an integer between 0 and 255.
    @returns {Number[]} A HSV triple in the form `(h, s, v)`
      where `h` is in degrees (as a float) between 0° and 360° and
            `s` and `v` are percents between 0 and 1.
   */
  rgbToHsv: function (r, g, b) {
    r /= 255;
    g /= 255;
    b /= 255;

    var max = Math.max(r, g, b),
        min = Math.min(r, g, b),
        d = max - min,
        h, s = max === 0 ? 0 : d / max, v = max;

    // achromatic
    if (max === min) {
      h = 0;
    } else {
      switch (max) {
      case r:
        h = (g - b) / d + (g < b ? 6 : 0);
        break;
      case g:
        h = (b - r) / d + 2;
        break;
      case b:
        h = (r - g) / d + 4;
        break;
      }
      h /= 6;
    }
    h *= 360;

    return [h, s, v];
  },

  /**
    Returns the RGB for a color defined in
    the HSL color space.

    (Notes are taken from the W3 spec, and are
     written in ABC)

    @param {Number} h The hue of the color as a degree between 0° and 360°
    @param {Number} s The saturation of the color as a percent between 0 and 1.
    @param {Number} l The luminosity of the color as a percent between 0 and 1.
    @returns {Number[]} A RGB triple in the form `(r, g, b)`
      where each of the values are integers between 0 and 255.
    @see http://www.w3.org/TR/css3-color/#hsl-color
   */
  hslToRgb: function (h, s, l) {
    h /= 360;

  // HOW TO RETURN hsl.to.rgb(h, s, l):
    var m1, m2, hueToRgb = SC.Color.hueToRgb,
        clamp = SC.Color.clampToDeviceGamut;

    // SELECT:
      // l<=0.5: PUT l*(s+1) IN m2
      // ELSE: PUT l+s-l*s IN m2
    m2 = l <= 0.5 ? l * (s + 1) : l + s - l * s;
    // PUT l*2-m2 IN m1
    m1 = l * 2 - m2;
    // PUT hue.to.rgb(m1, m2, h+1/3) IN r
    // PUT hue.to.rgb(m1, m2, h    ) IN g
    // PUT hue.to.rgb(m1, m2, h-1/3) IN b
    // RETURN (r, g, b)
    return [clamp(hueToRgb(m1, m2, h + 1/3) * 255),
            clamp(hueToRgb(m1, m2, h)       * 255),
            clamp(hueToRgb(m1, m2, h - 1/3) * 255)];
  },

  /** @private
    Returns the RGB value for a given hue.
   */
  hueToRgb: function (m1, m2, h) {
  // HOW TO RETURN hue.to.rgb(m1, m2, h):
    // IF h<0: PUT h+1 IN h
    if (h < 0) h++;
    // IF h>1: PUT h-1 IN h
    if (h > 1) h--;
    // IF h*6<1: RETURN m1+(m2-m1)*h*6
    if (h < 1/6) return m1 + (m2 - m1) * h * 6;
    // IF h*2<1: RETURN m2
    if (h < 1/2) return m2;
    // IF h*3<2: RETURN m1+(m2-m1)*(2/3-h)*6
    if (h < 2/3) return m1 + (m2 - m1) * (2/3 - h) * 6;
    // RETURN m1
    return m1;
  },

  /**
    Returns an RGB color transformed into the
    HSL colorspace as triple `(h, s, l)`.

    @param {Number} r The red component as an integer between 0 and 255.
    @param {Number} g The green component as an integer between 0 and 255.
    @param {Number} b The blue component as an integer between 0 and 255.
    @returns {Number[]} A HSL triple in the form `(h, s, l)`
      where `h` is in degrees (as a float) between 0° and 360° and
            `s` and `l` are percents between 0 and 1.
   */
  rgbToHsl: function (r, g, b) {
    r /= 255;
    g /= 255;
    b /= 255;

    var max = Math.max(r, g, b),
        min = Math.min(r, g, b),
        h, s, l = (max + min) / 2,
        d = max - min;

    // achromatic
    if (max === min) {
      h = s = 0;
    } else {
      s = l > 0.5
          ? d / (2 - max - min)
          : d / (max + min);

      switch (max) {
      case r:
        h = (g - b) / d + (g < b ? 6 : 0);
        break;
      case g:
        h = (b - r) / d + 2;
        break;
      case b:
        h = (r - g) / d + 4;
        break;
      }
      h /= 6;
    }
    h *= 360;

    return [h, s, l];
  },

  // ..........................................................
  // Regular expressions for accepted color types
  //
  PARSE_RGBA: /^rgba\(\s*([\d]+%?)\s*,\s*([\d]+%?)\s*,\s*([\d]+%?)\s*,\s*([.\d]+)\s*\)$/,
  PARSE_RGB : /^rgb\(\s*([\d]+%?)\s*,\s*([\d]+%?)\s*,\s*([\d]+%?)\s*\)$/,
  PARSE_HSLA: /^hsla\(\s*(-?[\d]+)\s*\s*,\s*([\d]+)%\s*,\s*([\d]+)%\s*,\s*([.\d]+)\s*\)$/,
  PARSE_HSL : /^hsl\(\s*(-?[\d]+)\s*,\s*([\d]+)%\s*,\s*([\d]+)%\s*\)$/,
  PARSE_HEX : /^#([0-9a-fA-F]{3}|[0-9a-fA-F]{6})$/,
  PARSE_ARGB: /^#[0-9a-fA-F]{8}$/,

  /**
    A mapping of anglicized colors to their hexadecimal
    representation.

    Computed by running the following code at http://www.w3.org/TR/css3-color

       var T = {}, color = null,
           colors = document.querySelectorAll('.colortable')[1].querySelectorAll('.c');

       for (var i = 0; i < colors.length; i++) {
         if (i % 4 === 0) {
           color = colors[i].getAttribute('style').split(':')[1];
         } else if (i % 4 === 1) {
           T[color] = colors[i].getAttribute('style').split(':')[1].toUpperCase();
         }
       }
       JSON.stringify(T);

    @see http://www.w3.org/TR/css3-color/#svg-color
   */
  KEYWORDS: {"aliceblue":"#F0F8FF","antiquewhite":"#FAEBD7","aqua":"#00FFFF","aquamarine":"#7FFFD4","azure":"#F0FFFF","beige":"#F5F5DC","bisque":"#FFE4C4","black":"#000000","blanchedalmond":"#FFEBCD","blue":"#0000FF","blueviolet":"#8A2BE2","brown":"#A52A2A","burlywood":"#DEB887","cadetblue":"#5F9EA0","chartreuse":"#7FFF00","chocolate":"#D2691E","coral":"#FF7F50","cornflowerblue":"#6495ED","cornsilk":"#FFF8DC","crimson":"#DC143C","cyan":"#00FFFF","darkblue":"#00008B","darkcyan":"#008B8B","darkgoldenrod":"#B8860B","darkgray":"#A9A9A9","darkgreen":"#006400","darkgrey":"#A9A9A9","darkkhaki":"#BDB76B","darkmagenta":"#8B008B","darkolivegreen":"#556B2F","darkorange":"#FF8C00","darkorchid":"#9932CC","darkred":"#8B0000","darksalmon":"#E9967A","darkseagreen":"#8FBC8F","darkslateblue":"#483D8B","darkslategray":"#2F4F4F","darkslategrey":"#2F4F4F","darkturquoise":"#00CED1","darkviolet":"#9400D3","deeppink":"#FF1493","deepskyblue":"#00BFFF","dimgray":"#696969","dimgrey":"#696969","dodgerblue":"#1E90FF","firebrick":"#B22222","floralwhite":"#FFFAF0","forestgreen":"#228B22","fuchsia":"#FF00FF","gainsboro":"#DCDCDC","ghostwhite":"#F8F8FF","gold":"#FFD700","goldenrod":"#DAA520","gray":"#808080","green":"#008000","greenyellow":"#ADFF2F","grey":"#808080","honeydew":"#F0FFF0","hotpink":"#FF69B4","indianred":"#CD5C5C","indigo":"#4B0082","ivory":"#FFFFF0","khaki":"#F0E68C","lavender":"#E6E6FA","lavenderblush":"#FFF0F5","lawngreen":"#7CFC00","lemonchiffon":"#FFFACD","lightblue":"#ADD8E6","lightcoral":"#F08080","lightcyan":"#E0FFFF","lightgoldenrodyellow":"#FAFAD2","lightgray":"#D3D3D3","lightgreen":"#90EE90","lightgrey":"#D3D3D3","lightpink":"#FFB6C1","lightsalmon":"#FFA07A","lightseagreen":"#20B2AA","lightskyblue":"#87CEFA","lightslategray":"#778899","lightslategrey":"#778899","lightsteelblue":"#B0C4DE","lightyellow":"#FFFFE0","lime":"#00FF00","limegreen":"#32CD32","linen":"#FAF0E6","magenta":"#FF00FF","maroon":"#800000","mediumaquamarine":"#66CDAA","mediumblue":"#0000CD","mediumorchid":"#BA55D3","mediumpurple":"#9370DB","mediumseagreen":"#3CB371","mediumslateblue":"#7B68EE","mediumspringgreen":"#00FA9A","mediumturquoise":"#48D1CC","mediumvioletred":"#C71585","midnightblue":"#191970","mintcream":"#F5FFFA","mistyrose":"#FFE4E1","moccasin":"#FFE4B5","navajowhite":"#FFDEAD","navy":"#000080","oldlace":"#FDF5E6","olive":"#808000","olivedrab":"#6B8E23","orange":"#FFA500","orangered":"#FF4500","orchid":"#DA70D6","palegoldenrod":"#EEE8AA","palegreen":"#98FB98","paleturquoise":"#AFEEEE","palevioletred":"#DB7093","papayawhip":"#FFEFD5","peachpuff":"#FFDAB9","peru":"#CD853F","pink":"#FFC0CB","plum":"#DDA0DD","powderblue":"#B0E0E6","purple":"#800080","red":"#FF0000","rosybrown":"#BC8F8F","royalblue":"#4169E1","saddlebrown":"#8B4513","salmon":"#FA8072","sandybrown":"#F4A460","seagreen":"#2E8B57","seashell":"#FFF5EE","sienna":"#A0522D","silver":"#C0C0C0","skyblue":"#87CEEB","slateblue":"#6A5ACD","slategray":"#708090","slategrey":"#708090","snow":"#FFFAFA","springgreen":"#00FF7F","steelblue":"#4682B4","tan":"#D2B48C","teal":"#008080","thistle":"#D8BFD8","tomato":"#FF6347","turquoise":"#40E0D0","violet":"#EE82EE","wheat":"#F5DEB3","white":"#FFFFFF","whitesmoke":"#F5F5F5","yellow":"#FFFF00","yellowgreen":"#9ACD32"},

  /**
    Parses any valid CSS color into a `SC.Color` object. Given invalid input, will return a
    `SC.Color` object in an error state (with isError: YES).

    @param {String} color The CSS color value to parse.
    @returns {SC.Color} The color object representing the color passed in.
   */
  from: function (color) {
    // Fast path: clone another color.
    if (SC.kindOf(color, SC.Color)) {
      return color.copy();
    }

    // Slow path: string
    var hash = SC.Color._parse(color),
        C = SC.Color;

    // Gatekeep: bad input.
    if (!hash) {
      return SC.Color.create({
        original: color,
        isError: YES
      });
    }

    return C.create({
      original: color,
      r: C.clampInt(hash.r, 0, 255),
      g: C.clampInt(hash.g, 0, 255),
      b: C.clampInt(hash.b, 0, 255),
      a: C.clamp(hash.a, 0, 1)
    });
  },

  /** @private
    Parses any valid CSS color into r, g, b and a values. Returns null for invalid inputs.

    For internal use only. External code should call `SC.Color.from` or `SC.Color#cssText`.

    @param {String} color The CSS color value to parse.
    @returns {Hash || null} A hash of r, g, b, and a values.
   */
  _parse: function (color) {
    var C = SC.Color,
        oColor = color,
        r, g, b, a = 1,
        percentOrDeviceGamut = function (value) {
          var v = parseInt(value, 10);
          return value.slice(-1) === "%"
                 ? C.clampInt(v * 2.55, 0, 255)
                 : C.clampInt(v, 0, 255);
        };

    if (C.KEYWORDS.hasOwnProperty(color)) {
      color = C.KEYWORDS[color];
    } else if (SC.none(color) || color === '') {
      color = 'transparent';
    }

    if (C.PARSE_RGB.test(color)) {
      color = color.match(C.PARSE_RGB);

      r = percentOrDeviceGamut(color[1]);
      g = percentOrDeviceGamut(color[2]);
      b = percentOrDeviceGamut(color[3]);

    } else if (C.PARSE_RGBA.test(color)) {
      color = color.match(C.PARSE_RGBA);

      r = percentOrDeviceGamut(color[1]);
      g = percentOrDeviceGamut(color[2]);
      b = percentOrDeviceGamut(color[3]);

      a = parseFloat(color[4], 10);

    } else if (C.PARSE_HEX.test(color)) {
      // The three-digit RGB notation (#rgb)
      // is converted into six-digit form (#rrggbb)
      // by replicating digits, not by adding zeros.
      if (color.length === 4) {
        color = '#' + color.charAt(1) + color.charAt(1)
                    + color.charAt(2) + color.charAt(2)
                    + color.charAt(3) + color.charAt(3);
      }

      r = parseInt(color.slice(1, 3), 16);
      g = parseInt(color.slice(3, 5), 16);
      b = parseInt(color.slice(5, 7), 16);

    } else if (C.PARSE_ARGB.test(color)) {
      r = parseInt(color.slice(3, 5), 16);
      g = parseInt(color.slice(5, 7), 16);
      b = parseInt(color.slice(7, 9), 16);

      a = parseInt(color.slice(1, 3), 16) / 255;

    } else if (C.PARSE_HSL.test(color)) {
      color = color.match(C.PARSE_HSL);
      color = C.hslToRgb(((parseInt(color[1], 10) % 360 + 360) % 360),
                         C.clamp(parseInt(color[2], 10) / 100, 0, 1),
                         C.clamp(parseInt(color[3], 10) / 100, 0, 1));

      r = color[0];
      g = color[1];
      b = color[2];

    } else if (C.PARSE_HSLA.test(color)) {
      color = color.match(C.PARSE_HSLA);

      a = parseFloat(color[4], 10);

      color = C.hslToRgb(((parseInt(color[1], 10) % 360 + 360) % 360),
                         C.clamp(parseInt(color[2], 10) / 100, 0, 1),
                         C.clamp(parseInt(color[3], 10) / 100, 0, 1));

      r = color[0];
      g = color[1];
      b = color[2];

    // See http://www.w3.org/TR/css3-color/#transparent-def
    } else if (color === "transparent") {
      r = g = b = 0;
      a = 0;

    } else {
      return null;
    }

    return {
      r: r,
      g: g,
      b: b,
      a: a
    };
  }
});

/* >>>>>>>>>> BEGIN source/system/device.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('system/core_query');
sc_require('system/ready');
sc_require('system/root_responder');
sc_require('system/platform');

SC.PORTRAIT_ORIENTATION = 'portrait';
SC.LANDSCAPE_ORIENTATION = 'landscape';
SC.NO_ORIENTATION = 'desktop'; // value 'desktop' for backwards compatibility

/**
  The device object allows you to check device specific properties such as
  orientation and if the device is offline, as well as observe when they change
  state.

  ## Orientation
  When a touch device changes orientation, the orientation property will be
  set accordingly which you can observe

  ## Offline support
  In order to build a good offline-capable web application, you need to know
  when your app has gone offline so you can for instance queue your server
  requests for a later time or provide a specific UI/message.

  Similarly, you also need to know when your application has returned to an
  'online' state again, so that you can re-synchronize with the server or do
  anything else that might be needed.

  By observing the 'isOffline' property you can be notified when this state
  changes. Note that this property is only connected to the navigator.onLine
  property, which is available on most modern browsers.

*/
SC.device = SC.Object.create({

  /**
    Sets the orientation for devices, either SC.LANDSCAPE_ORIENTATION
    or SC.PORTRAIT_ORIENTATION.

    @type String
    @default SC.PORTRAIT_ORIENTATION
  */
  orientation: SC.PORTRAIT_ORIENTATION,

  /**
    Indicates whether the device is currently online or offline. For browsers
    that do not support this feature, the default value is NO.

    Is currently inverse of the navigator.onLine property. Most modern browsers
    will update this property when switching to or from the browser's Offline
    mode, and when losing/regaining network connectivity.

    @type Boolean
    @default NO
  */
  isOffline: NO,

  /**
    Returns a Point containing the last known X and Y coordinates of the
    mouse, if present.

    @type Point
  */
  mouseLocation: function() {
    var responder = SC.RootResponder.responder,
        lastX = responder._lastMoveX,
        lastY = responder._lastMoveY;

    if (SC.empty(lastX) || SC.empty(lastY)) {
      return null;
    }

    return { x: lastX, y: lastY };
  }.property(),

  /**
    Initialize the object with some properties up front
  */
  init: function() {
    arguments.callee.base.apply(this,arguments);

    if (navigator && navigator.onLine === false) {
      this.set('isOffline', YES);
    }
  },

  /**
    As soon as the DOM is up and running, make sure we attach necessary
    event handlers
  */
  setup: function() {
    var responder = SC.RootResponder.responder;
    responder.listenFor(['online', 'offline'], window, this);

    this.orientationHandlingShouldChange();
  },

  // ..........................................................
  // ORIENTATION HANDLING
  //

  /**
    Determines which method to use for orientation changes.
    Either detects orientation changes via the current size
    of the window, or by the window.onorientationchange event.
  */
  orientationHandlingShouldChange: function() {
    if (SC.platform.windowSizeDeterminesOrientation) {
      SC.Event.remove(window, 'orientationchange', this, this.orientationchange);
      this.windowSizeDidChange(SC.RootResponder.responder.get('currentWindowSize'));
    } else if (SC.platform.supportsOrientationChange) {
      SC.Event.add(window, 'orientationchange', this, this.orientationchange);
      this.orientationchange();
    }
  },

  /**
    @param {Hash} newSize The new size of the window
    @returns YES if the method altered the orientation, NO otherwise
  */
  windowSizeDidChange: function(newSize) {
    if (SC.platform.windowSizeDeterminesOrientation) {
      if (newSize.height >= newSize.width) {
        SC.device.set('orientation', SC.PORTRAIT_ORIENTATION);
      } else {
        SC.device.set('orientation', SC.LANDSCAPE_ORIENTATION);
      }

      return YES;
    }
    return NO;
  },

  /**
    Called when the window.onorientationchange event is fired.
  */
  orientationchange: function(evt) {
    SC.run(function() {
      if (window.orientation === 0 || window.orientation === 180) {
        SC.device.set('orientation', SC.PORTRAIT_ORIENTATION);
      } else {
        SC.device.set('orientation', SC.LANDSCAPE_ORIENTATION);
      }
    });
  },

  /** @private */
  orientationObserver: function () {
    var body = SC.$(document.body),
        orientation = this.get('orientation');

    if (orientation === SC.PORTRAIT_ORIENTATION) {
      body.addClass('sc-portrait');
    } else {
      body.removeClass('sc-portrait');
    }

    if (orientation === SC.LANDSCAPE_ORIENTATION) {
      body.addClass('sc-landscape');
    } else {
      body.removeClass('sc-landscape');
    }
  }.observes('orientation'),


  // ..........................................................
  // CONNECTION HANDLING
  //

  online: function(evt) {
    SC.run(function () {
      this.set('isOffline', NO);
    }, this);
  },

  offline: function(evt) {
    SC.run(function () {
      this.set('isOffline', YES);
    }, this);
  }

});

/*
  Invoked when the document is ready, but before main is called.  Creates
  an instance and sets up event listeners as needed.
*/
SC.ready(function() {
  SC.device.setup();
});

/* >>>>>>>>>> BEGIN source/system/key_bindings.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


// Key Bindings are used to map a keyboard input to an action message on a
// responder.  These bindings are most useful when implementing sophisticated
// keyboard input mechanisms.  For keyboard shortcuts, instead use menus, etc.

SC.MODIFIED_KEY_BINDINGS = {
  'ctrl_.': 'cancel',
  'shift_tab': 'insertBacktab',
  'shift_left': 'moveLeftAndModifySelection',
  'shift_right': 'moveRightAndModifySelection',
  'shift_up': 'moveUpAndModifySelection',
  'shift_down': 'moveDownAndModifySelection',
  'alt_left': 'moveLeftAndModifySelection',
  'alt_right': 'moveRightAndModifySelection',
  'alt_up': 'moveUpAndModifySelection',
  'alt_down': 'moveDownAndModifySelection',
  'ctrl_a': 'selectAll'
} ;

SC.BASE_KEY_BINDINGS = {
  'escape': 'cancel',
  'backspace': 'deleteBackward',
  'delete': 'deleteForward',
  'return': 'insertNewline',
  'tab': 'insertTab',
  'left': 'moveLeft',
  'right': 'moveRight',
  'up': 'moveUp',
  'down': 'moveDown',
  'home': 'moveToBeginningOfDocument',
  'end': 'moveToEndOfDocument',
  'pagedown': 'pageDown',
  'pageup': 'pageUp'
} ;


/* >>>>>>>>>> BEGIN source/system/page.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @class SC.Page

  A Page object is used to store a set of views that can be lazily configured
  as needed.  The page object works by overloading the get() method.  The
  first time you try to get the page
  
  @extends SC.Object
*/
SC.Page = SC.Object.extend(
/** @scope SC.Page.prototype */ {
  
  /**
    When you create a page, you can set it's "owner" property to an
    object outside the page definition. This allows views in the page
    to use the owner object as a target, (as well as other objects
    accessible through the owner object). E.g.
    
        myButton: SC.ButtonView.design({
          title: 'Click me',
          target: SC.outlet('page.owner'),
          action: 'buttonClicked'
        })
    
    Usually, you'll set 'owner' to the object defined in core.js.
  */
  owner: null,
  
  get: function(key) {
    var value = this[key] ;
    if (value && value.isClass) {
      this[key] = value = value.create({ page: this }) ;
      return value ;
    } else return arguments.callee.base.apply(this,arguments);
  },

  /**
    Returns the named property unless the property is a view that has not yet
    been configured.  In that case it will return undefined.  You can use this
    method to safely get a view without waking it up.
  */
  getIfConfigured: function(key) {
    var ret = this[key] ;
    return (ret && ret.isViewClass) ? null : this.get(key);
  },

  /**
    Applies a localization to every view builder defined on the page.  You must call this before you construct a view to apply the localization.
  */
  loc: function(locs) {
    var view, key;
    for(key in locs) {
      if (!locs.hasOwnProperty(key)) continue ;
      view = this[key] ;
      if (!view || !view.isViewClass) continue ;
      view.loc(locs[key]);
    }
    return this ;
  }

  //needsDesigner: YES,
  
  //inDesignMode: YES
    
}) ;

// ..........................................................
// SUPPORT FOR LOADING PAGE DESIGNS
// 

/** Calling design() on a page is the same as calling create() */
SC.Page.design = SC.Page.create ;

/** Calling localization returns passed attrs. */
SC.Page.localization = function(attrs) { return attrs; };



/* >>>>>>>>>> BEGIN source/system/render_context.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('system/builder');

/** set update mode on context to replace content (preferred) */
SC.MODE_REPLACE = 'replace';

/** set update mode on context to append content */
SC.MODE_APPEND = 'append';

/** set update mode on context to prepend content */
SC.MODE_PREPEND = 'prepend';

/** list of numeric properties that should not have 'px' appended */
SC.NON_PIXEL_PROPERTIES = ['zIndex', 'opacity'];

/** a list of styles that get expanded into multiple properties, add more as you discover them */
SC.COMBO_STYLES = {
  WebkitTransition: ['WebkitTransitionProperty', 'WebkitTransitionDuration', 'WebkitTransitionDelay', 'WebkitTransitionTimingFunction']
};

/**
  @namespace

  A RenderContext is a builder that can be used to generate HTML for views or
  to update an existing element.  Rather than making changes to an element
  directly, you use a RenderContext to queue up changes to the element,
  finally applying those changes or rendering the new element when you are
  finished.

  You will not usually create a render context yourself but you will be passed
  a render context as the first parameter of your render() method on custom
  views.

  Render contexts are essentially arrays of strings.  You can add a string to
  the context by calling push().  You can retrieve the entire array as a
  single string using join().  This is basically the way the context is used
  for views.  You are passed a render context and expected to add strings of
  HTML to the context like a normal array.  Later, the context will be joined
  into a single string and converted into real HTML for display on screen.

  In addition to the core push and join methods, the render context also
  supports some extra methods that make it easy to build tags.

  context.begin() <-- begins a new tag context
  context.end() <-- ends the tag context...
*/
SC.RenderContext = SC.Builder.create(
  /** @lends SC.RenderContext */ {

  SELF_CLOSING: SC.CoreSet.create().addEach(['area', 'base', 'basefront', 'br', 'hr', 'input', 'img', 'link', 'meta']),

  /**
    When you create a context you should pass either a tag name or an element
    that should be used as the basis for building the context.  If you pass
    an element, then the element will be inspected for class names, styles
    and other attributes.  You can also call update() or replace() to
    modify the element with you context contents.

    If you do not pass any parameters, then we assume the tag name is 'div'.

    A second parameter, parentContext, is used internally for chaining.  You
    should never pass a second argument.

    @param {String|DOMElement} tagNameOrElement
    @returns {SC.RenderContext} receiver
  */
  init: function (tagNameOrElement, prevContext) {
    var tagNameOrElementIsString;

    // if a prevContext was passed, setup with that first...
    if (prevContext) {
      this.prevObject = prevContext;
      this.strings    = prevContext.strings;
      this.offset     = prevContext.length + prevContext.offset;
    }

    if (!this.strings) this.strings = [];

    // if tagName is string, just setup for rendering new tagName
    if (tagNameOrElement === undefined) {
      tagNameOrElement = 'div';
      tagNameOrElementIsString = YES;
    }
    else if (tagNameOrElement === 'div'  ||  tagNameOrElement === 'label'  ||  tagNameOrElement === 'a') {
      // Fast path for common tags.
      tagNameOrElementIsString = YES;
    }
    else if (SC.typeOf(tagNameOrElement) === SC.T_STRING) {
      tagNameOrElement = tagNameOrElement.toLowerCase();
      tagNameOrElementIsString = YES;
    }

    if (tagNameOrElementIsString) {
      this._tagName     = tagNameOrElement;
      this._needsTag    = YES; // used to determine if end() needs to wrap tag
      this.needsContent = YES;

      // increase length of all contexts to leave space for opening tag
      var c = this;
      while (c) { c.length++; c = c.prevObject; }

      this.strings.push(null);
      this._selfClosing = this.SELF_CLOSING.contains(tagNameOrElement);
    } else {
      this._elem        = tagNameOrElement;
      this._needsTag    = NO;
      this.length       = 0;
      this.needsContent = NO;
    }
    return this;
  },

  // ..........................................................
  // PROPERTIES
  //

  // NOTE: We store this as an actual array of strings so that browsers that
  // support dense arrays will use them.
  /**
    The current working array of strings.

    @type Array
  */
  strings: null,

  /**
    this initial offset into the strings array where this context instance
    has its opening tag.

    @type Number
  */
  offset: 0,

  /**
    the current number of strings owned by the context, including the opening
    tag.

    @type Number
  */
  length: 0,

  /**
    Specify the method that should be used to update content on the element.
    In almost all cases you want to replace the content.  Very carefully
    managed code (such as in CollectionView) can append or prepend content
    instead.

    You probably do not want to change this property unless you know what you
    are doing.

    @type String
  */
  updateMode: SC.MODE_REPLACE,

  /**
    YES if the context needs its content filled in, not just its outer
    attributes edited.  This will be set to YES anytime you push strings into
    the context or if you don't create it with an element to start with.
  */
  needsContent: NO,

  // ..........................................................
  // CORE STRING API
  //

  /**
    Returns the string at the designated index.  If you do not pass anything
    returns the string array.  This index is an offset from the start of the
    strings owned by this context.

    @param {Number} idx the index
    @returns {String|Array}
  */
  get: function (idx) {
    var strings = this.strings || [];
    return (idx === undefined) ? strings.slice(this.offset, this.length) : strings[idx + this.offset];
  },

  /** @deprecated */
  html: function (line) {
    

    return this.push(line);
  },

  /**
    Adds a string to the render context for later joining and insertion.  To
    HTML escape the string, see the similar text() method instead.

    Note: You can pass multiple string arguments to this method and each will
    be pushed.

    When used in render() for example,

        MyApp.MyView = SC.View.extend({

          innerText: '',

          render: function (context) {
            var innerText = this.get('innerText');

            // This will be pushed into the DOM all at once.
            context.push('<div class="inner-div">', innerText, '<span class="inner-span">**</span></div>');
          }

        });

    @param {String} line the HTML to add to the context
    @returns {SC.RenderContext} receiver
  */
  push: function (line) {
    var strings = this.strings, len = arguments.length;
    if (!strings) this.strings = strings = []; // create array lazily

    if (len > 1) {
      strings.push.apply(strings, arguments);
    } else {
      strings.push(line);
    }

    // adjust string length for context and all parents...
    var c = this;
    while (c) { c.length += len; c = c.prevObject; }

    this.needsContent = YES;

    return this;
  },

  /**
    Pushes the passed string to the render context for later joining and
    insertion, but first escapes the string to ensure that no user-entered HTML
    is processed as HTML.  To push the string without escaping, see the similar
    push() method instead.

    Note: You can pass multiple string arguments to this method and each will
    be escaped and pushed.

    When used in render() for example,

        MyApp.MyView = SC.View.extend({

          userText: '<script src="http://maliciousscripts.com"></script>',

          render: function (context) {
            var userText = this.get('userText');

            // Pushes "&lt;script src="http://maliciousscripts.com"&gt;&lt;/script&gt;" in the DOM
            context.text(userText);
          }

        });

    @param {String} line the text to add to the context
    @returns {SC.RenderContext} receiver
  */
  text: function () {
    var len = arguments.length,
      idx = 0;

    for (idx = 0; idx < len; idx++) {
      this.push(SC.RenderContext.escapeHTML(arguments[idx]));
    }

    return this;
  },

  /**
    Joins the strings together, closes any open tags and returns the final result.

    @param {String} joinChar optional string to use in joins. def empty string
    @returns {String} joined string
  */
  join: function (joinChar) {
    // generate tag if needed...
    if (this._needsTag) this.end();

    var strings = this.strings;
    return strings ? strings.join(joinChar || '') : '';
  },

  // ..........................................................
  // GENERATING
  //

  /**
    Begins a new render context based on the passed tagName or element.
    Generate said context using end().

    @returns {SC.RenderContext} new context
  */
  begin: function (tagNameOrElement) {
    return SC.RenderContext(tagNameOrElement, this);
  },

  /**
    If the current context targets an element, this method returns the
    element.  If the context does not target an element, this method will
    render the context into an offscreen element and return it.

    @returns {DOMElement} the element
  */
  element: function () {
    return this._elem ? this._elem : SC.$(this.join())[0];
  },

  /**
    Removes an element with the passed id in the currently managed element.
  */
  remove: function (elementId) {
    if (!elementId) return;

    var el, elem = this._elem;
    if (!elem || !elem.removeChild) return;

    el = document.getElementById(elementId);
    if (el) {
      el = elem.removeChild(el);
      el = null;
    }
  },

  /**
    If an element was set on this context when it was created, this method
    will actually apply any changes to the element itself.  If you have not
    written any inner html into the context, then the innerHTML of the
    element will not be changed, otherwise it will be replaced with the new
    innerHTML.

    Also, any attributes, id, classNames or styles you've set will be
    updated as well.  This also ends the editing context session and cleans
    up.

    @returns {SC.RenderContext} previous context or null if top
  */
  update: function () {
    var elem = this._elem,
        mode = this.updateMode,
        cq, value, factory, cur, next;

    // this._innerHTMLReplaced = NO;

    if (!elem) {
      // throw new Error("Cannot update context because there is no source element");
      return;
    }

    cq = this.$();

    // replace innerHTML
    if (this.length > 0) {
      // this._innerHTMLReplaced = YES;
      if (mode === SC.MODE_REPLACE) {
        cq.html(this.join());
      } else {
        factory = elem.cloneNode(false);
        factory.innerHTML = this.join();
        cur = factory.firstChild;
        while (cur) {
          next = cur.nextSibling;
          elem.insertBefore(cur, next);
          cur = next;
        }
        cur = next = factory = null; // cleanup
      }
    }

    // attributes, styles, and class names will already have been set.

    // id="foo"
    if (this._idDidChange && (value = this._id)) {
      cq.attr('id', value);
    }

    // now cleanup element...
    elem = this._elem = null;
    return this.prevObject || this;
  },

  // these are temporary objects are reused by end() to avoid memory allocs.
  _DEFAULT_ATTRS: {},

  /**
    Ends the current tag editing context.  This will generate the tag string
    including any attributes you might have set along with a closing tag.

    The generated HTML will be added to the render context strings.  This will
    also return the previous context if there is one or the receiver.

    If you do not have a current tag, this does nothing.

    @returns {SC.RenderContext}
  */
  end: function () {
    // NOTE: If you modify this method, be careful to consider memory usage
    // and performance here.  This method is called frequently during renders
    // and we want it to be as fast as possible.

    // generate opening tag.

    // get attributes first.  Copy in className + styles...
    var tag = '', styleStr = '', key, value,
        attrs = this._attrs, className = this._classes,
        id = this._id, styles = this._styles, strings, selfClosing;

    // add tag to tag array
    tag = '<' + this._tagName;

    // add any attributes...
    if (attrs || className || styles || id) {
      if (!attrs) attrs = this._DEFAULT_ATTRS;
      if (id) attrs.id = id;
      // old versions of safari (5.0)!!!! throw an error if we access
      // attrs.class. meh...
      if (className) attrs['class'] = className.join(' ');

      // add in styles.  note how we avoid memory allocs here to keep things
      // fast...
      if (styles) {
        for (key in styles) {
          if (!styles.hasOwnProperty(key)) continue;
          value = styles[key];
          if (value === null) continue; // skip empty styles
          if (typeof value === SC.T_NUMBER && !SC.NON_PIXEL_PROPERTIES.contains(key)) value += "px";
          styleStr = styleStr + this._dasherizeStyleName(key) + ": " + value + "; ";
        }
        attrs.style = styleStr;
      }

      // now convert attrs hash to tag array...
      tag = tag + ' '; // add space for joining0
      for (key in attrs) {
        if (!attrs.hasOwnProperty(key)) continue;
        value = attrs[key];
        if (value === null) continue; // skip empty attrs
        tag = tag + key + '="' + value + '" ';
      }

      // if we are using the DEFAULT_ATTRS temporary object, make sure we
      // reset.
      if (attrs === this._DEFAULT_ATTRS) {
        delete attrs.style;
        delete attrs['class'];
        delete attrs.id;
      }

    }

    // this is self closing if there is no content in between and selfClosing
    // is not set to false.
    strings = this.strings;
    selfClosing = (this._selfClosing === NO) ? NO : (this.length === 1);
    tag = tag + (selfClosing ? ' />' : '>');

    strings[this.offset] = tag;

    // now generate closing tag if needed...
    if (!selfClosing) {
      strings.push('</' + this._tagName + '>');

      // increase length of receiver and all parents
      var c = this;
      while (c) { c.length++; c = c.prevObject; }
    }

    // if there was a source element, cleanup to avoid memory leaks
    this._elem = null;
    return this.prevObject || this;
  },

  /**
    Generates a tag with the passed options.  Like calling context.begin().end().

    @param {String} tagName optional tag name.  default 'div'
    @param {Hash} opts optional tag options.  defaults to empty options.
    @returns {SC.RenderContext} receiver
  */
  tag: function (tagName, opts) {
    return this.begin(tagName, opts).end();
  },

  // ..........................................................
  // BASIC HELPERS
  //

  /**
    Reads outer tagName if no param is passed, sets tagName otherwise.

    @param {String} tagName pass to set tag name.
    @returns {String|SC.RenderContext} tag name or receiver
  */
  tagName: function (tagName) {
    if (tagName === undefined) {
      if (!this._tagName && this._elem) this._tagName = this._elem.tagName;
      return this._tagName;
    } else {
      this._tagName = tagName;
      this._tagNameDidChange = YES;
      return this;
    }
  },

  /**
    Reads the outer tag id if no param is passed, sets the id otherwise.

    @param {String} idName the id or set
    @returns {String|SC.RenderContext} id or receiver
  */
  id: function (idName) {
    if (idName === undefined) {
      if (!this._id && this._elem) this._id = this._elem.id;
      return this._id;
    } else {
      this._id = idName;
      this._idDidChange = YES;
      return this;
    }
  },

  // ..........................................................
  // CSS CLASS NAMES SUPPORT
  //

  /** @deprecated */
  classNames: function (deprecatedArg) {
    if (deprecatedArg) {
      

      return this.setClass(deprecatedArg);
    } else {
      

      return this.classes();
    }
  },

  /**
    Retrieves the class names for the current context.

    @returns {Array} classNames array
  */
  classes: function () {
    if (!this._classes) {
      if (this._elem) {
        // Get the classes from the element.
        var attr = this.$().attr('class');

        if (attr && (attr = attr.toString()).length > 0) {
          this._classes = attr.split(/\s/);
        } else {
          // No class on the element.
          this._classes = [];
        }
      } else {
        this._classes = [];
      }
    }

    return this._classes;
  },

  /**
    Adds a class or classes to the current context.

    This is a convenience method that simply calls setClass(nameOrClasses, YES).

    @param {String|Array} nameOrClasses a class name or an array of class names
    @returns {SC.RenderContext} receiver
  */
  addClass: function (nameOrClasses) {
    // Convert arrays into objects for use by setClass
    if (SC.typeOf(nameOrClasses) === SC.T_ARRAY) {
      for (var i = 0, length = nameOrClasses.length, obj = {}; i < length; i++) {
        obj[nameOrClasses[i]] = YES;
      }
      nameOrClasses = obj;
    }

    return this.setClass(nameOrClasses, YES);
  },

  /**
    Removes the specified class name from the current context.

    This is a convenience method that simply calls setClass(name, NO).

    @param {String} name the class to remove
    @returns {SC.RenderContext} receiver
  */
  removeClass: function (name) {
    return this.setClass(name, NO);
  },

  /**
    Sets or unsets class names on the current context.

    You can either pass a single class name and a boolean indicating whether
    the value should be added or removed, or you can pass a hash with all
    the class names you want to add or remove with a boolean indicating
    whether they should be there or not.

    When used in render() for example,

        MyApp.MyView = SC.View.extend({

          isAdministrator: NO,

          render: function (context) {
            var isAdministrator = this.get('isAdministrator');

            // Sets the 'is-admin' class appropriately.
            context.setClass('is-admin', isAdministrator);
          }

        });

    @param {String|Hash} nameOrClasses either a single class name or a hash of class names with boolean values indicating whether to add or remove the class
    @param {Boolean} shouldAdd if a single class name for nameOrClasses is passed, this
    @returns {SC.RenderContext} receiver
  */
  setClass: function (nameOrClasses, shouldAdd) {
    var didChange = NO,
      classes = this.classes();

    // Add the updated classes to the internal classes object.
    if (SC.typeOf(nameOrClasses) === SC.T_ARRAY) {
      

      this.resetClasses();
      classes = this.classes();

      for (var i = 0, length = nameOrClasses.length; i < length; i++) {
        didChange = this._setClass(classes, nameOrClasses[i], YES) || didChange;
      }
    } else if (SC.typeOf(nameOrClasses) === SC.T_HASH) {
      for (var name in nameOrClasses) {
        if (!nameOrClasses.hasOwnProperty(name)) continue;

        shouldAdd = nameOrClasses[name];
        didChange = this._setClass(classes, name, shouldAdd) || didChange;
      }
    } else {
      didChange = this._setClass(classes, nameOrClasses, shouldAdd);
    }

    if (didChange) {
      this._classesDidChange = YES;

      // Apply the styles to the element if we have one already.
      if (this._elem) {
        this.$().attr('class', classes.join(' '));
      }
    }

    return this;
  },

  /** @private */
  _setClass: function (classes, name, shouldAdd) {
    var didChange = NO,
      idx;

    idx = classes.indexOf(name);
    if (idx >= 0 && !shouldAdd) {
      classes.splice(idx, 1);
      didChange = YES;
    } else if (idx < 0 && shouldAdd) {
      classes.push(name);
      didChange = YES;
    }

    return didChange;
  },

  /**
    Returns YES if the outer tag current has the passed class name, NO
    otherwise.

    @param {String} name the class name
    @returns {Boolean}
  */
  hasClass: function (name) {
    if (this._elem) {
      return this.$().hasClass(name);
    }

    return this.classes().indexOf(name) >= 0;
  },

  /** @deprecated */
  resetClassNames: function () {
    

    return this.resetClasses();
  },

  /**
    Removes all class names from the context.

    Be aware that setClass() only effects the class names specified.  If there
    are existing class names that are not modified by a call to setClass(), they
    will remain on the context.  For example, if you call addClass('a') and
    addClass('b') followed by setClass({ b:NO }), the 'b' class will be
    removed, but the 'a' class will be unaffected.

    If you want to call setClass() or addClass() to replace all classes, you
    should call this method first.

    @returns {SC.RenderContext} receiver
  */
  resetClasses: function () {
    var didChange = NO,
      classes = this.classes();

    // Check for changes.
    didChange = classes.length;

    // Reset.
    this._classes = [];
    if (didChange) {
      this._classesDidChange = YES;

      // Apply the styles to the element if we have one already.
      if (this._elem) {
        this.$().attr('class', '');
      }
    }

    return this;
  },

  // ..........................................................
  // CSS Styles Support
  //

  /** @private */
  _STYLE_REGEX: /-?\s*([^:\s]+)\s*:\s*([^;]+)\s*;?/g,

  /**
    Retrieves the current styles for the context.

    @returns {Object} styles hash
  */
  styles: function (deprecatedArg) {
    // Fast path!
    if (deprecatedArg) {
      

      return this.setStyle(deprecatedArg);
    }

    if (!this._styles) {
      if (this._elem) {
        // Get the styles from the element.
        var attr = this.$().attr('style');

        if (attr && (attr = attr.toString()).length > 0) {
          // Ensure attributes are lower case for IE
          if (SC.browser.name === SC.BROWSER.ie) {
            attr = attr.toLowerCase();
          }
          var styles = {},
            match,
            regex = this._STYLE_REGEX;

          regex.lastIndex = 0;
          while (match = regex.exec(attr)) {
            styles[this._camelizeStyleName(match[1])] = match[2];
          }

          this._styles = styles;
        } else {
          // No style on the element.
          this._styles = {};
        }
      } else {
        this._styles = {};
      }
    }

    return this._styles;
  },

  /**
    Adds the specified style to the current context.

    This is a convenience method that simply calls setStyle(nameOrStyles, value).

    @param {String|Object} nameOrStyles the name of a style or a hash of style names with values
    @param {String|Number} value style value if a single style name for nameOrStyles is passed
    @returns {SC.RenderContext} receiver
  */
  addStyle: function (nameOrStyles, value) {
    

    return this.setStyle(nameOrStyles, value);
  },

  /**
    Removes the specified style from the current context.

    This is a convenience method that simply calls setStyle(name, undefined).

    @param {String} styleName the name of the style to remove
    @returns {SC.RenderContext} receiver
  */
  removeStyle: function (styleName) {
    return this.setStyle(styleName);
  },

  /** @deprecated */
  css: function (nameOrStyles, value) {
    

    return this.setStyle(nameOrStyles, value);
  },

  /**
    Sets or unsets a style or styles on the context.

    Passing a value will set the value for the given style name, passing a null
    or undefined value will unset any current value for the given style name and
    remove it.

    Be aware that setStyle() only effects the styles specified.  If there
    are existing styles that are not modified by a call to setStyle(), they
    will remain on the context.  For example, if you call addStyle('margin-left', 10)
    and addStyle('margin-right', 10) followed by setClass({ 'margin-right': null }),
    the 'margin-right' style will be removed, but the 'margin-left' style will
    be unaffected.

    If you want to call setStyle() or addStyle() to replace all styles, you
    should call resetStyles() method first.

    When used in render() for example,

        MyApp.MyView = SC.View.extend({

          textColor: 'blue',

          // By default this syle will not appear since the value is null.
          fontFamily: null,

          render: function (context) {
            var textColor = this.get('textColor'),
              fontFamily = this.get('fontFamily');

            // Set the `color` and `fontFamily` styles.
            context.setStyle({
              color: textColor,
              fontFamily: fontFamily
            });
          }
        });

    @param {String|Object} nameOrStyles the name of a style or a hash of style names with values
    @param {String|Number} [value] style value if a single style name for nameOrStyles is passed
    @returns {SC.RenderContext} receiver
  */
  setStyle: function (nameOrStyles, value) {
    var didChange = NO,
      styles = this.styles();

    // Add the updated styles to the internal styles object.
    if (SC.typeOf(nameOrStyles) === SC.T_HASH) {
      for (var key in nameOrStyles) {
        // Call a separate function so that it may be optimized.
        didChange = this._sc_setStyleFromObject(didChange, key, nameOrStyles, styles);
      }
    } else {
      didChange = this._deleteComboStyles(styles, nameOrStyles);
      didChange = this._setOnHash(styles, nameOrStyles, value) || didChange;
    }

    // Set the styles on the element if we have one already.
    if (didChange && this._elem) {
      // Note: jQuery .css doesn't remove old styles
      this.$().css(styles);
    }

    return this;
  },

  /** @private Sets the style by key from the styles object. This allows for optimization outside of the for..in loop. */
  _sc_setStyleFromObject: function (didChange, key, stylesObject, styles) {
    if (!stylesObject.hasOwnProperty(key)) return false;

    var value = stylesObject[key];

    didChange = this._deleteComboStyles(styles, key) || didChange;
    didChange = this._setOnHash(styles, key, value) || didChange;

    return didChange;
  },

  /** @private */
  _deleteComboStyles: function (styles, key) {
    var comboStyles = SC.COMBO_STYLES[key],
        didChange = NO, tmp;

    if (comboStyles) {
      for (var idx = 0, idxLen = comboStyles.length; idx < idxLen; idx++) {
        tmp = comboStyles[idx];
        if (styles[tmp]) {
          delete styles[tmp];
          didChange = YES;
        }
      }
    }

    return didChange;
  },

  /** @private Sets or unsets the key:value on the hash and returns whether a change occurred. */
  _setOnHash: function (hash, key, value) {
    var cur = hash[key],
      didChange = true;

    /*jshint eqnull:true */
    if (cur == null && value != null) {
      hash[key] = value;
    } else if (cur != null && value == null) {
      // Unset using '' so that jQuery will remove the value, null is not reliable (ex. WebkitTransform)
      hash[key] = '';
    } else if (cur != value) {
      hash[key] = value;
    } else {
      didChange = false;
    }

    return didChange;
  },

  /**
    Removes all styles from the context.

    Be aware that setStyle() only affects the styles specified.  If there
    are existing styles that are not modified by a call to setStyle(), they
    will remain on the context.  For example, if you call addStyle('margin-left', 10)
    and addStyle('margin-right', 10) followed by setClass({ 'margin-right': null }),
    the 'margin-right' style will be removed, but the 'margin-left' style will
    be unaffected.

    If you want to call setStyle() or addStyle() to replace all styles, you
    should call this method first.

    @returns {SC.RenderContext} receiver
   */
  resetStyles: function () {
    var didChange = NO,
      styles = this.styles();

    // Check for changes (i.e. are there any properties in the object).
    for (var key in styles) {
      if (!styles.hasOwnProperty(key)) continue;

      didChange = YES;
    }

    // Reset.
    this._styles = {};
    if (didChange) {
      // Apply the styles to the element if we have one already.
      if (this._elem) {
        this.$().attr('style', '');
      }
    }

    return this;
  },

  // ..........................................................
  // ARBITRARY ATTRIBUTES SUPPORT
  //

  /**
    Retrieves the current attributes for the context, less the class and style
    attributes.

    If you retrieve the attributes hash to edit it, you must pass the hash back
    to setAttr in order for it to be applied to the element on rendering.

    Use classes() or styles() to get those specific attributes.

    @returns {Object} attributes hash
  */
  attrs: function () {
    if (!this._attrs) {
      if (this._elem) {
        // Get the attributes from the element.
        var attrs = {},
          elAttrs = this._elem.attributes,
          length = elAttrs.length;

        for (var i = 0, attr, name; i < length; i++) {
          attr = elAttrs.item(i);
          name = attr.nodeName;
          if (name.match(/^(?!class|style).*$/i)) {
            attrs[name] = attr.value;
          }
        }

        this._attrs = attrs;
      } else {
        this._attrs = {};
      }
    }

    return this._attrs;
  },

  /** @deprecated */
  attr: function (nameOrAttrs, value) {
    // Fast path.
    if (nameOrAttrs) {

      if (SC.typeOf(nameOrAttrs) === SC.T_HASH || value !== undefined) {
        

        return this.setAttr(nameOrAttrs, value);
      } else {
        

        return this.attrs()[nameOrAttrs];
      }
    }
    


    return this.attrs();
  },

  /**
    Adds the specified attribute to the current context.

    This is a convenience method that simply calls setAttr(nameOrAttrs, value).

    @param {String|Object} nameOrAttrs the name of an attribute or a hash of attribute names with values
    @param {String|Number} value attribute value if a single attribute name for nameOrAttrs is passed
    @returns {SC.RenderContext} receiver
  */
  addAttr: function (nameOrAttrs, value) {
    

    return this.setAttr(nameOrAttrs, value);
  },

  /**
    Removes the specified attribute from the current context.

    This is a convenience method that simply calls setAttr(name, undefined).

    @param {String} styleName the name of the attribute to remove
    @returns {SC.RenderContext} receiver
  */
  removeAttr: function (name) {
    


    return this.setAttr(name);
  },

  /**
    Sets or unsets an attribute or attributes on the context.  Passing a value
    will set the value for the given attribute name, passing a null or undefined
    value will unset any current value for the given attribute name and remove
    it.

    When used in render() for example,

        MyApp.MyView = SC.View.extend({

          // By default this syle will not appear since the value is null.
          title: null,

          render: function (context) {
            var title = this.get('title');

            // Set the `title` and `data-test` attributes.
            context.setAttr({
              title: title,
              'data-test': SC.buildMode === 'test'
            });
          }
        });

    @param {String|Object} nameOrAttrs the name of an attribute or a hash of attribute names with values
    @param {String} [value] attribute value if a single attribute name for nameOrAttrs is passed
    @returns {SC.RenderContext} receiver
  */
  setAttr: function (nameOrAttrs, value) {
    var didChange = NO,
      attrs = this.attrs(),
      key;

    


    // Add the updated attrs to the internal attrs object.
    if (SC.typeOf(nameOrAttrs) === SC.T_HASH) {
      for (key in nameOrAttrs) {
        if (!nameOrAttrs.hasOwnProperty(key)) continue;

        value = nameOrAttrs[key];
        didChange = this._setOnHash(attrs, key, value) || didChange;
      }
    } else {
      didChange = this._setOnHash(attrs, nameOrAttrs, value);
    }

    if (didChange) {
      this._attrsDidChange = YES;

      // Apply the attrs to the element if we have one already.
      if (this._elem) {
        this.$().attr(nameOrAttrs, value);
      }
    }

    return this;
  },

  //
  // COREQUERY SUPPORT
  //
  /**
    Returns a CoreQuery instance for the element this context wraps (if
    it wraps any). If a selector is passed, the CoreQuery instance will
    be for nodes matching that selector.

    Renderers may use this to modify DOM.
   */
  $: function (sel) {
    var ret, elem = this._elem;
    ret = !elem ? SC.$([]) : (sel === undefined) ? SC.$(elem) : SC.$(sel, elem);
    elem = null;
    return ret;
  },


  /** @private
  */
  _camelizeStyleName: function (name) {
    // IE wants the first letter lowercase so we can allow normal behavior
    var needsCap = name.match(/^-(webkit|moz|o)-/),
        camelized = SC.String.camelize(name);

    if (needsCap) {
      return camelized.substr(0, 1).toUpperCase() + camelized.substr(1);
    } else {
      return camelized;
    }
  },

  /** @private
    Converts camelCased style names to dasherized forms
  */
  _dasherizeStyleName: function (name) {
    var dasherized = SC.String.dasherize(name);
    if (dasherized.match(/^(webkit|moz|ms|o)-/)) { dasherized = '-' + dasherized; }
    return dasherized;
  }

});

(function () {
  // this regex matches all <, > or &, unless & is immediately followed by at last 1 up to 7 alphanumeric
  // characters and a ;. For instance:
  // Some evil <script src="evil.js"> but this is legal &amp; these are not & &illegalese;
  // would become:
  // Some evil &lt;script src="evil.js"&gt; but this is legal &amp; these are not &amp; &amp;illegalese;
  var _escapeHTMLRegex = /[<>]|&(?![\d\w#]{1,7};)/g, _escapeHTMLMethod = function (match) {
    switch (match) {
    case '&':
      return '&amp;';
    case '<':
      return '&lt;';
    case '>':
      return '&gt;';
    }
  };

  /**
    Helper method escapes the passed string to ensure HTML is displayed as
    plain text while preserving HTML entities like &apos; , &agrave;, etc.
    You should make sure you pass all user-entered data through
    this method to avoid errors.  You can also do this with the text() helper
    method on a render context.

    @param {String|Number} text value to escape
    @returns {String} string with all HTML values properly escaped
  */
  SC.RenderContext.escapeHTML = function (text) {
    if (!text) return '';
    if (SC.typeOf(text) === SC.T_NUMBER) { text = text.toString(); }
    return text.replace(_escapeHTMLRegex, _escapeHTMLMethod);
  };
})();

/* >>>>>>>>>> BEGIN source/system/selection_set.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/** @class

  A SelectionSet contains a set of objects that represent the current
  selection.  You can select objects by either adding them to the set directly
  or indirectly by selecting a range of indexes on a source object.

  @extends SC.Object
  @extends SC.Enumerable
  @extends SC.Freezable
  @extends SC.Copyable
  @since SproutCore 1.0
*/
SC.SelectionSet = SC.Object.extend(SC.Enumerable, SC.Freezable, SC.Copyable,
  /** @scope SC.SelectionSet.prototype */ {

  /**
    Walk like a duck.

    @type Boolean
  */
  isSelectionSet: YES,

  /**
    Total number of indexes in the selection set

    @type Number
  */
  length: function() {
    var ret     = 0,
        sets    = this._sets,
        objects = this._objects;
    if (objects) ret += objects.get('length');
    if (sets) sets.forEach(function(s) { ret += s.get('length'); });
    return ret ;
  }.property().cacheable(),

  // ..........................................................
  // INDEX-BASED SELECTION
  //

  /**
    A set of all the source objects used in the selection set.  This
    property changes automatically as you add or remove index sets.

    @type SC.Array
  */
  sources: function() {
    var ret  = [],
        sets = this._sets,
        len  = sets ? sets.length : 0,
        idx, set, source;

    for(idx=0;idx<len;idx++) {
      set = sets[idx];
      if (set && set.get('length')>0 && set.source) ret.push(set.source);
    }
    return ret ;
  }.property().cacheable(),

  /**
    Returns the index set for the passed source object or null if no items are
    seleted in the source.

    @param {SC.Array} source the source object
    @returns {SC.IndexSet} index set or null
  */
  indexSetForSource: function(source) {
    if (!source || !source.isSCArray) return null; // nothing to do

    var cache   = this._indexSetCache,
        objects = this._objects,
        ret, idx;

    // try to find in cache
    if (!cache) cache = this._indexSetCache = {};
    ret = cache[SC.guidFor(source)];
    if (ret && ret._sourceRevision && (ret._sourceRevision !== source.propertyRevision)) {
      ret = null;
    }

    // not in cache.  generate from index sets and any saved objects
    if (!ret) {
      ret = this._indexSetForSource(source, NO);
      if (ret && ret.get('length')===0) ret = null;

      if (objects) {
        if (ret) ret = ret.copy();
        objects.forEach(function(o) {
          if ((idx = source.indexOf(o)) >= 0) {
            if (!ret) ret = SC.IndexSet.create();
            ret.add(idx);
          }
        }, this);
      }

      if (ret) {
        ret = cache[SC.guidFor(source)] = ret.frozenCopy();
        ret._sourceRevision = source.propertyRevision;
      }
    }

    return ret;
  },

  /**
    @private

    Internal method gets the index set for the source, ignoring objects
    that have been added directly.
  */
  _indexSetForSource: function(source, canCreate) {
    if (canCreate === undefined) canCreate = YES;

    var guid  = SC.guidFor(source),
        index = this[guid],
        sets  = this._sets,
        len   = sets ? sets.length : 0,
        ret   = null;

    if (index >= len) index = null;
    if (SC.none(index)) {
      if (canCreate && !this.isFrozen) {
        this.propertyWillChange('sources');
        if (!sets) sets = this._sets = [];
        ret = sets[len] = SC.IndexSet.create();
        ret.source = source ;
        this[guid] = len;
        this.propertyDidChange('sources');
      }

    } else ret = sets ? sets[index] : null;
    return ret ;
  },

  /**
    Add the passed index, range of indexSet belonging to the passed source
    object to the selection set.

    The first parameter you pass must be the source array you are selecting
    from.  The following parameters may be one of a start/length pair, a
    single index, a range object or an IndexSet.  If some or all of the range
    you are selecting is already in the set, it will not be selected again.

    You can also pass an SC.SelectionSet to this method and all the selected
    sets will be added from their instead.

    @param {SC.Array} source source object or object to add.
    @param {Number} start index, start of range, range or IndexSet
    @param {Number} length length if passing start/length pair.
    @returns {SC.SelectionSet} receiver
  */
  add: function(source, start, length) {

    if (this.isFrozen) throw new Error(SC.FROZEN_ERROR);

    var sets, len, idx, set, oldlen, newlen, setlen, objects;

    // normalize
    if (start === undefined && length === undefined) {
      if (!source) throw new Error("Must pass params to SC.SelectionSet.add()");
      if (source.isIndexSet) return this.add(source.source, source);
      if (source.isSelectionSet) {
        sets = source._sets;
        objects = source._objects;
        len  = sets ? sets.length : 0;

        this.beginPropertyChanges();
        for(idx=0;idx<len;idx++) {
          set = sets[idx];
          if (set && set.get('length')>0) this.add(set.source, set);
        }
        if (objects) this.addObjects(objects);
        this.endPropertyChanges();
        return this ;

      }
    }

    set    = this._indexSetForSource(source, YES);
    oldlen = this.get('length');
    setlen = set.get('length');
    newlen = oldlen - setlen;

    set.add(start, length);

    this._indexSetCache = null;

    newlen += set.get('length');
    if (newlen !== oldlen) {
      this.propertyDidChange('length');
      this.enumerableContentDidChange();
      if (setlen === 0) this.notifyPropertyChange('sources');
    }

    return this ;
  },

  /**
    Removes the passed index, range of indexSet belonging to the passed source
    object from the selection set.

    The first parameter you pass must be the source array you are selecting
    from.  The following parameters may be one of a start/length pair, a
    single index, a range object or an IndexSet.  If some or all of the range
    you are selecting is already in the set, it will not be selected again.

    @param {SC.Array} source source object. must not be null
    @param {Number} start index, start of range, range or IndexSet
    @param {Number} length length if passing start/length pair.
    @returns {SC.SelectionSet} receiver
  */
  remove: function(source, start, length) {

    if (this.isFrozen) throw new Error(SC.FROZEN_ERROR);

    var sets, len, idx, i, set, oldlen, newlen, setlen, objects, object;

    // normalize
    if (start === undefined && length === undefined) {
      if (!source) throw new Error("Must pass params to SC.SelectionSet.remove()");
      if (source.isIndexSet) return this.remove(source.source, source);
      if (source.isSelectionSet) {
        sets = source._sets;
        objects = source._objects;
        len  = sets ? sets.length : 0;

        this.beginPropertyChanges();
        for(idx=0;idx<len;idx++) {
          set = sets[idx];
          if (set && set.get('length')>0) this.remove(set.source, set);
        }
        if (objects) this.removeObjects(objects);
        this.endPropertyChanges();
        return this ;
      }
    }

    // save starter info
    set    = this._indexSetForSource(source, YES);
    oldlen = this.get('length');
    newlen = oldlen - set.get('length');

    // if we have objects selected, determine if they are in the index
    // set and remove them as well.
    if (set && (objects = this._objects)) {

      // convert start/length to index set so the iterator below will work...
      if (length !== undefined) {
        start = SC.IndexSet.create(start, length);
        length = undefined;
      }

      for (i = objects.get('length') - 1; i >= 0; --i) {
        object = objects[i];
        idx = source.indexOf(object);
        if (start.contains(idx)) {
          objects.remove(object);
          newlen--;
        }
      }
    }

    // remove indexes from source index set
    set.remove(start, length);
    setlen = set.get('length');
    newlen += setlen;

    // update caches; change enumerable...
    this._indexSetCache = null;
    if (newlen !== oldlen) {
      this.propertyDidChange('length');
      this.enumerableContentDidChange();
      if (setlen === 0) this.notifyPropertyChange('sources');
    }

    return this ;
  },


  /**
    Returns YES if the selection contains the named index, range of indexes.

    @param {Object} source source object for range
    @param {Number} start index, start of range, range object, or indexSet
    @param {Number} length optional range length
    @returns {Boolean}
  */
  contains: function(source, start, length) {
    if (start === undefined && length === undefined) {
      return this.containsObject(source);
    }

    var set = this.indexSetForSource(source);
    if (!set) return NO ;
    return set.contains(start, length);
  },

  /**
    Returns YES if the index set contains any of the passed indexes.  You
    can pass a single index, a range or an index set.

    @param {Object} source source object for range
    @param {Number} start index, range, or IndexSet
    @param {Number} length optional range length
    @returns {Boolean}
  */
  intersects: function(source, start, length) {
    var set = this.indexSetForSource(source, NO);
    if (!set) return NO ;
    return set.intersects(start, length);
  },


  // ..........................................................
  // OBJECT-BASED API
  //

  _TMP_ARY: [],

  /**
    Adds the object to the selection set.  Unlike adding an index set, the
    selection will actually track the object independent of its location in
    the array.

    @param {Object} object
    @returns {SC.SelectionSet} receiver
  */
  addObject: function(object) {
    var ary = this._TMP_ARY, ret;
    ary[0] = object;

    ret = this.addObjects(ary);
    ary.length = 0;

    return ret;
  },

  /**
    Adds objects in the passed enumerable to the selection set.  Unlike adding
    an index set, the seleciton will actually track the object independent of
    its location the array.

    @param {SC.Enumerable} objects
    @returns {SC.SelectionSet} receiver
  */
  addObjects: function(objects) {
    var cur = this._objects,
        oldlen, newlen;
    if (!cur) cur = this._objects = SC.CoreSet.create();
    oldlen = cur.get('length');

    cur.addEach(objects);
    newlen = cur.get('length');

    this._indexSetCache = null;
    if (newlen !== oldlen) {
      this.propertyDidChange('length');
      this.enumerableContentDidChange();
    }
    return this;
  },

  /**
    Removes the object from the selection set.  Note that if the selection
    set also selects a range of indexes that includes this object, it may
    still be in the selection set.

    @param {Object} object
    @returns {SC.SelectionSet} receiver
  */
  removeObject: function(object) {
    var ary = this._TMP_ARY, ret;
    ary[0] = object;

    ret = this.removeObjects(ary);
    ary.length = 0;

    return ret;
  },

  /**
    Removes the objects from the selection set.  Note that if the selection
    set also selects a range of indexes that includes this object, it may
    still be in the selection set.

    @param {Object} object
    @returns {SC.SelectionSet} receiver
  */
  removeObjects: function(objects) {
    var cur = this._objects,
        oldlen, newlen, sets;

    if (!cur) return this;

    oldlen = cur.get('length');

    cur.removeEach(objects);
    newlen = cur.get('length');

    // also remove from index sets, if present
    if (sets = this._sets) {
      sets.forEach(function(set) {
        oldlen += set.get('length');
        set.removeObjects(objects);
        newlen += set.get('length');
      }, this);
    }

    this._indexSetCache = null;
    if (newlen !== oldlen) {
      this.propertyDidChange('length');
      this.enumerableContentDidChange();
    }
    return this;
  },

  /**
    Returns YES if the selection contains the passed object.  This will search
    selected ranges in all source objects.

    @param {Object} object the object to search for
    @returns {Boolean}
  */
  containsObject: function(object) {
    // fast path
    var objects = this._objects ;
    if (objects && objects.contains(object)) return YES ;

    var sets = this._sets,
        len  = sets ? sets.length : 0,
        idx, set;
    for(idx=0;idx<len;idx++) {
      set = sets[idx];
      if (set && set.indexOf(object)>=0) return YES;
    }

    return NO ;
  },


  // ..........................................................
  // GENERIC HELPER METHODS
  //

  /**
    Constrains the selection set to only objects found in the passed source
    object.  This will remove any indexes selected in other sources, any
    indexes beyond the length of the content, and any objects not found in the
    set.

    @param {Object} source the source to limit
    @returns {SC.SelectionSet} receiver
  */
  constrain: function (source) {
    var set, len, max, objects;

    this.beginPropertyChanges();

    // remove sources other than this one
    this.get('sources').forEach(function(cur) {
      if (cur === source) return; //skip
      var set = this._indexSetForSource(source, NO);
      if (set) this.remove(source, set);
    },this);

    // remove indexes beyond end of source length
    set = this._indexSetForSource(source, NO);
    if (set && ((max=set.get('max'))>(len=source.get('length')))) {
      this.remove(source, len, max-len);
    }

    // remove objects not in source
    if (objects = this._objects) {
      var i, cur;
      for (i = objects.length - 1; i >= 0; i--) {
        cur = objects[i];
        if (source.indexOf(cur) < 0) this.removeObject(cur);
      }
    }

    this.endPropertyChanges();
    return this ;
  },

  /**
    Returns YES if the passed index set or selection set contains the exact
    same source objects and indexes as  the receiver.  If you pass any object
    other than an IndexSet or SelectionSet, returns NO.

    @param {Object} obj another object.
    @returns {Boolean}
  */
  isEqual: function(obj) {
    var left, right, idx, len, sources, source;

    // fast paths
    if (!obj || !obj.isSelectionSet) return NO ;
    if (obj === this) return YES;
    if ((this._sets === obj._sets) && (this._objects === obj._objects)) return YES;
    if (this.get('length') !== obj.get('length')) return NO;

    // check objects
    left = this._objects;
    right = obj._objects;
    if (left || right) {
      if ((left ? left.get('length'):0) !== (right ? right.get('length'):0)) {
        return NO;
      }
      if (left && !left.isEqual(right)) return NO ;
    }

    // now go through the sets
    sources = this.get('sources');
    len     = sources.get('length');
    for(idx=0;idx<len;idx++) {
      source = sources.objectAt(idx);
      left = this._indexSetForSource(source, NO);
      right = this._indexSetForSource(source, NO);
      if (!!right !== !!left) return NO ;
      if (left && !left.isEqual(right)) return NO ;
    }

    return YES ;
  },

  /**
    Clears the set.  Removes all IndexSets from the object

    @returns {SC.SelectionSet}
  */
  clear: function() {
    if (this.isFrozen) throw new Error(SC.FROZEN_ERROR);
    if (this._sets) this._sets.length = 0 ; // truncate
    if (this._objects) this._objects = null;

    this._indexSetCache = null;
    this.propertyDidChange('length');
    this.enumerableContentDidChange();
    this.notifyPropertyChange('sources');

    return this ;
  },

  /**
   Clones the set into a new set.

   @returns {SC.SelectionSet}
  */
  copy: function() {
    var ret  = this.constructor.create(),
        sets = this._sets,
        len  = sets ? sets.length : 0 ,
        idx, set;

    if (sets && len>0) {
      sets = ret._sets = sets.slice();
      for(idx=0;idx<len;idx++) {
        if (!(set = sets[idx])) continue ;
        set = sets[idx] = set.copy();
        ret[SC.guidFor(set.source)] = idx;
      }
    }

    if (this._objects) ret._objects = this._objects.copy();
    return ret ;
  },

  /**
    @private

    Freezing a SelectionSet also freezes its internal sets.
  */
  freeze: function() {
    if (this.get('isFrozen')) { return this ; }
    var sets = this._sets,
        loc  = sets ? sets.length : 0,
        set ;

    while(--loc >= 0) {
      set = sets[loc];
      if (set) { set.freeze(); }
    }

    if (this._objects) { this._objects.freeze(); }
    this.set('isFrozen', YES);
    return this;
    // return arguments.callee.base.apply(this,arguments);
  },

  // ..........................................................
  // ITERATORS
  //

  /** @private */
  toString: function() {
    var sets = this._sets || [];
    sets = sets.map(function(set) {
      return set.toString().replace("SC.IndexSet", SC.guidFor(set.source));
    }, this);
    if (this._objects) sets.push(this._objects.toString());
    return "SC.SelectionSet:%@<%@>".fmt(SC.guidFor(this), sets.join(','));
  },

  /** @private */
  firstObject: function() {
    var sets    = this._sets,
        objects = this._objects;

    // if we have sets, get the first one
    if (sets && sets.get('length')>0) {
      var set  = sets ? sets[0] : null,
          src  = set ? set.source : null,
          idx  = set ? set.firstObject() : -1;
      if (src && idx>=0) return src.objectAt(idx);
    }

    // otherwise if we have objects, get the first one
    return objects ? objects.firstObject() : undefined;

  }.property(),

  /** @private
    Implement primitive enumerable support.  Returns each object in the
    selection.
  */
  nextObject: function(count, lastObject, context) {
    var objects, ret;

    // TODO: Make this more efficient.  Right now it collects all objects
    // first.

    if (count === 0) {
      objects = context.objects = [];
      this.forEach(function(o) { objects.push(o); }, this);
      context.max = objects.length;
    }

    objects = context.objects ;
    ret = objects[count];

    if (count+1 >= context.max) {
      context.objects = context.max = null;
    }

    return ret ;
  },

  /**
    Iterates over the selection, invoking your callback with each __object__.
    This will actually find the object referenced by each index in the
    selection, not just the index.

    The callback must have the following signature:

        function callback(object, index, source, indexSet) { ... }

    If you pass a target, it will be used when the callback is called.

    @param {Function} callback function to invoke.
    @param {Object} target optional content. otherwise uses window
    @returns {SC.SelectionSet} receiver
  */
  forEach: function(callback, target) {
    var sets = this._sets,
        objects = this._objects,
        len = sets ? sets.length : 0,
        set, idx;

    for(idx=0;idx<len;idx++) {
      set = sets[idx];
      if (set) set.forEachObject(callback, target);
    }

    if (objects) objects.forEach(callback, target);
    return this ;
  }

});

/** @private */
SC.SelectionSet.prototype.clone = SC.SelectionSet.prototype.copy;

/**
  Default frozen empty selection set

  @property {SC.SelectionSet}
*/
SC.SelectionSet.EMPTY = SC.SelectionSet.create().freeze();


/* >>>>>>>>>> BEGIN source/system/sparse_array.js */
// ==========================================================================
// Project:   SproutCore Costello - Property Observing Library
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('mixins/delegate_support') ;

/**
  @class

  A dynamically filled array.  A SparseArray makes it easy for you to create
  very large arrays of data but then to defer actually populating that array
  until it is actually needed.  This is often much faster than generating an
  array up front and paying the cost to load your data then.

  Although technically all arrays in JavaScript are "sparse" (in the sense
  that you can read and write properties at arbitrary indexes), this array
  keeps track of which elements in the array have been populated already
  and which ones have not.  If you try to get a value at an index that has
  not yet been populated, the SparseArray will notify a delegate object first,
  giving the delegate a chance to populate the component.

  Most of the time, you will use a SparseArray to incrementally load data
  from the server.  For example, if you have a contact list with 3,000
  contacts in it, you may create a SparseArray with a length of 3,000 and set
  that as the content for a ListView.  As the ListView tries to display the
  visible contacts, it will request them from the SparseArray, which will in
  turn notify your delegate, giving you a chance to load the contact data from
  the server.

  @extends SC.Enumerable
  @extends SC.Array
  @extends SC.Observable
  @extends SC.DelegateSupport
  @since SproutCore 1.0
*/

SC.SparseArray = SC.Object.extend(SC.Observable, SC.Enumerable, SC.Array,
  SC.DelegateSupport, /** @scope SC.SparseArray.prototype */ {

  // ..........................................................
  // LENGTH SUPPORT
  //

  _requestingLength: 0,
  _requestingIndex: 0,

  /**
    The length of the sparse array.  The delegate for the array should set
    this length.

    @type Number
  */
  length: function() {
    var del = this.delegate ;
    if (del && SC.none(this._length) && del.sparseArrayDidRequestLength) {
      this._requestingLength++ ;
      del.sparseArrayDidRequestLength(this);
      this._requestingLength-- ;
    }
    return this._length || 0 ;
  }.property().cacheable(),

  /**
    Call this method from a delegate to provide a length for the sparse array.
    If you pass null for this property, it will essentially "reset" the array
    causing your delegate to be called again the next time another object
    requests the array length.

    @param {Number} length the length or null
    @returns {SC.SparseArray} receiver
  */
  provideLength: function(length) {
    var oldLength;
    if (SC.none(length)) this._sa_content = null ;
    if (length !== this._length) {
      oldLength = this._length;
      this._length = length ;
      if (this._requestingLength <= 0) { this.arrayContentDidChange(0, oldLength||0, length||0) ; }
    }
    return this ;
  },

  // ..........................................................
  // READING CONTENT
  //

  /**
    The minimum range of elements that should be requested from the delegate.
    If this value is set to larger than 1, then the sparse array will always
    fit a requested index into a range of this size and request it.

    @type Number
  */
  rangeWindowSize: 1,

  /**
    This array contains all the start_indexes of ranges requested. This is to
    avoid calling sparseArrayDidRequestRange to often. Indexes are removed and
    added as range requests are completed.
  */
  requestedRangeIndex: null,

  /**
    Make sure to create the index array during init so that it is not shared
    between all instances.
  */
  init: function() {
    arguments.callee.base.apply(this,arguments);
    this.requestedRangeIndex = [];

    this._TMP_PROVIDE_ARRAY = [];
    this._TMP_PROVIDE_RANGE = { length: 1 };
    this._TMP_RANGE = {};
  },

  /**
    Returns the object at the specified index.  If the value for the index
    is currently undefined, invokes the didRequestIndex() method to notify
    the delegate.

    The omitMaterializing flag ensures that the object will not be materialized,
    but it simply checks for the presence of an object at the specified index
    and will return YES (or undefined if not found). This is useful in the case
    of SparseArrays, where you might NOT want to request the index to be loaded,
    but simply need a shallow check to see if the position has been filled.

    @param {Number} idx the index to get
    @param {Boolean} omitMaterializing
    @return {Object} the object
  */
  objectAt: function(idx, omitMaterializing) {
    var content = this._sa_content, ret ;

    if (idx >= this.get('length')) return undefined;
    if (!content) content = this._sa_content = [] ;
    if ((ret = content[idx]) === undefined) {
      if(!omitMaterializing) this.requestIndex(idx);
      ret = content[idx]; // just in case the delegate provided immediately
    }
    return ret ;
  },

  /**
    Returns the set of indexes that are currently defined on the sparse array.
    If you pass an optional index set, the search will be limited to only
    those indexes.  Otherwise this method will return an index set containing
    all of the defined indexes.  Currently this can be quite expensive if
    you have a lot of indexes defined.

    @param {SC.IndexSet} indexes optional from indexes
    @returns {SC.IndexSet} defined indexes
  */
  definedIndexes: function(indexes) {
    var ret = SC.IndexSet.create(),
        content = this._sa_content,
        idx, len;

    if (!content) return ret.freeze(); // nothing to do

    if (indexes) {
      indexes.forEach(function(idx) {
        if (content[idx] !== undefined) ret.add(idx);
      });
    } else {
      len = content.length;
      for(idx=0;idx<len;idx++) {
        if (content[idx] !== undefined) ret.add(idx);
      }
    }

    return ret.freeze();
  },

  _TMP_RANGE: {},

  /**
    Called by objectAt() whenever you request an index that has not yet been
    loaded.  This will possibly expand the index into a range and then invoke
    an appropriate method on the delegate to request the data.

    It will check if the range has been already requested.

    @param {Number} idx the index to retrieve
    @returns {SC.SparseArray} receiver
  */
  requestIndex: function(idx) {
    var del = this.delegate;
    if (!del) return this; // nothing to do

    // adjust window
    var len = this.get('rangeWindowSize'), start = idx;
    if (len > 1) start = start - Math.floor(start % len);
    if (len < 1) len = 1 ;

    // invoke appropriate callback
    this._requestingIndex++;
    if (del.sparseArrayDidRequestRange) {
      var range = this._TMP_RANGE;
      if(this.wasRangeRequested(start)===-1){
        range.start = start;
        range.length = len;
        this.requestedRangeIndex.push(start);
        del.sparseArrayDidRequestRange(this, range);
      }
    } else if (del.sparseArrayDidRequestIndex) {
      while(--len >= 0) del.sparseArrayDidRequestIndex(this, start + len);
    }
    this._requestingIndex--;

    return this ;
  },

  /*
    This method is called by requestIndex to check if the range has already
    been requested. We assume that rangeWindowSize is not changed often.

     @param {Number} startIndex
     @return {Number} index in requestRangeIndex
  */
  wasRangeRequested: function(rangeStart) {
    var i, ilen;
    for(i=0, ilen=this.requestedRangeIndex.length; i<ilen; i++){
      if(this.requestedRangeIndex[i]===rangeStart) return i;
    }
    return -1;
  },

  /*
    This method has to be called after a request for a range has completed.
    To remove the index from the sparseArray to allow future updates on the
    range.

     @param {Number} startIndex
     @return {Number} index in requestRangeIndex
  */
  rangeRequestCompleted: function(start) {
    var i = this.wasRangeRequested(start);
    if(i>=0) {
      this.requestedRangeIndex.removeAt(i,1);
      return YES;
    }
    return NO;
  },

  /**
    This method sets the content for the specified to the objects in the
    passed array.  If you change the way SparseArray implements its internal
    tracking of objects, you should override this method along with
    objectAt().

    @param {Range} range the range to apply to
    @param {Array} array the array of objects to insert
    @returns {SC.SparseArray} receiver
  */
  provideObjectsInRange: function(range, array) {
    var content = this._sa_content ;
    if (!content) content = this._sa_content = [] ;
    var start = range.start, len = range.length;
    while(--len >= 0) content[start+len] = array.objectAt(len);
    if (this._requestingIndex <= 0) this.arrayContentDidChange(range.start, range.length, range.length);
    return this ;
  },

  /**
    Convenience method to provide a single object at a specified index.  Under
    the covers this calls provideObjectsInRange() so you can override only
    that method and this one will still work.

    @param {Number} index the index to insert
    @param {Object} the object to insert
    @return {SC.SparseArray} receiver
  */
  provideObjectAtIndex: function(index, object) {
    var array = this._TMP_PROVIDE_ARRAY, range = this._TMP_PROVIDE_RANGE;
    array[0] = object;
    range.start = index;
    return this.provideObjectsInRange(range, array);
  },

  /**
    Invalidates the array content in the specified range.  This is not the
    same as editing an array.  Rather it will cause the array to reload the
    content from the delegate again when it is requested.

    @param {Range} the range
    @returns {SC.SparseArray} receiver
  */
  objectsDidChangeInRange: function(range) {

    // delete cached content
    var content = this._sa_content ;
    if (content) {
      // if range covers entire length of cached content, just reset array
      if (range.start === 0 && SC.maxRange(range)>=content.length) {
        this._sa_content = null ;

      // otherwise, step through the changed parts and delete them.
      } else {
        var start = range.start, loc = Math.min(start + range.length, content.length);
        while (--loc>=start) content[loc] = undefined;
      }
    }
    this.arrayContentDidChange(range.start, range.length, range.length) ; // notify
    return this ;
  },

  /**
    Optimized version of indexOf().  Asks the delegate to provide the index
    of the specified object.  If the delegate does not implement this method
    then it will search the internal array directly.

    @param {Object} obj the object to search for
    @returns {Number} the discovered index or -1 if not found
  */
  indexOf: function(obj) {
    var c, ret, del = this.delegate ;
    if (del && del.sparseArrayDidRequestIndexOf) {
      ret = del.sparseArrayDidRequestIndexOf(this, obj);
    }

    if (SC.none(ret)) {
      c = this._sa_content ;
      if (!c) c = this._sa_content = [] ;
      ret = c.indexOf(obj) ;
    }
    return ret;
  },

  // ..........................................................
  // EDITING
  //

  /**
    Array primitive edits the objects at the specified index unless the
    delegate rejects the change.

    @param {Number} idx the index to begin to replace
    @param {Number} amt the number of items to replace
    @param {Array} objects the new objects to set instead
    @returns {SC.SparseArray} receiver
  */
  replace: function(idx, amt, objects) {
    objects = objects || [] ;

    // if we have a delegate, get permission to make the replacement.
    var del = this.delegate ;
    if (del) {
      if (!del.sparseArrayShouldReplace ||
          !del.sparseArrayShouldReplace(this, idx, amt, objects)) {
            return this;
      }
    }

    // go ahead and apply to local content.
    var content = this._sa_content ;
    if (!content) content = this._sa_content = [] ;
    content.replace(idx, amt, objects) ;

    // update length
    var len = objects ? (objects.get ? objects.get('length') : objects.length) : 0;
    var delta = len - amt ;

    this.arrayContentWillChange(idx, amt, len) ;

    if (!SC.none(this._length)) {
      this.propertyWillChange('length');
      this._length += delta;
      this.propertyDidChange('length');
    }

    this.arrayContentDidChange(idx, amt, len);

    return this ;
  },

  /**
    Resets the SparseArray, causing it to reload its content from the
    delegate again.

    @returns {SC.SparseArray} receiver
  */
  reset: function() {
    var oldLength;
    this._sa_content = null ;
    oldLength = this._length;
    this._length = null ;
    this.arrayContentDidChange(0, oldLength, 0);
    this.invokeDelegateMethod(this.delegate, 'sparseArrayDidReset', this);
    return this ;
  }

}) ;

/**
  Convenience metohd returns a new sparse array with a default length already
  provided.

  @param {Number} len the length of the array
  @returns {SC.SparseArray}
*/
SC.SparseArray.array = function(len) {
  return this.create({ _length: len||0 });
};

/* >>>>>>>>>> BEGIN source/system/timer.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @class

  A Timer executes a method after a defined period of time.  Timers are
  significantly more efficient than using setTimeout() or setInterval()
  because they are cooperatively scheduled using the run loop.  Timers are
  also gauranteed to fire at the same time, making it far easier to keep
  multiple timers in sync.

  ## Overview

  Timers were created for SproutCore as a way to efficiently defer execution
  of code fragments for use in Animations, event handling, and other tasks.

  Browsers are typically fairly inconsistent about when they will fire a
  timeout or interval based on what the browser is currently doing.  Timeouts
  and intervals are also fairly expensive for a browser to execute, which
  means if you schedule a large number of them it can quickly slow down the
  browser considerably.

  Timers, on the other handle, are scheduled cooperatively using the
  SC.RunLoop, which uses exactly one timeout to fire itself when needed and
  then executes by timers that need to fire on its own.  This approach can
  be many times faster than using timers and guarantees that timers scheduled
  to execute at the same time generally will do so, keeping animations and
  other operations in sync.

  ## Scheduling a Timer

  To schedule a basic timer, you can simply call SC.Timer.schedule() with
  a target and action you wish to have invoked:

      var timer = SC.Timer.schedule({
        target: myObject, action: 'timerFired', interval: 100
      });

  When this timer fires, it will call the timerFired() method on myObject.

  In addition to calling a method on a particular object, you can also use
  a timer to execute a variety of other types of code:

   - If you include an action name, but not a target object, then the action will be passed down the responder chain.
   - If you include a property path for the action property (e.g. 'MyApp.someController.someMethod'), then the method you name will be executed.
   - If you include a function in the action property, then the function will be executed.  If you also include a target object, the function will be called with this set to the target object.

  In general these properties are read-only.  Changing an interval, target,
  or action after creating a timer will have an unknown effect.

  ## Scheduling Repeating Timers

  In addition to scheduling one time timers, you can also schedule timers to
  execute periodically until some termination date.  You make a timer
  repeating by adding the repeats: YES property:

      var timer = SC.Timer.schedule({
        target: myObject,
        action: 'updateAnimation',
        interval: 100,
        repeats: YES,
        until: Time.now() + 1000
      }) ;

  The above example will execute the myObject.updateAnimation() every 100msec
  for 1 second from the current time.

  If you want a timer to repeat without expiration, you can simply omit the
  until: property.  The timer will then repeat until you invalidate it.

  ## Pausing and Invalidating Timers

  If you have created a timer but you no longer want it to execute, you can
  call the invalidate() method on it.  This will remove the timer from the
  run loop and clear certain properties so that it will not run again.

  You can use the invalidate() method on both repeating and one-time timers.

  If you do not want to invalidate a timer completely but you just want to
  stop the timer from execution temporarily, you can alternatively set the
  isPaused property to YES:

      timer.set('isPaused', YES) ;
      // Perform some critical function; timer will not execute
      timer.set('isPaused', NO) ;

  When a timer is paused, it will be scheduled and will fire like normal,
  but it will not actually execute the action method when it fires.  For a
  one time timer, this means that if you have the timer paused when it fires,
  it may never actually execute the action method.  For repeating timers,
  this means the timer will remain scheduled but simply will not execute its
  action while the timer is paused.

  ## Firing Timers

  If you need a timer to execute immediately, you can always call the fire()
  method yourself.  This will execute the timer action, if the timer is not
  paused.  For a one time timer, it will also invalidate the timer and remove
  it from the run loop.  Repeating timers can be fired anytime and it will
  not interrupt their regular scheduled times.


  @extends SC.Object
  @author Charles Jolley
  @version 1.0
  @since version 1.0
*/
SC.Timer = SC.Object.extend(
/** @scope SC.Timer.prototype */ {

  /**
    The target object whose method will be invoked when the time fires.

    You can set either a target/action property or you can pass a specific
    method.

    @type {Object}
    @field
  */
  target: null,

  /**
    The action to execute.

    The action can be a method name, a property path, or a function.  If you
    pass a method name, it will be invoked on the target object or it will
    be called up the responder chain if target is null.  If you pass a
    property path and it resolves to a function then the function will be
    called.  If you pass a function instead, then the function will be
    called in the context of the target object.

    @type {String, Function}
  */
  action: null,

  /**
    Set if the timer should be created from a memory pool.  Normally you will
    want to leave this set, but if you plan to use bindings or observers with
    this timer, then you must set isPooled to NO to avoid reusing your timer.

    @type Boolean
  */
  isPooled: NO,

  /**
    The time interval in milliseconds.

    You generally set this when you create the timer.  If you do not set it
    then the timer will fire as soon as possible in the next run loop.

    @type {Number}
  */
  interval: 0,

  /**
    Timer start date offset.

    The start date determines when the timer will be scheduled.  The first
    time the timer fires will be interval milliseconds after the start
    date.

    Generally you will not set this property yourself.  Instead it will be
    set automatically to the current run loop start date when you schedule
    the timer.  This ensures that all timers scheduled in the same run loop
    cycle will execute in the sync with one another.

    The value of this property is an offset like what you get if you call
    Date.now().

    @type {Number}
  */
  startTime: null,

  /**
    YES if you want the timer to execute repeatedly.

    @type {Boolean}
  */
  repeats: NO,

  /**
    Last date when the timer will execute.

    If you have set repeats to YES, then you can also set this property to
    have the timer automatically stop executing past a certain date.

    This property should contain an offset value like startOffset.  However if
    you set it to a Date object on create, it will be converted to an offset
    for you.

    If this property is null, then the timer will continue to repeat until you
    call invalidate().

    @type {Date, Number}
  */
  until: null,

  /**
    Set to YES to pause the timer.

    Pausing a timer does not remove it from the run loop, but it will
    temporarily suspend it from firing.  You should use this property if
    you will want the timer to fire again the future, but you want to prevent
    it from firing temporarily.

    If you are done with a timer, you should call invalidate() instead of
    setting this property.

    @type {Boolean}
  */
  isPaused: NO,

  /**
    YES onces the timer has been scheduled for the first time.
  */
  isScheduled: NO,

  /**
    YES if the timer can still execute.

    This read only property will return YES as long as the timer may possibly
    fire again in the future.  Once a timer has become invalid, it cannot
    become valid again.

    @field
    @type {Boolean}
  */
  isValid: YES,

  /**
    Set to the current time when the timer last fired.  Used to find the
    next 'frame' to execute.
  */
  lastFireTime: 0,

  /**
    Computed property returns the next time the timer should fire.  This
    property resets each time the timer fires.  Returns -1 if the timer
    cannot fire again.

    @type Time
  */
  fireTime: function() {
    if (!this.get('isValid')) { return -1 ; }  // not valid - can't fire

    // can't fire w/o startTime (set when schedule() is called).
    var start = this.get('startTime');
    if (!start || start === 0) { return -1; }

    // fire interval after start.
    var interval = this.get('interval'), last = this.get('lastFireTime');
    if (last < start) { last = start; } // first time to fire

    // find the next time to fire
    var next ;
    if (this.get('repeats')) {
      if (interval === 0) { // 0 means fire as fast as possible.
        next = last ; // time to fire immediately!

      // find the next full interval after start from last fire time.
      } else {
        next = start + (Math.floor((last - start) / interval)+1)*interval;
      }

    // otherwise, fire only once interval after start
    } else {
      next = start + interval ;
    }

    // can never have a fireTime after until
    var until = this.get('until');
    if (until && until>0 && next>until) next = until;

    return next ;
  }.property('interval', 'startTime', 'repeats', 'until', 'isValid', 'lastFireTime').cacheable(),

  /**
    Schedules the timer to execute in the runloop.

    This method is called automatically if you create the timer using the
    schedule() class method.  If you create the timer manually, you will
    need to call this method yourself for the timer to execute.

    @returns {SC.Timer} The receiver
  */
  schedule: function() {
    if (!this.get('isValid')) return this; // nothing to do

    this.beginPropertyChanges();

    // if start time was not set explicitly when the timer was created,
    // get it from the run loop.  This way timer scheduling will always
    // occur in sync.
    if (!this.startTime) this.set('startTime', SC.RunLoop.currentRunLoop.get('startTime')) ;

    // now schedule the timer if the last fire time was < the next valid
    // fire time.  The first time lastFireTime is 0, so this will always go.
    var next = this.get('fireTime'), last = this.get('lastFireTime');
    if (next >= last) {
      this.set('isScheduled', YES);
      SC.RunLoop.currentRunLoop.scheduleTimer(this, next);
    }

    this.endPropertyChanges() ;

    return this ;
  },
  /**
    Invalidates the timer so that it will not execute again.  If a timer has
    been scheduled, it will be removed from the run loop immediately.

    @returns {SC.Timer} The receiver
  */
  invalidate: function() {
    this.beginPropertyChanges();
    this.set('isValid', NO);

    var runLoop = SC.RunLoop.currentRunLoop;
    if(runLoop) runLoop.cancelTimer(this);

    this.action = this.target = null ; // avoid memory leaks
    this.endPropertyChanges();

    // return to pool...
    if (this.get('isPooled')) SC.Timer.returnTimerToPool(this);
    return this ;
  },

  /**
    Immediately fires the timer.

    If the timer is not-repeating, it will be invalidated.  If it is repeating
    you can call this method without interrupting its normal schedule.

    @returns {void}
  */
  fire: function() {

    // this will cause the fireTime to recompute
    var last = Date.now();
    this.set('lastFireTime', last);

    var next = this.get('fireTime');

    // now perform the fire action unless paused.
    if (!this.get('isPaused')) this.performAction() ;

     // reschedule the timer if needed...
     if (next > last) {
       this.schedule();
     } else {
       this.invalidate();
     }
  },

  /**
    Actually fires the action. You can override this method if you need
    to change how the timer fires its action.
  */
  performAction: function() {
    var typeOfAction = SC.typeOf(this.action);

    // if the action is a function, just try to call it.
    if (typeOfAction == SC.T_FUNCTION) {
      this.action.call((this.target || this), this) ;

    // otherwise, action should be a string.  If it has a period, treat it
    // like a property path.
    } else if (typeOfAction === SC.T_STRING) {
      if (this.action.indexOf('.') >= 0) {
        var path = this.action.split('.') ;
        var property = path.pop() ;

        var target = SC.objectForPropertyPath(path, window) ;
        var action = target.get ? target.get(property) : target[property];
        if (action && SC.typeOf(action) == SC.T_FUNCTION) {
          action.call(target, this) ;
        } else {
          throw new Error('%@: Timer could not find a function at %@'.fmt(this, this.action));
        }

      // otherwise, try to execute action direction on target or send down
      // responder chain.
      } else {
        SC.RootResponder.responder.sendAction(this.action, this.target, this);
      }
    }
  },

  init: function() {
    arguments.callee.base.apply(this,arguments);

    // convert startTime and until to times if they are dates.
    if (this.startTime instanceof Date) {
      this.startTime = this.startTime.getTime() ;
    }

    if (this.until instanceof Date) {
      this.until = this.until.getTime() ;
    }
  },

  /** @private - Default values to reset reused timers to. */
  RESET_DEFAULTS: {
    target: null, action: null,
    isPooled: NO, isPaused: NO, isScheduled: NO, isValid: YES,
    interval: 0, repeats: NO, until: null,
    startTime: null, lastFireTime: 0
  },

  /**
    Resets the timer settings with the new settings.  This is the method
    called by the Timer pool when a timer is reused.  You will not normally
    call this method yourself, though you could override it if you need to
    reset additional properties when a timer is reused.

    @params {Hash} props properties to copy over
    @returns {SC.Timer} receiver
  */
  reset: function(props) {
    if (!props) props = SC.EMPTY_HASH;

    // note: we copy these properties manually just to make them fast.  we
    // don't expect you to use observers on a timer object if you are using
    // pooling anyway so this won't matter.  Still notify of property change
    // on fireTime to clear its cache.
    this.propertyWillChange('fireTime');
    var defaults = this.RESET_DEFAULTS ;
    for(var key in defaults) {
      if (!defaults.hasOwnProperty(key)) continue ;
      this[key] = SC.none(props[key]) ? defaults[key] : props[key];
    }
    this.propertyDidChange('fireTime');
    return this ;
  },

  // ..........................................................
  // TIMER QUEUE SUPPORT
  //

  /** @private - removes the timer from its current timerQueue if needed.
    return value is the new "root" timer.
  */
  removeFromTimerQueue: function(timerQueueRoot) {
    var prev = this._timerQueuePrevious, next = this._timerQueueNext ;

    if (!prev && !next && timerQueueRoot !== this) return timerQueueRoot ; // not in a queue...

    // else, patch up to remove...
    if (prev) prev._timerQueueNext = next ;
    if (next) next._timerQueuePrevious = prev ;
    this._timerQueuePrevious = this._timerQueueNext = null ;
    return (timerQueueRoot === this) ? next : timerQueueRoot ;
  },

  /** @private - schedules the timer in the queue based on the runtime. */
  scheduleInTimerQueue: function(timerQueueRoot, runTime) {
    this._timerQueueRunTime = runTime ;

    // find the place to begin
    var beforeNode = timerQueueRoot;
    var afterNode = null ;
    while(beforeNode && beforeNode._timerQueueRunTime < runTime) {
      afterNode = beforeNode ;
      beforeNode = beforeNode._timerQueueNext;
    }

    if (afterNode) {
      afterNode._timerQueueNext = this ;
      this._timerQueuePrevious = afterNode ;
    }

    if (beforeNode) {
      beforeNode._timerQueuePrevious = this ;
      this._timerQueueNext = beforeNode ;
    }

    // I am the new root if beforeNode === root
    return (beforeNode === timerQueueRoot) ? this : timerQueueRoot ;
  },

  /** @private
    adds the receiver to the passed array of expired timers based on the
    current time and then recursively calls the next timer.  Returns the
    first timer that is not expired.  This is faster than iterating through
    the timers because it does some faster cleanup of the nodes.
  */
  collectExpiredTimers: function(timers, now) {
    if (this._timerQueueRunTime > now) return this ; // not expired!
    timers.push(this);  // add to queue.. fixup next. assume we are root.
    var next = this._timerQueueNext ;
    this._timerQueueNext = null;
    if (next) next._timerQueuePrevious = null;
    return next ? next.collectExpiredTimers(timers, now) : null;
  }

}) ;

/** @scope SC.Timer */

/*
  Created a new timer with the passed properties and schedules it to
  execute.  This is the same as calling SC.Time.create({ props }).schedule().

  Note that unless you explicitly set isPooled to NO, this timer will be
  pulled from a shared memory pool of timers.  You cannot using bindings or
  observers on these timers as they may be reused for future timers at any
  time.

  @params {Hash} props Any properties you want to set on the timer.
  @returns {SC.Timer} new timer instance.
*/
SC.Timer.schedule = function(props) {
  // get the timer.
  var timer ;
  if (!props || SC.none(props.isPooled) || props.isPooled) {
    timer = this.timerFromPool(props);
  } else timer = this.create(props);
  return timer.schedule();
} ;

/**
  Returns a new timer from the timer pool, copying the passed properties onto
  the timer instance.  If the timer pool is currently empty, this will return
  a new instance.
*/
SC.Timer.timerFromPool = function(props) {
  var timers = this._timerPool;
  if (!timers) timers = this._timerPool = [] ;
  var timer = timers.pop();
  if (!timer) timer = this.create();
  return timer.reset(props) ;
};

/**
  Returns a timer instance to the timer pool for later use.  This is done
  automatically when a timer is invalidated if isPooled is YES.
*/
SC.Timer.returnTimerToPool = function(timer) {
  if (!this._timerPool) this._timerPool = [];

  this._timerPool.push(timer);
  return this ;
};



/* >>>>>>>>>> BEGIN source/system/utils.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

// These are helpful utility functions for calculating range and rect values
sc_require('system/browser');

SC.mixin( /** @scope SC */ {

  /**
    Takes a URL of any type and normalizes it into a fully qualified URL with
    hostname.  For example:

        "some/path" => "http://localhost:4020/some/path"
        "/some/path" => "http://localhost:4020/some/path"
        "http://localhost:4020/some/path" => "http://localhost:4020/some/path"

    @param url {String} the URL
    @returns {String} the normalized URL
  */
  normalizeURL: function(url) {
    if (url.slice(0,1) == '/') {
      url = window.location.protocol + '//' + window.location.host + url ;
    } else if ((url.slice(0,5) == 'http:') || (url.slice(0,6) == 'https:')) {
      // no change
    } else {
      url = window.location.href + '/' + url ;
    }
    return url ;
  },

  /** Return true if the number is between 0 and 1 */
  isPercentage: function(val){
    return (val<1 && val>0);
  },

  /** Return the left edge of the frame */
  minX: function(frame) {
    return frame.x || 0;
  },

  /** Return the right edge of the frame. */
  maxX: function(frame) {
    return (frame.x || 0) + (frame.width || 0);
  },

  /** Return the midpoint of the frame. */
  midX: function(frame) {
    return (frame.x || 0) + ((frame.width || 0) / 2) ;
  },

  /** Return the top edge of the frame */
  minY: function(frame) {
    return frame.y || 0 ;
  },

  /** Return the bottom edge of the frame */
  maxY: function(frame) {
    return (frame.y || 0) + (frame.height || 0) ;
  },

  /** Return the midpoint of the frame */
  midY: function(frame) {
    return (frame.y || 0) + ((frame.height || 0) / 2) ;
  },

  /** Returns the point that will center the frame X within the passed frame. */
  centerX: function(innerFrame, outerFrame) {
    return (outerFrame.width - innerFrame.width) / 2 ;
  },

  /** Return the point that will center the frame Y within the passed frame. */
  centerY: function(innerFrame, outerFrame) {
    return (outerFrame.height - innerFrame.height) /2  ;
  },

  /**
    The offset of an element.

    This function returns the left and top offset of an element with respect to either the document, the
    viewport or the element's parent element.  In standard SproutCore applications, the coordinates of the
    viewport are equivalent to the document, but a HTML5 application that wishes to use this component
    of SproutCore might need to properly distinguish between the two.

    For a useful discussion on the concepts of offsets and coordinates, see:
    http://www.quirksmode.org/mobile/viewports.html.

    @param {DOMElement|jQuery|String} elem the element to find the offset of.
      This is passed to `jQuery()`, so any value supported by `jQuery()` will work.
    @param {String} relativeToFlag flag to determine which relative element to determine offset by.
      One of either: 'document', 'viewport' or 'parent' (default: 'document').
    @returns {Object} the offset of the element as an Object (ie. Hash) in the form { x: value, y: value }.
   */
  offset: function(elem, relativeToFlag) {
    var userAgent,
        index,
        mobileBuildNumber,
        result;

    relativeToFlag = relativeToFlag || 'document';

    if (relativeToFlag === 'parent') {
      result = jQuery(elem).position();
    } else {
      result = jQuery(elem).offset();

      // jQuery does not workaround a problem with Mobile Safari versions prior to 4.1 that add the scroll
      // offset to the results of getBoundingClientRect.
      //
      // See http://dev.jquery.it/ticket/6446
      if (SC.browser.isMobileSafari) {
        userAgent = navigator.userAgent;
        index = userAgent.indexOf('Mobile/');
        mobileBuildNumber = userAgent.substring(index + 7, index + 9);

        if (parseInt(SC.browser.mobileSafari, 0) <= 532 || (mobileBuildNumber <= "8A")) {
          result.left -= window.pageXOffset;
          result.top -= window.pageYOffset;
        }
      }

      // Subtract the scroll offset for viewport coordinates
      if (relativeToFlag === 'viewport') {

        if(SC.browser.isIE8OrLower){
          result.left -= $(window).scrollLeft();
          result.top -= $(window).scrollTop();
        }else{
          result.left -= window.pageXOffset;
          result.top -= window.pageYOffset;
        }
      }
    }

    // Translate 'left', 'top' to 'x', 'y'

    try{
      result.x = result.left;
      result.y = result.top;
    } catch (e) {
      // We need this for IE, when the element is detached, for some strange
      // reason the object returned by element.getBoundingClientRect()
      // is read-only
      result = {x:result.left, y:result.top};
    }
    delete result.left;
    delete result.top;

    return result;
  },

  /**
    @deprecated Use SC.offset instead.

    SC.offset() is more accurate, more flexible in the value for the element parameter and
    easier to understand.

    @param el The DOM element
    @returns {Point} A hash with x, y offsets.
  */
  viewportOffset: function(el) {
    

    var result = SC.offset(el, 'viewport');

    return {x: result.left, y: result.top};
  }

}) ;

/* >>>>>>>>>> BEGIN source/system/utils/rect.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
SC.mixin( /** @scope SC */ {
  /** A Point at {0,0} */
  ZERO_POINT: { x: 0, y: 0 },

  /** Check if the given point is inside the rect. */
  pointInRect: function(point, f) {
    return  (point.x >= SC.minX(f)) &&
            (point.y >= SC.minY(f)) &&
            (point.x <= SC.maxX(f)) &&
            (point.y <= SC.maxY(f)) ;
  },

  /** Return true if the two frames match.  You can also pass only points or sizes.

    @param r1 {Rect} the first rect
    @param r2 {Rect} the second rect
    @param delta {Float} an optional delta that allows for rects that do not match exactly. Defaults to 0.1
    @returns {Boolean} true if rects match
   */
  rectsEqual: function(r1, r2, delta) {
    if (!r1 || !r2) return (r1 == r2) ;
    if (!delta && delta !== 0) delta = 0.1;
    if ((r1.y != r2.y) && (Math.abs(r1.y - r2.y) > delta)) return NO ;
    if ((r1.x != r2.x) && (Math.abs(r1.x - r2.x) > delta)) return NO ;
    if ((r1.width != r2.width) && (Math.abs(r1.width - r2.width) > delta)) return NO ;
    if ((r1.height != r2.height) && (Math.abs(r1.height - r2.height) > delta)) return NO ;
    return YES ;
  },

  /** Returns the insersection between two rectangles.

    @param r1 {Rect} The first rect
    @param r2 {Rect} the second rect
    @returns {Rect} the intersection rect.  width || height will be 0 if they do not interset.
  */
  intersectRects: function(r1, r2) {
    // find all four edges
    var ret = {
      x: Math.max(SC.minX(r1), SC.minX(r2)),
      y: Math.max(SC.minY(r1), SC.minY(r2)),
      width: Math.min(SC.maxX(r1), SC.maxX(r2)),
      height: Math.min(SC.maxY(r1), SC.maxY(r2))
    } ;

    // convert edges to w/h
    ret.width = Math.max(0, ret.width - ret.x) ;
    ret.height = Math.max(0, ret.height - ret.y) ;
    return ret ;
  },

  /** Returns the union between two rectangles

    @param r1 {Rect} The first rect
    @param r2 {Rect} The second rect
    @returns {Rect} The union rect.
  */
  unionRects: function(r1, r2) {
    // find all four edges
    var ret = {
      x: Math.min(SC.minX(r1), SC.minX(r2)),
      y: Math.min(SC.minY(r1), SC.minY(r2)),
      width: Math.max(SC.maxX(r1), SC.maxX(r2)),
      height: Math.max(SC.maxY(r1), SC.maxY(r2))
    } ;

    // convert edges to w/h
    ret.width = Math.max(0, ret.width - ret.x) ;
    ret.height = Math.max(0, ret.height - ret.y) ;
    return ret ;
  },

  /**
    Returns a copy of the passed rect, scaled by the specified scale, centered on the specified origin.

    @param {Rect} rect The rectangle to scale.
    @param {Number|Array|Hash} scale The scale (or [scaleX, scaleY], or { x: scaleX, y: scaleY}) to apply. Defaults to 1.
    @param {Number} originX The horizontal scale origin. Defaults to 0.5 (center).
    @param {Number} originY The vertical scale origin. Defaults to 0.5 (center).
    @returns {Rect} The scaled rect.
  */
  scaleRect: function(rect, scale, originX, originY) {
    // Defaults
    if (scale == null) scale = 1;
    if (originX == null) originX = 0.5;
    if (originY == null) originY = 0.5;

    // Gatekeep: Identity scale.
    if (scale === 1) return SC.cloneRect(rect);

    // Unpack scale.
    var scaleX, scaleY;
    switch (SC.typeOf(scale)) {
      case SC.T_ARRAY:
        scaleX = scale[0];
        scaleY = scale[1];
        break;
      case SC.T_HASH:
        scaleX = scale.x;
        scaleY = scale.y;
        break;
      default:
        scaleX = scale;
        scaleY = scale;
        break;
    }

    var scaledHeight = rect.height * scaleY,
      scaledWidth = rect.width * scaleX,
      dHeight = scaledHeight - rect.height,
      dWidth = scaledWidth - rect.width;
    
    // X and Y positions change depending on the origin of the scale. For example, if the
    // width scales down ten pixels and the origin is 50%, x will move five pixesl (10 * 0.5)
    // to the right.
    var scaledX = rect.x - (dWidth * originX),
      scaledY = rect.y - (dHeight * originY);

    return {
      height: scaledHeight,
      width: scaledWidth,
      x: scaledX,
      y: scaledY
    };
  },

  /**
    Duplicates the passed rect.

    This is faster than Object.clone().

    @param r {Rect} The rect to clone.
    @returns {Rect} The cloned rect
  */
  cloneRect: function(r) {
    return { x: r.x, y: r.y, width: r.width, height: r.height } ;
  },

  /** Returns a string representation of the rect as {x, y, width, height}.

    @param r {Rect} The rect to stringify.
    @returns {String} A string representation of the rect.
  */
  stringFromRect: function(r) {
    if (!r) {
      return "(null)";
    }
    else {
      return '{ x:'+r.x+', y:'+r.y+', width:'+r.width+', height:'+r.height+' }';
    }
  }


});

/* >>>>>>>>>> BEGIN source/views/view/design_mode.js */
// ==========================================================================
// Project:   SproutCore
// Copyright: @2012 7x7 Software, Inc.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
sc_require("views/view");

// When in debug mode, developers can log the design mode.



// The class names assigned to view elements depending on the current design
// mode.
SC.DESIGN_MODE_CLASS_NAMES = {
  s: 'sc-small',
  m: 'sc-medium',
  l: 'sc-large',
  xl: 'sc-xlarge'
};

/** @private This adds design modes support to SC.View. */
SC.View.reopen(
  /** @scope SC.View.prototype */ {

  // ------------------------------------------------------------------------
  // Properties
  //

  /**
    The current design mode of the application and this view.

    If the application has designModes specified, this property will be set
    automatically when the view is created and as the window size changes
    across the design mode boundaries.

    @property {String}
    @default null
  */
  designMode: null,

  /**
    The dynamic adjustments to apply to this view depending on the current
    design mode.

    If you specify designModes on the application, this hash will be checked
    for a matching adjustment to apply for the current design mode.

    @property {Object}
    @default null
  */
  modeAdjust: null,

  // ------------------------------------------------------------------------
  // Methods
  //

  /** @private Recursively set the designMode on each child view. */
  adjustChildDesignModes: function (lastDesignMode, designMode) {
    var childViews = this.get('childViews');

    var i, len = childViews.get('length');
    for (i = 0; i < len; i++) {
      var childView = childViews.objectAt(i);

      childView.updateDesignMode(lastDesignMode, designMode);
    }
  },

  _sc_assignProperty: function (key, value) {
    if (key === 'layout') {
      var newExplicitLayout = this._sc_computeExplicitLayout(value), // Convert the layout to an explicit layout.
          layoutDiff = {},
          explicitLayout = this.get('explicitLayout');
      for (var layoutKey in newExplicitLayout) {
        var currentValue = explicitLayout[layoutKey];

        layoutDiff[layoutKey] = currentValue === undefined ? null : currentValue;

        if (layoutKey === 'centerX') {
          layoutDiff.left = explicitLayout.left;
          layoutDiff.right = explicitLayout.right;
        }

        if (layoutKey === 'centerY') {
          layoutDiff.top = explicitLayout.top;
          layoutDiff.bottom = explicitLayout.bottom;
        }
      }

      this._originalProperties.layout = layoutDiff;
    } else {
      // Get the original value of the property for reset.
      this._originalProperties[key] = this.get(key);
    }

    // Apply the override.
    if (key === 'layout') {
      

      this.adjust(value);
    } else {
      

      this.set(key,value);
    }
  },

  _sc_revertProperty: function (key, oldValue) {
    


    if (key === 'layout') {
      this.adjust(oldValue);
    } else {
      this.set(key, oldValue);
    }
  },

  /**
    Updates the design mode for this view.

    This method is called automatically by the view's pane whenever the pane
    determines that the design mode, as specified in the pane's designModes
    property, has changed.  You should likely never need to call it manually.

    This method updates the designMode property of the view, adjusts
    the layout if a matching design adjustment in the view's designAdjustments
    property is found and adds a class name to the view for the current
    design mode.

    Note that updating the design mode also updates all child views of this
    view.

    @param {String} lastDesignMode the previously applied design mode
    @param {String} [designMode] the name of the design mode
   */
  updateDesignMode: function (lastDesignMode, designMode) {
    // Fast path.
    if (lastDesignMode === designMode) { return; }

    var classNames = this.get('classNames'),
      modeAdjust,
      elem,
      key,
      layer,
      newProperties,
      prevProperties,
      size;

    this.set('designMode', designMode);

    // Get the size name portion of the mode.
    if (designMode) {
      size = designMode.split('_')[0];
    }

    modeAdjust = this.get('modeAdjust');
    if (modeAdjust) {
      // Stop observing changes for a moment.
      this.beginPropertyChanges();

      // Unset any previous properties.
      prevProperties = this._originalProperties;
      if (prevProperties) {
        


        for (key in prevProperties) {
          this._sc_revertProperty(key, prevProperties[key]);
        }

        // Remove the cache.
        this._originalProperties = null;
      }

      if (designMode) {
        // Apply new properties. The orientation specific properties override the size properties.
        if (modeAdjust[size] || modeAdjust[designMode]) {
          newProperties = SC.merge(modeAdjust[size], modeAdjust[designMode]);

          


          // Cache the original properties for reset.
          this._originalProperties = {};
          for (key in newProperties) {
            this._sc_assignProperty(key, newProperties[key]);
          }
        }
      }

      // Resume observing.
      this.endPropertyChanges();
    }

    // Apply the design mode as a class name.
    // This is done here rather than through classNameBindings, because we can
    // do it here without needing to setup a designMode observer for each view.
    var designClass;
    layer = this.get('layer');
    if (layer) {
      elem = this.$();

      // If we had previously added a class to the element, remove it.
      if (lastDesignMode) {
        designClass = SC.DESIGN_MODE_CLASS_NAMES[lastDesignMode.split('_')[0]];
        elem.removeClass(designClass);
        classNames.removeObject(designClass);
      }

      // If necessary, add a new class.
      if (designMode) {
        designClass = SC.DESIGN_MODE_CLASS_NAMES[size];
        elem.addClass(designClass);
        classNames.push(designClass);
      }
    } else {
      if (designMode) {
        designClass = SC.DESIGN_MODE_CLASS_NAMES[size];
        // Ensure that it gets into the classNames array
        // so it is displayed when we render.
        classNames.push(designClass);
      }
    }

    // Set the designMode on each child view (may be null).
    this.adjustChildDesignModes(lastDesignMode, designMode);
  }

});

/* >>>>>>>>>> BEGIN source/panes/main.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('panes/pane');
sc_require('panes/keyboard');
sc_require('panes/layout');
sc_require('panes/manipulation');
sc_require('panes/pane_statechart');

/** @class

  Most SproutCore applications have a main pane, which dominates the
  application page.  You can extend from this view to implement your own main
  pane.  This class will automatically make itself main whenever you append it
  to a document, removing any other main pane that might be currently in
  place.  If you do have another already focused as the keyPane, this view
  will also make itself key automatically.  The default way to use the main
  pane is to simply add it to your page like this:

      SC.MainPane.create().append();

  This will cause your root view to display.  The default layout for a
  MainPane is to cover the entire document window and to resize with the
  window.

  @extends SC.Pane
  @since SproutCore 1.0
*/
SC.MainPane = SC.Pane.extend({
  /** @private */
  layout: { minHeight: 200, minWidth: 200 },

  /**
    Called when the pane is attached.  Takes on main pane status.
   */
  didAppendToDocument: function () {
    var responder = this.rootResponder;

    responder.makeMainPane(this);
    this.becomeKeyPane();

    // Update the body overflow on attach.
    this.setBodyOverflowIfNeeded();
  },

  /**
    Called when the pane is detached.  Resigns main pane status.
  */
  willRemoveFromDocument: function () {
    var responder = this.rootResponder;

    // Stop controlling the body overflow on detach.
    this.unsetBodyOverflowIfNeeded();

    responder.makeMainPane(null);
    this.resignKeyPane();
  },

  /** @private The 'updatedLayout' event. */
  _updatedLayout: function () {
    arguments.callee.base.apply(this,arguments);

    // If by chance the minHeight or minWidth changed we would need to alter the body overflow request.
    this.setBodyOverflowIfNeeded();
  },

  /** @private */
  acceptsKeyPane: YES,

  /** @private */
  classNames: ['sc-main']
});


/* >>>>>>>>>> BEGIN javascript.js */
/* >>>>>>>>>> BEGIN source/system/routes.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @class

  SC.routes manages the browser location. You can change the hash part of the
  current location. The following code

      SC.routes.set('location', 'notes/edit/4');

  will change the location to http://domain.tld/my_app#notes/edit/4. Adding
  routes will register a handler that will be called whenever the location
  changes and matches the route:

      SC.routes.add(':controller/:action/:id', MyApp, MyApp.route);

  You can pass additional parameters in the location hash that will be relayed
  to the route handler:

      SC.routes.set('location', 'notes/show/4?format=xml&language=fr');

  The syntax for the location hash is described in the location property
  documentation, and the syntax for adding handlers is described in the
  add method documentation.

  Browsers keep track of the locations in their history, so when the user
  presses the 'back' or 'forward' button, the location is changed, SC.route
  catches it and calls your handler. Except for Internet Explorer versions 7
  and earlier, which do not modify the history stack when the location hash
  changes.

  SC.routes also supports HTML5 history, which uses a '/' instead of a '#'
  in the URLs, so that all your website's URLs are consistent.
*/
SC.routes = SC.Object.create(
  /** @scope SC.routes.prototype */{

  /**
    Set this property to YES if you want to use HTML5 history, if available on
    the browser, instead of the location hash.

    HTML 5 history uses the history.pushState method and the window's popstate
    event.

    By default it is NO, so your URLs will look like:

        http://domain.tld/my_app#notes/edit/4

    If set to YES and the browser supports pushState(), your URLs will look
    like:

        http://domain.tld/my_app/notes/edit/4

    You will also need to make sure that baseURI is properly configured, as
    well as your server so that your routes are properly pointing to your
    SproutCore application.

    @see http://dev.w3.org/html5/spec/history.html#the-history-interface
    @property
    @type {Boolean}
  */
  wantsHistory: NO,

  /**
    A read-only boolean indicating whether or not HTML5 history is used. Based
    on the value of wantsHistory and the browser's support for pushState.

    @see wantsHistory
    @property
    @type {Boolean}
  */
  usesHistory: null,

  /**
    The base URI used to resolve routes (which are relative URLs). Only used
    when usesHistory is equal to YES.

    The build tools automatically configure this value if you have the
    html5_history option activated in the Buildfile:

        config :my_app, :html5_history => true

    Alternatively, it uses by default the value of the href attribute of the
    <base> tag of the HTML document. For example:

        <base href="http://domain.tld/my_app">

    The value can also be customized before or during the execution of the
    main() method.

    @see http://www.w3.org/TR/html5/semantics.html#the-base-element
    @property
    @type {String}
  */
  baseURI: document.baseURI,

  /** @private
    A boolean value indicating whether or not the ping method has been called
    to setup the SC.routes.

    @property
    @type {Boolean}
  */
  _didSetup: NO,

  /** @private
    Internal representation of the current location hash.

    @property
    @type {String}
  */
  _location: null,

  /** @private
    Routes are stored in a tree structure, this is the root node.

    @property
    @type {SC.routes._Route}
  */
  _firstRoute: null,

  /** @private
    Internal method used to extract and merge the parameters of a URL.

    @returns {Hash}
  */
  _extractParametersAndRoute: function(obj, coerce) {
    var params = {},
        route = obj.route || '',
        separator, parts, i, len, crumbs, key;

    separator = (route.indexOf('?') < 0 && route.indexOf('&') >= 0) ? '&' : '?';

    parts = route.split(separator);
    route = parts.shift();

    params = this.deparam(parts.join('&'), coerce || false);

    // overlay any parameter passed in obj
    for (key in obj) {
      if (obj.hasOwnProperty(key) && key !== 'route') {
        params[key] = '' + obj[key];
      }
    }

    params.params = separator + $.param(params);
    params.route = route;

    return params;
  },

  /**
    The current location hash. It is the part in the browser's location after
    the '#' mark.

    The following code

        SC.routes.set('location', 'notes/edit/4');

    will change the location to http://domain.tld/my_app#notes/edit/4 and call
    the correct route handler if it has been registered with the add method.

    You can also pass additional parameters. They will be relayed to the route
    handler. For example, the following code

        SC.routes.add(':controller/:action/:id', MyApp, MyApp.route);
        SC.routes.set('location', 'notes/show/4?format=xml&language=fr');

    will change the location to
    http://domain.tld/my_app#notes/show/4?format=xml&language=fr and call the
    MyApp.route method with the following argument:

        { route: 'notes/show/4',
          params: '?format=xml&language=fr',
          controller: 'notes',
          action: 'show',
          id: '4',
          format: 'xml',
          language: 'fr' }

    The location can also be set with a hash, the following code

        SC.routes.set('location',
          { route: 'notes/edit/4', format: 'xml', language: 'fr' });

    will change the location to
    http://domain.tld/my_app#notes/show/4?format=xml&language=fr.

    The 'notes/show/4&format=xml&language=fr' syntax for passing parameters,
    using a '&' instead of a '?', as used in SproutCore 1.0 is still supported.

    @property
    @type {String}
  */
  location: function(key, value) {
    var lsk;
    this._skipRoute = NO;
    if (value !== undefined) {
      // The 'location' and 'informLocation' properties essentially
      // represent a single property, but with different behavior
      // when setting the value. Because of this, we manually
      // update the cached value for the opposite property to
      // ensure they remain in sync. You shouldn't do this in
      // your own code unless you REALLY know what you are doing.
      lsk = this.informLocation.lastSetValueKey;
      if (lsk && this._kvo_cache) this._kvo_cache[lsk] = value;
    }
    return this._extractLocation(key, value);
  }.property(),

  /*
    Works exactly like 'location' but you use this property only when
    you want to just change the location w/out triggering the routes
  */
  informLocation: function(key, value){
    var lsk;
    this._skipRoute = YES;
    if (value !== undefined) {
      // The 'location' and 'informLocation' properties essentially
      // represent a single property, but with different behavior
      // when setting the value. Because of this, we manually
      // update the cached value for the opposite property to
      // ensure they remain in sync. You shouldn't do this in
      // your own code unless you REALLY know what you are doing.
      lsk = this.location.lastSetValueKey;
      if (lsk && this._kvo_cache) this._kvo_cache[lsk] = value;
    }
    return this._extractLocation(key, value);
  }.property(),

  _extractLocation: function(key, value) {
    var crumbs, encodedValue;

    if (value !== undefined) {
      if (value === null) {
        value = '';
      }

      if (typeof(value) === 'object') {
        crumbs = this._extractParametersAndRoute(value);
        value = crumbs.route + crumbs.params;
      }

      // Only update the browser if this event triggered from within the app, rather
      // than from the browser back or forward buttons.
      if (!this._exogenous) {
        if (!SC.empty(value) || (this._location && this._location !== value)) {
          encodedValue = encodeURI(value);

          if (this.usesHistory) {
            if (encodedValue.length > 0) {
              encodedValue = '/' + encodedValue;
            }
            window.history.pushState(null, null, this.get('baseURI') + encodedValue);
          } else {
            window.location.hash = encodedValue;
          }
        }
      }

      // Cache locally.
      this._location = value;
    }

    return this._location;
  },

  /**
    You usually don't need to call this method. It is done automatically after
    the application has been initialized.

    It registers for the hashchange event if available. If not, it creates a
    timer that looks for location changes every 150ms.
  */
  ping: function() {
    var that;

    if (!this._didSetup) {
      this._didSetup = YES;

      if (this.get('wantsHistory') && SC.platform.supportsHistory) {
        this.usesHistory = YES;

        this.popState();
        SC.Event.add(window, 'popstate', this, this.popState);

      } else {
        this.usesHistory = NO;

        if (SC.platform.supportsHashChange) {
          this.hashChange();
          SC.Event.add(window, 'hashchange', this, this.hashChange);

        } else {
          // we don't use a SC.Timer because we don't want
          // a run loop to be triggered at each ping
          that = this;
          this._invokeHashChange = function() {
            that.hashChange();
            setTimeout(that._invokeHashChange, 100);
          };
          this._invokeHashChange();
        }
      }
    }
  },

  /**
    Event handler for the hashchange event. Called automatically by the browser
    if it supports the hashchange event, or by our timer if not.
  */
  hashChange: function(event) {
    // Mark this location change as coming from the browser, which therefore doesn't
    // need to be updated.
    this._exogenous = YES;

    var loc = window.location.hash;

    // Remove the '#' prefix
    loc = (loc && loc.length > 0) ? loc.slice(1, loc.length) : '';

    if (!SC.browser.isMozilla) {
      // because of bug https://bugzilla.mozilla.org/show_bug.cgi?id=483304
      loc = decodeURI(loc);
    }

    if (this.get('location') !== loc && !this._skipRoute) {
      SC.run(function() {
        this.set('location', loc);
      }, this);
    }

    this._skipRoute = NO;
    this._exogenous = NO;
  },

  popState: function(event) {
    // Mark this location change as coming from the browser, which therefore doesn't
    // need to be updated.
    this._exogenous = YES;

    var base = this.get('baseURI'),
        loc = document.location.href;

    if (loc.slice(0, base.length) === base) {

      // Remove the base prefix and the extra '/'
      loc = loc.slice(base.length + 1, loc.length);

      if (this.get('location') !== loc && !this._skipRoute) {
        SC.run(function() {
          this.set('location', loc);
        }, this);
      }
    }

    this._skipRoute = NO;
    this._exogenous = NO;
  },

  /**
    Adds a route handler. Routes have the following format:

     - 'users/show/5' is a static route and only matches this exact string,
     - ':action/:controller/:id' is a dynamic route and the handler will be
        called with the 'action', 'controller' and 'id' parameters passed in a
        hash,
     - '*url' is a wildcard route, it matches the whole route and the handler
        will be called with the 'url' parameter passed in a hash.

    Route types can be combined, the following are valid routes:

     - 'users/:action/:id'
     - ':controller/show/:id'
     - ':controller/*url'

    @param {String} route the route to be registered
    @param {Object} target the object on which the method will be called, or
      directly the function to be called to handle the route
    @param {Function} method the method to be called on target to handle the
      route, can be a function or a string
  */
  add: function(route, target, method) {
    if (!this._didSetup) {
      this.invokeNext(this.ping);
    }

    if (method === undefined && SC.typeOf(target) === SC.T_FUNCTION) {
      method = target;
      target = null;
    } else if (SC.typeOf(method) === SC.T_STRING) {
      method = target[method];
    }

    if (!this._firstRoute) this._firstRoute = this._Route.create();
    this._firstRoute.add(route.split('/'), target, method);

    return this;
  },

  /**
    Observer of the 'location' property that calls the correct route handler
    when the location changes.
  */
  locationDidChange: function() {
    this.trigger();
  }.observes('location'),

  /**
    Triggers a route even if already in that route (does change the location, if it
    is not already changed, as well).

    If the location is not the same as the supplied location, this simply lets "location"
    handle it (which ends up coming back to here).
  */
  trigger: function() {
    var firstRoute = this._firstRoute,
        location = this.get('location'),
        params, route;

    if (firstRoute) {
      params = this._extractParametersAndRoute({ route: location });
      location = params.route;
      delete params.route;
      delete params.params;
      route = firstRoute.routeForParts(location.split('/'), params);
      if (route && route.method) {
        route.method.call(route.target || this, params);
      }
    }
  },

  /**
    Function to create an object out of a urlencoded param string.

    @param {String} string the parameter string
    @param {Boolean} coerce coerce the values? (Default NO)
  */
  deparam: function(string, coerce) {
    var obj = {},
      coerce_types = { 'true': !0, 'false': !1, 'null': null },
      params, len, idx, param, key, val, cur, i, keys, keys_last,
      dec = decodeURIComponent, toString = Object.prototype.toString;

    // This allows any URL-like string to also be objectified
    if (string.indexOf('?') >= 0) {
      string = string.split('?')[1];
      if (string.indexOf('#') >= 0) {
        string = string.split('#')[0];
      }
    } else if (string.indexOf('#') >= 0) {
      string = string.split('#')[1];
    }

    params = string.replace(/\+/g, ' ').split('&');
    len = params.length;
    for (idx = 0; idx < len; ++idx) {
      param = params[idx].split('='), key = dec(param[0]), cur = obj,
        keys = key.split(']['), keys_last = key.length - 1;

      if (/\[/.test(keys[0]) && /\]$/.test(keys[keys_last])) {
        keys[keys_last] = keys[keys_last].replace(/\]$/, '');
        keys = keys.shift().split('[').concat(keys);
        keys_last = keys.length - 1;
      } else { keys_last = 0; }

      if (param.length === 2) {
        val = dec(param[1]);

        if (coerce) {
          val = val && !isNaN(val)              ? +val              // gotta be a number
            : val === 'undefined'             ? undefined
            : coerce_types[val] !== undefined ? coerce_types[val]
            : val;
        }

        if (keys_last) {
          for (i = 0; i < keys_last; ++i) {
            key = keys[i] === '' ? cur.length : keys[i];
            cur = cur[key] = i < keys_last
              ? cur[key] || (keys[i + 1] && isNaN(keys[i + 1]) ? {} : [])
              : val;
          }
        } else {
          if (toString.apply(obj[key]) === '[object Array]') obj[key].push(val);
          else if (obj[key] !== undefined) obj[key] = [obj[key], val];
          else obj[key] = val;
        }
      } else if (key) {
        obj[key] = coerce ? undefined : '';
      }
    }
    return obj;
  },

  /**
    @private
    @class

    SC.routes._Route is a class used internally by SC.routes. The routes defined by your
    application are stored in a tree structure, and this is the class for the
    nodes.
  */
  _Route: SC.Object.extend(
  /** @scope SC.routes._Route.prototype */ {

    target: null,

    method: null,

    staticRoutes: null,

    dynamicRoutes: null,

    wildcardRoutes: null,

    add: function(parts, target, method) {
      var part, nextRoute;

      // clone the parts array because we are going to alter it
      parts = SC.clone(parts);

      if (!parts || parts.length === 0) {
        this.target = target;
        this.method = method;

      } else {
        part = parts.shift();

        // there are 3 types of routes
        switch (part.slice(0, 1)) {

        // 1. dynamic routes
        case ':':
          part = part.slice(1, part.length);
          if (!this.dynamicRoutes) this.dynamicRoutes = {};
          if (!this.dynamicRoutes[part]) this.dynamicRoutes[part] = this.constructor.create();
          nextRoute = this.dynamicRoutes[part];
          break;

        // 2. wildcard routes
        case '*':
          part = part.slice(1, part.length);
          if (!this.wildcardRoutes) this.wildcardRoutes = {};
          nextRoute = this.wildcardRoutes[part] = this.constructor.create();
          break;

        // 3. static routes
        default:
          if (!this.staticRoutes) this.staticRoutes = {};
          if (!this.staticRoutes[part]) this.staticRoutes[part] = this.constructor.create();
          nextRoute = this.staticRoutes[part];
        }

        // recursively add the rest of the route
        if (nextRoute) nextRoute.add(parts, target, method);
      }
    },

    routeForParts: function(parts, params) {
      var part, key, route;

      // clone the parts array because we are going to alter it
      parts = SC.clone(parts);

      // if parts is empty, we are done
      if (!parts || parts.length === 0) {
        return this.method ? this : null;

      } else {
        part = parts.shift();

        // try to match a static route
        if (this.staticRoutes && this.staticRoutes[part]) {
          return this.staticRoutes[part].routeForParts(parts, params);

        } else {

          // else, try to match a dynamic route
          for (key in this.dynamicRoutes) {
            route = this.dynamicRoutes[key].routeForParts(parts, params);
            if (route) {
              params[key] = part;
              return route;
            }
          }

          // else, try to match a wildcard route
          for (key in this.wildcardRoutes) {
            parts.unshift(part);
            params[key] = parts.join('/');
            return this.wildcardRoutes[key].routeForParts(null, params);
          }

          // if nothing was found, it means that there is no match
          return null;
        }
      }
    }

  })

});


/* >>>>>>>>>> BEGIN javascript.js */
/* >>>>>>>>>> BEGIN source/system/datetime.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  Standard error thrown by `SC.Scanner` when it runs out of bounds

  @static
  @constant
  @type Error
*/
SC.SCANNER_OUT_OF_BOUNDS_ERROR = SC.$error("Out of bounds.");

/**
  Standard error thrown by `SC.Scanner` when  you pass a value not an integer.

  @static
  @constant
  @type Error
*/
SC.SCANNER_INT_ERROR = SC.$error("Not an int.");

/**
  Standard error thrown by `SC.SCanner` when it cannot find a string to skip.

  @static
  @constant
  @type Error
*/
SC.SCANNER_SKIP_ERROR = SC.$error("Did not find the string to skip.");

/**
  Standard error thrown by `SC.Scanner` when it can any kind a string in the
  matching array.

  @static
  @constant
  @type Error
*/
SC.SCANNER_SCAN_ARRAY_ERROR = SC.$error("Did not find any string of the given array to scan.");

/**
  Standard error thrown when trying to compare two dates in different
  timezones.

  @static
  @constant
  @type Error
*/
SC.DATETIME_COMPAREDATE_TIMEZONE_ERROR = SC.$error("Can't compare the dates of two DateTimes that don't have the same timezone.");

/**
  Standard ISO8601 date format

  @static
  @type String
  @default '%Y-%m-%dT%H:%M:%S%Z'
  @constant
*/
SC.DATETIME_ISO8601 = '%Y-%m-%dT%H:%M:%S%Z';


/** @class

  A Scanner reads a string and interprets the characters into numbers. You
  assign the scanner's string on initialization and the scanner progresses
  through the characters of that string from beginning to end as you request
  items.

  Scanners are used by `DateTime` to convert strings into `DateTime` objects.

  @extends SC.Object
  @since SproutCore 1.0
  @author Martin Ottenwaelter
*/
SC.Scanner = SC.Object.extend(
/** @scope SC.Scanner.prototype */ {

  /**
    The string to scan. You usually pass it to the create method:

        SC.Scanner.create({string: 'May, 8th'});

    @type String
  */
  string: null,

  /**
    The current scan location. It is incremented by the scanner as the
    characters are processed.
    The default is 0: the beginning of the string.

    @type Integer
  */
  scanLocation: 0,

  /**
    Reads some characters from the string, and increments the scan location
    accordingly.

    @param {Integer} len The amount of characters to read
    @throws {SC.SCANNER_OUT_OF_BOUNDS_ERROR} If asked to read too many characters
    @returns {String} The characters
  */
  scan: function(len) {
    if (this.scanLocation + len > this.length) SC.SCANNER_OUT_OF_BOUNDS_ERROR.throw();
    var str = this.string.substr(this.scanLocation, len);
    this.scanLocation += len;
    return str;
  },

  /**
    Reads some characters from the string and interprets it as an integer.

    @param {Integer} min_len The minimum amount of characters to read
    @param {Integer} [max_len] The maximum amount of characters to read (defaults to the minimum)
    @throws {SC.SCANNER_INT_ERROR} If asked to read non numeric characters
    @returns {Integer} The scanned integer
  */
  scanInt: function(min_len, max_len) {
    if (max_len === undefined) max_len = min_len;
    var str = this.scan(max_len);
    var re = new RegExp("^\\d{" + min_len + "," + max_len + "}");
    var match = str.match(re);
    if (!match) SC.SCANNER_INT_ERROR.throw();
    if (match[0].length < max_len) {
      this.scanLocation += match[0].length - max_len;
    }
    return parseInt(match[0], 10);
  },

  /**
    Attempts to skip a given string.

    @param {String} str The string to skip
    @throws {SC.SCANNER_SKIP_ERROR} If the given string could not be scanned
    @returns {Boolean} YES if the given string was successfully scanned, NO otherwise
  */
  skipString: function(str) {
    if (this.scan(str.length) !== str) SC.SCANNER_SKIP_ERROR.throw();
    return YES;
  },

  /**
    Attempts to scan any string in a given array.

    @param {Array} ary the array of strings to scan
    @throws {SC.SCANNER_SCAN_ARRAY_ERROR} If no string of the given array is found
    @returns {Integer} The index of the scanned string of the given array
  */
  scanArray: function(ary) {
    for (var i = 0, len = ary.length; i < len; i++) {
      if (this.scan(ary[i].length) === ary[i]) {
        return i;
      }
      this.scanLocation -= ary[i].length;
    }
    SC.SCANNER_SCAN_ARRAY_ERROR.throw();
  }

});


/** @class

  A class representation of a date and time. It's basically a wrapper around
  the Date javascript object, KVO-friendly and with common date/time
  manipulation methods.

  This object differs from the standard JS Date object, however, in that it
  supports time zones other than UTC and that local to the machine on which
  it is running.  Any time zone can be specified when creating an
  `SC.DateTime` object, e.g.

      // Creates a DateTime representing 5am in Washington, DC and 10am in London
      var d = SC.DateTime.create({ hour: 5, timezone: 300 }); // -5 hours from UTC
      var e = SC.DateTime.create({ hour: 10, timezone: 0 }); // same time, specified in UTC

  and it is true that `d.isEqual(e)`.

  The time zone specified upon creation is permanent, and any calls to
  `get()` on that instance will return values expressed in that time zone. So,

      d.get('hour') returns 5.
      e.get('hour') returns 10.

  but

      d.get('milliseconds') === e.get('milliseconds')

  is true, since they are technically the same position in time.

  You can also use SC.DateTime as a record attribute on a data model.

      SC.Record.attr(SC.DateTime); // Default format is ISO8601. See `SC.DateTime.recordFormat`
      SC.Record.attr(SC.DateTime, { format: '%d/%m/%Y' }); // Attribute stored as a string in '%d/%m/%Y' format
      SC.Record.attr(SC.DateTime, { useUnixTime: YES }); // Attribute stored as a number in Unix time

  @extends SC.Object
  @extends SC.Freezable
  @extends SC.Copyable
  @author Martin Ottenwaelter
  @author Jonathan Lewis
  @author Josh Holt
  @since SproutCore 1.0
*/
SC.DateTime = SC.Object.extend(SC.Freezable, SC.Copyable,
/** @scope SC.DateTime.prototype */ {

  /**
    @private

    Internal representation of a date: the number of milliseconds
    since January, 1st 1970 00:00:00.0 UTC.

    @property
    @type {Integer}
  */
  _ms: 0,

  /** @read-only
    The offset, in minutes, between UTC and the object's timezone.
    All calls to `get()` will use this time zone to translate date/time
    values into the zone specified here.

    @type Integer
  */
  timezone: 0,

  /**
    A `SC.DateTime` instance is frozen by default for better performance.

    @type Boolean
  */
  isFrozen: YES,

  /**
    Returns a new `SC.DateTime` object where one or more of the elements have been adjusted
    according to the `options` parameter. The possible options that can be adjusted are `timezone`,
    `year`, `month`, `day`, `hour`, `minute`, `second` and `millisecond`.

    This is particularly useful when we want to get to a certain date or time based on an existing
    date or time without having to know all the elements of the existing date.

    For example, say we needed a datetime for midnight on whatever day we are given. The easiest
    way to do this is to take the datetime we are given and adjust it. For example,

        var midnight = someDate.adjust({ hour: 24 }); // Midnight on whatever day `someDate` is.

    ### Adjusting Time

    The time options, `hour`, `minute`, `second`, `millisecond`, are reset cascadingly by default.
    So for example, if only the hour is passed, then the minute, second, and millisecond will be set
    to 0. Or for another example, if the hour and minute are passed, then second and millisecond
    would be set to 0. To disable this simply pass `false` as the second argument to `adjust`.

    ### Adjusting Timezone

    If a time zone is passed in the options hash, all dates and times are assumed to be local to it,
    and the returned `SC.DateTime` instance has that time zone. If none is passed, it defaults to
    the value of `SC.DateTime.timezone`.

    Note that passing only a time zone does not affect the actual milliseconds since Jan 1, 1970,
    only the time zone in which it is expressed when displayed.

    @param {Object} options the amount of date/time to advance the receiver
    @param {Boolean} [resetCascadingly] whether to reset the time elements cascadingly from hour down to millisecond. Default `true`.
    @returns {SC.DateTime} copy of receiver
  */
  adjust: function(options, resetCascadingly) {
    var timezone;

    options = options ? SC.clone(options) : {};
    timezone = (options.timezone !== undefined) ? options.timezone : (this.timezone !== undefined) ? this.timezone : 0;

    return this.constructor._adjust(options, this._ms, timezone, resetCascadingly)._createFromCurrentState();
  },

  /**
    Returns a new `SC.DateTime` object where one or more of the elements have been advanced
    according to the `options` parameter. The possible options that can be advanced are `year`,
    `month`, `day`, `hour`, `minute`, `second` and `millisecond`.

    Note, you should not use floating point values as it might give unpredictable results.

    @param {Object} options the amount of date/time to advance the receiver
    @returns {DateTime} copy of the receiver
  */
  advance: function(options) {
    return this.constructor._advance(options, this._ms, this.timezone)._createFromCurrentState();
  },

  /**
    Generic getter.

    The properties you can get are:

      - `year`
      - `month` (January is 1, contrary to JavaScript Dates for which January is 0)
      - `day`
      - `dayOfWeek` (Sunday is 0)
      - `hour`
      - `minute`
      - `second`
      - `millisecond`
      - `milliseconds`, the number of milliseconds since
        January, 1st 1970 00:00:00.0 UTC
      - `elapsed`, the number of milliseconds until (-), or since (+), the date.
      - `isLeapYear`, a boolean value indicating whether the receiver's year
        is a leap year
      - `daysInMonth`, the number of days of the receiver's current month
      - `dayOfYear`, January 1st is 1, December 31th is 365 for a common year
      - `week` or `week1`, the week number of the current year, starting with
        the first Sunday as the first day of the first week (00..53)
      - `week0`, the week number of the current year, starting with
        the first Monday as the first day of the first week (00..53)
      - `lastMonday`, `lastTuesday`, etc., `nextMonday`,
        `nextTuesday`, etc., the date of the last or next weekday in
        comparison to the receiver.

    @param {String} key the property name to get
    @return the value asked for
  */
  unknownProperty: function(key) {
    return this.constructor._get(key, this._ms, this.timezone);
  },

  /**
    Formats the receiver according to the given format string. Should behave
    like the C strftime function.

    The format parameter can contain the following characters:

      - `%a` -- The abbreviated weekday name ("Sun")
      - `%A` -- The full weekday name ("Sunday")
      - `%b` -- The abbreviated month name ("Jan")
      - `%B` -- The full month name ("January")
      - `%c` -- The preferred local date and time representation
      - `%d` -- Day of the month (01..31)
      - `%D` -- Day of the month (0..31)
      - `%E` -- Elapsed time, according to localized text formatting strings. See below.
      - `%h` -- Hour of the day, 24-hour clock (0..23)
      - `%H` -- Hour of the day, 24-hour clock (00..23)
      - `%i` -- Hour of the day, 12-hour clock (1..12)
      - `%I` -- Hour of the day, 12-hour clock (01..12)
      - `%j` -- Day of the year (001..366)
      - `%m` -- Month of the year (01..12)
      - `%M` -- Minute of the hour (00..59)
      - `%o` -- The day's ordinal abbreviation ('st', 'nd', 'rd', etc.)
      - `%p` -- Meridian indicator ("AM" or "PM")
      - `%S` -- Second of the minute (00..60)
      - `%s` -- Milliseconds of the second (000..999)
      - `%U` -- Week number of the current year,
          starting with the first Sunday as the first
          day of the first week (00..53)
      - `%W` -- Week number of the current year,
          starting with the first Monday as the first
          day of the first week (00..53)
      - `%w` -- Day of the week (Sunday is 0, 0..6)
      - `%x` -- Preferred representation for the date alone, no time
      - `%X` -- Preferred representation for the time alone, no date
      - `%y` -- Year without a century (00..99)
      - `%Y` -- Year with century
      - `%Z` -- Time zone (ISO 8601 formatted)
      - `%%` -- Literal "%" character

    The Elapsed date format is a special, SproutCore specific formatting
    feature which will return an accurate-ish, human readable indication
    of elapsed time. For example, it might return "In 5 minutes", or "A year
    ago".

    For example,

        var date = SC.DateTime.create();

        date.toFormattedString("%E"); // "Right now"

        date.advance({ minute: 4 });
        date.toFormattedString("%E"); // "In 4 minutes"

        date.advance({ day: -7 });
        date.toFormattedString("%E"); // "About a week ago"

    To customize the output for the %E formatter, override the date
    localization strings inside of in your app.  The English localization
    strings used are:

        '_SC.DateTime.now' : 'Right now',
        '_SC.DateTime.secondIn' : 'In a moment',
        '_SC.DateTime.secondsIn' : 'In %e seconds',
        '_SC.DateTime.minuteIn' : 'In a minute',
        '_SC.DateTime.minutesIn' : 'In %e minutes',
        '_SC.DateTime.hourIn' : 'An hour from now',
        '_SC.DateTime.hoursIn' : 'In about %e hours',
        '_SC.DateTime.dayIn' : 'Tomorrow at %i:%M %p',
        '_SC.DateTime.daysIn' : '%A at %i:%M %p',
        '_SC.DateTime.weekIn' : 'Next week',
        '_SC.DateTime.weeksIn' : 'In %e weeks',
        '_SC.DateTime.monthIn' : 'Next month',
        '_SC.DateTime.monthsIn' : 'In %e months',
        '_SC.DateTime.yearIn' : 'Next year',
        '_SC.DateTime.yearsIn' : 'In %e years',

        '_SC.DateTime.secondAgo' : 'A moment ago',
        '_SC.DateTime.secondsAgo' : '%e seconds ago',
        '_SC.DateTime.minuteAgo' : 'A minute ago',
        '_SC.DateTime.minutesAgo' : '%e minutes ago',
        '_SC.DateTime.hourAgo' : 'An hour ago',
        '_SC.DateTime.hoursAgo' : 'About %e hours ago',
        '_SC.DateTime.dayAgo' : 'Yesterday at %i:%M %p',
        '_SC.DateTime.daysAgo' : '%A at %i:%M %p',
        '_SC.DateTime.weekAgo' : 'About a week ago',
        '_SC.DateTime.weeksAgo' : '%e weeks ago',
        '_SC.DateTime.monthAgo' : 'About a month ago',
        '_SC.DateTime.monthsAgo' : '%e months ago',
        '_SC.DateTime.yearAgo' : 'Last year',
        '_SC.DateTime.yearsAgo' : '%e years ago'

    Notice the special "%e" parameter in the localized strings.  This will be
    replaced with the number of intervals (seconds, minutes, weeks, etc) that
    are appropriate.

    @param {String} format the format string
    @return {String} the formatted string
  */
  toFormattedString: function(fmt) {
    return this.constructor._toFormattedString(fmt, this._ms, this.timezone);
  },

  /**
    Formats the receiver according ISO 8601 standard. It is equivalent to
    calling toFormattedString with the `'%Y-%m-%dT%H:%M:%S%Z'` format string.

    @return {String} the formatted string
  */
  toISO8601: function(){
    return this.constructor._toFormattedString(SC.DATETIME_ISO8601, this._ms, this.timezone);
  },

   /**
     Returns the suffix of the date for use in english eg 21st 22nd 22rd
    speech.

    @return {String}
   */
  dayOrdinal: function(){
     return this.get('day').ordinal();
   }.property(),

  /**
    @private

    Creates a string representation of the receiver.

    (Debuggers often call the `toString` method. Because of the way
    `SC.DateTime` is designed, calling `SC.DateTime._toFormattedString` would
    have a nasty side effect. We shouldn't therefore call any of
    `SC.DateTime`'s methods from `toString`)

    @returns {String}
  */
  toString: function() {
    return "UTC: " +
           new Date(this._ms).toUTCString() +
           ", timezone: " +
           this.timezone;
  },

  /**
    Returns `YES` if the passed `SC.DateTime` is equal to the receiver, ie: if their
    number of milliseconds since January, 1st 1970 00:00:00.0 UTC are equal.
    This is the preferred method for testing equality.

    @see SC.DateTime#compare
    @param {SC.DateTime} aDateTime the DateTime to compare to
    @returns {Boolean}
  */
  isEqual: function(aDateTime) {
    return this.constructor.compare(this, aDateTime) === 0;
  },

  /**
    Returns a copy of the receiver. Because of the way `SC.DateTime` is designed,
    it just returns the receiver.

    @returns {SC.DateTime}
  */
  copy: function() {
    return this;
  },

  /**
    Returns a copy of the receiver with the timezone set to the passed
    timezone. The returned value is equal to the receiver (ie `SC.Compare`
    returns 0), it is just the timezone representation that changes.

    If you don't pass any argument, the target timezone is assumed to be 0,
    ie UTC.

    Note that this method does not change the underlying position in time,
    but only the time zone in which it is displayed. In other words, the underlying
    number of milliseconds since Jan 1, 1970 does not change.

    @return {SC.DateTime}
  */
  toTimezone: function(timezone) {
    if (timezone === undefined) timezone = 0;
    return this.advance({ timezone: timezone - this.timezone });
  }

});

SC.DateTime.mixin(SC.Comparable,
/** @scope SC.DateTime */ {

  /**
    The default format (ISO 8601) in which DateTimes are stored in a record.
    Change this value if your backend sends and receives dates in another
    format.

    This value can also be customized on a per-attribute basis with the format
    property. For example:

        SC.Record.attr(SC.DateTime, { format: '%d/%m/%Y %H:%M:%S' })

    @type String
    @default SC.DATETIME_ISO8601
  */
  recordFormat: SC.DATETIME_ISO8601,

  /**
    @type Array
    @default ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday']
  */
  dayNames: ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'],

  /**
    @private

    The English day names used for the 'lastMonday', 'nextTuesday', etc., getters.

    @type Array
  */
  _englishDayNames: ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'],

  /**
    @type Array
    @default ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat']
  */
  abbreviatedDayNames: ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'],

  /**
    @type Array
    @default ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December']
  */
  monthNames: ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'],

  /**
    @type Array
    @default ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec']
  */
  abbreviatedMonthNames: ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],

  /**
    @type Array
    @default ['AM', 'PM']
  */
  AMPMNames:['AM', 'PM'],

  /**
    @private

    The unique internal `Date` object used to make computations. Better
    performance is obtained by having only one Date object for the whole
    application and manipulating it with `setTime()` and `getTime()`.

    Note that since this is used for internal calculations across many
    `SC.DateTime` instances, it is not guaranteed to store the date/time that
    any one `SC.DateTime` instance represents.  So it might be that

        this._date.getTime() !== this._ms

    Be sure to set it before using for internal calculations if necessary.

    @type Date
  */
  _date: new Date(),

  /**
    @private

    The offset, in minutes, between UTC and the currently manipulated
    `SC.DateTime` instance.

    @type Integer
  */
  _tz: 0,

  /**
    The offset, in minutes, between UTC and the local system time. This
    property is computed at loading time and should never be changed.

    @type Integer
    @default new Date().getTimezoneOffset()
    @constant
  */
  timezone: new Date().getTimezoneOffset(),

  /**
    @private

    A cache of `SC.DateTime` instances. If you attempt to create a `SC.DateTime`
    instance that has already been created, then it will return the cached
    value.

    @type Array
  */
  _dt_cache: {},

  /**
    @private

    The index of the latest cached value. Used with `_DT_CACHE_MAX_LENGTH` to
    limit the size of the cache.

    @type Integer
  */
  _dt_cache_index: -1,

  /**
    @private

    The maximum length of `_dt_cache`. If this limit is reached, then the cache
    is overwritten, starting with the oldest element.

    @type Integer
  */
  _DT_CACHE_MAX_LENGTH: 1000,

  /**
    @private

    Both args are optional, but will only overwrite `_date` and `_tz` if
    defined. This method does not affect the DateTime instance's actual time,
    but simply initializes the one `_date` instance to a time relevant for a
    calculation. (`this._date` is just a resource optimization)

    This is mainly used as a way to store a recursion starting state during
    internal calculations.

    'milliseconds' is time since Jan 1, 1970.
    'timezone' is the current time zone we want to be working in internally.

    Returns a hash of the previous milliseconds and time zone in case they
    are wanted for later restoration.
  */
  _setCalcState: function(ms, timezone) {
    var previous = {
      milliseconds: this._date.getTime(),
      timezone: this._tz
    };

    if (ms !== undefined) this._date.setTime(ms);
    if (timezone !== undefined) this._tz = timezone;

    return previous;
  },

  /**
    @private

    By this time, any time zone setting on 'hash' will be ignored.
    'timezone' will be used, or the last this._tz.
  */
  _setCalcStateFromHash: function(hash, timezone) {
    var tz = (timezone !== undefined) ? timezone : this._tz; // use the last-known time zone if necessary
    var ms = this._toMilliseconds(hash, this._ms, tz); // convert the hash (local to specified time zone) to milliseconds (in UTC)
    return this._setCalcState(ms, tz); // now call the one we really wanted
  },

  /**
    @private
    @see SC.DateTime#unknownProperty
  */
  _get: function(key, start, timezone) {
    var ms, doy, m, y, firstDayOfWeek, dayOfWeek, dayOfYear, prefix, suffix;
    var currentWeekday, targetWeekday;
    var d = this._date;
    var originalTime, v = null;

    // Set up an absolute date/time using the given milliseconds since Jan 1, 1970.
    // Only do it if we're given a time value, though, otherwise we want to use the
    // last one we had because this `_get()` method is recursive.
    //
    // Note that because these private time calc methods are recursive, and because all DateTime instances
    // share an internal this._date and `this._tz` state for doing calculations, methods
    // that modify `this._date` or `this._tz` should restore the last state before exiting
    // to avoid obscure calculation bugs.  So we save the original state here, and restore
    // it before returning at the end.
    originalTime = this._setCalcState(start, timezone); // save so we can restore it to how it was before we got here

    // Check this first because it is an absolute value -- no tweaks necessary when calling for milliseconds
    if (key === 'milliseconds') {
      v = d.getTime();
    }
    else if (key === 'timezone') {
      v = this._tz;
    }

    // 'nextWeekday' or 'lastWeekday'.
    // We want to do this calculation in local time, before shifting UTC below.
    if (v === null) {
      prefix = key.slice(0, 4);
      suffix = key.slice(4);
      if (prefix === 'last' || prefix === 'next') {
        currentWeekday = this._get('dayOfWeek', start, timezone);
        targetWeekday = this._englishDayNames.indexOf(suffix);
        if (targetWeekday >= 0) {
          var delta = targetWeekday - currentWeekday;
          if (prefix === 'last' && delta >= 0) delta -= 7;
          if (prefix === 'next' && delta <  0) delta += 7;
          this._advance({ day: delta }, start, timezone);
          v = this._createFromCurrentState();
        }
      }
    }

    if (v === null) {
      // need to adjust for alternate display time zone.
      // Before calculating, we need to get everything into a common time zone to
      // negate the effects of local machine time (so we can use all the 'getUTC...() methods on Date).
      if (timezone !== undefined) {
        this._setCalcState(d.getTime() - (timezone * 60000), 0); // make this instance's time zone the new UTC temporarily
      }

      // simple keys
      switch (key) {
        case 'year':
          v = d.getUTCFullYear(); //TODO: investigate why some libraries do getFullYear().toString() or getFullYear()+""
          break;
        case 'month':
          v = d.getUTCMonth()+1; // January is 0 in JavaScript
          break;
        case 'day':
          v = d.getUTCDate();
          break;
        case 'dayOfWeek':
          v = d.getUTCDay();
          break;
        case 'hour':
          v = d.getUTCHours();
          break;
        case 'minute':
          v = d.getUTCMinutes();
          break;
        case 'second':
          v = d.getUTCSeconds();
          break;
        case 'millisecond':
          v = d.getUTCMilliseconds();
          break;
        case 'elapsed':
          v = +new Date() - d.getTime() - (timezone * 60000);
          break;
      }

      // isLeapYear
      if ((v === null) && (key === 'isLeapYear')) {
        y = this._get('year');
        v = (y%4 === 0 && y%100 !== 0) || y%400 === 0;
      }

      // daysInMonth
      if ((v === null) && (key === 'daysInMonth')) {
        switch (this._get('month')) {
          case 4:
          case 6:
          case 9:
          case 11:
            v = 30;
            break;
          case 2:
            v = this._get('isLeapYear') ? 29 : 28;
            break;
          default:
            v = 31;
            break;
        }
      }

      // dayOfYear
      if ((v === null) && (key === 'dayOfYear')) {
        ms = d.getTime(); // save time
        doy = this._get('day');
        this._setCalcStateFromHash({ day: 1 });
        for (m = this._get('month') - 1; m > 0; m--) {
          this._setCalcStateFromHash({ month: m });
          doy += this._get('daysInMonth');
        }
        d.setTime(ms); // restore time
        v = doy;
      }

      // week, week0 or week1
      if ((v === null) && (key.slice(0, 4) === 'week')) {
        // firstDayOfWeek should be 0 (Sunday) or 1 (Monday)
        firstDayOfWeek = key.length === 4 ? 1 : parseInt(key.slice('4'), 10);
        dayOfWeek = this._get('dayOfWeek');
        dayOfYear = this._get('dayOfYear') - 1;
        if (firstDayOfWeek === 0) {
          v = parseInt((dayOfYear - dayOfWeek + 7) / 7, 10);
        }
        else {
          v = parseInt((dayOfYear - (dayOfWeek - 1 + 7) % 7 + 7) / 7, 10);
        }
      }
    }

    // restore the internal calculation state in case someone else was in the
    // middle of a calculation (we might be recursing).
    this._setCalcState(originalTime.milliseconds, originalTime.timezone);

    return v;
  },

  /**
    @private

    Sets the internal calculation state to something specified.
  */
  _adjust: function(options, start, timezone, resetCascadingly) {
    var ms = this._toMilliseconds(options, start, timezone, resetCascadingly);
    this._setCalcState(ms, timezone);
    return this; // for chaining
  },

  /**
    @private
    @see SC.DateTime#advance
  */
  _advance: function(options, start, timezone) {
    var opts = options ? SC.clone(options) : {};
    var tz;

    for (var key in opts) {
      opts[key] += this._get(key, start, timezone);
    }

    // The time zone can be advanced by a delta as well, so try to use the
    // new value if there is one.
    tz = (opts.timezone !== undefined) ? opts.timezone : timezone; // watch out for zero, which is acceptable as a time zone

    return this._adjust(opts, start, tz, NO);
  },

  /*
    @private

    Converts a standard date/time options hash to an integer representing that position
    in time relative to Jan 1, 1970
  */
  _toMilliseconds: function(options, start, timezone, resetCascadingly) {
    var opts = options ? SC.clone(options) : {};
    var d = this._date;
    var previousMilliseconds = d.getTime(); // rather than create a new Date object, we'll reuse the instance we have for calculations, then restore it
    var ms, tz;

    // Initialize our internal for-calculations Date object to our current date/time.
    // Note that this object was created in the local machine time zone, so when we set
    // its params later, it will be assuming these values to be in the same time zone as it is.
    // It's ok for start to be null, in which case we'll just keep whatever we had in 'd' before.
    if (!SC.none(start)) {
      d.setTime(start); // using milliseconds here specifies an absolute location in time, regardless of time zone, so that's nice
    }

    // We have to get all time expressions, both in 'options' (assume to be in time zone 'timezone')
    // and in 'd', to the same time zone before we can any calculations correctly.  So because the Date object provides
    // a suite of UTC getters and setters, we'll temporarily redefine 'timezone' as our new
    // 'UTC', so we don't have to worry about local machine time.  We do this by subtracting
    // milliseconds for the time zone offset.  Then we'll do all our calculations, then convert
    // it back to real UTC.

    // (Zero time zone is considered a valid value.)
    tz = (timezone !== undefined) ? timezone : (this.timezone !== undefined) ? this.timezone : 0;
    d.setTime(d.getTime() - (tz * 60000)); // redefine 'UTC' to establish a new local absolute so we can use all the 'getUTC...()' Date methods

    // the time options (hour, minute, sec, millisecond)
    // reset cascadingly (see documentation)
    if (resetCascadingly === undefined || resetCascadingly === YES) {
      if ( !SC.none(opts.hour) && SC.none(opts.minute)) {
        opts.minute = 0;
      }
      if (!(SC.none(opts.hour) && SC.none(opts.minute)) &&
          SC.none(opts.second)) {
        opts.second = 0;
      }
      if (!(SC.none(opts.hour) && SC.none(opts.minute) && SC.none(opts.second)) &&
          SC.none(opts.millisecond)) {
        opts.millisecond = 0;
      }
    }

    // Get the current values for any not provided in the options hash.
    // Since everything is in 'UTC' now, use the UTC accessors.  We do this because,
    // according to javascript Date spec, you have to set year, month, and day together
    // if you're setting any one of them.  So we'll use the provided Date.UTC() method
    // to get milliseconds, and we need to get any missing values first...
    if (SC.none(opts.year))        opts.year = d.getUTCFullYear();
    if (SC.none(opts.month))       opts.month = d.getUTCMonth() + 1; // January is 0 in JavaScript
    if (SC.none(opts.day))         opts.day = d.getUTCDate();
    if (SC.none(opts.hour))        opts.hour = d.getUTCHours();
    if (SC.none(opts.minute))      opts.minute = d.getUTCMinutes();
    if (SC.none(opts.second))      opts.second = d.getUTCSeconds();
    if (SC.none(opts.millisecond)) opts.millisecond = d.getUTCMilliseconds();

    // Ask the JS Date to calculate milliseconds for us (still in redefined UTC).  It
    // is best to set them all together because, for example, a day value means different things
    // to the JS Date object depending on which month or year it is.  It can now handle that stuff
    // internally as it's made to do.
    ms = Date.UTC(opts.year, opts.month - 1, opts.day, opts.hour, opts.minute, opts.second, opts.millisecond);

    // Now that we've done all our calculations in a common time zone, add back the offset
    // to move back to real UTC.
    d.setTime(ms + (tz * 60000));
    ms = d.getTime(); // now get the corrected milliseconds value

    // Restore what was there previously before leaving in case someone called this method
    // in the middle of another calculation.
    d.setTime(previousMilliseconds);

    return ms;
  },

  /**
    Returns a new `SC.DateTime` object advanced according the the given parameters.
    The parameters can be:

     - none, to create a `SC.DateTime` instance initialized to the current
       date and time in the local timezone,
     - a integer, the number of milliseconds since
       January, 1st 1970 00:00:00.0 UTC
     - a options hash that can contain any of the following properties: year,
       month, day, hour, minute, second, millisecond, timezone

    Note that if you attempt to create a `SC.DateTime` instance that has already
    been created, then, for performance reasons, a cached value may be
    returned.

    The timezone option is the offset, in minutes, between UTC and local time.
    If you don't pass a timezone option, the date object is created in the
    local timezone. If you want to create a UTC+2 (CEST) date, for example,
    then you should pass a timezone of -120.

    @param options one of the three kind of parameters described above
    @returns {SC.DateTime} the SC.DateTime instance that corresponds to the
      passed parameters, possibly fetched from cache
  */
  create: function() {
    var arg = arguments.length === 0 ? {} : arguments[0];
    var timezone;

    // if simply milliseconds since Jan 1, 1970 are given, just use those
    if (SC.typeOf(arg) === SC.T_NUMBER) {
      arg = { milliseconds: arg };
    }

    // Default to local machine time zone if none is given
    timezone = (arg.timezone !== undefined) ? arg.timezone : this.timezone;
    if (timezone === undefined) timezone = 0;

    // Desired case: create with milliseconds if we have them.
    // If we don't, convert what we have to milliseconds and recurse.
    if (!SC.none(arg.milliseconds)) {

      // quick implementation of a FIFO set for the cache
      var key = 'nu' + arg.milliseconds + timezone, cache = this._dt_cache;
      var ret = cache[key];
      if (!ret) {
        var previousKey, idx = this._dt_cache_index, C = this;
        ret = cache[key] = new C([{ _ms: arg.milliseconds, timezone: timezone }]);
        idx = this._dt_cache_index = (idx + 1) % this._DT_CACHE_MAX_LENGTH;
        previousKey = cache[idx];
        if (previousKey !== undefined && cache[previousKey]) delete cache[previousKey];
        cache[idx] = key;
      }
      return ret;
    }
    // otherwise, convert what we have to milliseconds and try again
    else {
      var now = new Date();

      return this.create({ // recursive call with new arguments
        milliseconds: this._toMilliseconds(arg, now.getTime(), timezone, arg.resetCascadingly),
        timezone: timezone
      });
    }
  },

  /**
    @private

    Calls the `create()` method with the current internal `_date` value.

    @return {SC.DateTime} the SC.DateTime instance returned by create()
  */
  _createFromCurrentState: function() {
    return this.create({
      milliseconds: this._date.getTime(),
      timezone: this._tz
    });
  },

  /**
    Returns a `SC.DateTime` object created from a given string parsed with a given
    format. Returns `null` if the parsing fails.

    @see SC.DateTime#toFormattedString for a description of the format parameter
    @param {String} str the string to parse
    @param {String} fmt the format to parse the string with
    @returns {DateTime} the DateTime corresponding to the string parameter
  */
  parse: function(str, fmt) {
    // Declared as an object not a literal since in some browsers the literal
    // retains state across function calls
    var re = new RegExp('(?:%([aAbBcdDhHiIjmMpsSUWwxXyYZ%])|(.))', "g");
    var d, parts, opts = {}, check = {}, scanner = SC.Scanner.create({string: str});

    if (SC.none(fmt)) fmt = SC.DATETIME_ISO8601;

    try {
      while ((parts = re.exec(fmt)) !== null) {
        switch(parts[1]) {
          case 'a': check.dayOfWeek = scanner.scanArray(this.abbreviatedDayNames); break;
          case 'A': check.dayOfWeek = scanner.scanArray(this.dayNames); break;
          case 'b': opts.month = scanner.scanArray(this.abbreviatedMonthNames) + 1; break;
          case 'B': opts.month = scanner.scanArray(this.monthNames) + 1; break;
          case 'c': throw new Error("%c is not implemented");
          case 'd':
          case 'D': opts.day = scanner.scanInt(1, 2); break;
          case 'e': throw new Error("%e is not implemented");
          case 'E': throw new Error("%E is not implemented");
          case 'h':
          case 'H': opts.hour = scanner.scanInt(1, 2); break;
          case 'i':
          case 'I': opts.hour = scanner.scanInt(1, 2); break;
          case 'j': throw new Error("%j is not implemented");
          case 'm': opts.month = scanner.scanInt(1, 2); break;
          case 'M': opts.minute = scanner.scanInt(1, 2); break;
          case 'p': opts.meridian = scanner.scanArray(this.AMPMNames); break;
          case 'S': opts.second = scanner.scanInt(1, 2); break;
          case 's': opts.millisecond = scanner.scanInt(1, 3); break;
          case 'U': throw new Error("%U is not implemented");
          case 'W': throw new Error("%W is not implemented");
          case 'w': throw new Error("%w is not implemented");
          case 'x': throw new Error("%x is not implemented");
          case 'X': throw new Error("%X is not implemented");
          case 'y': opts.year = scanner.scanInt(2); opts.year += (opts.year > 70 ? 1900 : 2000); break;
          case 'Y': opts.year = scanner.scanInt(4); break;
          case 'Z':
            var modifier = scanner.scan(1);
            if (modifier === 'Z') {
              opts.timezone = 0;
            } else if (modifier === '+' || modifier === '-' ) {
              var h = scanner.scanInt(2);
              if (scanner.scan(1) !== ':') scanner.scan(-1);
              var m = scanner.scanInt(2);
              opts.timezone = (modifier === '+' ? -1 : 1) * (h*60 + m);
            }
            break;
          case '%': scanner.skipString('%'); break;
          default:  scanner.skipString(parts[0]); break;
        }
      }
    } catch (e) {
      SC.Logger.log('SC.DateTime.createFromString ' + e.toString());
      return null;
    }

    if (!SC.none(opts.meridian) && !SC.none(opts.hour)) {
      if ((opts.meridian === 1 && opts.hour !== 12) ||
          (opts.meridian === 0 && opts.hour === 12)) {
        opts.hour = (opts.hour + 12) % 24;
      }
      delete opts.meridian;
    }

    d = this.create(opts);

    if (!SC.none(check.dayOfWeek) && d.get('dayOfWeek') !== check.dayOfWeek) {
      return null;
    }

    return d;
  },

  /**
    @private

    Converts the x parameter into a string padded with 0s so that the string’s
    length is at least equal to the len parameter.

    @param {Object} x the object to convert to a string
    @param {Integer} the minimum length of the returned string
    @returns {String} the padded string
  */
  _pad: function(x, len) {
    var str = '' + x;
    if (len === undefined) len = 2;
    while (str.length < len) str = '0' + str;
    return str;
  },

  /**
    @private
    @see SC.DateTime#_toFormattedString
  */
  __toFormattedString: function(part, start, timezone) {
    var hour, offset;

    // Note: all calls to _get() here should include only one
    // argument, since _get() is built for recursion and behaves differently
    // if arguments 2 and 3 are included.
    //
    // This method is simply a helper for this._toFormattedString() (one underscore);
    // this is only called from there, and _toFormattedString() has already
    // set up the appropriate internal date/time/timezone state for it.

    switch(part[1]) {
      case 'a': return this.abbreviatedDayNames[this._get('dayOfWeek')];
      case 'A': return this.dayNames[this._get('dayOfWeek')];
      case 'b': return this.abbreviatedMonthNames[this._get('month')-1];
      case 'B': return this.monthNames[this._get('month')-1];
      case 'c': return this._date.toString();
      case 'd': return this._pad(this._get('day'));
      case 'D': return this._get('day');
      case 'E': return this._toFormattedString(this.__getElapsedStringFormat(start, timezone), start, timezone);
      case 'h': return this._get('hour');
      case 'H': return this._pad(this._get('hour'));
      case 'i':
        hour = this._get('hour');
        return (hour === 12 || hour === 0) ? 12 : (hour + 12) % 12;
      case 'I':
        hour = this._get('hour');
        return this._pad((hour === 12 || hour === 0) ? 12 : (hour + 12) % 12);
      case 'j': return this._pad(this._get('dayOfYear'), 3);
      case 'm': return this._pad(this._get('month'));
      case 'M': return this._pad(this._get('minute'));
      case 'o': return this._get('day').ordinal();
      case 'p': return this._get('hour') > 11 ? this.AMPMNames[1] : this.AMPMNames[0];
      case 'S': return this._pad(this._get('second'));
      case 's': return this._pad(this._get('millisecond'), 3);
      case 'u': return this._pad(this._get('utc')); //utc
      case 'U': return this._pad(this._get('week0'));
      case 'W': return this._pad(this._get('week1'));
      case 'w': return this._get('dayOfWeek');
      case 'x': return this._date.toDateString();
      case 'X': return this._date.toTimeString();
      case 'y': return this._pad(this._get('year') % 100);
      case 'Y': return this._get('year');
      case 'Z':
        offset = -1 * timezone;
        return (offset >= 0 ? '+' : '-') +
               this._pad(parseInt(Math.abs(offset)/60, 10)) +
               ':' +
               this._pad(Math.abs(offset)%60);
      case '%': return '%';
    }
  },

  /**
    @private
    @see SC.DateTime#toFormattedString
  */
  _toFormattedString: function(format, start, timezone) {
    var that = this;

    // need to move into local time zone for these calculations
    this._setCalcState(start - (timezone * 60000), 0); // so simulate a shifted 'UTC' time

    return format.replace(/\%([aAbBcdeEDhHiIjmMopsSUWwxXyYZ\%])/g, function() {
      var v = that.__toFormattedString.call(that, arguments, start, timezone);
      return v;
    });
  },

  /**
    @private
    @see SC.DateTime#toFormattedString
   */
  __getElapsedStringFormat: function(start, timezone) {
    return "";
  },

  /**
    This will tell you which of the two passed `DateTime` is greater by
    comparing their number of milliseconds since
    January, 1st 1970 00:00:00.0 UTC.

    @param {SC.DateTime} a the first DateTime instance
    @param {SC.DateTime} b the second DateTime instance
    @returns {Integer} -1 if a < b,
                       +1 if a > b,
                       0 if a == b
  */
  compare: function(a, b) {
    if (SC.none(a) || SC.none(b)) throw new Error("You must pass two valid dates to compare()");
    var ma = a.get('milliseconds');
    var mb = b.get('milliseconds');
    return ma < mb ? -1 : ma === mb ? 0 : 1;
  },

  /**
    This will tell you which of the two passed DateTime is greater
    by only comparing the date parts of the passed objects. Only dates
    with the same timezone can be compared.

    @param {SC.DateTime} a the first DateTime instance
    @param {SC.DateTime} b the second DateTime instance
    @returns {Integer} -1 if a < b,
                       +1 if a > b,
                       0 if a == b
    @throws {SC.DATETIME_COMPAREDATE_TIMEZONE_ERROR} if the passed arguments
      don't have the same timezone
  */
  compareDate: function(a, b) {
    if (SC.none(a) || SC.none(b)) throw new Error("You must pass two valid dates to compareDate()");
    if (a.get('timezone') !== b.get('timezone')) SC.DATETIME_COMPAREDATE_TIMEZONE_ERROR.throw();
    var ma = a.adjust({hour: 0}).get('milliseconds');
    var mb = b.adjust({hour: 0}).get('milliseconds');
    return ma < mb ? -1 : ma === mb ? 0 : 1;
  },

  /**
    Returns the interval of time between the two passed in DateTimes in units
    according to the format.

    You can display the difference in weeks (w), days (d), hours (h), minutes (M)
    or seconds (S).

    @param {SC.DateTime} a the first DateTime instance
    @param {SC.DateTime} b the second DateTime instance
    @param {String} format the interval to get the difference in
  */
  difference: function(a, b, format) {
    if (SC.none(a) || SC.none(b)) throw new Error("You must pass two valid dates to difference()");
    var ma = a.get('milliseconds'),
        mb = b.get('milliseconds'),
        diff = mb - ma,
        divider;

    switch(format) {
    case 'd':
    case 'D':
      divider = 864e5;  // day: 1000 * 60 * 60 * 24
      break;
    case 'h':
    case 'H':
      divider = 36e5; // hour: 1000 * 60 * 60
      break;
    case 'M':
      divider = 6e4; // minute: 1000 * 60
      break;
    case 'S':
      divider = 1e3;  // second: 1000
      break;
    case 's':
      divider = 1;
      break;
    case 'W':
      divider = 6048e5; // week: 1000 * 60 * 60 * 24 * 7
      break;
    default:
      throw new Error(format + " is not supported");
    }

    var ret = diff/divider;

    return Math.round(ret);
  }



});

/**
  Adds a transform to format the DateTime value to a String value according
  to the passed format string.

      valueBinding: SC.Binding.dateTime('%Y-%m-%d %H:%M:%S')
                              .from('MyApp.myController.myDateTime');

  @param {String} format format string
  @returns {SC.Binding} this
*/
SC.Binding.dateTime = function (format) {
  return this.transform(function (value) {
    return value ? value.toFormattedString(format) : null;
  });
};


/* >>>>>>>>>> BEGIN javascript.js */
/* >>>>>>>>>> BEGIN source/lproj/strings.js */
// ==========================================================================
// Project: SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
// Portions ©2008-2011 Apple Inc. All rights reserved.
// License: Licensed under MIT license (see license.js)
// ==========================================================================

SC.stringsFor('English', {
  '_SC.DateTime.dayNames' : 'Sunday Monday Tuesday Wednesday Thursday Friday Saturday',
  '_SC.DateTime.abbreviatedDayNames' : 'Sun Mon Tue Wed Thu Fri Sat',
  '_SC.DateTime.monthNames' : 'January February March April May June July August September October November December',
  '_SC.DateTime.abbreviatedMonthNames' : 'Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec',
  '_SC.DateTime.AMPMNames' : 'AM PM',

  '_SC.DateTime.now' : 'Right now',
  '_SC.DateTime.secondIn' : 'In a moment',
  '_SC.DateTime.secondsIn' : 'In %e seconds',
  '_SC.DateTime.minuteIn' : 'In a minute',
  '_SC.DateTime.minutesIn' : 'In %e minutes',
  '_SC.DateTime.hourIn' : 'An hour from now',
  '_SC.DateTime.hoursIn' : 'In about %e hours',
  '_SC.DateTime.dayIn' : 'Tomorrow at %i:%M %p',
  '_SC.DateTime.daysIn' : '%A at %i:%M %p',
  '_SC.DateTime.weekIn' : 'Next week',
  '_SC.DateTime.weeksIn' : 'In %e weeks',
  '_SC.DateTime.monthIn' : 'Next month',
  '_SC.DateTime.monthsIn' : 'In %e months',
  '_SC.DateTime.yearIn' : 'Next year',
  '_SC.DateTime.yearsIn' : 'In %e years',

  '_SC.DateTime.secondAgo' : 'A moment ago',
  '_SC.DateTime.secondsAgo' : '%e seconds ago',
  '_SC.DateTime.minuteAgo' : 'A minute ago',
  '_SC.DateTime.minutesAgo' : '%e minutes ago',
  '_SC.DateTime.hourAgo' : 'An hour ago',
  '_SC.DateTime.hoursAgo' : 'About %e hours ago',
  '_SC.DateTime.dayAgo' : 'Yesterday at %i:%M %p',
  '_SC.DateTime.daysAgo' : '%A at %i:%M %p',
  '_SC.DateTime.weekAgo' : 'About a week ago',
  '_SC.DateTime.weeksAgo' : '%e weeks ago',
  '_SC.DateTime.monthAgo' : 'About a month ago',
  '_SC.DateTime.monthsAgo' : '%e months ago',
  '_SC.DateTime.yearAgo' : 'Last year',
  '_SC.DateTime.yearsAgo' : '%e years ago'
});

/* >>>>>>>>>> BEGIN source/system/datetime.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

SC.DateTime.mixin(
/** @scope SC.DateTime */ {

  /**
    @private

    Called on `document.ready`.

    Because localizations may have been modified by an application developer,
    we need to wait for the ready event to actually evaluate the localizations.
  */
  _setup: function() {
    SC.DateTime.dayNames = SC.String.w(SC.String.loc('_SC.DateTime.dayNames'));
    SC.DateTime.abbreviatedDayNames = SC.String.w(SC.String.loc('_SC.DateTime.abbreviatedDayNames'));
    SC.DateTime.monthNames = SC.String.w(SC.String.loc('_SC.DateTime.monthNames'));
    SC.DateTime.abbreviatedMonthNames = SC.String.w(SC.String.loc('_SC.DateTime.abbreviatedMonthNames'));
    SC.DateTime.AMPMNames = SC.String.w(SC.String.loc('_SC.DateTime.AMPMNames'));
  },
  
  /**
    @private
    
    Elapsed string formatting override, as it depends on localization.
    
    @see SC.DateTime#toFormattedString
   */
  __getElapsedStringFormat: function(start, timezone) {
    
    var elapsed = Math.floor((+new Date() - this._date.getTime() - (timezone * 60000)) / 1000);
    var future = !!(elapsed < 0) ? "In" : "Ago";
    var interval = 0;
    var intervalType = "now";
    
    if(Math.abs(elapsed) > 31536000) { // 60 * 60 * 24 * 365 - years
      interval = Math.floor(Math.abs(elapsed / 31536000));
      intervalType = 'year';
    } else if(Math.abs(elapsed) > 2678400) { // 60 * 60 * 24 * 31 - months
      interval = Math.floor(Math.abs(elapsed / 2678400));
      intervalType = 'month';
    } else if(Math.abs(elapsed) > 604800) { // 60 * 60 * 24 * 7 - weeks
      interval = Math.floor(Math.abs(elapsed / 604800));
      intervalType = 'week';
    } else if(Math.abs(elapsed) > 86400) { // 60 * 60 * 24 - day
      interval = Math.floor(Math.abs(elapsed / 86400));
      intervalType = 'day';
    } else if(Math.abs(elapsed) > 3600) { // 60 * 60 - hour
      interval = Math.floor(Math.abs(elapsed / 3600));
      intervalType = 'hour';
    } else if(Math.abs(elapsed) > 60) { // 60 - minute
      interval = Math.floor(Math.abs(elapsed / 60));
      intervalType = 'minute';
    } else if(Math.abs(elapsed) > 0) { // second
      interval = Math.abs(elapsed);
      intervalType = 'second';
    }
    
    var formatString = '_SC.DateTime.now';
    if(intervalType !== 'now') {
      formatString = "_SC.DateTime.%@%@%@".fmt(intervalType, interval > 1 ? "s" : "", future);
    }
    return formatString.loc().replace('%e', interval);
  },

});

jQuery(document).ready(function() {
  SC.DateTime._setup();
});


/* >>>>>>>>>> BEGIN javascript.js */
/* >>>>>>>>>> BEGIN source/mixins/websocket_delegate.js */
// ==========================================================================
// Project:   SC.WebSocket
// Copyright: ©2013 Nicolas BADIA and contributors
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/** 
  @namespace
  
  A WebSocket Delegate is consulted by `SC.WebSocket` when events are received.
  You may want to handle this events before propagate them to eventual listeners.

  Example:

    var ws = SC.WebSocket.create({
      server: 'ws://server',
      delegate: MyApp.WebSocketDelegate
    });
  
  @since SproutCore 1.11
  @author Nicolas BADIA
*/
SC.WebSocketDelegate = {
  
  /**
    Walk like a duck

    @type Boolean
  */
  isWebSocketDelegate: true,

  // ..........................................................
  // CALLBACKS
  //

  /**
    The passed webSocket connection is open.

    @param webSocket {SC.WebSocket} The webSocket object
    @param event {Event}
  */
  webSocketDidOpen: function (webSocket, event) {},

  /**
    A message has been received. Before processing it, you have
    a chance to check it. 

    For example, if `isJSON` is true, you will want to check if the message
    is a correct JSON.

    @param webSocket {SC.WebSocket} The webSocket object
    @param data {String}  
    @returns {String|Boolean} Return true to prevent further handling
  */
  webSocketDidReceiveMessage: function (webSocket, data) {
    switch(data) {
      case 'ping': return true; break;
    }

    if (this.get('isJSON')) {
      try {
        JSON.parse(data);
      }
      catch(e) {
        return true;
      }
    }
  },

  /**
    The websocket connection is close. Return true to prevent a
    reconnection or further handling.

    @param webSocket {SC.WebSocket} The webSocket object
    @param closeEvent {CloseEvent} The closeEvent
    @returns {Boolean} Return true to prevent further handling
  */
  webSocketDidClose: function (webSocket, closeEvent) {},

  /**
    Call when an error occur.

    @param webSocket {SC.WebSocket} The webSocket object
    @param event {Event} 
    @returns {Boolean} Return true to prevent further handling
  */
  webSocketDidError: function (webSocket, event) {},

};


/* >>>>>>>>>> BEGIN source/system/response.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
/*global ActiveXObject */

/**
  @class

  A response represents a single response from a server request and handles the communication to
  the server.  An instance of this class is returned whenever you call `SC.Request.send()`.

  SproutCore only defines one concrete subclass of `SC.Response`,`SC.XHRResponse`. In order to
  use `SC.Request` with a non-XHR request type you should create a custom class that extends
  `SC.Response` and set your custom class as the value of `responseClass` on all requests.

  For example,

      var request = SC.Request.getUrl(resourceAddress)
                              .set('responseClass', MyApp.CustomProtocolResponse)
                              .send();

  To extend `SC.Response`, please look at the property and methods listed below. For more examples,
  please look at the code in `SC.XHRResponse`.

  @extend SC.Object
  @since SproutCore 1.0
*/
SC.Response = SC.Object.extend(
/** @scope SC.Response.prototype */ {

  /**
    Walk like a duck

    @type Boolean
  */
  isResponse: YES,

  /**
    Becomes true if there was a failure.  Makes this into an error object.

    @type Boolean
    @default NO
  */
  isError: NO,

  /**
    Always the current response

    @field
    @type SC.Response
    @default `this`
  */
  errorValue: function() {
    return this;
  }.property().cacheable(),

  /**
    The error object generated when this becomes an error

    @type SC.Error
    @default null
  */
  errorObject: null,

  /**
    Request used to generate this response.  This is a copy of the original
    request object as you may have modified the original request object since
    then.

    To retrieve the original request object use originalRequest.

    @type SC.Request
    @default null
  */
  request: null,

  /**
    The request object that originated this request series.  Mostly this is
    useful if you are looking for a reference to the original request.  To
    inspect actual properties you should use request instead.

    @field
    @type SC.Request
    @observes request
  */
  originalRequest: function() {
    var ret = this.get('request');
    while (ret.get('source')) { ret = ret.get('source'); }
    return ret;
  }.property('request').cacheable(),

  /**
    Type of request. Must be an HTTP method. Based on the request.

    @field
    @type String
    @observes request
  */
  type: function() {
    return this.getPath('request.type');
  }.property('request').cacheable(),

  /**
    URL of request.

    @field
    @type String
    @observes request
  */
  address: function() {
    return this.getPath('request.address');
  }.property('request').cacheable(),

  /**
    If set then will attempt to automatically parse response as JSON
    regardless of headers.

    @field
    @type Boolean
    @default NO
    @observes request
  */
  isJSON: function() {
    return this.getPath('request.isJSON') || NO;
  }.property('request').cacheable(),

  /**
    If set, then will attempt to automatically parse response as XML
    regardless of headers.

    @field
    @type Boolean
    @default NO
    @observes request
  */
  isXML: function() {
    return this.getPath('request.isXML') || NO;
  }.property('request').cacheable(),

  /**
    Returns the hash of listeners set on the request.

    @field
    @type Hash
    @observes request
  */
  listeners: function() {
    return this.getPath('request.listeners');
  }.property('request').cacheable(),

  /**
    The response status code.

    @type Number
    @default -100
  */
  status: -100, // READY

  /**
    Headers from the response. Computed on-demand

    @type Hash
    @default null
  */
  headers: null,

  /**
    The response body or the parsed JSON. Returns a SC.Error instance
    if there is a JSON parsing error. If isJSON was set, will be parsed
    automatically.

    @field
    @type {Hash|String|SC.Error}
  */
  body: function() {
    // TODO: support XML
    // TODO: why not use the content-type header?
    var ret = this.get('encodedBody');
    if (ret && this.get('isJSON')) {
      try {
        ret = SC.json.decode(ret);
      } catch(e) {
        return SC.Error.create({
          message: e.name + ': ' + e.message,
          label: 'Response',
          errorValue: this });
      }
    }
    return ret;
  }.property('encodedBody').cacheable(),

  /**
    @private
    @deprecated Use body instead.

    Alias for body.

    @type Hash|String
    @see #body
  */
  response: function() {
    return this.get('body');
  }.property('body').cacheable(),

  /**
    Set to YES if response is cancelled

    @type Boolean
    @default NO
  */
  isCancelled: NO,

  /**
    Set to YES if the request timed out. Set to NO if the request has
    completed before the timeout value. Set to null if the timeout timer is
    still ticking.

    @type Boolean
    @default null
  */
  timedOut: null,

  /**
    The timer tracking the timeout

    @type Number
    @default null
  */
  timeoutTimer: null,


  // ..........................................................
  // METHODS
  //

  /**
    Called by the request manager when its time to actually run. This will
    invoke any callbacks on the source request then invoke transport() to
    begin the actual request.
  */
  fire: function() {
    var req = this.get('request'),
        source = req ? req.get('source') : null;

    // first give the source a chance to fixup the request and response
    // then freeze req so no more changes can happen.
    if (source && source.willSend) { source.willSend(req, this); }
    req.freeze();

    // if the source did not cancel the request, then invoke the transport
    // to actually trigger the request.  This might receive a response
    // immediately if it is synchronous.
    if (!this.get('isCancelled')) { this.invokeTransport(); }

    // If the request specified a timeout value, then set a timer for it now.
    var timeout = req.get('timeout');
    if (timeout) {
      var timer = SC.Timer.schedule({
        target: this,
        action: 'timeoutReached',
        interval: timeout,
        repeats: NO
      });
      this.set('timeoutTimer', timer);
    }

    // if the transport did not cancel the request for some reason, let the
    // source know that the request was sent
    if (!this.get('isCancelled') && source && source.didSend) {
      source.didSend(req, this);
    }
  },

  /**
    Called by `SC.Response#fire()`. Starts the transport by invoking the
    `SC.Response#receive()` function.
  */
  invokeTransport: function() {
    this.receive(function(proceed) { this.set('status', 200); }, this);
  },

  /**
    Invoked by the transport when it receives a response. The passed-in
    callback will be invoked to actually process the response. If cancelled
    we will pass NO. You should clean up instead.

    Invokes callbacks on the source request also.

    @param {Function} callback the function to receive
    @param {Object} context context to execute the callback in
    @returns {SC.Response} receiver
  */
  receive: function(callback, context) {
    if (!this.get('timedOut')) {
      // If we had a timeout timer scheduled, invalidate it now.
      var timer = this.get('timeoutTimer');
      if (timer) { timer.invalidate(); }
      this.set('timedOut', NO);
    }

    var req = this.get('request');
    var source = req ? req.get('source') : null;

    SC.run(function() {
      // invoke the source, giving a chance to fixup the response or (more
      // likely) cancel the request.
      if (source && source.willReceive) { source.willReceive(req, this); }

      // invoke the callback.  note if the response was cancelled or not
      callback.call(context, !this.get('isCancelled'));

      // if we weren't cancelled, then give the source first crack at handling
      // the response.  if the source doesn't want listeners to be notified,
      // it will cancel the response.
      if (!this.get('isCancelled') && source && source.didReceive) {
        source.didReceive(req, this);
      }

      // notify listeners if we weren't cancelled.
      if (!this.get('isCancelled')) { this.notify(); }
    }, this);

    // no matter what, remove from inflight queue
    SC.Request.manager.transportDidClose(this);
    return this;
  },

  /**
    Default method just closes the connection. It will also mark the request
    as cancelled, which will not call any listeners.
  */
  cancel: function() {
    if (!this.get('isCancelled')) {
      this.set('isCancelled', YES);
      this.cancelTransport();
      SC.Request.manager.transportDidClose(this);
    }
  },

  /**
    Default method just closes the connection.

    @returns {Boolean} YES if this response has not timed out yet, NO otherwise
  */
  timeoutReached: function() {
    // If we already received a response yet the timer still fired for some
    // reason, do nothing.
    if (this.get('timedOut') === null) {
      this.set('timedOut', YES);
      this.cancelTransport();

      // Invokes any relevant callbacks and notifies registered listeners, if
      // any. In the event of a timeout, we set the status to 0 since we
      // didn't actually get a response from the server.
      this.receive(function(proceed) {
        if (!proceed) { return; }

        // Set our value to an error.
        var error = SC.$error("HTTP Request timed out", "Request", 0);
        error.set("errorValue", this);
        this.set('isError', YES);
        this.set('errorObject', error);
        this.set('status', 0);
      }, this);

      return YES;
    }

    return NO;
  },

  /**
    Override with concrete implementation to actually cancel the transport.
  */
  cancelTransport: function() {},

  /**
    @private

    Will notify each listener. Returns true if any of the listeners handle.
  */
  _notifyListeners: function(listeners, status) {
    var notifiers = listeners[status], args, target, action;
    if (!notifiers) { return NO; }

    var handled = NO;
    var len = notifiers.length;

    for (var i = 0; i < len; i++) {
      var notifier = notifiers[i];
      args = (notifier.args || []).copy();
      args.unshift(this);

      target = notifier.target;
      action = notifier.action;
      if (SC.typeOf(action) === SC.T_STRING) { action = target[action]; }

      handled = action.apply(target, args);
    }

    return handled;
  },

  /**
    Notifies any saved target/action. Call whenever you cancel, or end.

    @returns {SC.Response} receiver
  */
  notify: function() {
    var listeners = this.get('listeners'),
        status = this.get('status'),
        baseStat = Math.floor(status / 100) * 100,
        handled = NO;

    if (!listeners) { return this; }

    handled = this._notifyListeners(listeners, status);
    if (!handled && baseStat !== status) { handled = this._notifyListeners(listeners, baseStat); }
    if (!handled && status !== 0) { handled = this._notifyListeners(listeners, 0); }

    return this;
  },

  /**
    String representation of the response object

    @returns {String}
  */
  toString: function() {
    var ret = arguments.callee.base.apply(this,arguments);
    return "%@<%@ %@, status=%@".fmt(ret, this.get('type'), this.get('address'), this.get('status'));
  }

});

/**
  @class

  Concrete implementation of `SC.Response` that implements support for using XHR requests. This is
  the default response class that `SC.Request` uses and it is able to create cross-browser
  compatible XHR requests to the address defined on a request and to notify according to the status
  code fallbacks registered on the request.

  You will not typically deal with this class other than to receive an instance of it when handling
  `SC.Request` responses. For more information on how to create a request and handle an XHR response,
  please @see SC.Request.

  @extends SC.Response
  @since SproutCore 1.0
*/
SC.XHRResponse = SC.Response.extend(
/** @scope SC.XHRResponse.prototype */{

  /**
    Implement transport-specific support for fetching all headers
  */
  headers: function() {
    var xhr = this.get('rawRequest'),
        str = xhr ? xhr.getAllResponseHeaders() : null,
        ret = {};

    if (!str) { return ret; }

    str.split("\n").forEach(function(header) {
      var idx = header.indexOf(':'),
          key, value;

      if (idx >= 0) {
        key = header.slice(0,idx);
        value = header.slice(idx + 1).trim();
        ret[key] = value;
      }
    }, this);

    return ret;
  }.property('status').cacheable(),

  /**
    Returns a header value if found.

    @param {String} key The header key
    @returns {String}
  */
  header: function(key) {
    var xhr = this.get('rawRequest');
    return xhr ? xhr.getResponseHeader(key) : null;
  },

  /**
    Implement transport-specific support for fetching tasks

    @field
    @type String
    @default #rawRequest
  */
  encodedBody: function() {
    var xhr = this.get('rawRequest');

    if (!xhr) { return null; }
    if (this.get('isXML')) { return xhr.responseXML; }

    return xhr.responseText;
  }.property('status').cacheable(),

  /**
    Cancels the request.
  */
  cancelTransport: function() {
    var rawRequest = this.get('rawRequest');
    if (rawRequest) { rawRequest.abort(); }
    this.set('rawRequest', null);
  },


  /**
    Starts the transport of the request

    @returns {XMLHttpRequest|ActiveXObject}
  */
  invokeTransport: function() {
    var listener, listeners, listenersForKey,
      rawRequest,
      request = this.get('request'),
      transport, handleReadyStateChange, async, headers;

    rawRequest = this.createRequest();
    this.set('rawRequest', rawRequest);

    // configure async callback - differs per browser...
    async = !!request.get('isAsynchronous');

    if (async) {
      if (SC.platform.get('supportsXHR2ProgressEvent')) {
        // XMLHttpRequest Level 2

        // Add progress event listeners that were specified on the request.
        listeners = request.get("listeners");
        if (listeners) {
          for (var key in listeners) {

            // Make sure the key is not an HTTP numeric status code.
            if (isNaN(parseInt(key, 10))) {
              // We still allow multiple notifiers on progress events, but we
              // don't try to optimize this by using a single listener, because
              // it is highly unlikely that the developer will add duplicate
              // progress event notifiers and if they did, it is also unlikely
              // that they would expect them to cascade in the way that the
              // status code notifiers do.
              listenersForKey = listeners[key];
              for (var i = 0, len = listenersForKey.length; i < len; i++) {
                listener = listenersForKey[i];

                var keyTarget = key.split('.');
                if (SC.none(keyTarget[1])) {
                  SC.Event.add(rawRequest, keyTarget[0], listener.target, listener.action, listener.args);
                } else {
                  SC.Event.add(rawRequest[keyTarget[0]], keyTarget[1], listener.target, listener.action, listener.args);
                }
              }
            }
          }
        }

        if (SC.platform.get('supportsXHR2LoadEndEvent')) {
          SC.Event.add(rawRequest, 'loadend', this, this.finishRequest);
        } else {
          SC.Event.add(rawRequest, 'load', this, this.finishRequest);
          SC.Event.add(rawRequest, 'error', this, this.finishRequest);
          SC.Event.add(rawRequest, 'abort', this, this.finishRequest);
        }
      } else if (window.XMLHttpRequest && rawRequest.addEventListener) {
        // XMLHttpRequest Level 1 + support for addEventListener (IE prior to version 9.0 lacks support for addEventListener)
        SC.Event.add(rawRequest, 'readystatechange', this, this.finishRequest);
      } else {
        transport = this;
        handleReadyStateChange = function() {
          if (!transport) { return null; }
          var ret = transport.finishRequest();
          if (ret) { transport = null; }
          return ret;
        };
        rawRequest.onreadystatechange = handleReadyStateChange;
      }
    }

    // initiate request.
    rawRequest.open(this.get('type'), this.get('address'), async);

    // headers need to be set *after* the open call.
    headers = this.getPath('request.headers');
    for (var headerKey in headers) {
      rawRequest.setRequestHeader(headerKey, headers[headerKey]);
    }

    // Do we need to allow Cookies for x-domain requests?
    if (!this.getPath('request.isSameDomain') && this.getPath('request.allowCredentials')) {
      rawRequest.withCredentials = true;
    }

    // now send the actual request body - for sync requests browser will
    // block here
    rawRequest.send(this.getPath('request.encodedBody'));
    if (!async) { this.finishRequest(); }

    return rawRequest;
  },

  /**
    Creates the correct XMLHttpRequest object for this browser.

    You can override this if you need to, for example, create an XHR on a
    different domain name from an iframe.

    @returns {XMLHttpRequest|ActiveXObject}
  */
  createRequest: function() {
    var rawRequest;

    // check native support first
    if (window.XMLHttpRequest) {
      rawRequest = new XMLHttpRequest();
    } else {
      // There are two relevant Microsoft MSXML object types.
      // See here for more information:
      // http://www.snook.ca/archives/javascript/xmlhttprequest_activex_ie/
      // http://blogs.msdn.com/b/xmlteam/archive/2006/10/23/using-the-right-version-of-msxml-in-internet-explorer.aspx
      // http://msdn.microsoft.com/en-us/library/windows/desktop/ms763742(v=vs.85).aspx
      try { rawRequest = new ActiveXObject("MSXML2.XMLHTTP.6.0");  } catch(e) {}
      try { if (!rawRequest) rawRequest = new ActiveXObject("MSXML2.XMLHTTP");  } catch(e) {}
    }

    return rawRequest;
  },

  /**
    @private

    Called by the XHR when it responds with some final results.

    @param {XMLHttpRequest} rawRequest the actual request
    @returns {Boolean} YES if completed, NO otherwise
  */
  finishRequest: function(evt) {
    var listener, listeners, listenersForKey,
      rawRequest = this.get('rawRequest'),
      readyState = rawRequest.readyState,
      request,
      error, status, msg;

    if (readyState === 4 && !this.get('timedOut')) {
      this.receive(function(proceed) {
        if (!proceed) { return; }

        // collect the status and decide if we're in an error state or not
        status = -1;
        try {
          status = rawRequest.status || 0;
          // IE mangles 204 to 1223. See http://bugs.jquery.com/ticket/1450 and many others
          status = status === 1223 ? 204 : status;
        } catch (e) {}

        // if there was an error - setup error and save it
        if ((status < 200) || (status >= 300)) {

          try {
            msg = rawRequest.statusText || '';
          } catch(e2) {
            msg = '';
          }

          error = SC.$error(msg || "HTTP Request failed", "Request", status);
          error.set("errorValue", this);
          this.set('isError', YES);
          this.set('errorObject', error);
        }

        // set the status - this will trigger changes on related properties
        this.set('status', status);
      }, this);

      // Avoid memory leaks
      if (SC.platform.get('supportsXHR2ProgressEvent')) {
        // XMLHttpRequest Level 2

        if (SC.platform.get('supportsXHR2LoadEndEvent')) {
          SC.Event.remove(rawRequest, 'loadend', this, this.finishRequest);
        } else {
          SC.Event.remove(rawRequest, 'load', this, this.finishRequest);
          SC.Event.remove(rawRequest, 'error', this, this.finishRequest);
          SC.Event.remove(rawRequest, 'abort', this, this.finishRequest);
        }

        request = this.get('request');
        listeners = request.get("listeners");
        if (listeners) {
          for (var key in listeners) {

            // Make sure the key is not an HTTP numeric status code.
            if (isNaN(parseInt(key, 10))) {
              listenersForKey = listeners[key];
              for (var i = 0, len = listenersForKey.length; i < len; i++) {
                listener = listenersForKey[i];

                var keyTarget = key.split('.');
                if (SC.none(keyTarget[1])) {
                  SC.Event.remove(rawRequest, keyTarget[0], listener.target, listener.action, listener.args);
                } else {
                  SC.Event.remove(rawRequest[keyTarget[0]], keyTarget[1], listener.target, listener.action, listener.args);
                }
              }
            }
          }
        }
      } else if (window.XMLHttpRequest && rawRequest.addEventListener) {
        // XMLHttpRequest Level 1 + support for addEventListener (IE prior to version 9.0 lacks support for addEventListener)
        SC.Event.remove(rawRequest, 'readystatechange', this, this.finishRequest);
      } else {
        rawRequest.onreadystatechange = null;
      }

      return YES;
    }
    return NO;
  }

});

/* >>>>>>>>>> BEGIN source/system/request.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('system/response');

/**
  @class

  Implements support for AJAX requests using XHR, XHR2 and other protocols.

  SC.Request is essentially a client version of the request/response objects you receive when
  implementing HTTP servers.

  To send a request, you just need to create your request object, configure your options, and call
  `send()` to initiate the request. The request will be added to the pending request queue managed
  by `SC.Request.manager`.

  For example,

      // Create a simple XHR request.
      var request = SC.Request.create();
      request.set('address', resourceAddress);
      request.set('type', 'GET');
      request.send();

  The previous example will create an XHR GET request to `resourceAddress`. Because the `address`
  and `type` of the request must be set on every request, there are helper methods on `SC.Request`
  that you will likely use in every situation.

  For example, the previous example can be written more concisely as,

      // Create a simple XHR request.
      var request = SC.Request.getUrl(resourceAddress);

  There are four other helper methods to cover the other common HTTP method types: `POST`, `DELETE`,
  `PUT` and `PATCH`, which are `postUrl`, `deleteUrl`, `putUrl` and `patchUrl` respectively. Since
  you may also send a body with `POST`, `PUT` and `PATCH` requests, those helper methods also take a
  second argument `body` (which is analogous to calling `request.set('body', body)`).

  ## Responses

  ### XHR Requests & Custom Communication Protocols

  By default, the request will create an instance of `SC.XHRResponse` in order to complete the
  request. As the name implies, the `SC.XHRResponse` class will make an XHR request to the server,
  which is the typical method that the SproutCore client will communicate with remote endpoints.

  In order to use a custom response type handler, you should extend `SC.Response` and set the
  `responseClass` of the request to your custom response type.

  For example,

      var request = SC.Request.getUrl(resourceAddress).set('responseClass', MyApp.CustomProtocolResponse);


  ### Handling Responses

  `SC.Request` supports multiple response handlers based on the status code of the response. This
  system is quite intelligent and allows for specific callbacks to handle specific status codes
  (e.g. 404) or general status codes (e.g. 400) or combinations of both. Callbacks are registered
  using the `notify` method, which accepts a `target` and a `method` which will be called when the
  request completes. The most basic example of registering a general response handler would be like
  so,

      // The response handler target (typically a state or controller or some such SC.Object instance).
      var targetObject;

      targetObject = SC.Object.create({

        handleResponse: function (response) {
          // Handle the various possible status codes.
          var status = response.get('status');
          if (status === 200) { // 200 OK
            // Do something.
          } else if (status < 400) { // i.e. 3xx
            // Do something.
          } else ...
        }

      });


      // Create a simple XHR request.
      var request;

      request = SC.Request.getUrl(resourceAddress)
                          .notify(targetObject, 'handleResponse')
                          .send();

  However, this approach requires that every response handler be able to handle all of the possible
  error codes that we may be able to handle in a more general manner. It's also more code for us
  to write to write all of the multiple condition statements. For this reason, the `notify` method
  accepts an optional status code argument *before* the target and method. You can use a generic
  status code (i.e. 400) or a specific status code (i.e. 404). If you use a generic status code, all
  statuses within that range will result in that callback being used.

  For example, here is a more specific example,

      // The response handler target (typically a data source or state or some such SC.Object instance).
      var targetObject;

      targetObject = SC.Object.create({

        gotOK: function (response) { // 2xx Successful
          // Do something.

          return true; // Return true to ensure that any following generic handlers don't run!
        },

        gotForbidden: function (response) { // 403 Forbidden
          // Do something.

          return true; // Return true to ensure that any following generic handlers don't run!
        },

        gotUnknownError: function (response) { // 3xx, 4xx (except 403), 5xx
          // Do something.
        }

      });


      // Create a simple XHR request.
      var request;

      request = SC.Request.getUrl(resourceAddress)
                          .notify(200, targetObject, 'gotOK')
                          .notify(403, targetObject, 'gotForbidden')
                          .notify(targetObject, 'gotUnknownError')
                          .send();

  Please note that the notifications will fall through in the order they are added if not handled.
  This means that the generic handler `gotUnknownError` will be called for any responses not caught
  by the other handlers. In this example, to ensure that `gotUnknownError` doesn't get called when a
  2xx or 403 response comes in, those handlers *return `true`*.

  Please also note that this design allows us to easily re-use handler methods. For example, we may
  choose to have `gotUnknownError` be the standard last resort fallback handler for all requests.

  For more examples, including handling of XHR2 progress events, please @see SC.Request.prototype.notify.

  ### Response Bodies & JSON Decoding

  The body of the response is the `body` property on the response object which is passed to the
  notify target method. For example,

      gotOK: function (response) { // 2xx Successful
        var body = response.get('body');

        // Do something.

        return true; // Return true to ensure that any following generic handlers don't run!
      },

  The type of the body will depend on what the server returns, but since it will typically be JSON,
  we have a built-in option to have the body be decoded into a JavaScript object automatically by
  setting `isJSON` to true on the request.

  For example,

      // Create a simple XHR request.
      var request;

      request = SC.Request.getUrl(resourceAddress)
                          .set('isJSON', true)
                          .notify(200, targetObject, 'gotOK')
                          .send();

  There is a helper method to achieve this as well, `json()`,

      // Create a simple XHR request.
      var request;

      request = SC.Request.getUrl(resourceAddress)
                          .json() // Set `isJSON` to true.
                          .notify(200, targetObject, 'gotOK')
                          .send();

  @extends SC.Object
  @extends SC.Copyable
  @extends SC.Freezable
  @since SproutCore 1.0
*/
SC.Request = SC.Object.extend(SC.Copyable, SC.Freezable,
/** @scope SC.Request.prototype */ {

  // ..........................................................
  // PROPERTIES
  //

  /**
    Whether to allow credentials, such as Cookies, in the request. While this has no effect on
    requests to the same domain, cross-domain requests require that the transport be configured to
    allow the inclusion of credentials such as Cookies.

    You can change this property using the chainable `credentials()` helper method (or set it directly).

    @type Boolean
    @default YES
  */
  allowCredentials: YES,

  /**
    Sends the request asynchronously instead of blocking the browser. You
    should almost always make requests asynchronous. You can change this
    options with the async() helper option (or simply set it directly).

    @type Boolean
    @default YES
  */
  isAsynchronous: YES,

  /**
    Processes the request and response as JSON if possible. You can change
    this option with the json() helper method.

    @type Boolean
    @default NO
  */
  isJSON: NO,

  /**
    Process the request and response as XML if possible. You can change this
    option with the xml() helper method.

    @type Boolean
    @default NO
  */
  isXML: NO,

  /**
    Specifies whether or not the request will have custom headers attached
    to it. By default, SC.Request attaches X-Requested-With and
    X-SproutCore-Version headers to all outgoing requests. This allows
    you to override that behavior.

    You may want to set this to NO if you are making simple CORS requests
    in compatible browsers. See <a href="http://www.w3.org/TR/cors/">CORS
    Spec for more information.</a>

    TODO: Add unit tests for this feature

    @type Boolean
    @default YES
  */
  attachIdentifyingHeaders: YES,

  /**
    Current set of headers for the request

    @field
    @type Hash
    @default {}
  */
  headers: function() {
    var ret = this._headers;
    if (!ret) { ret = this._headers = {}; }
    return ret;
  }.property().cacheable(),

  /**
    Whether the request is within the same domain or not. The response class may use this property
    to determine specific cross domain configurations.

    @field
    @type Boolean
  */
  isSameDomain: function () {
    var address = this.get('address'),
      urlRegex = /^([\w\+\.\-]+:)(?:\/\/([^\/?#:]*)(?::(\d+)|)|)/,
      location = window.location,
      parts, originParts;

      // This pattern matching strategy was taken from jQuery.
      parts = urlRegex.exec( address.toLowerCase()  );
      originParts = urlRegex.exec( location.href.toLowerCase() );

      return SC.none(parts) ||
        (parts[1] === originParts[1] &&  // protocol
         parts[2] === originParts[2] &&  // domain
         (parts[3] || (parts[1] === "http:" ? 80 : 443 ) ) === (originParts[3] || (originParts[1] === "http:" ? 80 : 443))); // port
  }.property('address').cacheable(),

  /**
    Underlying response class to actually handle this request. Currently the
    only supported option is SC.XHRResponse which uses a traditional
    XHR transport.

    @type SC.Response
    @default SC.XHRResponse
  */
  responseClass: SC.XHRResponse,

  /**
    The original request for copied requests.

    @property SC.Request
    @default null
  */
  source: null,

  /**
    The URL this request to go to.

    @type String
    @default null
  */
  address: null,

  /**
    The HTTP method to use.

    @type String
    @default 'GET'
  */
  type: 'GET',

  /**
    An optional timeout value of the request, in milliseconds. The timer
    begins when SC.Response#fire is actually invoked by the request manager
    and not necessarily when SC.Request#send is invoked. If this timeout is
    reached before a response is received, the equivalent of
    SC.Request.manager#cancel() will be invoked on the SC.Response instance
    and the didReceive() callback will be called.

    An exception will be thrown if you try to invoke send() on a request that
    has both a timeout and isAsyncronous set to NO.

    @type Number
    @default null
  */
  timeout: null,

  /**
    The body of the request.  May be an object if isJSON or isXML is set,
    otherwise should be a string.

    @type Object|String
    @default null
  */
  body: null,

  /**
    The body, encoded as JSON or XML if needed.

    @field
    @type Object|String
    @default #body
  */
  encodedBody: function() {
    // TODO: support XML
    var ret = this.get('body');
    if (ret && this.get('isJSON')) { ret = SC.json.encode(ret); }
    return ret;
  }.property('isJSON', 'isXML', 'body').cacheable(),


  // ..........................................................
  // CALLBACKS
  //

  /**
    Invoked on the original request object just before a copied request is
    frozen and then sent to the server. This gives you one last change to
    fixup the request; possibly adding headers and other options.

    If you do not want the request to actually send, call cancel().

    @param {SC.Request} request A copy of the request object, not frozen
    @param {SC.Response} response The object that will wrap the response
  */
  willSend: function(request, response) {},

  /**
    Invoked on the original request object just after the request is sent to
    the server. You might use this callback to update some state in your
    application.

    The passed request is a frozen copy of the request, indicating the
    options set at the time of the request.

    @param {SC.Request} request A copy of the request object, frozen
    @param {SC.Response} response The object that will wrap the response
    @returns {Boolean} YES on success, NO on failure
  */
  didSend: function(request, response) {},

  /**
    Invoked when a response has been received but not yet processed. This is
    your chance to fix up the response based on the results. If you don't
    want to continue processing the response call response.cancel().

    @param {SC.Request} request A copy of the request object, frozen
    @param {SC.Response} response The object that will wrap the response
  */
  willReceive: function(request, response) {},

  /**
    Invoked after a response has been processed but before any listeners are
    notified. You can do any standard processing on the request at this
    point. If you don't want to allow notifications to continue, call
    response.cancel()

    @param {SC.Request} request A copy of the request object, frozen
    @param {SC.Response} response The object that will wrap the response
  */
  didReceive: function(request, response) {},


  // ..........................................................
  // HELPER METHODS
  //

  /** @private */
  concatenatedProperties: 'COPY_KEYS',

  /** @private */
  COPY_KEYS: ['attachIdentifyingHeaders', 'allowCredentials', 'isAsynchronous', 'isJSON', 'isXML', 'address', 'type', 'timeout', 'body', 'responseClass', 'willSend', 'didSend', 'willReceive', 'didReceive'],

  /**
    Returns a copy of the current request. This will only copy certain
    properties so if you want to add additional properties to the copy you
    will need to override copy() in a subclass.

    @returns {SC.Request} new request
  */
  copy: function() {
    var ret = {},
        keys = this.COPY_KEYS,
        loc = keys.length,
        key;

    while(--loc >= 0) {
      key = keys[loc];
      if (this.hasOwnProperty(key)) {
        ret[key] = this.get(key);
      }
    }

    if (this.hasOwnProperty('listeners')) {
      ret.listeners = SC.copy(this.get('listeners'));
    }

    if (this.hasOwnProperty('_headers')) {
      ret._headers = SC.copy(this._headers);
    }

    ret.source = this.get('source') || this;

    return this.constructor.create(ret);
  },

  /**
    To set headers on the request object. Pass either a single key/value
    pair or a hash of key/value pairs. If you pass only a header name, this
    will return the current value of the header.

    @param {String|Hash} key
    @param {String} value
    @returns {SC.Request|Object} receiver
  */
  header: function(key, value) {
    var header, headers;

    if (SC.typeOf(key) === SC.T_STRING) {
      headers = this._headers;
      if (arguments.length === 1) {
        return headers ? headers[key] : null;
      } else {
        this.propertyWillChange('headers');
        if (!headers) { headers = this._headers = {}; }
        headers[key] = value;
        this.propertyDidChange('headers');
        return this;
      }

    // handle parsing hash of parameters
    } else if (value === undefined) {
      headers = key;
      this.beginPropertyChanges();
      for(header in headers) {
        if (!headers.hasOwnProperty(header)) { continue; }
        this.header(header, headers[header]);
      }
      this.endPropertyChanges();
      return this;
    }

    return this;
  },

  /**
    Clears the list of headers that were set on this request.
    This could be used by a subclass to blow-away any custom
    headers that were added by the super class.
  */
  clearHeaders: function() {
    this.propertyWillChange('headers');
    this._headers = {};
    this.propertyDidChange('headers');
  },

  /**
    Converts the current request to be asynchronous.

    @param {Boolean} flag YES to make asynchronous, NO or undefined. Default YES.
    @returns {SC.Request} receiver
  */
  async: function(flag) {
    if (flag === undefined) { flag = YES; }
    return this.set('isAsynchronous', flag);
  },

  /**
    Converts the current request to request allowing credentials or not.

    @param {Boolean} flag YES to request allowing credentials, NO to disallow credentials. Default YES.
    @returns {SC.Request} receiver
  */
  credentials: function(flag) {
    if (flag === undefined) { flag = YES; }
    return this.set('allowCredentials', flag);
  },

  /**
    Sets the maximum amount of time the request will wait for a response.

    @param {Number} timeout The timeout in milliseconds.
    @returns {SC.Request} receiver
  */
  timeoutAfter: function(timeout) {
    return this.set('timeout', timeout);
  },

  /**
    Converts the current request to use JSON.

    @param {Boolean} flag YES to make JSON, NO or undefined. Default YES.
    @returns {SC.Request} receiver
  */
  json: function(flag) {
    if (flag === undefined) { flag = YES; }
    if (flag) { this.set('isXML', NO); }
    return this.set('isJSON', flag);
  },

  /**
    Converts the current request to use XML.

    @param {Boolean} flag YES to make XML, NO or undefined. Default YES.
    @returns {SC.Request} recevier
  */
  xml: function(flag) {
    if (flag === undefined) { flag = YES; }
    if (flag) { this.set('isJSON', NO); }
    return this.set('isXML', flag);
  },

  /**
    Called just before a request is enqueued.  This will encode the body
    into JSON if it is not already encoded, and set identifying headers
  */
  _prep: function() {
    var hasContentType = !!this.header('Content-Type');

    if (this.get('attachIdentifyingHeaders')) {
      this.header('X-Requested-With', 'XMLHttpRequest');
      this.header('X-SproutCore-Version', SC.VERSION);
    }

    // Set the Content-Type header only if not specified and the request
    // includes a body.
    if (!hasContentType && !!this.get('body')) {
      if (this.get('isJSON')) {
        this.header('Content-Type', 'application/json');
      } else if (this.get('isXML')) {
        this.header('Content-Type', 'text/xml');
      }
    }
    return this;
  },

  /**
    Will fire the actual request. If you have set the request to use JSON
    mode then you can pass any object that can be converted to JSON as the
    body. Otherwise you should pass a string body.

    @param {String|Object} [body]
    @returns {SC.Response} New response object
  */
  send: function(body) {
    // Sanity-check: Be sure a timeout value was not specified if the request
    // is synchronous (because it wouldn't work).
    var timeout = this.get('timeout');
    if (timeout && !this.get('isAsynchronous')) {
      throw new Error("Timeout values cannot be used with synchronous requests");
    } else if (timeout === 0) {
      throw new Error("The timeout value must either not be specified or must be greater than 0");
    }

    if (body) { this.set('body', body); }
    return SC.Request.manager.sendRequest(this.copy()._prep());
  },

  /**
    Resends the current request. This is more efficient than calling send()
    for requests that have already been used in a send. Otherwise acts just
    like send(). Does not take a body argument.

    @returns {SC.Response} new response object
  */
  resend: function() {
    var req = this.get('source') ? this : this.copy()._prep();
    return SC.Request.manager.sendRequest(req);
  },

  /**
    Configures a callback to execute as a request progresses or completes. You
    must pass at least a target and action/method to this and optionally an
    event name or status code.

    You may also pass additional arguments which will then be passed along to
    your callback.

    ## Scoping With Status Codes

    If you pass a status code as the first argument to this method, the
    accompanying notification callback will only be called if the response
    status matches the status code. For example, if you pass 201 (or
    SC.Request.CREATED), the accompanying method will only be called if the
    response status from the server is also 201.

    You can also pass "generic" status codes such as 200, 300, or 400, which
    will be invoked anytime the status code is in the same range and if a more
    specific notifier was not registered first and returned YES.

    Finally, passing a status code of 0 or no status at all will cause your
    method to be executed no matter what the resulting status is unless a
    more specific notifier was registered first and returned YES.

    For example,

        var req = SC.Request.create({type: 'POST'});
        req.notify(201, this, this.reqWasCreated);  // Handle a specific status code
        req.notify(401, this, this.reqWasUnauthorized);  // Handle a specific status code
        req.notify(400, this, this.reqDidRedirect);  // Handle any 4xx status
        req.notify(this, function(response, arg1, arg2) {
          // do something
        }, arg1, arg2);  // Handle any status.  Also, passing additional arguments to the callback handler

    ## Notifying on Progress Events

    If you pass a progress event name your callback will be called each time
    the event fires on the response.  For example, the XMLHttpRequest Level 2
    specification defines several progress events: loadstart, progress, abort,
    error, load, timeout and loadend.  Therefore, when using the default
    SC.Request responseClass, SC.XHRResponse, you can be notified of each of
    these events by simply providing the matching event name.

    Note that many older browsers do not support XMLHttpRequest Level 2.  See
    http://caniuse.com/xhr2 for a list of supported browsers.

    For example,

      var req = SC.Request.create({type: 'GET'});
      req.notify('progress', this, this.reqDidProgress); // Handle 'progress' events
      req.notify('abort', this, this.reqDidAbort); // Handle 'abort' events
      req.notify('upload.progress', this, this.reqUploadDidProgress); // Handle 'progress' events on the XMLHttpRequestUpload
      req.send();

    ## Callback Format

    Your notification callback should expect to receive the Response object as
    the first parameter for status code notifications and the Event object for
    progress notifications; plus any additional parameters that you pass. If
    your callback handles the notification and to prevent further handling, it
    should return YES.

    @param [statusOrEvent] {Number|String} A Number status code or String Event name.
    @param target {Object} The target object for the callback action.
    @param action {String|Function} The method name or function to call on the target.
    @returns {SC.Request} The SC.Request object.
  */
  notify: function(statusOrEvent, target, action) {
    var args,
      i, len;

    


    // Normalize arguments
    if (SC.typeOf(statusOrEvent) !== SC.T_NUMBER && SC.typeOf(statusOrEvent) !== SC.T_STRING) {
      // Accept multiple additional arguments (Do so before shifting the arguments!)

      // Fast arguments access.
      // Accessing `arguments.length` is just a Number and doesn't materialize the `arguments` object, which is costly.
      args = new Array(arguments.length - 2); //  SC.A(arguments).slice(2)
      for (i = 0, len = args.length; i < len; i++) { args[i] = arguments[i + 2]; }

      // Shift the arguments
      action = target;
      target = statusOrEvent;
      statusOrEvent = 0;
    } else {
      // Accept multiple additional arguments.

      if (arguments.length > 3) {
        // Fast arguments access.
        // Accessing `arguments.length` is just a Number and doesn't materialize the `arguments` object, which is costly.
        args = new Array(arguments.length - 3); //  SC.A(arguments).slice(3)
        for (i = 0, len = args.length; i < len; i++) { args[i] = arguments[i + 3]; }
      } else {
        args = [];
      }
    }

    // Prepare listeners for this object and notification target.
    var listeners = this.get('listeners');
    if (!listeners) { this.set('listeners', listeners = {}); }
    if(!listeners[statusOrEvent]) { listeners[statusOrEvent] = []; }

    // Add another listener for the given status code or event name.
    listeners[statusOrEvent].push({target: target, action: action, args: args});

    return this;
  }

});

SC.Request.mixin(
/** @scope SC.Request */ {

  /**
    Helper method for quickly setting up a GET request.

    @param {String} address url of request
    @returns {SC.Request} receiver
  */
  getUrl: function(address) {
    return this.create().set('address', address).set('type', 'GET');
  },

  /**
    Helper method for quickly setting up a POST request.

    @param {String} address url of request
    @param {String} body
    @returns {SC.Request} receiver
  */
  postUrl: function(address, body) {
    var req = this.create().set('address', address).set('type', 'POST');
    if(body) { req.set('body', body) ; }
    return req ;
  },

  /**
    Helper method for quickly setting up a DELETE request.

    @param {String} address url of request
    @returns {SC.Request} receiver
  */
  deleteUrl: function(address) {
    return this.create().set('address', address).set('type', 'DELETE');
  },

  /**
    Helper method for quickly setting up a PUT request.

    @param {String} address url of request
    @param {String} body
    @returns {SC.Request} receiver
  */
  putUrl: function(address, body) {
    var req = this.create().set('address', address).set('type', 'PUT');
    if(body) { req.set('body', body) ; }
    return req ;
  },

  /**
    Helper method for quickly setting up a PATCH request.

    @param {String} address url of request
    @param {String} body
    @returns {SC.Request} receiver
  */
  patchUrl: function(address, body) {
    var req = this.create().set('address', address).set('type', 'PATCH');
    if(body) { req.set('body', body) ; }
    return req ;
  }

});

/* @private Gates loadend warning. */
SC.Request.WARN_ON_LOADEND = YES;

/**
  @class

  The request manager coordinates all of the active XHR requests. It will
  only allow a certain number of requests to be active at a time; queuing
  any others. This allows you more precise control over which requests load
  in which order.

  @since SproutCore 1.0
*/
SC.Request.manager = SC.Object.create(
/** @scope SC.Request.manager */{

  /**
    Maximum number of concurrent requests allowed. 6 for all browsers.

    @type Number
    @default 6
  */
  maxRequests: 6,

  /**
    Current requests that are inflight.

    @type Array
    @default []
  */
  inflight: [],

  /**
    Requests that are pending and have not been started yet.

    @type Array
    @default []
  */
  pending: [],


  // ..........................................................
  // METHODS
  //

  /**
    Invoked by the send() method on a request. This will create a new low-
    level transport object and queue it if needed.

    @param {SC.Request} request the request to send
    @returns {SC.Object} response object
  */
  sendRequest: function(request) {
    if (!request) { return null; }

    // create low-level transport.  copy all critical data for request over
    // so that if the request has been reconfigured the transport will still
    // work.
    var response = request.get('responseClass').create({ request: request });

    // add to pending queue
    this.get('pending').pushObject(response);
    this.fireRequestIfNeeded();

    return response;
  },

  /**
    Cancels a specific request. If the request is pending it will simply
    be removed. Otherwise it will actually be cancelled.

    @param {SC.Response} response a response object
    @returns {Boolean} YES if cancelled
  */
  cancel: function(response) {
    var pending = this.get('pending'),
        inflight = this.get('inflight');

    if (pending.indexOf(response) >= 0) {
      this.propertyWillChange('pending');
      pending.removeObject(response);
      this.propertyDidChange('pending');
      return YES;
    } else if (inflight.indexOf(response) >= 0) {
      response.cancel();

      inflight.removeObject(response);
      this.fireRequestIfNeeded();
      return YES;
    }

    return NO;
  },

  /**
    Cancels all inflight and pending requests.

    @returns {Boolean} YES if any items were cancelled.
  */
  cancelAll: function() {
    var pendingLen = this.getPath('pending.length'),
      inflightLen = this.getPath('inflight.length'),
      inflight = this.get('inflight'),
      pending = this.get('pending');

    if(pendingLen || inflightLen) {
      // Iterate backwards.
      for( var i = inflightLen - 1; i >= 0; i--) {
        // This will 'eventually' try to remove the request from
        // inflight, but it's not fast enough for us.
        var r = inflight.objectAt(i);
        r.cancel();
      }

      // Manually scrub the arrays without screwing up memory pointers.
      pending.replace(0, pendingLen);
      inflight.replace(0, inflightLen);

      return YES;

    }
    return NO;
  },

  /**
    Checks the inflight queue. If there is an open slot, this will move a
    request from pending to inflight.

    @returns {Object} receiver
  */
  fireRequestIfNeeded: function() {
    var pending = this.get('pending'),
        inflight = this.get('inflight'),
        max = this.get('maxRequests'),
        next;

    if ((pending.length>0) && (inflight.length<max)) {
      next = pending.shiftObject();
      inflight.pushObject(next);
      next.fire();
    }
  },

  /**
    Called by a response/transport object when finishes running. Removes
    the transport from the queue and kicks off the next one.
  */
  transportDidClose: function(response) {
    this.get('pending').removeObject(response);
    this.get('inflight').removeObject(response);
    this.fireRequestIfNeeded();
  },

  /**
    Checks if the response is in the pending queue.

    @param {SC.Response} response a response object
    @return {Boolean} is response in pending queue
  */
  isPending: function(response) {
    return this.get('pending').contains(response);
  },

  /**
    Checks if the response is in the inflight queue.

    @param {SC.Response} response a response object
    @return {Boolean} is response in inflight queue
  */
  isInFlight: function(response) {
    return this.get('inflight').contains(response);
  }

});

/* >>>>>>>>>> BEGIN source/system/websocket.js */
// ==========================================================================
// Project:   SC.WebSocket
// Copyright: ©2013 Nicolas BADIA and contributors
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('mixins/websocket_delegate');

/**
  @class

  Implements support for WebSocket.

  Example Usage:

    var ws = SC.WebSocket.create({
      server: 'ws://server',
    }).connect();

    ws.notify(this, 'wsReceivedMessage');

    ws.send('message');

  @since SproutCore 1.11
  @extends SC.Object
  @extends SC.DelegateSupport
  @author Nicolas BADIA
*/
SC.WebSocket = SC.Object.extend(SC.DelegateSupport, SC.WebSocketDelegate, {

  /**
    URL of the WebSocket server.

    @type String
    @default null
  */
  server: null,

  /**
    Determines if the browser support the WebSocket protocol.

    @type Boolean
    @default null
    @readOnly
  */
  isSupported: null,

  /**
    Determines if the connection is open or not.

    @type Boolean
    @readOnly
  */
  isConnected: false,

  /**
    In order to handle authentification, set `isAuth` to NO in the
    `webSocketDidOpen` delegate method just after sending a request to
    authentificate the connection. This way, any futher message will be put in
    queue until the server tels you the connection is authentified. Once it
    did, you should set `isAuth` to YES to resume the queue.

    If you don't need authentification, leave `isAuth` to null.

    @type Boolean
    @default null
  */
  isAuth: null,

  /**
    Processes the messages as JSON if possible.

    @type Boolean
    @default true
  */
  isJSON: true,

  /**
    A WebSocket delegate.

    @see SC.WebSocketDelegate
    @type {SC.WebSocketDelegate}
    @default null
  */
  delegate: null,

  /**
    Determines if we should attempt to try an automatic reconnection
    if the connection is close.

    @type {SC.WebSocketDelegate}
    @default null
  */
  autoReconnect: true,

  /**
    The interval in milliseconds to waits before trying a reconnection.

    @type {SC.WebSocketDelegate}
    @default null
  */
  reconnectInterval: 10000, // 10 secondes


  // ..........................................................
  // PUBLIC METHODS
  //

  /**
    Call this method to open a connection.

    @returns {SC.WebSocket}
  */
  connect: function() {
    var that = this;

    if (this.isSupported === null) this.set('isSupported', !!window.WebSocket);

    if (!this.isSupported || this.socket) return this;

    try {
      var socket = this.socket = new WebSocket(this.get('server'));

      socket.onopen = function() {
        SC.RunLoop.begin();
        that.onOpen.apply(that, arguments);
        SC.RunLoop.end();
      };

      socket.onmessage = function() {
        SC.RunLoop.begin();
        that.onMessage.apply(that, arguments);
        SC.RunLoop.end();
      };

      socket.onclose = function() {
        SC.RunLoop.begin();
        that.onClose.apply(that, arguments);
        SC.RunLoop.end();
      };

      socket.onerror = function() {
        SC.RunLoop.begin();
        that.onError.apply(that, arguments);
        SC.RunLoop.end();
      };
    } catch(e) {
      SC.error('An error has occurred while connnecting to the websocket server: '+e);
    }

    return this;
  },

  /**
    Call this method to close a connection.

    @param code {Number} A numeric value indicating the status code explaining why the connection is being closed. If this parameter is not specified, a default value of 1000 (indicating a normal "transaction complete" closure) is assumed.
    @param reason {String} A human-readable string explaining why the connection is closing. This string must be no longer than 123 bytes of UTF-8 text (not characters).
    @returns {SC.WebSocket}
  */
  close: function(code, reason) {
    var socket = this.socket;

    if (socket && socket.readyState === SC.WebSocket.OPEN) {
      this.socket.close(code, reason);
    }

    return this;
  },

  /**
    Configures a callback to execute when an event happen. You must pass
    at least a target and action/method to this and optionally an event name.

    You may also pass additional arguments which will then be passed along to
    your callback.

    Example:

        var websocket = SC.WebSocket.create({ server: 'ws://server' }).connect();

        webSocket.notify('onopen', this, 'wsWasOpen');
        webSocket.notify('onmessage', this, 'wsReceivedMessage'); // You can ommit onmessage here
        webSocket.notify('onclose', this, 'wsWasClose');
        webSocket.notify('onerror', this, 'wsDidError');

    ## Callback Format

    Your notification callback should expect to receive the WebSocket object as
    the first parameter and the event or message; plus any additional parameters that you pass. If your callback handles the notification and to prevent further handling, it
    should return YES.

    @param target {String} String Event name.
    @param target {Object} The target object for the callback action.
    @param action {String|Function} The method name or function to call on the target.
    @returns {SC.WebSocket} The SC.WebSocket object.
  */
  notify: function(event, target, action) {
    var args,
      i, len;

    if (SC.typeOf(event) !== SC.T_STRING) {
      // Fast arguments access.
      // Accessing `arguments.length` is just a Number and doesn't materialize the `arguments` object, which is costly.
      args = new Array(arguments.length - 2); //  SC.A(arguments).slice(2)
      for (i = 0, len = args.length; i < len; i++) { args[i] = arguments[i + 2]; }

      // Shift the arguments
      action = target;
      target = event;
      event = 'onmessage';
    } else {
      if (arguments.length > 3) {
        // Fast arguments access.
        // Accessing `arguments.length` is just a Number and doesn't materialize the `arguments` object, which is costly.
        args = new Array(arguments.length - 3); //  SC.A(arguments).slice(3)
        for (i = 0, len = args.length; i < len; i++) { args[i] = arguments[i + 3]; }
      } else {
        args = [];
      }
    }

    var listeners = this.get('listeners');
    if (!listeners) { this.set('listeners', listeners = {}); }
    if(!listeners[event]) { listeners[event] = []; }

    


    // Add another listener for the given event name.
    listeners[event].push({target: target, action: action, args: args});

    return this;
  },

  /**
    Send the passed message. If the connection is not yet open or anthentified,
    the message will be put in the queue.

    @param message {String|Object} The message to send.
    @returns {SC.WebSocket}
  */
  send: function(message) {
    if (this.isConnected === true && this.isAuth !== false) {
      if (this.isJSON) {
        message = JSON.stringify(message);
      }

      this.socket.send(message);
    }
    else {
      this.addToQueue(message);
    }
    return this;
  },

  // ..........................................................
  // PRIVATE METHODS
  //

  /**
     @private
  */
  onOpen: function(event) {
    var del = this.get('objectDelegate');

    this.set('isConnected', true);

    var ret = del.webSocketDidOpen(this, event);
    if (ret !== true) this._notifyListeners('onopen', event);

    this.fireQueue();
  },

  /**
     @private
  */
  onMessage: function(messageEvent) {
    if (messageEvent) {
      var del = this.get('objectDelegate'),
        message,
        data,
        ret;

      message = data = messageEvent.data;
      ret = del.webSocketDidReceiveMessage(this, data);

      if (ret !== true) {
        if (this.isJSON) {
          message = JSON.parse(data);
        }
        this._notifyListeners('onmessage', message);
      }
    }

    // If there is message in the queue, we fire them
    this.fireQueue();
  },

  /**
     @private
  */
  onClose: function(closeEvent) {
    var del = this.get('objectDelegate');

    this.set('isConnected', false);
    this.set('isAuth', null);
    this.socket = null;

    var ret = del.webSocketDidClose(this, closeEvent);

    if (ret !== true) {
      this._notifyListeners('onclose', closeEvent);
      this.tryReconnect();
    }
  },

  /**
     @private
  */
  onError: function(event) {
    var del = this.get('objectDelegate'),
      ret = del.webSocketDidError(this, event);

    if (ret !== true) this._notifyListeners('onerror', event);
  },

  /**
     @private

     Add the message to the queue
  */
  addToQueue: function(message) {
    var queue = this.queue;
    if (!queue) { this.queue = queue = []; }

    queue.push(message);
  },

  /**
     @private

     Send the messages from the queue.
  */
  fireQueue: function() {
    var queue = this.queue;
    if (!queue || queue.length === 0) return;

    queue = SC.A(queue);
    this.queue = null;

    for (var i = 0, len = queue.length; i < len; i++) {
      var message = queue[i];
      this.send(message);
    }
  },

  /**
    @private
  */
  tryReconnect: function() {
    if (!this.get('autoReconnect')) return;

    var that = this;
    setTimeout(function() { that.connect(); }, this.get('reconnectInterval'));
  },

  /**
    @private

    Will notify each listener. Returns true if any of the listeners handle.
  */
  _notifyListeners: function(event, message) {
    var listeners = (this.listeners || {})[event], notifier, target, action, args;
    if (!listeners) { return NO; }

    var handled = NO,
      len = listeners.length;

    for (var i = 0; i < len; i++) {
      notifier = listeners[i];
      args = (notifier.args || []).copy();
      args.unshift(message);
      args.unshift(this);

      target = notifier.target;
      action = notifier.action;
      if (SC.typeOf(action) === SC.T_STRING) { action = target[action]; }

      handled = action.apply(target, args);
      if (handled === true) return handled;
    }

    return handled;
  },

  /**
    @private
  */
  objectDelegate: function () {
    var del = this.get('delegate');
    return this.delegateFor('isWebSocketDelegate', del, this);
  }.property('delegate').cacheable(),

  // ..........................................................
  // PRIVATE PROPERTIES
  //

  /**
    @private

    @type WebSocket
    @default null
  */
  socket: null,

  /**
    @private

    @type Object
    @default null
  */
  listeners: null,

  /**
    @private

    Messages that needs to be send once the connection is open.

    @type Array
    @default null
  */
  queue: null,

});

// Class Methods
SC.WebSocket.mixin( /** @scope SC.WebSocket */ {

  // ..........................................................
  // CONSTANTS
  //

  /**
    The connection is not yet open.

    @static
    @constant
    @type Number
    @default 0
  */
  CONNECTING: 0,

  /**
    The connection is open and ready to communicate.

    @static
    @constant
    @type Number
    @default 1
  */
  OPEN: 1,

  /**
    The connection is in the process of closing.

    @static
    @constant
    @type Number
    @default 2
  */
  CLOSING: 2,

  /**
    The connection is closed or couldn't be opened.

    @static
    @constant
    @type Number
    @default 3
  */
  CLOSED: 3,

});


/* >>>>>>>>>> BEGIN javascript.js */
/* >>>>>>>>>> BEGIN source/core.js */

/**
  If true, then all SproutCore controls can be focused when the user presses the
  tab key. Otherwise, only `SC.TextFieldView`'s will be focused.

  @type Boolean
  @default false
  @constant
*/
SC.FOCUS_ALL_CONTROLS = false;

/* >>>>>>>>>> BEGIN source/mixins/tree_item_content.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @namespace

  A tree item is a model object that acts as a node in a tree-like data
  structure such as a hierarchy of folders or outline of items.  This mixin
  can be applied to tree item model objects to customize the way the tree
  information is extracted from the object.

  ## Basic Implementation

  If you add this mixin, you must implement the treeItemChildren property so
  that it returns the current array of child tree items for the receiver.  If
  you do not implement this property the tree item will not function.

  ## Optimizing Branches

  The most common use of this mixin is to override the treeItemBranchIndexes
  property to return an index set of child items that are themselves branches
  in the tree.  Normally the TreeController will need to walk every item in
  your list to determine these branch items.  However by implementing this
  method yourself, you can provide a result faster.

  If none of your child items are branches, override this property to return
  null or an empty index set.

  @since SproutCore 1.0
*/
SC.TreeItemContent = {

  /**
    Walk like a duck.

    @type Boolean
    @default YES
  */
  isTreeItemContent: YES,

  /**
    Property returns the children for this tree item.  The default simply
    returns null.  If you implement this mixin, you MUST implement this
    property to return the actual tree item children for the item.

    @type SC.Array
    @default null
  */
  treeItemChildren: null,

  /**
    The default property used to determine if the tree item is expanded.  You
    can implement you model object to update this property or you can override
    treeItemDisclosureState() to compute the disclosure state however you
    want.

    @type Boolean
    @default YES
  */
  treeItemIsExpanded: YES,

  /**
    Indicates whether the tree item should be rendered as a group or not.
    This property is only useful on the root item in your tree.  Setting it to
    YES on any other item will be ignored.

    @type Boolean
    @default NO
  */
  treeItemIsGrouped: NO,

  /**
    Returns the disclosure state for the tree item, which appears at the
    index of the parent's treeItemChildren array.  The response must be one of
    SC.BRANCH_OPEN, SC.BRANCH_CLOSED or SC.LEAF_NODE.

    If the parent parameter is null, then this item is part of the root
    children array.

    This method will only be called for tree items that have children.  Tree
    items with no children are assumed to be leaf nodes.

    The default implementation uses the treeItemIsExpanded property to
    determine if the item should be open or closed.

    @param {Object} parent the parent item containing this item
    @param {Number} idx the index of the item in the parent
    @returns {Number} branch state
  */
  treeItemDisclosureState: function(parent, idx) {
    return this.get('treeItemIsExpanded') ? SC.BRANCH_OPEN : SC.BRANCH_CLOSED;
  },

  /**
    Collapse the tree item.  The default implementation will change the
    treeItemIsExpanded property, but you can override this method to handle
    collapsing anyway you like.

    @param {Object} parent the parent item containing this item
    @param {Number} idx the index of the item in the parent
    @returns {void}
  */
  treeItemCollapse: function(parent, idx) {
    this.setIfChanged('treeItemIsExpanded', NO);
  },

  /**
    Expand the tree item.  The default implementation will change the
    treeItemIsExpanded property, but you can override this method to handle
    collapsing anyway you like.

    @param {Object} parent the parent item containing this item
    @param {Number} idx the index of the item in the parent
    @returns {void}
  */
  treeItemExpand: function(parent, idx) {
    this.setIfChanged('treeItemIsExpanded', YES);
  },

  /**
    Returns an index set containing the child indexes of the item that are
    themselves branches.  This will only be called on tree items with a branch
    disclosure state.

    If the passed parent and index are both null, then the receiver is the
    root node in the tree.

    The default implementation iterates over the item's children to get the
    disclosure state of each one.  Child items with a branch disclosure state
    will have their index added to the return index set.

    You may want to override this method to provide a more efficient
    implementation if you are working with large data sets and can infer which
    children are branches without iterating over each one.

    If you know for sure that all of the child items for this item are leaf
    nodes and not branches, simply override this method to return null.

    @param {Object} parent the parent item containing this item
    @param {Number} index the index of the item in the parent
    @returns {SC.IndexSet} branch indexes
  */
  treeItemBranchIndexes: function(parent, index) {
    var children = this.get('treeItemChildren'),
        ret, lim, idx, item;

    if (!children) return null ; // nothing to do

    ret = SC.IndexSet.create();
    lim = children.get('length');
    for(idx=0;idx<lim;idx++) {
      if (!(item = children.objectAt(idx))) continue;
      if (!item.get('treeItemChildren')) continue;
      if (item.treeItemDisclosureState(this,idx)!==SC.LEAF_NODE) ret.add(idx);
    }

    return ret.get('length')>0 ? ret : null;
  }

};

/* >>>>>>>>>> BEGIN source/mixins/collection_content.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  Used for contentIndexDisclosureState().  Indicates open branch node.

  @type Number
  @constant
*/
SC.BRANCH_OPEN = 0x0011;

/**
  Used for contentIndexDisclosureState().  Indicates closed branch node.

  @type Number
  @constant
*/
SC.BRANCH_CLOSED = 0x0012;

/**
  Used for contentIndexDisclosureState().  Indicates leaf node.

  @type Number
  @constant
*/
SC.LEAF_NODE = 0x0020;

/**
  @namespace

  This mixin provides standard methods used by a CollectionView to provide
  additional meta-data about content in a collection view such as selection
  or enabled state.

  You can apply this mixin to a class that you set as a delegate or to the
  object you set as content.

  @since SproutCore 1.0
*/
SC.CollectionContent = {

  /**
    Used to detect the mixin by SC.CollectionView

    @type Boolean
  */
  isCollectionContent: YES,

  /**
    Return YES if the content index should be selected.  Default behavior
    looks at the selection property on the view.

    @param {SC.CollectionView} collection the collection view
    @param {SC.Array} content the content object
    @param {Number} idx the content index
    @returns {Boolean} YES, NO, or SC.MIXED_STATE
  */
  contentIndexIsSelected: function(collection, content, idx) {
    var sel = collection.get('selection');
    return sel ? sel.contains(content, idx) : NO ;
  },

  /**
    Returns YES if the content index should be enabled.  Default looks at the
    isEnabled state of the collection view.

    @param {SC.CollectionView} collection the collection view
    @param {SC.Array} content the content object
    @param {Number} idx the content index
    @returns {Boolean} YES, NO, or SC.MIXED_STATE
  */
  contentIndexIsEnabled: function(collection, content, idx) {
    return collection.get('isEnabled');
  },

  // ..........................................................
  // GROUPING
  //

  /**
    Optionally return an index set containing the indexes that may be group
    views.  For each group view, the delegate will actually be asked to
    confirm the view is a group using the contentIndexIsGroup() method.

    If grouping is not enabled, return null.

    @param {SC.CollectionView} collection the calling view
    @param {SC.Array} content the content object
    @return {SC.IndexSet}
  */
  contentGroupIndexes: function(collection, content) {
    return null;
  },

  /**
    Returns YES if the item at the specified content index should be rendered
    using the groupExampleView instead of the regular exampleView.  Note that
    a group view is different from a branch/leaf view.  Group views often
    appear with different layout and a different look and feel.

    Default always returns NO.

    @param {SC.CollectionView} collection the collection view
    @param {SC.Array} content the content object
    @param {Number} idx the content index
    @returns {Boolean} YES, NO, or SC.MIXED_STATE
  */
  contentIndexIsGroup: function(collection, content, idx) {
    return NO ;
  },

  // ..........................................................
  // OUTLINE VIEWS
  //

  /**
    Returns the outline level for the item at the specified index.  Can be
    used to display hierarchical lists.

    Default always returns -1 (no outline).

    @param {SC.CollectionView} collection the collection view
    @param {SC.Array} content the content object
    @param {Number} idx the content index
    @returns {Boolean} YES, NO, or SC.MIXED_STATE
  */
  contentIndexOutlineLevel: function(collection, content, idx) {
    return -1;
  },

  /**
    Returns a constant indicating the disclosure state of the item.  Must be
    one of SC.BRANCH_OPEN, SC.BRANCH_CLOSED, SC.LEAF_NODE.  If you return one
    of the BRANCH options then the item may be rendered with a disclosure
    triangle open or closed.  If you return SC.LEAF_NODe then the item will
    be rendered as a leaf node.

    Default returns SC.LEAF_NODE.

    @param {SC.CollectionView} collection the collection view
    @param {SC.Array} content the content object
    @param {Number} idx the content index
    @returns {Boolean} YES, NO, or SC.MIXED_STATE
  */
  contentIndexDisclosureState: function(collection, content, idx) {
    return SC.LEAF_NODE;
  },

  /**
    Called to expand a content index item if it is currently in a closed
    disclosure state.  The default implementation does nothing.

    @param {SC.CollectionView} collection the collection view
    @param {SC.Array} content the content object
    @param {Number} idx the content index
    @returns {void}
  */
  contentIndexExpand: function(collection, content, idx) {
    SC.Logger.log('contentIndexExpand(%@, %@, %@)'.fmt(collection, content, idx));
  },

  /**
    Called to collapse a content index item if it is currently in an open
    disclosure state.  The default implementation does nothing.

    @param {SC.CollectionView} collection the collection view
    @param {SC.Array} content the content object
    @param {Number} idx the content index
    @returns {void}
  */
  contentIndexCollapse: function(collection, content, idx) {
    SC.Logger.log('contentIndexCollapse(%@, %@, %@)'.fmt(collection, content, idx));
  }

};

/* >>>>>>>>>> BEGIN source/private/tree_item_observer.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('mixins/tree_item_content');
sc_require('mixins/collection_content');

/**
  @ignore
  @class

  A TreeNode is an internal class that will manage a single item in a tree
  when trying to display the item in a hierarchy.

  When displaying a tree of objects, a tree item object will be nested to
  cover every object that might have child views, ignoring those that will
  definitely not. (Any node which has children or may have children should
  advertise this by exposing an array at its treeItemChildrenKey property;
  any node which does not do so is assumed to be permanently childless, so
  we optimize by not observing it. In CS terms, nodes can implicitly
  advertise whether they are *leaves-or-branches* and should be observed,
  or are *permanently leaves*, and may remain unobserved.)

  TreeNode stores an array which contains either a number pointing to the
  next place in the array there is a child item or it contains a child item.

  @extends SC.Object
  @extends SC.Array
  @extends SC.CollectionContent
  @since SproutCore 1.0
*/
SC.TreeItemObserver = SC.Object.extend(SC.Array, SC.CollectionContent, {

  


  /** @private */
  _cachedItem: null,

  /** @private */
  _cachedDelegate: null,

  /**
    The node in the tree this observer will manage.  Set when creating the
    object.  If you are creating an observer manually, you must set this to
    a non-null value.
  */
  item: null,

  /**
    The controller delegate.  If the item does not implement the
    TreeItemContent method, delegate properties will be used to determine how
    to access the content.  Set automatically when a tree item is created.

    If you are creating an observer manually, you must set this to a non-null
    value.
  */
  delegate: null,

  /**
    The key used to retrieve children from the observed item. If a
    delegate exists, the key will be the value of the `treeItemChildrenKey`
    property of the delegate. Otherwise, the key will be `treeItemChildren`.

    @type String
    @default 'treeItemChildren'
  */
  treeItemChildrenKey: 'treeItemChildren',

  /**
    The key used to identify the expanded state of the observed item.
    If a delegate exists, the key will be the value of the `treeItemIsExpandedKey`
    property of the delegate. Otherwise, the key will be `treeItemIsExpanded`.

    @type String
    @default 'treeItemIsExpanded'
  */
  treeItemIsExpandedKey: 'treeItemIsExpanded',

  // ..........................................................
  // FOR NESTED OBSERVERS
  //

  /**
    The parent TreeItemObserver for this observer.  Must be set on create.
  */
  parentObserver: null,

  /**
    The parent item for the observer item.  Computed automatically from the
    parent.  If the value of this is null, then this is the root of the tree.
  */
  parentItem: function () {
    var p = this.get('parentObserver');
    return p ? p.get('item') : null;
  }.property('parentObserver').cacheable(),

  /**
    Index location in parent's children array.  If this is the root item
    in the tree, should be null.
  */
  index: null,

  outlineLevel: 0,

  // ..........................................................
  // EXTRACTED FROM ITEM
  //

  /**
    Array of child tree items.  Extracted from the item automatically on init.
  */
  children: null,

  /**
    Disclosure state of this item.  Must be SC.BRANCH_OPEN or SC.BRANCH_CLOSED
    If this is the root of a item tree, the observer will have children but
    no parent or parent item.  IN this case the disclosure state is always
    SC.BRANCH_OPEN.

    @property
    @type Number
  */
  disclosureState: SC.BRANCH_OPEN,

  /**
    IndexSet of children with branches.  This will ask the delegate to name
    these indexes.  The default implementation will iterate over the children
    of the item but a more optimized version could avoid touching each item.

    @property
    @type SC.IndexSet
  */
  branchIndexes: function () {
    var item = this.get('item'),
        len, pitem, idx, children, ret;

    // no item - no branches
    if (!item) return SC.IndexSet.EMPTY;

    // if item is treeItemContent then ask it directly
    else if (item.isTreeItemContent) {
      pitem  = this.get('parentItem');
      idx    = this.get('index');
      return item.treeItemBranchIndexes(pitem, idx);

    // otherwise, loop over children and determine disclosure state for each
    } else {
      children = this.get('children');
      if (!children) return null; // no children - no branches
      ret = SC.IndexSet.create();
      len = children.get('length');
      pitem = item; // save parent

      for (idx = 0; idx < len; idx++) {
        item = children.objectAt(idx);
        if (!item) continue;
        if (!this._computeChildren(item, pitem, idx)) continue; // no children
        if (this._computeDisclosureState(item, pitem, idx) !== SC.LEAF_NODE) {
          ret.add(idx);
        }
      }

      return ret.get('length') > 0 ? ret : null;
    }
  }.property('children').cacheable(),

  /**
    Returns YES if the item itself should be shown, NO if only its children
    should be shown.  Normally returns YES unless the parentObject is null.
  */
  isHeaderVisible: function () {
    return !!this.get('parentObserver');
  }.property('parentObserver').cacheable(),

  /**
    Get the current length of the tree item including any of its children.
  */
  length: 0,

  // ..........................................................
  // SC.ARRAY SUPPORT
  //

  /**
    Get the object at the specified index.  This will talk the tree info
    to determine the proper place.  The offset should be relative to the
    start of this tree item.  Calls recursively down the tree.

    This should only be called with an index you know is in the range of item
    or its children based on looking at the length.

    @param {Number} index
    @param {Boolean} omitMaterializing
    @returns {Object}
  */
  objectAt: function (index, omitMaterializing) {
    var len   = this.get('length'),
        item  = this.get('item'),
        cache = this._objectAtCache,
        cur   = index,
        indexes, children;

    if (index >= len) return undefined;
    if (this.get('isHeaderVisible')) {
      if (index === 0) return item;
      else cur--;
    }
    item = null;

    if (!cache) cache = this._objectAtCache = [];
    if ((item = cache[index]) !== undefined) return item;

    children = this.get('children');
    if (!children) return undefined; // no children - nothing to get

    // loop through branch indexes, reducing the offset until it matches
    // something we might actually return.
    indexes = this.get('branchIndexes');
    if (indexes) {
      indexes.forEach(function (i) {
        if (item || (i > cur)) return; // past end - nothing to do

        var observer = this.branchObserverAt(i), len;
        if (!observer) return; // nothing to do

        // if cur lands inside of this observer's length, use objectAt to get
        // otherwise, just remove len from cur.
        len = observer.get('length');
        if (i + len > cur) {
          item = observer.objectAt(cur - i, omitMaterializing);
          cur = -1;
        } else {
          cur = cur - (len - 1);
        }

      }, this);
    }

    if (cur >= 0) item = children.objectAt(cur, omitMaterializing); // get internal if needed
    cache[index] = item; // save in cache

    return item;
  },

  /**
    Implements SC.Array.replace() primitive.  For this method to succeed, the
    range you replace must lie entirely within the same parent item, otherwise
    this will raise an exception.

    ### The Operation Parameter

    Note that this replace method accepts an additional parameter "operation"
    which is used when you try to insert an item on a boundary between
    branches whether it should be inserted at the end of the previous group
    after the group.  If you don't pass operation, the default is
    SC.DROP_BEFORE, which is the expected behavior.

    Even if the operation is SC.DROP_AFTER, you should still pass the actual
    index where you expect the item to be inserted.  For example, if you want
    to insert AFTER the last index of an 3-item array, you would still call:

        observer.replace(3, 0, [object1 .. objectN], SC.DROP_AFTER)

    The operation is simply used to disambiguate whether the insertion is
    intended to be AFTER the previous item or BEFORE the items you are
    replacing.

    @param {Number} start the starting index
    @param {Number} amt the number of items to replace
    @param {SC.Array} objects array of objects to insert
    @param {Number} operation either SC.DROP_BEFORE or SC.DROP_AFTER
    @returns {SC.TreeItemObserver} receiver
  */
  replace: function (start, amt, objects, operation) {

    var cur = start,
        observer = null,
        indexes, len, max;

    if (operation === undefined) operation = SC.DROP_BEFORE;

    // adjust the start location based on branches, possibly passing on to an
    // observer.
    if (this.get('isHeaderVisible')) cur--; // exclude my own header item
    if (cur < 0) throw new Error("Tree Item cannot replace itself");

    // remove branch lengths.  If the adjusted start location lands inside of
    // another branch, then just let that observer handle it.
    indexes = this.get('branchIndexes');
    if (indexes) {
      indexes.forEach(function (i) {
        if (observer || (i >= cur)) return; // nothing to do
        observer = this.branchObserverAt(i);
        if (!observer) return; // nothing to do

        len = observer.get('length');

        // if this branch range is before the start loc, just remove it and
        // go on.  If cur is somewhere inside of the range, then save to pass
        // on.  Note use of operation to determine the ambiguous end op.
        if ((i + len === cur) && operation === SC.DROP_AFTER) {
          cur = cur - i;
        } else if (i + len > cur) {
          cur = cur - i; // put inside of nested range
        } else {
          cur = cur - (len - 1);
          observer = null;
        }
      }, this);
    }

    // if an observer was saved, pass on call.
    if (observer) {
      observer.replace(cur, amt, objects, operation);
      return this;
    }

    // no observer was saved, which means cur points to an index inside of
    // our own range.  Now amt just needs to be adjusted to remove any
    // visible branches as well.
    max = cur + amt;
    if (amt > 1 && indexes) { // if amt is 1 no need...
      indexes.forEachIn(cur, indexes.get('max') - cur, function (i) {
        if (i > max) return; // nothing to do
        if (!(observer = this.branchObserverAt(i))) return; // nothing to do
        len = observer.get('length');
        max = max - (len - 1);
      }, this);
    }

    // get amt back out.  if amt is negative, it means that the range passed
    // was not cleanly inside of this range.  raise an exception.
    amt = max - cur;

    // ok, now that we are adjusted, get the children and forward the replace
    // call on.  if there are no children, bad news...
    var children = this.get('children');
    if (!children) throw new Error("cannot replace() tree item with no children");

    if ((amt < 0) || (max > children.get('length'))) {
      throw new Error("replace() range must lie within a single tree item");
    }

    children.replace(cur, amt, objects, operation);

    // don't call enumerableContentDidChange() here because, as an observer,
    // we should be notified by the children array itself.

    return this;
  },

  /**
    Called whenever the content for the passed observer has changed.  Default
    version notifies the parent if it exists and updates the length.

    The start, amt and delta params should reflect changes to the children
    array, not to the expanded range for the wrapper.
  */
  observerContentDidChange: function (start, amt, delta) {

    // clear caches
    this.invalidateBranchObserversAt(start);
    this._objectAtCache = this._outlineLevelCache = null;
    this._disclosureStateCache = null;
    this.notifyPropertyChange('branchIndexes');

    var oldlen = this.get('length'),
        newlen = this._computeLength(),
        parent = this.get('parentObserver'), set;

    // update length if needed
    if (oldlen !== newlen) {
      this.set('length', newlen);
    }

    // if we have a parent, notify that parent that we have changed.
    if (!this._notifyParent) return this; // nothing more to do

    if (parent) {
      set = SC.IndexSet.create(this.get('index'));
      parent._childrenRangeDidChange(parent.get('children'), null, '[]', set);

    // otherwise, note the enumerable content has changed.  note that we need
    // to convert the passed change to reflect the computed range
    } else {
      if (oldlen === newlen) {
        amt = this.expandChildIndex(start + amt);
        start = this.expandChildIndex(start);
        amt = amt - start;
        delta = 0;

      } else {
        start = this.expandChildIndex(start);
        amt   = newlen - start;
        delta = newlen - oldlen;
      }

      var removedCount = amt;
      var addedCount = delta + removedCount;
      this.arrayContentDidChange(start, removedCount, addedCount);
    }
  },

  /**
    Accepts a child index and expands it to reflect any nested groups.
  */
  expandChildIndex: function (index) {

    var ret = index;
    if (this.get('isHeaderVisible')) index++;

    // fast path
    var branches = this.get('branchIndexes');
    if (!branches || branches.get('length') === 0) return ret;

    // we have branches, adjust for their length
    branches.forEachIn(0, index, function (idx) {
      ret += this.branchObserverAt(idx).get('length') - 1;
    }, this);

    return ret; // add 1 for item header
  },

  // ..........................................................
  // SC.COLLECTION CONTENT SUPPORT
  //

  /** SC.CollectionContent
    Called by the collection view to return any group indexes.  The default
    implementation will compute the indexes one time based on the delegate
    treeItemIsGrouped
  */
  contentGroupIndexes: function (view, content) {
    var ret;

    if (content !== this) return null; // only care about receiver

    // If this is not the root item, never do grouping
    if (this.get('parentObserver')) return null;

    var item = this.get('item'), group, indexes, cur, padding;

    if (item && item.isTreeItemContent) group = item.get('treeItemIsGrouped');
    else group = !!this.delegate.get('treeItemIsGrouped');

    // If grouping is enabled, build an index set with all of our local groups.
    if (group) {
      ret      = SC.IndexSet.create();
      indexes  = this.get('branchIndexes');

      if (indexes) {
        // Start at the minimum index, which is equal for the tree and flat array
        cur = indexes.min();

        // Padding is the difference between the tree index and array index for the current tree index
        padding = 0;
        indexes.forEach(function (i) {
          ret.add(i + padding, 1);

          var observer = this.branchObserverAt(i);
          if (observer) {
            padding += observer.get('length') - 1;
            cur += padding;
          }
        }, this);
      }
    } else {
      ret = null;
    }

    return ret;
  },

  /** SC.CollectionContent */
  contentIndexIsGroup: function (view, content, idx) {
    var indexes = this.contentGroupIndexes(view, content);
    return indexes ? indexes.contains(idx) : NO;
  },

  /**
    Returns the outline level for the specified index.
  */
  contentIndexOutlineLevel: function (view, content, index) {
    if (content !== this) return -1; // only care about us

    var cache = this._outlineLevelCache;
    if (cache && (cache[index] !== undefined)) return cache[index];
    if (!cache) cache = this._outlineLevelCache = [];

    var len   = this.get('length'),
        cur   = index,
        ret   = null,
        indexes;

    if (index >= len) return -1;

    if (this.get('isHeaderVisible')) {
      if (index === 0) {
        cache[0] = this.get('outlineLevel') - 1;
        return cache[0];
      } else {
        cur--;
      }
    }

    // loop through branch indexes, reducing the offset until it matches
    // something we might actually return.
    indexes = this.get('branchIndexes');
    if (indexes) {
      indexes.forEach(function (i) {
        if ((ret !== null) || (i > cur)) return; // past end - nothing to do

        var observer = this.branchObserverAt(i), len;
        if (!observer) return; // nothing to do

        // if cur lands inside of this observer's length, use objectAt to get
        // otherwise, just remove len from cur.
        len = observer.get('length');
        if (i + len > cur) {
          ret = observer.contentIndexOutlineLevel(view, observer, cur - i);
          cur = -1;
        } else {
          cur = cur - (len - 1);
        }

      }, this);
    }

    if (cur >= 0) ret = this.get('outlineLevel'); // get internal if needed
    cache[index] = ret; // save in cache
    return ret;
  },

  /**
    Returns the disclosure state for the specified index.
  */
  contentIndexDisclosureState: function (view, content, index) {
    if (content !== this) return -1; // only care about us

    var cache = this._disclosureStateCache;
    if (cache && (cache[index] !== undefined)) return cache[index];
    if (!cache) cache = this._disclosureStateCache = [];

    var len   = this.get('length'),
        cur   = index,
        ret   = null,
        indexes;

    if (index >= len) return SC.LEAF_NODE;

    if (this.get('isHeaderVisible')) {
      if (index === 0) {
        cache[0] = this.get('disclosureState');
        return cache[0];
      } else {
        cur--;
      }
    }

    // loop through branch indexes, reducing the offset until it matches
    // something we might actually return.
    indexes = this.get('branchIndexes');
    if (indexes) {
      indexes.forEach(function (i) {
        if ((ret !== null) || (i > cur)) return; // past end - nothing to do

        var observer = this.branchObserverAt(i), len;
        if (!observer) return; // nothing to do

        // if cur lands inside of this observer's length, use objectAt to get
        // otherwise, just remove len from cur.
        len = observer.get('length');
        if (i + len > cur) {
          ret  = observer.contentIndexDisclosureState(view, observer, cur - i);
          cur  = -1;
        } else {
          cur = cur - (len - 1);
        }

      }, this);
    }

    if (cur >= 0) ret = SC.LEAF_NODE; // otherwise its a leaf node
    cache[index] = ret; // save in cache
    return ret;
  },

  /**
    Expands the specified content index.  This will search down until it finds
    the branchObserver responsible for this item and then calls _collapse on
    it.
  */
  contentIndexExpand: function (view, content, idx) {
    var indexes, cur = idx, children, item;

    if (content !== this) return; // only care about us
    if (this.get('isHeaderVisible')) {
      if (idx === 0) {
        this._expand(this.get('item'));
        return;
      } else {
        cur--;
      }
    }

    indexes = this.get('branchIndexes');
    if (indexes) {
      indexes.forEach(function (i) {
        if (i >= cur) return; // past end - nothing to do
        var observer = this.branchObserverAt(i), len;
        if (!observer) return;

        len = observer.get('length');
        if (i + len > cur) {
          observer.contentIndexExpand(view, observer, cur - i);
          cur = -1; //done
        } else {
          cur = cur - (len - 1);
        }

      }, this);
    }

    // if we are still inside of the range then maybe pass on to a child item
    if (cur >= 0) {
      children = this.get('children');
      item     = children ? children.objectAt(cur) : null;
      if (item) this._expand(item, this.get('item'), cur);
    }
  },

  /**
    Called to collapse a content index item if it is currently in an open
    disclosure state.  The default implementation does nothing.

    @param {SC.CollectionView} view the collection view
    @param {SC.Array} content the content object
    @param {Number} idx the content index
    @returns {void}
  */
  contentIndexCollapse: function (view, content, idx) {
    var indexes, children, item, cur = idx;

    if (content !== this) return; // only care about us
    if (this.get('isHeaderVisible')) {
      if (idx === 0) {
        this._collapse(this.get('item'));
        return;
      } else {
        cur--;
      }
    }

    indexes = this.get('branchIndexes');
    if (indexes) {
      indexes.forEach(function (i) {
        if (i >= cur) return; // past end - nothing to do
        var observer = this.branchObserverAt(i), len;
        if (!observer) return;

        len = observer.get('length');
        if (i + len > cur) {
          observer.contentIndexCollapse(view, observer, cur - i);
          cur = -1; //done
        } else {
          cur = cur - (len - 1);
        }

      }, this);
    }

    // if we are still inside of the range then maybe pass on to a child item
    if (cur >= 0) {
      children = this.get('children');
      item     = children ? children.objectAt(cur) : null;
      if (item) this._collapse(item, this.get('item'), cur);
    }
  },

  // ..........................................................
  // BRANCH NODES
  //

  /**
    Returns the branch item for the specified index.  If none exists yet, it
    will be created.
  */
  branchObserverAt: function (index) {
    var byIndex = this._branchObserversByIndex,
        indexes = this._branchObserverIndexes,
        ret, item, children;

    if (!byIndex) byIndex = this._branchObserversByIndex = [];
    if (!indexes) {
      indexes = this._branchObserverIndexes = SC.IndexSet.create();
    }

    ret = byIndex[index];
    if (ret) return ret; // use cache

    // no observer for this content exists, create one
    children = this.get('children');
    item   = children ? children.objectAt(index) : null;
    if (!item) return null; // can't create an observer for a null item

    byIndex[index] = ret = SC.TreeItemObserver.create({
      item:     item,
      delegate: this.get('delegate'),
      parentObserver:   this,
      index:  index,
      outlineLevel: this.get('outlineLevel') + 1
    });

    indexes.add(index); // save for later invalidation
    return ret;
  },

  /**
    Invalidates any branch observers on or after the specified index range.
  */
  invalidateBranchObserversAt: function (index) {
    var byIndex = this._branchObserversByIndex,
        indexes = this._branchObserverIndexes;

    if (!byIndex || byIndex.length <= index) return this; // nothing to do
    if (index < 0) index = 0;

    // destroy any observer on or after the range
    indexes.forEachIn(index, indexes.get('max') - index, function (i) {
      var observer = byIndex[i];
      if (observer) observer.destroy();
    }, this);

    byIndex.length = index; // truncate to dump extra indexes

    return this;
  },

  // ..........................................................
  // INTERNAL METHODS
  //

  /** @private */
  _cleanUpCachedDelegate: function () {
    var cachedDelegate = this._cachedDelegate;

    if (cachedDelegate) {
      cachedDelegate.removeObserver('treeItemIsExpandedKey', this, this.treeItemIsExpandedKeyDidChange);
      cachedDelegate.removeObserver('treeItemChildrenKey', this, this.treeItemChildrenKeyDidChange);
      cachedDelegate.removeObserver('treeItemIsGrouped', this, this.treeItemIsGroupedDidChange);

      // Remove the delegate specific key observers from the cached item.
      this._cleanUpCachedItem();

      // Reset the delegate specific keys.
      this.set('treeItemChildrenKey', 'treeItemChildren');
      this.set('treeItemIsExpandedKey', 'treeItemIsExpanded');

      // Remove the cache.
      this._cachedDelegate = null;
    }
  },

  /** @private */
  _cleanUpCachedItem: function () {
    var cachedItem = this._cachedItem,
      treeItemIsExpandedKey = this.get('treeItemIsExpandedKey'),
      treeItemChildrenKey = this.get('treeItemChildrenKey');

    if (cachedItem) {
      cachedItem.removeObserver(treeItemIsExpandedKey, this, this._itemIsExpandedDidChange);
      cachedItem.removeObserver(treeItemChildrenKey, this, this._itemChildrenDidChange);

      // Remove the cache.
      this._cachedItem = null;
    }
  },

  /** SC.Object.prototype.init */
  init: function () {
    arguments.callee.base.apply(this,arguments);

    // Initialize the item and the delegate. Be sure to set up the delegate first,
    // because it determines the keys to observe on the item.
    this._delegateDidChange();
    this._itemDidChange();

    this._notifyParent = YES; // avoid infinite loops
  },

  /** SC.Object.prototype.destroy
    Called just before a branch observer is removed.  Should stop any
    observing and invalidate any child observers.
  */
  destroy: function () {
    this.invalidateBranchObserversAt(0);
    this._objectAtCache = null;
    this._notifyParent = NO; // parent doesn't care anymore

    // Cleanup the observed item and delegate.
    this._cleanUpCachedItem();
    this._cleanUpCachedDelegate();

    var children = this._children,
        ro = this._childrenRangeObserver;
    if (children && ro) children.removeRangeObserver(ro);

    this.set('length', 0);

    arguments.callee.base.apply(this,arguments);
  },

  /** @private */
  _itemDidChange: function () {
    var item = this.get('item'),
      treeItemChildrenKey,
      treeItemIsExpandedKey;

    treeItemIsExpandedKey = this.get('treeItemIsExpandedKey');
    treeItemChildrenKey = this.get('treeItemChildrenKey');

    // Cleanup the previous observed item.
    this._cleanUpCachedItem();

    


    item.addObserver(treeItemIsExpandedKey, this, this._itemIsExpandedDidChange);
    item.addObserver(treeItemChildrenKey, this, this._itemChildrenDidChange);

    // Fire the observer functions once to initialize.
    this.beginPropertyChanges();
    this._itemIsExpandedDidChange();
    this._itemChildrenDidChange();
    this.endPropertyChanges();

    // Track the item so that when it changes we can clean-up.
    this._cachedItem = item;
  }.observes('item'),

  /** @private */
  _itemIsExpandedDidChange: function () {
    var state = this.get('disclosureState'),
      item = this.get('item'),
      next;

    next = this._computeDisclosureState(item);
    if (state !== next) { this.set('disclosureState', next); }
  },

  /** @private */
  _itemChildrenDidChange: function () {
    var children = this.get('children'),
      item = this.get('item'),
      next;

    next = this._computeChildren(item);
    if (children !== next) { this.set('children', next); }
  },

  /** @private
    Called whenever the children or disclosure state changes.  Begins or ends
    observing on the children array so that changes can propogate outward.
  */
  _childrenDidChange: function () {
    var state = this.get('disclosureState'),
      cur   = state === SC.BRANCH_OPEN ? this.get('children') : null,
      last  = this._children,
      ro    = this._childrenRangeObserver;

    if (last === cur) return this; //nothing to do

    if (ro) last.removeRangeObserver(ro);

    if (cur) {
      this._childrenRangeObserver = cur.addRangeObserver(null, this, this._childrenRangeDidChange);
    } else {
      this._childrenRangeObserver = null;
    }

    this._children = cur;
    this._childrenRangeDidChange(cur, null, '[]', null);
  }.observes("children", "disclosureState"),

  /** @private
    Called anytime the actual content of the children has changed.  If this
    changes the length property, then notifies the parent that the content
    might have changed.
  */
  _childrenRangeDidChange: function (array, objects, key, indexes) {
    var children = this.get('children'),
      len = children ? children.get('length') : 0,
      min = indexes ? indexes.get('min') : 0,
      max = indexes ? indexes.get('max') : len,
      old = this._childrenLen || 0;

    this._childrenLen = len; // save for future calls
    this.observerContentDidChange(min, max - min, len - old);
  },

  /** @private
    Computes the current disclosure state of the item by asking the item or
    the delegate.  If no pitem or index is passed, the parentItem and index
    will be used.
  */
  _computeDisclosureState: function (item, pitem, index) {
    var key;

    // no item - assume leaf node
    if (!item || !this._computeChildren(item)) return SC.LEAF_NODE;

    // item implement TreeItemContent - call directly
    else if (item.isTreeItemContent) {
      if (pitem === undefined) pitem = this.get('parentItem');
      if (index === undefined) index = this.get('index');
      return item.treeItemDisclosureState(pitem, index);

    // otherwise get treeItemDisclosureStateKey from delegate
    } else {
      key = this.get('treeItemIsExpandedKey');
      return item.get(key) ? SC.BRANCH_OPEN : SC.BRANCH_CLOSED;
    }
  },

  /** @private
    Collapse the item at the specified index.  This will either directly
    modify the property on the item or call the treeItemCollapse() method.
  */
  _collapse: function (item, pitem, index) {
    var key;

    // no item - assume leaf node
    if (!item || !this._computeChildren(item)) return this;

    // item implement TreeItemContent - call directly
    else if (item.isTreeItemContent) {
      if (pitem === undefined) pitem = this.get('parentItem');
      if (index === undefined) index = this.get('index');
      item.treeItemCollapse(pitem, index);

    // otherwise get treeItemDisclosureStateKey from delegate
    } else {
      key = this.get('treeItemIsExpandedKey');
      item.setIfChanged(key, NO);
    }

    return this;
  },

  /** @private Each time the delegate changes, observe it for changes to its keys. */
  _delegateDidChange: function () {
    var delegate = this.get('delegate');

    // Clean up the previous observed delegate.
    this._cleanUpCachedDelegate();

    if (delegate) {
      delegate.addObserver('treeItemChildrenKey', this, this.treeItemChildrenKeyDidChange);
      delegate.addObserver('treeItemIsExpandedKey', this, this.treeItemIsExpandedKeyDidChange);
      delegate.addObserver('treeItemIsGrouped', this, this.treeItemIsGroupedDidChange);

      // Fire the observer functions once to initialize.
      this.treeItemChildrenKeyDidChange();
      this.treeItemIsExpandedKeyDidChange();
      this.treeItemIsGroupedDidChange();
    }

    // Re-initialize the item to match the new delegate.
    this._itemDidChange();

    // Cache the previous delegate so we can clean up.
    this._cachedDelegate = delegate;
  }.observes('delegate'),

  /** @private
    Expand the item at the specified index.  This will either directly
    modify the property on the item or call the treeItemExpand() method.
  */
  _expand: function (item, pitem, index) {
    var key;

    // no item - assume leaf node
    if (!item || !this._computeChildren(item)) return this;

    // item implement TreeItemContent - call directly
    else if (item.isTreeItemContent) {
      if (pitem === undefined) pitem = this.get('parentItem');
      if (index === undefined) index = this.get('index');
      item.treeItemExpand(pitem, index);

    // otherwise get treeItemDisclosureStateKey from delegate
    } else {
      key = this.get('treeItemIsExpandedKey');
      item.setIfChanged(key, YES);
    }

    return this;
  },

  /** @private
    Computes the children for the passed item.
  */
  _computeChildren: function (item) {
    var key;

    if (!item) { // no item - no children
      return null;
    } else if (item.isTreeItemContent) {  // item implements TreeItemContent - call directly
      return item.get('treeItemChildren');
    } else { // otherwise get treeItemChildrenKey from delegate
      key = this.get('treeItemChildrenKey');
      return item.get(key);
    }
  },

  /** @private
    Computes the length of the array by looking at children.
  */
  _computeLength: function () {
    var ret = this.get('isHeaderVisible') ? 1 : 0,
        state = this.get('disclosureState'),
        children = this.get('children'),
        indexes;

    // if disclosure is open, add children count + length of branch observers.
    if ((state === SC.BRANCH_OPEN) && children) {
      ret += children.get('length');

      indexes = this.get('branchIndexes');
      if (indexes) {
        indexes.forEach(function (idx) {
          var observer = this.branchObserverAt(idx);
          ret += observer.get('length') - 1;
        }, this);
      }
    }
    return ret;
  },

  /** @private */
  treeItemChildrenKeyDidChange: function () {
    var del = this.get('delegate'),
      key;

    key = del ? del.get('treeItemChildrenKey') : 'treeItemChildren';
    this.set('treeItemChildrenKey', key ? key : 'treeItemChildren');
  },

  /** @private */
  treeItemIsExpandedKeyDidChange: function () {
    var del = this.get('delegate'),
      key;

    key = del ? del.get('treeItemIsExpandedKey') : 'treeItemIsExpanded';
    this.set('treeItemIsExpandedKey', key ? key : 'treeItemIsExpanded');
  },

  /** @private */
  treeItemIsGroupedDidChange: function () {
    this.notifyPropertyChange('branchIndexes');
  }

});


/* >>>>>>>>>> BEGIN source/controllers/tree.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('private/tree_item_observer');

/*
  TODO Document more
*/

/**
  @class

  A TreeController manages a tree of model objects that you might want to
  display in the UI using a collection view.  For the most part, you should
  work with a TreeController much like you would an ObjectController, except
  that the TreeController will also provide an arrangedObjects property that
  can be used as the content of a CollectionView.

  @extends SC.ObjectController
  @extends SC.SelectionSupport
  @since SproutCore 1.0
*/
SC.TreeController = SC.ObjectController.extend(SC.SelectionSupport,
/** @scope SC.TreeController.prototype */ {

  // ..........................................................
  // PROPERTIES
  //

  /**
    Set to YES if you want the top-level items in the tree to be displayed as
    group items in the collection view.

    @type Boolean
    @default NO
  */
  treeItemIsGrouped: NO,

  /**
    If your content support expanding and collapsing of content, then set this
    property to the name of the key on your model that should be used to
    determine the expansion state of the item.  The default is
    "treeItemIsExpanded"

    @type String
    @default "treeItemIsExpanded"
  */
  treeItemIsExpandedKey: "treeItemIsExpanded",

  /**
    Set to the name of the property on your content object that holds the
    children array for each tree node.  The default is "treeItemChildren".

    @type String
    @default "treeItemChildren"
  */
  treeItemChildrenKey: "treeItemChildren",

  /**
    Returns an SC.Array object that actually will represent the tree as a
    flat array suitable for use by a CollectionView.  Other than binding this
    property as the content of a CollectionView, you generally should not
    use this property directly.  Instead, work on the tree content using the
    TreeController like you would any other ObjectController.

    @type SC.Array
  */
  arrangedObjects: null,

  // ..........................................................
  // PRIVATE
  //

  /** @private - setup observer on init if needed. */
  init: function() {
    arguments.callee.base.apply(this,arguments);

    // Initialize arrangedObjects.
    this._contentDidChange();
  },

  /** @private */
  _contentDidChange: function () {
    var arrangedObjects = this.get('arrangedObjects'),
      content = this.get('content');

    if (content) {
      if (arrangedObjects) {
        arrangedObjects.set('item', content);
      } else {
        arrangedObjects = SC.TreeItemObserver.create({ item: content, delegate: this });

        // Bind selection properties across to the observer.
        arrangedObjects.bind('allowsSelection', this, 'allowsSelection');
        arrangedObjects.bind('allowsMultipleSelection', this, 'allowsMultipleSelection');
        arrangedObjects.bind('allowsEmptySelection', this, 'allowsEmptySelection');

        // Observe the enumerable property in order to update the selection when it changes.
        arrangedObjects.addObserver('[]', this, this._sctc_arrangedObjectsContentDidChange);

        this.set('arrangedObjects', arrangedObjects);
      }
    } else {
      // Since there is no content. Destroy the previous tree item observer and indicate that arrangedObjects has changed.
      if (arrangedObjects) {
        arrangedObjects.destroy();
        this.set('arrangedObjects', null);

        // Update the selection if it exists.
        this._sctc_arrangedObjectsContentDidChange();
      }
    }
  }.observes('content'),

  /** @private */
  _sctc_arrangedObjectsContentDidChange: function () {
    this.updateSelectionAfterContentChange();
  }.observes(),

  canSelectGroups: NO,

  /**
    @private

    Returns the first item in arrangedObjects that is not a group.  This uses
    a brute force approach right now; we assume you probably don't have a lot
    of groups up front.
  */
  firstSelectableObject: function () {
    var objects = this.get('arrangedObjects'),
        indexes, len, idx     = 0;

    if (!objects) return null; // fast track

    // other fast track. if you want something fancier use collectionViewDelegate
    if (this.get('canSelectGroups')) return objects.get('firstObject');

    indexes = objects.contentGroupIndexes(null, objects);
    len = objects.get('length');
    while (indexes.contains(idx) && (idx < len)) idx++;
    return idx >= len ? null : objects.objectAt(idx);
  }.property()

});


/* >>>>>>>>>> BEGIN source/delegates/inline_text_field.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @namespace

  This is the default InlineEditorDelegate for SC.LabelView. The default editor
  is an SC.InlineTextFieldView.

  Only one editor is allowed to be active at a time. If another view requests an
  editor while an editor is already active, the delegate will first attempt to
  commit the existing editor, then discard it if commit fails, and fail to
  acquire if the active editor could not be discarded.

  Each time an editor is required, it instantiates it and appends it to the same
  parentView as the view being edited. The editor is responsible for positioning
  itself correctly in its beginEditing method.

  @since SproutCore 1.0
*/
SC.InlineTextFieldDelegate = /** @scope SC.InlineTextFieldDelegate */{

  /**
    The current shared inline editor.

    @type SC.InlineTextFieldView
  */
  editor: null,

  /**
    If an editor is currently active, dismisses it by first attempting to commit
    and if that fails attempting to dismiss. If that fails, the acquire fails
    and returns null.

    Otherwise, it creates the editor as a child of the client view's parentView
    and returns it.

    The default editor is an SC.InlineTextFieldView. The client view may
    customize this by setting a different inlineEditor as its exampleEditor
    property.

    @param {SC.InlineEditable} label the label that is requesting an editor
    @returns {SC.InlineEditor} the editor the label should use to edit
  */
  acquireEditor: function (label) {
    var editor = this.editor;

    if (editor) {
      // attempt to end editing on the previous editor and return null if unable
      // to end editing successfully
      if (editor.get('isEditing') && !editor.commitEditing() && !editor.discardEditing()) return null;

      // now release it
      this.releaseEditor(editor);
    }

    // default to SC.InlineTextFieldView
    var exampleEditor = label.exampleEditor ? label.exampleEditor : SC.InlineTextFieldView,
    parentView = label.get('parentView');

    // set ourself as the delegate for the editor
    editor = this.editor = parentView.createChildView(exampleEditor, {
      inlineEditorDelegate: this
    });

    parentView.appendChild(editor);

    return editor;
  },

  /**
    Cleans up the given editor by simply destroying it, which removes it from
    the view hierarchy. The client view should null any references to the editor
    so it may be garbage collected.

    @params {SC.InlineEditor} editor the editor that should be cleaned up
    @returns {Boolean} whether the cleanup succeeded
  */
  releaseEditor: function (editor) {
    editor.destroy();

    this.editor = null;

    return YES;
  }
};


/* >>>>>>>>>> BEGIN source/system/string.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


/** @private */
SC.STRING_TITLEIZE_REGEXP = (/([\s|\-|\_|\n])([^\s|\-|\_|\n]?)/g);
SC.STRING_HUMANIZE_REGEXP = (/[\-_]/g);
SC.STRING_REGEXP_ESCAPED_REGEXP = (/([\\\.\+\*\?\[\^\]\$\(\)\{\}\=\!\<\>\|\:])/g);

/** @private
  Since there are many strings that are commonly dasherized(), we'll maintain
  // a cache.  Moreover, we'll pre-add some common ones.
*/
SC.STRING_DASHERIZE_CACHE = {
  top:      'top',
  left:     'left',
  right:    'right',
  bottom:   'bottom',
  width:    'width',
  height:   'height',
  minWidth: 'min-width',
  maxWidth: 'max-width'
};

/**
  @namespace
  @lends SC.String
*/
SC.mixin(SC.String, {

  /**
    Capitalizes every word in a string.  Unlike titleize, spaces or dashes
    will remain in-tact.

    ## Examples

      - **Input String** -> **Output String**
      - my favorite items -> My Favorite Items
      - css-class-name -> Css-Class-Name
      - action_name -> Action_Name
      - innerHTML -> InnerHTML

    @param {String} str String to capitalize each letter2
    @returns {String} capitalized string
  */
  capitalizeEach: function(str) {
    return str.replace(SC.STRING_TITLEIZE_REGEXP,
      function(subStr, sep, character) {
        return (character) ? (sep + character.toUpperCase()) : sep;
      }).capitalize();
  },

  /**
    Converts a string to a title.  This will decamelize the string, convert
    separators to spaces and capitalize every word.

    ## Examples

      - **Input String** -> **Output String**
      - my favorite items -> My Favorite Items
      - css-class-name -> Css Class Name
      - action_name -> Action Name
      - innerHTML -> Inner HTML

    @param {String} str String to titleize
    @return {String} titleized string.
  */
  titleize: function(str) {
    var ret = str.replace(SC.STRING_DECAMELIZE_REGEXP,'$1_$2'); // decamelize
    return ret.replace(SC.STRING_TITLEIZE_REGEXP,
      function(subStr, separater, character) {
        return character ? ' ' + character.toUpperCase() : ' ';
      }).capitalize();
  },

  /**
    Converts the string into a class name.  This method will camelize your
    string and then capitalize the first letter.

    ## Examples

      - **Input String** -> **Output String**
      - my favorite items -> MyFavoriteItems
      - css-class-name -> CssClassName
      - action_name -> ActionName
      - innerHTML -> InnerHtml

    @param {String} str String to classify
    @returns {String}
  */
  classify: function(str) {
    var ret = str.replace(SC.STRING_TITLEIZE_REGEXP,
      function(subStr, separater, character) {
        return character ? character.toUpperCase() : '';
      });
    var first = ret.charAt(0), upper = first.toUpperCase();
    return first !== upper ? upper + ret.slice(1) : ret;
  },

  /**
    Converts a camelized string or a string with dashes or underscores into
    a string with components separated by spaces.

    ## Examples

      - **Input String** -> **Output String**
      - my favorite items -> my favorite items
      - css-class-name -> css class name
      - action_name -> action name
      - innerHTML -> inner html

    @param {String} str String to humanize
    @returns {String} the humanized string.
  */
  humanize: function(str) {
    return SC.String.decamelize(str).replace(SC.STRING_HUMANIZE_REGEXP,' ');
  },

  /**
    Will escape a string so it can be securely used in a regular expression.

    Useful when you need to use user input in a regular expression without
    having to worry about it breaking code if any reserved regular expression
    characters are used.

    @param {String} str String to escape for regex
    @returns {String} the string properly escaped for use in a regexp.
  */
  escapeForRegExp: function(str) {
    return str.replace(SC.STRING_REGEXP_ESCAPED_REGEXP, "\\$1");
  },

  /**
    Removes any standard diacritic characters from the string. So, for
    example, all instances of 'Á' will become 'A'.

    @param {String} str String to remove diacritics from
    @returns {String} the modified string
  */
  removeDiacritics: function(str) {
    // Lazily create the SC.diacriticMappingTable object.
    var diacriticMappingTable = SC.diacriticMappingTable;
    if (!diacriticMappingTable) {
      SC.diacriticMappingTable = {
       'À':'A', 'Á':'A', 'Â':'A', 'Ã':'A', 'Ä':'A', 'Å':'A', 'Ā':'A', 'Ă':'A',
       'Ą':'A', 'Ǎ':'A', 'Ǟ':'A', 'Ǡ':'A', 'Ǻ':'A', 'Ȁ':'A', 'Ȃ':'A', 'Ȧ':'A',
       'Ḁ':'A', 'Ạ':'A', 'Ả':'A', 'Ấ':'A', 'Ầ':'A', 'Ẩ':'A', 'Ẫ':'A', 'Ậ':'A',
       'Ắ':'A', 'Ằ':'A', 'Ẳ':'A', 'Ẵ':'A', 'Ặ':'A', 'Å':'A', 'Ḃ':'B', 'Ḅ':'B',
       'Ḇ':'B', 'Ç':'C', 'Ć':'C', 'Ĉ':'C', 'Ċ':'C', 'Č':'C', 'Ḉ':'C', 'Ď':'D',
       'Ḋ':'D', 'Ḍ':'D', 'Ḏ':'D', 'Ḑ':'D', 'Ḓ':'D', 'È':'E', 'É':'E', 'Ê':'E',
       'Ë':'E', 'Ē':'E', 'Ĕ':'E', 'Ė':'E', 'Ę':'E', 'Ě':'E', 'Ȅ':'E', 'Ȇ':'E',
       'Ȩ':'E', 'Ḕ':'E', 'Ḗ':'E', 'Ḙ':'E', 'Ḛ':'E', 'Ḝ':'E', 'Ẹ':'E', 'Ẻ':'E',
       'Ẽ':'E', 'Ế':'E', 'Ề':'E', 'Ể':'E', 'Ễ':'E', 'Ệ':'E', 'Ḟ':'F', 'Ĝ':'G',
       'Ğ':'G', 'Ġ':'G', 'Ģ':'G', 'Ǧ':'G', 'Ǵ':'G', 'Ḡ':'G', 'Ĥ':'H', 'Ȟ':'H',
       'Ḣ':'H', 'Ḥ':'H', 'Ḧ':'H', 'Ḩ':'H', 'Ḫ':'H', 'Ì':'I', 'Í':'I', 'Î':'I',
       'Ï':'I', 'Ĩ':'I', 'Ī':'I', 'Ĭ':'I', 'Į':'I', 'İ':'I', 'Ǐ':'I', 'Ȉ':'I',
       'Ȋ':'I', 'Ḭ':'I', 'Ḯ':'I', 'Ỉ':'I', 'Ị':'I', 'Ĵ':'J', 'Ķ':'K', 'Ǩ':'K',
       'Ḱ':'K', 'Ḳ':'K', 'Ḵ':'K', 'Ĺ':'L', 'Ļ':'L', 'Ľ':'L', 'Ḷ':'L', 'Ḹ':'L',
       'Ḻ':'L', 'Ḽ':'L', 'Ḿ':'M', 'Ṁ':'M', 'Ṃ':'M', 'Ñ':'N', 'Ń':'N', 'Ņ':'N',
       'Ň':'N', 'Ǹ':'N', 'Ṅ':'N', 'Ṇ':'N', 'Ṉ':'N', 'Ṋ':'N', 'Ò':'O', 'Ó':'O',
       'Ô':'O', 'Õ':'O', 'Ö':'O', 'Ō':'O', 'Ŏ':'O', 'Ő':'O', 'Ơ':'O', 'Ǒ':'O',
       'Ǫ':'O', 'Ǭ':'O', 'Ȍ':'O', 'Ȏ':'O', 'Ȫ':'O', 'Ȭ':'O', 'Ȯ':'O', 'Ȱ':'O',
       'Ṍ':'O', 'Ṏ':'O', 'Ṑ':'O', 'Ṓ':'O', 'Ọ':'O', 'Ỏ':'O', 'Ố':'O', 'Ồ':'O',
       'Ổ':'O', 'Ỗ':'O', 'Ộ':'O', 'Ớ':'O', 'Ờ':'O', 'Ở':'O', 'Ỡ':'O', 'Ợ':'O',
       'Ṕ':'P', 'Ṗ':'P', 'Ŕ':'R', 'Ŗ':'R', 'Ř':'R', 'Ȑ':'R', 'Ȓ':'R', 'Ṙ':'R',
       'Ṛ':'R', 'Ṝ':'R', 'Ṟ':'R', 'Ś':'S', 'Ŝ':'S', 'Ş':'S', 'Š':'S', 'Ș':'S',
       'Ṡ':'S', 'Ṣ':'S', 'Ṥ':'S', 'Ṧ':'S', 'Ṩ':'S', 'Ţ':'T', 'Ť':'T', 'Ț':'T',
       'Ṫ':'T', 'Ṭ':'T', 'Ṯ':'T', 'Ṱ':'T', 'Ù':'U', 'Ú':'U', 'Û':'U', 'Ü':'U',
       'Ũ':'U', 'Ū':'U', 'Ŭ':'U', 'Ů':'U', 'Ű':'U', 'Ų':'U', 'Ư':'U', 'Ǔ':'U',
       'Ǖ':'U', 'Ǘ':'U', 'Ǚ':'U', 'Ǜ':'U', 'Ȕ':'U', 'Ȗ':'U', 'Ṳ':'U', 'Ṵ':'U',
       'Ṷ':'U', 'Ṹ':'U', 'Ṻ':'U', 'Ụ':'U', 'Ủ':'U', 'Ứ':'U', 'Ừ':'U', 'Ử':'U',
       'Ữ':'U', 'Ự':'U', 'Ṽ':'V', 'Ṿ':'V', 'Ŵ':'W', 'Ẁ':'W', 'Ẃ':'W', 'Ẅ':'W',
       'Ẇ':'W', 'Ẉ':'W', 'Ẋ':'X', 'Ẍ':'X', 'Ý':'Y', 'Ŷ':'Y', 'Ÿ':'Y', 'Ȳ':'Y',
       'Ẏ':'Y', 'Ỳ':'Y', 'Ỵ':'Y', 'Ỷ':'Y', 'Ỹ':'Y', 'Ź':'Z', 'Ż':'Z', 'Ž':'Z',
       'Ẑ':'Z', 'Ẓ':'Z', 'Ẕ':'Z',
       '`': '`',
       'à':'a', 'á':'a', 'â':'a', 'ã':'a', 'ä':'a', 'å':'a', 'ā':'a', 'ă':'a',
       'ą':'a', 'ǎ':'a', 'ǟ':'a', 'ǡ':'a', 'ǻ':'a', 'ȁ':'a', 'ȃ':'a', 'ȧ':'a',
       'ḁ':'a', 'ạ':'a', 'ả':'a', 'ấ':'a', 'ầ':'a', 'ẩ':'a', 'ẫ':'a', 'ậ':'a',
       'ắ':'a', 'ằ':'a', 'ẳ':'a', 'ẵ':'a', 'ặ':'a', 'ḃ':'b', 'ḅ':'b', 'ḇ':'b',
       'ç':'c', 'ć':'c', 'ĉ':'c', 'ċ':'c', 'č':'c', 'ḉ':'c', 'ď':'d', 'ḋ':'d',
       'ḍ':'d', 'ḏ':'d', 'ḑ':'d', 'ḓ':'d', 'è':'e', 'é':'e', 'ê':'e', 'ë':'e',
       'ē':'e', 'ĕ':'e', 'ė':'e', 'ę':'e', 'ě':'e', 'ȅ':'e', 'ȇ':'e', 'ȩ':'e',
       'ḕ':'e', 'ḗ':'e', 'ḙ':'e', 'ḛ':'e', 'ḝ':'e', 'ẹ':'e', 'ẻ':'e', 'ẽ':'e',
       'ế':'e', 'ề':'e', 'ể':'e', 'ễ':'e', 'ệ':'e', 'ḟ':'f', 'ĝ':'g', 'ğ':'g',
       'ġ':'g', 'ģ':'g', 'ǧ':'g', 'ǵ':'g', 'ḡ':'g', 'ĥ':'h', 'ȟ':'h', 'ḣ':'h',
       'ḥ':'h', 'ḧ':'h', 'ḩ':'h', 'ḫ':'h', 'ẖ':'h', 'ì':'i', 'í':'i', 'î':'i',
       'ï':'i', 'ĩ':'i', 'ī':'i', 'ĭ':'i', 'į':'i', 'ǐ':'i', 'ȉ':'i', 'ȋ':'i',
       'ḭ':'i', 'ḯ':'i', 'ỉ':'i', 'ị':'i', 'ĵ':'j', 'ǰ':'j', 'ķ':'k', 'ǩ':'k',
       'ḱ':'k', 'ḳ':'k', 'ḵ':'k', 'ĺ':'l', 'ļ':'l', 'ľ':'l', 'ḷ':'l', 'ḹ':'l',
       'ḻ':'l', 'ḽ':'l', 'ḿ':'m', 'ṁ':'m', 'ṃ':'m', 'ñ':'n', 'ń':'n', 'ņ':'n',
       'ň':'n', 'ǹ':'n', 'ṅ':'n', 'ṇ':'n', 'ṉ':'n', 'ṋ':'n', 'ò':'o', 'ó':'o',
       'ô':'o', 'õ':'o', 'ö':'o', 'ō':'o', 'ŏ':'o', 'ő':'o', 'ơ':'o', 'ǒ':'o',
       'ǫ':'o', 'ǭ':'o', 'ȍ':'o', 'ȏ':'o', 'ȫ':'o', 'ȭ':'o', 'ȯ':'o', 'ȱ':'o',
       'ṍ':'o', 'ṏ':'o', 'ṑ':'o', 'ṓ':'o', 'ọ':'o', 'ỏ':'o', 'ố':'o', 'ồ':'o',
       'ổ':'o', 'ỗ':'o', 'ộ':'o', 'ớ':'o', 'ờ':'o', 'ở':'o', 'ỡ':'o', 'ợ':'o',
       'ṕ':'p', 'ṗ':'p', 'ŕ':'r', 'ŗ':'r', 'ř':'r', 'ȑ':'r', 'ȓ':'r', 'ṙ':'r',
       'ṛ':'r', 'ṝ':'r', 'ṟ':'r', 'ś':'s', 'ŝ':'s', 'ş':'s', 'š':'s', 'ș':'s',
       'ṡ':'s', 'ṣ':'s', 'ṥ':'s', 'ṧ':'s', 'ṩ':'s', 'ţ':'t', 'ť':'t', 'ț':'t',
       'ṫ':'t', 'ṭ':'t', 'ṯ':'t', 'ṱ':'t', 'ẗ':'t', 'ù':'u', 'ú':'u', 'û':'u',
       'ü':'u', 'ũ':'u', 'ū':'u', 'ŭ':'u', 'ů':'u', 'ű':'u', 'ų':'u', 'ư':'u',
       'ǔ':'u', 'ǖ':'u', 'ǘ':'u', 'ǚ':'u', 'ǜ':'u', 'ȕ':'u', 'ȗ':'u', 'ṳ':'u',
       'ṵ':'u', 'ṷ':'u', 'ṹ':'u', 'ṻ':'u', 'ụ':'u', 'ủ':'u', 'ứ':'u', 'ừ':'u',
       'ử':'u', 'ữ':'u', 'ự':'u', 'ṽ':'v', 'ṿ':'v', 'ŵ':'w', 'ẁ':'w', 'ẃ':'w',
       'ẅ':'w', 'ẇ':'w', 'ẉ':'w', 'ẘ':'w', 'ẋ':'x', 'ẍ':'x', 'ý':'y', 'ÿ':'y',
       'ŷ':'y', 'ȳ':'y', 'ẏ':'y', 'ẙ':'y', 'ỳ':'y', 'ỵ':'y', 'ỷ':'y', 'ỹ':'y',
       'ź':'z', 'ż':'z', 'ž':'z', 'ẑ':'z', 'ẓ':'z', 'ẕ':'z'
      };
      diacriticMappingTable = SC.diacriticMappingTable;
    }

    var original, replacement, ret = "",
        length = str.length;

    for (var i = 0; i <= length; ++i) {
      original = str.charAt(i);
      replacement = diacriticMappingTable[original];
      ret += replacement || original;
    }
    return ret;
  },


  /**
    Converts a word into its plural form.

    @param {String} str String to pluralize
    @returns {String} the plural form of the string
  */
  pluralize: function(str) {
    var inflectionConstants = SC.Locale.currentLocale.inflectionConstants;

    // Fast path if there is no inflection constants for a locale
    if (!inflectionConstants) return str.toString();

    var idx, len,
      compare = str.split(/\s/).pop(), //check only the last word of a string
      restOfString = str.replace(compare,''),
      isCapitalized = compare.charAt(0).match(/[A-Z]/) ? true : false;

    compare = compare.toLowerCase();
    for (idx=0, len=inflectionConstants.UNCOUNTABLE.length; idx < len; idx++) {
      var uncountable = inflectionConstants.UNCOUNTABLE[idx];
      if (compare == uncountable) {
        return str.toString();
      }
    }
    for (idx=0, len=inflectionConstants.IRREGULAR.length; idx < len; idx++) {
      var singular = inflectionConstants.IRREGULAR[idx][0],
          plural   = inflectionConstants.IRREGULAR[idx][1];
      if ((compare == singular) || (compare == plural)) {
        if(isCapitalized) plural = plural.capitalize();
        return restOfString + plural;
      }
    }
    for (idx=0, len=inflectionConstants.PLURAL.length; idx < len; idx++) {
      var regex          = inflectionConstants.PLURAL[idx][0],
        replace_string = inflectionConstants.PLURAL[idx][1];
      if (regex.test(compare)) {
        return str.replace(regex, replace_string);
      }
    }
  },

  /**
    Converts a word into its singular form.

    @param {String} str String to singularize
    @returns {String} the singular form of the string
  */
  singularize: function(str) {
    var inflectionConstants = SC.Locale.currentLocale.inflectionConstants;

    // Fast path if there is no inflection constants for a locale
    if (!inflectionConstants) return str.toString();

    var idx, len,
      compare = str.split(/\s/).pop(), //check only the last word of a string
      restOfString = str.replace(compare,''),
      isCapitalized = compare.charAt(0).match(/[A-Z]/) ? true : false;

    compare = compare.toLowerCase();
    for (idx=0, len=inflectionConstants.UNCOUNTABLE.length; idx < len; idx++) {
      var uncountable = inflectionConstants.UNCOUNTABLE[idx];
      if (compare == uncountable) {
        return str.toString();
      }
    }
    for (idx=0, len=inflectionConstants.IRREGULAR.length; idx < len; idx++) {
      var singular = inflectionConstants.IRREGULAR[idx][0],
        plural   = inflectionConstants.IRREGULAR[idx][1];
      if ((compare == singular) || (compare == plural)) {
        if(isCapitalized) singular = singular.capitalize();
        return restOfString + singular;
      }
    }
    for (idx=0, len=inflectionConstants.SINGULAR.length; idx < len; idx++) {
      var regex          = inflectionConstants.SINGULAR[idx][0],
          replace_string = inflectionConstants.SINGULAR[idx][1];
      if (regex.test(compare)) {
        return str.replace(regex, replace_string);
      }
    }
  }

});

/** @private */
SC.String.strip = SC.String.trim;

/* >>>>>>>>>> BEGIN source/ext/string.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('system/string');

SC.supplement(String.prototype, {

  /**
    @see SC.String.capitalizeEach
  */
  capitalizeEach: function() {
    return SC.String.capitalizeEach(this, arguments);
  },

  /**
    @see SC.String.titleize
  */
  titleize: function(str) {
    return SC.String.titleize(this, arguments);
  },

  /**
    @see SC.String.classify
  */
  classify: function(str) {
    return SC.String.classify(this, arguments);
  },

  /**
    @see SC.String.humanize
  */
  humanize: function(str) {
    return SC.String.humanize(this, arguments);
  },

  /**
    @see SC.String.escapeForRegExp
  */
  escapeForRegExp: function(str) {
    return SC.String.escapeForRegExp(this, arguments);
  },

  /**
    @see SC.String.removeDiacritics
  */
  removeDiacritics: function(str) {
    return SC.String.removeDiacritics(this, arguments);
  },

  /**
    @see SC.String.trim
  */
  trim: function(str) {
    return SC.String.trim(this, arguments);
  },

  /**
    @see SC.String.trimLeft
  */
  trimLeft: function (str) {
    return SC.String.trimLeft(this, arguments);
  },

  /**
    @see SC.String.trimRight
  */
  trimRight: function (str) {
    return SC.String.trimRight(this, arguments);
  },

  /**
    @see SC.String.pluralize
  */
  pluralize: function(str) {
    return SC.String.pluralize(this, arguments);
  },

  /**
    @see SC.String.singularize
  */
  singularize: function(str) {
    return SC.String.singularize(this, arguments);
  }

});
/* >>>>>>>>>> BEGIN source/system/gesture.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


/**
  @class

  An SC.Gesture analyzes SC.Touch objects and determines if they are part
  of a gesture. If they are, SC.Gestures keep the views that own them up-to-date
  as that gesture progresses, informing it when it starts, when some aspect of
  it changes, when it ends, and—for convenience—when it is considered to have
  been "triggered".

  Gestures can call the following methods on their views:

  - [gestureName](args...): called when the gesture has occurred. This is
    useful for event-style gestures, where you aren't interested in when it starts or
    ends, but just that it has occurred. SC.SwipeGesture triggers this after the
    swipe has moved a minimum amount—40px by default.

  - [gestureName]Start(args...): called when the gesture is first recognized.
    For instance, a swipe gesture may be recognized after the finger has moved a
    minimum distance in a horizontal.

  - [gestureName]Changed(args...): called when some property of the gesture
    has changed. For instance, this may be called continuously as the user swipes as
    the swipe's distance changes.

  - [gestureName]Cancelled(args...): called when a gesture, for one reason
    or another, is no longer recognized. For instance, a horizontal swipe gesture
    could cancel if the user moves too far in a vertical direction.

  - [gestureName]End(args...): called when a gesture ends. A swipe would end
    when the user lifts their finger.

  Gesture Lifecycle
  ------------------------
  Gestures start receiving events when their view—usually mixing in SC.Gesturable—tells it
  about activities with "unassigned" touches. "Unassigned" touches are touches that have
  not _yet_ been assigned to a gesture.

  The touch becomes "assigned" when the gesture's touchIsInGesture method returns YES.
  When a touch is assigned to a gesture, the gesture becomes the touch's touch responder;
  this means that it will receive a touchStart event (to which it must return YES), and
  then, all further touch events will be sent _directly_ to the gesture—the gesture's view
  will not receive them at all.

  At any point, the gesture may tell the view that it has started, ended, or changed. In
  addition, the gesture may tell the view it has been "triggered." A gesture is not
  necessarily "triggered" when it starts and ends; for instance, a swipe gesture might
  only be triggered if the swipe moves more than a specified amount. The ability to track
  when the gesture has been triggered allows views to easily handle the gesture as its own
  event, rather than as the individual events that are part of it.

  If, at some point, the gesture must release the touch back (perhaps the gesture had _thought_
  the touch was a part of it, but turned out to be incorrect), the release(touch) method releases
  it back to the view.

  Exclusivity
  ---------------------------------
  The concept described above gives the gestures a way to be either exclusive or inclusive as-needed:
  they can choose to take exclusive control of a touch if they think it is theirs, but if they are
  not sure, they can wait and see.

  Status Object
  ---------------------------------
  It is a common need to track some data related to the touch, but without modifying the touch itself.
  SC.Gesture is able to keep track of simple hashes for you, mapping them to the SC.Touch object,
  so that you can maintain some state related to the touch.

  For instance, you could set status.failed in touchesDragged, if a touch that you previously
  thought may have been part of the gesture turned out not to be, and then check for
  status.failed in touchIsInGesture, returning NO if present. This would cause the touch
  to never be considered for your gesture again.

  touchIsInGesture is called with the status hash provided in the second argument. You may look
  up the status hash for a touch at any time by calling this.statusForTouch(touch).


  Implementing a Gesture
  ---------------------------------
  To write a gesture, you would generally implement the following methods:

  - touchIsInGesture: Return YES when the touch is—or is likely enough to be that you
    want your gesture to have exclusive control over the touch. You usually do not
    perform much gesture logic here—instead, you save it for touchStart, which will
    get called after you return YES from this method.

  - touchStart: Return YES to accept control of the touch. If you do not return YES,
    your gesture will not receive touchesDragged nor touchEnd events. At this point,
    you may (or may not) wish to tell the view that the gesture has started by using the
    start(args...) method.

  - touchesDragged: Use this as you would use it in an SC.View to track the touches
    assigned to the gesture. At this point, you might want to tell the view that the
    gesture has updated by using the change(args...) method.

  - touchEnd: Again, use this like you would in an SC.View to track when touches
    assigned to the gesture have ended. This is also a potential time to alert the view
    that the gesture has ended, by using the end(args...) method. Further, this may
    also be the time to "trigger" the gesture.

*/
SC.Gesture = SC.Object.extend({

  /** @private Tracks when the gesture is active or not. */
  _sc_isActive: false,

  /**
    Whether to receive touch events for each distinct touch (rather than only the first touch start
    and last touch end).

    @type Boolean
    @default false
    @see SC.View#acceptsMultitouch
  */
  acceptsMultitouch: false,

  /**
    The gesture's name. When calling events on the owning SC.View, this name will
    be prefixed to the methods. For instance, if the method to be called is
    'Start', and the gesture's name is 'swipe', SC.Gesture will call 'swipeStart'.

    @type String
    @default "gesture"
  */
  name: "gesture",

  /**
    Return YES to take exclusive control over the touch. In addition to the
    SC.Touch object you may take control of, you are also provided a "status"
    hash, which is unique for both the gesture instance and the touch instance,
    which you may use for your own purposes.

    @param {SC.Touch} touch The touch.
    @param {Object} status A unique status hash for the given touch.
    @returns {Boolean} true if the gesture should claim the touch; false to leave it unclaimed.
  */
  touchIsInGesture: function(touch, status) {
    return NO;
  },

  /**
    After you return YES from touchIsInGesture (or otherwise 'take' a touch, perhaps
    using the 'take' method), touchStart will be called.

    This is where you do any logic needed now that the touch is part of the gesture.
    For instance, you could inform the view that the gesture has started by calling
    this.start().

    NOTE: SC.Gesture is just like SC.View in that it has an acceptsMultitouch property.
    If NO (the default), the gesture will only receive touchStart for the first touch
    assigned to it, and only receive touchEnd for the last touch that ends.

    @param {SC.Touch} touch The touch that started.
    @returns {Boolean} true if the gesture should respond to the touch; false otherwise (this should always return true)
    @see SC.ResponderProtocol#touchStart
  */
  touchStart: function(touch) {
    return true;
  },

  /**
    Called when a touch assigned to the gesture ends.

    If there are no remaining touches on the gesture, you may want to call end() to
    notify the view that the gesture has ended (if you haven't ended the gesture
    already).

    NOTE: SC.Gesture is just like SC.View in that it has an acceptsMultitouch property.
    If NO (the default), the gesture will only receive touchStart for the first touch
    assigned to it, and only receive touchEnd for the last touch that ends.

    @name touchEnd
    @function
    @param {SC.Touch} touch The touch that ended.
  */

  /**
    Starts the gesture (marking it as "active"), and notifies the view.

    You can pass any number of arguments to start. They will, along with
    the gesture instance itself, will be passed to the appropriate gesture
    event on the SC.View.
  */
  start: function() {
    if (!this._sc_isActive) {
      this._sc_isActive = true;

      // var argumentsLength = arguments.length,
      //     args = new Array(argumentsLength + 1);

      // // Unshift this to the front of arguments.
      // args[0] = this;
      // for (var i = 0, len = argumentsLength; i < len; i++) { args[i + 1] = arguments[i]; }

      // var act = this.name + "Start";
      // if (this.view[act]) this.view[act].apply(this.view, args);

      // Fast arguments access. Don't materialize the `arguments` object, it is costly.
      var argumentsLength = arguments.length,
          args = new Array(argumentsLength);

      for (var i = 0, len = argumentsLength; i < len; i++) { args[i] = arguments[i]; }

      var act = this.name + "Start";
      if (this.view[act]) this.view[act].apply(this.view, args);
    }
  },

  /**
    Ends the gesture, if it is active (marking it as not active), and notifies
    the view.

    You may pass any number of arguments to end(). They, along with your gesture
    instance itself, will be passed to the appropriate gesture event on the SC.View.
  */
  end: function() {
    if (this._sc_isActive) {
      this._sc_isActive = false;

      // var argumentsLength = arguments.length,
      //     args = new Array(argumentsLength + 1);

      // // Unshift this to the front of arguments.
      // args[0] = this;
      // for (var i = 0, len = argumentsLength; i < len; i++) { args[i + 1] = arguments[i]; }

      // var act = this.name + "End";
      // if (this.view[act]) this.view[act].apply(this.view, args);

      // Fast arguments access. Don't materialize the `arguments` object, it is costly.
      var argumentsLength = arguments.length,
          args = new Array(argumentsLength);

      for (var i = 0, len = argumentsLength; i < len; i++) { args[i] = arguments[i]; }

      var act = this.name + "End";
      if (this.view[act]) this.view[act].apply(this.view, args);
    }
  },

  /**
    If the gesture is active, notifies the view that the gesture has
    changed.

    The gesture, along with any arguments to change(), will be passed to
    the appropriate method on the SC.View.
  */
  change: function() {
    if (this._sc_isActive) {
      // var argumentsLength = arguments.length,
      //     args = new Array(argumentsLength + 1);

      // // Unshift this to the front of arguments.
      // args[0] = this;
      // for (var i = 0, len = argumentsLength; i < len; i++) { args[i + 1] = arguments[i]; }

      // var act = this.name + "Changed";
      // if (this.view[act]) this.view[act].apply(this.view, args);

      // Fast arguments access. Don't materialize the `arguments` object, it is costly.
      var argumentsLength = arguments.length,
          args = new Array(argumentsLength);

      for (var i = 0, len = argumentsLength; i < len; i++) { args[i] = arguments[i]; }

      var act = this.name + "Changed";
      if (this.view[act]) this.view[act].apply(this.view, args);
    }
  },

  /**
    Cancels the gesture, if it is active, and notifies the view that the
    gesture has been cancelled.

    Gestures are cancelled when they have ended, but any action that would
    normally be appropriate due to their ending should not be performed.

    The gesture, along with any arguments to cancel(), will be passed to the
    appropriate method on the SC.View.
  */
  cancel: function(){
    if (this._sc_isActive) {
      this._sc_isActive = false;

      // var argumentsLength = arguments.length,
      //     args = new Array(argumentsLength + 1);

      // // Unshift this to the front of arguments.
      // args[0] = this;
      // for (var i = 0, len = argumentsLength; i < len; i++) { args[i + 1] = arguments[i]; }

      // var act = this.name + "Cancelled";
      // if (this.view[act]) this.view[act].apply(this.view, args);

      // Fast arguments access. Don't materialize the `arguments` object, it is costly.
      var argumentsLength = arguments.length,
          args = new Array(argumentsLength);

      for (var i = 0, len = argumentsLength; i < len; i++) { args[i] = arguments[i]; }

      var act = this.name + "Cancelled";
      if (this.view[act]) this.view[act].apply(this.view, args);
    }
  },

  /**
    Triggers the gesture, notifying the view that the gesture has happened.

    You should trigger a gesture where it would be natural to say it has "happened";
    for instance, if a touch moves a couple of pixels, you probably wouldn't say
    a swipe has occurred—though you might say it has "begun." And you wouldn't necessarily
    wait until the touch has ended either. Once the touch has moved a certain amount,
    there has definitely been a swipe. By calling trigger() at this point, you will
    tell the view that it has occurred.

    For SC.SwipeGesture, this allows a view to implement only swipe(), and then be
    automatically notified whenever any swipe has occurred.
  */
  trigger: function() {
    // Fast arguments access. Don't materialize the `arguments` object, it is costly.
    var argumentsLength = arguments.length,
        // args = new Array(argumentsLength + 1);
        args = new Array(argumentsLength);

    // // Unshift this to the front of arguments.
    // args[0] = this;
    // for (var i = 0, len = argumentsLength; i < len; i++) { args[i + 1] = arguments[i]; }

    for (var i = 0, len = argumentsLength; i < len; i++) { args[i] = arguments[i]; }

    var act = this.name;
    if (this.view[act]) this.view[act].apply(this.view, args);
  },

  /**
    Takes possession of a touch.

    This is called automatically when you return YES from touchIsInGesture.
  */
  // take: function(touch) {
  //   if (!touch.isTaken) {
  //     touch.isTaken = YES; // because even changing responder won't prevent it from being used this cycle.
  //     if (SC.none(touch.touchResponder) || touch.touchResponder !== this) touch.makeTouchResponder(this, YES);
  //   }
  //   

  // },

  /**
    Releases a touch back to its previous owner, which is usually the view. This allows
    you to give back control of a touch that it turns out is not part of the gesture.

    This takes effect immediately, because you would usually call this from
    touchesDragged or such.
  */
  // release: function(touch) {
  //   if (touch.isTaken) {
  //     touch.isTaken = NO;
  //     if (touch.nextTouchResponder) touch.makeTouchResponder(touch.nextTouchResponder);
  //   }
  //   

  // },

  /**
    Discards a touch, making its responder null. This makes the touch go away and never
    come back—not to this gesture, nor to any other, nor to the view, nor to any other
    view.
  */
  // discardTouch: function(touch) {
  //   touch.isTaken = YES; // because even changing responder won't prevent it from being used this cycle.
  //   touch.makeTouchResponder(null);
  // },

  /**
    Called by the view when a touch session has begun.

    You should override this method in your custom SC.Gesturable subclasses to set up any touch
    session state. For example, you may want to track the initial touch start time in order to
    decide how to react when or if additional touches start later.

    @param {SC.Touch} touch The touch that started the session.
    @returns {void}
    */
  touchSessionStarted: function (touch) {
  },

  /**
    Called by the view when the touch session has ended.

    This will occur because all touches in the session have finished.

    You should override this method in your custom SC.Gesturable subclasses to clean up any state
    variables used in the touch session.

    @returns {void}
   */
  touchSessionEnded: function () {
  },

  /**
    Called by the view when the touch session was cancelled.

    This will occur because this gesture returned `false` in any of `touchAddedToSession`,
    `touchesMovedInSession`, `touchEndedInSession`, `touchCancelledInSession` to indicate that the
    gesture is no longer interested in the session or because another gesture claimed the touch
    session for itself, forcing all other gestures out (rare).

    You should override this method in your custom SC.Gesturable subclasses to clean up any state
    variables used in the touch session.

    @returns {void}
   */
  touchSessionCancelled: function () {
  },

  /**
    @param {SC.Touch} touch The touch to be added to the session.
    @param {Array} touchesInSession The touches already in the session.
    @returns {Boolean} True if the gesture is still interested in the touch session; false to stop getting notified for any further touch changes in the touch session.
    */
  touchAddedToSession: function (touch, touchesInSession) {
    return true; // Most gestures should theoretically be interested in a new touch session.
  },

  /**
    @param {SC.Touch} touch The touch to be removed from the session.
    @param {Array} touchesInSession The touches still remaining in the session.
    @returns {Boolean} True if the gesture is still interested in the touch session; false to stop getting notified for any further touch changes in the touch session.
    */
  touchCancelledInSession: function (touch, touchesInSession) {
    return true;
  },

  /**
    @param {SC.Touch} touch The touch to be removed from the session.
    @param {Array} touchesInSession The touches still remaining in the session.
    @returns {Boolean} True if the gesture is still interested in the touch session; false to stop getting notified for any further touch changes in the touch session.
    */
  touchEndedInSession: function (touch, touchesInSession) {
    return true;
  },

  /**
    @param {Array} touchesInSession The touches in the session.
    @returns {Boolean} True if the gesture is still interested in the touch session; false to stop getting notified for any further touch changes in the touch session.
    */
  touchesMovedInSession: function (touchesInSession) {
    return true;
  }

});

/* >>>>>>>>>> BEGIN source/gestures/pinch_gesture.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require("system/gesture");

/*
  TODO Document this class
*/

/**
  @class
  @extends SC.Gesture
*/
SC.PinchGesture = SC.Gesture.extend(
/** @scope SC.PinchGesture.prototype */{

  /** @private Whether we have started pinching or not.

    @type Boolean
    @default false
  */
  _sc_isPinching: false,

  /** @private The previous distance between touches.

    @type Number
    @default null
  */
  _sc_pinchAnchorD: null,

  /** @private The initial scale of the view before pinching.

    @type Number
    @default null
  */
  _sc_pinchAnchorScale: null,

  /**
    @type String
    @default "pinch"
  */
  name: "pinch",

  /**
    The amount of time in milliseconds that touches should stop moving before a `pinchEnd` event
    will fire. When a pinch gesture begins, the `pinchStart` event is fired and as long as the
    touches continue to change distance, multiple `pinch` events will fire. If the touches remain
    active but don't change distance any longer, then after `pinchDelay` milliseconds the `pinchEnd`
    event will fire.

    @type Number
    @default 500
    */
  pinchDelay: 500,

  /**
    The number of pixels that multiple touches need to expand or contract in order to trigger the
    beginning of a pinch.

    @type Number
    @default 3
    */
  // pinchStartThreshold: 3,

  /** @private Cleans up the touch session. */
  _sc_cleanUpTouchSession: function () {
    // If we were pinching before, end the pinch immediately.
    if (this._sc_isPinching) {
      this._sc_pinchingTimer.invalidate();
      this._sc_pinchingTimer = null;
      this._sc_lastPinchTime = null;
      this._sc_isPinching = false;

      // Trigger the gesture, 'pinchEnd'.
      this.end();
    }

    // Clean up.
    this._sc_pinchAnchorD = null;
  },

  /** @private Shared function for when a touch ends or cancels. */
  _sc_touchFinishedInSession: function (touch, touchesInSession) {
    // If there are more than two touches, keep monitoring for pinches by updating _sc_pinchAnchorD.
    if (touchesInSession.length > 1) {
      // Get the averaged touches for the the view. Because pinch is always interested in every touch
      // the touchesInSession will equal the touches for the view.
      var avgTouch = touch.averagedTouchesForView(this.view);

      this._sc_pinchAnchorD = avgTouch.d;

    // Disregard incoming touches by clearing out _sc_pinchAnchorD and end an active pinch immediately.
    } else {
      this._sc_cleanUpTouchSession();
    }
  },

  /** @private Triggers pinchEnd and resets _sc_isPinching if enough time has passed. */
  _sc_triggerPinchEnd: function () {
    // If a pinch came in since the time the timer was registered, set up a new timer for the
    // remaining time.
    if (this._sc_lastPinchTime) {
      var timePassed = Date.now() - this._sc_lastPinchTime,
          pinchDelay = this.get('pinchDelay');

      // Prepare to send 'pinchEnd' again.
      this._sc_pinchingTimer = SC.Timer.schedule({
        target: this,
        action: this._sc_triggerPinchEnd,
        interval: pinchDelay - timePassed // Trigger the timer the amount of time left since the last pinch
      });

      // Clear out the last pinch time.
      this._sc_lastPinchTime = null;

    // No additional pinches appeared in the amount of time.
    } else {
      // Trigger the gesture, 'pinchEnd'.
      this.end();

      // Clear out the pinching session.
      this._sc_isPinching = false;
      this._sc_pinchingTimer = null;
    }
  },

  /**
    The pinch gesture is always interested in the touch session. When a new touch is added, the
    distance between all of the touches is registered in order to check for distance changes
    equating to a pinch gesture.

    @param {SC.Touch} touch The touch to be added to the session.
    @param {Array} touchesInSession The touches already in the session.
    @returns {Boolean} True.
    @see SC.Gesture#touchAddedToSession
    */
  touchAddedToSession: function (touch, touchesInSession) {
    // Get the averaged touches for the the view. Because pinch is always interested in every touch
    // the touchesInSession will equal the touches for the view.
    var avgTouch = touch.averagedTouchesForView(this.view, true);

    this._sc_pinchAnchorD = avgTouch.d;

    return true;
  },

  /**
    If a touch cancels, the pinch remains interested (even if there's only one touch left, because a
    second touch may appear again), but updates its internal variable for tracking for pinch
    movements.

    @param {SC.Touch} touch The touch to be removed from the session.
    @param {Array} touchesInSession The touches in the session.
    @returns {Boolean} True
    @see SC.Gesture#touchCancelledInSession
    */
  touchCancelledInSession: function (touch, touchesInSession) {
    this._sc_touchFinishedInSession(touch, touchesInSession);

    return true;
  },

  /**
    If a touch ends, the pinch remains interested (even if there's only one touch left, because a
    second touch may appear again), but updates its internal variable for tracking for pinch
    movements.

    @param {SC.Touch} touch The touch to be removed from the session.
    @param {Array} touchesInSession The touches in the session.
    @returns {Boolean} True
    @see SC.Gesture#touchEndedInSession
    */
  touchEndedInSession: function (touch, touchesInSession) {
    this._sc_touchFinishedInSession(touch, touchesInSession);

    return true;
  },

  /**
    The pinch is only interested in more than one touch moving. If there are multiple touches
    moving and the distance between the touches has changed then a `pinchStart` event will fire.
    If the touches keep expanding or contracting, the `pinch` event will repeatedly fire. Finally,
    if the touch distance stops changing and enough time passes (value of `pinchDelay`), the
    `pinchEnd` event will fire.

    Therefore, it's possible for a pinch gesture to start and end more than once in a single touch
    session. For example, a person may touch two fingers down, expand them to zoom in (`pinchStart`
    and multiple `pinch` events fire) and then if they stop or move their fingers in one direction
    in tandem to scroll content (`pinchEnd` event fires after `pinchDelay` exceeded). If the person
    then starts expanding their fingers again without lifting them, a new set of pinch events will
    fire.

    @param {Array} touchesInSession All touches in the session.
    @returns {Boolean} True.
    @see SC.Gesture#touchesMovedInSession
    */
  touchesMovedInSession: function (touchesInSession) {
    // console.log('touchesMovedInSession: %@'.fmt(touchesInSession.length));
    // We should pay attention to the movement.
    if (touchesInSession.length > 1) {
      // Get the averaged touches for the the view. Because pinch is always interested in every touch
      // the touchesInSession will equal the touches for the view.
      var avgTouch = SC.Touch.averagedTouch(touchesInSession); // touchesInSession[0].averagedTouchesForView(this.view);

      var touchDeltaD = this._sc_pinchAnchorD - avgTouch.d,
          absDeltaD = Math.abs(touchDeltaD);

      // console.log('  this._sc_pinchAnchorD, %@ - avgTouch.d, %@ = touchDeltaD, %@'.fmt(this._sc_pinchAnchorD, avgTouch.d, touchDeltaD));
      if (absDeltaD > 0) {
        // Trigger the gesture, 'pinchStart', once.
        if (!this._sc_isPinching) {
          this.start();

          // Prepare to send 'pinchEnd'.
          this._sc_pinchingTimer = SC.Timer.schedule({
            target: this,
            action: this._sc_triggerPinchEnd,
            interval: this.get('pinchDelay')
          });

          // Track that we are pinching.
          this._sc_isPinching = true;

        // Update the last pinch time so that when the timer expires, it doesn't fire pinchEnd.
        // This is faster than invalidating and creating a new timer each time this method is called.
        } else {
          this._sc_lastPinchTime = Date.now();
        }

        // The percentage difference in touch distance.
        var scalePercentChange = avgTouch.d / this._sc_pinchAnchorD,
            scale = this._sc_pinchAnchorScale * scalePercentChange;

        // Trigger the gesture, 'pinch'.
        this.trigger(scale, touchesInSession.length);

        // Reset the anchor.
        this._sc_pinchAnchorD = avgTouch.d;
        this._sc_pinchAnchorScale = scale;
      }
    }

    return true;
  },

  /**
    Cleans up all touch session variables.

    @returns {void}
    @see SC.Gesture#touchSessionCancelled
    */
  touchSessionCancelled: function () {
    // Clean up.
    this._sc_cleanUpTouchSession();
  },

  /**
    Cleans up all touch session variables and triggers the gesture.

    @returns {void}
    @see SC.Gesture#touchSessionEnded
    */
  touchSessionEnded: function () {
    // Clean up.
    this._sc_cleanUpTouchSession();
  },

  /**
    Registers the scale of the view when it starts.

    @param {SC.Touch} touch The touch that started the session.
    @returns {void}
    @see SC.Gesture#touchSessionStarted
    */
  touchSessionStarted: function (touch) {
    var viewLayout = this.view.get('layout');

    /*jshint eqnull:true*/
    this._sc_pinchAnchorScale = viewLayout.scale == null ? 1 : viewLayout.scale;
  }

});

/* >>>>>>>>>> BEGIN source/gestures/swipe_gesture.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require("system/gesture");


/**
  @static
  @type String
  @constant
*/
SC.SWIPE_HORIZONTAL = [0, 180];

/**
  @static
  @type String
  @constant
*/
SC.SWIPE_VERTICAL = [90, -90];

/**
  @static
  @type String
  @constant
*/
SC.SWIPE_ANY = null;

/**
  @static
  @type String
  @constant
*/
SC.SWIPE_LEFT = [180];

/**
  @static
  @type String
  @constant
*/
SC.SWIPE_RIGHT = [0];

/**
  @static
  @type String
  @constant
*/
SC.SWIPE_UP = [-90];

/**
  @static
  @type String
  @constant
*/
SC.SWIPE_DOWN = [90];

/**
  ## What is a "swipe"?

  A swipe is one or more quick unidirectionally moving touches that end abruptly. By this, it is
  meant that at some point the touches begin to move quickly, `swipeVelocity` in a single direction,
  `angles`, and cover a fair amount of distance, `swipeDistance`, before ending.

  The single direction that the touches move in, must follow one of the angles specified in the
  `angles` array. However, the touches do not need to precisely match an angle and may vary by
  an amount above or below the angle as defined by the `tolerance` property.

  Because the swipe is the last moment of the touch session, the swipe gesture is always interested
  in a touch session. As long as the last distance traveled is great enough and at an
  approved angle, then a swipe will trigger.

  @class
  @extends SC.Gesture
*/
SC.SwipeGesture = SC.Gesture.extend(
/** @scope SC.SwipeGesture.prototype */ {

  //
  // - Properties --------------------------------------------------------------------
  //

  /** @private The last approved angle. Is set as long as a swipe appears valid. */
  _sc_lastAngle: null,

  /** @private The last computed distance. Is set as long as a swipe appears valid. */
  _sc_lastDistance: null,

  /** @private The number of touches in the current swipe. */
  _sc_numberOfTouches: 0,

  /** @private The initial point where a swipe appears to begin. */
  _sc_swipeAnchorX: null,

  /** @private The initial point where a swipe appears to begin. */
  _sc_swipeAnchorY: null,

  /** @private The last time a movement in a swipe was recorded. */
  _sc_swipeLastMovedAt: null,

  /**
    The angles that the swipe will accept, between 0° and ±180°. The angles start from the right
    side (0°) and end at the left side (±180°). With the positive angles passing through *down*
    (+90°) and the negative angles passing through *up* (-90°). The following ASCII art shows the
    directions of the angles,


                        -90° (up)
                          |
                          |
        (left) ± 180° --------- 0° (right)
                          |
                          |
                 (down) +90°

    To make this easier, there are several predefined angles arrays that you can use,

    * SC.SWIPE_HORIZONTAL ([180, 0]), i.e. left or right
    * SC.SWIPE_VERTICAL ([-90, 90]), i.e. up or down
    * SC.SWIPE_ANY (null), i.e. 0° to up, down, left or right
    * SC.SWIPE_LEFT ([180]), i.e. left only
    * SC.SWIPE_RIGHT ([0]), i.e. right only
    * SC.SWIPE_UP ([-90]), i.e. up only
    * SC.SWIPE_DOWN ([90]), down only

    However, you can provide any combination of angles that you want. For example, to support
    45° angled swipes to the right and straight swipes to the left, we would use,

       angles: [180, -45, 45] // 180° straight left, -45° up & right, 45° down & right

    ## How to use the angles.

    When the `swipe` event fires, the angle of the swipe is passed to your view allowing you to
    recognize which of the supported angles matched the swipe.

    Note, there is one special case, as defined by `SC.SWIPE_ANY`, which is to set angles to `null`
    in order to support swipes in *any* direction. The code will look for a swipe (unidirectional
    fast motion) in any direction and pass the observed angle to the `swipe` handler.

    @type Array
    @default 24
  */
  // This is a computed property in order to provide backwards compatibility for direction.
  // When direction is removed completely, this can become a simple `SC.SWIPE_HORIZONTAL` value.
  angles: function (key, value) {
    var direction = this.get('direction'),
      ret = SC.SWIPE_HORIZONTAL;

    // Backwards compatibility support
    if (!SC.none(direction)) {
      


      return direction;
    }

    if (!SC.none(value)) { ret = value; }

    return ret;
  }.property('direction').cacheable(),


  /** @deprecated Version 1.11. Please use the `angles` property instead.
    @type Array
    @default SC.SWIPE_HORIZONTAL
  */
  direction: SC.SWIPE_HORIZONTAL,

  /**
    @type String
    @default "swipe"
    @readOnly
  */
  name: "swipe",

  /**
    The distance in pixels that touches must move in a single direction to be far enough in order to
    be considered a swipe. If the touches don't move `swipeDistance` amount of pixels, then the
    gesture will not trigger.

    @type Number
    @default 40
  */
  swipeDistance: 40,

  /**
    The velocity in pixels per millisecond that touches must be traveling to begin a swipe motion.
    If the touches are moving slower than the velocity, the swipe start point won't be set.

    @type Number
    @default 0.5
  */
  swipeVelocity: 0.5,

  /**
    Amount of degrees that a touch is allowed to vary off of the target angle(s).

    @type Number
    @default 15
  */
  tolerance: 15,

  //
  // - Methods --------------------------------------------------------------------
  //

  /** @private Cleans up the touch session. */
  _sc_cleanUpTouchSession: function (wasCancelled) {
    // Clean up.
    this._sc_numberOfTouches = 0;
    this._sc_lastDistance = null;
    this._sc_swipeStartedAt = null;
    this._sc_lastAngle = null;
    this._sc_swipeAnchorX = null;
    this._sc_swipeAnchorY = null;
  },

  /** @private Timer used to tell if swipe was too slow. */
  _sc_swipeTooSlow: function () {
    // The session took to long to finish from when a swipe appeared to start. Reset.
    this._sc_cleanUpTouchSession();
  },

  /**
    The swipe gesture is always interested in a touch session, because it is only concerned in how
    the session ends. If it ends with a fast unidirectional sliding movement, then it is a swipe.

    Note, that for multiple touches, touches are expected to start while other touches are already
    moving. When touches are added we update the swipe start position. This means that inadvertent
    taps that occur while swiping could break a swipe recognition by making the swipe too short to
    register.

    @param {SC.Touch} touch The touch to be added to the session.
    @param {Array} touchesInSession The touches already in the session.
    @returns {Boolean} True as long as the new touch doesn't start too late after the first touch.
    @see SC.Gesture#touchAddedToSession
    */
  // TODO: What about first touch starts moving, second touch taps, first touch finishes?
  // TODO: What about first touch starts tap, second touch starts moving, first touch finishes tap, second touch finishes?
  touchAddedToSession: function (touch, touchesInSession) {
    // Get the averaged touches for the the view. Because pinch is always interested in every touch
    // the touchesInSession will equal the touches for the view.
    var avgTouch = touch.averagedTouchesForView(this.view, true);

    this._sc_swipeAnchorX = avgTouch.x;
    this._sc_swipeAnchorY = avgTouch.y;

    return true;
  },

  /**
    The swipe gesture is always interested in a touch session, because it is only concerned in how
    the session ends. If it ends with a fast unidirectional sliding movement, then it is a swipe.

    Note, that a touch may cancel while swiping (went off screen inadvertently). Because of this we
    don't immediately reduce the number of touches in the swipe, because if the rest of the touches
    end right away in a swipe, it's best to consider the cancelled touch as part of the group.

    @param {SC.Touch} touch The touch to be removed from the session.
    @param {Array} touchesInSession The touches in the session.
    @returns {Boolean} True
    @see SC.Gesture#touchCancelledInSession
    */
  touchCancelledInSession: function (touch, touchesInSession) {
    return true;
  },

  /**
    The swipe gesture is always interested in a touch session, because it is only concerned in how
    the session ends. If it ends with a fast unidirectional sliding movement, then it is a swipe.

    Note, that touches are expected to end while swiping. Because of this we don't immediately
    reduce the number of touches in the swipe, because if the rest of the touches also end right
    away in a swiping motion, it's best to consider this ended touch as part of the group.

    @param {SC.Touch} touch The touch to be removed from the session.
    @param {Array} touchesInSession The touches in the session.
    @returns {Boolean} True if it is the first touch to end or a subsequent touch that ends not too long after the first touch ended.
    @see SC.Gesture#touchEndedInSession
  */
  touchEndedInSession: function (touch, touchesInSession) {
    return true;
  },

  /** @private Test the given angle against an approved angle. */
  _sc_testAngle: function (absoluteCurrentAngle, currentIsPositive, approvedAngle, tolerance) {
    var angleIsPositive = approvedAngle >= 0,
        absoluteAngle = !angleIsPositive ? Math.abs(approvedAngle) : approvedAngle,
        upperBound = absoluteAngle + tolerance,
        lowerBound = absoluteAngle - tolerance,
        ret = false;

    if (lowerBound <= absoluteCurrentAngle && absoluteCurrentAngle <= upperBound) {
      // Special case: ex. Don't confuse -45° with 45° or vice versa.
      var upperBoundIsPositive = upperBound >= 0 && upperBound <= 180,
          lowerBoundIsPositive = lowerBound >= 0;

      ret = upperBoundIsPositive === lowerBoundIsPositive ? currentIsPositive === angleIsPositive : true;
    }

    return ret;
  },

  /**
    The swipe gesture is always interested in a touch session, because it is only concerned in how
    the session ends. If it ends with a fast unidirectional sliding movement, then it is a swipe.

    @param {Array} touchesInSession All touches in the session.
    @returns {Boolean} True as long as none of the touches have moved too far off-axis to be a clean swipe.
    @see SC.Gesture#touchesMovedInSession
    */
  touchesMovedInSession: function (touchesInSession) {
    // Get the averaged touches for the the view. Because swipe is always interested in every touch
    // (or none) the touchesInSession will equal the touches for the view.
    var angles = this.get('direction'),
        avgTouch = touchesInSession[0].averagedTouchesForView(this.view),
        xDiff = avgTouch.x - this._sc_swipeAnchorX,
        yDiff = avgTouch.y - this._sc_swipeAnchorY,
        currentAngle = Math.atan2(yDiff, xDiff) * (180 / Math.PI),
        absoluteCurrentAngle = Math.abs(currentAngle),
        currentIsPositive = currentAngle >= 0,
        tolerance = this.get('tolerance'),
        approvedAngle = null,
        angle;

    // There is one special case, when angles is null, allow all angles.
    if (angles === null) {
      // Use the last angle against itself.
      angle = this._sc_lastAngle;

      if (angle !== null) {
        var withinLastAngle = this._sc_testAngle(absoluteCurrentAngle, currentIsPositive, angle, tolerance);

        // If still within the start angle, leave it going.
        if (withinLastAngle) {
          approvedAngle = angle;
        } else {
          approvedAngle = currentAngle;
        }
      } else {
        approvedAngle = currentAngle;
      }

    // Check against approved angles.
    } else {
      for (var i = 0, len = angles.length; i < len; i++) {
        angle = angles[i];

        // If the current angle is within the tolerance of the given angle, it's a match.
        if (this._sc_testAngle(absoluteCurrentAngle, currentIsPositive, angle, tolerance)) {
          approvedAngle = angle;

          break; // No need to continue.
        }
      }
    }

    // Got angle.
    if (approvedAngle !== null) {
      // Same angle. Ensure we're traveling fast enough to keep the angle.
      if (this._sc_lastAngle === approvedAngle) {
        // Get distance between the anchor and current average point.
        var dx = Math.abs(xDiff),
            dy = Math.abs(yDiff),
            now = Date.now(),
            distance,
            velocity;

        distance = Math.pow(dx * dx + dy * dy, 0.5);
        velocity = distance / (now - this._sc_swipeStartedAt);

        // If velocity is too slow, lost swipe.
        var minimumVelocity = this.get('swipeVelocity');
        if (velocity < minimumVelocity) {
          this._sc_lastAngle = null;
          this._sc_swipeAnchorX = avgTouch.x;
          this._sc_swipeAnchorY = avgTouch.y;
          this._sc_lastDistance = 0;
          this._sc_swipeStartedAt = null;
        } else {
          // Track how far we've gone in this approved direction.
          this._sc_lastDistance = distance;
          this._sc_swipeLastMovedAt = Date.now();
        }

      // This is the first matched angle or a new direction. Track its values for future comparison.
      } else {
        // Track the current approved angle and when we started going on it.
        this._sc_lastAngle = approvedAngle;
        this._sc_swipeStartedAt = Date.now();

        // Use the current number of touches as the number in the session. Some may get cancelled.
        this._sc_numberOfTouches = touchesInSession.length;
      }

    // No angle or lost the angle.
    } else {
      this._sc_lastAngle = null;
      this._sc_swipeAnchorX = avgTouch.x;
      this._sc_swipeAnchorY = avgTouch.y;
      this._sc_lastDistance = 0;
      this._sc_swipeStartedAt = null;
    }

    return true;
  },

  /**
    Cleans up all touch session variables.

    @returns {void}
    @see SC.Gesture#touchSessionCancelled
    */
  touchSessionCancelled: function () {
    // Clean up.
    this._sc_cleanUpTouchSession(true);
  },

  /**
    Cleans up all touch session variables and triggers the gesture.

    @returns {void}
    @see SC.Gesture#touchSessionEnded
    */
  touchSessionEnded: function () {
    // Watch out for touches that move far and fast, but then hesitate too long before ending.
    var notTooLongSinceLastMove = (Date.now() - this._sc_swipeLastMovedAt) < 200;

    // If an approved angle remained set, the distance was far enough and it wasn't too long since
    // the last movement, trigger the gesture, 'swipe'.
    if (this._sc_lastAngle !== null &&
      this._sc_lastDistance > this.get('swipeDistance') &&
      notTooLongSinceLastMove) {
      this.trigger(this._sc_lastAngle, this._sc_numberOfTouches);
    }

    // Clean up (will fire tapEnd if _sc_isTapping is true).
    this._sc_cleanUpTouchSession(false);
  },

  touchSessionStarted: function (touch) {
    this._sc_swipeAnchorX = touch.pageX;
    this._sc_swipeAnchorY = touch.pageY;
  }

});

/* >>>>>>>>>> BEGIN source/gestures/tap_gesture.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2010 Strobe Inc. All rights reserved.
// Author:    Peter Wagenet
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require("system/gesture");

/**
  ## What is a "tap"?

  A tap is a touch that starts and ends in a short amount of time without moving along either axis.
  A tap may consist of more than one touch, provided that the touches start and end together. The time
  allowed for touches to start and end together is defined by `touchUnityDelay`.
  Again, to be considered a tap, there should be very little movement of any touches on either axis
  while still touching. The amount of movement allowed is defined by `tapWiggle`.

  @class
  @extends SC.Gesture
*/
SC.TapGesture = SC.Gesture.extend(
/** @scope SC.TapGesture.prototype */{

  /** @private The time that the first touch started at. */
  _sc_firstTouchAddedAt: null,

  /** @private The time that the first touch ended at. */
  _sc_firstTouchEndedAt: null,

  /** @private A flag used to track when the touch was long enough to register tapStart (and tapEnd). */
  _sc_isTapping: false,

  /** @private The number of touches in the current tap. */
  _sc_numberOfTouches: 0,

  /** @private A timer started after the first touch starts. */
  _sc_tapStartTimer: null,

  /**
    @type String
    @default "tap"
    @readOnly
  */
  name: "tap",

  /**
    The amount of time in milliseconds between when the first touch starts and the last touch ends
    that should be considered a short enough time to constitute a tap.

    @type Number
    @default 250
  */
  tapLengthDelay: 250,

  /**
    The amount of time in milliseconds after the first touch starts at which, *if the tap hasn't
    ended in that time*, the `tapStart` event should trigger.

    Because taps may be very short or because movement of the touch may invalidate a tap gesture
    entirely, you generally won't want to update the state of the view immediately when a touch
    starts.

    @type Number
    @default 150
    */
  tapStartDelay: 150,

  /**
    The number of pixels that a touch may move before it will no longer be considered a tap. If any
    of the touches move more than this amount, the gesture will give up.

    @type Number
    @default 10
  */
  tapWiggle: 10,

  /**
    The number of milliseconds that touches must start and end together in in order to be considered a
    tap. If the touches start too far apart in time or end too far apart in time based on this
    value, the gesture will give up.

    @type Number
    @default 75
  */
  touchUnityDelay: 75,

  /** @private Calculates the distance a touch has moved. */
  _sc_calculateDragDistance: function (touch) {
    return Math.sqrt(Math.pow(touch.pageX - touch.startX, 2) + Math.pow(touch.pageY - touch.startY, 2));
  },

  /** @private Cleans up the touch session. */
  _sc_cleanUpTouchSession: function (wasCancelled) {
    if (this._sc_isTapping) {
      // Trigger the gesture, 'tapCancelled'.
      if (wasCancelled) {
        this.cancel();

      // Trigger the gesture, 'tapEnd'.
      } else {
        this.end();
      }

      this._sc_isTapping = false;
    }

    // Clean up.
    this._sc_tapStartTimer.invalidate();
    this._sc_numberOfTouches = 0;
    this._sc_tapStartTimer = this._sc_firstTouchAddedAt = this._sc_firstTouchEndedAt = null;
  },

  /** @private Triggers the tapStart event. Should *not* be reachable unless the tap is still valid. */
  _sc_triggerTapStart: function () {
      // Trigger the gesture, 'tapStart'.
    this.start();

    this._sc_isTapping = true;
  },

  /**
    The tap gesture only remains interested in a touch session as long as none of the touches have
    started too long after the first touch (value of `touchUnityDelay`). Once any touch has started
    too late, the tap gesture gives up for the entire touch session and won't attempt to re-engage
    (i.e. even if an extra touch "taps" cleanly in the same touch session, it won't trigger any
    further tap callbacks).

    @param {SC.Touch} touch The touch to be added to the session.
    @param {Array} touchesInSession The touches already in the session.
    @returns {Boolean} True as long as the new touch doesn't start too late after the first touch.
    @see SC.Gesture#touchAddedToSession
    */
  touchAddedToSession: function (touch, touchesInSession) {
    var stillInterestedInSession,
        delay;

    // If the new touch came in too late after the first touch was added.
    delay = Date.now() - this._sc_firstTouchAddedAt;
    stillInterestedInSession = delay < this.get('touchUnityDelay');

    return stillInterestedInSession;
  },

  /**
    If a touch cancels, the tap doesn't care and remains interested.

    @param {SC.Touch} touch The touch to be removed from the session.
    @param {Array} touchesInSession The touches in the session.
    @returns {Boolean} True
    @see SC.Gesture#touchCancelledInSession
    */
  touchCancelledInSession: function (touch, touchesInSession) {
    return true;
  },

  /**
    The tap gesture only remains interested in a touch session as long as none of the touches have
    ended too long after the first touch ends (value of `touchUnityDelay`). Once any touch has ended
    too late, the tap gesture gives up for the entire touch session and won't attempt to re-engage
    (i.e. even if an extra touch "taps" cleanly in the same touch session, it won't trigger any
    further tap callbacks).

    @param {SC.Touch} touch The touch to be removed from the session.
    @param {Array} touchesInSession The touches in the session.
    @returns {Boolean} True if it is the first touch to end or a subsequent touch that ends not too long after the first touch ended.
    @see SC.Gesture#touchEndedInSession
  */
  touchEndedInSession: function (touch, touchesInSession) {
    var stillInterestedInSession;

    // Increment the number of touches in the tap.
    this._sc_numberOfTouches += 1;

    // If it's the first touch to end, remain interested unless tapLengthDelay has passed.
    if (this._sc_firstTouchEndedAt === null) {
      this._sc_firstTouchEndedAt = Date.now();
      stillInterestedInSession = this._sc_firstTouchEndedAt - this._sc_firstTouchAddedAt < this.get('tapLengthDelay');

    // If the touch ended too late after the first touch ended, give up entirely.
    } else {
      stillInterestedInSession = Date.now() - this._sc_firstTouchEndedAt < this.get('touchUnityDelay');
    }

    return stillInterestedInSession;
  },

  /**
    The tap gesture only remains interested in a touch session as long as none of the touches have
    moved too far (value of `tapWiggle`). Once any touch has moved too far, the tap gesture gives
    up for the entire touch session and won't attempt to re-engage (i.e. even if an extra touch
    "taps" cleanly in the same touch session, it won't trigger any further tap callbacks).

    @param {Array} touchesInSession All touches in the session.
    @returns {Boolean} True as long as none of the touches have moved too far to be a clean tap.
    @see SC.Gesture#touchesMovedInSession
    */
  touchesMovedInSession: function (touchesInSession) {
    var stillInterestedInSession = true;

    for (var i = 0, len = touchesInSession.length; i < len; i++) {
      var touch = touchesInSession[i],
          movedTooFar = this._sc_calculateDragDistance(touch) > this.get('tapWiggle');

      // If any touch has gone too far, we don't want to consider any further tap actions for this
      // session. No need to continue.
      if (movedTooFar) {
        stillInterestedInSession = false;
        break;
      }
    }

    return stillInterestedInSession;
  },

  /**
    Cleans up all touch session variables.

    @returns {void}
    @see SC.Gesture#touchSessionCancelled
    */
  touchSessionCancelled: function () {
    // Clean up (will fire tapCancelled if _sc_isTapping is true).
    this._sc_cleanUpTouchSession(true);
  },

  /**
    Cleans up all touch session variables and triggers the gesture.

    @returns {void}
    @see SC.Gesture#touchSessionEnded
    */
  touchSessionEnded: function () {
    // Trigger the gesture, 'tap'.
    this.trigger(this._sc_numberOfTouches);

    // Clean up (will fire tapEnd if _sc_isTapping is true).
    this._sc_cleanUpTouchSession(false);
  },

  /**
    Registers when the first touch started.

    @param {SC.Touch} touch The touch that started the session.
    @returns {void}
    @see SC.Gesture#touchSessionStarted
    */
  touchSessionStarted: function (touch) {
    // Initialize.
    this._sc_firstTouchAddedAt = Date.now();

    this._sc_tapStartTimer = SC.Timer.schedule({
      target: this,
      action: this._sc_triggerTapStart,
      interval: this.get('tapStartDelay')
    });
  }

});

/* >>>>>>>>>> BEGIN source/license.js */
/** 
 * @license Portions of this software are copyright Yahoo, Inc, used under the following license:
 * Software License Agreement (BSD License)
 * Copyright (c) 2009, Yahoo! Inc.
 * All rights reserved.
 * Redistribution and use of this software in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 * 
 * Redistributions of source code must retain the above copyright notice, this list of conditions and the
 * following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 * Neither the name of Yahoo! Inc. nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission of Yahoo! Inc.
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * Sources of Intellectual Property Included in the YUI Library
 * Where not otherwise indicated, all YUI content is authored by Yahoo! engineers and consists of Yahoo!-owned intellectual property. YUI is issued by Yahoo! under the BSD license above. In some specific instances, YUI will incorporate work done by developers outside of Yahoo! with their express permission.

*/

/** 
 * @license jQuery 1.2.6 - New Wave Javascript
 * 
 * Copyright (c) 2008 John Resig (jquery.com)
 * Dual licensed under the MIT (MIT-LICENSE.txt)
 * and GPL (GPL-LICENSE.txt) licenses.
 *  
 * $Date: 2008-05-24 14:22:17 -0400 (Sat, 24 May 2008) $
 * $Rev: 5685 $
*/
/* >>>>>>>>>> BEGIN source/lproj/inflections.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/** @private
  Active Support style inflection constants
*/
SC.hashesForLocale('en', 'inflectionConstants', {
  /** @private */
  PLURAL: [
    [/(quiz)$/i,               "$1zes"  ],
    [/^(ox)$/i,                "$1en"   ],
    [/([m|l])ouse$/i,          "$1ice"  ],
    [/(matr|vert|ind)ix|ex$/i, "$1ices" ],
    [/(x|ch|ss|sh)$/i,         "$1es"   ],
    [/([^aeiouy]|qu)y$/i,      "$1ies"  ],
    [/(hive)$/i,               "$1s"    ],
    [/(?:([^f])fe|([lr])f)$/i, "$1$2ves"],
    [/sis$/i,                  "ses"    ],
    [/([ti])um$/i,             "$1a"    ],
    [/(buffal|tomat)o$/i,      "$1oes"  ],
    [/(bu)s$/i,                "$1ses"  ],
    [/(alias|status)$/i,       "$1es"   ],
    [/(octop|vir)us$/i,        "$1i"    ],
    [/(ax|test)is$/i,          "$1es"   ],
    [/s$/i,                    "s"      ],
    [/$/,                      "s"      ]
  ],

  /** @private */
  SINGULAR: [
    [/(quiz)zes$/i,                                                    "$1"     ],
    [/(matr)ices$/i,                                                   "$1ix"   ],
    [/(vert|ind)ices$/i,                                               "$1ex"   ],
    [/^(ox)en/i,                                                       "$1"     ],
    [/(alias|status)es$/i,                                             "$1"     ],
    [/(octop|vir)i$/i,                                                 "$1us"   ],
    [/(cris|ax|test)es$/i,                                             "$1is"   ],
    [/(shoe)s$/i,                                                      "$1"     ],
    [/(o)es$/i,                                                        "$1"     ],
    [/(bus)es$/i,                                                      "$1"     ],
    [/([m|l])ice$/i,                                                   "$1ouse" ],
    [/(x|ch|ss|sh)es$/i,                                               "$1"     ],
    [/(m)ovies$/i,                                                     "$1ovie" ],
    [/(s)eries$/i,                                                     "$1eries"],
    [/([^aeiouy]|qu)ies$/i,                                            "$1y"    ],
    [/([lr])ves$/i,                                                    "$1f"    ],
    [/(tive)s$/i,                                                      "$1"     ],
    [/(hive)s$/i,                                                      "$1"     ],
    [/([^f])ves$/i,                                                    "$1fe"   ],
    [/(^analy)ses$/i,                                                  "$1sis"  ],
    [/((a)naly|(b)a|(d)iagno|(p)arenthe|(p)rogno|(s)ynop|(t)he)ses$/i, "$1$2sis"],
    [/([ti])a$/i,                                                      "$1um"   ],
    [/(n)ews$/i,                                                       "$1ews"  ],
    [/s$/i,                                                            ""       ]
  ],

  /** @private */
  IRREGULAR: [
    ['move',   'moves'   ],
    ['sex',    'sexes'   ],
    ['child',  'children'],
    ['man',    'men'     ],
    ['person', 'people'  ],
    ['woman',  'women'   ],
    ['self',   'selves'  ]
  ],

  /** @private */
  UNCOUNTABLE: [
    "sheep",
    "fish",
    "series",
    "species",
    "money",
    "rice",
    "information",
    "info",
    "equipment"
  ]
});
/* >>>>>>>>>> BEGIN source/mixins/auto_mixin.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @deprecated SC.AutoMixin is deprecated. Please use the property autoMixins of SC.View instead
  @namespace

  Use this mixin to automatically mix in a list of mixins into all
  child views created _by the view_ (that are created at view initialization).

  @since SproutCore 1.0
*/
SC.AutoMixin = {

  /**
    An array of mixins to automatically mix in to each child view of this
    view when the child view is created.

    @type Array
    @default []
  */
  autoMixins: [],

  /**
    @private
    Override createChildViews to mix in the mixins defined in autoMixins.
  */
  createChildView: function (view, attrs) {
    if (!view.isClass) {
      attrs = view;
    } else {
      // attrs should always exist...
      if (!attrs) { attrs = {}; }
      // clone the hash that was given so we do not pollute it if it's being reused
      else { attrs = SC.clone(attrs); }
    }

    attrs.owner = attrs.parentView = this;
    if (!attrs.page) attrs.page = this.page;

    if (view.isClass) {
      // Track that we created this view.
      attrs.createdByParent = true;

      // Add the mixins to the child's attributes.
      var applyMixins = SC.clone(this.get("autoMixins"));
      applyMixins.push(attrs);

      view = view.create.apply(view, applyMixins);
    }

    return view;
  }

};

/* >>>>>>>>>> BEGIN source/system/utils/string_measurement.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

SC.mixin( /** @scope SC */ {

  _copy_computed_props: [
    "maxWidth", "maxHeight", "paddingLeft", "paddingRight", "paddingTop", "paddingBottom",
    "fontFamily", "fontSize", "fontStyle", "fontWeight", "fontVariant", "lineHeight",
    "whiteSpace", "letterSpacing", "wordWrap"
  ],

  /**
    Returns a string representation of the layout hash.

    Layouts can contain the following keys:
      - left: the left edge
      - top: the top edge
      - right: the right edge
      - bottom: the bottom edge
      - height: the height
      - width: the width
      - centerX: an offset from center X
      - centerY: an offset from center Y
      - minWidth: a minimum width
      - minHeight: a minimum height
      - maxWidth: a maximum width
      - maxHeight: a maximum height
      - rotateX
      - rotateY
      - rotateZ
      - scale

    @param layout {Hash} The layout hash to stringify.
    @returns {String} A string representation of the layout hash.
  */
  stringFromLayout: function(layout) {
    // Put them in the reverse order that we want to display them, because
    // iterating in reverse is faster for CPUs that can compare against zero
    // quickly.
    var keys = ['maxHeight', 'maxWidth', 'minHeight', 'minWidth', 'centerY',
                'centerX', 'width', 'height', 'bottom', 'right', 'top',
                'left', 'zIndex', 'opacity', 'border', 'borderLeft',
                'borderRight', 'borderTop', 'borderBottom', 'rotateX',
                'rotateY', 'rotateZ', 'scale'],
        keyValues = [], key,
        i = keys.length;
    while (--i >= 0) {
      key = keys[i];
      if (layout.hasOwnProperty(key)) {
        keyValues.push(key + ':' + layout[key]);
      }
    }

    return '{ ' + keyValues.join(', ') + ' }';
  },

  /**
    Given a string and a fixed width, calculates the height of that
    block of text using a style string, a set of class names,
    or both.

    @param str {String} The text to calculate
    @param width {Number} The fixed width to assume the text will fill
    @param style {String} A CSS style declaration.  E.g., 'font-weight: bold'
    @param classNames {Array} An array of class names that may affect the style
    @param ignoreEscape {Boolean} To NOT html escape the string.
    @returns {Number} The height of the text given the passed parameters
  */
  heightForString: function(str, width, style, classNames, ignoreEscape) {
    var elem = this._heightCalcElement, classes, height;

    if(!ignoreEscape) str = SC.RenderContext.escapeHTML(str);

    // Coalesce the array of class names to one string, if the array exists
    classes = (classNames && SC.typeOf(classNames) === SC.T_ARRAY) ? classNames.join(' ') : '';

    if (!width) width = 100; // default to 100 pixels

    // Only create the offscreen element once, then cache it
    if (!elem) {
      elem = this._heightCalcElement = document.createElement('div');
      document.body.insertBefore(elem, null);
    }

    style = style+'; width: '+width+'px; left: '+(-1*width)+'px; position: absolute';
    var cqElem = SC.$(elem);
    cqElem.attr('style', style);

    if (classes !== '') {
      cqElem.attr('class', classes);
    }

    elem.innerHTML = str;
    height = elem.clientHeight;

    elem = null; // don't leak memory
    return height;
  },

  /**
    Sets up a string measuring environment.

    You may want to use this, in conjunction with teardownStringMeasurement and
    measureString, instead of metricsForString, if you will be measuring many
    strings with the same settings. It would be a lot more efficient, as it
    would only prepare and teardown once instead of several times.

    @param exampleElement The example element to grab styles from, or the style
                          string to use.
    @param classNames {String} (Optional) Class names to add to the test element.
  */
  prepareStringMeasurement: function(exampleElement, classNames) {
    var element = this._metricsCalculationElement, classes, style,
        cqElem;

    // collect the class names
    classes = SC.A(classNames).join(' ');

    // get the calculation element
    if (!element) {
      var parentElement = document.createElement("div");

      // To have effectively unbounded widths when no max-width is set,
      // give the metricsCalculationElement a very wide sandbox.
      // To make sure it's never visible, position it way, way offscreen.
      parentElement.style.cssText = "position:absolute; left:-10010px; top:-10px;"+
                                    "width:10000px; height:0px; overflow:hidden;"+
                                    "visibility:hidden;";

      element = this._metricsCalculationElement = document.createElement("div");

      parentElement.appendChild(element);
      document.body.insertBefore(parentElement, null);
    }

    cqElem = SC.$(element);
    // two possibilities: example element or type string
    if (SC.typeOf(exampleElement) != SC.T_STRING) {
      var computed = null;
      if (document.defaultView && document.defaultView.getComputedStyle) {
        computed = document.defaultView.getComputedStyle(exampleElement, null);
      } else {
      computed = exampleElement.currentStyle;
      }

      var props = this._copy_computed_props;

      // firefox ONLY allows this method
      for (var i = 0; i < props.length; i++) {
        var prop = props[i], val = computed[prop];
        element.style[prop] = val;
      }

      // and why does firefox specifically need "font" set?
      var cs = element.style; // cached style
      if (cs.font === "") {
        var font = "";
        if (cs.fontStyle) font += cs.fontStyle + " ";
        if (cs.fontVariant) font += cs.fontVariant + " ";
        if (cs.fontWeight) font += cs.fontWeight + " ";
        if (cs.fontSize) font += cs.fontSize; else font += "10px"; //force a default
        if (cs.lineHeight) font += "/" + cs.lineHeight;
        font += " ";
        if (cs.fontFamily) font += cs.fontFamily; else cs += "sans-serif";

        element.style.font = font;
      }

      SC.mixin(element.style, {
        left: "0px", top: "0px", position: "absolute", bottom: "auto", right: "auto", width: "auto", height: "auto"
      });
     // clean up
      computed = null;
    } else {
      // it is a style string already
      style = exampleElement;

      // set style
      cqElem.attr("style", style + "; position:absolute; left: 0px; top: 0px; bottom: auto; right: auto; width: auto; height: auto;");
    }

    element.className = classes;
    element = null;
  },

  /**
    Tears down the string measurement environment. Usually, this doesn't _have_
    to be called, but there are too many what ifs: for example, what if the measurement
    environment has a bright green background and is over 10,000px wide? Guess what: it will
    become visible on the screen.

    So, generally, we tear the measurement environment down so that it doesn't cause issue.
    However, we keep the DOM element for efficiency.
  */
  teardownStringMeasurement: function() {
    var element = this._metricsCalculationElement;

    // clear element
    element.innerHTML = "";
    element.className = "";
    element.setAttribute("style", ""); // get rid of any junk from computed style.
    element = null;
  },

  /**
    Measures a string in the prepared environment.

    An easier and simpler alternative (but less efficient for bulk measuring) is metricsForString.

    @param string {String} The string to measure.
    @param ignoreEscape {Boolean} To NOT html escape the string.
  */
  measureString: function(string, ignoreEscape) {
    var element = this._metricsCalculationElement,
    padding = 0;

    if (!element) {
      throw new Error("measureString requires a string measurement environment to be set up. Did you mean metricsForString?");
    }

    // since the string has already been escaped (if the user wants it to be),
    // we should set the innerHTML instead of innertext
    if(ignoreEscape) element.innerHTML = string;
    // the conclusion of which to use (innerText or textContent) should be cached
    else if (typeof element.innerText != "undefined") element.innerText = string;
    else element.textContent = string;

    // for some reason IE measures 1 pixel too small
    if(SC.browser.isIE) padding = 1;

    // generate result
    var result = {
      width: element.clientWidth + padding,
      height: element.clientHeight
    };

    // Firefox seems to be 1 px short at times, especially with non english characters.
    if (SC.browser.isMozilla) {
      result.width += 1;
    }

    element = null;
    return result;
  },

  /**
    Given a string and an example element or style string, and an optional
    set of class names, calculates the width and height of that block of text.

    To constrain the width, set max-width on the exampleElement or in the style string.

    @param string {String} The string to measure.
    @param exampleElement The example element to grab styles from, or the style string to use.
    @param classNames {String} (Optional) Class names to add to the test element.
    @param ignoreEscape {Boolean} To NOT html escape the string.
  */
  metricsForString: function(string, exampleElement, classNames, ignoreEscape) {
    SC.prepareStringMeasurement(exampleElement, classNames);
    var result = SC.measureString(string, ignoreEscape);
    SC.teardownStringMeasurement();
    return result;
  }

});

/* >>>>>>>>>> BEGIN source/mixins/auto_resize.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require("system/utils/string_measurement");

/**
  @class
  Use this mixin to make your view automatically resize based upon its value,
  title, or other string property. Only works for views that support automatic
  resizing.

  Supporting Automatic Resizing
  -------------------------------------
  To support automatic resizing, your view must provide these properties:

  - *`supportsAutoResize`.* Must be set to YES.

  - *`autoResizeLayer`* A DOM element to use as a template for resizing the
    view. Font sizes and other styles will be copied to the measuring element
    SproutCore uses to measure the text.

  - *`autoResizeText`.* The text to measure. A button view might make a proxy
    to its `displayTitle`, for instance.

  Your view may also supply:

  - *`autoResizePadding`.* An amount to add to the measured size. This may be either
    a single number to be added to both width and height, or a hash containing
    separate `width` and `height` properties.


  NOTE: these properties are not defined in the mixin itself because the supporting view,
  rather than the user of SC.AutoResize, will be providing the properties, and mixing
  SC.AutoResize into the view should not override these properties.
*/
SC.AutoResize = {
  /*@scope SC.AutoResize.prototype */

  /**
    If YES, automatically resizes the view (default). If NO, only measures,
    setting 'measuredSize' to the measured value (you can bind to measuredSize
    and update size manually).

    @type Boolean
    @default YES
  */
  shouldAutoResize: YES,

  /**
    If NO, prevents SC.AutoResize from doing anything at all.

    @type Boolean
    @default YES
  */
  shouldMeasureSize: YES,

  /**
    Caches sizes for measured strings. This cache does not have a max size, so
    should only be used when a view has a limited number of possible values.
    Multiple views that have the same batchResizeId will share the same cache.

    @type Boolean
    @default NO
  */
  shouldCacheSizes: NO,

  /**
    Determines if the view's width should be resized
    on calculation.

    @type Boolean
    @default YES
  */
  shouldResizeWidth: YES,

  /**
    Determines if the view's height should be resized
    on calculation. Default is NO to retain backwards
    compatibility.

    @type Boolean
    @default NO
  */
  shouldResizeHeight: NO,

  /**
    The measured size of the view's content (the value of the autoResizeField).
    This property is observable, and, if used in conjunction with setting
    shouldAutoResize to NO, allows you to customize the 'sizing' part, using
    SC.AutoResize purely for its measuring code.

    @type Rect
  */
  measuredSize: { width: 0, height: 0 },

  /**
    If provided, will limit the maximum width to this value.
  */
  maxWidth: null,

  /**
    If provided, will limit the maximum height to this value.
  */
  maxHeight: null,

  /**
    If YES, the view's text will be resized to fit the view. This is applied _after_ any
    resizing, so will only take affect if shouldAutoResize is off, or a maximum width/height
    is set.

    You also must set a minimum and maximum font size. Any auto resizing will happen at the
    maximum size, and then the text will be resized as necessary.
  */
  shouldAutoFitText: NO,

  /**
    If NO, the calculated font size may be any size between minFontSize and
    maxFontSize. If YES, it will only be either minFontSize or maxFontSize.

    @type Boolean
    @default NO
  */
  autoFitDiscreteFontSizes: NO,

  /**
    The minimum font size to use when automatically fitting text. If shouldAutoFitText is set,
    this _must_ be supplied.

    Font size is in pixels.
  */
  minFontSize: 12,

  /**
    The maximum font size to use when automatically fitting text. If shouldAutoFitText is set,
    this _must_ be supplied.

    Font size is in pixels.
  */
  maxFontSize: 20,

  /**
    If shouldAutoFitText is YES, this is the calculated font size.
  */
  calculatedFontSize: 20,

  fontPropertyDidChange: function() {
    if(this.get('shouldAutoFitText')) this.invokeLast(this.fitTextToFrame);
  }.observes('shouldAutoFitText', 'minFontSize', 'maxFontSize', 'measuredSize'),

  /**
    Observes the measured size and actually performs the resize if necessary.
  */
  measuredSizeDidChange: function() {
    var measuredSize = this.get('measuredSize'),
      calculatedWidth = measuredSize.width,
      calculatedHeight = measuredSize.height,
      paddingHeight, paddingWidth,
      autoResizePadding = this.get('autoResizePadding') || 0,
      maxWidth = this.get('maxWidth'),
      maxHeight = this.get('maxHeight');

    if (SC.typeOf(autoResizePadding) === SC.T_NUMBER) {
      paddingHeight = paddingWidth = autoResizePadding;
    } else {
      paddingHeight = autoResizePadding.height;
      paddingWidth = autoResizePadding.width;
    }

    calculatedHeight += paddingHeight;
    calculatedWidth += paddingWidth;

    if (this.get('shouldAutoResize')) {
      // if we are allowed to autoresize, adjust the layout
      if (this.get('shouldResizeWidth')) {
        if (maxWidth && calculatedWidth > maxWidth) {
          calculatedWidth = maxWidth;
        }
        this.set('calculatedWidth', calculatedWidth);

        this.adjust('width', calculatedWidth);
      }

      if (this.get('shouldResizeHeight')) {
        if (maxHeight && calculatedHeight > maxHeight) {
          calculatedHeight = maxHeight;
        }
        this.set('calculatedHeight', calculatedHeight);
        this.adjust('height', calculatedHeight);
      }
    }

  }.observes('shouldAutoResize', 'measuredSize', 'autoResizePadding', 'maxWidth', 'maxHeight', 'shouldResizeWidth', 'shouldResizeHeight'),

  /**
    @private
    Begins observing the auto resize field.
  */
  


  /**
    If this property is provided, all views that share the same value for this property will be resized as a batch for increased performance.

    @type String
  */
  batchResizeId: null,

  /**
    Schedules a measurement to happen later.
  */
  scheduleMeasurement: function() {
    var batchResizeId = this.get('batchResizeId');

    // only measure if we are visible, active, and the text or style actually changed
    if (!this.get('shouldMeasureSize') || !this.get('isVisibleInWindow') || (this.get('autoResizeText') === this._lastMeasuredText && batchResizeId === this._lastMeasuredId)) return;

    // batchResizeId is allowed to be undefined; views without an id will just
    // get measured one at a time
    SC.AutoResizeManager.scheduleMeasurementForView(this, batchResizeId);
  }.observes('isVisibleInWindow', 'shouldMeasureSize', 'autoResizeText', 'batchResizeId'),

  /** @private */
  _lastMeasuredText: null,

  /** @private */
  _cachedMetrics: function(key, value) {
    if(!this.get('shouldCacheSizes')) return;

    // if we don't have a tag, then it is unique per view
    // you shouldn't usually turn on caching without a tag, but it is supported
    var cacheSlot = SC.cacheSlotFor(this.get('batchResizeId') || this),
    autoResizeText = this.get('autoResizeText');

    if(value) cacheSlot[autoResizeText] = value;
    else value = cacheSlot[autoResizeText];

    return value;
  }.property('shouldCacheSizes', 'autoResizeText', 'batchResizeId').cacheable(),

  /**
    Measures the size of the view.

    @param batch For internal use during batch resizing.
  */
  measureSize: function(batch) {
    var metrics, layer = this.get('autoResizeLayer'),
        autoResizeText = this.get('autoResizeText'),
        ignoreEscape = !this.get('escapeHTML'),
        batchResizeId = this.get('batchResizeId'),
        cachedMetrics = this.get('_cachedMetrics');
        // maxFontSize = this.get('maxFontSize');

    if (!layer) return;

    // There are three special cases.
    //   - size is cached: the cached size is used with no measurement
    //     necessary
    //   - empty: we should do nothing. The metrics are 0.
    //   - batch mode: just call measureString.
    //
    // If we are in neither of those special cases, we should go ahead and
    // resize normally.
    //
    if(cachedMetrics) {
      metrics = cachedMetrics;
    }

    else if (SC.none(autoResizeText) || autoResizeText === "") {
      metrics = { width: 0, height: 0 };
    }

    else if (batch) {
      metrics = SC.measureString(autoResizeText, ignoreEscape);
    }

    else {
      this.prepareLayerForStringMeasurement(layer);

      metrics = SC.metricsForString(autoResizeText, layer, this.get('classNames'), ignoreEscape);
    }

    // In any case, we set measuredSize.
    this.set('measuredSize', metrics);

    // and update the cache if we are using it
    if(this.get('shouldCacheSizes')) this.setIfChanged('_cachedMetrics', metrics);

    // set the measured value so we can avoid extra measurements in the future
    this._lastMeasuredText = autoResizeText;
    this._lastMeasuredId = batchResizeId;

    return metrics;
  },


  //
  // FITTING TEXT
  //

  /**
    If we are fitting text, the layer must be measured with its font size set to our
    maximum font size.
  */
  prepareLayerForStringMeasurement: function(layer) {
    var maxFontSize = this.get('maxFontSize');

    if (this.get('shouldAutoFitText') && this.get('calculatedFontSize') !== maxFontSize) {
      layer.style.fontSize = maxFontSize + "px";
    }

    // When resizing only the height, we should restrict the width to that of the given
    // layer. This way, the height will grow appropriately to fit the target as
    // text *wraps* within the current width.
    if (!this.get('shouldResizeWidth')) {
      layer.style.maxWidth = $(layer).outerWidth() + 'px';
    }
  },

  /**
    Whenever the view resizes, the text fitting must be reevaluated.
  */
  viewDidResize: function(orig) {
    orig();

    this.fontPropertyDidChange();
  }.enhance(),

  /**
    Fits the text into the frame's size, minus autoResizePadding.
  */
  fitTextToFrame: function() {
    // we can only fit text when we have a layer.
    var layer = this.get('autoResizeLayer');
    if (!layer) return;

    var maxFontSize = this.get('maxFontSize'),
        minFontSize = this.get('minFontSize');

    // if the font size has been adjusted, reset it to the max
    this.prepareLayerForStringMeasurement(layer);

    var frame = this.get('frame'),

        padding = this.get('autoResizePadding') || 0,

        // these need to be shrunk by 1 pixel or text that is exactly as wide as
        // the frame will be truncated
        width = frame.width - 1, height = frame.height - 1,
        measured = this.get('measuredSize'),
        mWidth = measured.width, mHeight = measured.height,
        actual;

    // figure out and apply padding to the width/height
    if(SC.typeOf(padding) === SC.T_NUMBER) {
      width -= padding;
      height -= padding;
    } else {
      width -= padding.width;
      height -= padding.height;
    }

    // measured size is at maximum. If there is no resizing to be done, short-circuit.
    if (mWidth <= width && mHeight <= height) return;

    // if only discrete values are allowed, we can short circuit here and just
    // use the minimum
    if(this.get('autoFitDiscreteFontSizes')) {
      actual = minFontSize;
    }

    // otherwise we have to find the actual best font size
    else {
      // now, we are going to make an estimate font size. We will figure out the proportion
      // of both actual width and actual height to the measured width and height, and then we'll
      // pick the smaller. We'll multiply that by the maximum font size to figure out
      // a rough guestimate of the proper font size.
      var xProportion = width / mWidth, yProportion = height / mHeight,

          guestimate = Math.floor(maxFontSize * Math.min(xProportion, yProportion)),

          classNames = this.get('classNames'),
          ignoreEscape = !this.get('escapeHTML'),
          value = this.get('autoResizeText'),

          metrics;


      guestimate = actual = Math.min(maxFontSize, Math.max(minFontSize, guestimate));

      // Now, we must test the guestimate. Based on that, we'll either loop down
      // or loop up, depending on the measured size.
      layer.style.fontSize = guestimate + "px";
      metrics = SC.metricsForString(value, layer, classNames, ignoreEscape);

      if (metrics.width > width || metrics.height > height) {

        // if we're larger, we must go down until we are smaller, at which point we are done.
        for (guestimate = guestimate - 1; guestimate >= minFontSize; guestimate--) {
          layer.style.fontSize = guestimate + "px";
          metrics = SC.metricsForString(value, layer, classNames, ignoreEscape);

          // always have an actual in this case; even if we can't get it small enough, we want
          // to keep this as close as possible.
          actual = guestimate;

          // if the new size is small enough, stop shrinking and set it for real
          if (metrics.width <= width && metrics.height <= height) {
            break;
          }
        }

      } else if (metrics.width < width || metrics.height < height) {
        // if we're smaller, we must go up until we hit maxFontSize or get larger. If we get
        // larger, we want to use the previous guestimate (which we know was valid)
        //
        // So, we'll start actual at guestimate, and only increase it while we're smaller.
        for (guestimate = guestimate + 1; guestimate <= maxFontSize; guestimate++) {
          layer.style.fontSize = guestimate + "px";
          metrics = SC.metricsForString(value, layer, classNames, ignoreEscape);

          // we update actual only if it is still valid. Then below, whether valid
          // or not, if we are at or past the width/height we leave
          if (metrics.width <= width && metrics.height <= height) {
            actual = guestimate;
          }

          // we put this in a separate if statement JUST IN CASE it is ===.
          // Unlikely, but possible, and why ruin a good thing?
          if (metrics.width >= width || metrics.height >= height){
            break;
          }
        }
      }
    }

    layer.style.fontSize = actual + "px";
    this.set('calculatedFontSize', actual);
  },

  /**
    Extends renderSettingsToContext to add font size if shouldAutoFitText is YES.
  */
  applyAttributesToContext: function(orig, context) {
    orig(context);

    if (this.get('shouldAutoFitText')) {
      context.setStyle('font-size', this.get('calculatedFontSize') + "px");
    }
  }.enhance(),

  /**
    @private
    When the layer is first created, measurement will need to take place.
  */
  didCreateLayer: function(orig) {
    orig();

    this.scheduleMeasurement();
  }.enhance(),

  /** @private
    If the view has a transitionIn property, we have to delay the transition
    setup and execution until after we measure.  In order to prevent a brief
    flash of the view, we ensure it is hidden while it is being measured and
    adjusted.

    TODO: consider making the measurement state a formal SC.View state
  */
  _transitionIn: function (original, inPlace) {
    // In order to allow views to measure and adjust themselves on append, we
    // can't transition until after the measurement is done.
    var preTransitionOpacity = this.get('layout').opacity || 1;

    this.adjust('opacity', 0);
    this.invokeNext(function () {
      this.adjust('opacity', preTransitionOpacity);
      original(inPlace);
    });
  }.enhance()

};

/**
 * @private
 * @class
 * Manages batch auto resizing.
 *
 * This used to be part of SC.AutoResize, but we shouldn't mix these
 * methods/properties into each view.
 */
SC.AutoResizeManager = {
  /**
    Views queued for batch resizing, but with no batch resize id.

    @property {SC.CoreSet}
  */
  measurementQueue: SC.CoreSet.create(),

  /**
    Schedules a re-measurement for the specified view in the batch with the
    given id.

    If a batch does not exist by that id, it will be created. If there is no id,
    the view will be measured individually.

    @param view The view to measure.
    @param id The id of the batch to measure the view in.
  */
  scheduleMeasurementForView: function(view) {
    this.measurementQueue.add(view);

    SC.RunLoop.currentRunLoop.invokeOnce(this.doBatchResize);
  },

  /**
    Cancels a scheduled measurement for a view in the named batch id.

    @param view The view that was scheduled for measurement.
    @param id The batch id the view was scheduled in.
  */
  cancelMeasurementForView: function(view, id) {
    this.measurementQueue.remove(view);
  },

  /**
    Processes all autoResize batches. This will automatically be invoked at the
    end of any run loop in which measurements were scheduled.
  */
  doBatchResize: function() {
    // make sure we are called from the correct scope.
    // this will make our property references below clearer.
    if (this !== SC.AutoResizeManager) {
      return SC.AutoResizeManager.doBatchResize();
    }

    var tag, view, layer, measurementQueue = this.measurementQueue, prepared, autoResizeText,
    i, len;

    while((len = measurementQueue.get('length')) > 0) {
      prepared = NO;
      // save the first tag we see
      tag = measurementQueue[len - 1].get('batchResizeId');

      // now we iterate over all the views with the same tag
      for(i = len - 1; i >= 0; --i) {
        view = measurementQueue[i];

        // if the view has a different tag, skip it
        if(view.get('batchResizeId') !== tag) continue;

        // make sure the view is still qualified to be measured
        if(view.get('isVisibleInWindow') && view.get('shouldMeasureSize') && (layer = view.get('autoResizeLayer'))) {
          autoResizeText = view.get('autoResizeText');

          // if the text is empty or a size is cached don't bother preparing
          if(!SC.none(autoResizeText) && autoResizeText !== "" && !view.get('_cachedMetrics') && !prepared) {
            // this is a bit of a hack: before we can prepare string measurement, there are cases where we
            // need to reset the font size first (specifically, if we are also fitting text)
            //
            // It is expected that all views in a batch will have the same font settings.
            view.prepareLayerForStringMeasurement(layer);

            // now we can tell SC to prepare the layer with the settings from the view's layer
            SC.prepareStringMeasurement(layer, view.get('classNames'));
            prepared = YES;
          }

          view.measureSize(YES);
        }

        // it's been handled
        measurementQueue.remove(view);

        // if the view didn't have a tag, we can't batch so just move on
        if(!tag) break;
      }

      // only call teardown if prepare was called
      if(prepared) {
        SC.teardownStringMeasurement();
      }
    }
  }

};

/* >>>>>>>>>> BEGIN source/mixins/button.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

if(SC.Button) {
  SC.Button.initMixin = function(){
    throw new Error("SC.Button is deprecated as a mixin and is now a subclass of SC.TemplateView. Subclass SC.ButtonView instead.");
  };
}


/* >>>>>>>>>> BEGIN source/mixins/content_display.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @namespace

  The SC.ContentDisplay mixin makes it easy to automatically update your view
  display whenever relevant properties on a content object change.  To use
  this mixin, include it in your view and then add the names of the
  properties on the content object you want to trigger a displayDidChange()
  method on your view. Your updateDisplay() method will then be called at the
  end of the run loop.

  ## Example

      MyApp.MyViewClass = SC.View.extend(SC.ContentDisplay, {

        contentDisplayProperties: ['title', 'isEnabled', 'hasChildren'],

        ...
      });

  @since SproutCore 1.0
*/
SC.ContentDisplay = {

  /** @private */
  concatenatedProperties: 'contentDisplayProperties',

  /**
    Add an array with the names of any property on the content object that
    should trigger an update of the display for your view.  Changes to the
    content object will only invoke your display method once per runloop.

    @type Array
    @default []
  */
  contentDisplayProperties: [],

  /** @private
    Setup observers on the content object when initializing the mixin.
  */
  initMixin: function() {
    this._display_contentDidChange();
  },

  /**
   * Remove observer on existing content object, if present
   * @private
   */
  destroyMixin: function () {
    if (!this._display_content) return;
    this._display_stopObservingContent(this._display_content);
    this._display_content = null;
  },

  /** @private */
  _display_beginObservingContent: function(content) {
    var f = this._display_contentPropertyDidChange;

    if (SC.isArray(content)) {
      content.invoke('addObserver', '*', this, f);
    }
    else if (content.addObserver) {
      content.addObserver('*', this, f);
    }
  },

  /** @private */
  _display_stopObservingContent: function(content) {
    var f = this._display_contentPropertyDidChange;

    if (SC.isArray(content)) {
      content.invoke('removeObserver', '*', this, f);
    }
    else if (content.removeObserver) {
      content.removeObserver('*', this, f);
    }
  },

  /** @private */
  _display_contentDidChange: function(target, key, value) {
    // handle changes to the content...
    if ((value = this.get('content')) === this._display_content) return;

    // stop listening to old content.
    var content = this._display_content;
    if (content) this._display_stopObservingContent(content);

    // start listening for changes on the new content object.
    content = this._display_content = value;
    if (content) this._display_beginObservingContent(content);

    this.displayDidChange();
  }.observes('content'),

  /** @private Invoked when properties on the content object change. */
  _display_contentPropertyDidChange: function(target, key, value, propertyRevision) {
    if (key === '*') {
      this.displayDidChange() ;
    } else {
      // only update if a displayProperty actually changed...s
      var ary = this.get('contentDisplayProperties') ;
      if (ary && ary.indexOf(key)>=0) this.displayDidChange();
    }
  }

} ;

/* >>>>>>>>>> BEGIN source/mixins/content_value_support.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2010 Sprout Systems, Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @namespace

  This mixin allows a view to get its value from a content object based
  on the value of its contentValueKey.

      myView = SC.View.create({
        content: {prop: "abc123"},

        contentValueKey: 'prop'
      });

      // myView.get('value') will be "abc123"

  This is useful if you have a nested record structure and want to have
  it be reflected in a nested view structure. If your data structures
  only have primitive values, consider using SC.Control instead.
*/
SC.ContentValueSupport = {
  /**
    Walk like a duck.

    @type Boolean
    @default YES
  */
  hasContentValueSupport: YES,

  /** @private */
  initMixin: function () {
    // setup content observing if needed.
    this._control_contentKeysDidChange();
  },

  /** @private */
  destroyMixin: function () {
    // Remove old observers on self.
    this._cleanup_old_observers();

    // Remove old observers on content.
    this._cleanup_old_content_observers();
  },

  /**
    The value represented by this control.

    Most controls represent a value of some type, such as a number, string
    or image URL.  This property should hold that value.  It is bindable
    and observable.  Changing this value will immediately change the
    appearance of the control.  Likewise, editing the control
    will immediately change this value.

    If instead of setting a single value on a control, you would like to
    set a content object and have the control display a single property
    of that control, then you should use the content property instead.

    @type Object
    @default null
  */
  value: null,

  /**
    The content object represented by this control.

    Often you need to use a control to display some single aspect of an
    object, especially if you are using the control as an item view in a
    collection view.

    In those cases, you can set the content and contentValueKey for the
    control.  This will cause the control to observe the content object for
    changes to the value property and then set the value of that property
    on the "value" property of this object.

    Note that unless you are using this control as part of a form or
    collection view, then it would be better to instead bind the value of
    the control directly to a controller property.

    @type SC.Object
    @default null
  */
  content: null,

  /**
    Keys that should be observed on the content object and mapped to values on
    this object. Should be a hash of local keys that point to keys on the content to
    map to local values. For example, the default is {'contentValueKey': 'value'}.
    This means that the value of this.contentValueKey will be observed as a key on
    the content object and its value will be mapped to this.value.

    @type Hash
    @default null
  */
  contentKeys: null,

  _default_contentKeys: {
    contentValueKey: 'value'
  },

  /**
    The property on the content object that would want to represent the
    value of this control.  This property should only be set before the
    content object is first set.  If you have a displayDelegate, then
    you can also use the contentValueKey of the displayDelegate.

    @type String
    @default null
  */
  contentValueKey: null,

  /**
    Invoked whenever any property on the content object changes.

    The default implementation will update the value property of the view
    if the contentValueKey property has changed.  You can override this
    method to implement whatever additional changes you would like.

    The key will typically contain the name of the property that changed or
    '*' if the content object itself has changed.  You should generally do
    a total reset if '*' is changed.

    @param {Object} target the content object
    @param {String} key the property that changes
    @returns {void}
    @test in content
  */
  contentPropertyDidChange: function (target, key) {
    var contentKeys = this.get('contentKeys');

    if (contentKeys) {
      var contentKey;

      for (contentKey in contentKeys) {
        // if we found the specific contentKey, then just update that and we're done
        if (key === this.getDelegateProperty(contentKey, this, this.get('displayDelegate'), contentKeys)) {
          return this.updatePropertyFromContent(contentKeys[contentKey], key, contentKey, target);
        }

        // else if '*' is changed, then update for every contentKey
        else if (key === '*') {
          this.updatePropertyFromContent(contentKeys[contentKey], key, contentKey, target);
        }
      }
    }

    else {
      return this.updatePropertyFromContent('value', key, 'contentValueKey', target);
    }
  },

  /**
    Helper method you can use from your own implementation of
    contentPropertyDidChange().  This method will look up the content key to
    extract a property and then update the property if needed.  If you do
    not pass the content key or the content object, they will be computed
    for you.  It is more efficient, however, for you to compute these values
    yourself if you expect this method to be called frequently.

    @param {String} prop local property to update
    @param {String} key the contentproperty that changed
    @param {String} contentKey the local property that contains the key
    @param {Object} content
    @returns {SC.Control} receiver
  */
  updatePropertyFromContent: function (prop, key, contentKey, content) {
    var del, v;

    if (contentKey === undefined) contentKey = "content" + prop.capitalize() + "Key";

    // prefer our own definition of contentKey
    if (this[contentKey]) contentKey = this.get(contentKey);
    // if we don't have one defined check the delegate
    else if ((del = this.get('displayDelegate')) && (v = del[contentKey])) contentKey = del.get ? del.get(contentKey) : v;
    // if we have no key we can't do anything so just short circuit out
    else return this;

    // only bother setting value if the observer triggered for the correct key
    if (key === '*' || key === contentKey) {
      if (content === undefined) content = this.get('content');

      if (content) v = content.get ? content.get(contentKey) : content[contentKey];
      else v = null;

      this.setIfChanged(prop, v);
    }

    return this;
  },

  /**
    Relays changes to the value back to the content object if you are using
    a content object.

    This observer is triggered whenever the value changes.  It will only do
    something if it finds you are using the content property and
    contentValueKey and the new value does not match the old value of the
    content object.

    If you are using contentValueKey in some other way than typically
    implemented by this mixin, then you may want to override this method as
    well.

    @returns {void}
  */
  updateContentWithValueObserver: function (target, key) {
    var reverseContentKeys = this._reverseContentKeys;

    // if everything changed, iterate through and update them all
    if (!key || key === '*') {
      for (key in reverseContentKeys) {
        this.updateContentWithValueObserver(this, key);
      }
    }

    // get value -- set on content if changed
    var value = this.get(key);

    var content = this.get('content'),
    // get the key we should be setting on content, asking displayDelegate if
    // necessary
    contentKey = this.getDelegateProperty(reverseContentKeys[key], this, this.displayDelegate);

    // do nothing if disabled
    if (!contentKey || !content) return this;

    if (typeof content.setIfChanged === SC.T_FUNCTION) {
      content.setIfChanged(contentKey, value);
    }

    // avoid re-writing inherited props
    else if (content[contentKey] !== value) {
      content[contentKey] = value;
    }
  },

  /** @private
    This should be null so that if content is also null, the
    _contentDidChange won't do anything on init.
  */
  _control_content: null,
  _old_contentValueKeys: null,
  _old_contentKeys: null,

  /** @private
    Observes when a content object has changed and handles notifying
    changes to the value of the content object.

    Optimized for the default case of only observing contentValueKey. If you use
    a custom value for contentKeys it will switch to using a CoreSet to track
    observed keys.
  */
  _control_contentDidChange: function (target, key) {
    // remove an observer from the old content if necessary
    this._cleanup_old_content_observers();

    var content = this.get('content'),
    contentKeys = this.get('contentKeys'), contentKey,
    oldKeys = this._old_contentValueKeys,
    f = this.contentPropertyDidChange;

    // add observer to new content if necessary.
    if (content && content.addObserver) {
      // set case
      if (contentKeys) {
        // lazily create the key set
        if (!oldKeys) oldKeys = SC.CoreSet.create();

        // add observers to each key
        for (contentKey in contentKeys) {
          contentKey = this.getDelegateProperty(contentKey, this, this.get('displayDelegate'));

          if (contentKey) {
            content.addObserver(contentKey, this, f);

            oldKeys.add(contentKey);
          }
        }
      }

      // default case hardcoded for contentValueKey
      else {
        contentKey = this.getDelegateProperty('contentValueKey', this, this.get('displayDelegate'));

        if (contentKey) {
          content.addObserver(contentKey, this, f);

          // if we had a set before, continue using it
          if (oldKeys) oldKeys.add(contentKey);
          // otherwise just use a string
          else oldKeys = contentKey;
        }
      }
    }

    // notify that values did change.
    key = (!key || key === 'content') ? '*' : this.get(key);
    if (key) this.contentPropertyDidChange(content, key);

    // Cache values for clean up.
    this._control_content = content;
    this._old_contentValueKeys = oldKeys;
  }.observes('content'),

  /** @private
    Observes changes to contentKeys and sets up observers on the local keys to
    update the observers on the content object.
  */
  _control_contentKeysDidChange: function () {
    var key, reverse = {},
    // if no hash is present, use the default contentValueKey -> value
    contentKeys = this.get('contentKeys') || this._default_contentKeys,
    contentKey,
    f = this._control_contentDidChange,
    reverseF = this.updateContentWithValueObserver;

    // Remove old observers.
    this._cleanup_old_observers();

    // add new observers
    for (key in contentKeys) {
      contentKey = contentKeys[key];

      // build reverse mapping to update content with value
      reverse[contentKey] = key;

      // add value observer
      this.addObserver(contentKey, this, reverseF);

      // add content key observer
      this.addObserver(key, this, f);
    }

    // store reverse map for later use
    this._reverseContentKeys = reverse;

    this._old_contentKeys = contentKeys;

    // call the other observer now to update all the observers
    this._control_contentDidChange();
  }.observes('contentKeys'),

  /** @private */
  _cleanup_old_content_observers: function () {
    var old = this._control_content,
      oldKeys = this._old_contentValueKeys,
      oldType = SC.typeOf(oldKeys),
      f = this.contentPropertyDidChange,
      contentKey;

    if (old && old.removeObserver && oldKeys) {
      // default case
      if (oldType === SC.T_STRING) {
        old.removeObserver(oldKeys, this, f);

        this._old_contentValueKeys = oldKeys = null;
      }

      // set case
      else {
        var i, len = oldKeys.get('length');

        for (i = 0; i < len; i++) {
          contentKey = oldKeys[i];

          old.removeObserver(contentKey, this, f);
        }

        oldKeys.clear();
      }
    }
  },

  /** @private */
  _cleanup_old_observers: function () {
    var oldContentKeys = this._old_contentKeys,
      f = this._control_contentDidChange,
      reverseF = this.updateContentWithValueObserver,
      contentKey, key;

    // remove old observers
    for (key in oldContentKeys) {
      contentKey = oldContentKeys[key];

      this.removeObserver(contentKey, this, reverseF);
      this.removeObserver(key, this, f);
    }
  }
};


/* >>>>>>>>>> BEGIN source/mixins/control.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('mixins/content_value_support');
sc_require('system/string');

/**
  Option for controls to automatically calculate their size (should be default
  on controls that use renderers).

  @type String
  @constant
*/
SC.AUTO_CONTROL_SIZE = '__AUTO__';

/**
  Option for HUGE control size.

  @type String
  @constant
*/
SC.JUMBO_CONTROL_SIZE = 'sc-jumbo-size';

/**
  Option for HUGE control size.

  @type String
  @constant
*/
SC.HUGE_CONTROL_SIZE = 'sc-huge-size';

/**
  Option for large control size.

  @type String
  @constant
*/
SC.LARGE_CONTROL_SIZE = 'sc-large-size';

/**
  Option for standard control size.

  @type String
  @constant
*/
SC.REGULAR_CONTROL_SIZE = 'sc-regular-size';

/**
  Option for small control size.

  @type String
  @constant
*/
SC.SMALL_CONTROL_SIZE = 'sc-small-size';

/**
  Option for tiny control size

  @type String
  @constant
*/
SC.TINY_CONTROL_SIZE = 'sc-tiny-size';

/**
  @namespace

  A Control is a view that also implements some basic state functionality.
  Apply this mixin to any view that you want to have standard control
  functionality including showing a selected state, enabled state, focus
  state, etc.

  ## About Values and Content

  Controls typically are used to represent a single value, such as a number,
  boolean or string.  The value a control is managing is typically stored in
  a "value" property.  You will typically use the value property when working
  with controls such as buttons and text fields in a form.

  An alternative way of working with a control is to use it to manage some
  specific aspect of a content object.  For example, you might use a label
  view control to display the "name" property of a Contact record.  This
  approach is often necessary when using the control as part of a collection
  view.

  You can use the content-approach to work with a control by setting the
  "content" and "contentValueKey" properties of the control.  The
  "content" property is the content object you want to manage, while the
  "contentValueKey" is the name of the property on the content object
  you want the control to display.

  The default implementation of the Control mixin will essentially map the
  contentValueKey of a content object to the value property of the
  control.  Thus if you are writing a custom control yourself, you can simply
  work with the value property and the content object support will come for
  free.  Just write an observer for the value property and update your
  view accordingly.

  If you are working with a control that needs to display multiple aspects
  of a single content object (for example showing an icon and label), then
  you can override the contentValueDidChange() method instead of observing
  the value property.  This method will be called anytime _any_ property
  on the content object changes.  You should use this method to check the
  properties you care about on the content object and update your view if
  anything you care about has changed.

  ## Delegate Support

  Controls can optionally get the contentDisplayProperty from a
  displayDelegate, if it is set.  The displayDelegate is often used to
  delegate common display-related configurations such as which content value
  to show.  Anytime your control is shown as part of a collection view, the
  collection view will be automatically set as its displayDelegate.

  @since SproutCore 1.0
  @extends SC.ContentValueSupport
*/
SC.Control = SC.mixin(SC.clone(SC.ContentValueSupport),
/** @scope SC.Control.prototype */{

  /**
    Walk like a duck

    @type Boolean
    @default YES
    @readOnly
  */
  isControl: YES,

  /**
    The selected state of this control. Possible values:

      - `YES`
      - `NO`
      - SC.MIXED_STATE.

    @type Boolean
    @default NO
  */
  isSelected: NO,

  /** @private */
  isSelectedBindingDefault: SC.Binding.oneWay().bool(),

  /**
    Set to YES when the item is currently active.  Usually this means the
    mouse is current pressed and hovering over the control, however the
    specific implementation my vary depending on the control.

    Changing this property value by default will cause the Control mixin to
    add/remove an 'active' class name to the root element.

    @type Boolean
    @default NO
  */
  isActive: NO,

  /** @private */
  isActiveBindingDefault: SC.Binding.oneWay().bool(),

  /**
    The name of the property this control should display if it is part of an
    SC.FormView.

    If you add a control as part of an SC.FormView, then the form view will
    automatically bind the value to the property key you name here on the
    content object.

    @type String
    @default null
  */
  fieldKey: null,

  /**
    The human readable label you want shown for errors.  May be a loc string.

    If your field fails validation, then this is the name that will be shown
    in the error explanation.  If you do not set this property, then the
    fieldKey or the class name will be used to generate a human readable name.

    @type String
    @default null
  */
  fieldLabel: null,

  /**
    The human readable label for this control for use in error strings.  This
    property is computed dynamically using the following rules:

    If the fieldLabel is defined, that property is localized and returned.
    Otherwise, if the keyField is defined, try to localize using the string
    "ErrorLabel.{fieldKeyName}".  If a localized name cannot be found, use a
    humanized form of the fieldKey.

    Try to localize using the string "ErrorLabel.{ClassName}". Return a
    humanized form of the class name.

    @field
    @type String
    @observes 'fieldLabel'
    @observes 'fieldKey'
  */
  errorLabel: function () {
    var ret = this.get('fieldLabel'), fk, def, locFK;

    // Fast path!
    if (ret) return ret;

    // if field label is not provided, compute something...
    fk = this.get('fieldKey') || this.constructor.toString();
    def = fk ? SC.String.capitalize(SC.String.humanize(fk)) : '';
    locFK = SC.String.locWithDefault("FieldKey." + fk, def);
    return SC.String.locWithDefault("ErrorLabel." + fk, locFK);
  }.property('fieldLabel', 'fieldKey').cacheable(),

  /**
    The control size.  This will set a CSS style on the element that can be
    used by the current theme to vary the appearance of the control.

    Some controls will default to SC.AUTO_CONTROL_SIZE, which will allow you
    to simply size the control, and the most appropriate control size will
    automatically be picked; be warned, though, that if you don't specify
    a height, performance will be impacted as it must be calculated; if you do
    this, a warning will be issued. If you don't care, use SC.CALCULATED_CONTROL_SIZE.

    @type String
    @default SC.REGULAR_CONTROL_SIZE
  */
  controlSize: SC.REGULAR_CONTROL_SIZE,

  /** @private */
  displayProperties: ['isSelected', 'isActive', 'controlSize'],

  /** @private */
  _CONTROL_TMP_CLASSNAMES: {},

  /** @private
    Invoke this method in your updateDisplay() method to update any basic
    control CSS classes.
  */
  renderMixin: function (context, firstTime) {
    var sel = this.get('isSelected'),
      disabled = !this.get('isEnabledInPane'),
      // update the CSS classes for the control.  note we reuse the same hash
      // to avoid consuming more memory
      names = this._CONTROL_TMP_CLASSNAMES; // temporary object

    names.mixed = sel === SC.MIXED_STATE;
    names.sel = sel && (sel !== SC.MIXED_STATE);
    names.active = this.get('isActive');

    var controlSize = this.get("controlSize");
    if (!controlSize) {
      controlSize = SC.REGULAR_CONTROL_SIZE;
    }

    if (firstTime) {
      context.setClass(names);

      // delegates handle adding 'controlSize' on their own. We only support it
      // here for backwards-compatibility.
      if (!this.get('renderDelegate')) {
        context.addClass(controlSize);
      }
    } else {
      context.$().setClass(names);
      if (!this.get('renderDelegate')) {
        context.$().addClass(controlSize);
      }
    }

    // if the control implements the $input() helper, then fixup the input
    // tags
    if (!firstTime && this.$input) {
      var inps = this.$input();

      if (inps.attr('type') !== "radio") {
        this.$input().attr('disabled', disabled);
      }
    }
  }

});


/* >>>>>>>>>> BEGIN source/mixins/editable.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @namespace

  The Editable mixin is a standard protocol used to activate keyboard editing
  on views that are editable such as text fields, label views and item views.

  You should apply this mixin, or implement the methods, if you are
  designing an item view for a collection and you want to automatically
  trigger editing.

  ## Using Editable Views

  To use a view that includes the Editable mixin, you simply call three
  methods on the view:

    - To begin editing, call beginEditing().  This will make the view first responder and allow the user to make changes to it.  If the view cannot begin editing for some reason, it will return NO.
    - If you want to cancel editing, you should try calling discardEditing().  This will cause the editor to discard its changed value and resign first responder.  Some editors do not support cancelling editing and will return NO.  If this is the case, you may optionally try calling commitEditing() instead to force the view to resign first responder, even though this will commit the changes.
    - If you want to end editing, while saving any changes that were made, try calling commitEditing().  This will cause the editor to validate and apply its changed value and resign first responder.  If the editor cannot validate its contents for some reason, it will return NO.  In this case you may optionally try calling discardEditing() instead to force the view to resign first responder, even though this will discard the changes.

  ## Implementing an Editable View

  To implement a new view that is editable, you should implement the three
  methods defined below: beginEditing(), discardEditing(), and
  commitEditing().  If you already allow editing when your view becomes first
  responder and commit your changes when the view loses first responder status
  then you can simply apply this mixin and not override any methods.


  @since SproutCore 1.0
*/
SC.Editable = {

  /**
    Indicates whether a view is editable or not.  You can optionally
    implement the methods in this mixin to disallow editing is isEditable is
    NO.

    @type Boolean
    @default NO
  */
  isEditable: NO,

  /**
    Indicates whether editing is currently in progress.  The methods you
    implement should generally up this property as appropriate when you
    begin and end editing.

    @type Boolean
    @default NO
  */
  isEditing: NO,

  /**
    Begins editing on the view.

    This method is called by other views when they want you to begin editing.
    You should write this method to become first responder, perform any
    additional setup needed to begin editing and then return YES.

    If for some reason you do not want to allow editing right now, you can
    also return NO.  If your view is already editing, then you should not
    restart editing again but just return YES.

    The default implementation checks to see if editing is allowed, then
    becomes first responder and updates the isEditing property if appropriate.
    Generally you will want to replace this method with your own
    implementation and not call the default.

    @returns {Boolean} YES if editing began or is in progress, NO otherwise
  */
  beginEditing: function() {
    if (!this.get('isEditable')) return NO ;
    if (this.get('isEditing')) return YES ;

    // begin editing
    this.beginPropertyChanges();
    this.set('isEditing', YES) ;
    this.becomeFirstResponder();
    this.endPropertyChanges();

    return YES ;
  },

  /**
    Ends editing on the view, discarding any changes that were made to the
    view value in the meantime.

    This method is called by other views when they want to cancel editing
    that began earlier.  When this method is called you should resign first
    responder, restore the original value of the view and return YES.

    If your view cannot revert back to its original state before editing began
    then you can implement this method to simply return NO.  A properly
    implemented client may try to call commitEditing() instead to force your
    view to end editing anyway.

    If this method is called on a view that is not currently editing, you
    should always just return YES.

    The default implementation does not support discarding changes and always
    returns NO.

    @returns {Boolean} YES if changes were discarded and editing ended.
  */
  discardEditing: function() {
    // if we are not editing, return YES, otherwise NO.

    return !this.get('isEditing') ;
  },

  /**
    Ends editing on the view, committing any changes that were made to the
    view value in the meantime.

    This method is called by other views when they want to end editing,
    saving any changes that were made to the view in the meantime.  When this
    method is called you should resign first responder, save the latest
    value of the view and return YES.

    If your view cannot save the current state of the view for some reason
    (for example if validation fails), then you should return NO.  Properly
    implemented clients may then try to call discardEditing() to force your
    view to resign first responder anyway.

    Some views apply changes to their value immediately during an edit instead
    of waiting for the view to end editing.  If this is the case, you should
    still implement commitEditing but you simply may not save any value
    changes.

    If this method is called on a view that is not currently editing, you
    should always just return YES.

    The default implementation sets isEditing to NO, resigns first responder
    and returns YES.

    @returns {Boolean} YES if changes were discarded and editing ended.
  */
  commitEditing: function() {
    if (!this.get('isEditing')) return YES;
    this.set('isEditing', NO) ;
    this.resignFirstResponder();

    return YES ;
  }

} ;

/* >>>>>>>>>> BEGIN source/mixins/flowed_layout.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @type String
  @constant
*/
SC.ALIGN_JUSTIFY = "justify";

/**
  @namespace

  Normal SproutCore views are absolutely positioned--parent views have relatively
  little input on where their child views are placed.

  This mixin makes a view layout its child views itself, flowing left-to-right
  or up-to-down, and, optionally, wrapping.

  Child views with useAbsoluteLayout===YES will be ignored in the layout process.
  This mixin detects when child views have changed their size, and will adjust accordingly.
  It also observes child views' isVisible and calculatedWidth/Height properties, and, as a
  flowedlayout-specific extension, isHidden.

  These properties are observed through `#js:observeChildLayout` and `#js:unobserveChildLayout`;
  you can override the method to add your own properties. To customize isVisible behavior,
  you will also want to override shouldIncludeChildInFlow.

  This relies on the children's frames or, if specified, calculatedWidth and calculatedHeight
  properties.

  This view mixes very well with animation. Further, it is able to automatically mix
  in to child views it manages, created or not yet created, allowing you to specify
  settings such as animation once only, and have everything "just work".

  Like normal views, you simply specify child views--everything will "just work."

  @since SproutCore 1.0
*/
SC.FlowedLayout = {
  isFlowedLayout: YES,
  /**
    The direction of flow. Possible values:

      - SC.LAYOUT_HORIZONTAL
      - SC.LAYOUT_VERTICAL

    @type String
    @default SC.LAYOUT_HORIZONTAL
  */
  layoutDirection: SC.LAYOUT_HORIZONTAL,

  /**
    Whether the view should automatically resize (to allow scrolling, for instance)

    @type Boolean
    @default YES
  */
  autoResize: YES,

  /**
    @type Boolean
    @default YES
  */
  shouldResizeWidth: YES,

  /**
    @type Boolean
    @default YES
  */
  shouldResizeHeight: YES,

  /**
    The alignment of items within rows or columns. Possible values:

      - SC.ALIGN_LEFT
      - SC.ALIGN_CENTER
      - SC.ALIGN_RIGHT
      - SC.ALIGN_JUSTIFY

    @type String
    @default SC.ALIGN_LEFT
  */
  align: SC.ALIGN_LEFT,

  /**
    If YES, flowing child views are allowed to wrap to new rows or columns.

    @type Boolean
    @default YES
  */
  canWrap: YES,

  /**
    A set of spacings (left, top, right, bottom) for subviews. Defaults to 0s all around.
    This is the amount of space that will be before, after, above, and below the view. These
    spacings do not collapse into each other.

    You can also set flowSpacing on any child view, or implement flowSpacingForView.

    @type Hash
    @default `{ left: 0, bottom: 0, top: 0, right: 0 }`
  */
  defaultFlowSpacing: { left: 0, bottom: 0, top: 0, right: 0 },

  /**
    @type Hash

    Padding around the edges of this flow layout view. This is useful for
    situations where you don't control the layout of the FlowedLayout view;
    for instance, when the view is the contentView for a SC.ScrollView.

    @type Hash
    @default `{ left: 0, bottom: 0, top: 0, right: 0 }`
  */
  flowPadding: { left: 0, bottom: 0, right: 0, top: 0 },

  /**
    @private

    If the flowPadding somehow misses a property (one of the sides),
    we need to make sure a default value of 0 is still there.
   */
  _scfl_validFlowPadding: function() {
    var padding = this.get('flowPadding') || {}, ret = {};
    ret.left = padding.left || 0;
    ret.top = padding.top || 0;
    ret.bottom = padding.bottom || 0;
    ret.right = padding.right || 0;
    return ret;
  }.property('flowPadding').cacheable(),

  concatenatedProperties: ['childMixins'],

  /** @private */
  initMixin: function() {
    this._scfl_tileOnce();
    // register observer to detect the childViews changes
    this.addObserver( 'childViews.[]', this, this._scfl_childViewsDidChange );
  },

  /** @private
    Detects when the child views change.
  */
  _scfl_childViewsDidChange: function(c) {
    this._scfl_tileOnce();
  },

  /** @private */
  _scfl_layoutPropertyDidChange: function(childView) {
    this._scfl_tileOnce();
  }.observes('layoutDirection', 'align', 'flowPadding', 'canWrap', 'defaultFlowSpacing', 'isVisibleInWindow'),

  /** @private
    Overridden to only update if it is a view we do not manage, or the width or height has changed
    since our last record of it.
  */
  layoutDidChangeFor: function(c) {
    // now, check if anything has changed
    var l = c._scfl_lastLayout, cl = c.get('layout'), f = c.get('frame');
    if (!l) return arguments.callee.base.apply(this,arguments);

    var same = YES;

    // in short, if anything interfered with the layout, we need to
    // do something about it.
    if (l.left && l.left !== cl.left) same = NO;
    else if (l.top && l.top !== cl.top) same = NO;
    else if (!c.get('fillWidth') && l.width && l.width !== cl.width) same = NO;
    else if (!l.width && !c.get('fillWidth') && f.width !== c._scfl_lastFrame.width) same = NO;
    else if (!c.get('fillHeight') && l.height && l.height !== cl.height) same = NO;
    else if (!l.height && !c.get('fillHeight') && f.height !== c._scfl_lastFrame.height) same = NO;

    if (same) {
      return arguments.callee.base.apply(this,arguments);
    }

    // nothing has changed. This is where we do something
    this._scfl_tileOnce();
    arguments.callee.base.apply(this,arguments);
  },

  /** @private
    Sets up layout observers on child view. We observe three things:
    - isVisible
    - calculatedWidth
    - calculatedHeight

    Actual layout changes are detected through layoutDidChangeFor.
  */
  observeChildLayout: function(c) {
    if (c._scfl_isBeingObserved) return;
    c._scfl_isBeingObserved = YES;
    c.addObserver('flowSpacing', this, '_scfl_tileOnce');
    c.addObserver('isVisible', this, '_scfl_tileOnce');
    c.addObserver('useAbsoluteLayout', this, '_scfl_tileOnce');
    c.addObserver('calculatedWidth', this, '_scfl_tileOnce');
    c.addObserver('calculatedHeight', this, '_scfl_tileOnce');
    c.addObserver('startsNewRow', this, '_scfl_tileOnce');
    c.addObserver('isSpacer', this, '_scfl_tileOnce');
    c.addObserver('maxSpacerLength', this, '_scfl_tileOnce');
    c.addObserver('fillWidth', this, '_scfl_tileOnce');
    c.addObserver('fillHeight', this, '_scfl_tileOnce');
  },

  /** @private
    Removes observers on child view.
  */
  unobserveChildLayout: function(c) {
    c._scfl_isBeingObserved = NO;
    c.removeObserver('flowSpacing', this, '_scfl_tileOnce');
    c.removeObserver('isVisible', this, '_scfl_tileOnce');
    c.removeObserver('useAbsoluteLayout', this, '_scfl_tileOnce');
    c.removeObserver('calculatedWidth', this, '_scfl_tileOnce');
    c.removeObserver('calculatedHeight', this, '_scfl_tileOnce');
    c.removeObserver('startsNewRow', this, '_scfl_tileOnce');
    c.removeObserver('isSpacer', this, '_scfl_tileOnce');
    c.removeObserver('maxSpacerLength', this, '_scfl_tileOnce');
    c.removeObserver('fillWidth', this, '_scfl_tileOnce');
    c.removeObserver('fillHeight', this, '_scfl_tileOnce');
  },

  /**
    Determines whether the specified child view should be included in the flow layout.
    By default, if it has isVisible: NO or useAbsoluteLayout: YES, it will not be included.

    @field
    @type Boolean
    @default NO
  */
  shouldIncludeChildInFlow: function(idx, c) {
    return c.get('isVisible') && !c.get('useAbsoluteLayout');
  },

  /**
    Returns the flow spacings for a given view. By default, returns the view's flowSpacing,
    and if they don't exist, the defaultFlowSpacing for this view.

    @field
    @type Hash
  */
  flowSpacingForChild: function(idx, view) {
    var spacing = view.get('flowSpacing');
    if (SC.none(spacing)) spacing = this.get('defaultFlowSpacing');
    if (SC.none(spacing)) spacing = 0;

    if (SC.typeOf(spacing) === SC.T_NUMBER) {
      spacing = { left: spacing, right: spacing, bottom: spacing, top: spacing };
    } else {
      spacing['left'] = spacing['left'] || 0;
      spacing['right'] = spacing['right'] || 0;
      spacing['top'] = spacing['top'] || 0;
      spacing['bottom'] = spacing['bottom'] || 0;
    }

    return spacing;
  },

  /**
    Returns the flow size for a given view, excluding spacing. The default version
    checks the view's calculatedWidth/Height, then its frame.

    For spacers, this returns an empty size.

    @field
    @type Hash
    @default {width: 0, height: 0}
  */
  flowSizeForChild: function(idx, view) {
    var cw = view.get('calculatedWidth'), ch = view.get('calculatedHeight'),
    layoutDirection = this.get('layoutDirection'),
    calc = {}, f = view.get('frame'), l = view.get('layout');
    view._scfl_lastFrame = f;

    // if there is a calculated width, use that. NOTE: if calculatedWidth === 0,
    // it is invalid. This is the practice in other views.
    if (cw) {
      calc.width = cw;
    } else {
      // we should use the layout width if available to avoid breaking layouts
      // that have borders
      calc.width = l.width || f.width;
    }

    // same for calculated height
    if (ch) {
      calc.height = ch;
    } else {
      // we should use the layout width if available to avoid breaking layouts
      // that have borders
      calc.height = l.height || f.height;
    }

    // if it is a spacer, we must set the dimension that it
    // expands in to 0.
    if (view.get('isSpacer')) {
      calc.maxSpacerLength = view.get('maxSpacerLength');

      if (layoutDirection === SC.LAYOUT_HORIZONTAL) {
        calc.width = l.minWidth || 0;
      } else {
        calc.height = l.minHeight || 0;
      }
    }

    // if it has a fillWidth/Height, clear it for later
    if (layoutDirection === SC.LAYOUT_HORIZONTAL && view.get('fillHeight')) {
      calc.height = l.minHeight || 0;
    } else if (layoutDirection === SC.LAYOUT_VERTICAL && view.get('fillWidth')) {
      calc.width = l.minWidth || 0;
    }

    return calc;
  },

  /** @private */
  clippingFrame: function() {
    return { left: 0, top: 0, width: this.get('calculatedWidth'), height: this.get('calculatedHeight') };
  }.property('calculatedWidth', 'calculatedHeight'),

  /** @private */

  // the maximum row length when all flexible items are collapsed.
  _scfl_maxCollapsedRowLength: 0,

  // the total row size when all flexible rows are collapsed.
  _scfl_totalCollapsedRowSize: 0,


  _scfl_calculatedSizeDidChange: function() {
    if(this.get('autoResize')) {
      if (this.get('layoutDirection') == SC.LAYOUT_VERTICAL) {
        if (this.get('shouldResizeHeight')) {
          this.adjust('minHeight', this.get('_scfl_maximumCollapsedRowLength'));
        }

        if (this.get('shouldResizeWidth')) {
          this.adjust('minWidth', this.get('_scfl_totalCollapsedRowSize'));
        }
      } else {
        if (this.get('shouldResizeWidth')) {
          this.adjust('minWidth', this.get('_scfl_maximumCollapsedRowLength'));
        }
        if (this.get('shouldResizeHeight')) {
          this.adjust('minHeight', this.get('_scfl_totalCollapsedRowSize'));
        }
      }
    }
  }.observes('autoResize', 'shouldResizeWidth', '_scfl_maximumCollapsedRowLength', '_scfl_totalCollapsedRowSize', 'shouldResizeHeight'),

  /**
    @private
    Creates a plan, initializing all of the basic properties in it, but not
    doing anything further.

    Other methods should be called to do this:

    - _scfl_distributeChildrenIntoRows distributes children into rows.
    - _scfl_positionChildrenInRows positions the children within the rows.
      - this calls _scfl_positionChildrenInRow
    - _scfl_positionRows positions and sizes rows within the plan.

    The plan's structure is defined inside the method.

    Some of these methods may eventually be made public and/or delegate methods.
  */
  _scfl_createPlan: function() {
    var layoutDirection = this.get('layoutDirection'),
        flowPadding = this.get('_scfl_validFlowPadding'),
        frame = this.get('frame');

    var isVertical = (layoutDirection === SC.LAYOUT_VERTICAL);

    // A plan hash contains general information about the layout, and also,
    // the collection of rows.
    //
    // This method only fills out a subset of the properties in a plan.
    //
    var plan = {
      // The rows array starts empty. It will get filled out by the method
      // _scfl_distributeChildrenIntoRows.
      rows: undefined,


      // the maximum row length where all collapsible items are collapsed.
      maximumCollapsedRowLength: 0,

      // the total sizes of all rows when collapsed (With flex-height rows
      // at minimum size)
      totalCollapsedRowSize: 0,

      // These properties are calculated once here, but later used by
      // the various methods.
      isVertical: layoutDirection === SC.LAYOUT_VERTICAL,
      isHorizontal: layoutDirection === SC.LAYOUT_HORIZONTAL,

      flowPadding: flowPadding,

      planStartPadding: flowPadding[isVertical ? 'left' : 'top'],
      planEndPadding: flowPadding[isVertical ? 'right' : 'bottom'],

      rowStartPadding: flowPadding[isVertical ? 'top' : 'left'],
      rowEndPadding: flowPadding[isVertical ? 'bottom' : 'right'],

      maximumRowLength: undefined, // to be calculated below

      // if any rows need to fit to fill, this is the size to fill
      fitToPlanSize: undefined,


      align: this.get('align')
    };

    if (isVertical) {
      plan.maximumRowLength = frame.height - plan.rowStartPadding - plan.rowEndPadding;
      plan.fitToPlanSize = frame.width - plan.planStartPadding - plan.planEndPadding;
    } else {
      plan.maximumRowLength = frame.width - plan.rowStartPadding - plan.rowEndPadding;
      plan.fitToPlanSize = frame.height - plan.planStartPadding - plan.planEndPadding;
    }

    return plan;
  },

  /** @private */
  _scfl_distributeChildrenIntoRows: function(plan) {
    var children = this.get('childViews'), child, idx, len = children.length,
        isVertical = plan.isVertical, rows = [], lastIdx;

    lastIdx = -1; idx = 0;
    while (idx < len && idx !== lastIdx) {
      lastIdx = idx;

      var row = {
        // always a reference to the plan
        plan: plan,

        // the combined size of the items in the row. This is used, for instance,
        // in justification or right-alignment.
        rowLength: undefined,

        // the size of the row. When flowing horizontally, this is the height;
        // it is the opposite dimension of rowLength. It is calculated
        // both while positioning items in the row and while positioning the rows
        // themselves.
        rowSize: undefined,

        // whether this row should expand to fit any available space. In this case,
        // the size is the row's minimum size.
        shouldExpand: undefined,

        // to be decided by _scfl_distributeItemsIntoRows
        items: undefined,

        // to be decided by _scfl_positionRows
        position: undefined
      };

      idx = this._scfl_distributeChildrenIntoRow(children, idx, row);
      rows.push(row);
    }

    plan.rows = rows;
  },

  /**
    @private
    Distributes as many children as possible into a single row, stating
    at the given index, and returning the index of the next item, if any.
  */
  _scfl_distributeChildrenIntoRow: function(children, startingAt, row) {
    var idx, len = children.length, plan = row.plan, child, childSize, spacing,
        items = [], itemOffset = 0, isVertical = plan.isVertical, itemSize, itemLength,
        maxSpacerLength,
        canWrap = this.get('canWrap'),
        newRowPending = NO,
        maxItemLength = 0,
        max = row.plan.maximumRowLength;

    for (idx = startingAt; idx < len; idx++) {
      child = children[idx];

      // this must be set before we check if the child is included because even
      // if it isn't included, we need to remember that there is a line break
      // for later
      newRowPending = newRowPending || (items.length > 0 && child.get('startsNewRow'));

      if (!this.shouldIncludeChildInFlow(idx, child)) continue;

      childSize = this.flowSizeForChild(idx, child);
      spacing = this.flowSpacingForChild(idx, child);

      childSize.width += spacing.left + spacing.right;
      childSize.height += spacing.top + spacing.bottom;

      itemLength = childSize[isVertical ? 'height' : 'width'];
      if(!SC.none(childSize.maxSpacerLength)) maxSpacerLength = childSize.maxSpacerLength + (isVertical ? spacing.top + spacing.bottom : spacing.left + spacing.right);
      itemSize = childSize[isVertical ? 'width' : 'height'];

      // there are two cases where we must start a new row: if the child or a
      // previous child in the row that wasn't included has
      // startsNewRow === YES, and if the item cannot fit. Neither applies if there
      // is nothing in the row yet.
      if ((newRowPending || (canWrap && itemOffset + itemLength > max)) && items.length > 0) {
        break;
      }

      var item = {
        child: child,

        itemLength: itemLength,
        maxSpacerLength: maxSpacerLength,
        itemSize: itemSize,

        spacing: spacing,

        // The position in the row.
        //
        // note: in one process or another, this becomes left or top.
        // but before that, it is calculated.
        position: undefined,

        // whether this item should attempt to fill to the row's size
        fillRow: isVertical ? child.get('fillWidth') : child.get('fillHeight'),

        // whether this item is a spacer, and thus should be resized to its itemLength
        isSpacer: child.get('isSpacer'),

        // these will get set if necessary during the positioning code
        left: undefined, top: undefined,
        width: undefined, height: undefined
      };


      items.push(item);
      itemOffset += itemLength;
      maxItemLength = Math.max(itemLength, maxItemLength);
    }

    row.rowLength = itemOffset;

    // if the row cannot wrap, then the minimum size for the row (and therefore collapsed size)
    // is the same as the current row length: it consists of the minimum size of all items.
    //
    // If the row can wrap, then the longest item will determine the size of a fully
    // collapsed (one item per row) layout.
    var minRowLength = canWrap ? maxItemLength : row.rowLength;
    row.plan.maximumCollapsedRowLength = Math.max(minRowLength, row.plan.maximumCollapsedRowLength);
    row.items = items;
    return idx;
  },

  /** @private */
  _scfl_positionChildrenInRows: function(plan) {
    var rows = plan.rows, len = rows.length, idx;

    for (idx = 0; idx < len; idx++) {
      this._scfl_positionChildrenInRow(rows[idx]);
    }
  },

  /**
    @private
    Positions items within a row. The items are already in the row, this just
    modifies the 'position' property.

    This also marks a tentative size of the row, and whether it should be expanded
    to fit in any available extra space. Note the term 'size' rather than 'length'...
  */
  _scfl_positionChildrenInRow: function(row) {
    var items = row.items, len = items.length, idx, item, position, rowSize = 0,
        spacerCount = 0, spacerSize, align = row.plan.align, shouldExpand = YES,
        leftOver = 0, noMaxWidth = NO;

    //
    // STEP ONE: DETERMINE SPACER SIZE + COUNT
    //
    for (idx = 0; idx < len; idx++) {
      item = items[idx];
      if (item.isSpacer) {
        spacerCount += item.child.get('spaceUnits') || 1;
      }
    }

    // justification is like adding a spacer between every item. We'll actually account for
    // that later, but for now...
    if (align === SC.ALIGN_JUSTIFY) spacerCount += len - 1;

    // calculate spacer size
    spacerSize = Math.max(0, row.plan.maximumRowLength - row.rowLength) / spacerCount;

    // determine individual spacer sizes using spacerSize and limited by
    // each spacer's maxWidth (if they have one)
    while(spacerSize > 0) {
      for (idx = 0; idx < len; idx++) {
        item = items[idx];

        if (item.isSpacer) {
          item.itemLength += spacerSize * (item.child.get('spaceUnits') || 1);
          if(item.itemLength > item.maxSpacerLength) {
            leftOver +=  item.itemLength - item.maxSpacerLength;
            item.itemLength = item.maxSpacerLength;
          }
          else {
            noMaxWidth = YES;
          }
        }
      }

      // if none of the spacers can expand further, stop
      if(!noMaxWidth) break;

      spacerSize = Math.round(leftOver / spacerCount);
      leftOver = 0;
    }

    //
    // STEP TWO: ADJUST FOR ALIGNMENT
    // Note: if there are spacers, this has no effect, because they fill all available
    // space.
    //
    position = 0;
    if (spacerCount === 0 && (align === SC.ALIGN_RIGHT || align === SC.ALIGN_BOTTOM)) {
      position = row.plan.maximumRowLength - row.rowLength;
    } else if (spacerCount === 0 && (align === SC.ALIGN_CENTER || align === SC.ALIGN_MIDDLE)) {
      position = (row.plan.maximumRowLength / 2) - (row.rowLength / 2);
    }

    position += row.plan.rowStartPadding;
    //
    // STEP TWO: LOOP + POSITION
    //
    for (idx = 0; idx < len; idx++) {
      item = items[idx];

      // if this item has fillWidth or fillHeight set, the row should expand
      // laterally
      if(!item.fillRow) shouldExpand = NO;

      // if the item is not a fill-row item, this row has a size that all fill-row
      // items should expand to
      rowSize = Math.max(item.itemSize, rowSize);

      item.position = position;

      position += item.itemLength;

      // if justification is on, we have one more spacer
      // note that we check idx because position is used to determine the new rowLength.
      if (align === SC.ALIGN_JUSTIFY && idx < len - 1) position += spacerSize;
    }

    row.shouldExpand = len > 0 ? shouldExpand : NO;
    row.rowLength = position - row.plan.rowStartPadding; // row length does not include padding
    row.rowSize = rowSize;

    row.plan.totalCollapsedRowSize += row.rowSize;

  },

  /** @private */
  _scfl_positionRows: function(plan) {
    var rows = plan.rows, len = rows.length, idx, row, position,
        fillRowCount = 0, planSize = 0, fillSpace;

    // first, we need a count of rows that need to fill, and the size they
    // are filling to (the combined size of all _other_ rows).
    for (idx = 0; idx < len; idx++) {
      if (rows[idx].shouldExpand) fillRowCount++;
      planSize += rows[idx].rowSize;
    }

    fillSpace = plan.fitToPlanSize - planSize;

    // now, position+size the rows
    position = plan.planStartPadding;
    for (idx = 0; idx < len; idx++) {
      row = rows[idx];

      if (row.shouldExpand && fillSpace > 0) {
        row.rowSize += fillSpace / fillRowCount;
        fillRowCount--;
      }

      row.position = position;
      position += row.rowSize;
    }
  },

  /**
    @private
    Positions all of the child views according to the plan.
  */
  _scfl_applyPlan: function(plan) {
    var rows = plan.rows, rowIdx, rowsLen, row, longestRow = 0, totalSize = 0,
        items, itemIdx, itemsLen, item, layout, itemSize,

        isVertical = plan.isVertical;

    rowsLen = rows.length;
    for (rowIdx = 0; rowIdx < rowsLen; rowIdx++) {
      row = rows[rowIdx];
      longestRow = Math.max(longestRow, row.rowLength);
      totalSize += row.rowSize;

      items = row.items; itemsLen = items.length;

      for (itemIdx = 0; itemIdx < itemsLen; itemIdx++) {
        item = items[itemIdx];
        item.child.beginPropertyChanges();

        itemSize = item.fillRow ? row.rowSize : item.itemSize;

        layout = {
          left: item.spacing.left + (isVertical ? row.position : item.position),
          top: item.spacing.top + (isVertical ? item.position : row.position),
          width: isVertical ? itemSize : item.itemLength,
          height: isVertical ? item.itemLength : itemSize
        };

        layout.width -= item.spacing.left + item.spacing.right;
        layout.height -= item.spacing.top + item.spacing.bottom;

        this.applyPlanToView(item.child, layout);
        item.child._scfl_lastLayout = layout;

        item.child.endPropertyChanges();
      }
    }

    totalSize += plan.planStartPadding + plan.planEndPadding;
    longestRow += plan.rowStartPadding + plan.rowEndPadding;

    this.beginPropertyChanges();

    this.set('calculatedHeight', isVertical ? longestRow : totalSize);
    this.set('calculatedWidth', isVertical ? totalSize : longestRow);
    this.set('_scfl_maximumCollapsedRowLength', plan.maximumCollapsedRowLength);
    this.set('_scfl_totalCollapsedRowSize', plan.totalCollapsedRowSize);

    this.endPropertyChanges();
  },

  /**
    Applies the given layout to the view.
    Override this if you would like your view to, for example, animate to a new position.
  */
  applyPlanToView: function(view, layout) {
    view.adjust(layout);
  },

  /** @private */
  _scfl_tileOnce: function() {
    this.invokeLast(this._scfl_tile);
  },

  _scfl_tile: function() {
    // short circuit when hidden
    if(!this.get('isVisibleInWindow')) return;

    // first, do the plan
    var plan = this._scfl_createPlan();
    this._scfl_distributeChildrenIntoRows(plan);
    this._scfl_positionChildrenInRows(plan);
    this._scfl_positionRows(plan);
    this._scfl_applyPlan(plan);

    // save so it can be observed
    this.setIfChanged('numberOfRows', plan.rows.length);

    // second, observe all children, and stop observing any children we no longer
    // should be observing.
    var previouslyObserving = this._scfl_isObserving || SC.CoreSet.create(),
        nowObserving = this._scfl_isObserving = SC.CoreSet.create();

    var children = this.get('childViews'), len = children.length, idx, child;
    for (idx = 0; idx < len; idx++) {
      child = children[idx];

      if (!previouslyObserving.contains(child)) {
        this.observeChildLayout(child);
      } else {
        previouslyObserving.remove(child);
      }

      nowObserving.add(child);
    }

    len = previouslyObserving.length;
    for (idx = 0; idx < len; idx++) {
      this.unobserveChildLayout(previouslyObserving[idx]);
    }
  },

  /** @private */
  _scfl_frameDidChange: function() {
    var frame = this.get("frame"), lf = this._scfl_lastFrameSize || {};
    this._scfl_lastFrameSize = SC.clone(frame);

    if (lf.width == frame.width && lf.height == frame.height) {
      return;
    }

    this._scfl_tileOnce();
  }.observes('frame'),

  /** @private */
  destroyMixin: function() {
    this.removeObserver( 'childViews.[]', this, this._scfl_childViewsDidChange );

    var isObserving = this._scfl_isObserving;
    if (!isObserving) return;

    var len = isObserving.length, idx;
    for (idx = 0; idx < len; idx++) {
      this.unobserveChildLayout(isObserving[idx]);
    }
  },

  /** @private
    Reorders childViews so that the passed views are at the beginning in the order they are passed. Needed because childViews are laid out in the order they appear in childViews.
  */
  reorder: function(views) {
    if(!SC.typeOf(views) === SC.T_ARRAY) views = arguments;

    var i = views.length, childViews = this.childViews, view;

    // childViews.[] should be observed
    this.beginPropertyChanges();

    while(i-- > 0) {
      view = views[i];

      if(SC.typeOf(view) === SC.T_STRING) view = this.get(view);

      childViews.removeObject(view);
      childViews.unshiftObject(view);
    }

    this.endPropertyChanges();

    this._scfl_childViewsDidChange();

    return this;
  }
};


/* >>>>>>>>>> BEGIN source/mixins/gesturable.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @namespace

  You can mix in SC.Gesturable to your views to add some support for recognizing gestures.

  SproutCore views have built-in touch events. However, sometimes you may want
  to recognize gestures like tap, pinch, swipe, etc. This becomes tedious if you
  need to do this often, and more so if you need to check for multiple possible
  gestures on the same view.

  SC.Gesturable allows you to define a collection of gestures (SC.Gesture objects)
  that your view should recognize. When a gesture is recognized, methods will be
  called on the view:

    - [gestureName](gesture, args...): called when the gesture has occurred. This is
      useful for event-style gestures, where you aren't interested in when it starts or
      ends, but just that it has occurred. SC.SwipeGesture triggers this after the
      swipe has moved a minimum amount—40px by default.
    - [gestureName]Start(gesture, args...): called when the gesture is first recognized.
      For instance, a swipe gesture may be recognized after the finger has moved a
      minimum distance in a horizontal.
    - [gestureName]Changed(gesture, args...): called when some property of the gesture
      has changed. For instance, this may be called continuously as the user swipes as
      the swipe's distance changes.
    - [gestureName]Cancelled(gesture, args...): called when a gesture, for one reason
      or another, is no longer recognized. For instance, a horizontal swipe gesture
      could cancel if the user moves too far in a vertical direction.
    - [gestureName]End(gesture, args...): called when a gesture ends. A swipe would end
      when the user lifts their finger.

  Each of these methods is passed the gesture instance, in addition to any arguments
  the gesture sends for your convenience. The default swipe gesture sends an SC.Touch
  instance, the swipe direction, and the distance the swipe has moved in that direction.

  Using SC.Gesturable
  -------------------

  To make your view recognize gestures, mix in Gesturable and add items to the 'gestures'
  property:

      SC.View.extend(SC.Gesturable, {
        gestures: [SC.PinchGesture, 'mySwipeGesture'],

        // specifying as a string allows you to configure it:
        mySwipeGesture: SC.SwipeGesture.extend({
          direction: SC.SWIPE_VERTICAL,
          startDistance: 3,
          swipeDistance: 20
        }),

        // handle the swipe action
        swipe: function(touch, direction) {
          console.error("Swiped! In direction: " + direction);
        },

        swipeStart: function(touch, direction, delta) {
          console.error("Swipe started in direction: " + direction + "; dist: " + delta);
        },

        swipeChanged: function(touch, direction, delta) {
          console.error("Swipe continued in direction: " + direction + "; dist: " + delta);
        },

        swipeEnd: function(touch, direction, delta) {
          console.error("Completed swipe in direction: " + direction + "; dist: " + delta);
        }

      })

  @extends SC.ObjectMixinProtocol
  @extends SC.ResponderProtocol
*/
SC.Gesturable = {

  /** @private An array of all gestures currently interested in the touch session.

    @type Array
    @default null
  */
  _sc_interestedGestures: null,

  /** @private An array of the touches that are currently active in a touch session.

    @type Array
    @default null
  */
  _sc_touchesInSession: null,

  /**
    Gestures need to understand multiple touches.

    @type Boolean
    @default true
    @see SC.View#acceptsMultitouch
  */
  acceptsMultitouch: true,

  /**
    @type Array
    @default ['gestures']
    @see SC.Object#concatenatedProperties
  */
  concatenatedProperties: ['gestures'],

  /**
    The gestures that the view will support. This property must be set on the consumer of
    `SC.Gesturable` before it is initialized.

    These gestures should be objects that extend the `SC.Gesture` class. You can use SproutCore's
    pre-built gestures or create your own. If you create your own, you can use a property name
    in the list of gestures to refer to the actual gesture class, similar to how the childViews
    array works. For example,

        gestures: [SC.PinchGesture, 'mySwipeGesture'],

        // Specifying the Gesture by property name allows you to configure it.
        mySwipeGesture: SC.SwipeGesture.extend({
          direction: SC.SWIPE_VERTICAL,
          startDistance: 3,
          swipeDistance: 20
        }),

    Note that `gestures` is a *concatenated property*, which means that it will not be overwritten
    by subclasses. So for example, if the base class lists gestures as `[SC.PinchGesture]` and its
    subclass lists gestures as `[SC.TapGesture]`, the actual gestures supported by the subclass will
    be `[SC.PinchGesture, SC.TapGesture]`.

    @type Array
    @default null
  */
  gestures: null,

  /** @private Shared method for finishing a touch.

    @param {SC.Touch} touch The touch that ended or cancelled.
    @param {Boolean} wasCancelled Whether the touch was cancelled or not (i.e. ended normally).
  */
  _sc_gestureTouchFinish: function (touch, wasCancelled) {
    var touchesInSession = this._sc_touchesInSession,
        touchIndexInSession = touchesInSession.indexOf(touch);

    // Decrement our list of touches that are being acted upon.
    touchesInSession.replace(touchIndexInSession, 1);

    var gestures = this._sc_interestedGestures,
        idx,
        gesture;

    // Loop through the gestures in reverse, as the list may be mutated.
    for (idx = gestures.length - 1; idx >= 0; idx--) {
      var isInterested;

      gesture = gestures[idx];

      if (wasCancelled) {
        isInterested = gesture.touchCancelledInSession(touch, touchesInSession);
      } else {
        isInterested = gesture.touchEndedInSession(touch, touchesInSession);
      }

      // If the gesture is no longer interested in *any* touches for this session, remove it.
      if (!isInterested) {
        // Tell the gesture that the touch session has ended for it.
        gesture.touchSessionCancelled();

        gestures.replace(idx, 1);
      }
    }

    // Once there are no more touches in the session, reset the interested gestures.
    if (touchesInSession.length === 0) {
      // Notify all remaining interested gestures that the touch session has finished cleanly.
      var len;

      for (idx = 0, len = gestures.length; idx < len; idx++) {
        gesture = gestures[idx];

        gesture.touchSessionEnded();
      }

      // Clear out the current cache of interested gestures for the session.
      this._sc_interestedGestures.length = 0;
    }
  },

  /**
    When SC.Gesturable initializes, any gestures named on the view are instantiated.

    @see SC.ObjectMixinProtocol#initMixin
  */
  initMixin: function() {
    

    this.createGestures();
  },

  /** @private  Instantiates the gestures. */
  createGestures: function() {
    var gestures = this.get("gestures"),
        len = gestures.length,
        instantiatedGestures = [],
        idx;

    // loop through all gestures
    for (idx = 0; idx < len; idx++) {
      var gesture;

      // get the proper gesture
      if (SC.typeOf(gestures[idx]) === SC.T_STRING) {
        gesture = this.get(gestures[idx]);
      } else {
        gesture = gestures[idx];
      }

      // if it was not found, well, that's an error.
      if (!gesture) {
        throw new Error("Developer Error: Could not find gesture named '" + gestures[idx] + "' on view.");
      }

      // if it is a class, instantiate (it really ought to be a class...)
      if (gesture.isClass) {
        gesture = gesture.create({
          view: this
        });
      }

      // and set the gesture instance and add it to the array.
      if (SC.typeOf(gestures[idx]) === SC.T_STRING) this[gestures[idx]] = gesture;
      instantiatedGestures.push(gesture);
    }

    this.set("gestures", instantiatedGestures);
  },

  /**
    Handles touch start by handing it to the gesture recognizing code.

    If you override touchStart, you will need to call gestureTouchStart to
    give the gesture system control of the touch. You will continue to get
    events until if and when a gesture decides to take "possession" of a touch—
    at this point, you will get a [gestureName]Start event.

    You do not have to call gestureTouchStart immediately; you can call it
    at any time. This allows you to avoid passing control until _after_ you
    have determined your own touchStart, touchesDragged, and touchEnd methods
    are not going to handle it.

    @param {SC.Touch} touch The touch that started.
    @returns {Boolean} Whether the touch should be claimed by the view or not.
    @see SC.ResponderProtocol#touchStart
  */
  touchStart: function(touch) {
    return this.gestureTouchStart(touch);
  },

  /**
    Tells the gesture recognizing code about touches moving.

    If you override touchesDragged, you will need to call gestureTouchesDragged
    (at least for any touches you called gestureTouchStart for in touchStart) to
    allow the gesture system to update.

    @see SC.ResponderProtocol#touchesDragged
  */
  touchesDragged: function(evt, touches) {
    this.gestureTouchesDragged(evt, touches);
  },

  /**
    Tells the gesture recognizing code about a touch ending.

    If you override touchEnd, you will need to call gestureTouchEnd
    for any touches you called gestureTouchStart for in touchStart (if overridden).

    @param {SC.Touch} touch The touch that ended.
    @see SC.ResponderProtocol#touchEnd
  */
  touchEnd: function(touch) {
    this.gestureTouchEnd(touch);
  },

  /**
    Tells the gesture recognizing code about a touch cancelling.

    If you override touchCancelled, you will need to call gestureTouchCancelled
    for any touches you called gestureTouchStart for in touchStart (if overridden).

    @param {SC.Touch} touch The touch that cancelled.
    @see SC.ResponderProtocol#touchCancelled
  */
  touchCancelled: function (touch) {
    this.gestureTouchCancelled(touch);
  },

  /**
    Called by a gesture that has lost interest in the entire touch session, likely due to too much
    time having passed since `gestureTouchStart` or `gestureTouchesDragged` having been called.

    Simply removes the gesture from the list of interested gestures and calls
    `touchSessionCancelled` on the gesture.
  */
  gestureLostInterest: function (gesture) {
    var gestures = this._sc_interestedGestures,
        gestureIndex = gestures.indexOf(gesture);

    // Remove the gesture.
    if (gestureIndex >= 0) {
      gesture.touchSessionCancelled();

      gestures.replace(gestureIndex, 1);
    }
  },

  /**
    Tells the gesture recognizing system about a new touch. This notifies all gestures of a new
    touch session starting (if there were no previous touches) or notifies all interested gestures
    that a touch has been added.

    As touches are added beyond the first touch, gestures may "lose interest" in the touch session.
    For example, a gesture may explicitly want only a single touch and if a second touch appears,
    the gesture may not want any further updates on this touch session (even if the second touch
    ends again).

    @param {SC.Touch} touch The touch that started.
    @returns {Boolean} Whether any gesture is interested in the touch or not.
  */
  gestureTouchStart: function (touch) {
    var interestedGestures = this._sc_interestedGestures,
        touchesInSession = this._sc_touchesInSession,
        claimedTouch = false,
        idx;

    // Instantiate once.
    if (touchesInSession === null) {
      touchesInSession = this._sc_touchesInSession = [];
      interestedGestures = this._sc_interestedGestures = [];
    }

    // When there are no touches in the session, check all gestures.
    if (touchesInSession.length === 0) {
      var gestures = this.get("gestures"),
          len;

      for (idx = 0, len = gestures.length; idx < len; idx++) {
        var gesture = gestures[idx];

        gesture.touchSessionStarted(touch);
        interestedGestures.push(gesture);
      }

      // Keep this touch.
      claimedTouch = true;

    // Only check gestures that are interested.
    } else {
      // Loop through the gestures in reverse, as the list may be mutated.
      for (idx = interestedGestures.length - 1; idx >= 0; idx--) {
        var interestedGesture = interestedGestures[idx],
            isInterested;

        // Keep only the gestures still interested in the touch.
        isInterested = interestedGesture.touchAddedToSession(touch, touchesInSession);

        if (isInterested) {
          // Keep this touch.
          claimedTouch = true;
        } else {
          // Tell the gesture that the touch session has ended for it.
          interestedGesture.touchSessionCancelled();

          interestedGestures.replace(idx, 1);
        }
      }
    }

    // If any gesture is interested in the new touch. Add it to the list of touches in the session.
    if (claimedTouch) {
      touchesInSession.push(touch);
    }

    return claimedTouch;
  },

  /**
    Tells the gesture recognition system that touches have moved.

    @param {SC.Event} evt The touch event.
    @param {Array} touches The touches previously claimed by this view.
    @returns {void}
  */
  gestureTouchesDragged: function (evt, touches) {
    var gestures = this._sc_interestedGestures,
        touchesInSession = this._sc_touchesInSession;

    // Loop through the gestures in reverse, as the list may be mutated.
    for (var i = gestures.length - 1; i >= 0; i--) {
      var gesture = gestures[i],
          isInterested = gesture.touchesMovedInSession(touchesInSession);

      // If the gesture is no longer interested in *any* touches for this session, remove it.
      if (!isInterested) {
        // Tell the gesture that the touch session has ended for it.
        gesture.touchSessionCancelled();

        gestures.replace(i, 1);

        // TODO: When there are no more interested gestures? Do what with the touches? Anything?
      }
    }
  },

  /**
    Tells the gesture recognition system that an unassigned touch has ended.

    This informs all of the gestures that the touch ended. The touch is
    an unassigned touch as, if it were assigned to a gesture, it would have
    been sent directly to the gesture, bypassing this view.
  */
  gestureTouchEnd: function(touch) {
    this._sc_gestureTouchFinish(touch, false);
  },

  /**
    Tells the gesture recognition system that an unassigned touch has cancelled.

    This informs all of the gestures that the touch cancelled. The touch is
    an unassigned touch as, if it were assigned to a gesture, it would have
    been sent directly to the gesture, bypassing this view.
  */
  gestureTouchCancelled: function(touch) {
    this._sc_gestureTouchFinish(touch, true);
  }
};

/* >>>>>>>>>> BEGIN source/mixins/inline_editable.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @namespace

  This mixin is used for views that show a seperate editor view to edit.
  For example, the default behavior of SC.LabelView if isEditable is set
  to YES is to popup an SC.InlineTextFieldView when double clicked. This is a
  seperate text input that will handle the editing and save its value back to
  the label when it is finished.

  To use this functionality, all you have to do is apply this mixin to
  your view. You may define your own SC.InlineEditorDelegate to further
  customize editing behavior.

      MyProject.MyView = SC.View.extend(SC.InlineEditable, {
        inlineEditorDelegate: myDelegate
      });

  The delegate methods will default to your view unless the
  inlineEditorDelegate implements them. Simple views do not require a
  seperate delegate. If your view has a more complicated editing
  interaction, you may also implement a custom delegate. For example, if
  you have a form with several views that all edit together, you might
  set the parent view as the delegate so it can manage the lifecycle and
  layout of the editors.

  See SC.InlineEditorDelegate for more information on using a delegate to
  customize your view's edit behavior.

  Your view can now be edited by calling beginEditing() on it.

      myView.beginEditing();

  This will create an editor for the view. You can then end the editing process
  by calling commitEditing() or discardEditing() on either the view or the
  editor. commitEditing() will save the value and discard will revert to the
  original value.

      myView.commitEditing();
      myView.discardEditing();

  Note that the editor is a private property of the view, so the only views that
  should be able to access the methods on it are the editor itself, the view it
  is editing, and their delegates.
*/
SC.InlineEditable = {

  /**
    Walk like a duck.

    @type Boolean
    @default YES
  */
  isInlineEditable: YES,

  /**
    Flag to enable or disable editing.

    @type Boolean
    @default YES
  */
  isEditable: YES,

  /**
    The view that will be used to edit this view. Defaults to
    SC.InlineTextFieldView, which is simply a text field that positions itself
    over the view being edited.

    @type SC.InlineEditor
    @default SC.InlineTextFieldView
  */
  exampleEditor: SC.InlineTextFieldView,

  /**
    Indicates whether the view is currently editing. Attempting to
    beginEditing a view that is already editing will fail.

    @type Boolean
    @default NO
  */
  isEditing: NO,

  /**
    Delegate that will be notified of events related to the editing
    process. Also responsible for managing the lifecycle of the editor.

    @type SC.InlineEditorDelegate
    @default SC.InlineTextFieldDelegate
  */
  inlineEditorDelegate: SC.InlineTextFieldDelegate,

  /**
    @private
    The editor responsible for editing this view.
  */
  _editor: null,

  /**
    Tells the view to start editing. This will create an editor for it
    and transfer control to the editor.

    Will fail if the delegate returns NO to inlineEditorShouldBeginEditing.

    @returns {Boolean} whether the view successfully entered edit mode
  */
  beginEditing: function() {
    var del;

    del = this.delegateFor('inlineEditorShouldBeginEditing', this.inlineEditorDelegate);
    if(del && !del.inlineEditorShouldBeginEditing(this, this.get('value'))) return NO;

    this._editor = this.invokeDelegateMethod(this.inlineEditorDelegate, 'acquireEditor', this);

    if(this._editor) return this._editor.beginEditing(this);
    else return NO;
  },

  /**
    Tells the view to save the value currently in the editor and finish
    editing. The delegate will be consulted first by calling
    inlineEditorShouldCommitEditing, and the operation will not be
    allowed if the delegate returns NO.

    Will fail if the delegate returns NO to inlineEditorShouldCommitEditing.

    @returns {Boolean} whether the delegate allowed the value to be committed
  */
  commitEditing: function() {
    return this._editor ? this._editor.commitEditing() : NO;
  },

  /**
    Tells the view to leave edit mode and revert to the value it had
    before editing. May fail if the delegate returns NO to
    inlineEditorShouldDiscardEditing. It is possible for the delegate to
    return false to inlineEditorShouldDiscardEditing but true to
    inlineEditorShouldCommitEditing, so a client view may attempt to
    call commitEditing in case discardEditing fails.

    Will fail if the delegate returns NO to inlineEditorShouldDiscardEditing.

    @returns {Boolean} whether the delegate allowed the view to discard its value
  */
  discardEditing: function() {
    return this._editor ? this._editor.discardEditing() : NO;
  },

  /**
    Allows the view to begin editing if it is editable and it is not
    already editing.

    @returns {Boolean} if the view is allowed to begin editing
  */
  inlineEditorShouldBeginEditing: function() {
    return !this.get('isEditing') && this.get('isEditable');
  },

  // TODO: implement validator
  /**
    By default, the editor starts with the value of the view being edited.

    @params {SC.InlineEditable} editor the view being edited
    @params {SC.InlineEditor} value the editor for the view
    @params {Object} editable the initial value of the editor
  */
  inlineEditorWillBeginEditing: function(editor, value, editable) {
    editor.set('value', this.get('value'));
  },

  /**
    Sets isEditing to YES once editing has begun.

    @params {SC.InlineEditable} the view being edited
    @params {SC.InlineEditor} the editor for the view
    @params {Object} the initial value of the editor
  */
  inlineEditorDidBeginEditing: function(editor, value, editable) {
    this.set('isEditing', YES);
  },

  /** @private
    Calls inlineEditorWillEndEditing for backwards compatibility.

    @params {SC.InlineEditable} the view being edited
    @params {SC.InlineEditor} the editor for the view
    @params {Object} the initial value of the editor
  */
  inlineEditorWillCommitEditing: function(editor, value, editable) {
    if(this.inlineEditorWillEndEditing) this.inlineEditorWillEndEditing(editor, value);
  },

  /**
    By default, commiting editing simply sets the value that the editor
    returned and cleans up.

    @params {SC.InlineEditable} the view being edited
    @params {SC.InlineEditor} the editor for the view
    @params {Object} the initial value of the editor
  */
  inlineEditorDidCommitEditing: function(editor, value, editable) {
    editable.setIfChanged('value', value);

    if(this.inlineEditorDidEndEditing) this.inlineEditorDidEndEditing(editor, value);

    this._endEditing();
  },

  /**
    Calls inlineEditorWillEndEditing for backwards compatibility.

    @params {SC.InlineEditable} the view being edited
    @params {SC.InlineEditor} the editor for the view
    @params {Object} the initial value of the editor
  */
  inlineEditorWillDiscardEditing: function(editor, editable) {
    if(this.inlineEditorWillEndEditing) this.inlineEditorWillEndEditing(editor, this.get('value'));
  },

  /**
    Calls inlineEditorDidEndEditing for backwards compatibility and then
    cleans up.

    @params {SC.InlineEditable} the view being edited
    @params {SC.InlineEditor} the editor for the view
    @params {Object} the initial value of the editor
  */
  inlineEditorDidDiscardEditing: function(editor, editable) {
    if(this.inlineEditorDidEndEditing) this.inlineEditorDidEndEditing(editor, this.get('value'));

    this._endEditing();
  },

  /**
    @private
    Shared code used to cleanup editing after both discarding and commiting.
  */
  _endEditing: function() {
    // _editor may be null if we were called using the
    // SC.InlineTextFieldView class methods
    if(this._editor) {
      this.invokeDelegateMethod(this.inlineEditorDelegate, 'releaseEditor', this._editor);
      this._editor = null;
    }

    this.set('isEditing', NO);
  }
};


/* >>>>>>>>>> BEGIN source/mixins/inline_editor.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2010 Sprout Systems, Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @namespace

  This mixin is for a view that is editable but is acting as a proxy to
  edit another view. For example, a calendar picker that pops up over
  top of a date display.

  Instantiation and destruction will be handled by the InlineEditorDelegate
  defined on the InlineEditable view.

  Any runtime configuration should be handled by the delegate's
  inlineEditorWillBeginEditing method. This will be done at the start of the
  beginEditing function, so your view should be able to handle having value
  changed by this method.

  Your view should also be sure to cleanup completely when editing is finished,
  because the delegate may decide to reuse the same editor elsewhere.

  See SC.InlineTextFieldView for an example of an implementation of
  SC.InlineEditor.
*/
SC.InlineEditor = {

  /**
    Walk like a duck.

    @type Boolean
    @default YES
    @readOnly
  */
  isInlineEditor: YES,

  /**
    Indicates the view is currently editing. For a typical editor, this
    will always be true as long as the view exists, but some
    InlineEditorDelegates may have more complex lifecycles in which
    editors are reused.

    @type Boolean
    @default NO
  */
  isEditing: NO,

  /**
    The delegate responsible for the editors lifecycle as well as the
    target for notifications. This property should be set when the
    delegate creates the editor and does not need to be in the view
    definition.

    @type SC.InlineEditorDelegate
    @default null
  */
  inlineEditorDelegate: null,

  /**
    @private
    The view that this view is responsible for editing.
    @type SC.InlineEditable
  */
  _target: null,

  /**
    Tells the editor to begin editing another view with the given starting value.
    Editors may be reused so make sure that the editor is fully cleaned
    up and reinitialized.

    Sets isEditing to YES.

    Will fail if the editor is already editing.

    If you override this method, be sure to call arguments.callee.base.apply(this,arguments) at the beginning of
    you function so that the delegate will be able to configure the view when it
    is notified of the inlineEditorWillBeginEditing event.

    @param {SC.View} editable the view being edited
    @returns {Boolean} whether the editor was able to successfully begin editing
  */
  beginEditing:function(editable) {
    if(this.get('isEditing') || !editable || !editable.isInlineEditable) return NO;

    var del, target;

    target = this._target = editable;

    del = this.delegateFor('inlineEditorWillBeginEditing', this.inlineEditorDelegate, target);
    if(del) del.inlineEditorWillBeginEditing(this, this.get('value'), target);

    this.set('isEditing', YES);

    // needs to be invoked last because it needs to run after the view becomes
    // first responder
    this.invokeLast(this._callDidBegin);

    // remember that we invoked in case commit gets called before the invoke
    // goes off
    this._didBeginInvoked = YES;

    return YES;
  },

  /**
    @private
    Notifies the delegate of the didBeginEditing event. Needs to be invoked last
    because becoming first responder doesn't happen until the end of the runLoop
    and didBegin is supposed to occur after the editor becomes first responder.
  */
  _callDidBegin: function() {
    // don't notify if we already ended editing
    if(!this.get('isEditing')) return NO;

    this._didBeginInvoked = NO;

    var target = this._target, del;

    del = this.delegateFor('inlineEditorDidBeginEditing', this.inlineEditorDelegate, target);
    if(del) del.inlineEditorDidBeginEditing(this, this.get('value'), target);
  },

  /**
    Tells the editor to save its value back to its target view and end
    editing. Since the editor is a private property of the view it is
    editing for, this function should only be called from the editor
    itself. For example, you may want your editor to handle the enter
    key by calling commitEditing on itself.

    Will fail if the editor is not editing or if the delegate returns NO to
    inlineEditorShouldCommitEditing.

    @returns {Boolean} whether the editor was allowed to successfully commit its value
  */
  commitEditing:function() {
    if(!this.get('isEditing')) return NO;

    // if the handler was invoked but never went off, call it now
    if(this._didBeginInvoked) this._callDidBegin();

    var del, target = this._target;

    del = this.delegateFor('inlineEditorShouldCommitEditing', this.inlineEditorDelegate, target);
    if(del && !del.inlineEditorShouldCommitEditing(this, this.get('value'), target)) return NO;

    del = this.delegateFor('inlineEditorWillCommitEditing', this.inlineEditorDelegate, target);
    if(del) del.inlineEditorWillCommitEditing(this, this.get('value'), target);

    this._endEditing();

    del = this.delegateFor('inlineEditorDidCommitEditing', this.inlineEditorDelegate, target);
    if(del) del.inlineEditorDidCommitEditing(this, this.get('value'), target);

    return YES;
  },

  /**
    Tells the editor to discard its value and end editing. Like
    commitEditing, this should only be called by other methods of the
    editor. For example, the handle for the escape key might call
    discardEditing.

    Will fail if the editor is not editing or if the delegate returns NO to
    inlineEditorShouldDiscardEditing.

    @returns {Boolean} whether the editor was allowed to discard its value
  */
  discardEditing:function() {
    if(!this.get('isEditing')) return NO;

    // if the handler was invoked but never went off, call it now
    if(this._didBeginInvoked) this._callDidBegin();

    var del, target = this._target;

    del = this.delegateFor('inlineEditorShouldDiscardEditing', this.inlineEditorDelegate, target);
    if(del && !del.inlineEditorShouldDiscardEditing(this, target)) return NO;

    del = this.delegateFor('inlineEditorWillDiscardEditing', this.inlineEditorDelegate, target);
    if(del) del.inlineEditorWillDiscardEditing(this, target);

    this._endEditing();

    del = this.delegateFor('inlineEditorDidDiscardEditing', this.inlineEditorDelegate, target);
    if(del) del.inlineEditorDidDiscardEditing(this, target);

    return YES;
  },

  /**
    @private
    Performs the cleanup functionality shared between discardEditing and
    commitEditing.
  */
  _endEditing: function() {
    this.set('isEditing', NO);
    this._target = null;
  }

};

/* >>>>>>>>>> BEGIN source/mixins/inline_editor_delegate.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @namespace
  
  This delegate is consulted by view implementing SC.InlineEditable and
  SC.InlineEditor and controls the lifecycle of the editor as well as begin
  notified of events in the editing process.
  
  By default it edits an SC.LabelView using an SC.InlineTextFieldView.

  All methods will be attempted to be called on the inlineEditorDelegate of the
  inlineEditor or inlineEditable first and then the target view if it didn't exist
  on the delegate. This allows you to implement default delegate handlers on your
  editable view.
  
  @since SproutCore 1.0
*/
SC.InlineEditorDelegate = {

  // ..........................................................
  // Required Functions
  // 

  /**
    Acquires an editor for the view. This may simply create one and return it,
    or you may implement more complex lifecycle management like pooling of
    editors.

    May return null if for some reason an editor could not be required.

    You must override this function.

    @params {SC.InlineEditable} editable the view that is begin edited
    @returns {SC.InlineEditor} an editor for the view
  */
  acquireEditor:function(editable) {},

  /**
    Releases an editor. This may simply remove it from its parent and dispose of
    it, or you may implement more complex lifecycle management like pooling of
    editors.

    You must override this function.

    @params {SC.InlineEditor} editor the editor being released
    @returns {Boolean} YES if it was successfully released
  */
  releaseEditor:function(editor) {},


  // ..........................................................
  // Optional Functions
  // 

  /**
    Determines if the view should be allowed to begin editing and returns YES if
    so. Isn't passed the editor because it hasn't been created yet. If this
    method is not defined the editor will assume it is always allowed to begin
    editing.

    @params {SC.InlineEditable} editable the view that is attempting to begin editing
    @params {Object} value the current value of the view
    @returns {Boolean} YES if the view is allowed to edit
  */
  inlineEditorShouldBeginEditing: function(editable, value) {},

  /**
    Notifies the delegate that the view was allowed to begin editing and the
    editor has been acquired, but hasn't actually done any setup. Most views will
    set their current value as the starting value of the editor here, and
    depending on the editor other configuration options may be available.

    Since the editor's value hasn't been configured with, the value passed here will be
    the default value of the editor.

    @params {SC.InlineEditable} the view being edited
    @params {SC.InlineEditor} the editor for the view
    @params {Object} the value the editor will start with
  */
  inlineEditorWillBeginEditing:function(editor, value, editable) {},

  /**
    Notifies the delegate that the editor has finished setting up itself and is
    now editing.

    @params {SC.InlineEditable} the view being edited
    @params {SC.InlineEditor} the editor for the view
    @params {Object} the value the editor started with
  */
  inlineEditorDidBeginEditing:function(editor, value, editable) {},

  /**
    Determines if the editor is allowed to end editing and store its value back
    to the view being edited. If this method is not defined the editor will
    assume it is always allowed to commit.

    @params {SC.InlineEditable} the view being edited
    @params {SC.InlineEditor} the editor for the view
    @params {Object} the value the editor is attempting to commit
  */
  inlineEditorShouldCommitEditing:function(editor, value, editable) {},

  /**
    Notifies the delegate that the editor was allowed to commit and is going to
    commit but hasn't actually performed any cleanup yet.

    @params {SC.InlineEditable} the view being edited
    @params {SC.InlineEditor} the editor for the view
    @params {Object} the value the editor ended with
  */
  inlineEditorWillCommitEditing:function(editor, value, editable) {},

  /**
    Notifies the delegate that the editor was allowed to commit and finished
    performing any cleanup necessary. This is where you should save the final
    value back to your view after performing any necessary transforms to it.

    @params {SC.InlineEditable} the view being edited
    @params {SC.InlineEditor} the editor for the view
    @params {Object} the value the editor ended with
  */
  inlineEditorDidCommitEditing:function(editor, value, editable) {},

  /**
    Determines if the editor is allowed to discard its current value and end
    editing. If this method is undefined the editor will assume it is always
    allowed to discard.

    @params {SC.InlineEditable} the view being edited
    @params {SC.InlineEditor} the editor for the view
  */
  inlineEditorShouldDiscardEditing:function(editor, editable) {},

  /**
    Notifies the delegate that the view was allowed to discard editing but
    hasn't performed any cleanup yet.

    @params {SC.InlineEditable} the view being edited
    @params {SC.InlineEditor} the editor for the view
  */
  inlineEditorWillDiscardEditing:function(editor, editable) {},

  /**
    Notifies the delegate that the editor has finished cleaning up after
    discarding editing.

    @params {SC.InlineEditable} the view being edited
    @params {SC.InlineEditor} the editor for the view
  */
  inlineEditorDidDiscardEditing:function(editor, editable) {},


  // ..........................................................
  // Backwards Compatibility
  // 

  /**
    @private

    Notifies the delegate that the editor will end editing but hasn't cleaned up
    yet. This can be caused by both commit or discard. If it was a discard, the
    value will be the same as the current value of the editable view. Otherwise,
    it was a commit and the value will be the value of the editor.

    This method is for backwards compatibility and should not be used.

    @params {SC.InlineEditable} the view being edited
    @params {SC.InlineEditor} the editor for the view
    @params {Object} the final value of the edit
  */
  inlineEditorWillEndEditing: function(editor, value, editable) {},

  /**
    @private

    Notifies the delegate that the editor has cleaned up after editing. This can
    be caused by both commit or discard. If it was a discard, the value will be
    the same as the current value of the editable view. Otherwise, it was a
    commit and the value will be the value of the editor.

    This method is for backwards compatibility and should not be used.

    @params {SC.InlineEditable} the view being edited
    @params {SC.InlineEditor} the editor for the view
    @params {Object} the final value of the edit
  */
  inlineEditorDidEndEditing: function(editor, value, editable) {}
};


/* >>>>>>>>>> BEGIN source/mixins/inner_frame.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @type String
  @constant
*/
SC.SCALE_NONE = "none";

/**
  Stretch/shrink the shape to fill the frame

  @type String
  @constant
*/
SC.FILL = "fill";

/**
  Stretch/shrink the shape to fill the frame while maintaining aspect ratio, such
  that the shortest dimension will just fit within the frame and the longest dimension will
  overflow and be cropped.

  @type String
  @constant
*/
SC.FILL_PROPORTIONALLY = SC.BEST_FILL = "best-fill";

/**
  Stretch/shrink the shape to fit the frame while maintaining aspect ratio, such that the
  longest dimension will just fit within the frame

  @type String
  @constant
*/
SC.BEST_FIT = "best-fit";

/**
  Shrink the shape to fit the frame while maintaining aspect ratio, such that
  the longest dimension will just fit within the frame.  Do not stretch the shape if the shape's
  width is less than the frame's width.

  @type String
  @constant
*/
SC.BEST_FIT_DOWN_ONLY = "best-fit-down";

/**
  @namespace

  InnerFrame provides the innerFrameForSize function, which will return a frame for the given size adjusted
  to fit within the given outer size, according to the align and scale properties.

  View's that render images will find this mixin particularly useful for fitting their images.
 */
SC.InnerFrame = {

  /**
    Align the shape within its frame. Possible values:

      - SC.ALIGN_TOP_LEFT
      - SC.ALIGN_TOP
      - SC.ALIGN_TOP_RIGHT
      - SC.ALIGN_LEFT
      - SC.ALIGN_CENTER
      - SC.ALIGN_RIGHT
      - SC.ALIGN_BOTTOM_LEFT
      - SC.ALIGN_BOTTOM
      - SC.ALIGN_BOTTOM_RIGHT

    @type String
    @default SC.ALIGN_CENTER
  */
  align: SC.ALIGN_CENTER,

  /**
    Returns a frame (x, y, width, height) fitting the source size (sourceWidth & sourceHeight) within the
    destination size (destWidth & destHeight) according to the align and scale properties.  This is essential to
    positioning child views or elements within parent views or elements in elegant ways.

    @param {Number} sourceWidth
    @param {Number} sourceHeight
    @param {Number} destWidth
    @param {Number} destHeight
    @returns {Object} the inner frame with properties: {x: value, y: value, width: value, height: value }
  */
  innerFrameForSize: function(sourceWidth, sourceHeight, destWidth, destHeight) {
    var align = this.get('align'),
        scale = this.get('scale'),
        scaleX,
        scaleY,
        result;

    // Fast path
    result = { x: 0, y: 0, width: destWidth, height: destHeight };
    if (scale === SC.FILL) return result;

    // Determine the appropriate scale
    scaleX = destWidth / sourceWidth;
    scaleY = destHeight / sourceHeight;

    switch (scale) {
      case SC.BEST_FILL:
        scale = scaleX > scaleY ? scaleX : scaleY;
        break;
      case SC.BEST_FIT:
        scale = scaleX < scaleY ? scaleX : scaleY;
        break;
      case SC.BEST_FIT_DOWN_ONLY:
        if ((sourceWidth > destWidth) || (sourceHeight > destHeight)) {
          scale = scaleX < scaleY ? scaleX : scaleY;
        } else {
          scale = 1.0;
        }
        break;
      case SC.SCALE_NONE:
        scale = 1.0;
        break;
      default: // Number
        if (isNaN(window.parseFloat(scale)) || (window.parseFloat(scale) <= 0)) {
          SC.Logger.warn("SC.InnerFrame: The scale '%@' was not understood.  Scale must be one of SC.FILL, SC.BEST_FILL, SC.BEST_FIT, SC.BEST_FIT_DOWN_ONLY or a positive number greater than 0.00.".fmt(scale));

          // Don't attempt to scale or offset the image
          return result;
        }
    }

    sourceWidth *= scale;
    sourceHeight *= scale;
    result.width = Math.round(sourceWidth);
    result.height = Math.round(sourceHeight);

    // Align the image within its frame
    switch (align) {
      case SC.ALIGN_LEFT:
        result.x = 0;
        result.y = (destHeight / 2) - (sourceHeight / 2);
        break;
      case SC.ALIGN_RIGHT:
        result.x = destWidth - sourceWidth;
        result.y = (destHeight / 2) - (sourceHeight / 2);
        break;
      case SC.ALIGN_TOP:
        result.x = (destWidth / 2) - (sourceWidth / 2);
        result.y = 0;
        break;
      case SC.ALIGN_BOTTOM:
        result.x = (destWidth / 2) - (sourceWidth / 2);
        result.y = destHeight - sourceHeight;
        break;
      case SC.ALIGN_TOP_LEFT:
        result.x = 0;
        result.y = 0;
        break;
      case SC.ALIGN_TOP_RIGHT:
        result.x = destWidth - sourceWidth;
        result.y = 0;
        break;
      case SC.ALIGN_BOTTOM_LEFT:
        result.x = 0;
        result.y = destHeight - sourceHeight;
        break;
      case SC.ALIGN_BOTTOM_RIGHT:
        result.x = destWidth - sourceWidth;
        result.y = destHeight - sourceHeight;
        break;
      default: // SC.ALIGN_CENTER || SC.ALIGN_MIDDLE
        

        result.x = (destWidth / 2) - (sourceWidth / 2);
        result.y = (destHeight / 2) - (sourceHeight / 2);
    }

    return result;
  },

  /**
    Determines how the shape will scale to fit within its containing space. Possible values:

      - SC.SCALE_NONE
      - SC.FILL
      - SC.BEST_FILL
      - SC.BEST_FIT
      - SC.BEST_FIT_DOWN_ONLY

    @type String
    @default SC.FILL
  */
  scale: SC.FILL
};

/* >>>>>>>>>> BEGIN source/mixins/static_layout.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @namespace

  SC.StaticLayout is now built in to SC.View.  You do not need to
  apply this mixin to use static layout.  Just set useStaticLayout to YES.



  Normally, SproutCore views use absolute positioning to display themselves
  on the screen.  While this is both the fastest and most efficient way to
  display content in the web browser, sometimes your user interface might need
  to take advantage of the more advanced "flow" layout offered by the browser
  when you use static and relative positioning.

  This mixin can be added to a view class to enable the use of any kind of
  static and relative browser positioning.  In exchange for using static
  layout, you will lose a few features that are normally available on a view
  class such as the 'frame' and 'clippingFrame' properties as well as
  notifications when your view or parentView are resized.

  Normally, if you are allowing the browser to manage the size and positioning
  of your view, these feature will not be useful to your code anyway.

  ## Using StaticLayout

  To enable static layout on your view, just include this mixin on the view.
  SproutCore's builtin views that are capable of being used in static
  layouts already incorporate this mixin.  Then set the "useStaticLayout"
  property on your view class to YES.

  You can then use CSS or the render() method on your view to setup the
  positioning on your view using any browser layout mechanism you want.

  ## Example

      // JavaScript

      MyApp.CommentView = SC.View.extend(SC.StaticLayout, {

        classNames: ['comment-view'],

        useStaticLayout: YES,

        ...
      });

      // CSS

      .comment-view {
        display: block;
        position: relative;
      }

  @deprecated Version 1.10
  @since SproutCore 1.0
*/
SC.StaticLayout = {

  /**
    Walk like a duck.  Used to determine that this mixin has been applied.
    Note that a view that hasStaticLayout still may not actually use static
    layout unless useStaticLayout is also set to YES.

    @type Boolean
    @default YES
  */
  hasStaticLayout: YES,

  initMixin: function () {
    

  }

};

/* >>>>>>>>>> BEGIN source/mixins/validatable.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @namespace

  Views that include the Validatable mixin can be used with validators to
  ensure their values are valid.

*/
SC.Validatable = {

  /** @private */
  initMixin: function() {
    this._validatable_validatorDidChange() ;
  },

  /**
    The validator for this field.

    Set to a validator class or instance.  If this points to a class, it will
    be instantiated when the validator is first used.

    @type SC.Validator
    @default null
  */
  validator: null,

  /**
    This property must return the human readable name you want used when
    describing an error condition.  For example, if set this property to
    "Your Email", then the returned error string might be something like
    "Your Email is not valid".

    You can return a loc string here if you like.  It will be localized when
    it is placed into the error string.

    @type String
    @default null
  */
  errorLabel: null,

  /**
    YES if the receiver is currently valid.

    This property watches the value property by default.  You can override
    this property if you want to use some other method to calculate the
    current valid state.

    @field
    @type Boolean
    @default YES
  */
  isValid: function() {
    return SC.typeOf(this.get('value')) !== SC.T_ERROR;
  }.property('value'),

  /**
    The form that the view belongs to.  May be null if the view does not
    belong to a form.  This property is usually set automatically by an
    owner form view.

    @type SC.View
    @default null
  */
  ownerForm: null,

  /**
    Attempts to validate the receiver.

    Runs the validator and returns SC.VALIDATE_OK, SC.VALIDATE_NO_CHANGE,
    or an error object.  If no validator is installed, this method will
    always return SC.VALIDATE_OK.

    @param {Boolean} partialChange YES if this is a partial edit.
    @returns {String} SC.VALIDATE_OK, error, or SC.VALIDATE_NO_CHANGE
  */
  performValidate: function(partialChange) {
    var ret = SC.VALIDATE_OK ;

    if (this._validator) {
      var form = this.get('ownerForm') ;
      if (partialChange) {
        ret = this._validator.validatePartial(form,this) ;

        // if the partial returned NO_CHANGE, then check to see if the
        // field is valid anyway.  If it is not valid, then don't update the
        // value.  This way the user can have partially constructed values
        // without the validator trying to convert it to an object.
        if ((ret == SC.VALIDATE_NO_CHANGE) && (this._validator.validateChange(form, this) == SC.VALIDATE_OK)) {
          ret = SC.VALIDATE_OK;
        }
      } else ret = this._validator.validateChange(form, this) ;
    }
    return ret ;
  },

  /**
    Runs validateSubmit.  You should use this in your implementation of
    validateSubmit.  If no validator is installed, this always returns
    SC.VALIDATE_OK

    @returns {String}
  */
  performValidateSubmit: function() {
    return this._validator ? this._validator.validateSubmit(this.get('ownerForm'), this) : SC.VALIDATE_OK;
  },

  /**
    Runs a keydown validation.  Returns YES if the keydown should be
    allowed, NO otherwise.  If no validator is defined, always returns YES.

    @param {String} charStr the key string
    @returns {Boolean}
  */
  performValidateKeyDown: function(evt) {
    // ignore anything with ctrl or meta key press
    var charStr = evt.getCharString();
    if (!charStr) return YES ;
    return this._validator ? this._validator.validateKeyDown(this.get('ownerForm'), this, charStr) : YES;
  },

  /**
    Returns the validator object, if one has been created.

    @field
    @type SC.Validator
  */
  validatorObject: function() {
    return this._validator;
  }.property(),

  /**
    Invoked by the owner form just before submission.  Override with your
    own method to commit any final changes after you perform validation.

    The default implementation simply calls performValidateSubmit() and
    returns that value.

    @type Boolean
  */
  validateSubmit: function() { return this.performValidateSubmit(); },

  /**
    Convert the field value string into an object.

    This method will call the validators objectForFieldValue if it exists.

    @param {Object} fieldValue the raw value from the field.
    @param {Boolean} partialChange
    @returns {Object}
  */
  objectForFieldValue: function(fieldValue, partialChange) {
    return this._validator ? this._validator.objectForFieldValue(fieldValue, this.get('ownerForm'), this) : fieldValue ;
  },

  /**
    Convert the object into a field value.

    This method will call the validator's fieldValueForObject if it exists.

    @param object {Object} the objec to convert
    @returns {Object}
  */
  fieldValueForObject: function(object) {
    return this._validator ? this._validator.fieldValueForObject(object, this.get('ownerForm'), this) : object ;
  },

  /** @private */
  _validatable_displayObserver: function() {
    this.displayDidChange();
  }.observes('isValid'),

  /** @private */
  renderMixin: function(context) {
    context.setClass('invalid', !this.get('isValid'));
  },

  /** @private
    Invoked whenever the attached validator changes.
  */
  _validatable_validatorDidChange: function() {
    var form = this.get('ownerForm') ;
    var val = SC.Validator.findFor(form, this, this.get('validator')) ;
    if (val != this._validator) {
      this.propertyWillChange('validatorObject');
      if (this._validator) this._validator.detachFrom(form, this) ;
      this._validator = val;
      if (this._validator) this._validator.attachTo(form, this) ;
      this.propertyDidChange('validatorObject');
    }
  }.observes('validator', 'ownerForm')

};

/* >>>>>>>>>> BEGIN source/render_delegates/render_delegate.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @class
  Base class for all render delegates.

  You should use SC.RenderDelegate or a subclass of it as the base for all 
  of your render delegates. SC.RenderDelegate offers many helper methods 
  and can be simpler to subclass between themes than `SC.Object`.

  Creating & Subclassing
  ===
  You create render delegates just like you create SC.Objects:

      MyTheme.someRenderDelegate = SC.RenderDelegate.create({ ... });

  You can subclass a render delegate and use that:

      MyTheme.RenderDelegate = SC.RenderDelegate.extend({ ... });
      MyTheme.someRenderDelegate = MyTheme.RenderDelegate.create({});

  And you can even subclass instances or SC.RenderDelegate:

      MyTheme.someRenderDelegate = SC.RenderDelegate.create({ ... });
      MyTheme.otherRenderDelegate = MyTheme.someRenderDelegate.create({ ... });

      // this allows you to subclass another theme's render delegate:
      MyTheme.buttonRenderDelegate = SC.BaseTheme.buttonRenderDelegate.create({ ... });

  For render delegates, subclassing and instantiating are the same.

  NOTE: Even though `.extend` and `.create` technically do the same thing, 
  convention dictates that you use `.extend` for RenderDelegates that 
  will be used primarily as base classes, and `create` for RenderDelegates
  that you expect to be instances.

  Rendering and Updating
  ===
  Render delegates are most commonly used for two things: rendering and updating
  DOM representations of controls.

  Render delegates use their `render` and `update` methods to do this:

      render: function(dataSource, context) {
        // rendering tasks here
        // example:
        context.begin('div').addClass('title')
          .text(dataSource.get('title')
        .end();
      },

      update: function(dataSource, jquery) {
        // updating tasks here
        // example:
        jquery.find('.title').text(dataSource.get('title'));
      }

  Variables
  ===
  The data source provides your render delegate with all of the information
  needed to render. However, the render delegate's consumer--usually a view--
  may need to get information back.

  For example, `SC.AutoResize` resizes controls to fit their text. You can use
  it to size a button to fit its title. But it can't just make the button
  have the same width as its title: it needs to be a little larger to make room
  for the padding to the left and right sides of the title.

  This padding will vary from theme to theme.
  
  You can specify properties on the render delegate like any other property:

      MyRenderDelegate = SC.RenderDelegate.create({
        autoSizePadding: 10
        ...
      });

  But there are multiple sizes of buttons; shouldn't the padding change as
  well? You can add hashes for the various control sizes and override properties:

      SC.RenderDelegate.create({
        autoSizePadding: 10,

        'sc-jumbo-size': {
          autoResizePadding: 20
        }

  For details, see the discussion on size helpers below.

  You can also calculate values for the data source. In this example, we calculate
  the autoSizePadding to equal half the data source's height:

      SC.RenderDelegate.create({
        autoSizePaddingFor: function(dataSource) {
          if (dataSource.get('frame')) {
            return dataSource.get('frame').height / 2;
          }
        }


  When SC.ButtonView tries to get `autoSizePadding`, the render delegate will look for
  `autoSizePaddingFor`. It will be called if it exists. Otherwise, the property will
  be looked up like normal.

  Note: To support multiple sizes, you must also render the class name; see size
  helper discussion below.

  Helpers
  ===
  SC.RenderDelegate have "helper methods" to assist the rendering process.
  There are a few built-in helpers, and you can add your own.

  Slices
  ----------------------
  Chance provides the `includeSlices` method to easily slice images for
  use in the SproutCore theme system.

      includeSlices(dataSource, context, slices);

  You can call this to add DOM that matches Chance's `@include slices()`
  directive. For example:

      MyTheme.buttonRenderDelegate = SC.RenderDelegate.create({
        className: 'button',
        render: function(dataSource, context) {
          this.includeSlices(dataSource, context, SC.THREE_SLICE);
        }
      });

  DOM elements will be added as necessary for the slices. From your CSS, you
  can match it like this:

      $theme.button {
        @include slices('button.png', $left: 3, $right: 3);
      }

  See the Chance documentation at http://guides.sproutcore.com/chance.html
  for more about Chance's `@include slices` directive.

  Sizing Helpers
  -------------------------
  As discussed previously, you can create hashes of properties for each size. 
  However, to support sizing, you must render the size's class name.

  Use the `addSizeClassName` and `updateSizeClassName` methods:

      SC.RenderDelegate.create({
        render: function(dataSource, context) {
          // if you want to include a class name for the control size
          // so you can style it via CSS, include this line:
          this.addSizeClassName(dataSource, context);

          ...
        },

        update: function(dataSource, jquery) {
          // and don't forget to use its companion in update as well:
          this.updateSizeClassName(dataSource, jquery);

          ...
        }
      });

  Controls that allow multiple sizes should also be able to automatically choose
  the correct size based on the `layout` property supplied by the user. To support
  this, you can add properties to your size hashes:

      'sc-regular-size': {
        // to match _only_ 24px-high buttons
        height: 24,

        // or, alternatively, to match ones from 22-26:
        minHeight: 20, maxHeight: 26,

        // you can do the same for width if you wanted
        width: 100
      }

  The correct size will be calculated automatically when `addSlizeClassName` is
  called. If the view explicitly supplies a control size, that size will be used;
  otherwise, it will be calculated automatically based on the properties in your
  size hash.

  Adding Custom Helpers
  ---------------------
  You can mix your own helpers into this base class by calling 
  SC.RenderDelegate.mixin; they will be available to all render delegates:

      SC.RenderDelegate.mixin({
        myHelperMethod: function(dataSource) { ... }
      });


  You can then use the helpers from your render delegates:

      MyTheme.someRenderDelegate = SC.RenderDelegate.create({
        className: 'some-thingy',
        render: function(dataSource, context) {
          this.myHelperMethod(dataSource);
        }
      });


  By convention, all render delegate methods should take a `dataSource` as 
  their first argument. If they do any rendering or updating, their second
  argument should be the `SC.RenderContext` or `jQuery` object to use.

  In addition, helpers like these are only meant for methods that should
  be made available to _all_ render delegates. If your method is specific
  to just one, add it directly; if it is specific to just a few in your
  own theme, consider just using mixins or subclassing SC.RenderDelegate:

      // If you use it in a couple of render delegates, perhaps a mixin
      // would be best:
      MyTheme.MyRenderHelper = {
        helper: function(dataSource) {
          ...
        }
      };

      MyTheme.myRenderDelegate = SC.RenderDelegate.create(MyTheme.MyRenderHelper, {
        render: function(dataSource, context) { ... }
      });


      // If you use it in all render delegates in your theme, perhaps it
      // would be better to create an entire subclass of
      // SC.RenderDelegate:
      MyTheme.RenderDelegate = SC.RenderDelegate.extend({
        helper: function(dataSource) {
          ...
        }
      });

      MyTheme.myRenderDelegate = MyTheme.RenderDelegate.create({
        render: function(dataSource, context) { ... }
      });

  Data Sources
  ===
  Render delegates get the content to be rendered from their data sources.

  A data source can be any object, so long as the object implements
  the following methods:

  - `get(propertyName)`: Returns a value for a given property.
  - `didChangeFor(context, propertyName)`: Returns YES if any properties
    listed have changed since the last time `didChangeFor` was called with
    the same context.

  And the following properties (to be accessed through `.get`):

  - `theme`: The theme being used to render.
  - `renderState`: An empty hash for the render delegate to save state in.
    While render delegates are _usually_ completely stateless, there are
    cases where they may need to save some sort of state.
*/
SC.RenderDelegate = /** @scope SC.RenderDelegate.prototype */{
  
  // docs will look more natural if these are all considered instance
  // methods/properties.

  /**
    Creates a new render delegate based on this one. When you want to
    create a render delegate, you call this:
   
        MyTheme.myRenderDelegate = SC.RenderDelegate.create({
          className: 'my-render-delegate',
          render: function(dataSource, context) {
            // your code here...
          }
        })
  */
  create: function() {
    var ret = SC.beget(this);

    var idx, len = arguments.length;
    for (idx = 0; idx < len; idx++) {
      ret.mixin(arguments[idx]);
    }

    return ret;
  },

  /**
    Adds extra capabilities to this render delegate.
   
    You can use this to add helpers to all render delegates:
   
        SC.RenderDelegate.reopen({
          myHelperMethod: function(dataSource) { ... }
        });
   
  */
  reopen: function(mixin) {
    var i, v;
    for (i in mixin) {
      v = mixin[i];
      if (!mixin.hasOwnProperty(i)) {
        continue;
      }

      if (typeof v === 'function' && v !== this[i]) {
        v.base = this[i] || SC.K;
      }

      if (v && v.isEnhancement && v !== this[i]) {
        v = SC._enhance(this[i] || SC.K, v);
      }

      this[i] = v;
    }
  },

  /**
    Returns the specified property from this render delegate.
    Implemented to match SC.Object's API.
  */
  get: function(propertyName) { return this[propertyName]; },

  /**
    Gets or generates the named property for the specified
    dataSource. If a method `propertyName + 'For'` is found,
    it will be used to compute the value, `dataSource`
    being passed as an argument. Otherwise, it will simply
    be looked up on the render delegate.
    
    NOTE: this implementation is a reference implementation. It
    is overridden in the sizing code (helpers/sizing.js) to be
    size-sensitive.
  */
  getPropertyFor: function(dataSource, propertyName) {
    if (this[propertyName + 'For']) {
      return this[propertyName + 'For'](dataSource, propertyName);
    }

    return this[propertyName];
  },

  /**
    All render delegates should have a class name. Any time a render delegate is
    used, this name should be added as a class name (`SC.View`s do this
    automatically).
  */
  className: undefined,

  /**
    Writes the DOM representation of this render delegate to the
    supplied `SC.RenderContext`, using the supplied `dataSource`
    for any data needed.
    
    @method
    @param {DataSource} dataSource An object from which to get
    data. See documentation on data sources above.
    @param {SC.RenderContext} context A context to render DOM into.
  */
  render: function(dataSource, context) {

  },

  /**
    Updates the DOM representation of this render delegate using
    the supplied `jQuery` instance and `dataSource`.
    
    @method
    @param {DataSource} dataSource An object from which to get
    data. See documentation on data sources above.
    @param {jQuery} jquery A jQuery instance containing the DOM
    element to update. This will be the DOM generated by `render()`.
  */
  update: function(dataSource, jQuery) {

  }
};

// create and extend are technically identical.
SC.RenderDelegate.extend = SC.RenderDelegate.create;

// and likewise, as this is both a class and an instance, mixin makes
// sense instead of reopen...
SC.RenderDelegate.mixin = SC.RenderDelegate.reopen;

/* >>>>>>>>>> BEGIN source/render_delegates/canvas_image.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2009 Sprout Systems, Inc. and contributors.
//            Portions ©2010-2011 Strobe Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('render_delegates/render_delegate');

/**
  @class
  Renders and updates DOM representations of an image.

  Parameters
  --------------------------
  Expects these properties on the data source:

  - image: An Image object which has completed loading

  If any of these are not present in the data source, the render delegate
  will throw an error.

  Optional Parameters:
  ---------------------------
  If present, these properties will be used.

  - width: Used on the canvas element. If not provided, 0 is used and the canvas
            will not be visible.
  - height: Used on the canvas element. If not provided, 0 is used and the canvas
            will not be visible.
  - scale: If provided, the image will maintain aspect ratio as specified by this
          property. One of
            - SC.SCALE_NONE
            - SC.FILL
            - SC.BEST_FILL
            - SC.BEST_FIT
            - SC.BEST_FIT_DOWN_ONLY
            - percentage {Number}
          If not provided, SC.FILL will be the default (ie. expected image behaviour)
  - align: If provided, the image will align itself within its frame.  One of
            - SC.ALIGN_CENTER
            - SC.ALIGN_TOP_LEFT
            - SC.ALIGN_TOP
            - SC.ALIGN_TOP_RIGHT
            - SC.ALIGN_RIGHT
            - SC.ALIGN_BOTTOM_RIGHT
            - SC.ALIGN_BOTTOM
            - SC.ALIGN_BOTTOM_LEFT
            - SC.ALIGN_LEFT
  - backgroundColor: If provided, the canvas will render a backgroundColor
*/

SC.BaseTheme.canvasImageRenderDelegate = SC.RenderDelegate.create({
  className: 'canvasImage',

  /** @private
    We don't have an element yet, so we do the minimal necessary setup
    here.
  */
  render: function (dataSource, context) {
    var width = dataSource.get('width') || 0,
        height = dataSource.get('height') || 0,
        type = dataSource.get('type') || SC.IMAGE_TYPE_URL,
        value = dataSource.get('value');

    // Support for CSS sprites (TODO: Remove this)
    if (value && type === SC.IMAGE_TYPE_CSS_CLASS) {
      context.addClass(value);
      dataSource.renderState._last_class = value;
    }

    context.setAttr('width', width);
    context.setAttr('height', height);
  },

  update: function (dataSource, jquery) {
    var elem = jquery[0],
        image = dataSource.get('image'),
        frame = dataSource.get('frame'),
        frameWidth = frame.width,
        frameHeight = frame.height,
        innerFrame = dataSource.get('innerFrame'),
        backgroundColor = dataSource.get('backgroundColor'),
        renderState = dataSource.get('renderState'),
        context,
        lastClass = dataSource.renderState._last_class,
        type = dataSource.get('type') || SC.IMAGE_TYPE_URL,
        value = dataSource.get('value');

    // Support for CSS sprites
    if (lastClass) jquery.removeClass(lastClass);
    if (value && type === SC.IMAGE_TYPE_CSS_CLASS) {
      jquery.addClass(value);
      dataSource.renderState._last_class = value;

      // Clear the context in case there was a URL previously
      if (elem && elem.getContext) {
        context = elem.getContext('2d');
        context.clearRect(0, 0, frameWidth, frameHeight);
      }
    } else {

      // We only care about specific values, check specifically for what matters
      var innerFrameDidChange = ![innerFrame.x, innerFrame.y, innerFrame.width, innerFrame.height].isEqual(renderState._lastInnerFrameValues),
          elemSizeDidChange = ![elem.width, elem.height].isEqual(renderState._lastElemSizeValues),
          backgroundDidChange = dataSource.didChangeFor('canvasImageRenderDelegate', 'backgroundColor'),
          imageDidChange = dataSource.didChangeFor('canvasImageRenderDelegate', 'image') || (image && image.complete) !== renderState._lastImageComplete;

      if (elemSizeDidChange || innerFrameDidChange || backgroundDidChange || imageDidChange) {

        if (elem && elem.getContext) {
          elem.height = frameHeight;
          elem.width = frameWidth;

          context = elem.getContext('2d');

          context.clearRect(0, 0, frameWidth, frameHeight);

          if (backgroundColor) {
            context.fillStyle = backgroundColor;
            context.fillRect(0, 0, frameWidth, frameHeight);
          }

          if (image && image.complete) {
            context.drawImage(image, Math.floor(innerFrame.x), Math.floor(innerFrame.y), Math.floor(innerFrame.width), Math.floor(innerFrame.height));
          }
        }

        // Update caches
        renderState._lastInnerFrameValues = [innerFrame.x, innerFrame.y, innerFrame.width, innerFrame.height];
        renderState._lastElemSizeValues = [elem.width, elem.height];
        renderState._lastImageComplete = image && image.complete;
      }
    }
  }

});

/* >>>>>>>>>> BEGIN source/render_delegates/container.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('render_delegates/render_delegate');

SC.BaseTheme.containerRenderDelegate = SC.RenderDelegate.create({
  render: function(dataSource, context) {

  },
  
  update: function() {

  }
});

/* >>>>>>>>>> BEGIN source/render_delegates/helpers/sizing.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2009 Sprout Systems, Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('render_delegates/render_delegate');

SC.RenderDelegate.reopen({
  /**
    A list of size names to look for when automatically determining
    control size. By default, this has all of the SproutCore control sizes.
  */
  sizes: [
    SC.TINY_CONTROL_SIZE, SC.SMALL_CONTROL_SIZE,
    SC.REGULAR_CONTROL_SIZE, SC.LARGE_CONTROL_SIZE,
    SC.HUGE_CONTROL_SIZE, SC.JUMBO_CONTROL_SIZE
  ],

  /**
    Determines the correct size for the given data source, and returns the
    hash, if any, representing it.
   
    The hashes to choose from are properties on the render delegate. You define
    them with the same name as you would use for styling. For example,
    SC.REGULAR_CONTROL_SIZE uses a property name 'sc-regular-size':
   
        SC.RenderDelegate.create({
          'sc-regular-size': {
            // my properties here
          }
   
    If no matching size is found, the hash (if any) for SC.REGULAR_CONTROL_SIZE
    will be returned.
   
    @param {DataSource} dataSource The data source in which to find `controlSize`
    or `frame` and to determine the size for.
   
    @returns {Hash undefined}
  */
  sizeFor: function(dataSource) {
    var controlSize = dataSource.get('controlSize'), size, idx, len;

    // if there is a control size set on the control
    // then we need to use it, and give an error if we
    // don't have it.
    if (controlSize) {
      if (!this[controlSize]) {
        // create a hash for the control size
        this[controlSize] = {};
      }

      size = this[controlSize];

      // make sure there's a name on the size for use as class name
      if (!size.name) {
        size.name = controlSize;
      }

      return size;
    }

    // try to determine control size for the supplied frame
    // TODO: cache this in dataSource.renderState
    var frame = dataSource.get('frame');
    if (!frame) {
      size = this['sc-regular-size'];

      // create the size hash if needed
      if (!size) { size = this['sc-regular-size'] = {}; }
      if (!size.name) { size.name = 'sc-regular-size'; }
      return size;
    }

    // loop to automatically find size
    for (idx = 0; idx < len; idx++) {
      key = sizes[idx];
      size = this[key];

      // when the size is not defined, skip it.
      if (!size) {
        continue;
      }

      if (
        // if no auto-size-selection params are supplied, then we cannot
        // automatically select a size...
        (
          size.width === undefined && size.height === undefined && 
          size.minHeight === undefined && size.minWidth === undefined &&
          size.maxHeight === undefined && size.maxWidth === undefined
        ) ||

        // otherwise, if any are defined and are non-equal
        (size.width !== undefined && frame.width !== size.width) ||
        (size.minWidth !== undefined && frame.width < size.minWidth) ||
        (size.maxWidth !== undefined && frame.width > size.maxWidth) ||

        (size.height !== undefined && frame.height !== size.height) ||
        (size.minHeight !== undefined && frame.height < size.minHeight) ||
        (size.maxHeight !== undefined && frame.height < size.maxHeight)
      ) {
        continue;
      }

      // the size needs a name to use as a class name. If one is not already
      // present, set it to the key.
      if (!size.name) {
        size.name = key;
      }

      return size;
    }

    // hardcoded to return regular size if defined
    size = this['sc-regular-size'];

    // create the size hash if needed
    if (!size) { size = this['sc-regular-size'] = {}; }
    if (!size.name) { size.name = 'sc-regular-size'; }


    return size;
  },

  /**
    Determines the proper size for the dataSource, and then renders the class
    name corresponding to that size.
  */
  addSizeClassName: function(dataSource, context) {
    var size = this.sizeFor(dataSource);
    if (size) {
      context.addClass(size.name);
    }
  },

  /**
    Determines the proper size for the dataSource, and then updates
    the DOM to include that size's class name.
  */
  updateSizeClassName: function(dataSource, jquery) {
    var size = this.sizeFor(dataSource);
    if (size) {
      jquery.addClass(size.name);
    }
  },

  /**
    Retrieves the given property for the specified data source. This property
    may be static, or may be computed specifically for this data source. This
    version fo `getPropertyFor` will check in your size hashes to see if any
    properties have been overridden.
    
    @param {DataSource} dataSource The data source to get the property
    for. Some properties may differ based on the data source; for instance,
    some may have different values depending on size.
    @param {String} propertyName The name of the property to retrieve.
  */
  getPropertyFor: function(dataSource, propertyName) {
    var size = this.sizeFor(dataSource);
    if (size) {
      if (size[propertyName + 'For']) {
        return size[propertyName + 'For'](dataSource, propertyName);
      } else if (size[propertyName] !== undefined) {
        return size[propertyName];
      }
    }

    if (this[propertyName + 'For']) {
      return this[propertyName + 'For'];
    }

    return this[propertyName];
  }
});

/* >>>>>>>>>> BEGIN source/render_delegates/image.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2009 Sprout Systems, Inc. and contributors.
//            Portions ©2010-2011 Strobe Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('render_delegates/render_delegate');

/**
  @class
  Renders and updates DOM representations of an image.

  Parameters
  --------------------------
  Expects these properties on the data source:

  - image: An Image object which has completed loading

  If any of these are not present in the data source, the render delegate
  will throw an error.

  Optional Parameters:
  ---------------------------
  If present, these properties will be used.

  - imageValue: A String which represents the src or CSS class of the image
  - displayToolTip: A String which is rendered as a toolTip on the element
  - type: The type of image being rendered. One of:
              - SC.IMAGE_TYPE_NONE
              - SC.IMAGE_TYPE_URL
              - SC.IMAGE_TYPE_CSS_CLASS
          If not provided, SC.IMAGE_TYPE_URL is the default
*/

SC.BaseTheme.imageRenderDelegate = SC.RenderDelegate.create({
  className: 'image',

  render: function (dataSource, context) {
    var image = dataSource.get('image'),
      value = dataSource.get('value'),
      type = dataSource.get('type') || SC.IMAGE_TYPE_URL,
      toolTip = dataSource.get('toolTip');

    // Place the img within a div, so that we may scale & offset the img
    context = context.begin('img');
    context.setAttr('src', image.src);

    // Support for CSS sprites (TODO: Remove this)
    if (value && type === SC.IMAGE_TYPE_CSS_CLASS) {
      context.addClass(value);
      dataSource.renderState._last_class = value;
    }

    if (toolTip) {
      context.setAttr('title', toolTip);
      context.setAttr('alt', toolTip);
    }

    // Adjust the layout of the img
    context.addStyle(this.imageStyles(dataSource));

    context = context.end();
  },

  update: function (dataSource, jquery) {
    var image = dataSource.get('image'),
      lastClass = dataSource.renderState._last_class,
      value = dataSource.get('value'),
      type = dataSource.get('type') || SC.IMAGE_TYPE_URL,
      toolTip = dataSource.get('toolTip');

    jquery = jquery.find('img');

    jquery.attr('src', image.src);

    // Support for CSS sprites (TODO: Remove this)
    if (lastClass) jquery.removeClass(lastClass);
    if (value && type === SC.IMAGE_TYPE_CSS_CLASS) {
      jquery.addClass(value);
      dataSource.renderState._last_class = value;
    }

    if (toolTip) {
      jquery.attr('title', toolTip);
      jquery.attr('alt', toolTip);
    }

    // Adjust the layout of the img
    jquery.css(this.imageStyles(dataSource));
  },

  imageStyles: function (dataSource) {
    var innerFrame = dataSource.get('innerFrame');
    return {
      'position': 'absolute',
      'left': Math.round(innerFrame.x),
      'top': Math.round(innerFrame.y),
      'width': Math.round(innerFrame.width),
      'height': Math.round(innerFrame.height)
    };
  }

});

/* >>>>>>>>>> BEGIN source/render_delegates/label.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('render_delegates/render_delegate');

/**
  @class
  Renders and updates DOM representations of a label.

  Parameters
  --------------------------
  Expects these properties on the data source:

  - title

  If any of these are not present in the data source, the render delegate
  will throw an error.

  Optional Parameters:
  ---------------------------
  If present, these properties will be used.

  - icon: should be either a class name or a URL
  - hint: allows the label to display a hint value if its title is empty.
  - escapeHTML: whether the HTML should be escaped to prevent XSS attacks
    and the like.
  - textAlign
  - needsEllipsis: Whether an ellipsis (...) should be added after the title
    if the title is too long.
*/

SC.BaseTheme.labelRenderDelegate = SC.RenderDelegate.create({
  className: 'label',

  render: function(dataSource, context) {
    var toolTip = dataSource.get('toolTip');

    this.addSizeClassName(dataSource, context);

    // Set the toolTip.
    if (toolTip) {
      context.setAttr('title', toolTip);
    }

    /*
      TODO [CC @ 1.5] These properties have been deprecated. We should remove them
            in the next release
    */
    context.addStyle({
      textAlign: dataSource.get('textAlign') || null
    });

    context.setClass('ellipsis', dataSource.get('needsEllipsis') || NO);
    context.setClass('icon', dataSource.get('icon') || NO);

    var html = this.htmlForTitleAndIcon(dataSource);
    context.push(html);

    // we could use didChangeFor, but in this case, checking the generated
    // HTML will probably be faster (and definitely be simpler)
    // because several properties are used.
    dataSource.get('renderState')._lastHTMLForTitleAndIcon = html;
  },

  update: function(dataSource, jquery) {
    var toolTip = dataSource.get('toolTip');

    this.updateSizeClassName(dataSource, jquery);

    /*
      TODO [CC @ 1.5] These properties have been deprecated. We should remove them
            in the next release
    */
    jquery.css({
      textAlign: dataSource.get('textAlign') || null
    });

    // Update the toolTip.
    if (toolTip) {
      jquery.attr('title', toolTip);
    } else {
      jquery.removeAttr('title');
    }

    jquery.setClass('ellipsis', dataSource.get('needsEllipsis') || NO);

    var html = this.htmlForTitleAndIcon(dataSource);
    if (dataSource.get('renderState')._lastHTMLForTitleAndIcon !== html) {
      jquery.html(html);
      dataSource.get('renderState')._lastHTMLForTitleAndIcon = html;
    }
  },

  /**
    Generates the HTML for the title and icon of the label. Render delegates can
    override this to change how that HTML renders without affecting the rest of the
    rendering of the label.

    @param dataSource The data source that provides the title and icon properties.
    @return the html to use
  */
  htmlForTitleAndIcon: function(dataSource) {
    var title = dataSource.get('title'),
        hint = dataSource.get('hint'),
        escapeHTML = dataSource.get('escapeHTML'),
        icon = dataSource.get('icon') || '';

    // Escape the body if needed. This prevents potential XSS attacks.
    if (title && escapeHTML) {
      title = SC.RenderContext.escapeHTML(title) ;
    }

    // Escape the hint if needed. This prevents potential XSS attacks.
    if (hint && escapeHTML) { hint = SC.RenderContext.escapeHTML(hint); }
    if (hint && !title) {
      title = "<span class='sc-hint'>" + hint + "</span>";
    }

    if (icon) {
      // If the icon property is the path to an image, create an image tag
      // that points to that URL.
      if (icon.indexOf('/') >= 0) {
        icon = '<img src="'+icon+'" alt="" class="icon" />';

      // Otherwise, the icon property is a class name that should be added
      // to the image tag. Display a blank image so that the user can add
      // background image using CSS.
      } else {
        icon = '<img src="'+SC.BLANK_IMAGE_URL+'" alt="" class="icon '+icon+'" />';
      }
    }

    return icon + (SC.none(title) ? '' : title);
  }

});

/* >>>>>>>>>> BEGIN source/tasks/task.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  Represents a single task which can be run by a task queue. Note that tasks
  are actually allowed to add themselves back onto the queue if they did not/
  might not finish.
*/
SC.Task = SC.Object.extend({
  run: function(queue) {
    // if needed, you could put the task back on the queue for later finishing.
  }
});

/* >>>>>>>>>> BEGIN source/system/app_cache.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2012 7x7 Software, Inc.
// License:   Licensed under MIT license
// ==========================================================================
sc_require("tasks/task");


/** @private */
SC.AppCacheTask = SC.Task.extend({
  run: function () {
    window.applicationCache.update();
    SC.appCache._appCacheStatusDidChange();
  }
});


/** @class

  This is a very simple object that makes it easier to use the
  window.applicationCache in a SproutCore application.

  The reason this object exists is that SproutCore applications
  are excellent candidates for offline access but, it takes more than a little
  effort to understand the application cache's various possible states and
  events in order to use it effectively.

  You will likely find a use for SC.appCache in two scenarios.  The first is
  you want to ensure that your users are notified each time a new version of
  your application is deployed in order to ensure they get the latest version.
  Because of the manner in which the application cache works, a user may launch
  a previous version from the cache and not see the new version.  In this
  scenario, you would simply check the value of SC.appCache.get('hasNewVersion')
  at some point in your app's initialization cycle.  If hasNewVersion is true,
  you can then check SC.appCache.get('isNewVersionValid') to determine whether
  to show a message to the user informing them of the new version and reload
  the app or to log that the new version failed to upload so you can fix it.

  Note, because the application cache takes some time to determine if a new
  version exists, hasNewVersion may initially be `undefined`.  Therefore, you
  will likely want to add an observer to the property and continue on with
  your app.  By using an observer, you can also tap into another feature of
  SC.appCache, which is to lazily check for updates after the app is loaded.
  Typically, the browser only checks for updates on the initial load of a page,
  but by setting SC.appCache.set('shouldPoll', true), you can have SC.appCache
  check for updates in the background at a set interval.  Your observer will
  then fire if hasNewVersion ever changes while the app is in use.

  For example,

      // A sample application.
      MyApp = SC.Application.create({

        // Called when the value of SC.appCache.hasNewVersion changes.
        appCacheHasNewVersionDidChange: function () {
          var hasNewVersion = SC.appCache.get('hasNewVersion'),
            isNewVersionValid = SC.appCache.get('isNewVersionValid');

          if (hasNewVersion) {
            if (isNewVersionValid) {
              // Show a message to the user.
              MyApp.mainPage.get('newVersionAvailablePanel').append();
            } else {
              // There is a new version available, but it failed to load.
              SC.error('Failed to update application cache.');
            }

            // Clean up.
            SC.appCache.removeObserver('hasNewVersion', this, 'appCacheHasNewVersionDidChange');
          } else {
            // Start polling for new versions.  Because the observer is still attached,
            // appCacheHasNewVersionDidChange will be called if a new version ever becomes available.
            SC.appCache.set('shouldPoll', true);
          }

        }

      });

      // The loading state in our sample application.
      MyApp.LoadingState = SC.State.extend({

        enterState: function () {
          var hasNewVersion = SC.appCache.get('hasNewVersion');

          if (SC.none(hasNewVersion)) {
            // The application cache is either caching for the first time , updating or idle.
            // In either case we will observe it.
            SC.appCache.addObserver('hasNewVersion', MyApp, 'appCacheHasNewVersionDidChange');
          } else if (hasNewVersion) {
            // There is already a new version available, use our existing code to handle it.
            MyApp.appCacheHasNewVersionDidChange();
          } else {
            // There is no new version, but it's possible that one will appear.
            // User our existing code to start polling for new versions.
            MyApp.appCacheHasNewVersionDidChange();
            SC.appCache.addObserver('hasNewVersion', MyApp, 'appCacheHasNewVersionDidChange');
          }
        }

      });

  The second scenario is if you want to present a UI indicating when the app is
  ready for offline use.  Remember that it takes some time for the browser
  to retrieve all the resources in the manifest, so an app may be running for
  a while before it is ready for offline use.  In this scenario, you would
  observe the isReadyForOffline property of SC.appCache.

  Like hasNewVersion, isReadyForOffline has three possible values: undefined, true or false,
  where the property is undefined while the value is still undetermined.

  For example,

      // A sample view.
      MyApp.MyView = SC.View.extend({

        childView: ['offlineIndicatorCV'],

        // An image we use to indicate when the app is safe to use offline.
        offlineIndicatorCV: SC.ImageView.extend({
          valueBinding: SC.Binding.oneWay('SC.appCache.isReadyForOffline').
            transform(function (isReadyForOffline) {
              if (isReadyForOffline) {
                return 'offline-ready';
              } else if (SC.none(isReadyForOffline)) {
                return 'offline-unknown';
              } else {
                return 'offline-not-ready';
              }
            })
        })

      });

  The following are some excellent resources on the application cache that were
  used to develop this class:

  - [Using the application cache - HTML | MDN](https://developer.mozilla.org/en-US/docs/HTML/Using_the_application_cache)
  - [Appcache Facts](http://appcachefacts.info)
  - [Offline Web Applications - Dive Into HTML5](http://diveintohtml5.info/offline.html)

  @extends SC.Object
  @since Version 1.10
*/
SC.appCache = SC.Object.create(
/** @scope SC.appCache.prototype */{

  // ------------------------------------------------------------------------
  // Properties
  //

  /**
    Whether the new version is valid or not.

    This property is undefined until it can be determined that a new version exists
    or doesn't exist and if it does exist, whether it is valid or not.

    @field
    @type Boolean
    @default undefined
    @readonly
    */
  isNewVersionValid: function () {
    var hasNewVersion = this.get('hasNewVersion'),
      ret,
      status = this.get('status');

    if (SC.platform.supportsApplicationCache) {
      if (hasNewVersion) {
        if (status === window.applicationCache.UPDATEREADY) {
          ret = true;
        } else {
          ret = false;
        }
      } // Else we don't know yet.
    } else {
      // The platform doesn't support it, so it must always be false.
      ret = false;
    }

    return ret;
  }.property('hasNewVersion').cacheable(),

  /**
    Whether the application may be run offline or not.

    This property is undefined until it can be determined that the application
    has been cached or not cached.

    @field
    @type Boolean
    @default undefined
    @readonly
    */
  isReadyForOffline: function () {
    var ret,
      status = this.get('status');

    if (SC.platform.supportsApplicationCache) {
      if (status === window.applicationCache.IDLE ||
          status === window.applicationCache.UPDATEREADY) {
        ret = true;
      } else if (status === window.applicationCache.UNCACHED ||
          status === window.applicationCache.OBSOLETE) {
        ret = false;
      } // Else we don't know yet.
    } else {
      // The platform doesn't support it, so it must always be false.
      ret = false;
    }

    return ret;
  }.property('status').cacheable(),

  /**
    Whether there is a new version of the application's cache or not.

    This property is undefined until it can be determined that a new version exists
    or not.  Note that the new version may not necessarily be valid.  You
    should check isNewVersionValid after determining that hasNewVersion is
    true.

    @field
    @type Boolean
    @default undefined
    @readonly
    */
  hasNewVersion: function () {
    var ret,
      status = this.get('status');

    if (SC.platform.supportsApplicationCache) {
      if (status === window.applicationCache.UPDATEREADY ||
          status === window.applicationCache.OBSOLETE) {
        // It is only true if there is an update (which may have failed).
        ret = true;
      } else if (status === window.applicationCache.IDLE) {
        // It is only false if there was no update.
        ret = false;
      } // Else we don't know yet.
    } else {
      // The platform doesn't support it, so it must always be false.
      ret = false;
    }

    return ret;
  }.property('status').cacheable(),

  /**
    The interval in milliseconds to poll for updates when shouldPoll is true.

    @type Number
    @default 1800000 (30 minutes)
    */
  interval: 1800000,

  /**
    The progress of the application cache between 0.0 (0%) and 1.0 (100%).

    @type Number
    @default 0.0
    */
  progress: 0,

  /**
    Whether or not to regularly check for updates to the application cache
    while the application is running.

    This is useful for applications that are left open for several hours at a
    time, such as a SproutCore application being used in business.  In order to
    ensure that the users have the latest version, you can set this property
    to true to have the application regularly check for updates.

    Updates are run using the background task queue, so as to pose the smallest
    detriment possible to performance.

    @field
    @type Boolean
    @default false
    */
  shouldPoll: function (key, value) {
    if (SC.none(value)) {
      // Default value.
      value = false;
    } else if (value) {
      var status = this.get('status');
      if (status === window.applicationCache.IDLE) {
        // Start regularly polling for updates.
        this._timer = SC.Timer.schedule({
          target: this,
          action: '_checkForUpdates',
          interval: this.get('interval'),
          repeats: YES
        });
      } else {
        

      }
    } else {
      // Stop any previous polling.
      if (this._timer) {
        this._timer.invalidate();
        this._timer = null;
        this._task = null;
      }
    }

    return value;
  }.property().cacheable(),

  /**
    The current window.applicationCache status.

    This is a KVO mapping of window.applicationCache.status.  Possible values
    are:

    * window.applicationCache.UNCACHED
    * window.applicationCache.IDLE
    * window.applicationCache.CHECKING
    * window.applicationCache.DOWNLOADING
    * window.applicationCache.UPDATEREADY
    * window.applicationCache.OBSOLETE

    Because of the various interpretations these statuses can mean, you will
    likely find it easier to use the helper properties on SC.appCache instead.

    @type Number
    @default 0
    */
  status: 0,

  // ------------------------------------------------------------------------
  // Methods
  //

  /** @private */
  _appCacheDidProgress: function (evt) {
    evt = evt.originalEvent;
    if (evt.lengthComputable) {
      this.set('progress', evt.loaded / evt.total);
    } else {
      this.set('progress', null);
    }
  },

  /** @private */
  _appCacheStatusDidChange: function () {
    var appCache = window.applicationCache,
      status;

    status = appCache.status;

    // Clear all previous event listeners.
    SC.Event.remove(appCache);
    switch (status) {
    case appCache.UNCACHED: // UNCACHED == 0
      break;
    case appCache.IDLE: // IDLE == 1
      this.set('progress', 1);
      break;
    case appCache.CHECKING: // CHECKING == 2
      SC.Event.add(appCache, 'downloading', this, '_appCacheStatusDidChange');
      SC.Event.add(appCache, 'noupdate', this, '_appCacheStatusDidChange');
      SC.Event.add(appCache, 'error', this, '_appCacheStatusDidChange');
      break;
    case appCache.DOWNLOADING: // DOWNLOADING == 3
      SC.Event.add(appCache, 'progress', this, '_appCacheDidProgress');
      SC.Event.add(appCache, 'cached', this, '_appCacheStatusDidChange');
      SC.Event.add(appCache, 'updateready', this, '_appCacheStatusDidChange');
      SC.Event.add(appCache, 'error', this, '_appCacheStatusDidChange');
      break;
    case appCache.UPDATEREADY:  // UPDATEREADY == 4
      break;
    case appCache.OBSOLETE: // OBSOLETE == 5
      break;
    default:
      SC.error('Unknown application cache status: %@'.fmt(appCache.status));
      break;
    }

    // Update our status.
    this.set('status', status);
  },

  /** @private Adds a task to check for application updates to the background task queue. */
  _checkForUpdates: function () {
    var task = this._task;

    if (this.get('status') === window.applicationCache.IDLE) {
      if (!task) { task = this._task = SC.AppCacheTask.create(); }
      SC.backgroundTaskQueue.push(task);
    } else {
      // Stop polling if the status isn't IDLE.
      this.set('shouldPoll', false);
    }
  },

  /** @private */
  init: function () {
    arguments.callee.base.apply(this,arguments);

    if (SC.platform.supportsApplicationCache) {
      // By the time that this object is created, we may have already passed
      // out of the CHECKING state, but _appCacheStatusDidChange() will take care of it.
      this._appCacheStatusDidChange();
    } else {
      SC.warn('Unable to use SC.appCache, the browser does not support the application cache.');
    }
  }

});

/* >>>>>>>>>> BEGIN source/system/benchmark.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
/*globals $A */

/** @namespace

  This bit of meta-programming magic can install a benchmark handler on any
  object method.  When a benchmark is installed, the time required to execute
  the method will be printed to the console log every time the method is
  called.

  This class can be used to implement benchmarking.  To use this object, just
  call start() with a key name and end() with a keyname.  The benchmark will
  be logged.  If you set verbose = true, then benchmark will log every time it
  saves a bench.  Otherwise, it just keeps stats.  You can get the stats by
  calling report().

  Benchmark does not require anything other than the date.js class.  It also
  does not rely on SC.Object so that you can benchmark code in that area as
  well.

  The benchmark has three types of reports.

    - report(): Returns an abbreviated list with just the durations of the bench.
              Also, it averages multiple runs. Everything is reported on the top
              level only.
    - timelineReport(): Returns an list of benchmarks and sub-benchmarks. If the
                      the globalStartTime is set, then it will show relative
                      time from that time.
    - timelineChart(): Displays a chart of all the benchmarks (not sub-benchmarks)
                     relative to the first time capture or to the globalStartTime.
                     Hide this by calling hideChart()

  @since SproutCore 1.0
*/
SC.Benchmark = {

  /**
    If true, then benchmarks will be logged to the console as they are
    recorded.

    @type Boolean
    @default NO
  */
  verbose: NO,

  /**
    If false, benchmarking will be disabled.  You might want to disable this
    during production to maximize performance.

    @type Boolean
    @default YES
  */
  enabled: YES,

  /**
    Events are a way of assigning specific, individual times to names, rather than
    durations of time. A benchmark event can only occur once—if it occurs again, it
    will overwrite the old event.

    The purpose of events is different than the purpose for normal benchmarks. Normal
    benchmarks may be used to benchmark a specific process, and may do so repeatedly;
    events, conversely, are usually used to benchmark things like startup time, and
    occur only once. For instance, an 'event' is registered when the document is ready.

    Events are kept as a hash of names to timestamps. To add an event, just set it:

        SC.Benchmark.events['myEventName'] = new Date().getTime();

        // Or, more conveniently:
        SC.Benchmark.addEvent('myEventName', [optional time]);

    On a timeline chart, events are usually represented as lines rather than bars. However,
    if you add eventNameStart and eventNameEnd, they will be automatically added as standard
    benchmarks.

    This is useful when adding preload events to SC.benchmarkPreloadEvents; as SC.Benchmark
    does not yet exist, you cannot call .start() and .end(), but adding the items to
    SC.benchmarkPreloadEvents will ensure they are included.

    @type Object
    @default {}
  */
  events: {},

  /**
    This hash stores collected stats.  It contains key value pairs.  The value
    will be a hash with the following properties:

      - *runs*: the number of times this stat has run
      - *amt*: the total time consumed by this (divide by runs to get avg)
      - *name*: an optional longer name you assigned to the stat key.  Set this  using name().

    @type Object
    @default {}
  */
  stats: {},

  /**
    If set, one can tell when the benchmark is started relatively to the global start time.

    This property is set to a default automatically (from HTML5 NavigationTiming if possible,
    otherwise the SC bootstrap).

    @type Number
    @default null
  */
  globalStartTime: null,

  /**
    Adds an 'event' to the events hash.

    Unlike normal benchmarks, recorded with start/end and that represent a block of time,
    events represent a single instance in time. Further, unlike normal benchmarks, which
    may be run more than once for the same benchmark name, only one instance in time
    will be recorded for any event name.

    @param {String} name
      A name that identifies the event. If addEvent is called again with the same name,
      the previous call's timestamp will be overwritten.
    @param {Number} time
      Optional. The timestamp to record for the event.
  */
  addEvent: function(name, time) {
    if (!time) time = new Date().getTime();
    this.events[name] = time;
  },

  /**
    Call this method at the start of whatever you want to collect.
    If a parentKey is passed, then you will attach the stat to the parent,
    otherwise it will be on the top level. If topLevelOnly is passed, then
    recursive calls to the start will be ignored and only the top level call
    will be benchmarked.

    @param {String} key
      A unique key that identifies this benchmark.  All calls to start/end
      with the same key will be groups together.
    @param {String} parentKey
      A unique key that identifies the parent benchmark.  All calls to
      start/end with the same key will be groups together.
    @param {Number} time
      Only pass if you want to explicitly set the start time.  Otherwise the
      start time is now.
    @param {Boolean} topLevelOnly
      If true then recursive calls to this method with the same key will be
      ignored.
    @returns {String} the passed key
  */
  start: function(key, parentKey, time, topLevelOnly) {
    var start,
        stat;

    if (this.enabled) {
      start = time || Date.now();

      if (parentKey) stat = this._subStatFor(key, parentKey);
      else stat = this._statFor(key);

      if (stat) {
        if (topLevelOnly && stat._starts.length > 0) stat._starts.push('ignore');
        else stat._starts.push(start);

        stat._times.push({ start: start, _subStats: {} });
      }
    }
    return key;
  },

  /**
    Call this method at the end of whatever you want to collect.  This will
    save the collected benchmark.

    @param {String} key
      The benchmark key you used when you called start()
    @param {String} parentKey
      The benchmark parent key you used when you called start()
    @param {Number} time
      Only pass if you want to explicitly set the end time.  Otherwise start
      time is now.
  */
  end: function(key, parentKey, time) {
    var stat,
        start,
        end,
        dur;

    if (!this.enabled) { return; }

    if (parentKey) {
      stat = this._subStatFor(key, parentKey);
    } else {
      stat = this._statFor(key);
    }

    if (stat && stat._starts.length) {
      start = stat._starts.pop();

      // top level only.
      if (start !== 'ignore') {
        end = (time || Date.now());
        dur = end - start;

        stat._times[stat._times.length-1].end = end;
        stat._times[stat._times.length-1].dur = dur;

        stat.amt += dur;
        stat.runs++;

        if (this.verbose) { this.log(key); }
      }
    } else {
      SC.Logger.log('SC.Benchmark "%@" ended without a matching start.  No information was saved.'.fmt(key));
    }
  },

  /**
    Set the inital global start time.

    @param {Number} time global start time
  */
  setGlobalStartTime: function(time) {
    this.globalStartTime = time;
  },

  /**
    This is a simple way to benchmark a function.  The function will be
    run with the name you provide the number of times you indicate.  Only the
    function is a required param.

    @param {Function} func function to benchmark
    @param {String} [key] benchmark key
    @param {Number} [reps] how many times to run the function
    @returns {*} Most recent return value from func
  */
  bench: function(func, key, reps) {
    var ret;
    if (!key) { key = "bench%@".fmt(this._benchCount++); }
    if (!reps) { reps = 1; }

    while (--reps >= 0) {
      SC.Benchmark.start(key);
      ret = func();
      SC.Benchmark.end(key);
    }

    return ret ;
  },

  /**
    Install a wrapper around a method to benchmark it whenever it is run.

    @param {Object} object target object to install on
    @param {String} method name of the method on object
    @param {Boolean} topLevelOnly should recursive calls to this method
                                  with the same key will be ignored
  */
  install: function(object, method, topLevelOnly) {
    // save the original method.
    var fn = object['b__' + method] = object[method],
        join = Array.prototype.join;

    // replace with this helper.
    object[method] = function() {
      var key = '%@(%@)'.fmt(method, join.call(arguments, ', ')),
          ret;
      SC.Benchmark.start(key, null, null, topLevelOnly);
      ret = fn.apply(this, arguments);
      SC.Benchmark.end(key);
      return ret;
    };
  },

  /**
    Restore the original method, deactivating the benchmark.

    @param {Object} object the object to change
    @param {String} method the method name as a string
  */
  restore: function(object, method) {
    object[method] = object['b__' + method];
  },

  /**
    This method will return a string containing a report of the stats
    collected so far.  If you pass a key, only the stats for that key will
    be returned.  Otherwise, all keys will be used.
  */
  report: function(key) {
    if (key) return this._genReport(key) ;
    var ret = [] ;
    for(var k in this.stats) {
      if (!this.stats.hasOwnProperty(k)) continue ;
      ret.push(this._genReport(k)) ;
    }
    return ret.join("\n") ;
  },

  /**
    Generate a human readable benchmark report. Pass in appName if you desire.

    @param {String} application name.
  */
  timelineReport: function(appName) {
    appName = (appName) ? 'SproutCore Application' : appName;
    var ret = [appName, 'User-Agent: %@'.fmt(navigator.userAgent), 'Report Generated: %@ (%@)'.fmt(new Date().toString(), Date.now()), ''] ;

    var chart = this._compileChartData(true);
    for(var i=0; i<chart.length; i++)
    {
      if(chart[i][4])
      {
        ret.push(this._timelineGenSubReport(chart[i]));
      }
      else
      {
        ret.push(this._timelineGenReport(chart[i]));
      }
    }
    return ret.join("\n") ;
  },

  /**
    Returns a hash containing the HTML representing the timeline chart, and
    various metrics and information about the chart:

        - html
        - totalWidth
        - totalHeight
        - totalCapturedTime
        - pointsCaptured

    @returns {Hash}
  */
  getTimelineChartContent: function() {
    // Compile the data.
    var chart = this._compileChartData(false);
    var chartLen = chart.length;

    // Return if there is nothing to draw.
    if(chartLen === 0) return;

    // Get the global start of the graph.
    var gStart = this.globalStartTime ? this.globalStartTime : chart[0][1];
    var maxDur = chart[chartLen-1][2]-gStart;
    var maxHeight = 25+chartLen*30;
    var incr = Math.ceil(maxDur/200)+1;
    var maxWidth = incr*50;
    var leftPadding = 10, rightPadding = 300;


    var str = "<div class = 'sc-benchmark-timeline-chart' style = 'position:relative;'>";
    str += "<div class = 'sc-benchmark-top'></div>";

    // add tick marks
    for (var i = 0; i < incr; i++) {
      str += "<div class = 'sc-benchmark-tick' style = '";
      str += "left: " + (leftPadding + i * 50) + "px; ";
      str += "height: " + maxHeight + "px;";
      str += "'></div>";

      str += "<div class = 'sc-benchmark-tick-label' style = '";
      str += "left: " + (leftPadding + i * 50) + "px; ";
      str += "'>" + (i * 200) + "ms</div>";
    }

    // print each chart item
    for (i = 0; i < chartLen; i++) {
      str += "<div class = 'sc-benchmark-row ";
      str += (i % 2 === 0) ? 'even' : 'odd';
      str += "' style = '";
      str += "top: " + (50 + (i * 30)) + "px; ";
      str += "'></div>";

      var div = document.createElement('div');
      var start = chart[i][1];
      var end = chart[i][2];
      var duration = chart[i][3];


      str += "<div class = 'sc-benchmark-bar' style = '";
      str += 'left:'+ (leftPadding + ((start-gStart)/4))+'px; width: '+((duration/4)) + 'px;';
      str += 'top: '+(28+(i*30))+'px;';

      str += "' title = 'start: " + (start-gStart) + " ms, end: " + (end-gStart) + ' ms, duration: ' + duration + " ms'";
      str += ">";
      str += '&nbsp;' + chart[i][0] + " <span class='sc-benchmark-emphasis'>";
      str += duration + "ms (start: " + (start - gStart) + "ms)";
      str += "</span>";

      str += "</div>";
    }

    // add the events
    var events = this.events, idx = 0;
    for (i in events) {
      var t = events[i] - gStart;
      str += "<div class = 'sc-benchmark-event idx" + (idx % 10) + "' style = '";
      str += "left: " + (leftPadding + t / 4) + "px; height: " + maxHeight + "px; top: 20px;";
      str += "' title = '" + i + ": " + t + "'></div>";
      idx++;
    }

    str += "</div>";

    return {
      html: str,
      totalCapturedTime: maxDur,
      pointsCaptured: chartLen,
      width: maxWidth + leftPadding + rightPadding,
      height: maxHeight
    };
  },

  /**
    Returns a view with the timeline chart. The view has a 'reload' method to
    refresh its data.

    @returns {SC.View}
  */
  getTimelineChartView: function() {
    var view = SC.ScrollView.create({
      contentView: SC.StaticContentView.extend({

      }),

      reload: function() {
        var content = SC.Benchmark.getTimelineChartContent();
        this.contentView.set('content', content.html);
        this.contentView.adjust({
          width: content.width,
          height: content.height
        });

        this.chartContent = content;

        SC.RunLoop.invokeLater(SC.Benchmark, function() {
          this.contentView.notifyPropertyChange('frame');
        });
      }
    });

    view.reload();

    return view;
  },

  /**
    Generate a human readable benchmark chart. Pass in appName if you desire.
  */
  timelineChart: function(appName) {
    SC.RunLoop.begin();

    var i=0;
    // Hide the chart if there is an existing one.
    this.hideChart();

    // Compile the data.
    var chartView = this.getTimelineChartView();
    var chartLen = chartView.chartContent.pointsCaptured,
        chartCapturedTime = chartView.chartContent.totalCapturedTime;

    // Get the global start of the graph.

    this._benchmarkChart = SC.Pane.create({
      classNames: ["sc-benchmark-pane"],
      layout: { left: 20, right: 20, bottom: 20, top: 20 },
      childViews: ["title", "exit"],
      exit: SC.ButtonView.extend({
        layout: { right: 20, top: 20, width: 100, height: 30 },
        title: "Hide Chart",
        target: this,
        action: "hideChart"
      }),

      title: SC.LabelView.extend({
        classNames: ['sc-benchmark-title'],
        layout: { left: 20, top: 23, right: 200, height: 30 },
        value: ((appName) ? appName : 'SproutCore Application') + (' - Total Captured Time: ' + chartCapturedTime +' ms - Points Captured: ' + chartLen)
      })

    }).append();

    chartView.set('layout', { left: 20, top: 60, bottom: 20, right: 20 });
    this._benchmarkChart.appendChild(chartView);

    SC.RunLoop.end();
  },

  /*
    Hide chart.
  */
  hideChart: function() {
    if (this._benchmarkChart) {
      this._benchmarkChart.remove();
      this._benchmarkChart = null;
    }

    return YES;
  },

  /** @private
    Because we show a pane to display the chart...
  */
  tryToPerform: function(action, sender) {
    if (this[action]) return this[action](sender);
    return NO;
  },

  /**
    This method is just like report() except that it will log the results to
    the console.
  */
  log: function(key) {
    // log each line to make this easier to read on an iPad
    var lines = this.report(key).split('\n'),
        len   = lines.length, idx;
    for(idx=0;idx<len;idx++) SC.Logger.log(lines[idx]);
  },

  /**
    This will activate profiling if you have Firebug installed.  Otherwise
    does nothing.
  */
  startProfile: function(key) {
    if (!this.enabled) return ;
    SC.Logger.profile(key) ;
  },

  endProfile: function(key) {
    if (!this.enabled) return ;
    SC.Logger.profileEnd(key) ;
  },


  // ..........................................................
  // Internal Support
  //

  /** @private
    Loads data from both the browser's own event hash and SC's pre-load event hash.
  */
  loadPreloadEvents: function() {
    var preloadEvents = SC.benchmarkPreloadEvents, events = [], idx, len, evt;

    // the browsers may have their own event hash. Ours uses the same format, so
    // all that we need to do is mixin the browser's to our own.
    if (typeof webkitPerformance !== 'undefined') SC.mixin(preloadEvents, webkitPerformance.timing);

    // we will attempt to find when the loading started and use that as our
    // global start time, but only do so if the global start time is not already set.
    if (!this.globalStartTime) {
      // the potential events representing start time can be either from the browser
      // or our own recordings. We prefer the browser.
      var globalStartEvents = ['navigation', 'navigationStart', 'headStart'];
      len = globalStartEvents.length;

      for (idx = 0; idx < len; idx++) {
        if (preloadEvents[globalStartEvents[idx]]) {
          this.globalStartTime = preloadEvents[globalStartEvents[idx]];
          break;
        }
      }
    }

    // the JavaScript start time will be one recorded by us
    // we record headStart in bootstrap.
    this.javascriptStartTime = preloadEvents['headStart'];

    // finally, mix in the events to our own events hash
    SC.mixin(this.events, preloadEvents);

    this._hasLoadedPreloadEvents = true;
  },

  /** @private
    Some events represent a beginning and end. While this is not common for events
    that take place after the app loads (as they can just use SC.Benchmark.start/end),
    SC.Benchmark.start/end is not available before load—as such, code will add
    *Start and *End events to the event hash.

    This method iterates over the event hash and removes those items that represent
    starts and ends, calling .start/.end for them.
  */
  _loadBenchmarksFromEvents: function() {
    if (!this._hasLoadedPreloadEvents) this.loadPreloadEvents();

    var events = this.events;
    for (var i in events) {
      if (i.substr(-3) !== 'End') continue;

      var stem = i.substr(0, i.length - 3);
      if (!events[stem + 'Start']) continue;

      SC.Benchmark.start(stem, undefined, events[stem + 'Start']);
      SC.Benchmark.end(stem, undefined, events[stem + 'End']);

      delete events[stem + 'Start'];
      delete events[stem + 'End'];
    }
  },

  /** @private
    Generates, sorts, and returns the array of all the data that has been captured.
  */
  _compileChartData: function(showSub) {
    this._loadBenchmarksFromEvents();

    var chart = [], dispKey;
    for(var key in this.stats)
    {
      var stat = this.stats[key];
      for(var i=0; i<stat._times.length; i++)
      {
        var st = stat._times[i];
        dispKey = (stat._times.length > 1) ? (i+1)+' - '+key : key;
        chart.push([dispKey, st.start, st.end, st.dur, false]);
        if(showSub)
        {
          var subStats = st._subStats;
          for(var k in subStats)
          {

            var subStat = subStats[k];
            for(var j=0; j<subStat._times.length; j++)
            {
              var s = subStat._times[j];
              dispKey = (subStat._times.length > 1) ? (j+1)+' - '+k : k;
              chart.push([dispKey, s.start, s.end, s.dur, true]);

            }
          }
        }
      }
    }

    chart.sort(function(a,b)
    {
      if(a[1] < b[1])
      {
        return -1;
      }
      else if(a[1] == b[1])
      {
        if(a[3] && !b[3]) return -1;
        if(!a[3] && b[3]) return 1;
        return 0;
      }
      return 1;
    });

    return chart;
  },

  // Generate the traditional report show multiple runs averaged.
  /** @private */
  _genReport: function(key) {
    var stat = this._statFor(key),
        avg = (stat.runs > 0) ? (Math.floor(stat.amt * 1000 / stat.runs) / 1000) : 0,
        last,
        ret;

    if (stat._times.length) {
      last = stat._times[stat._times.length - 1];
      ret = 'BENCH %@ msec: %@ (%@x); latest: %@'.fmt(avg, (stat.name || key), stat.runs, last.end - last.start);
    } else {
      ret = 'No information for SC.Benchmark "%@".'.fmt(key);
    }

    return ret;
  },

  // Generate the report in the form of at time line. This returns the parent.
  /** @private */
  _timelineGenReport: function(val)
  {
    if(this.globalStartTime)
    {
      return 'BENCH start: %@ msec, duration: %@ msec,  %@'.fmt((val[1]-this.globalStartTime), val[3], val[0]) ;
    }
    else
    {
      return 'BENCH duration: %@ msec, %@'.fmt( val[3],  val[0]) ;
    }
  },

  // Generate the report in the form of at time line. This returns the children.
  /** @private */
  _timelineGenSubReport: function(val)
  {
    if(this.globalStartTime)
    {
      return '   CHECKPOINT BENCH start: %@ msec, duration: %@ msec,  %@'.fmt((val[1]-this.globalStartTime), val[3], val[0]) ;
    }
    else
    {
      return '   CHECKPOINT BENCH duration: %@ msec, %@'.fmt( val[3], val[0]) ;
    }
  },

  // returns a stats hash for the named key and parent key.  If the hash does not exist yet,
  // creates it.
  /** @private */
  _subStatFor: function(key, parentKey) {
    var parentStat = this.stats[parentKey],
        parentTimeLen = parentStat ? parentStat._times.length : 0,
        parentSubStats,
        ret;

    if (!parentTimeLen) { return; }
    parentSubStats = parentStat._times[parentTimeLen - 1]._subStats;
    ret = parentSubStats[key];
    if (!ret) {
      ret = parentSubStats[key] = {
        runs: 0, amt: 0, name: key, _starts: [], _times: []
      };
    }

    return ret ;
  },

  // returns a stats hash for the named key.  If the hash does not exist yet,
  // creates it.
  /** @private */
  _statFor: function(key) {
    var ret = this.stats[key];
    if (!ret) {
      ret = this.stats[key] = {
        runs: 0, amt: 0, name: key, _starts: [], _times: []
      };
    }
    return ret;
  },

  /** @private */
  reset: function() { this.stats = {} ; },

  // This is private, but it is used in some places, so we are keeping this for
  // compatibility.
  /** @private */
  _bench: function(func, name) {
    SC.Benchmark.bench(func, name, 1) ;
  },

  /** @private */
  _benchCount: 1

} ;

SC.Benchmark = SC.Benchmark;

/* >>>>>>>>>> BEGIN source/system/cookie.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


/** @class

  Allows for easier handling of the document.cookie object. To create a cookie,
  simply call SC.Cookie.create. To retrieve a cookie, use SC.Cookie.find.
  Cookies are not added to document.cookie, which SC.Cookie.find uses, until you
  have called SC.Cookie#write.

  Heavy inspiration from the
  {@link <a href="http://plugins.jquery.com/project/cookie">jQuery cookie plugin</a>}.

  @extends SC.Object
  @since Sproutcore 1.0
  @author Colin Campbell
*/

SC.Cookie = SC.Object.extend(
/** @scope SC.Cookie.prototype */{

  // ..........................................................
  // PROPERTIES
  //

  /**
    @type String
    @default null
  */
  name: null,

  /**
    @type String
    @default ''
  */
  value: '',

  /**
    Amount of time until the cookie expires. Set to -1 in order to delete the cookie.

    If passing an Integer, it is interpreted as a number of days.

    @type Integer|SC.DateTime|Date
    @default null
  */
  expires: null,

  /**
    @type String
    @deafult null
  */
  path: null,

  /**
    @type String
    @default null
  */
  domain: null,

  /**
    If true, the secure attribute of the cookie will be set and the cookie transmission will
    require a secure protocol (like HTTPS).

    @type Boolean
    @default NO
  */
  secure: NO,

  /**
    Walk like a duck

    @type Boolean
    @default YES
    @readOnly
  */
  isCookie: YES,


  // ..........................................................
  // METHODS
  //

  /**
    Sets SC.Cookie#expires to -1, which destroys the cookie.
  */
  destroy: function() {
    this.set('expires', -1);
    this.write();

    arguments.callee.base.apply(this,arguments);
  },

  /**
    Writes this SC.Cookie to document.cookie and adds it to SC.Cookie collection. To find this
    cookie later, or on reload, use SC.Cookie.find.

    @see SC.Cookie.find
  */
  write: function() {
    var name = this.get('name'),
        value = this.get('value'),
        expires = this.get('expires'),
        path = this.get('path'),
        domain = this.get('domain'),
        secure = this.get('secure'),
        output = '',
        date;

    if (expires) {
      if (typeof expires === SC.T_NUMBER) {
        date = new Date();
        date.setTime(date.getTime() + (expires*24*60*60*1000));
      } else if (SC.DateTime && expires.get && expires.get('milliseconds')) {
        date = new Date(expires.get('milliseconds'));
      } else if (expires.toUTCString && expires.toUTCString.apply) {
        date = expires;
      }

      if (date) output = "; expires=" + date.toUTCString();
    }

    if (!SC.none(path)) output += '; path=' + path;
    if (!SC.none(domain)) output += '; domain=' + domain;
    if (secure === YES) output += '; secure';

    document.cookie = name + "=" + encodeURIComponent(value) + output;

    return this;
  }

});

SC.Cookie.mixin(
  /** @scope SC.Cookie */ {

  /**
    Finds a cookie that has been stored

    @param {String} name The name of the cookie
    @returns SC.Cookie object containing name and value of cookie
  */
  find: function(name) {
    if (document.cookie && document.cookie !== '') {
      var cookies = document.cookie.split(';');
      for (var i = 0; i < cookies.length; i++) {
        var cookie = SC.String.trim(String(cookies[i]));
        if (cookie.substring(0, name.length + 1) === (name + "=")) {
          return SC.Cookie.create({
            name: name,
            value: decodeURIComponent(cookie.substring(name.length + 1))
          });
        }
      }
    }
    return null;
  }

});

SC.CookieMonster = {
  nomNomNom: function(cookie) {
    var isCookie = SC.kindOf(cookie, SC.Cookie);
    if (isCookie) {
      SC.Logger.log("YUM!");
      return cookie.destroy();
    }
    
    SC.Logger.error("Y U PASS ME NO COOKIE? %@", cookie);
    return NO;
  }
};
/* >>>>>>>>>> BEGIN source/system/core_query.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

 SC.mixin(SC.$.fn, /** @scope SC.$.prototype */ {

  /**
    You can either pass a single class name and a boolean indicating whether
    the value should be added or removed, or you can pass a hash with all
    the class names you want to add or remove with a boolean indicating
    whether they should be there or not.

    This is far more efficient than using addClass/removeClass.

    @param {String|Hash} className class name or hash of classNames + bools
    @param {Boolean} shouldAdd for class name if a string was passed
    @returns {SC.CoreQuery} receiver
  */
  setClass: function(className, shouldAdd) {
    if (SC.none(className)) { return this; } //nothing to do
    var isHash = SC.typeOf(className) !== SC.T_STRING,
        fix = this._fixupClass, key;

    this.each(function() {
      if (this.nodeType !== 1) { return; } // nothing to do

      // collect the class name from the element and build an array
      var classNames = this.className.split(/\s+/), didChange = NO;

      // loop through hash or just fix single className
      if (isHash) {
        for(var key in className) {
          if (className.hasOwnProperty(key)) {
            didChange = fix(classNames, key, className[key]) || didChange;
          }
        }
      } else {
        didChange = fix(classNames, className, shouldAdd);
      }

      // if classNames were changed, join them and set...
      if (didChange) { this.className = classNames.join(' '); }
    });
    return this ;
  },

  /** @private used by setClass */
  _fixupClass: function(classNames, name, shouldAdd) {
    var indexOf = classNames.indexOf(name);
    // if should add, add class...
    if (shouldAdd) {
      if (indexOf < 0) { classNames.push(name); return YES ; }

    // otherwise, null out class name (this will leave some extra spaces)
    } else if (indexOf >= 0) { classNames[indexOf]=null; return YES; }
    return NO ;
  }


});

/* >>>>>>>>>> BEGIN source/system/exception_handler.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @namespace

  If an exception is thrown during execution of your SproutCore app, this
  object will be given the opportunity to handle it.

  By default, a simple error message is displayed prompting the user to
  reload. You could override the handleException method to, for example, send
  an XHR to your servers so you can collect information about crashes in your
  application.

  Since the application is in an unknown state when an exception is thrown, we
  rely on JavaScript and DOM manipulation to generate the error instead of
  using SproutCore views.

  @since SproutCore 1.5
*/
SC.ExceptionHandler = {

  /** @private */
  enabled: (SC.buildMode !== 'debug'),

  /**
    Called when an exception is encountered by code executed using SC.run().

    By default, this will display an error dialog to the user. If you
    want more sophisticated behavior, override this method.

    @param {Exception} exception the exception thrown during execution
  */
  handleException: function(exception) {
    if (this.isShowingErrorDialog) return NO;
    
    this._displayErrorDialog(exception);
    
    return NO;
  },

  /** @private
    Creates the error dialog and appends it to the DOM.

    @param {Exception} exception the exception to display
  */
  _displayErrorDialog: function(exception) {
    var html = this._errorDialogHTMLForException(exception),
        node = document.createElement('div');

    node.style.cssText = "left: 0px; right: 0px; top: 0px; bottom: 0px; position: absolute; background-color: white; background-color: rgba(255,255,255,0.6); z-index:100;";
    node.innerHTML = html;

    document.body.appendChild(node);

    this.isShowingErrorDialog = YES;
  },

  /** @private
    Given an exception, returns the HTML for the error dialog.

    @param {Exception} exception the exception to display
    @returns {String}
  */
  _errorDialogHTMLForException: function(exception) {
    var html;

    html = [
'<div id="sc-error-dialog" style="position: absolute; width: 500px; left: 50%; top: 50%; margin-left: -250px; background-color: white; border: 1px solid black; font-family: Monaco, monospace; font-size: 9px; letter-spacing: 1px; padding: 10px">',
  'An error has occurred which prevents the application from running:',
  '<br><br>',
  exception.message,
  '<div id="sc-error-dialog-reload-button" onclick="window.location.reload();" style="float: right; font-family: Monaco, monospace; font-size: 9px; letter-spacing: 1px; border: 1px solid black; padding: 3px; clear: both; margin-top: 20px; cursor: pointer;">',
  'Reload',
  '</div>',
'</div>'
    ];

    return html.join('');
  },

  /**
    YES if an exception was thrown and the error dialog is visible.

    @type Boolean
    @default NO
  */
  isShowingErrorDialog: NO
};
/* >>>>>>>>>> BEGIN source/system/image_queue.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

SC.IMAGE_ABORTED_ERROR = SC.$error("SC.Image.AbortedError", "Image", -100) ;

SC.IMAGE_FAILED_ERROR = SC.$error("SC.Image.FailedError", "Image", -101) ;

/**
  @class
  
  The image queue can be used to control the order of loading images.
  
  Images queues are necessary because browsers impose strict limits on the 
  number of concurrent connections that can be open at any one time to any one 
  host. By controlling the order and timing of your loads using this image 
  queue, you can improve the percieved performance of your application by 
  ensuring the images you need most load first.
  
  Note that if you use the SC.ImageView class, it will use this image queue 
  for you automatically.
  
  ## Loading Images
  
  When you need to display an image, simply call the loadImage() method with 
  the URL of the image, along with a target/method callback. The signature of 
  your callback should be:
  
      imageDidLoad: function(imageUrl, imageOrError) {
        //...
      }

  The "imageOrError" parameter will contain either an image object or an error 
  object if the image could not be loaded for some reason.  If you receive an 
  error object, it will be one of SC.IMAGE_ABORTED_ERROR or 
  SC.IMAGE_FAILED_ERROR.
  
  You can also optionally specify that the image should be loaded in the 
  background.  Background images are loaded with a lower priority than 
  foreground images.
  
  ## Aborting Image Loads
  
  If you request an image load but then no longer require the image for some 
  reason, you should notify the imageQueue by calling the releaseImage() 
  method.  Pass the URL, target and method that you included in your original 
  loadImage() request.  
  
  If you have requested an image before, you should always call releaseImage() 
  when you are finished with it, even if the image has already loaded.  This 
  will allow the imageQueue to properly manage its own internal resources.
  
  This method may remove the image from the queue of images that need or load 
  or it may abort an image load in progress to make room for other images.  If 
  the image is already loaded, this method will have no effect.
  
  ## Reloading an Image
  
  If you have already loaded an image, the imageQueue will avoid loading the 
  image again.  However, if you need to force the imageQueue to reload the 
  image for some reason, you can do so by calling reloadImage(), passing the 
  URL.
  
  This will cause the image queue to attempt to load the image again the next 
  time you call loadImage on it.
  
  @extends SC.Object
  @since SproutCore 1.0
*/
SC.imageQueue = SC.Object.create(/** @scope SC.imageQueue.prototype */ {

  /**
    The maximum number of images that can load from a single hostname at any
    one time.  For most browsers 4 is a reasonable number, though you may 
    tweak this on a browser-by-browser basis.
  */
  loadLimit: 4,
  
  /**
    The number of currently active requests on the queue. 
  */
  activeRequests: 0,
  
  /**
    Loads an image from the server, calling your target/method when complete.
    
    You should always pass at least a URL and optionally a target/method.  If 
    you do not pass the target/method, the image will be loaded in background 
    priority.  Usually, however, you will want to pass a callback to be 
    notified when the image has loaded.  Your callback should have a signature 
    like:

        imageDidLoad: function(imageUrl, imageOrError) { .. }

    If you do pass a target/method you can optionally also choose to load the 
    image either in the foreground or in the background.  The imageQueue 
    prioritizes foreground images over background images.  This does not impact 
    how many images load at one time.
    
    @param {String} url
    @param {Object} target
    @param {String|Function} method
    @param {Boolean} isBackgroundFlag
    @returns {SC.imageQueue} receiver
  */
  loadImage: function(url, target, method, isBackgroundFlag) {
    // normalize params
    var type = SC.typeOf(target);
    if (SC.none(method) && SC.typeOf(target)===SC.T_FUNCTION) {
      target = null; method = target ;
    }
    if (SC.typeOf(method) === SC.T_STRING) {
      method = target[method];      
    }
    // if no callback is passed, assume background image.  otherwise, assume
    // foreground image.
    if (SC.none(isBackgroundFlag)) {
      isBackgroundFlag = SC.none(target) && SC.none(method);
    }
    
    // get image entry in queue.  If entry is loaded, just invoke callback
    // and quit.
    var entry = this._imageEntryFor(url) ;
    if (entry.status === this.IMAGE_LOADED) {
      if (method) method.call(target || entry.image, entry.url, entry.image);
      
    // otherwise, add to list of callbacks and queue image.
    } else {
      if (target || method) this._addCallback(entry, target, method);
      entry.retainCount++; // increment retain count, regardless of callback
      this._scheduleImageEntry(entry, isBackgroundFlag);
    }
  },
  
  /**
    Invoke this method when you are finished with an image URL.  If you 
    passed a target/method, you should also pass it here to remove it from
    the list of callbacks.
    
    @param {String} url
    @param {Object} target
    @param {String|Function} method
    @returns {SC.imageQueue} receiver
  */
  releaseImage: function(url, target, method) {
    // get entry.  if there is no entry, just return as there is nothing to 
    // do.
    var entry = this._imageEntryFor(url, NO) ;
    if (!entry) return this ;
    
    // there is an entry, decrement the retain count.  If <=0, delete!
    if (--entry.retainCount <= 0) {
      this._deleteEntry(entry); 
    
    // if >0, just remove target/method if passed
    } else if (target || method) {
      // normalize
      var type = SC.typeOf(target);
      if (SC.none(method) && SC.typeOf(target)===SC.T_FUNCTION) {
        target = null; method = target ;
      }
      if (SC.typeOf(method) === SC.T_STRING) {
        method = target[method];      
      }

      // and remove
      this._removeCallback(entry, target, method) ;
    }
  },

  /** 
    Forces the image to reload the next time you try to load it.
  */
  reloadImage: function(url) {
    var entry = this._imageEntryFor(url, NO); 
    if (entry && entry.status===this.IMAGE_LOADED) {
      entry.status = this.IMAGE_WAITING;
    }
  },
  
  /**
    Initiates a load of the next image in the image queue.  Normally you will
    not need to call this method yourself as it will be initiated 
    automatically when the queue becomes active.
  */
  loadNextImage: function() {
    var entry = null, queue;

    // only run if we don't have too many active request...
    if (this.get('activeRequests')>=this.get('loadLimit')) return; 
    
    // first look in foreground queue
    queue = this._foregroundQueue ;
    while(queue.length>0 && !entry) entry = queue.shift();
    
    // then look in background queue
    if (!entry) {
      queue = this._backgroundQueue ;
      while(queue.length>0 && !entry) entry = queue.shift();
    }
    this.set('isLoading', !!entry); // update isLoading...
    
    // if we have an entry, then initiate an image load with the proper 
    // callbacks.
    if (entry) {
      // var img = (entry.image = new Image()) ;
      var img = entry.image ;
      if(!img) return;

      // Using bind here instead of setting onabort/onerror/onload directly
      // fixes an issue with images having 0 width and height
      $(img).bind('abort', this._imageDidAbort);
      $(img).bind('error', this._imageDidError);
      $(img).bind('load', this._imageDidLoad);
      img.src = entry.url ;
      
      // add to loading queue.
      this._loading.push(entry) ;
    
      // increment active requests and start next request until queue is empty
      // or until load limit is reached.
      this.incrementProperty('activeRequests');
      this.loadNextImage();
    } 
  },
  
  // ..........................................................
  // SUPPORT METHODS
  // 

  /** @private Find or create an entry for the URL. */
  _imageEntryFor: function(url, createIfNeeded) {
    if (createIfNeeded === undefined) createIfNeeded = YES;
    var entry = this._images[url] ;
    if (!entry && createIfNeeded) {
      var img = new Image() ;
      entry = this._images[url] = { 
        url: url, status: this.IMAGE_WAITING, callbacks: [], retainCount: 0, image: img
      };
      img.entry = entry ; // provide a link back to the image
    } else if (entry && entry.image === null) {
    	// Ensure that if we retrieve an entry that it has an associated Image,
    	// since failed/aborted images will have had their image property nulled.
    	entry.image = new Image();
    	entry.image.entry = entry;
    }
    return entry ;
  },
  
  /** @private deletes an entry from the image queue, descheduling also */
  _deleteEntry: function(entry) {
    this._unscheduleImageEntry(entry) ;
    delete this._images[entry.url];    
  },
  
  /** @private 
    Add a callback to the image entry.  First search the callbacks to make
    sure this is only added once.
  */
  _addCallback: function(entry, target, method) {
    var callbacks = entry.callbacks;

    // try to find in existing array
    var handler = callbacks.find(function(x) {
      return x[0]===target && x[1]===method;
    }, this);
    
    // not found, add...
    if (!handler) callbacks.push([target, method]);
    callbacks = null; // avoid memory leaks
    return this ;
  },
  
  /** @private
    Removes a callback from the image entry.  Removing a callback just nulls
    out that position in the array.  It will be skipped when executing.
  */
  _removeCallback: function(entry, target, method) {
    var callbacks = entry.callbacks ;
    callbacks.forEach(function(x, idx) {
      if (x[0]===target && x[1]===method) callbacks[idx] = null;
    }, this);
    callbacks = null; // avoid memory leaks
    return this ;
  },
  
  /** @private 
    Adds an entry to the foreground or background queue to load.  If the 
    loader is not already running, start it as well.  If the entry is in the
    queue, but it is in the background queue, possibly move it to the
    foreground queue.
  */
  _scheduleImageEntry: function(entry, isBackgroundFlag) {

    var background = this._backgroundQueue ;
    var foreground = this._foregroundQueue ;
    
    // if entry is loaded, nothing to do...
    if (entry.status === this.IMAGE_LOADED) return this;

    // if image is already in background queue, but now needs to be
    // foreground, simply remove from background queue....
    if ((entry.status===this.IMAGE_QUEUED) && !isBackgroundFlag && entry.isBackground) {
      background[background.indexOf(entry)] = null ;
      entry.status = this.IMAGE_WAITING ;
    }
    
    // if image is not in queue already, add to queue.
    if (entry.status!==this.IMAGE_QUEUED) {
      var queue = (isBackgroundFlag) ? background : foreground ;
      queue.push(entry);
      entry.status = this.IMAGE_QUEUED ;
      entry.isBackground = isBackgroundFlag ;
    }
    
    // if the image loader is not already running, start it...
    if (!this.isLoading) this.invokeLater(this.loadNextImage, 100);
    this.set('isLoading', YES);
    
    return this ; // done!
  },
  
  /** @private
    Removes an entry from the foreground or background queue.  
  */
  _unscheduleImageEntry: function(entry) {
    // if entry is not queued, do nothing
    if (entry.status !== this.IMAGE_QUEUED) return this ;
    
    var queue = entry.isBackground ? this._backgroundQueue : this._foregroundQueue ;
    queue[queue.indexOf(entry)] = null; 
    
    // if entry is loading, abort it also.  Call local abort method in-case
    // browser decides not to follow up.
    if (this._loading.indexOf(entry) >= 0) {
      // In some cases queue.image is undefined. Is it ever defined?
      if (queue.image) queue.image.abort();
      this.imageStatusDidChange(entry, this.ABORTED);
    }
    
    return this ;
  },
  
  /** @private invoked by Image().  Note that this is the image instance */
  _imageDidAbort: function() {
    SC.run(function() {
      SC.imageQueue.imageStatusDidChange(this.entry, SC.imageQueue.ABORTED);
    }, this);
  },
  
  _imageDidError: function() {
    SC.run(function() {
      SC.imageQueue.imageStatusDidChange(this.entry, SC.imageQueue.ERROR);
    }, this);
  },
  
  _imageDidLoad: function() {
    SC.run(function() {
      SC.imageQueue.imageStatusDidChange(this.entry, SC.imageQueue.LOADED);
    }, this);
  },

  /** @private called whenever the image loading status changes.  Notifies
    items in the queue and then cleans up the entry.
  */
  imageStatusDidChange: function(entry, status) {
    if (!entry) return; // nothing to do...
    
    var url = entry.url ;
    
    // notify handlers.
    var value ;
    switch(status) {
      case this.LOADED:
        value = entry.image;
        break;
      case this.ABORTED:
        value = SC.IMAGE_ABORTED_ERROR;
        break;
      case this.ERROR:
        value = SC.IMAGE_FAILED_ERROR ;
        break;
      default:
        value = SC.IMAGE_FAILED_ERROR ;
        break;
    }
    entry.callbacks.forEach(function(x){
      var target = x[0], method = x[1];
      method.call(target, url, value);
    },this);
    
    // now clear callbacks so they aren't called again.
    entry.callbacks = [];
    
    // finally, if the image loaded OK, then set the status.  Otherwise
    // set it to waiting so that further attempts will load again
    entry.status = (status === this.LOADED) ? this.IMAGE_LOADED : this.IMAGE_WAITING ;
    
    // now cleanup image...
    var image = entry.image ;
    if (image) {
      image.onload = image.onerror = image.onabort = null ; // no more notices
      if (status !== this.LOADED) entry.image = null;
    }

    // remove from loading queue and periodically compact
    this._loading[this._loading.indexOf(entry)]=null;
    if (this._loading.length > this.loadLimit*2) {
      this._loading = this._loading.compact();
    }
    
    this.decrementProperty('activeRequests');
    this.loadNextImage() ;
  },
  
  init: function() {
    arguments.callee.base.apply(this,arguments);
    this._images = {};
    this._loading = [] ;
    this._foregroundQueue = [];
    this._backgroundQueue = [];
  },
  
  IMAGE_LOADED: "loaded",
  IMAGE_QUEUED: "queued",
  IMAGE_WAITING: "waiting",
  
  ABORTED: 'aborted',
  ERROR: 'error',
  LOADED: 'loaded'
});

/* >>>>>>>>>> BEGIN source/system/math.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @class
  
  Implements some enhancements to the built-in Number object that makes it
  easier to handle rounding and display of numbers.
  
  @since SproutCore 1.0
  @author Colin Campbell
*/
SC.Math = SC.Object.create(
/** @lends SC.Math.prototype */ {
  
  /**
    Checks to see if the number is near the supplied parameter to a certain lambda.
    
    @param {Number} n1 First number in comparison.
    @param {Number} n2 Number to compare against the first.
    @param {Number} lambda The closeness sufficient for a positive result. Default 0.00001
    @returns {Boolean}
  */
  near: function(n1, n2, lambda) {
    if (!lambda) lambda = 0.00001;
    return Math.abs(n1 - n2) <= lambda;
  },
  
  /**
    Rounds a number to a given decimal place. If a negative decimalPlace
    parameter is provided, the number will be rounded outward (ie. providing
    -3 will round to the thousands).
    
    Function is insufficient for high negative values of decimalPlace parameter.
    For example, (123456.789).round(-5) should evaluate to 100000 but instead
    evaluates to 99999.999... 
    
    @param {Number} n The number to round
    @param {Integer} decimalPlace
    @returns {Number}
  */
  round: function(n, decimalPlace) {
    if (!decimalPlace) decimalPlace = 0;
    var factor = Math.pow(10, decimalPlace);
    if (decimalPlace < 0) {
       // stop rounding errors from hurting the factor...
      var s = factor.toString();
      factor = s.substring(0, s.indexOf("1")+1);
    }
    n = n.valueOf();
    return Math.round(n * factor) / factor;
  }
  
}) ;

/* >>>>>>>>>> BEGIN source/system/module.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/*globals jQuery */

sc_require('tasks/task');




/**
  SC.Module is responsible for dynamically loading in JavaScript and other
  resources. These packages of code and resources, called bundles, can be
  loaded by your application once it has finished loading, allowing you to
  reduce the time taken for it to launch.

  You can explicitly load a module by calling SC.Module.loadModule(), or you
  can mark a module as prefetched in your Buildfile. In those cases,
  SproutCore will automatically start to load the bundle once the application
  has loaded and the user has remained idle for more than one second.
*/

SC.Module = SC.Object.create(/** @scope SC.Module */ {

  /**
    Returns YES if the module is ready; NO if it is not loaded or its
    dependencies have not yet loaded.

    @param {String} moduleName the name of the module to check
    @returns {Boolean}
  */
  isModuleReady: function (moduleName) {
    var moduleInfo = SC.MODULE_INFO[moduleName];
    return moduleInfo ? !!moduleInfo.isReady : NO;
  },

  /**
    Asynchronously loads a module if it is not already loaded. If you pass
    a function, or a target and action, it will be called once the module
    has finished loading.

    If the module you request has dependencies (as specified in the Buildfile)
    that are not yet loaded, it will load them first before executing the
    requested module.

    @param moduleName {String}
    @param target {Function}
    @param method {Function}
    @returns {Boolean} YES if already loaded, NO otherwise
  */
  loadModule: function (moduleName, target, method) {
    var module = SC.MODULE_INFO[moduleName],
        

        args;

    if (arguments.length > 3) {
      // Fast arguments access.
      // Accessing `arguments.length` is just a Number and doesn't materialize the `arguments` object, which is costly.
      args = new Array(arguments.length - 3); //  SC.A(arguments).slice(3)
      for (var i = 0, len = args.length; i < len; i++) { args[i] = arguments[i + 3]; }
    } else {
      args = [];
    }

    // Treat the first parameter as the callback if the target is a function and there is
    // no method supplied.
    if (method === undefined && SC.typeOf(target) === SC.T_FUNCTION) {
      method = target;
      target = null;
    }

    


    // If we couldn't find anything in the SC.MODULE_INFO hash, we don't have any record of the
    // requested module.
    if (!module) {
      throw new Error("SC.Module: could not find module '%@'".fmt(moduleName));
    }

    // If this module was in the middle of being prefetched, we now need to
    // execute it immediately when it loads.
    module.isPrefetching = NO;

    // If the module is already loaded, execute the callback immediately if SproutCore is loaded,
    // or else as soon as SC has finished loading.
    if (module.isLoaded && !module.isWaitingForRunLoop) {
      


      // we can't just eval it if its dependencies have not been met...
      if (!this._dependenciesMetForModule(moduleName)) {
        // we can't let it return normally here, because we need the module to wait until the end of the run loop.
        // This is because the module may set up bindings.
        this._addCallbackForModule(moduleName, target, method, args);

        this._loadDependenciesForModule(moduleName);

        return NO;
      }

      // If the module has finished loading and we have the string
      // representation, try to evaluate it now.
      if (module.source) {
        

        this._evaluateStringLoadedModule(module);

        // we can't let it return normally here, because we need the module to wait until the end of the run loop.
        // This is because the module may set up bindings.
        this._addCallbackForModule(moduleName, target, method, args);

        this.invokeLast(function () {
          module.isReady = YES;
          this._moduleDidBecomeReady(moduleName);
        });

        return NO;
      }

      if (method) {
        if (SC.isReady) {
          SC.Module._invokeCallback(moduleName, target, method, args);
        } else {
          // Queue callback for when SC has finished loading.
          SC.ready(SC.Module, function () {
            SC.Module._invokeCallback(moduleName, target, method, args);
          });
        }
      }

      return YES;
    }

    // The module has loaded, but is waiting for the end of the run loop before it is "ready";
    // we just need to add the callback.
    else if (module.isWaitingForRunLoop) {
      this._addCallbackForModule(moduleName, target, method, args);
    }
    // The module is not yet loaded, so register the callback and, if necessary, begin loading
    // the code.
    else {

      


      // If this method is called more than once for the same module before it is finished
      // loading, we might have multiple callbacks that need to be executed once it loads.
      this._addCallbackForModule(moduleName, target, method, args);

      // If this is the first time the module has been requested, determine its dependencies
      // and begin loading them as well as the JavaScript for this module.
      if (!module.isLoading) {
        this._loadDependenciesForModule(moduleName);
        this._loadCSSForModule(moduleName);
        this._loadJavaScriptForModule(moduleName);
        module.isLoading = YES;
      }

      return NO;
    }
  },

  _addCallbackForModule: function (moduleName, target, method, args) {
    var module = SC.MODULE_INFO[moduleName];

    // Retrieve array of callbacks from MODULE_INFO hash.
    var callbacks = module.callbacks || [];

    if (method) {
      callbacks.push(function () {
        SC.Module._invokeCallback(moduleName, target, method, args);
      });
    }

    module.callbacks = callbacks;
  },

  /**
    @private

    Loads a module in string form. If you prefetch a module, its source will
    be held as a string in memory until SC.Module.loadModule() is called, at
    which time its JavaScript will be evaluated.

    You shouldn't call this method directly; instead, mark modules as
    prefetched in your Buildfile. SproutCore will automatically prefetch those
    modules once your application has loaded and the user is idle.

    @param {String} moduleName the name of the module to prefetch
  */
  prefetchModule: function (moduleName) {
    var module = SC.MODULE_INFO[moduleName];

    if (module.isLoading || module.isLoaded) return;

    if (SC.LOG_MODULE_LOADING) SC.debug("SC.Module: Prefetching module '%@'.", moduleName);
    this._loadDependenciesForModule(moduleName);
    this._loadCSSForModule(moduleName);
    this._loadJavaScriptForModule(moduleName);
    module.isLoading = YES;
    module.isPrefetching = YES;
  },

  // ..........................................................
  // INTERNAL SUPPORT
  //

  /** @private
    If a module is marked for lazy instantiation, this method will execute the closure and call
    any registered callbacks.
  */
  _executeLazilyInstantiatedModule: function (moduleName, targetName, methodName) {
    var lazyInfo =  SC.LAZY_INSTANTIATION[moduleName];
    var target;
    var method;
    var idx, len;

    if (SC.LOG_MODULE_LOADING) {
      SC.debug("SC.Module: Module '%@' is marked for lazy instantiation, instantiating it now…", moduleName);
    }

    len = lazyInfo.length;
    for (idx = 0; idx < len; idx++) {
      // Iterate through each function associated with this module, and attempt to execute it.
      try {
        lazyInfo[idx]();
      } catch (e) {
        SC.Logger.error("SC.Module: Failed to lazily instatiate entry for  '%@'".fmt(moduleName));
      }
    }

    // Free up memory containing the functions once they have been executed.
    delete SC.LAZY_INSTANTIATION[moduleName];

    // Now that we have executed the functions, try to find the target and action for the callback.
    target = this._targetForTargetName(targetName);
    method = this._methodForMethodNameInTarget(methodName, target);

    if (!method) {
      throw new Error("SC.Module: could not find callback for lazily instantiated module '%@'".fmt(moduleName));
    }
  },

  /**
    Evaluates a module's JavaScript if it is stored in string format, then
    deletes that code from memory.

    @param {Hash} module the module to evaluate
  */
  _evaluateStringLoadedModule: function (module) {
    var moduleSource = module.source;

    // so, force a run loop.
    jQuery.globalEval(moduleSource);

    delete module.source;

    if (module.cssSource) {
      var el = document.createElement('style');
      el.setAttribute('type', 'text/css');
      if (el.styleSheet) {
        el.styleSheet.cssText = module.cssSource;
      } else {
        var content = document.createTextNode(module.cssSource);
        el.appendChild(content);
      }

      document.getElementsByTagName('head')[0].appendChild(el);
    }

    module.isReady = YES;
  },

  /**
    @private

    Creates <link> tags for every CSS resource in a module.

    @param {String} moduleName the name of the module whose CSS should be loaded
  */
  _loadCSSForModule: function (moduleName) {
    var head = document.getElementsByTagName('head')[0];
    var module = SC.MODULE_INFO[moduleName];
    var styles = module.styles || [];
    var len = styles.length;
    var url;
    var el;
    var idx;

    if (!head) head = document.documentElement; // fix for Opera
    len = styles.length;

    for (idx = 0; idx < len; idx++) {
      url = styles[idx];

      if (url.length > 0) {
        if (SC.LOG_MODULE_LOADING) SC.debug("SC.Module: Loading CSS file in '%@' -> '%@'", moduleName, url);

        // if we are on a retina device lets load the retina style sheet instead
        if (window.devicePixelRatio > 1 || window.location.search.indexOf("2x") > -1) {
          url = url.replace('.css', '@2x.css');
        }

        el = document.createElement('link');
        el.setAttribute('href', url);
        el.setAttribute('rel', "stylesheet");
        el.setAttribute('type', "text/css");
        head.appendChild(el);
      }
    }

    el = null;
  },

  _loadJavaScriptForModule: function (moduleName) {
    var module = SC.MODULE_INFO[moduleName];
    var el;
    var url;
    var dependencies = module.dependencies;
    var dependenciesAreLoaded = YES;

    // If this module has dependencies, determine if they are loaded.
    if (dependencies && dependencies.length > 0) {
      dependenciesAreLoaded = this._dependenciesMetForModule(moduleName);
    }

    // If the module is prefetched, always load the string representation.
    if (module.isPrefetched) {
      url = module.stringURL;
    } else {
      if (dependenciesAreLoaded) {
        // Either we have no dependencies or they've all loaded already,
        // so just execute the code immediately once it loads.
        url = module.scriptURL;
      } else {
        // Because the dependencies might load after this module, load the
        // string representation so we can execute it once all dependencies
        // are in place.
        url = module.stringURL;
      }
    }

    if (url.length > 0) {
      if (SC.LOG_MODULE_LOADING) SC.debug("SC.Module: Loading JavaScript file in '%@' -> '%@'", moduleName, url);

      el = document.createElement('script');
      el.setAttribute('type', "text/javascript");
      el.setAttribute('src', url);

      if (el.addEventListener) {
        el.addEventListener('load', function () {
          SC.run(function () {
            SC.Module._moduleDidLoad(moduleName);
          });
        }, false);
      } else if (el.readyState) {
        el.onreadystatechange = function () {
          if (this.readyState === 'complete' || this.readyState === 'loaded') {
            SC.run(function () {
              SC.Module._moduleDidLoad(moduleName);
            });
          }
        };
      }

      document.body.appendChild(el);
    }
  },

  /**
    @private

    Returns YES if all of the dependencies for a module are ready.

    @param {String} moduleName the name of the module being checked
    @returns {Boolean} whether the dependencies are loaded
  */
  _dependenciesMetForModule: function (moduleName) {
    var dependencies = SC.MODULE_INFO[moduleName].dependencies || [];
    var idx, len = dependencies.length;
    var dependencyName;
    var module;

    for (idx = 0; idx < len; idx++) {
      dependencyName = dependencies[idx];
      module = SC.MODULE_INFO[dependencyName];

      if (!module) throw new Error("SC.loadModule: Unable to find dependency %@ for module %@.".fmt(dependencyName, moduleName));

      if (!module.isReady) {
        return NO;
      }
    }

    return YES;
  },

  /**
    Loads all unloaded dependencies for a module, then creates the <script> and <link> tags to
    load the JavaScript and CSS for the module.
  */
  _loadDependenciesForModule: function (moduleName) {
    // Load module's dependencies first.
    var moduleInfo      = SC.MODULE_INFO[moduleName];

    

    var dependencies    = moduleInfo.dependencies || [];
    var dependenciesMet = YES;
    var len             = dependencies.length;
    var idx;
    var requiredModuleName;
    var requiredModule;
    var dependents;

    for (idx = 0; idx < len; idx++) {
      requiredModuleName = dependencies[idx];
      requiredModule = SC.MODULE_INFO[requiredModuleName];

      // Try to find dependent module in MODULE_INFO
      if (!requiredModule) {
        throw new Error("SC.Module: could not find required module '%@' for module '%@'".fmt(requiredModuleName, moduleName));
      } else {

        // Required module has been requested but hasn't loaded yet.
        if (requiredModule.isLoading) {
          dependenciesMet = NO;

          dependents = requiredModule.dependents;
          if (!dependents) requiredModule.dependents = dependents = [];
          dependents.push(moduleName);
        }

        // Required module has already been loaded and evaluated, no need to worry about it.
        else if (requiredModule.isReady) {
          continue;
        }
        // Required module has not been loaded nor requested yet.
        else {
          dependenciesMet = NO;

          // Register this as a dependent module (used by SC._moduleDidLoad()...)
          dependents = requiredModule.dependents;
          if (!dependents) requiredModule.dependents = dependents = [];

          dependents.push(moduleName);

          


          // Load dependencies
          SC.Module.loadModule(requiredModuleName);
        }
      }
    }
  },

  /**
    @private

    Calls an action on a target to notify the target that a module has loaded.
  */
  _invokeCallback: function (moduleName, targetName, methodName, args) {
    var method;
    var target;

    target = this._targetForTargetName(targetName);
    method = this._methodForMethodNameInTarget(methodName, target);

    // If we weren't able to find the callback, this module may be lazily instantiated and
    // the callback won't exist until we execute the closure that it is wrapped in.
    if (!method) {
      if (SC.LAZY_INSTANTIATION[moduleName]) {
        this._executeLazilyInstantiatedModule(moduleName, targetName, methodName);

        target = this._targetForTargetName(targetName);
        method = this._methodForMethodNameInTarget(methodName, target);
      } else {
        throw new Error("SC.Module: could not find callback for '%@'".fmt(moduleName));
      }
    }

    if (!args) {
      args = [];
    }

    // The first parameter passed to the callback is the name of the module.
    args.unshift(moduleName);

    // Invoke the callback. Wrap it in a run loop if we are not in a runloop already.
    var needsRunLoop = !!SC.RunLoop.currentRunLoop;
    if (needsRunLoop) {
      SC.run(function () {
        method.apply(target, args);
      });
    } else {
      method.apply(target, args);
    }
  },

  /** @private
    Given a module name, iterates through all registered callbacks and calls them.
  */
  _invokeCallbacksForModule: function (moduleName) {
    var moduleInfo = SC.MODULE_INFO[moduleName], callbacks;
    if (!moduleInfo) return; // shouldn't happen, but recover anyway

    


    callbacks = moduleInfo.callbacks || [];

    for (var idx = 0, len = callbacks.length; idx < len; ++idx) {
      callbacks[idx]();
    }
  },

  _evaluateAndInvokeCallbacks: function (moduleName) {
    var moduleInfo = SC.MODULE_INFO;
    var module = moduleInfo[moduleName];
    


    if (module.source) {
      this._evaluateStringLoadedModule(module);
    }

    // this is ugly, but a module evaluated late like this won't be done instantiating
    // until the end of a run loop. Also, the code here is not structured in a way that makes
    // it easy to "add a step" before saying a module is ready. And finally, invokeLater doesn't
    // accept arguments; hence, the closure.
    module.isWaitingForRunLoop = YES;
    this.invokeLast(function () {
      module.isReady = YES;
      this._moduleDidBecomeReady(moduleName);
    });
  },

  _moduleDidBecomeReady: function (moduleName) {
    var moduleInfo = SC.MODULE_INFO;
    var module = moduleInfo[moduleName];
    


    module.isWaitingForRunLoop = NO;

    if (SC.isReady) {
      SC.Module._invokeCallbacksForModule(moduleName);
      delete module.callbacks;
    } else {
      SC.ready(SC, function () {
        SC.Module._invokeCallbacksForModule(moduleName);
        delete module.callbacks;
      });
    }

    // for each dependent module, try and load them again...
    var dependents = module.dependents || [];
    var dependentName, dependent;

    for (var idx = 0, len = dependents.length; idx < len; idx++) {
      dependentName = dependents[idx];
      dependent = moduleInfo[dependentName];
      if (dependent.isLoaded && this._dependenciesMetForModule(dependentName)) {
        

        this._evaluateAndInvokeCallbacks(dependentName);
      }
    }

  },

  /** @private
    Called when the JavaScript for a module finishes loading.

    Any pending callbacks are called (if SC.isReady), and any dependent
    modules which were waiting for this module to load are notified so they
    can continue loading.

    @param moduleName {String} the name of the module that just loaded
  */
  _moduleDidLoad: function (moduleName) {
    var module = SC.MODULE_INFO[moduleName];
    

    var dependenciesMet;

    


    if (!module) {
      

      module = SC.MODULE_INFO[moduleName] = { isLoaded: YES, isReady: YES };
      return;
    }

    if (module.isLoaded) {
      

      return;
    }

    // Remember that we're loaded.
    delete module.isLoading;
    module.isLoaded = YES;

    if (!module.isPrefetching) {
      dependenciesMet = this._dependenciesMetForModule(moduleName);
      if (dependenciesMet) {
        this._evaluateAndInvokeCallbacks(moduleName);
      } else {
        

      }
    } else {
      delete module.isPrefetching;
      

    }
  },

  /**
    @private

    If necessary, converts a property path into a target object.

    @param {String|Object} targetName the string or object representing the target
    @returns Object
  */
  _targetForTargetName: function (targetName) {
    if (SC.typeOf(targetName) === SC.T_STRING) {
      return SC.objectForPropertyPath(targetName);
    }

    return targetName;
  },

  /**
    @private

    If necessary, converts a property path into a method object.

    @param {String|Object} methodName the string or object representing the method
    @param {Object} target the target from which to retrieve the method
    @returns Object
  */
  _methodForMethodNameInTarget: function (methodName, target) {
    if (SC.typeOf(methodName) === SC.T_STRING) {
      return SC.objectForPropertyPath(methodName, target);
    }

    return methodName;
  },

  /**
    A list of the methods to temporarily disable (and buffer calls for) when we are suspended.
  */
  methodsForSuspend: "loadModule _moduleDidLoad prefetchModule _moduleDidBecomeReady".w(),

  /**
    Call this in order to prevent expensive tasks from occurring at inopportune times.
  */
  suspend: function () {

    //Increment the suspension count, to support nested suspend()/resume() pairs.
    //We only do anything if the suspend count ends up at 1, as that implies it's
    //the first suspend() call.
    this._suspendCount = (this._suspendCount || 0) + 1;
    if (this._suspendCount !== 1) return;

    //Yummy variables.
    var methods = this.get('methodsForSuspend'),
        replaceKey, saveKey, key, i;

    //Now we go through the list of methods to suspend, and overwrite them with
    //versions that will buffer their calls in a _bufferedCalls array.
    for (i = 0; (key = methods[i]); i++) {
      //jshint loopfunc: true
      //Ensure the replacement function exists at a key where it'll be cached.
      if (!this[replaceKey = "__replacement_" + key + "__"]) {
        (this[replaceKey] = function () {
          (this._bufferedCalls || (this._bufferedCalls = [])).push({
            method: arguments.callee.methodName,
            arguments: arguments
          });
        }).methodName = key;
      }

      //Ensure the original function exists at a key where it'll be cached.
      if (!this[saveKey = "__saved_" + key + "__"]) this[saveKey] = this[key];

      //Ensure that the replacement function exists where the rest of the
      //code expects the original.
      this[key] = this[replaceKey];
    }
  },

  /**
    Call this in order to resume normal behavior of the methods here, and to
    finally perform any calls that may have occurred during suspension. Calls
    will run in the order they were received.
  */
  resume: function () {

    //First, we need to decrement the suspension count, and warn if the suspension
    //count implied that we weren't already suspended. Furthermore, if the suspend
    //count is not zero, then we haven't tackled the last suspend() call with a resume(),
    //and should therefore not resume.
    this._suspendCount = (this._suspendCount || 0) - 1;
    if (this._suspendCount < 0) {
      SC.warn("SC.Module.resume() was called without SC.Module having been in a suspended state. Call aborted.");
      this._suspendCount = 0;
      return;
    }
    if (this._suspendCount > 0) return;

    //Yummy variables.
    var methods = this.get('methodsForSuspend'),
        calls = this._bufferedCalls,
        key, i, call;

    //Restore the original methods to where they belong for normal functionality.
    for (i = 0; (key = methods[i]); i++) this[key] = this["__saved_" + key + "__"];

    //Perform any buffered calls that built up during the suspended period.
    for (i = 0; (call = calls) && calls[i]; i++) this[call.method].apply(this, call.arguments);

    //Clear the list of calls, so subsequent resume() calls won't flush them again.
    if (calls) calls.length = 0;
  }
});

/**
Inspect the list of modules and, for every prefetched module, create a
background task to load the module when the user remains idle.
*/
SC.ready(function () {
  var moduleInfo = SC.MODULE_INFO;
  var moduleName;
  var module;
  var task;

  // Iterate through all known modules and look for those that are marked
  // as prefetched.
  for (moduleName in moduleInfo) {
    module = moduleInfo[moduleName];

    if (module.isPrefetched) {
      // Create a task that will load the module, and then register it with
      // the global background task queue.
      task = SC.Module.PrefetchModuleTask.create({ prefetchedModuleName: moduleName });
      SC.backgroundTaskQueue.push(task);
    }
  }
});

SC.Module.PrefetchModuleTask = SC.Task.extend({
  prefetchedModuleName: null,
  run: function () {
    SC.Module.prefetchModule(this.prefetchedModuleName);
  }
});

/* >>>>>>>>>> BEGIN source/system/task_queue.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require("tasks/task");

/**
  Runs a set of tasks. Most importantly, has a runWhenIdle option that allows
  it to run when no user input is occurring. This allows, for instance, preloading
  bundles while not blocking user interaction.
*/
SC.TaskQueue = SC.Task.extend({
  
  init: function() {
    var self = this;
    this._doIdleEntry = function() {
      self._idleEntry();
    };
    
    this._suspendCount = 0;
    this._tasks = [];
  },
  
  /**
    If YES, the queue will automatically run in the background when the browser idles.
  */
  runWhenIdle: NO,
  
  /**
    A limit which, if exceeded, the task queue will wait until a later run
    to continue.
  */
  runLimit: 50,
  
  /**
    The duration between idle runs.
  */
  interval: 50,
  
  /**
    If running, YES.
  */
  isRunning: NO,
  
  /**
    The minimum elapsed time since the last event. As a rule of thumb, perhaps
    something equivalent to the expected duration of a task.
  */
  minimumIdleDuration: 500,
  
  _tasks: null,
  
  /**
    Returns YES if there are tasks in the queue.
  */
  hasTasks: function() {
    return this._tasks.length > 0;
  }.property('taskCount').cacheable(),
  
  /**
    Returns the number of tasks in the queue.
  */
  taskCount: function() {
    return this._tasks.length;
  }.property().cacheable(),
  
  /**
    Adds the task to the end of the queue.
  */
  push: function(task) {
    this._tasks.push(task);
    this.notifyPropertyChange('taskCount');
  },
  
  /**
    Removes and returns the first task in the queue.
  */
  next: function() {
    // null if there is no task
    if (this._tasks.length < 1) return null;
    
    // otherwise, return the first one in the queue
    var next = this._tasks.shift();
    this.notifyPropertyChange('taskCount');
    return next;
  },
  
  /**
    Suspends cycling of the queue. Only affects task queues that run when idle,
    such as the backgroundTaskQueue.
  */
  suspend: function() {
    this._suspendCount++;
  },
  
  /**
    Resumes cycling of the queue.
  */
  resume: function() {
    this._suspendCount--;
    if (this._suspendCount <= 0) {
      this._setupIdle();
    }
  },
  
  /**
    @private
    Sets up idling if needed when the task count changes.
  */
  _taskCountDidChange: function() {
    this._setupIdle();
  }.observes('taskCount'),
  
  /**
    When runWhenIdle changes, we need to setup idle again if needed. This allows us to suspend
    and resume processing of the background task queue.
  */
  _runWhenIdleDidChange: function() {
    this._setupIdle();
  }.observes('runWhenIdle'),
  
  /**
    Sets up the scheduled idling check if needed and applicable.
    @private
  */
  _setupIdle: function() {
    if (
      !this._suspendCount && this.get('runWhenIdle') && 
      !this._idleIsScheduled && this.get('taskCount') > 0
    ) {
      setTimeout(this._doIdleEntry, 
        this.get('interval')
      );
      this._idleIsScheduled = YES;
    }
  },
  
  /**
    The entry point for the idle.
    @private
  */
  _idleEntry: function() {
    this._idleIsScheduled = NO;
    var last = SC.RunLoop.lastRunLoopEnd;
    
    // if we are not supposed to run when idle we need to short-circuit out.
    if (!this.get('runWhenIdle') && !this._suspendCount) return;
    
    // if no recent events (within < 1s)
    if (Date.now() - last > this.get('minimumIdleDuration')) {
      SC.run(this.run, this);
      SC.RunLoop.lastRunLoopEnd = last; // we were never here
    }
    
    // set up idle timer if needed
    this._setupIdle();
  },
  
  /**
    Runs tasks until limit (TaskQueue.runLimit by default) is reached.
  */
  run: function(limit) {
    this.set("isRunning", YES);
    if (!limit) limit = this.get("runLimit");
    
    var task, start = Date.now();
    
    while (task = this.next()) {
      task.run(this);
      
      // check if the limit has been exceeded
      if (Date.now() - start > limit) break;
    }
    
    this.set("isRunning", NO);
  }
  
  
});

SC.backgroundTaskQueue = SC.TaskQueue.create({
  runWhenIdle: YES
});

/* >>>>>>>>>> BEGIN source/system/text_selection.js */
// ==========================================================================
// Project:   SproutCore Costello - Property Observing Library
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @class

  A simple object representing the selection inside a text field.  Each
  object is frozen and contains exactly three properties:

    *  start
    *  end
    *  length

  Important note:  In Internet Explorer, newlines in textarea elements are
  considered two characters.  SproutCore does not currently try to hide this from you.

  @extends SC.Object
  @extends SC.Copyable
  @extends SC.Freezable
  @since SproutCore 1.0
*/

SC.TextSelection = SC.Object.extend(SC.Copyable, SC.Freezable,
/** @scope SC.TextSelection.prototype */ {

  /**
    The number of characters appearing to the left of the beginning of the
    selection, starting at 0.

    @type {Number}
  */
  start: -1,

  /**
    The number of characters appearing to the left of the end of the
    selection.

    This will have the same value as 'start' if there is no selection and
    instead there is only a caret.

    @type {Number}
  */
  end: -1,

  /**
    The direction of the selection. Currently only supported on Chrome,
    Firefox, and Safari >= 6.

    Possible values are
      * 'none'
      * 'forward'
      * 'backward'

    @type {String}
    @default 'none'
  */
  direction: 'none',

  /**
    The length of the selection.  This is equivalent to (end - start) and
    exists mainly as a convenience.

    @type Number
  */
  length: function () {
    var start = this.get('start');
    var end   = this.get('end');
    if (start === -1 || end === -1) {
      return -1;
    } else {
      return end - start;
    }
  }.property('start', 'end').cacheable(),

  // ..........................................................
  // INTERNAL SUPPORT
  //

  init: function () {
    arguments.callee.base.apply(this,arguments);
    this.freeze();
  },

  copy: function () {
    return SC.TextSelection.create({
      start: this.get('start'),
      end:   this.get('end'),
      direction: this.get('direction')
    });
  },

  toString: function () {
    var length = this.get('length'),
        start = this.get('start'),
        end = this.get('end'),
        direction = this.get('direction');

    if (length  &&  length > 0) {
      if (length === 1) {
        return "[%@ character selected: {%@, %@}; direction: %@]".fmt(length, start, end, direction);
      }
      else {
        return "[%@ characters selected: {%@, %@}; direction: %@]".fmt(length, start, end, direction);
      }
    }
    else {
      return "[no text selected; caret at %@]".fmt(start);
    }
  }
});

/* >>>>>>>>>> BEGIN source/system/undo_manager.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @class

  This is a simple undo manager. It manages groups of actions which return
  something to an earlier state. It's your responsibility to make sure that
  these functions successfully undo the action, and register an undo action
  of their own (allowing redo).

  ## Using SC.UndoManager

  You should create one SC.UndoManager instance for each thing you want to
  allow undo on. For example, if a controller manages a single record, but
  you have two fields that should each have their own undo stack, you should
  create two separate managers.

  Register undo functions via the `registerUndoAction`, which takes a target,
  action, context and optional human-readable action name. Trigger actions by
  calling the `undo` and `redo` methods. Actions will be called with `context`
  as their only argument.

  Optionally, you can group undo actions; groups of actions are triggered
  together.

  ### Simple Example: A single value

  This example attaches an undo manager to a controller and registers an undo
  function each time the value of `value` changes. It also exposes methods to
  trigger undos and redos, triggered via buttons in the included stub view class.

        // Controller:
        MyApp.myController = SC.ObjectController.create({
          // Content, with `value`.
          content: SC.Object.create({ value: 'Hello, World.' }),

          // Undo manager.
          valueUndoManager: SC.UndoManager.create(),

          // Undo action.
          _valueUndoAction(val) {
            // This call will trigger the controller's `value` observer, triggering the registration
            // of another undo; the UndoManager will automatically and correctly interpret this as
            // the registration of a redo method.
            this.set('value', val);
          },

          // Value observer; tracks `value` and registers undos.
          valueDidChange: function() {
            // Get the values.
            var value = this.get('value'),
                previousValue = this._previousValue,
                that = this;

            // Update previous value.
            this._previousValue = value;

            // GATEKEEP: If the current value is the same as the previous value, there's nothing to do.
            if (previousValue === value) return;

            // GATEKEEP: If there is no previous value, it's probably our initial spinup. We don't want
            // to register an undo-back-to-undefined method, so we should return. (Your situation may be
            // different.)
            if (SC.none(previousValue)) return;

            // Otherwise, register an undo function. (previousValue is accessed via the closure.)
            this.undoManager.registerUndoAction(this, this._valueUndoAction, previousValue);
          }.observes('value')
        });

        // Stub view:
        MyApp.UndoableValueView = SC.View.extend({
          childViews: ['labelView', 'undoButtonView', 'redoButtonView'],
          labelView: SC.LabelView.extend({
            layout: { height: 24 },
            isEdiable: YES,
            valueBinding: 'MyApp.myController.value'
          }),
          undoButtonView: SC.ButtonView.extend({
            layout: { height: 24, width: 60, bottom: 0 },
            title: 'Undo',
            isEnabledBinding: SC.Binding.oneWay('MyApp.myController.valueUndoManager.canUndo'),
            target: 'MyApp.myController.valueUndoManager',
            action: 'undo'
          }),
          redoButtonView: SC.ButtonView.extend({
            layout: { height: 24, width: 60, bottom: 0, right: 0 },
            title: 'Redo',
            isEnabledBinding: SC.Binding.oneWay('MyApp.myController.valueUndoManager.canRedo'),
            target: 'MyApp.myController.valueUndoManager',
            action: 'redo'
          })
        });

  ### Advanced: Grouping undos

  Undo events registered by `registerUndoAction` will undo or redo one at a time. If you wish,
  you can group undo events into groups (for example, if you wish to group all undos which happen
  within a short duration of each other). Groups are fired all at once when `undo` or `redo` is
  called.

  To start a new undo group, call `beginUndoGroup`; to register undo functions to the currently-
  open group, call `registerGroupedUndoAction`; finally, to mark the end of a grouped set of undo
  functions, call `endUndoGroup`. In most cases, you will not need to call `beginUndoGroup` and
  `endUndoGroup`: if you call `registerUndoAction`, any open group will be closed, and a new group
  will be created and left open; calling `registerGroupedUndoAction` will simply add to the
  currently-open group, creating a new one if necessary. This means that in practice, you can call
  `registerUndoAction` to close previous groups and begin a new one, and `registerGroupedUndoAction`
  to add to an existing group.

  If `undo` is called while an undo group is open, UndoManager will simply close the group for
  you before executing it. This allows you to safely leave groups open pending possible additional
  undo actions.

  @extends SC.Object
*/
SC.UndoManager = SC.Object.extend(
/** @scope SC.UndoManager.prototype */ {

  /** 
    If name arguments are passed into `registerUndoAction` or related methods, then this property
    will expose the last undo action's name. You can use this to show the user what type of action
    will be undone (for example "typing" or "delete").

    @field
    @readonly
    @type String
    @default null
  */
  undoActionName: function () { 
    return this.undoStack ? this.undoStack.name : null;
  }.property('undoStack').cacheable(),

  /** 
    Exposes the timestamp of the most recent undo action.

    @field
    @readonly
    @type SC.DateTime
    @default null
  */
  undoActionTimestamp: function() {
    return this.undoStack ? this.undoStack.timeStamp : null;
  }.property('undoStack').cacheable(),

  /** 
    If name arguments are passed into `registerUndoAction` or related methods, then this property
    will expose the last redo action's name. You can use this to show the user what type of
    action will be redone (for example "Redo typing" or "Redo delete").

    @field
    @readonly
    @type String
    @default null
  */
  redoActionName: function () { 
    return this.redoStack ? this.redoStack.name : null;
  }.property('redoStack').cacheable(),

  /** 
    Exposes the timestamp of the most recent redo action.

    @field
    @readonly
    @type SC.DateTime
    @default null
  */
  redoActionTimestamp: function() {
    return this.redoStack ? this.redoStack.timeStamp : null;
  }.property('redoStack').cacheable(),

  /** 
    True if there is an undo action on the stack. Use to validate your menu item or enable
    your button.
    
    @field
    @readonly
    @type Boolean
    @default NO
  */
  canUndo: function () { 
    return !SC.none(this.undoStack);
  }.property('undoStack').cacheable(),
  
  /** 
    True if there is an redo action on the stack. Use to validate your menu item or enable
    your button.
    
    @field
    @readonly
    @type Boolean
    @default NO
  */
  canRedo: function () {
    return !SC.none(this.redoStack);
  }.property('redoStack').cacheable(),
  
  /**
    Tries to undo the last action. Fails if an undo group is currently open.

    @returns {Boolean} YES if succeeded, NO otherwise.
  */
  undo: function () {
    this._undoOrRedo('undoStack','isUndoing');
  },

  /**
    Tries to redo the last action. Fails if a redo group is currently open.
    
    @returns {Boolean} YES if succeeded, NO otherwise.
  */
  redo: function () {
    this._undoOrRedo('redoStack','isRedoing');
  },

  /**
    Resets the undo and redo stacks.
  */
  reset: function () {
    this._activeGroup = null;
    this.set('undoStack', null);
    this.set('redoStack', null);
  },

  /**
    The maximum number of undo groups the receiver holds.
    The undo stack is unlimited by default.

    @type Number
    @default 0
  */
  maxStackLength: 0,
  
  /**
    @type Boolean
    @default NO
  */
  isUndoing: NO,
  
  /**
    @type Boolean
    @default NO
  */
  isRedoing: NO, 
  
  // --------------------------------
  // UNDO ACTION REGISTRATION
  //

  /**
    Registers an undo action. If called while an undo is in progress (i.e. from your
    undo method, or from observers which it triggers), registers a redo action instead.
    
    @param {String|Object} target The action's target (`this`).
    @param {String|Function} action The method on `target` to be called.
    @param {Object} context The context passed to the action when called.
    @param {String} name An optional human-readable name for the undo action.
  */
  registerUndoAction: function(target, action, context, name) {
    // Calls to registerUndoAction close any open undo groups, open a new one and register
    // to it. This means that a series of calls to registerUndo will simply open and close
    // a series of single-function groups, as intended.

    if (!this.isUndoing && !this.isRedoing) {
      if (this._activeGroup) {
        this.endUndoGroup();
      }
      this.beginUndoGroup(name);
    }
    
    this.registerGroupedUndoAction(target, action, context);
  },

  /**
    Registers an undo action to the current group. If no group is open, opens a new
    one.

    @param {String|Object} target The action's target (`this`).
    @param {String|Function} action The method on `target` to be called.
    @param {Object} context The context passed to the action when called.
    @param {String} name An optional human-readable name for the undo action. Sets or
      changes the current group's name.
  */
  registerGroupedUndoAction: function(target, action, context, name) {
    // If we don't have an active group, route the call through registerUndoAction, which will
    // handle creating a new group for us before returning here. (Slight hack.)
    if (!this._activeGroup) {
      this.registerUndoAction(target, action, context, name);
    }
    // Otherwise, register the action.
    else {
      if (name) this._activeGroup.name = name;
      this._activeGroup.targets.push(target);
      this._activeGroup.actions.push(action);
      this._activeGroup.contexts.push(context);
      this._activeGroup.timeStamp = SC.DateTime.create();

      // If we're not mid-undo or -redo, then we're registering a new undo, and should
      // clear out any redoStack.
      if (!this.isUndoing && !this.isRedoing) {
        this.set('redoStack', null);
      }
    }
  },

  /**
    Begins a new undo group.

    Whenever you start an action that you expect to need to bundle under a single
    undo action in the menu, you should begin an undo group.  This way any
    undo actions registered by other parts of the application will be
    automatically bundled into this one action.

    When you are finished performing the action, balance this with a call to
    `endUndoGroup()`. (You can call `undo` or `redo` with an open group; the group
    will simply be closed and processed as normal.)

    @param {String} name
  */
  beginUndoGroup: function (name) {
    if (this._activeGroup) {
      

      return;
    }

    var stack = this.isUndoing ? 'redoStack' : 'undoStack';

    this._activeGroup = {
      // The action's name (see undoActionName). Optional.
      name: name,
      // Ordered lists of targets, actions and contexts. (Nth items in each list go together.)
      targets: [],
      actions: [],
      contexts: [],
      // The previous undo action. When this group is triggered, prev will become the new stack.
      prev: this.get(stack),
      // When the action was registered. Useful for grouping undo actions by time.
      timeStamp: SC.DateTime.create()
    };

    this.set(stack, this._activeGroup);
  },
 
  /**
    Ends a group of undo functions. All functions in an undo group will be undone or redone
    together when `undo` or `redo` is called.

    @see beginUndoGroup()
  */
  endUndoGroup: function () {
    var maxStackLength = this.get('maxStackLength'),
      stackName = this.isUndoing ? 'redoStack' : 'undoStack';

    if (!this._activeGroup) {
      

      return;
    }

    this._activeGroup = null;
    this.notifyPropertyChange(stackName);

    // If we have a maxStackLength, trace back through stack.prev that many times and
    // null out anything older.
    if (maxStackLength > 0) {
      var stack = this[stackName],
        i = 1;
      while(stack = stack.prev) {
        i++;
        if (i >= maxStackLength) {
          stack.prev = null;
        }
      }
    }
  },

  /**
    Change the name of the current undo group.
    
    @param {String} name
  */
  setActionName: function (name) {
    if (!this._activeGroup) {
      

      return;
    }
    this._activeGroup.name = name;
  },
  
  // --------------------------------
  // PRIVATE
  //
  
  /** @private */
  _activeGroup: null,
  
  /** @private */
  undoStack: null,
  
  /** @private */
  redoStack: null, 
  
  /** @private */
  _undoOrRedo: function (stack, state) {
    // Close out any open undo groups.
    if (this._activeGroup) this.endUndoGroup();

    // Flag the state.
    this.set(state, true);

    // Run the group of actions!
    var group = this.get(stack);
    if (group) {
      // Roll back the stack to the previous item.
      this.set(stack, group.prev);
      // Open a new group of the opposite persuasion with the same name. This makes sure a redo
      // action will have the same name as its corresponding undo action.
      this.beginUndoGroup(group.name);

      // Run the actions backwards.
      var len = group.actions.length,
          target, action, context, i;
      for (i = len - 1; i >= 0; i--) {
        target = group.targets[i];
        action = group.actions[i];
        context = group.contexts[i];

        // Normalize (for convenience and backward-compatibility).
        // If target is a function, it's the action.
        if (SC.typeOf(target) === SC.T_FUNCTION) {
          action = target;
          target = null;
        }
        // If target is a string, see if it points to an object.
        if (SC.typeOf(target) === SC.T_STRING) target = SC.objectForPropertyPath(target);
        // If action is a string, see if it's the name of a method on target.
        if (target && SC.typeOf(action) === SC.T_STRING && SC.typeOf(target[action]) === SC.T_FUNCTION) action = target[action];

        // Call!
        if (SC.typeOf(action) === SC.T_FUNCTION) action.call(target, context);
      }

      // Close the opposite-persuasion group opened above.
      this.endUndoGroup();
    }
    this.set(state, false);
  },

  /** @private */
  destroy: function() {
    this._activeGroup = null;
    this.set('undoStack', null);
    this.set('redoStack', null);
    return arguments.callee.base.apply(this,arguments);
  },

  /** @private Deprecated as of 1.11. Use registerUndoAction instead. */
  registerUndo: function (func, name) {
    

    this.registerUndoAction(null, func, null, name);
  }

});

/* >>>>>>>>>> BEGIN source/system/user_defaults.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
/*globals ie7userdata openDatabase*/
/**
  @class

  The UserDefaults object provides an easy way to store user preferences in
  your application on the local machine.  You use this by providing built-in
  defaults using the SC.userDefaults.defaults() method.  You can also
  implement the UserDefaultsDelegate interface to be notified whenever a
  default is required.

  You should also set the userDomain property on the defaults on page load.
  This will allow the UserDefaults application to store/fetch keys from
  localStorage for the correct user.

  You can also set an appDomain property if you want.  This will be
  automatically prepended to key names with no slashes in them.

  SC.userDefaults.getPath("global:contactInfo.userName");

  @extends SC.Object
  @since SproutCore 1.0
*/
SC.UserDefaults = SC.Object.extend(/** @scope SC.UserDefaults.prototype */ {

  ready: NO,

  /**
    the default domain for the user.  This will be used to store keys in
    local storage.  If you do not set this property, the wrong values may be
    returned.
  */
  userDomain: null,

  /**
    The default app domain for the user.  Any keys that do not include a
    slash will be prefixed with this app domain key when getting/setting.
  */
  appDomain: null,

  /** @private
    Defaults.  These will be used if not defined on localStorage.
  */
  _defaults: null,

  _safari3DB: null,

  /**
    Invoke this method to set the builtin defaults.  This will cause all
    properties to change.
  */
  defaults: function(newDefaults) {
    this._defaults = newDefaults ;
    this.allPropertiesDidChange();
  },

  /**
    Attempts to read a user default from local storage.  If not found on
    localStorage, use the the local defaults, if defined.  If the key passed
    does not include a slash, then add the appDomain or use "app/".

    @param {String} keyName
    @returns {Object} read value
  */
  readDefault: function(keyName) {
    // Note: different implementations of localStorage may return 'null' or
    // may return 'undefined' for missing properties so use SC.none() to check
    // for the existence of ret throughout this function.
    var isIE7, ret, userKeyName, localStorage, key, del, storageSafari3;

    // namespace keyname
    keyName = this._normalizeKeyName(keyName);
    userKeyName = this._userKeyName(keyName);

    // look into recently written values
    if (this._written) { ret = this._written[userKeyName]; }

    // attempt to read from localStorage
    isIE7 = SC.browser.isIE &&
        SC.browser.compare(SC.browser.version, '7') === 0;

    if(isIE7) {
      localStorage=document.body;
      try{
        localStorage.load("SC.UserDefaults");
      }catch(e){
        SC.Logger.error("Couldn't load userDefaults in IE7: "+e.description);
      }
    }else if(this.HTML5DB_noLocalStorage){
      storageSafari3 = this._safari3DB;
    }else{
      localStorage = window.localStorage ;
      if (!localStorage && window.globalStorage) {
        localStorage = window.globalStorage[window.location.hostname];
      }
    }
    if (localStorage || storageSafari3) {
      key=["SC.UserDefaults",userKeyName].join('-at-');
      if(isIE7) {
        ret=localStorage.getAttribute(key.replace(/\W/gi, ''));
      } else if(storageSafari3) {
        ret = this.dataHash[key];
      } else {
        ret = localStorage[key];
      }
      if (!SC.none(ret)) {
        try { ret = SC.json.decode(ret); }
        catch(ex) {}
      }
    }

    // if not found in localStorage, try to notify delegate
    del = this.delegate ;
    if (del && del.userDefaultsNeedsDefault) {
      ret = del.userDefaultsNeedsDefault(this, keyName, userKeyName);
    }

    // if not found in localStorage or delegate, try to find in defaults
    if (SC.none(ret) && this._defaults) {
      ret = this._defaults[userKeyName] || this._defaults[keyName];
    }

    return ret ;
  },

  /**
    Attempts to write the user default to local storage or at least saves them
    for now.  Also notifies that the value has changed.

    @param {String} keyName
    @param {Object} value
    @returns {SC.UserDefault} receiver
  */
  writeDefault: function(keyName, value) {
    var isIE7, userKeyName, written, localStorage, key, del, storageSafari3;

    keyName = this._normalizeKeyName(keyName);
    userKeyName = this._userKeyName(keyName);

    // save to local hash
    written = this._written ;
    if (!written) { written = this._written = {}; }
    written[userKeyName] = value ;

    // save to local storage
    isIE7 = SC.browser.isIE &&
        SC.browser.compare(SC.browser.version, '7') === 0;

    if(isIE7){
      localStorage=document.body;
    }else if(this.HTML5DB_noLocalStorage){
      storageSafari3 = this._safari3DB;
    }else{
       localStorage = window.localStorage ;
       if (!localStorage && window.globalStorage) {
         localStorage = window.globalStorage[window.location.hostname];
       }
    }
    key=["SC.UserDefaults",userKeyName].join('-at-');
    if (localStorage || storageSafari3) {
      var encodedValue = SC.json.encode(value);
      if(isIE7){
        localStorage.setAttribute(key.replace(/\W/gi, ''), encodedValue);
        localStorage.save("SC.UserDefaults");
      }else if(storageSafari3){
        var obj = this;
        storageSafari3.transaction(
          function (t) {
            t.executeSql("delete from SCLocalStorage where key = ?", [key],
              function (){
                t.executeSql("insert into SCLocalStorage(key, value)"+
                            " VALUES ('"+key+"', '"+encodedValue+"');",
                            [], obj._nullDataHandler, obj.killTransaction
                );
              }
            );
          }
        );
        this.dataHash[key] = encodedValue;
      }else{
        try{
          localStorage[key] = encodedValue;
        }catch(e){
          SC.Logger.error("Failed using localStorage. "+e);
        }
      }
    }

    // also notify delegate
    del = this.delegate;
    if (del && del.userDefaultsDidChange) {
      del.userDefaultsDidChange(this, keyName, value, userKeyName);
    }

    return this ;
  },

  /**
    Removed the passed keyName from the written hash and local storage.

    @param {String} keyName
    @returns {SC.UserDefaults} receiver
  */
  resetDefault: function(keyName) {
    var fullKeyName, isIE7, userKeyName, written, localStorage, key, storageSafari3;
    fullKeyName = this._normalizeKeyName(keyName);
    userKeyName = this._userKeyName(fullKeyName);

    this.propertyWillChange(keyName);
    this.propertyWillChange(fullKeyName);

    written = this._written;
    if (written) delete written[userKeyName];

    isIE7 = SC.browser.isIE &&
        SC.browser.compare(SC.browser.version, '7') === 0;

    if(isIE7){
       localStorage=document.body;
    }else if(this.HTML5DB_noLocalStorage){
         storageSafari3 = this._safari3DB;
    }else{
       localStorage = window.localStorage ;
       if (!localStorage && window.globalStorage) {
         localStorage = window.globalStorage[window.location.hostname];
       }
    }

    key=["SC.UserDefaults",userKeyName].join('-at-');

    if (localStorage) {
      if(isIE7){
        localStorage.setAttribute(key.replace(/\W/gi, ''), null);
        localStorage.save("SC.UserDefaults");
      } else if(storageSafari3){
        var obj = this;
        storageSafari3.transaction(
          function (t) {
            t.executeSql("delete from SCLocalStorage where key = ?", [key], null);
          }
        );
        delete this.dataHash[key];
      }else{
        // In case error occurs while deleting local storage in any browser,
        // do not allow it to propagate further
        try{
          delete localStorage[key];
        } catch(e) {
          SC.Logger.warn('Deleting local storage encountered a problem. '+e);
        }
      }
    }


    this.propertyDidChange(keyName);
    this.propertyDidChange(fullKeyName);
    return this ;
  },

  /**
    Is called whenever you .get() or .set() values on this object

    @param {Object} key
    @param {Object} value
    @returns {Object}
  */
  unknownProperty: function(key, value) {
    if (value === undefined) {
      return this.readDefault(key) ;
    } else {
      this.writeDefault(key, value);
      return value ;
    }
  },

  /**
    Normalize the passed key name.  Used by all accessors to automatically
    insert an appName if needed.
  */
  _normalizeKeyName: function(keyName) {
    if (keyName.indexOf(':')<0) {
      var domain = this.get('appDomain') || 'app';
      keyName = [domain, keyName].join(':');
    }
    return keyName;
  },

  /**
    Builds a user key name from the passed key name
  */
  _userKeyName: function(keyName) {
    var user = this.get('userDomain') || '(anonymous)' ;
    return [user,keyName].join('-at-');
  },

  _domainDidChange: function() {
    var didChange = NO;
    if (this.get("userDomain") !== this._scud_userDomain) {
      this._scud_userDomain = this.get('userDomain');
      didChange = YES;
    }

    if (this.get('appDomain') !== this._scud_appDomain) {
      this._scud_appDomain = this.get('appDomain');
      didChange = YES;
    }

    if (didChange) this.allPropertiesDidChange();
  }.observes('userDomain', 'appDomain'),

  init: function() {
    arguments.callee.base.apply(this,arguments);
    var isIE7;

    // Increment the jQuery ready counter, so that SproutCore will
    // defer loading the app until the user defaults are available.
    jQuery.readyWait++;

    if(SC.userDefaults && SC.userDefaults.get('dataHash')){
      var dh = SC.userDefaults.get('dataHash');
      if (dh) this.dataHash=SC.userDefaults.get('dataHash');
    }
    this._scud_userDomain = this.get('userDomain');
    this._scud_appDomain  = this.get('appDomain');

    isIE7 = SC.browser.isIE &&
        SC.browser.compare(SC.browser.version, '7') === 0;

    if(isIE7){
      //Add user behavior userData. This works in all versions of IE.
      //Adding to the body as is the only element never removed.
      document.body.addBehavior('#default#userData');
    }
    this.HTML5DB_noLocalStorage = SC.browser.isWebkit &&
      SC.browser.compare(SC.browser.engineVersion, '523')>0 &&
      SC.browser.compare(SC.browser.engineVersion, '528')<0;
    if(this.HTML5DB_noLocalStorage){
      var myDB;
      try {
        if (!window.openDatabase) {
          SC.Logger.error("Trying to load a database with safari version 3.1 "+
                  "to get SC.UserDefaults to work. You are either in a"+
                  " previous version or there is a problem with your browser.");
          return;
        } else {
          var shortName = 'scdb',
              version = '1.0',
              displayName = 'SproutCore database',
              maxSize = 65536; // in bytes,
          myDB = openDatabase(shortName, version, displayName, maxSize);

          // You should have a database instance in myDB.

        }
      } catch(e) {
        SC.Logger.error("Trying to load a database with safari version 3.1 "+
                "to get SC.UserDefaults to work. You are either in a"+
                " previous version or there is a problem with your browser.");
        return;
      }

      if(myDB){
        var obj = this;
        myDB.transaction(
          function (transaction) {
            transaction.executeSql('CREATE TABLE IF NOT EXISTS SCLocalStorage'+
              '(key TEXT NOT NULL PRIMARY KEY, value TEXT NOT NULL);',
              [], obj._nullDataHandler, obj.killTransaction);
          }
        );
        myDB.transaction(
          function (transaction) {

            transaction.parent = obj;
            transaction.executeSql('SELECT * from SCLocalStorage;',
                [], function(transaction, results){
                  var hash={}, row;
                  for(var i=0, iLen=results.rows.length; i<iLen; i++){
                    row=results.rows.item(i);
                    hash[row['key']]=row['value'];
                  }
                  transaction.parent.dataHash = hash;
                  SC.run(function() { jQuery.ready(true); });
                }, obj.killTransaction);
          }
        );
        this._safari3DB=myDB;
      }
    }else{
      jQuery.ready(true);
    }
  },


  //Private methods to use if user defaults uses the database in safari 3
  _killTransaction: function(transaction, error){
    return true; // fatal transaction error
  },

  _nullDataHandler: function(transaction, results){}
});

/** global user defaults. */
SC.userDefaults = SC.UserDefaults.create();

/* >>>>>>>>>> BEGIN source/system/utils/colors.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  These functions are deprecated use SC.Color instead.
  @deprecated
  @see SC.Color
 */
SC.mixin ( /** @scope SC */ {

  /** Returns hex color from hsv value */
  convertHsvToHex: function (h, s, v) {
    

    var rgb = SC.Color.hsvToRgb(h, s, v);
    return SC.Color.create({ r: rgb[0], g: rgb[1], b: rgb[2] }).toHex();
  },

  /** Returns hsv color from hex value */
  convertHexToHsv: function (hex) {
    

    var color = SC.Color.from(hex);
    return color && SC.Color.rgbToHsv(color.r, color.g, color.b);
  },

  /** regular expression for parsing color: rgb, hex */
  PARSE_COLOR_RGBRE: /^rgb\(\s*(\d+)\s*,\s*(\d+)\s*,\s*(\d+)\s*\)$/i,
  PARSE_COLOR_HEXRE: /^\#([0-9a-fA-F]{3}|[0-9a-fA-F]{6})$/,

  // return an array of r,g,b colour
  expandColor: function(color) {
    

    var hexColor, red, green, blue;
    hexColor = this.parseColor(color);
    if (hexColor) {
      red = parseInt(hexColor.slice(1, 3), 16);
      green = parseInt(hexColor.slice(3, 5), 16);
      blue = parseInt(hexColor.slice(5, 7), 16);
      return [red,green,blue];
    }
  },

  // parse rgb color or 3-digit hex color to return a properly formatted 6-digit hex colour spec, or false
  parseColor: function(string) {
    

    var i=0, color = '#', match, part;
    if(match = this.PARSE_COLOR_RGBRE.exec(string)) {
      for (i=1; i<=3; i++) {
        part = Math.max(0, Math.min(255, parseInt(match[i],0)));
        color += this.toColorPart(part);
      }
      return color;
    }
    if (match = this.PARSE_COLOR_HEXRE.exec(string)) {
      if(match[1].length == 3) {
        for (i=0; i<3; i++) {
          color += match[1].charAt(i) + match[1].charAt(i);
        }
        return color;
      }
      return '#' + match[1];
    }
    return false;
  },

  // convert one r,g,b number to a 2 digit hex string
  toColorPart: function(number) {
    if (number > 255) number = 255;
    var digits = number.toString(16);
    if (number < 16) return '0' + digits;
    return digits;
  }


});

/* >>>>>>>>>> BEGIN source/system/utils/misc.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

SC.mixin( /** @scope SC */ {
  _downloadFrames: 0, // count of download frames inserted into document

  /**
    Starts a download of the file at the named path.

    Use this method when you want to cause a file to be downloaded to a users
    desktop instead of having it display in the web browser.  Note that your
    server must return a header indicating that the file  is intended for
    download also.
  */
  download: function(path) {
    var tempDLIFrame=document.createElement('iframe'),
        frameId = 'DownloadFrame_' + this._downloadFrames;
    SC.$(tempDLIFrame).attr('id',frameId);
    tempDLIFrame.style.border='10px';
    tempDLIFrame.style.width='0px';
    tempDLIFrame.style.height='0px';
    tempDLIFrame.style.position='absolute';
    tempDLIFrame.style.top='-10000px';
    tempDLIFrame.style.left='-10000px';
    // Don't set the iFrame content yet if this is Safari
    if (!SC.browser.isSafari) {
      SC.$(tempDLIFrame).attr('src',path);
    }
    document.getElementsByTagName('body')[0].appendChild(tempDLIFrame);
    if (SC.browser.isSafari) {
      SC.$(tempDLIFrame).attr('src',path);
    }
    this._downloadFrames = this._downloadFrames + 1;
    if (!SC.browser.isSafari) {
      var r = function() {
        document.body.removeChild(document.getElementById(frameId));
        frameId = null;
      } ;
      r.invokeLater(null, 2000);
    }
    //remove possible IE7 leak
    tempDLIFrame = null;
  },

  // Get the computed style from specific element. Useful for cloning styles
  getStyle: function(oElm, strCssRule){
    var strValue = "";
    if(document.defaultView && document.defaultView.getComputedStyle){
      strValue = document.defaultView.getComputedStyle(oElm, "").getPropertyValue(strCssRule);
    }
    else if(oElm.currentStyle){
     strCssRule = strCssRule.replace(/\-(\w)/g, function (strMatch, p1){
      return p1.toUpperCase();
     });
     strValue = oElm.currentStyle[strCssRule];
    }
    return strValue;
  },

  // Convert double byte characters to standard Unicode. Considers only
  // conversions from zenkaku to hankaky roomaji
  uniJapaneseConvert: function (str){
    var nChar, cString= '', j, jLen;
    //here we cycle through the characters in the current value
    for (j=0, jLen = str.length; j<jLen; j++){
      nChar = str.charCodeAt(j);

      //here we do the unicode conversion from zenkaku to hankaku roomaji
      nChar = ((nChar>=65281 && nChar<=65392)?nChar-65248:nChar);

      //MS IME seems to put this character in as the hyphen from keyboard but not numeric pad...
      nChar = ( nChar===12540?45:nChar) ;
      cString = cString + String.fromCharCode(nChar);
    }
    return cString;
  },

  /**
    Determines if the given point is within the given element.

    The test rect will include the element's padding and can be configured to
    optionally include the border or border and margin.

    @param {Object} point the point as an Object (ie. Hash) in the form { x: value, y: value }.
    @param {DOMElement|jQuery|String} elem the element to test inclusion within.
      This is passed to `jQuery()`, so any value supported by `jQuery()` will work.
    @param {String} includeFlag flag to determine the dimensions of the element to test within.
      One of either: 'padding', 'border' or 'margin' (default: 'border').
    @param {String} relativeToFlag flag to determine which relative element to determine offset by.
      One of either: 'document', 'viewport' or 'parent' (default: 'document').
    @returns {Boolean} YES if the point is within the element; NO otherwise
  */

  // Note: This method is the most correct way to test the inclusion of a point within a DOM element.
  // First, it uses SC.offset which is a slightly improved version of jQuery's offset and much more reliable
  // than writing your own offset determination code.
  // Second, the offset must be adjusted to account for the element's left and top border
  // if not including the border or to account for the left and top margins when including the margins.
  pointInElement: function(point, elem, includeFlag, relativeToFlag) {
    var offset,
        width,
        height,
        rect;

    elem = jQuery(elem);
    includeFlag = includeFlag || 'border';

    // Find the offset
    offset = SC.offset(elem, relativeToFlag);

    // Find the dimensions
    if (includeFlag === 'padding') {
      width = elem.innerWidth();
      height = elem.innerHeight();

      // Adjust offset to account for top & left borders
      offset.x += window.parseInt(elem.css('border-left-width').replace('px', ''));
      offset.y += window.parseInt(elem.css('border-top-width').replace('px', ''));
    } else {
      width = elem.outerWidth(includeFlag === 'margin');
      height = elem.outerHeight(includeFlag === 'margin');

      if (includeFlag === 'margin') {
        // Adjust offset to account for top & left margins
        offset.x -= window.parseInt(elem.css('margin-left').replace('px', ''));
        offset.y -= window.parseInt(elem.css('margin-top').replace('px', ''));
      }
    }

    rect = {
      x: offset.x,
      y: offset.y,
      width: width,
      height: height
    };

    return SC.pointInRect(point, rect);
  },


  /**
    Switch the scale of your app. Useful when visualizing apps not designed
    for iphone.
  */
  switchScale: function() {
    $('head meta[name=viewport]').remove();
    if(window.innerWidth === window.screen.width){
      $('head').prepend('<meta name="viewport" content="width=device-width, initial-scale=0.5, maximum-scale=0.5, minimum-scale=0.5, user-scalable=0" />');
    }else{
      $('head').prepend('<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1, minimum-scale=1, user-scalable=0" />');
    }
  }
});

/* >>>>>>>>>> BEGIN source/system/utils/range.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

SC.mixin( /** @scope SC */ {
  /** A zero length range at zero. */
  ZERO_RANGE: { start: 0, length: 0 },

  RANGE_NOT_FOUND: { start: 0, length: -1 },

  /** Returns true if the passed index is in the specified range */
  valueInRange: function(value, range) {
    return (value >= 0) && (value >= range.start) && (value < (range.start + range.length));
  },

  /** Returns first value of the range. */
  minRange: function(range) { return range.start; },

  /** Returns the first value outside of the range. */
  maxRange: function(range) { return (range.length < 0) ? -1 : (range.start + range.length); },

  /** Returns the union of two ranges.  If one range is null, the other
   range will be returned.  */
  unionRanges: function(r1, r2) {
    if ((r1 == null) || (r1.length < 0)) return r2 ;
    if ((r2 == null) || (r2.length < 0)) return r1 ;

    var min = Math.min(r1.start, r2.start),
        max = Math.max(SC.maxRange(r1), SC.maxRange(r2)) ;
    return { start: min, length: max - min } ;
  },

  /** Returns the intersection of the two ranges or SC.RANGE_NOT_FOUND */
  intersectRanges: function(r1, r2) {
    if ((r1 == null) || (r2 == null)) return SC.RANGE_NOT_FOUND ;
    if ((r1.length < 0) || (r2.length < 0)) return SC.RANGE_NOT_FOUND;
    var min = Math.max(SC.minRange(r1), SC.minRange(r2)),
        max = Math.min(SC.maxRange(r1), SC.maxRange(r2)) ;
    if (max < min) return SC.RANGE_NOT_FOUND ;
    return { start: min, length: max-min };
  },

  /** Returns the difference of the two ranges or SC.RANGE_NOT_FOUND */
  subtractRanges: function(r1, r2) {
    if ((r1 == null) || (r2 == null)) return SC.RANGE_NOT_FOUND ;
    if ((r1.length < 0) || (r2.length < 0)) return SC.RANGE_NOT_FOUND;
    var max = Math.max(SC.minRange(r1), SC.minRange(r2)),
        min = Math.min(SC.maxRange(r1), SC.maxRange(r2)) ;
    if (max < min) return SC.RANGE_NOT_FOUND ;
    return { start: min, length: max-min };
  },

  /** Returns a clone of the range. */
  cloneRange: function(r) {
    return { start: r.start, length: r.length };
  },

  /** Returns true if the two passed ranges are equal.  A null value is
    treated like RANGE_NOT_FOUND.
  */
  rangesEqual: function(r1, r2) {
    if (r1===r2) return true ;
    if (r1 == null) return r2.length < 0 ;
    if (r2 == null) return r1.length < 0 ;
    return (r1.start == r2.start) && (r1.length == r2.length) ;
  }

});

/* >>>>>>>>>> BEGIN source/system/utils/string_metric_optimization.js */
SC.mixin( /** @scope SC */ {
  /**
    This function is similar to SC.metricsForString, but takes an extra argument after the string and before the exampleElement.
    That extra argument is *maxWidth*, which is the maximum allowable width in which the string can be displayed. This function
    will find the narrowest width (within *maxWidth*) that keeps the text at the same number of lines it would've normally wrapped
    to had it simply been put in a container of width *maxWidth*.

    If you have text that's 900 pixels wide on a single line, but pass *maxWidth* as 800, the metrics that will be returned will
    specify a height of two lines' worth of text, but a width of only around 450 pixels. The width this function determines will
    cause the text to be split as evenly as possible over both lines.

    If your text is 1500 pixels wide and *maxWidth* is 800, the width you'll get back will be approximately 750 pixels, because
    the 1500 horizontal pixels of text will still fit within two lines.

    If your text grows beyond 1600 horizontal pixels, it'll wrap to three lines. Suppose you have 1700 pixels of text. This much
    text would require three lines at 800px per line, but this function will return you a width of approximately 1700/3 pixels,
    in order to fill out the third line of text so it isn't just ~100px long.

    A binary search is used to find the optimimum width. There's no way to ask the browser this question, so the answer must be
    searched for. Understandably, this can cause a lot of measurements, which are NOT cheap.

    Therefore, very aggressive caching is used in order to get out of having to perform the search. The final optimimum width is a
    result of all the following values:

      - The string itself
      - The styles on the exampleElement
      - The classNames passed in
      - Whether ignoreEscape is YES or NO

    The caching goes against all of these in order to remember results. Note that maxWidth, though an argument, isn't one of them;
    this means that the optimal width will be searched for only once per distinct *number of lines of text* for a given string and
    styling. However, due to the fact that a passed exampleElement can have different styles a subsequent time it's passed in (but
    still remains the same object with the same GUID, etc), caching will not be enabled unless you either pass in a style string
    instead of an element, or unless your element has *cacheableForMetrics: YES* as a key on it. In most situations, the styles on
    an element won't change from call to call, so this is purely defensive and for arguably infrequent benefit, but it's good
    insurance. If you set the *cacheableForMetrics* key to YES on your exampleElement, caching will kick in, and repeated calls to
    this function will cease to have any appreciable amortized cost.

    The caching works by detecting and constructing known intervals of width for each number of lines required by widths in those
    intervals. As soon as you get a result from this function, it remembers that any width between the width it returned and the
    maxWidth you gave it will return that same result. This also applies to maxWidths greater than the with you passed in, up
    until the width at which the text can fit inside maxWidth with one fewer line break. However, at this point, the function
    can't know how MUCH larger maxWidth can get before getting to the next widest setting. A simple check can be done at this point
    to determine if the existing cached result can be used: if the height of the string at the new maxWidth is the same as the
    cached height, then we know the string didn't fit onto one fewer line, so return the cached value. If we did this check, we
    could return very quickly after only one string measurement, but EACH time we increase the maxWidth we'll have to do a new
    string measurement to check that we didn't end up with horizontal room for one fewer line. Because of this, instead of doing
    the check, the function will perform its binary search to go all the way UP to the minimum maxWidth at which one fewer line
    can be used to fit the text. After caching this value, all subsequent calls to the function will result in no string
    measurements as long as all the maxWidths are within the interval determined to lead to the cached result. So, the second call
    can in some cases be more expensive than it needs to be, but this saves A LOT of expense on all subsequent calls. The less
    often one calls metricsForString, the happier one's life is.

    The amount of time this function will take ranges from 0 to maybe 35ms on an old, slow machine, and, when used for window
    resizing, you'll see 35, 20, 0, 0, 0, ..., 0, 0, 35, 0, 0, 0, ..., 0, 0, 35, 0, 0, 0, ..., 0, 0, 0, 35, 0, 0, 0, ...
    After resizing through all the different caching intervals, the function will always execute quickly... under 1ms nearly always.
    The expensive calls are when a caching interval is crossed and a new cached set of metrics for the new number of lines of text
    must be calculated. And in reality, the number of sub-millisecond function calls will be much greater relative to the number
    of expensive calls, because window resizing just works like that.

    @param {String} string The text whose width you wish to optimize within your maximum width preference.

    @param {Number} maxWidth The maximum width the text is allowed to span, period. Can have "px" afterwards. Need not be a whole
                             number. It will be stripped of "px", and/or rounded up to the nearest integer, if necessary.

    @param {Element/String} exampleElement The element whose styles will be used to measure the width and height of the string.
                                           You can pass a string of CSSText here if you wish, just as with SC.metricsForString.

    @param {String} [classNames] Optional. Any class names you wish to also put on the measurement element.

    @param {Boolean} [ignoreEscape] Optional. If true, HTML in your string will not be escaped. If false or omitted, any HTML
                                              characters will be escaped for the measurement. If it's omitted where it should be
                                              true for correct results, the metrics returned will usually be much bigger than
                                              otherwise required.
  */
  bestStringMetricsForMaxWidth: function(string,maxWidth,exampleElement,classNames,ignoreEscape) {
    if(!maxWidth) { SC.warn("When calling bestMetricsForWidth, the second argument, maxWidth, is required. There's no reason to call this without a maxWidth."); return undefined; }
    maxWidth = Math.ceil(parseFloat(maxWidth));
    var                me = arguments.callee,
              exIsElement = SC.typeOf(exampleElement||(exampleElement=""))!==SC.T_STRING,
            savedMaxWidth = exIsElement ? exampleElement.style.maxWidth : undefined,
                    cache = (!exIsElement || exampleElement.cacheableForMetrics) ?
                              SC.cacheSlotFor(exampleElement,classNames,ignoreEscape,string) :
                              undefined,
                 applyMax = exIsElement ?
                              (me._applyMaxToEl||(me._applyMaxToEl=function(el,width) { el.style.maxWidth = width+"px"; return el; })) :
                              (me._applyMaxToStr||(me._applyMaxToStr=function(str,width) { return str.replace(/max-width:[^;]*;/g,'') + " max-width:"+width+"px"; })),
                removeMax = exIsElement ?
                              (me._removeMaxFromEl||(me._removeMaxFromEl=function(el) { el.style.maxWidth = "none"; return el; })) :
                              (me._removeMaxFromStr||(me._removeMaxFromStr=function(str) { return str.replace(/max-width:[^;]*;/g,'') + " max-width:none"; })),
          searchingUpward = false;
    if(cache) {
      cache.list || (cache.list = [{width: Infinity, height:0}]);
      for(var i=1,l=cache.list.length,inner,outer,ret; i<l && !ret; i++) {
        inner = cache.list[i];
        outer = cache.list[i-1];
        if(!inner || !inner.width) continue;
        if(maxWidth>=inner.width) {
          if((outer && outer.width) || (maxWidth<=inner.maxWidth)) {
            // console.error('returning from cache,',CW.Anim.enumerate(inner));
            return inner;
          }
          // searchingUpward = true;  //commented because this is currently problematic. If this remains false, duplicate work will be done if increasing in maxWidth since previous calls, but at least the results will be correct.
          ret = inner;
        }
      }
    }
    var            exEl = applyMax(exampleElement,maxWidth),
                metrics = SC.metricsForString(string,exEl,classNames,ignoreEscape),
        necessaryHeight = metrics.height,
          oneLineHeight = cache ? cache.parent.height || (cache.parent.height=SC.metricsForString('W',exEl,classNames).height) : SC.metricsForString('W',exEl,classNames).height,
                  lines = Math.round( necessaryHeight / oneLineHeight );
    if(searchingUpward) { lines--; necessaryHeight=lines*oneLineHeight; }
    if(necessaryHeight > oneLineHeight) {
      var hi = searchingUpward ? Math.ceil(metrics.width*2.5) : metrics.width,
          lo = searchingUpward ? metrics.width : Math.floor(metrics.width/2.5),
          middle ,
          now = new Date()*1,
          count = 0;
      while(hi-lo>1 || (metrics.height>necessaryHeight&&!searchingUpward) || (metrics.height<necessaryHeight&&searchingUpward)) {
        count++;
        middle = (hi+lo)/2;
        exEl = applyMax(exEl,middle);
        metrics = SC.metricsForString(string,exEl,classNames,ignoreEscape);
        if(metrics.height>necessaryHeight) lo = middle;
        else                               hi = middle;
      }
      metrics.width = Math.ceil(middle);
      metrics.height = necessaryHeight;
      metrics.maxWidth = maxWidth;
      metrics.lineHeight = oneLineHeight;
      metrics.lines = lines;
      metrics.searchPerformed = true;
      metrics.searchTime = new Date()*1 - now;
      metrics.searchCount = count;
    } else {
      if(searchingUpward) metrics = SC.metricsForString(string,exEl=removeMax(exEl),classNames,ignoreEscape);
      metrics.maxWidth = maxWidth;
      metrics.lineHeight = oneLineHeight;
      metrics.lines = lines;
      metrics.searchPerformed = false;
    }
    metrics.browserCorrection = 0;
    if(SC.browser.isIE) metrics.browserCorrection = 1;
    if(SC.browser.isMozilla) metrics.browserCorrection = 1;
    metrics.width = Math.min(maxWidth,metrics.width+metrics.browserCorrection);
    if(cache) {
      var entry = cache.list[lines];
      if(entry && entry.maxWidth<maxWidth) entry.maxWidth = maxWidth;
      if(!entry) entry = cache.list[lines] = metrics;
    }
    if(exIsElement) exEl.style.maxWidth = savedMaxWidth;
    ret = searchingUpward ? ret : metrics;
    // console.error('returning at end'+(searchingUpward?" after searching upward and finding"+CW.Anim.enumerate(metrics):"")+'. Returned value is ',CW.Anim.enumerate(ret));
    return ret;
  },

  /**
    Supply any number of arguments of any type, and this function will return you a hash associated with all those arguments.
    Call it twice with the same arguments in the same order, and the hash is the same. This is great for getting out of
    calculations whose answers depend on many different variables.

    @param {anything} your-arguments Any set of arguments whatsoever. If the FIRST argument is an array (including Arguments
                                     arrays), all other arguments will be ignored and the array will be treated as if its
                                     values at its numerical indices were passed in themselves as individual arguments.
    @returns {Hash} A cached workspace mapped to the ordered *n*-tuple of arguments passed into it.
  */
  cacheSlotFor: function() {
    var     me = arguments.callee.caller,
          curr = me.cache || (me.cache={});
    if(!arguments[0]) return curr;
    var   args = (arguments[0] instanceof Array || arguments[0].callee) ? arguments[0] : arguments,
        length = args.length,
           arg ,
             i ;
    for(i=0; i<length; i++) {
      if(typeof (arg=args[i]) === "object")
        arg = SC.guidFor(arg);
      curr = curr[arg] || (curr[arg]={parent:curr});
    }
    return curr;
  },

  /**
    Returns a wrapped copy of your function that caches its results according to its arguments. This function itself is cached, so
    the function you receive when you pass in a particular function will always be the same function.

    How was does this function handle its own caching? Using itself, of course! :-D

    Use this only on functions without side effects you depend on, and only on functions whose outputs depend entirely on their
    arguments and on nothing else external to them that could change.
  */
  cachedVersionOf: function() {
    var ret = function(func) {
      var ret = function() {     var cache = SC.cacheSlotFor(arguments);
                                 return cache.result || (cache.result = arguments.callee.func.apply(this,arguments));    };
      ret.func = func;
      return ret;
    };
    return ret(ret);
  }()
});

/* >>>>>>>>>> BEGIN source/transitions/adjust_bounce_transition.js */
// ==========================================================================
// Project:   SproutCore
// Copyright: @2013 7x7 Software, Inc.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


SC.mixin(SC.View,
  /** @scope SC.View */ {

  /** @class

    To modify the bounce animation, you may set the following transition
    options in `transitionAdjustOptions`:

      - bounces {Number} the number of bounce back iterations.  Default: 2
      - bounciness {Number} the bounce coefficient.  Default: 0.25
      - duration {Number} the number of seconds for the animation.  Default: 0.4

    @extends SC.ViewTransitionProtocol
    @see SC.View#animate for other timing functions.
    @since Version 1.10
  */
  BOUNCE_ADJUST: {

    /** @private */
    run: function (view, options, finalLayout) {
      var bounces = options.bounces || 2,
        bounciness = options.bounciness || 0.25,
        layout = view.get('layout'),
        frames = [],
        frameCount = (bounces * 2) + 1,
        duration,
        i;

      // Split the duration evenly per frame.
      duration = options.duration || 0.4;
      duration = duration / frameCount;

      // Construct the frame layouts.
      for (i = 0; i < frameCount; i++) {
        if (i % 2) {
          // Bounce back.
          frames[i] = { value: SC.clone(finalLayout), duration: duration, timing: 'ease-out' };
        } else {
          // Hit target.
          if (i === frameCount - 1) {
            frames[i] = { value: SC.clone(finalLayout), duration: duration, timing: 'ease-in-out' };
          } else {
            frames[i] = { value: SC.clone(finalLayout), duration: duration, timing: 'ease-in' };
          }
        }
      }

      // Adjust the bounce frame layouts.
      for (var key in finalLayout) {
        var finalValue = finalLayout[key],
          // The bounce is based on the "distance" to the final value and the bounciness value.
          bounce = Math.round((finalValue - layout[key]) * bounciness);

        // Adjust the layout property for each bounce.
        for (i = 0; i < bounces; i++) {
          // Pull out the bounce frames only.
          frames[(i * 2) + 1].value[key] = finalValue - bounce;

          // Cut back the bounce amount after each bounce
          bounce = Math.round(bounce * 0.5);
        }
      }

      var callback = function () {
        view.didTransitionAdjust();
      };

      // Animate through the frames.
      view._animateFrames(frames, callback, options.delay || 0);
    }
  }

});

/* >>>>>>>>>> BEGIN source/transitions/adjust_smooth_transition.js */
// ==========================================================================
// Project:   SproutCore
// Copyright: @2013 7x7 Software, Inc.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


SC.mixin(SC.View,
  /** @scope SC.View */ {

  /** @class

    To modify the smooth animation, you may set the following transition
    options in `transitionAdjustOptions`:

      - duration {Number} the number of seconds for the animation.  Default: 0.4

    @extends SC.ViewTransitionProtocol
    @see SC.View#animate for other timing functions.
    @since Version 1.10
  */
  SMOOTH_ADJUST: {

    /** @private */
    run: function (view, options, finalLayout) {
      var key,
        value;

      view.animate(finalLayout, {
        delay: options.delay || 0,
        duration: options.duration || 0.4,
        timing: options.timing || 'ease'
      }, function (data) {
        this.didTransitionAdjust();
      });
    }
  }

});

/* >>>>>>>>>> BEGIN source/transitions/adjust_spring_transition.js */
// ==========================================================================
// Project:   SproutCore
// Copyright: @2013 7x7 Software, Inc.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


SC.mixin(SC.View,
  /** @scope SC.View */ {

  /** @class

    To modify the spring animation, you may set the following transition
    options in `transitionAdjustOptions`:

      - springs {Number} the number of spring back iterations.  Default: 4
      - springiness {Number} the spring coefficient.  Default: 0.25
      - duration {Number} the number of seconds for the animation.  Default: 0.4

    @extends SC.ViewTransitionProtocol
    @see SC.View#animate for other timing functions.
    @since Version 1.10
  */
  SPRING_ADJUST: {

    /** @private */
    run: function (view, options, finalLayout) {
      var springs = options.springs || 4,
        springiness = options.springiness || 0.25,
        layout = view.get('layout'),
        frames = [],
        frameCount = springs + 1,
        duration,
        i;

      // Split the duration evenly per frame.
      duration = options.duration || 0.4;
      duration = duration / frameCount;

      // Construct the frame layouts.
      for (i = 0; i < frameCount; i++) {
        if (i !== 0) {
          frames[i] = { value: SC.clone(finalLayout), duration: duration, timing: 'ease-in-out' };
        } else {
          frames[i] = { value: SC.clone(finalLayout), duration: duration, timing: 'ease-out' };
        }
      }

      // Adjust the spring frame layouts.
      for (var key in finalLayout) {
        var finalValue = finalLayout[key],
          // The spring is based on the "distance" to the final value and the springiness value.
          spring = Math.round((finalValue - layout[key]) * springiness);

        // Adjust the layout property for each spring.
        for (i = 0; i < springs; i++) {
          if (i % 2) {
            frames[i].value[key] = finalValue - spring; // Overshoot back.
          } else {
            frames[i].value[key] = finalValue + spring; // Overshoot forward.
          }

          // Cut back the spring amount after each spring
          spring = Math.round(spring * 0.5);
        }
      }

      var callback = function () {
        view.didTransitionAdjust();
      };

      // Animate through the frames.
      view._animateFrames(frames, callback, options.delay || 0);
    }
  }

});

/* >>>>>>>>>> BEGIN source/transitions/bounce_transition.js */
// ==========================================================================
// Project:   SproutCore
// Copyright: @2013 7x7 Software, Inc.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


SC.mixin(SC.View,
  /** @scope SC.View */ {

 /** @class

    @extends SC.ViewTransitionProtocol
    @since Version 1.10
  */
  BOUNCE_IN: {

    /** @private */
    setup: function (view, options, inPlace) {
      var parentView = view.get('parentView'),
        parentFrame,
        viewFrame = view.get('borderFrame'),
        left,
        top;


      if (inPlace) {
        // Move from the current position.
      } else {
        // If there is no parentView, use the window's frame.
        if (parentView) {
          parentFrame = parentView.get('borderFrame');
        } else {
          parentFrame = SC.RootResponder.responder.currentWindowSize;
        }

        switch (options.direction) {
        case 'left':
          left = parentFrame.width;
          break;
        case 'up':
          top = parentFrame.height;
          break;
        case 'down':
          top = -viewFrame.height;
          break;
        default:
          left = -viewFrame.width;
        }
      }

      view.adjust({ centerX: null, centerY: null, bottom: null, left: left || viewFrame.x, right: null, top: top || viewFrame.y, height: viewFrame.height, width: viewFrame.width });
    },

    /** @private */
    run: function (view, options, finalLayout, finalFrame) {
      var layout = view.get('layout'),
        bounciness = options.bounciness || 0.25,
        bounce,
        duration,
        frames,
        finalValue,
        value, bounce1, bounce2;

      switch (options.direction) {
      case 'left':
        finalValue = finalFrame.x;
        value = { left: finalValue };
        bounce = -(finalValue - layout.left) * bounciness;
        bounce1 = { left: finalValue + bounce };
        bounce2 = { left: finalValue + (bounce * 0.5) };
        break;
      case 'up':
        finalValue = finalFrame.y;
        value = { top: finalValue };
        bounce = -(finalValue - layout.top) * bounciness;
        bounce1 = { top: finalValue + bounce };
        bounce2 = { top: finalValue + (bounce * 0.5) };
        break;
      case 'down':
        finalValue = finalFrame.y;
        value = { top: finalValue };
        bounce = (layout.top - finalValue) * bounciness;
        bounce1 = { top: finalValue + bounce };
        bounce2 = { top: finalValue + (bounce * 0.5) };
        break;
      default:
        finalValue = finalFrame.x;
        value = { left: finalValue };
        bounce = (layout.left - finalValue) * bounciness;
        bounce1 = { left: finalValue + bounce };
        bounce2 = { left: finalValue + (bounce * 0.5) };
      }

      // Split the duration evenly per frame.
      duration = options.duration || 0.4;
      duration = duration * 0.2;

      // Define the frames.
      frames = [
        { value: value, duration: duration, timing: 'ease-in' },
        { value: bounce1, duration: duration, timing: 'ease-out' },
        { value: value, duration: duration, timing: 'ease-in' },
        { value: bounce2, duration: duration, timing: 'ease-out' },
        { value: value, duration: duration, timing: 'ease-in-out' }
      ];

      var callback = function (data) {
        if (!data.isCancelled) {
          view.didTransitionIn();
        }
      };

      // Animate through the frames.
      view._animateFrames(frames, callback, options.delay || 0);
    }
  },


  /** @class

    @extends SC.ViewTransitionProtocol
    @since Version 1.10
  */
  BOUNCE_OUT: {

    /** @private */
    setup: function (view, options) {
      var viewFrame = view.get('borderFrame'),
        left = viewFrame.x,
        top = viewFrame.y,
        height = viewFrame.height,
        width = viewFrame.width;

      view.adjust({ centerX: null, centerY: null, bottom: null, left: left, right: null, top: top, height: height, width: width });
    },

    /** @private */
    run: function (view, options, finalLayout, finalFrame) {
      var bounciness = options.bounciness || 0.25,
        bounce,
        bounceValue,
        bounceValue2,
        duration,
        finalValue,
        frames,
        layout = view.get('layout'),
        viewFrame = view.get('borderFrame'),
        parentView = view.get('parentView'),
        parentFrame,
        startValue;

      // If there is no parentView, use the window's frame.
      if (parentView) {
        parentFrame = parentView.get('borderFrame');
      } else {
        parentFrame = SC.RootResponder.responder.currentWindowSize;
      }

      switch (options.direction) {
      case 'left':
        startValue = { left: layout.left };
        finalValue = { left: -viewFrame.width };
        bounce = (layout.left + viewFrame.width) * bounciness;
        bounceValue = { left: layout.left - (bounce * 0.5) };
        bounceValue2 = { left: layout.left - bounce };
        break;
      case 'up':
        startValue = { top: layout.top };
        finalValue = { top: -viewFrame.height };
        bounce = (layout.top + viewFrame.height) * bounciness;
        bounceValue = { top: layout.top - (bounce * 0.5) };
        bounceValue2 = { top: layout.top - bounce };
        break;
      case 'down':
        startValue = { top: layout.top };
        finalValue = { top: parentFrame.height };
        bounce = (parentFrame.height - layout.top) * bounciness;
        bounceValue = { top: layout.top + (bounce * 0.5) };
        bounceValue2 = { top: layout.top + bounce };
        break;
      default:
        startValue = { left: layout.left };
        finalValue = { left: parentFrame.width };
        bounce = (parentFrame.width - layout.left) * bounciness;
        bounceValue = { left: layout.left + (bounce * 0.5) };
        bounceValue2 = { left: layout.left + bounce };
      }

      // Split the duration evenly per frame.
      duration = options.duration || 0.6;
      duration = duration * 0.2;

      // Define the frames.
      frames = [
        { value: bounceValue, duration: duration, timing: 'ease-out' },
        { value: startValue, duration: duration, timing: 'ease-in' },
        { value: bounceValue2, duration: duration, timing: 'ease-out' },
        { value: startValue, duration: duration, timing: 'ease-in-out' },
        { value: finalValue, duration: duration, timing: 'ease-in' }
      ];

      var callback = function (data) {
        if (!data.isCancelled) {
          view.didTransitionOut();
        }
      };

      // Animate through the frames.
      view._animateFrames(frames, callback, options.delay || 0);
    }

  }

});

/* >>>>>>>>>> BEGIN source/transitions/fade_transition.js */
// ==========================================================================
// Project:   SproutCore
// Copyright: @2013 7x7 Software, Inc.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


SC.mixin(SC.View,
  /** @scope SC.View */ {

  /** @class

    @extends SC.ViewTransitionProtocol
    @see SC.View#animate for other timing functions.
    @since Version 1.10
  */
  FADE_IN: {

    /* @private */
    layoutProperties: ['opacity'],

    /** @private */
    setup: function (view, options, inPlace) {
      view.adjust({ opacity: inPlace ? view.get('layout').opacity || 0 : 0 });
    },

    /** @private */
    run: function (view, options, finalLayout, finalFrame) {
      view.animate('opacity', finalLayout.opacity || 1, {
        delay: options.delay || 0,
        duration: options.duration || 0.4,
        timing: options.timing || 'ease'
      }, function (data) {
        if (!data.isCancelled) {
          this.didTransitionIn();
        }
      });
    }
  },

  /** @class

    @extends SC.ViewTransitionProtocol
    @see SC.View#animate for other timing functions.
    @since Version 1.10
  */
  FADE_OUT: {

    /* @private */
    layoutProperties: ['opacity'],

    /** @private */
    run: function (view, options) {
      view.animate('opacity', 0, {
        delay: options.delay || 0,
        duration: options.duration || 0.4,
        timing: options.timing || 'ease'
      }, function (data) {
        if (!data.isCancelled) {
          this.didTransitionOut();
        }
      });
    }

  }

});

/* >>>>>>>>>> BEGIN source/transitions/pop_transition.js */
// ==========================================================================
// Project:   SproutCore
// Copyright: @2013 7x7 Software, Inc.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


SC.mixin(SC.View,
  /** @scope SC.View */ {

  /** @class

    @extends SC.ViewTransitionProtocol
    @since Version 1.10
  */
  POP_IN: {

    /* @private */
    layoutProperties: ['scale'],

    /** @private */
    setup: function (view, options, inPlace) {
      view.adjust({ scale: inPlace ? view.get('layout').scale || 0 : 0 });
    },

    /** @private */
    run: function (view, options, finalLayout, finalFrame) {
      var bigScale,
        duration,
        frames,
        poppiness = options.poppiness || 0.2,
        scale;

      scale = finalLayout.scale || 1;
      bigScale = scale * (poppiness + 1);

      duration = options.duration || 0.25;

      frames = [
        { value: { scale: bigScale }, duration: duration * 0.6, timing: 'ease-out' },
        { value: { scale: scale }, duration: duration * 0.4, timing: 'ease-in-out' }
      ];

      var callback = function (data) {
        if (!data.isCancelled) {
          view.didTransitionIn();
        }
      };

      // Animate through the frames.
      view._animateFrames(frames, callback, options.delay || 0);
    }
  },

  /** @class

    @extends SC.ViewTransitionProtocol
    @since Version 1.10
  */
  POP_OUT: {

    /* @private */
    layoutProperties: ['scale'],

    /** @private */
    run: function (view, options) {
      var bigScale,
        duration,
        frames,
        poppiness = options.poppiness || 0.15,
        scale;

      scale = view.get('layout').scale || 1;
      bigScale = scale * (poppiness + 1);

      duration = options.duration || 0.2;

      frames = [
        { value: { scale: bigScale }, duration: duration * 0.4, timing: 'ease-out' },
        { value: { scale: 0 }, duration: duration * 0.6, timing: 'ease-in-out' }
      ];

      var callback = function (data) {
        if (!data.isCancelled) {
          view.didTransitionOut();
        }
      };

      // Animate through the frames.
      view._animateFrames(frames, callback, options.delay || 0);
    }
  }
});

/* >>>>>>>>>> BEGIN source/transitions/scale_transition.js */
// ==========================================================================
// Project:   SproutCore
// Copyright: @2013 7x7 Software, Inc.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


SC.mixin(SC.View,
  /** @scope SC.View */ {

  /** @class

    @extends SC.ViewTransitionProtocol
    @since Version 1.10
  */
  SCALE_IN: {

    /* @private */
    layoutProperties: ['scale'],

    /** @private */
    setup: function (view, options, inPlace) {
      view.adjust({ scale: inPlace ? view.get('layout').scale || 0 : 0 });
    },

    /** @private */
    run: function (view, options, finalLayout, finalFrame) {
      view.animate('scale', finalLayout.scale || 1, {
        delay: options.delay || 0,
        duration: options.duration || 0.4,
        timing: options.timing || 'ease'
      }, function (data) {
        if (!data.isCancelled) {
          this.didTransitionIn();
        }
      });
    }
  },

  /** @class

    @extends SC.ViewTransitionProtocol
    @since Version 1.10
  */
  SCALE_OUT: {

    /* @private */
    layoutProperties: ['scale'],

    /** @private */
    run: function (view, options) {
      view.animate('scale', 0, {
        delay: options.delay || 0,
        duration: options.duration || 0.4,
        timing: options.timing || 'ease'
      }, function (data) {
        if (!data.isCancelled) {
          this.didTransitionOut();
        }
      });
    }

  }
});

/* >>>>>>>>>> BEGIN source/transitions/slide_transition.js */
// ==========================================================================
// Project:   SproutCore
// Copyright: @2013 7x7 Software, Inc.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


SC.mixin(SC.View,
  /** @scope SC.View */ {

  /** @class

    @extends SC.ViewTransitionProtocol
    @see SC.View#animate for other timing functions.
    @since Version 1.10
  */
  SLIDE_IN: {

    layoutProperties: ['top', 'bottom', 'left', 'right', 'height', 'width', 'centerX', 'centerY'],

    /** @private Starts from outside of parent unless inPlace is true. */
    setup: function (view, options, inPlace) {
      var parentView = view.get('parentView'),
        parentFrame,
        viewFrame = view.get('borderFrame'),
        left,
        top;

      if (inPlace) {
        // Move from the current position.
      } else {
        // If there is no parentView, use the window's frame.
        if (parentView) {
          parentFrame = parentView.get('borderFrame');
        } else {
          parentFrame = SC.RootResponder.responder.currentWindowSize;
        }

        switch (options.direction) {
        case 'left':
          left = parentFrame.width;
          break;
        case 'up':
          top = parentFrame.height;
          break;
        case 'down':
          top = -viewFrame.height;
          break;
        default:
          left = -viewFrame.width;
        }
      }

      // Convert to a HW accelerate-able layout.
      view.adjust({ centerX: null, centerY: null, bottom: null, left: left || viewFrame.x, right: null, top: top || viewFrame.y, height: viewFrame.height, width: viewFrame.width });
    },

    /** @private */
    run: function (view, options, finalLayout, finalFrame) {
      var key,
        value;

      if (options.direction === 'up' || options.direction === 'down') {
        key = 'top';
        value = finalFrame.y;
      } else {
        key = 'left';
        value = finalFrame.x;
      }

      view.animate(key, value, {
        delay: options.delay || 0,
        duration: options.duration || 0.4,
        timing: options.timing || 'ease'
      }, function (data) {
        if (!data.isCancelled) {
          this.didTransitionIn();
        }
      });
    }
  },

  /** @class

    @extends SC.ViewTransitionProtocol
    @see SC.View#animate for other timing functions.
    @since Version 1.10
  */
  SLIDE_OUT: {

    layoutProperties: ['top', 'bottom', 'left', 'right', 'height', 'width', 'centerX', 'centerY'],

    /** @private Starts from current position. */
    setup: function (view, options) {
      var viewFrame = view.get('borderFrame'),
        left = viewFrame.x,
        top = viewFrame.y,
        height = viewFrame.height,
        width = viewFrame.width;

      view.adjust({ centerX: null, centerY: null, bottom: null, left: left, right: null, top: top, height: height, width: width });
    },

    /** @private */
    run: function (view, options, finalLayout, finalFrame) {
      var viewFrame = view.get('borderFrame'),
        parentView = view.get('parentView'),
        parentFrame,
        key, value;

      // If there is no parentView, use the window's frame.
      if (parentView) {
        parentFrame = parentView.get('borderFrame');
      } else {
        parentFrame = SC.RootResponder.responder.currentWindowSize;
      }

      switch (options.direction) {
      case 'left':
        key = 'left';
        value = -viewFrame.width;
        break;
      case 'up':
        key = 'top';
        value = -viewFrame.height;
        break;
      case 'down':
        key = 'top';
        value = parentFrame.height;
        break;
      default:
        key = 'left';
        value = parentFrame.width;
      }

      view.animate(key, value, {
        delay: options.delay || 0,
        duration: options.duration || 0.4,
        timing: options.timing || 'ease'
      }, function (data) {
        if (!data.isCancelled) {
          this.didTransitionOut();
        }
      });
    }
  }

});

/* >>>>>>>>>> BEGIN source/transitions/spring_transition.js */
// ==========================================================================
// Project:   SproutCore
// Copyright: @2013 7x7 Software, Inc.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


SC.mixin(SC.View,
  /** @scope SC.View */ {

  /** @class

    @extends SC.ViewTransitionProtocol
    @since Version 1.10
  */
  SPRING_IN: {

    /** @private */
    setup: function (view, options, inPlace) {
      var parentView = view.get('parentView'),
        parentFrame,
        viewFrame = view.get('borderFrame'),
        left,
        top;

      if (inPlace) {
        // Move from the current position.
      } else {
        // If there is no parentView, use the window's frame.
        if (parentView) {
          parentFrame = parentView.get('borderFrame');
        } else {
          parentFrame = SC.RootResponder.responder.currentWindowSize;
        }

        switch (options.direction) {
        case 'left':
          left = parentFrame.width;
          break;
        case 'up':
          top = parentFrame.height;
          break;
        case 'down':
          top = -viewFrame.height;
          break;
        default:
          left = -viewFrame.width;
        }
      }

      view.adjust({ centerX: null, centerY: null, bottom: null, left: left || viewFrame.x, right: null, top: top || viewFrame.y, height: viewFrame.height, width: viewFrame.width });
    },

    /** @private */
    run: function (view, options, finalLayout, finalFrame) {
      var layout = view.get('layout'),
        springiness = options.springiness || 0.25,
        spring,
        duration,
        frames,
        finalValue,
        spring1, spring2, spring3,
        value;

      switch (options.direction) {
      case 'left':
        finalValue = finalFrame.x;
        value = { left: finalValue };
        spring = (layout.left - finalValue) * springiness;
        spring1 = { left: finalValue - spring };
        spring2 = { left: finalValue + (spring * 0.5) };
        spring3 = { left: finalValue - (spring * 0.25) };
        break;
      case 'up':
        finalValue = finalFrame.y;
        value = { top: finalValue };
        spring = (layout.top - finalValue) * springiness;
        spring1 = { top: finalValue - spring };
        spring2 = { top: finalValue + (spring * 0.5) };
        spring3 = { top: finalValue - (spring * 0.25) };
        break;
      case 'down':
        finalValue = finalFrame.y;
        value = { top: finalValue };
        spring = (finalValue - layout.top) * springiness;
        spring1 = { top: finalValue + spring };
        spring2 = { top: finalValue - (spring * 0.5) };
        spring3 = { top: finalValue + (spring * 0.25) };
        break;
      default:
        finalValue = finalFrame.x;
        value = { left: finalValue };
        spring = (finalValue - layout.left) * springiness;
        spring1 = { left: finalValue + spring };
        spring2 = { left: finalValue - (spring * 0.5) };
        spring3 = { left: finalValue + (spring * 0.25) };
      }

      // Split the duration evenly per frame.
      duration = options.duration || 0.4;
      duration = duration * 0.25;

      // Define the frames.
      frames = [
        { value: spring1, duration: duration, timing: 'ease-out' }, // Overshoot.
        { value: spring2, duration: duration, timing: 'ease-in-out' }, // Overshoot back.
        { value: spring3, duration: duration, timing: 'ease-in-out' }, // Overshoot.
        { value: value, duration: duration, timing: 'ease-in-out' } // Hit target.
      ];

      var callback = function (data) {
        if (!data.isCancelled) {
          view.didTransitionIn();
        }
      };

      // Animate through the frames.
      view._animateFrames(frames, callback, options.delay || 0);
    }
  },

  /** @class

    @extends SC.ViewTransitionProtocol
    @since Version 1.10
  */
  SPRING_OUT: {

    /** @private */
    setup: function (view, options) {
      var viewFrame = view.get('borderFrame'),
        left = viewFrame.x,
        top = viewFrame.y,
        height = viewFrame.height,
        width = viewFrame.width;

      view.adjust({ centerX: null, centerY: null, bottom: null, left: left, right: null, top: top, height: height, width: width });
    },

    /** @private */
    run: function (view, options, finalLayout, finalFrame) {
      var springiness = options.springiness || 0.25,
        duration,
        finalValue,
        frames,
        layout = view.get('layout'),
        viewFrame = view.get('borderFrame'),
        parentView = view.get('parentView'),
        parentFrame,
        spring,
        spring1, spring2;

      // If there is no parentView, use the window's frame.
      if (parentView) {
        parentFrame = parentView.get('borderFrame');
      } else {
        parentFrame = SC.RootResponder.responder.currentWindowSize;
      }

      switch (options.direction) {
      case 'left':
        finalValue = { left: -viewFrame.width };
        spring = (layout.left + viewFrame.width) * springiness;
        spring1 = { left: layout.left - (spring * 0.5) };
        spring2 = { left: layout.left + spring };
        break;
      case 'up':
        finalValue = { top: -viewFrame.height };
        spring = (layout.top + viewFrame.height) * springiness;
        spring1 = { top: layout.top - (spring * 0.5) };
        spring2 = { top: layout.top + spring };
        break;
      case 'down':
        finalValue = { top: parentFrame.height };
        spring = (parentFrame.height - layout.top) * springiness;
        spring1 = { top: layout.top + (spring * 0.5) };
        spring2 = { top: layout.top - spring };
        break;
      default:
        finalValue = { left: parentFrame.width };
        spring = (parentFrame.width - layout.left) * springiness;
        spring1 = { left: layout.left + (spring * 0.5) };
        spring2 = { left: layout.left - spring };
      }

      // Split the duration evenly per frame.
      duration = options.duration || 0.3;
      duration = duration * 0.33;

      // Define the frames.
      frames = [
        { value: spring1, duration: duration, timing: 'ease-in-out' },
        { value: spring2, duration: duration, timing: 'ease-in-out' },
        { value: finalValue, duration: duration, timing: 'ease-in' }
      ];

      var callback = function (data) {
        if (!data.isCancelled) {
          view.didTransitionOut();
        }
      };

      // Animate through the frames.
      view._animateFrames(frames, callback, options.delay || 0);
    }
  }
});

/* >>>>>>>>>> BEGIN source/views/container.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


/** @class

  A container view will display its "content" view as its only child.  You can
  use a container view to easily swap out views on your page.  In addition to
  displaying the actual view in the content property, you can also set the
  nowShowing property to the property path of a view in your page and the
  view will be found and swapped in for you.

  # Animated Transitions

  To animate the transition between views, you can provide a transitionSwap
  plugin to SC.ContainerView.  There are several common transitions pre-built
  and if you want to create your own, the SC.ViewTransitionProtocol defines the
  methods to implement.

  The transitions included with SC.ContainerView are:

    - SC.ContainerView.DISSOLVE - fades between the two views
    - SC.ContainerView.FADE_COLOR - fades out to a color and then in to the new view
    - SC.ContainerView.MOVE_IN - moves the new view in over top of the old view
    - SC.ContainerView.PUSH - pushes the old view out with the new view
    - SC.ContainerView.REVEAL - moves the old view out revealing the new view underneath

  To use a transitionSwap plugin, simply set it as the value of the container view's
  `transitionSwap` property.

  For example,

      container = SC.ContainerView.create({
        transitionSwap: SC.ContainerView.PUSH
      });

  Since each transitionSwap plugin predefines a unique animation, SC.ContainerView
  provides the transitionSwapOptions property to allow for modifications to the
  animation.

  For example,

      container = SC.ContainerView.create({
        transitionSwap: SC.ContainerView.PUSH,
        transitionSwapOptions: {
          duration: 1.25,    // Use a longer duration then default
          direction: 'up'    // Push the old content up
        }
      });

  All the predefined transitionSwap plugins take options to modify the default
  duration and timing of the animation and to see what other options are
  available, refer to the documentation of the plugin.

  @extends SC.View
  @since SproutCore 1.0
*/
SC.ContainerView = SC.View.extend(
  /** @scope SC.ContainerView.prototype */ {

  // ------------------------------------------------------------------------
  // Properties
  //

  /**
    @type Array
    @default ['sc-container-view']
    @see SC.View#classNames
    @see SC.Object#concatenatedProperties
  */
  classNames: ['sc-container-view'],

  /**
    The content view to display.  This will become the only child view of
    the view.  Note that if you set the nowShowing property to any value other
    than 'null', the container view will automatically change the contentView
    to reflect view indicated by the value.

    @type SC.View
    @default null
  */
  contentView: null,

  /** @private */
  contentViewBindingDefault: SC.Binding.single(),

  /**
    Whether the container view is in the process of transitioning or not.

    You should observe this property in order to delay any updates to the new
    content until the transition is complete.

    @type Boolean
    @default false
    @since Version 1.10
  */
  isTransitioning: NO,

  /**
    Optional path name for the content view.  Set this to a property path
    pointing to the view you want to display.  This will automatically change
    the content view for you. If you pass a relative property path or a single
    property name, then the container view will look for it first on its page
    object then relative to itself. If you pass a full property name
    (e.g. "MyApp.anotherPage.anotherView"), then the path will be followed
    from the top-level.

    @type String|SC.View
    @default null
  */
  nowShowing: null,

  /** @private */
  renderDelegateName: 'containerRenderDelegate',

  /**
    The transitionSwap plugin to use when swapping views.

    SC.ContainerView uses a pluggable transition architecture where the
    transition setup, animation and cleanup can be handled by a specified
    transitionSwap plugin.

    There are a number of pre-built plugins available:

      SC.ContainerView.DISSOLVE
      SC.ContainerView.FADE_COLOR
      SC.ContainerView.MOVE_IN
      SC.ContainerView.PUSH
      SC.ContainerView.REVEAL

    You can even provide your own custom transitionSwap plugins.  Just create an
    object that conforms to the SC.SwapTransitionProtocol protocol.

    @type Object (SC.SwapTransitionProtocol)
    @default null
    @since Version 1.10
  */
  transitionSwap: null,

  /**
    The options for the given transitionSwap plugin.

    These options are specific to the current transitionSwap plugin used and are
    used to modify the transition animation.  To determine what options
    may be used for a given transition and to see what the default options are,
    see the documentation for the transition plugin being used.

    Most transitions will accept a duration and timing option, but may
    also use other options.  For example, SC.ContainerView.PUSH accepts options
    like:

        transitionSwapOptions: {
          direction: 'left',
          duration: 0.25,
          timing: 'linear'
        }

    @type Object
    @default null
    @since Version 1.10
  */
  transitionSwapOptions: null,

  // ------------------------------------------------------------------------
  // Methods
  //

  /** @private */
  init: function () {
    var view;

    arguments.callee.base.apply(this,arguments);

    if (this.get('nowShowing')) {
      // If nowShowing is directly set, invoke the instantiation of
      // it as well.
      this.nowShowingDidChange();
    } else {
      // If contentView is directly set, then swap it into nowShowing so that it
      // is properly instantiated and ready for swapping.
      // Fixes: https://github.com/sproutcore/sproutcore/issues/1069
      view = this.get('contentView');

      if (view) {
        this.set('nowShowing', view);
      }
    }

    // Observe for changes to the content view and initialize once.
    this.addObserver('contentView', this, this._sc_contentViewDidChange);
    this._sc_contentViewDidChange();
  },

  /** @private Cancels the active transition. */
  _sc_cancelTransitions: function () {
    var contentStatecharts = this._contentStatecharts;

    // Exit all the statecharts immediately. This mutates the array!
    if (contentStatecharts) {
      for (var i = contentStatecharts.length - 1; i >= 0; i--) {
        contentStatecharts[i].doExit(true);
      }
    }
  },

  /** @private
    Overridden to prevent clipping of child views while animating.

    In particular, collection views have trouble being animated in a certain
    manner if they think their clipping frame hides themself.  For example,
    the PUSH transition returns a double width/height frame with an adjusted
    left/top while the transition is in process so neither view thinks it
    is clipped.
   */
  clippingFrame: function () {
    var contentStatecharts = this._contentStatecharts,
      frame = this.get('frame'),
      ret = arguments.callee.base.apply(this,arguments);

    // Allow for a modified clippingFrame while transitioning.
    if (this.get('isTransitioning')) {
      // Each transition may adjust the clippingFrame to accommodate itself.
      for (var i = contentStatecharts.length - 1; i >= 0; i--) {
        ret = contentStatecharts[i].transitionClippingFrame(ret);
      }
    } else {
      ret.width = frame.width;
    }

    return ret;
  }.property('parentView', 'frame').cacheable(),

  /** @private
    Invoked whenever the content property changes.  This method will simply
    call replaceContent.  Override replaceContent to change how the view is
    swapped out.
  */
  _sc_contentViewDidChange: function () {
    var contentView = this.get('contentView');

    // If it's an uninstantiated view, then attempt to instantiate it.
    if (contentView && contentView.kindOf(SC.CoreView)) {
      contentView = this.createChildView(contentView);
    }

    this.replaceContent(contentView);
  },

  /** @private */
  destroy: function () {
    // Clean up observers.
    this.removeObserver('contentView', this, this._sc_contentViewDidChange);

    // Cancel any active transitions.
    // Note: this will also destroy any content view that the container created.
    this._sc_cancelTransitions();

    // Remove our internal reference to the statecharts.
    this._contentStatecharts = this._currentStatechart = null;

    return arguments.callee.base.apply(this,arguments);
  },

  /** @private
    Invoked whenever the nowShowing property changes.  This will try to find
    the new content if possible and set it.  If you set nowShowing to an
    empty string or null, then the current content will be cleared.
  */
  nowShowingDidChange: function () {
    // This code turns this.nowShowing into a view object by any means necessary.
    var content = this.get('nowShowing');

    // If it's a string, try to turn it into the object it references...
    if (SC.typeOf(content) === SC.T_STRING && content.length > 0) {
      var dotspot = content.indexOf('.');
      // No dot means a local property, either to this view or this view's page.
      if (dotspot === -1) {
        var tempContent = this.get(content);
        content = SC.kindOf(tempContent, SC.CoreView) ? tempContent : SC.objectForPropertyPath(content, this.get('page'));
      }
      // Dot at beginning means local property path.
      else if (dotspot === 0) {
        content = this.getPath(content.slice(1));
      }
      // Dot after the beginning
      else {
        content = SC.objectForPropertyPath(content);
      }
    }

    // If it's an uninstantiated view, then attempt to instantiate it.
    if (content && content.kindOf(SC.CoreView)) {
      content = this.createChildView(content);
    }

    


    // Sets the content.
    this.set('contentView', content);
  }.observes('nowShowing'),

  /** @private Called by new content statechart to indicate that it is ready. */
  statechartReady: function () {
    var contentStatecharts = this._contentStatecharts;

    // Exit all other remaining statecharts immediately.  This mutates the array!
    // This allows transitions where the previous content is left in place to
    // clean up all previous content once the new content transitions in.
    for (var i = contentStatecharts.length - 2; i >= 0; i--) {
      contentStatecharts[i].doExit(true);
    }

    this.set('isTransitioning', NO);
  },

  /** @private Called by content statecharts to indicate that they have exited. */
  statechartEnded: function (statechart) {
    var contentStatecharts = this._contentStatecharts;

    // Remove the statechart.
    contentStatecharts.removeObject(statechart);

    // Once all the other statecharts have exited. Indicate that the current
    // statechart is entered. This allows transitions where the new
    // content is left in place to update state once all previous statecharts
    // have exited.
    if (contentStatecharts.length === 1) {
      contentStatecharts[0].entered();
    }
  },

  /** @private
    Replaces any child views with the passed new content.

    This method is automatically called whenever your contentView property
    changes.  You can override it if you want to provide some behavior other
    than the default.

    @param {SC.View} newContent the new content view or null.
  */
  replaceContent: function (newContent) {
    var contentStatecharts,
      currentStatechart = this._currentStatechart,
      newStatechart;

    // Track that we are transitioning.
    this.set('isTransitioning', YES);

    // Create a statechart for the new content.
    contentStatecharts = this._contentStatecharts;
    if (!contentStatecharts) { contentStatecharts = this._contentStatecharts = []; }

    // Call doExit on all current content statecharts.  Any statecharts in the
    // process of exiting may accelerate their exits.
    for (var i = contentStatecharts.length - 1; i >= 0; i--) {
      var found = contentStatecharts[i].doExit(false, newContent);

      // If the content already belongs to a content statechart reuse that statechart.
      if (found) {
        newStatechart = contentStatecharts[i];
        if (newStatechart) {
          newStatechart.set('previousStatechart', currentStatechart);
          newStatechart.gotoEnteringState();
        }
      }
    }

    // Add the new content statechart, which will enter automatically.
    if (!newStatechart) {
      newStatechart = SC.ContainerContentStatechart.create({
        container: this,
        content: newContent,
        previousStatechart: currentStatechart
      });

      contentStatecharts.pushObject(newStatechart);
    }

    // Track the current statechart.
    this._currentStatechart = newStatechart;
  },

  /** @private SC.Observable.prototype */
  set: function (key, value) {

    // Changing the transitionSwap in the middle of a transition must cancel the transitions.
    if (key === 'transitionSwap' && this.get('isTransitioning')) {
      


      // Cancel the active transitions.
      this._sc_cancelTransitions();
    }

    return arguments.callee.base.apply(this,arguments);
  }

});


// When in debug mode, core developers can log the container content states.



/** @private
  In order to support transitioning views in and out of the container view,
  each content view needs its own simple statechart.  This is required, because
  while only one view will ever be transitioning in, several views may be in
  the process of transitioning out.  See the 'SC.ContainerView Statechart.graffle'
  file in the repository.
*/
SC.ContainerContentStatechart = SC.Object.extend({

  // ------------------------------------------------------------------------
  // Properties
  //

  container: null,

  content: null,

  previousStatechart: null,

  state: 'none',

  // ------------------------------------------------------------------------
  // Methods
  //

  init: function () {
    arguments.callee.base.apply(this,arguments);

    // Default entry state.
    this.gotoEnteringState();
  },

  transitionClippingFrame: function (clippingFrame) {
    var container = this.get('container'),
      options = container.get('transitionSwapOptions') || {},
      transitionSwap = container.get('transitionSwap');

    if (transitionSwap && transitionSwap.transitionClippingFrame) {
      return transitionSwap.transitionClippingFrame(container, clippingFrame, options);
    } else {
      return clippingFrame;
    }
  },

  // ------------------------------------------------------------------------
  // Actions & Events
  //

  entered: function () {
    


    if (this.state === 'entering') {
      this.gotoReadyState();
    }
  },

  doExit: function (immediately, newContent) {
    if (this.state !== 'exited') {
      this.gotoExitingState(immediately, newContent);
    

    }

    // If the new content matches our own content, indicate this to the container.
    if (this.get('content') === newContent) {
      return true;
    } else {
      return false;
    }
  },

  exited: function () {
    


    if (this.state === 'exiting') {
      this.gotoExitedState();
    }
  },

  // ------------------------------------------------------------------------
  // States
  //

  // Entering
  gotoEnteringState: function () {
    var container = this.get('container'),
      content = this.get('content'),
      previousStatechart = this.get('previousStatechart'),
      options = container.get('transitionSwapOptions') || {},
      transitionSwap = container.get('transitionSwap');

    


    // If currently in the exiting state, reverse to entering.
    if (this.state === 'exiting' && transitionSwap.reverseBuildOut) {
      transitionSwap.reverseBuildOut(this, container, content, options);

      // Assign the state.
      this.set('state', 'entering');

      // Fast path!!
      return;
    } else if (content) {
      container.appendChild(content);
    }

    // Assign the state.
    this.set('state', 'entering');

    // Don't transition unless there is a previous statechart.
    if (previousStatechart && content && transitionSwap) {
      if (transitionSwap.willBuildInToView) {
        transitionSwap.willBuildInToView(container, content, previousStatechart, options);
      }

      if (transitionSwap.buildInToView) {
        transitionSwap.buildInToView(this, container, content, previousStatechart, options);
      } else {
        this.entered();
      }
    } else {
      this.entered();
    }
  },

  // Exiting
  gotoExitingState: function (immediately) {
    var container = this.get('container'),
      content = this.get('content'),
      exitCount = this._exitCount,
      options = container.get('transitionSwapOptions') || {},
      transitionSwap = container.get('transitionSwap');

    


    // If currently in the entering state, reverse to exiting.
    if (this.state === 'entering' && transitionSwap.reverseBuildIn) {
      transitionSwap.reverseBuildIn(this, container, content, options);

      // Assign the state.
      this.set('state', 'exiting');

      // Fast path!!
      return;
    }

    // Assign the state.
    this.set('state', 'exiting');

    if (!immediately && content && transitionSwap) {
      // Re-entering the exiting state may need to accelerate the transition, pass the count to the plugin.
      if (!exitCount) { exitCount = this._exitCount = 1; }

      if (transitionSwap.willBuildOutFromView) {
        transitionSwap.willBuildOutFromView(container, content, options, exitCount);
      }

      if (transitionSwap.buildOutFromView) {
        transitionSwap.buildOutFromView(this, container, content, options, exitCount);
      } else {
        // this.exited();
      }

      // Increment the exit count each time doExit is called.
      this._exitCount += 1;
    } else {
      this.exited();
    }
  },

  // Exited
  gotoExitedState: function () {
    var container = this.get('container'),
      content = this.get('content'),
      options = container.get('transitionSwapOptions') || {},
      transitionSwap = container.get('transitionSwap');

    


    if (content) {
      if (transitionSwap && transitionSwap.didBuildOutFromView) {
        transitionSwap.didBuildOutFromView(container, content, options);
      }

      if (content.createdByParent) {
        container.removeChildAndDestroy(content);
      } else {
        container.removeChild(content);
      }
    }

    // Send ended event to container view statechart.
    container.statechartEnded(this);

    // Reset the exiting count.
    this._exitCount = 0;

    // Assign the state.
    this.set('state', 'exited');
  },

  // Ready
  gotoReadyState: function () {
    var container = this.get('container'),
      content = this.get('content'),
      options = container.get('transitionSwapOptions') || {},
      transitionSwap = container.get('transitionSwap');

    


    if (content && transitionSwap && transitionSwap.didBuildInToView) {
      transitionSwap.didBuildInToView(container, content, options);
    }

    // Send ready event to container view statechart.
    container.statechartReady();

    // Assign the state.
    this.set('state', 'ready');
  }

});

/* >>>>>>>>>> BEGIN source/transitions/swap_dissolve_transition.js */
// ==========================================================================
// Project:   SproutCore
// Copyright: @2013 7x7 Software, Inc.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
sc_require('views/container');


SC.mixin(SC.ContainerView,
/** @scope SC.ContainerView */ {

  /** @class
    Provides dissolve transitions for SC.ContainerView.  The new content will
    fade in as the old content fades out of the view.

    To modify the dissolve animation, you can set the following transition
    options:

      - duration {Number} the number of seconds for the animation.  Default: 0.4
      - timing {String} the animation timing function.  Default: 'ease'

    @extends SC.ViewTransitionProtocol
    @see SC.View#animate for other timing functions.
    @since Version 1.10
  */
  DISSOLVE: {

    /** @private */
    willBuildInToView: function (container, content, previousStatechart, options) {
      content.adjust({ opacity: 0 });
    },

    /** @private */
    buildInToView: function (statechart, container, content, previousStatechart, options) {
      content.animate('opacity', 1, {
        duration: options.duration || 0.4,
        timing: options.timing || 'ease'
      }, function (data) {
        // We may already be in exiting state by the time we transition in.
        if (statechart.get('state') === 'entering') {
          statechart.entered();
        }
      });
    },

    /** @private */
    buildOutFromView: function (statechart, container, content, options, exitCount) {
      // We can call this transition repeatedly without effecting the current exit transition.
      if (exitCount == 1) {
        // Fade the current content at the same time.
        content.animate('opacity', 0, {
          duration: options.duration || 0.4,
          timing: options.timing || 'ease'
        }, function (data) {
          if (!data.isCancelled) {
            statechart.exited();
          }
        });
      }
    },

    /** @private */
    didBuildOutFromView: function (container, content, options) {
      // Reset the opacity in case this view is used elsewhere.
      content.adjust({ opacity: 1 });
    }

  }
});

/* >>>>>>>>>> BEGIN source/transitions/swap_fade_color_transition.js */
// ==========================================================================
// Project:   SproutCore
// Copyright: @2013 7x7 Software, Inc.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
sc_require('views/container');


SC.mixin(SC.ContainerView,
/** @scope SC.ContainerView */ {

 /** @class
    Provides fade through color transitions to SC.ContainerView.  The old
    content will fade out to a color and the new content will then fade in.

    To modify the fade through color animation, you can set the following
    transition options:

      - color {String} any valid CSS Color.  Default: 'black'
      - duration {Number} the number of seconds for the animation.  Default: 0.4
      - timing {String} the animation timing function.  Default: 'ease'

    @extends SC.ViewTransitionProtocol
    @see SC.View#animate for other timing functions.
    @since Version 1.10
  */
  FADE_COLOR: {

    /** @private */
    willBuildInToView: function (container, content, previousStatechart, options) {
      var color,
        colorView;

      content.adjust({ opacity: 0 });

      // Create a color view to fade through.
      color = SC.Color.from(options.color || 'black');
      colorView = SC.View.create({
        layout: { opacity: 0, zIndex: 1 },
        render: function (context) {
          context.addStyle('background-color', color.get('cssText'));
        }
      });
      container.appendChild(colorView);
    },

    /** @private */
    buildInToView: function (statechart, container, content, previousStatechart, options) {
      var childViews = container.get('childViews'),
        colorView;

      colorView = childViews.objectAt(childViews.get('length') - 1);

      // Fade the color in (uses half the total duration)
      colorView.animate('opacity', 1, {
        duration: options.duration * 0.5 || 0.4,
        timing: options.timing || 'ease-in'
      }, function () {
        // Show new content, then fade the color out.
        content.adjust('opacity', 1);

        colorView.animate('opacity', 0, {
          duration: options.duration * 0.5 || 0.4,
          timing: options.timing || 'ease-in'
        }, function (data) {
          // It's best to clean up the colorView here rather than try to find it again on teardown,
          // since multiple color views could be added.
          container.removeChild(this);
          this.destroy();

          // We may already be in exiting state by the time we transition in.
          if (statechart.get('state') === 'entering') {
            statechart.entered();
          }
        });
      });
    },

    /** @private */
    buildOutFromView: function (statechart, container, content, options, exitCount) {
      // Do nothing.
    }

  }

});

/* >>>>>>>>>> BEGIN source/transitions/swap_move_in_transition.js */
// ==========================================================================
// Project:   SproutCore
// Copyright: @2013 7x7 Software, Inc.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
sc_require('views/container');


SC.mixin(SC.ContainerView,
/** @scope SC.ContainerView */ {

   /** @class
    Provides move in transitions to SC.ContainerView.  The new content will
    move in over top of the old content.

    To modify the move in animation, you can set the following transition
    options:

      - direction {String} the direction to move new content in.  Default: 'left'.
        ** 'left' - moves new content from the right to the left
        ** 'right' - moves new content from the left to the right
        ** 'up' - moves new content from the bottom to the top
        ** 'down' - moves new content from the top to the bottom
      - duration {Number} the number of seconds for the animation.  Default: 0.4
      - timing {String} the animation timing function.  Default: 'ease'

    @extends SC.ViewTransitionProtocol
    @see SC.View#animate for other timing functions.
    @since Version 1.10
  */
  MOVE_IN: {

    /** @private */
    willBuildInToView: function (container, content, previousStatechart, options) {
      var frame = container.get('frame'),
        left,
        top,
        height,
        width;

      height = frame.height;
      width = frame.width;

      switch (options.direction) {
      case 'right':
        left = -width;
        break;
      case 'up':
        top = height;
        break;
      case 'down':
        top = -height;
        break;
      default:
        left = width;
      }

      content.adjust({ bottom: null, left: left || 0, right: null, top: top || 0, height: height, width: width });
    },

    /** @private */
    buildInToView: function (statechart, container, content, previousStatechart, options) {
      var key,
        value;

      switch (options.direction) {
      case 'right':
        key = 'left';
        break;
      case 'up':
        key = 'top';
        break;
      case 'down':
        key = 'top';
        break;
      default:
        key = 'left';
      }

      content.animate(key, 0, {
        duration: options.duration || 0.4,
        timing: options.timing || 'ease'
      }, function (data) {
        // We may already be in exiting state by the time we transition in.
        if (statechart.get('state') === 'entering') {
          statechart.entered();
        }
      });
    },

    /** @private */
    didBuildInToView: function (container, content, options) {
      // Convert to a flexible layout.
      content.adjust({ bottom: 0, right: 0, height: null, width: null });
    },

    /** @private */
    didBuildOutFromView: function (container, content, options) {
      // Convert to a flexible layout (in case we never fully entered).
      content.adjust({ bottom: 0, right: 0, height: null, width: null });
    },

    /** @private */
    buildOutFromView: function (statechart, container, content, options) {
      // Do nothing.
    }
  }

});

/* >>>>>>>>>> BEGIN source/transitions/swap_push_transition.js */
// ==========================================================================
// Project:   SproutCore
// Copyright: @2013 7x7 Software, Inc.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
sc_require('views/container');


SC.mixin(SC.ContainerView,
/** @scope SC.ContainerView */ {
  /** @class
    Provides push transitions to SC.ContainerView.  The new content will push
    the old content out of the view.

    To modify the push animation, you can set the following transition options:

      - direction {String} the direction to push new content in.  Default: 'left'
        ** 'left' - pushes new content from the right to the left
        ** 'right' - pushes new content from the left to the right
        ** 'up' - pushes new content from the bottom to the top
        ** 'down' - pushes new content from the top to the bottom
      - duration {Number} the number of seconds for the animation.  Default: 0.4
      - timing {String} the animation timing function.  Default: 'ease'

    @extends SC.ViewTransitionProtocol
    @see SC.View#animate for other timing functions.
    @since Version 1.10
  */
  PUSH: {

    /** @private */
    willBuildInToView: function (container, content, previousStatechart, options) {
      var adjustLeft = 0,
        adjustTop = 0,
        frame = container.get('frame'),
        left = 0,
        top = 0,
        height,
        width;

      height = frame.height;
      width = frame.width;

      // Push on to the edge of whatever the current position of previous content is.
      if (previousStatechart && previousStatechart.get('content')) {
        var adjustments = previousStatechart.getPath('content.liveAdjustments');

        adjustLeft = adjustments.left || 0;
        adjustTop = adjustments.top || 0;
      }

      switch (options.direction) {
      case 'right':
        left = -width + adjustLeft;
        break;
      case 'up':
        top = height + adjustTop;
        break;
      case 'down':
        top = -height + adjustTop;
        break;
      default:
        left = width + adjustLeft;
      }

      // Convert to an animatable layout.
      content.adjust({ bottom: null, right: null, left: left, top: top, height: height, width: width });
    },

    /** @private */
    buildInToView: function (statechart, container, content, previousStatechart, options) {
      var key;

      switch (options.direction) {
      case 'up':
        key = 'top';
        break;
      case 'down':
        key = 'top';
        break;
      default:
        key = 'left';
      }

      content.animate(key, 0, {
        duration: options.duration || 0.4,
        timing: options.timing || 'ease'
      }, function (data) {
        // We may already be in exiting state by the time we transition in.
        if (statechart.get('state') === 'entering') {
          statechart.entered();
        }
      });
    },

    /** @private */
    didBuildInToView: function (container, content, options) {
      // Convert to a flexible layout.
      content.adjust({ bottom: 0, right: 0, height: null, width: null });
    },

    /** @private */
    willBuildOutFromView: function (container, content, options) {
      var frame = container.get('frame'),
        height,
        width;

      height = frame.height;
      width = frame.width;

      // Convert to an animatable layout.
      content.adjust({ bottom: null, right: null, height: height, width: width });
    },

    /** @private */
    buildOutFromView: function (statechart, container, content, options, exitCount) {
      var frame = container.get('frame'),
        key,
        value;

      switch (options.direction) {
      case 'right':
        key = 'left';
        value = frame.width;
        break;
      case 'up':
        key = 'top';
        value = -frame.height;
        break;
      case 'down':
        key = 'top';
        value = frame.height;
        break;
      default:
        key = 'left';
        value = -frame.width;
      }

      content.animate(key, value * exitCount, {
        duration: options.duration || 0.4,
        timing: options.timing || 'ease'
      }, function (data) {
        if (!data.isCancelled) {
          statechart.exited();
        }
      });
    },

    /** @private */
    didBuildOutFromView: function (container, content, options) {
      // Convert to a flexible layout.
      content.adjust({ bottom: 0, right: 0, height: null, width: null });
    },

    /** @private */
    transitionClippingFrame: function (container, clippingFrame, options) {
      var frame = container.get('frame');

      switch (options.direction) {
      case 'right':
        clippingFrame.width = frame.width * 2;
        clippingFrame.x = -frame.width;
        break;
      case 'up':
        clippingFrame.height = frame.height * 2;
        clippingFrame.y = -frame.height;
        break;
      case 'down':
        clippingFrame.height = frame.height * 2;
        clippingFrame.y = 0;
        break;
      default:
        clippingFrame.width = frame.width * 2;
        clippingFrame.x = 0;
      }

      return clippingFrame;
    }
  }

});

/* >>>>>>>>>> BEGIN source/transitions/swap_reveal_transition.js */
// ==========================================================================
// Project:   SproutCore
// Copyright: @2013 7x7 Software, Inc.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
sc_require('views/container');


SC.mixin(SC.ContainerView,
/** @scope SC.ContainerView */ {
  /** @class
    Provides reveal transitions to SC.ContainerView.  The old content will
    move out revealing the new content underneath.

    To modify the reveal animation, you can set the following transition
    options:

      - direction {String} The direction to move old content off.  Default: 'left'
        ** 'left' - moves old content off to the left
        ** 'right' - moves old content off to the right
        ** 'up' - moves old content off to the top
        ** 'down' - moves old content off to the bottom
      - duration {Number} the number of seconds for the animation.  Default: 0.4
      - timing {String} the animation timing function.  Default: 'ease'

    @extends SC.ViewTransitionProtocol
    @see SC.View#animate for other timing functions.
    @since Version 1.10
  */
  REVEAL: {

    /** @private */
    buildInToView: function (statechart, container, content, previousStatechart, options) {
      // This transition is unique in that we have to wait for the previous
      // content to finish building out entirely, before we can be considered
      // fully entered.
      // if (previousStatechart && previousStatechart.get('content')) {
      //   previousStatechart.addObserver('state', this, this.previousStateDidChange, statechart);
      // }
    },

    /** @private */
    // reverseBuildIn: function (statechart, container, content, options) {
    //   var nextStatechart = container._currentStatechart;

    //   // We were waiting for another view to remove itself previously, now
    //   // we are going out because someone else is coming in. If that someone
    //   // else was also going out, then we should stay put because they are
    //   // going to reverse.
    //   if (nextStatechart && nextStatechart.get('content')) {
    //     nextStatechart.addObserver('state', this, this.nextStateDidChange, statechart);
    //   }
    // },

    /** @private */
    // previousStateDidChange: function (previousStatechart, key, alwaysNull, statechart) {
    //   if (previousStatechart.state === 'exited') {
    //     statechart.entered();

    //     // Clean up.
    //     previousStatechart.removeObserver('state', this, this.previousStateDidChange);
    //   }
    // },

    /** @private */
    didBuildInToView: function (container, content, options) {
      // Convert to a flexible layout.
      content.adjust({ bottom: 0, right: 0, height: null, width: null, zIndex: null });
    },

    /** @private */
    willBuildOutFromView: function (container, content, options, exitCount) {
      var frame = container.get('frame'),
        height,
        width;

      height = frame.height;
      width = frame.width;

      // Convert to a fixed layout. Put this view on top.
      content.adjust({ bottom: null, right: null, height: height, width: width, zIndex: exitCount });
    },

    /** @private */
    buildOutFromView: function (statechart, container, content, options, exitCount) {
      // We can call this transition repeatedly without effecting the current exit transition.
      if (exitCount === 1) {
        var frame = container.get('frame'),
          key,
          value;

        switch (options.direction) {
        case 'right':
          key = 'left';
          value = -frame.width;
          break;
        case 'up':
          key = 'top';
          value = -frame.height;
          break;
        case 'down':
          key = 'top';
          value = frame.height;
          break;
        default:
          key = 'left';
          value = frame.width;
        }

        content.animate(key, value, {
          duration: options.duration || 0.4,
          timing: options.timing || 'ease'
        }, function (data) {
          if (!data.isCancelled) {
            statechart.exited();
          }
        });
      }
    },

    /** @private */
    // reverseBuildOut: function (statechart, container, content, options) {
    //   var key, value;

    //   // Cancel the animation in place.
    //   content.cancelAnimation(SC.LayoutState.CURRENT);

    //   switch (options.direction) {
    //   case 'up':
    //   case 'down':
    //     key = 'top';
    //     value = 0;
    //     break;
    //   default:
    //     key = 'left';
    //     value = 0;
    //   }

    //   content.animate(key, value, {
    //     duration: options.duration || 0.2,
    //     timing: options.timing || 'ease'
    //   }, function (data) {
    //     if (!data.isCancelled) {
    //       statechart.entered();
    //     }
    //   });
    // },

    /** @private */
    didBuildOutFromView: function (container, content, options) {
      // Convert to a flexible layout.
      content.adjust({ top: 0, left: 0, bottom: 0, right: 0, height: null, width: null, zIndex: null });
    }

  }

});

/* >>>>>>>>>> BEGIN source/validators/validator.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('system/string');

SC.VALIDATE_OK = YES;
SC.VALIDATE_NO_CHANGE = NO;

/**
  @class
  
  Validators provide a way for you to implement simple form field validation
  and transformation.  To use a validator, simply name the validator in the
  "validate" attribute in your text field.  For example, if you want to
  validate a field using the PhoneNumberValidator use this:

      <input value="1234567890" validate="phone-number" />

  Validators get notified at three points.  You can implement one or all
  of these methods to support validation.  All of the validate methods except
  for validateKeypress behave the same way.  You are passed a form, field,
  and possibly the oldValue.  You are expected to return Validator.OK or
  an error string.  Inside this method you typically do one of all of the
  following:

  1. You can simply validate the field value and return OK or an error str
  2. You can modify the field value (for example, you could format the
     string to match some predefined format).
  3. If you need to roundtrip the server first to perform validation, you can
     return Validator.OK, then save the form and field info until after the
     roundtrip.  On return, if there is a problem, first verify the field
     value has not changed and then call form.errorFor(field,str) ;

  @extends SC.Object
  @since SproutCore 1.0
*/
SC.Validator = SC.Object.extend(
/** @scope SC.Validator.prototype */ {

  // ..........................................
  // OBJECT VALUE CONVERSION
  //
  // The following methods are used to convert the string value of a field
  // to and from an object value.  The default implementations return
  // the string, but you can override this to provide specific behaviors. 
  // For example, you might add or remove a dollar sign or convert the 
  // value to a number.
  
/**
  Returns the value to set in the field for the passed object value.  
  
  The form and view to be set MAY (but will not always) be passed also.  You
  should override this method to help convert an input object into a value
  that can be displayed by the field.  For example, you might convert a 
  date to a property formatted string or a number to a properly formatted
  value.
  
  @param {Object} object The object to transform
  @param {SC.FormView} form The form this field belongs to. (optional)
  @param {SC.View} view The view the value is required for.
  @returns {Object} a value (usually a string) suitable for display
*/
  fieldValueForObject: function(object, form, view) { return object; },
  
  /**
    Returns the object value for the passed string.
    
    The form and view MAY (but wil not always) be passed also.  You should
    override this method to convert a field value, such as string, into an
    object value suitable for consumption by the rest of the app.  For example
    you may convert a string into a date or a number.
    
    @param {String} value the field value.  (Usually a String).
    @param {SC.FormView} form The form this field belongs to. (optional)
    @param {SC.View} view The view this value was pulled from.
    @returns {Object} an object suitable for consumption by the app.
  */
  objectForFieldValue: function(value, form, view) { return value; },
  
  // ..........................................
  // VALIDATION PRIMITIVES
  //

  /**
    Validate the field value.  
    
    You can implement standard behavior for your validator by using the validate()
    and validateError() methods.  validate() should return NO if the field is not
    valid, YES otherwise.  If you return NO from this method, then the validateError()
    method will be called so you can generate an error object describing the specific problem.

    @param {SC.FormView} form the form this view belongs to
    @param {SC.View} field the field to validate.  Responds to fieldValue.
    @returns {Boolean} YES if field is valid.
  */
  validate: function(form, field) { return true; },

  /**
    Returns an error object if the field is invalid.
  
    This is the other standard validator method that can be used to implement basic validation.
    Return an error object explaining why the field is not valid.  It will only be called if
    validate() returned NO.
    
    The default implementation of this method returns a generic error message with the loc
    string "Invalid.Generate({fieldValue})".  You can simply define this loc string in
    strings.js if you prefer or you can override this method to provide a more specific error message.
  
    @param {SC.FormView} form the form this view belongs to
    @param {SC.View} field the field to validate.  Responds to fieldValue.
    @returns {SC.Error} an error object
  */
  validateError: function(form, field) { 
    return SC.$error(
      SC.String.loc("Invalid.General(%@)", field.get('fieldValue')),
      field.get('fieldKey')) ; 
  },

  // ..........................................
  // VALIDATION API
  //

  /**
    Invoked just before the user ends editing of the field.

    This is a primitive validation method.  You can implement the two higher-level
    methods (validate() and validateError()) if you prefer.
    
    The default implementation calls your validate() method and then validateError()
    if validate() returns NO.  This method should return SC.VALIDATE_OK if validation
    succeeded or an error object if it fails.
  
    @param {SC.FormView} form the form for the field
    @param {SC.View} field the field to validate
    @param {Object} oldValue: the value of the field before the change

    @returns SC.VALIDATE_OK or an error object.
  
  */
  validateChange: function(form, field, oldValue) { 
    return this.validate(form,field) ? SC.VALIDATE_OK : this.validateError(form, field);
  },

  /**
    Invoked just before the form is submitted.
  
    This method gives your validators one last chance to perform validation
    on the form as a whole.  The default version does the same thing as the 
    validateChange() method.
  
    @param {SC.FormView} form the form for the field
    @param {SC.View} field the field to validate

    @returns SC.VALIDATE_OK or an error object.
  
  */  
  validateSubmit: function(form, field) { 
    return this.validate(form,field) ? SC.VALIDATE_OK : this.validateError(form, field);
  },

  /**
    Invoked 1ms after the user types a key (if a change is allowed).  
  
    You can use this validate the new partial string and return an error if 
    needed. The default will validate a partial only if there was already an 
    error. This allows the user to try to get it right before you bug them.
  
    Unlike the other methods, you should return SC.VALIDATE_NO_CHANGE if you
    did not actually validate the partial string.  If you return 
    SC.VALIDATE_OK then any showing errors will be hidden.
  
    @param {SC.FormView} form the form for the field
    @param {SC.View} field the field to validate

    @returns SC.VALIDATE_OK, SC.VALIDATE_NO_CHANGE or an error object.
  */  
  validatePartial: function(form, field) { 
    if (!field.get('isValid')) {
      return this.validate(form,field) ? SC.VALIDATE_OK : this.validateError(form, field);
    } else return SC.VALIDATE_NO_CHANGE ;
  },
  
  /**
    Invoked when the user presses a key.  
  
    This method is used to restrict the letters and numbers the user is 
    allowed to enter.  You should not use this method to perform full 
    validation on the field.  Instead use validatePartial().
  
    @param {SC.FormView} form the form for the field
    @param {SC.View} field the field to validate
    @param {String} char the characters being added
    
    @returns {Boolean} YES if allowed, NO otherwise
  */
  validateKeyDown: function(form, field,charStr) { return true; },

  // .....................................
  // OTHER METHODS

  /**
    Called on all validators when they are attached to a field.  
  
    You can use this to do any setup that you need.  The default does nothing.
    
    @param {SC.FormView} form the form for the field
    @param {SC.View} field the field to validate
  */
  attachTo: function(form,field) { },

  /**
    Called on a validator just before it is removed from a field.  You can 
    tear down any setup you did for the attachTo() method.
    
    @param {SC.FormView} form the form for the field
    @param {SC.View} field the field to validate
  */
  detachFrom: function(form, field) {}

}) ;

SC.Validator.mixin(/** @scope SC.Validator */ {

  /**
    Return value when validation was performed and value is OK.
  */
  OK: true, 
  
  /**
    Return value when validation was not performed.
  */
  NO_CHANGE: false,  

  /**
    Invoked by a field whenever a validator is attached to the field.
    
    The passed validatorKey can be a validator instance, a validator class
    or a string naming a validator. To make your validator
    visible, you should name your validator under the SC.Validator base.
    for example SC.Validator.Number would get used for the 'number' 
    validator key.
  
    This understands validatorKey strings in the following format:

    * 'key' or 'multiple_words' will find validators Key and MultipleWords

    * if you want to share a single validator among multiple fields (for
      example to validate that two passwords are the same) set a name inside
      brackets. i.e. 'password[pwd]'.

    @param {SC.FormView} form the form for the field
    @param {SC.View} field the field to validate
    @param {Object} validatorKey the key to validate
    
    @returns {SC.Validator} validator instance or null
  */  
  findFor: function(form,field, validatorKey) {
    
    // Convert the validator into a validator instance.
    var validator ;
    if (!validatorKey) return ; // nothing to do...
    
    if (validatorKey instanceof SC.Validator) {
      validator = validatorKey ;
    } else if (validatorKey.isClass) {
      validator = validatorKey.create() ;
      
    } else if (SC.typeOf(validatorKey) === SC.T_STRING) {

      // extract optional key name
      var name = null ;
      var m = validatorKey.match(/^(.+)\[(.*)\]/) ;
      if (m) {
        validatorKey = m[1] ; name = m[2]; 
      }
      
      // convert the validatorKey name into a class.
      validatorKey = SC.String.classify(validatorKey);
      var validatorClass = SC.Validator[validatorKey] ;
      if (SC.none(validatorClass)) {
        throw new Error("validator %@ not found for %@".fmt(validatorKey, field));
      } else if (name) {

        // if a key was also passed, then find the validator in the list of
        // validators for the form.  Otherwise, just create a new instance.
        if (!form) {
          throw new Error("named validator (%@) could not be found for field %@ because the field does not belong to a form".fmt(name,field));
        }
        
        if (!form._validatorHash) form._validatorHash = {} ;
        validator = (name) ? form._validatorHash[name] : null ;
        if (!validator) validator = validatorClass.create() ;
        if (name) form._validatorHash[name] = validator ;
      } else validator = validatorClass.create() ;
    } 
    
    return validator ;
  },
  
  /**
    Convenience class method to call the fieldValueForObject() instance
    method you define in your subclass.
  */
  fieldValueForObject: function(object, form, field) {
    if (this.prototype && this.prototype.fieldValueForObject) {
      return this.prototype.fieldValueForObject(object,form,field) ;
    }
    else return null ;
  },
  
  /**
    Convenience class method to call the objectForFieldValue() instance
    method you define in your subclass.
  */
  objectForFieldValue: function(value, form, field) {
    if (this.prototype && this.prototype.objectForFieldValue) {
      return this.prototype.objectForFieldValue(value,form,field) ;
    }
    else return null ;
  }
  
});

/* >>>>>>>>>> BEGIN source/validators/credit_card.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('validators/validator') ;

/** @class
  Validate a field value as a credit card number.

  This validator will perform a basic check to ensure the credit card number
  is mathematically valid.  It will also accept numbers with spaces, dashes
  or other punctuation.

  Converted credit card numbers are broken into units of 4.

  Basic credit card validation courtesy David Leppek
  (https://www.azcode.com/Mod10)

  @extends SC.Validator
  @since SproutCore 1.0
*/
SC.Validator.CreditCard = SC.Validator.extend(
/** @scope SC.Validator.CreditCard.prototype */ {

  /**
    Expects a string of 16 digits.  Will split into groups of 4 for display.
  */
  fieldValueForObject: function(object, form, field) {
    if (typeof(object) == "string" && object.length == 16) {
      object = [object.slice(0,4),object.slice(4,8),object.slice(8,12),object.slice(12,16)].join(' ') ;
    }
    return object ;
  },

  /**
    Removes all whitespace or dashes to make a single string.
  */
  objectForFieldValue: function(value, form, field) {
    return value.replace(/[\s-\.\:]/g,'') ;
  },

  validate: function(form, field) {
    return this.checkNumber(field.get('fieldValue')) ;
  },

  validateError: function(form, field) {
    var label = field.get('errorLabel') || 'Field' ;
    return SC.$error(SC.String.loc("Invalid.CreditCard(%@)", label), label);
  },

  /**
    Allow only numbers, dashes, and spaces
  */
  validateKeyDown: function(form, field, charStr) {
    return !!charStr.match(/[0-9\- ]/);
  },

  checkNumber: function(ccNumb) {

    if (!ccNumb || ccNumb.length===0) return YES; // do not validate empty

    // remove any spaces or dashes
    ccNumb = ccNumb.replace(/[^0-9]/g,'');

    var valid = "0123456789";  // Valid digits in a credit card number
    var len = ccNumb.length;  // The length of the submitted cc number
    var iCCN = parseInt(ccNumb,0);  // integer of ccNumb
    var sCCN = ccNumb.toString();  // string of ccNumb
    sCCN = sCCN.replace (/^\s+|\s+$/g,'');  // strip spaces
    var iTotal = 0;  // integer total set at zero
    var bNum = true;  // by default assume it is a number
    var bResult = false;  // by default assume it is NOT a valid cc
    var temp;  // temp variable for parsing string
    var calc;  // used for calculation of each digit

    // Determine if the ccNumb is in fact all numbers
    for (var j=0; j<len; j++) {
      temp = "" + sCCN.substring(j, j+1);
      if (valid.indexOf(temp) == "-1"){bNum = false;}
    }

    // if it is NOT a number, you can either alert to the fact,
    // or just pass a failure
    if(!bNum) bResult = false;

    // Determine if it is the proper length
    if((len === 0)&&(bResult)){  // nothing, field is blank AND passed above # check
      bResult = false;
    } else{  // ccNumb is a number and the proper length - let's see if it is a valid card number
      if(len >= 15){  // 15 or 16 for Amex or V/MC
        for(var i=len;i>0;i--){  // LOOP through the digits of the card
          calc = parseInt(iCCN,0) % 10;  // right most digit
          calc = parseInt(calc,0);  // assure it is an integer
          iTotal += calc;  // running total of the card number as we loop - Do Nothing to first digit
          i--;  // decrement the count - move to the next digit in the card
          iCCN = iCCN / 10;                               // subtracts right most digit from ccNumb
          calc = parseInt(iCCN,0) % 10 ;    // NEXT right most digit
          calc = calc *2;                                 // multiply the digit by two
          // Instead of some screwy method of converting 16 to a string and then parsing 1 and 6 and then adding them to make 7,
          // I use a simple switch statement to change the value of calc2 to 7 if 16 is the multiple.
          switch(calc){
            case 10: calc = 1; break;       //5*2=10 & 1+0 = 1
            case 12: calc = 3; break;       //6*2=12 & 1+2 = 3
            case 14: calc = 5; break;       //7*2=14 & 1+4 = 5
            case 16: calc = 7; break;       //8*2=16 & 1+6 = 7
            case 18: calc = 9; break;       //9*2=18 & 1+8 = 9
            default: calc = calc;           //4*2= 8 &   8 = 8  -same for all lower numbers
          }
        iCCN = iCCN / 10;  // subtracts right most digit from ccNum
        iTotal += calc;  // running total of the card number as we loop
      }  // END OF LOOP
      if ((iTotal%10)===0){  // check to see if the sum Mod 10 is zero
        bResult = true;  // This IS (or could be) a valid credit card number.
      } else {
        bResult = false;  // This could NOT be a valid credit card number
        }
      }
    }
    return bResult; // Return the results
  }

}) ;

/* >>>>>>>>>> BEGIN source/validators/date.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('validators/validator') ;

/**
  Handle parsing and display of dates.
  
  @class
  @extends SC.Validator
  @author Charles Jolley
  @version 1.0
*/
SC.Validator.Date = SC.Validator.extend(
/** @scope SC.Validator.Date.prototype */ {

  /**
    The standard format you want the validator to convert dates to.
  */
  format: '%b %d, %Y %i:%M:%S %p',
  
  /**
    if we have a number, then convert to a date object.
  */
  fieldValueForObject: function(object, form, field) {
    var format = this.get('format'),
        dateTime;

    /*
      TODO [CC] deprecated warning, we should remove this in a future release
    */
    


    if (SC.typeOf(object) === SC.T_NUMBER) {
      dateTime = SC.DateTime.create(object);
    } else if (object instanceof Date) {
      dateTime = object.getTime();
    }

    if (dateTime) { object = dateTime.toFormattedString(format); }

    return object;
  },

  /**
    Try to pass value as a date. convert into a number, or return null if
    it could not be parsed.
  */
  objectForFieldValue: function(value, form, field) {
    var format = this.get('format'),
        dateTime;

    /*
      TODO [CC] deprecated warning, we should remove this in a future release
    */
    


    if (value) {
      dateTime = SC.DateTime.parse(value, format);
      value = dateTime ? dateTime._ms : null;
    }
    return value ;
  }
    
}) ;

/* >>>>>>>>>> BEGIN source/validators/date_time.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('validators/validator');

/**
  This validates a SC.DateTime, used in SC.DateFieldView.
  
  @class
  @extends SC.Validator
  @author Juan Pablo Goldfinger
  @version 1.0
*/
SC.Validator.DateTime = SC.Validator.extend({

  /**
    The standard format you want the validator to convert dates to.
  */
  format: '%d/%m/%Y',

  /**
    if we have a number, then convert to a date object.
  */
  fieldValueForObject: function(object, form, field) {
    if (SC.kindOf(object, SC.DateTime)) {
      object = object.toFormattedString(this.get('format'));
    } else {
      object = null;
    }
    return object;
  },

  /**
    Try to pass value as a date. convert into a number, or return null if
    it could not be parsed.
  */
  objectForFieldValue: function(value, form, field) {
    if (value) {
      value = SC.DateTime.parse(value, this.get('format'));
    }
    return value;
  }

});

/* >>>>>>>>>> BEGIN source/validators/email.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('validators/validator') ;

/**
  Requires a valid email format.
  
  @class
  @extends SC.Validator
  @version 1.0
*/
SC.Validator.Email = SC.Validator.extend(
/** @scope SC.Validator.Email.prototype */ {
  
  validate: function(form, field) { 
    return (field.get('fieldValue') || '').match(/.+@.+\...+/) ; 
  },
  
  validateError: function(form, field) {
    var label = field.get('errorLabel') || 'Field' ;
    return SC.$error(SC.String.loc("Invalid.Email(%@)", label), label) ;
  }  
    
}) ;

/**
  This variant allows an empty field as well as an email address.
  
  @class
  @extends SC.Validator.Email
  @author Charles Jolley
  @version 1.0
*/
SC.Validator.EmailOrEmpty = SC.Validator.Email.extend(
/** @scope SC.Validator.EmailOrEmpty.prototype */ {
  validate: function(form, field) {
    var value = field.get('fieldValue') ; 
    return (value && value.length > 0) ? value.match(/.+@.+\...+/) : true ;
  }
}) ;

/* >>>>>>>>>> BEGIN source/validators/not_empty.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('validators/validator') ;

/**
  Requires some content in field, but does not check the specific content.
  
  @class
  @extends SC.Validator
  @author Charles Jolley
  @version 1.0
*/
SC.Validator.NotEmpty = SC.Validator.extend(
/** @scope SC.Validator.NotEmpty.prototype */ {
  
  validate: function(form, field) {
    var value = field.get('fieldValue');
    if (SC.none(value)) { return NO; }
    if (! SC.none(value.length)) { return value.length > 0; }
    return YES;
  },
  
  validateError: function(form, field) {
    var label = field.get('errorLabel') || 'Field' ;
    return SC.$error(SC.String.loc("Invalid.NotEmpty(%@)", SC.String.capitalize(label)), field.get('errorLabel'));
  }

}) ;

/* >>>>>>>>>> BEGIN source/validators/number.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('validators/validator') ;
sc_require('system/utils/misc');

/**
  Handles parsing and validating of numbers.
  
  @extends SC.Validator
  @author Charles Jolley
  @version 1.0
  @class
*/
SC.Validator.Number = SC.Validator.extend(
/** @scope SC.Validator.Number.prototype */ {

  /**
    Number of decimal places to show.  
    
    If 0, then numbers will be treated as integers.  Otherwise, numbers will
    show with a fixed number of decimals.
  */
  places: 0,
  
  fieldValueForObject: function(object, form, field) {
    switch(SC.typeOf(object)) {
      case SC.T_NUMBER:
        object = object.toFixed(this.get('places')) ;
        break ;
      case SC.T_NULL:
      case SC.T_UNDEFINED:
        object = '';
        break ;
    }
    return object ;
  },

  objectForFieldValue: function(value, form, field) {
    // strip out commas
    var result;
    value = value.replace(/,/g,'');
    switch(SC.typeOf(value)) {
      case SC.T_STRING:
        if (value.length === 0) {
          value = null ;
        } else if (this.get('places') > 0) {
          value = parseFloat(value) ;
        } else {
          if(value.length===1 && value.match(/-/)) value = null;
          else {
            result = parseInt(value,0) ;
            if(isNaN(result)){
              value = SC.uniJapaneseConvert(value);
              value = parseInt(value,0) ;
              if(isNaN(value)) value='';
            }else value = result;
          }
        }
        break ;
      case SC.T_NULL:
      case SC.T_UNDEFINED:
        value = null ;
        break ;
    }
    return value ;
  },
  
  validate: function(form, field) { 
    var value = field.get('fieldValue') ;
    return (value === '') || !(isNaN(value) || isNaN(parseFloat(value))) ; 
  },
  
  validateError: function(form, field) {
    var label = field.get('errorLabel') || 'Field' ;
    return SC.$error(SC.String.loc("Invalid.Number(%@)", label), label) ;
  },
  
  /** 
    Allow only numbers, dashes, period, and commas
  */
  validateKeyDown: function(form, field, charStr) {
    if(!charStr) charStr = "";
    var text = field.$input().val();
    if (!text) text='';
    text+=charStr;

    if(this.get('places')===0){
      if(charStr.length===0) return true;
      else return text.match(/^[\-{0,1}]?[0-9,\0]*/)[0]===text;
    }else {
      if(charStr.length===0) return true;
      else return text.match(/^[\-{0,1}]?[0-9,\0]*\.?[0-9\0]+/)===text;
    }
  }
    
}) ;

/* >>>>>>>>>> BEGIN source/validators/password.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('validators/validator') ;

/**
  Ensures all fields with the Password validator attached in the same form
  contain the same value.
  
  @class
  @extends SC.Validator
  @author Charles Jolley
  @version 1.0
*/
SC.Validator.Password = SC.Validator.extend(
/** @scope SC.Validator.Password.prototype */ {

  attachTo: function(form,field) {
    arguments.callee.base.apply(this,arguments);
    if (!this.fields) this.fields = [] ;
    this.fields.push(field) ;
  },

  validate: function(force) {
    if (!this.fields || this.fields.length === 0) return true ;
    
    var empty = false ;
    var notEmpty = false ;
    var ret = true ;
    var value = this.fields[0].get('fieldValue') ;
    this.fields.forEach(function(field) {
      var curValue = field.get('fieldValue') ;
      if (curValue != value) ret= false ;
      if (!curValue || curValue.length === 0) empty = true ;
      if (curValue && curValue.length > 0) notEmpty = true ;
    }) ;

    // if forces, valid OK if there was an empty.  If not forced, valid OK 
    // only if all fields match AND they are not all empty.
    if (force) {
      return (notEmpty === false) ? false : ret ;
    } else {
      return (empty === true) ? true : ret ;
    }
  },
  
  // update field states
  updateFields: function(form,valid) {
    if (!this.fields || this.fields.length === 0) return true ;
    var err = SC.String.loc("Invalid.Password");
    var topField = this._field ;
    this.fields.forEach(function(f) {
      var msg = (valid) ? null : ((f == topField) ? err : '') ;
      form.setErrorFor(f,msg) ;
    }) ;
    return (valid) ? SC.VALIDATE_OK : err ;
  },
  
  validateChange: function(form, field, oldValue) { 
    return this.updateFields(form, this.validate(false)) ;
  },

  // this method is called just before the form is submitted.
  // field: the field to validate.
  validateSubmit: function(form, field) { 
    return this.updateFields(form, this.validate(true)) ;
  },

  // this method gets called 1ms after the user types a key (if a change is
  // allowed).  You can use this validate the new partial string and return 
  // an error if needed.
  //
  // The default will validate a partial only if there was already an error.
  // this allows the user to try to get it right before you bug them.
  validatePartial: function(form, field) {
    var isInvalid = !this._field.get('isValid') ;
    if (isInvalid) {
      return this.updateFields(form, this.validate(false)) ;
    } else return SC.VALIDATE_NO_CHANGE ;
  }
    
}) ;

/* >>>>>>>>>> BEGIN source/validators/positive_integer.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('validators/validator') ;

/**
  Handles parsing and validating of positive integers.
  
  @extends SC.Validator
  @author Nirumal Thomas
  @version 1.0
  @class
*/
SC.Validator.PositiveInteger = SC.Validator.extend(
/** @scope SC.Validator.PositiveInteger.prototype */ {

  /**
    Default Value to be displayed. If the value in the text field is null,
    undefined or an empty string, it will be replaced by this value.

    @property
    @type Number
    @default null
  */
  defaultValue: null,

  fieldValueForObject: function(object, form, field) {
    switch(SC.typeOf(object)) {
      case SC.T_NUMBER:
        object = object.toFixed(0) ;
        break ;
      case SC.T_NULL:
      case SC.T_UNDEFINED:
        object = this.get('defaultValue') ;
        break ;
    }
    return object ;
  },

  objectForFieldValue: function(value, form, field) {
    // strip out commas
    value = value.replace(/,/g,'');
    switch(SC.typeOf(value)) {
      case SC.T_STRING:
        if (value.length === 0) {
          value = this.get('defaultValue') ;
        } else {
          value = parseInt(value, 0) ;
        }
        break ;
      case SC.T_NULL:
      case SC.T_UNDEFINED:
        value = this.get('defaultValue') ;
        break ;
    }
    if(isNaN(value)) return this.get('defaultValue');
    return value ;
  },

  validate: function(form, field) {
    var value = field.get('fieldValue') ;
    return (value === '') || !isNaN(value) ;
  },
  
  validateError: function(form, field) {
    var label = field.get('errorLabel') || 'Field' ;
    return SC.$error(SC.String.loc("Invalid.Number(%@)", label), label) ;
  },
  
  /** 
    Allow only numbers
  */
  validateKeyDown: function(form, field, charStr) {
    var text = field.$input().val();
    if (!text) text='';
    text+=charStr;
    if(charStr.length===0) return true ;
    else return text.match(/^[0-9\0]*/)[0]===text;
  }
    
}) ;

/* >>>>>>>>>> BEGIN source/views/field.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('mixins/validatable') ;

/** @class

  Base view for managing a view backed by an input element.  Since the web
  browser provides native support for editing input elements, this view
  provides basic support for listening to changes on these input elements and
  responding to them.

  Generally you will not work with a FieldView directly.  Instead, you should
  use one of the subclasses implemented by your target platform such as
  SC.CheckboxView, SC.RadioView, SC.TextFieldView, and so on.

  @extends SC.View
  @extends SC.Control
  @extends SC.Validatable
  @since SproutCore 1.0
*/
SC.FieldView = SC.View.extend(SC.Control, SC.Validatable,
/** @scope SC.FieldView.prototype */ {

  /**
  _field_isMouseDown: NO,

  /**
    The raw value of the field itself.  This is computed from the 'value'
    property by passing it through any validator you might have set.  This is
    the value that will be set on the field itself when the view is updated.

    @type String
  */
  fieldValue: function() {
    var value = this.get('value');
    if (SC.typeOf(value) === SC.T_ERROR) value = value.get('errorValue');
    return this.fieldValueForObject(value);
  }.property('value', 'validator').cacheable(),

  // ..........................................................
  // PRIMITIVES
  //

  /**
    Override to return an CoreQuery object that selects the input elements
    for the view.  If this method is defined, the field view will
    automatically edit the attrbutes of the input element to reflect the
    current isEnabled state among other things.
  */
  $input: function() {
    var elementTagName = this._inputElementTagName(); // usually "input"
    return this.$(elementTagName).andSelf().filter(elementTagName);
  },

  /** @private
    Override to specify the HTML element type to use as the field. For
    example, "input" or "textarea".
  */
  _inputElementTagName: function() {
    return 'input';
  },

  /**
    Override to set the actual value of the field.

    The default implementation will simple copy the newValue to the value
    attribute of any input tags in the receiver view.  You can override this
    method to provide specific functionality needed by your view.

    @param {Object} newValue the value to display.
    @returns {SC.FieldView} receiver
  */
  setFieldValue: function(newValue) {
    if (SC.none(newValue)) newValue = '' ;
    var input = this.$input();

    // Don't needlessly set the element if it already has the value, because
    // doing so moves the cursor to the end in some browsers.
    if (input.val() !== newValue) {
      input.val(newValue);
    }
    return this ;
  },

  /**
    Override to retrieve the actual value of the field.

    The default implementation will simply retrieve the value attribute from
    the first input tag in the receiver view.

    @returns {String} value
  */
  getFieldValue: function() {
    return this.$input().val();
  },

  _field_fieldValueDidChange: function(evt) {
    SC.run(function() {
      this.fieldValueDidChange(NO);
    }, this);
  },

  /**
    Your class should call this method anytime you think the value of the
    input element may have changed.  This will retrieve the value and update
    the value property of the view accordingly.

    If this is a partial change (i.e. the user is still editing the field and
    you expect the value to change further), then be sure to pass YES for the
    partialChange parameter.  This will change the kind of validation done on
    the value.  Otherwise, the validator may mark the field as having an error
    when the user is still in mid-edit.

    @param partialChange (optional) YES if this is a partial change.
    @returns {Boolean|SC.Error} result of validation.
  */
  fieldValueDidChange: function(partialChange) {
    // collect the field value and convert it back to a value
    var fieldValue = this.getFieldValue();
    var value = this.objectForFieldValue(fieldValue, partialChange);
    this.setIfChanged('value', value);


    // ======= [Old code -- left here for concept reminders. Basic validation
    // API works without it] =======

    // validate value if needed...

    // this.notifyPropertyChange('fieldValue');
    //
    // // get the field value and set it.
    // // if ret is an error, use that instead of the field value.
    // var ret = this.performValidate ? this.performValidate(partialChange) : YES;
    // if (ret === SC.VALIDATE_NO_CHANGE) return ret ;
    //
    // this.propertyWillChange('fieldValue');
    //
    // // if the validator says everything is OK, then in addition to posting
    // // out the value, go ahead and pass the value back through itself.
    // // This way if you have a formatter applied, it will reformat.
    // //
    // // Do this BEFORE we set the value so that the valueObserver will not
    // // overreact.
    // //
    // var ok = SC.$ok(ret);
    // var value = ok ? this._field_getFieldValue() : ret ;
    // if (!partialChange && ok) this._field_setFieldValue(value) ;
    // this.set('value',value) ;
    //
    // this.propertyDidChange('fieldValue');
    //
    // return ret ;
  },

  // ..........................................................
  // INTERNAL SUPPORT
  //

  /** @private
    invoked when the value property changes.  Sets the field value...
  */
  _field_valueDidChange: function() {
    this.setFieldValue(this.get('fieldValue'));
  }.observes('fieldValue'),

  /**
    SC.View view state callback.

    After the layer is created, set the field value and begin observing
    change events on the input field.
  */
  didCreateLayer: function() {
    this.setFieldValue(this.get('fieldValue'));
    this._addChangeEvent();
  },

  /**
    SC.View state callback.

    Removes the change event from the input field.
  */
  willDestroyLayer: function() {
    SC.Event.remove(this.$input(), 'change', this, this._field_fieldValueDidChange);
  },

  // ACTIONS
  // You generally do not need to override these but they may be used.

  /**
    Called to perform validation on the field just before the form
    is submitted.  If you have a validator attached, this will get the
    validators.
  */
  // validateSubmit: function() {
  //   var ret = this.performValidateSubmit ? this.performValidateSubmit() : YES;
  //   // save the value if needed
  //   var value = SC.$ok(ret) ? this._field_getFieldValue() : ret ;
  //   if (value != this.get('value')) this.set('value', value) ;
  //   return ret ;
  // },

  // OVERRIDE IN YOUR SUBCLASS
  // Override these primitives in your subclass as required.

  /**
    SC.RootResponder event handler.

    Allow the browser to do its normal event handling for the mouse down
    event.  But first, set isActive to YES.
  */
  mouseDown: function(evt) {
    this._field_isMouseDown = YES;
    evt.allowDefault();
    return YES;
  },

  /**
    SC.RootResponder event handler.

    Remove the active class on mouseExited if mouse is down.
  */
  mouseExited: function(evt) {
    if (this._field_isMouseDown) this.set('isActive', NO);
    evt.allowDefault();
    return YES;
  },

  /**
    SC.RootResponder event handler.

    If mouse was down and we renter the button area, set the active state again.
  */
  mouseEntered: function(evt) {
    this.set('isActive', this._field_isMouseDown);
    evt.allowDefault();
    return YES;
  },

  /**
    SC.RootResponder event handler.

    On mouse up, remove the isActive class and then allow the browser to do
    its normal thing.
  */
  mouseUp: function(evt) {
    // track independently in case isEnabled has changed
    if (this._field_isMouseDown) this.set('isActive', NO);
    this._field_isMouseDown = NO;
    evt.allowDefault();
    return YES ;
  },

  /**
    SC.RootResponder event handler.

    Simply allow keyDown & keyUp to pass through to the default web browser
    implementation.
  */
  keyDown: function(evt) {

    // handle tab key
    if (evt.which === 9 || evt.keyCode===9) {
      var view = evt.shiftKey ? this.get('previousValidKeyView') : this.get('nextValidKeyView');
      if (view) view.becomeFirstResponder();
      else evt.allowDefault();
      return YES ; // handled
    }

    // validate keyDown...
    if (this.performValidateKeyDown(evt)) {
      this._isKeyDown = YES ;
      evt.allowDefault();
    } else {
      evt.stop();
    }

    return YES;
  },

  /**
    Override of SC.Responder.prototype.acceptsFirstResponder.

    Tied to the `isEnabledInPane` state.
  */
  acceptsFirstResponder: function() {
    if (SC.FOCUS_ALL_CONTROLS) { return this.get('isEnabledInPane'); }
    return NO;
  }.property('isEnabledInPane'),

  /** @private */
  _addChangeEvent: function() {
    SC.Event.add(this.$input(), 'change', this, this._field_fieldValueDidChange);
  },

  /** @private */
  // these methods use the validator to convert the raw field value returned
  // by your subclass into an object and visa versa.
  _field_setFieldValue: function(newValue) {
    this.propertyWillChange('fieldValue');
    if (this.fieldValueForObject) {
      newValue = this.fieldValueForObject(newValue) ;
    }
    var ret = this.setFieldValue(newValue) ;
    this.propertyDidChange('fieldValue');
    return ret ;
  },

  /** @private */
  _field_getFieldValue: function() {
    var ret = this.getFieldValue() ;
    if (this.objectForFieldValue) ret = this.objectForFieldValue(ret);
    return ret ;
  }
});


/* >>>>>>>>>> BEGIN source/views/image.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
//            Portions ©2010 Strobe Inc.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

SC.IMAGE_STATE_NONE = 'none';
SC.IMAGE_STATE_LOADING = 'loading';
SC.IMAGE_STATE_LOADED = 'loaded';
SC.IMAGE_STATE_FAILED = 'failed';

SC.IMAGE_TYPE_NONE = 'NONE';
SC.IMAGE_TYPE_URL = 'URL';
SC.IMAGE_TYPE_CSS_CLASS = 'CSS_CLASS';

/**
  URL to a transparent GIF.  Used for spriting.
*/
SC.BLANK_IMAGE_DATAURL = "data:image/gif;base64,R0lGODlhAQABAJAAAP///wAAACH5BAUQAAAALAAAAAABAAEAAAICBAEAOw==";

SC.BLANK_IMAGE_URL = SC.browser.isIE && SC.browser.compare(SC.browser.version, '8') <= 0 ? '../../../../static/sproutcore/foundation/de/cert/source/resources/blank.gif' : SC.BLANK_IMAGE_DATAURL;

SC.BLANK_IMAGE = new Image();
SC.BLANK_IMAGE.src = SC.BLANK_IMAGE_URL;
SC.BLANK_IMAGE.width = SC.BLANK_IMAGE.height = 1;

/**
  @class

  Displays an image in the browser.

  The ImageView can be used to efficiently display images in the browser.
  It includes a built in support for a number of features that can improve
  your page load time if you use a lot of images including a image loading
  cache and automatic support for CSS spriting.

  Note that there are actually many controls that will natively include
  images using an icon property name.

  @extends SC.View
  @extends SC.Control
  @extends SC.InnerFrame
  @since SproutCore 1.0
*/
SC.ImageView = SC.View.extend(SC.Control, SC.InnerFrame,
/** @scope SC.ImageView.prototype */ {

  classNames: 'sc-image-view',

  // Don't apply this role until each image view can assign a non-empty string value for @aria-label <rdar://problem/9941887>
  // ariaRole: 'img',

  displayProperties: ['align', 'scale', 'value', 'displayToolTip'],

  /** @private */
  renderDelegateName: function () {
    return (this.get('useCanvas') ? 'canvasImage' : 'image') + "RenderDelegate";
  }.property('useCanvas').cacheable(),

  /** @private */
  tagName: function () {
    return this.get('useCanvas') ? 'canvas' : 'div';
  }.property('useCanvas').cacheable(),


  // ..........................................................
  // Properties
  //

  /**
    If YES, this image can load in the background.  Otherwise, it is treated
    as a foreground image.  If the image is not visible on screen, it will
    always be treated as a background image.
  */
  canLoadInBackground: NO,

  /** @private
    @type Image
    @default SC.BLANK_IMAGE
  */
  image: SC.BLANK_IMAGE,


  /** @private
    The frame for the inner img element or for the canvas to draw within, altered according to the scale
    and align properties provided by SC.InnerFrame.

    @type Object
  */
  innerFrame: function () {
    var image = this.get('image'),
      imageWidth = image.width,
      imageHeight = image.height,
      frame = this.get('frame');

    if (SC.none(frame)) return { x: 0, y: 0, width: 0, height: 0 };  // frame is 'null' until rendered when useStaticLayout === YES

    return this.innerFrameForSize(imageWidth, imageHeight, frame.width, frame.height);
  }.property('align', 'image', 'scale', 'frame').cacheable(),

  /**
    If YES, any specified toolTip will be localized before display.

    @type Boolean
    @default YES
  */
  localize: YES,

  /**
    Current load status of the image.

    This status changes as an image is loaded from the server.  If spriting
    is used, this will always be loaded.  Must be one of the following
    constants: SC.IMAGE_STATE_NONE, SC.IMAGE_STATE_LOADING,
    SC.IMAGE_STATE_LOADED, SC.IMAGE_STATE_FAILED

    @type String
  */
  status: SC.IMAGE_STATE_NONE,

  /**
    Will be one of the following constants: SC.IMAGE_TYPE_URL or
    SC.IMAGE_TYPE_CSS_CLASS

    @type String
    @observes value
  */
  type: function () {
    var value = this.get('value');

    if (SC.ImageView.valueIsUrl(value)) return SC.IMAGE_TYPE_URL;
    else if (!SC.none(value)) return SC.IMAGE_TYPE_CSS_CLASS;
    return SC.IMAGE_TYPE_NONE;
  }.property('value').cacheable(),

  /**
    The canvas element performs better than the img element since we can
    update the canvas image without causing browser reflow.  As an additional
    benefit, canvas images are less easily copied, which is generally in line
    with acting as an 'application'.

    @type Boolean
    @default YES if supported
    @since SproutCore 1.5
  */
  useCanvas: function () {
    return SC.platform.supportsCanvas && !this.get('useStaticLayout');
  }.property('useStaticLayout').cacheable(),

  /**
    If YES, image view will use the SC.imageQueue to control loading.  This
    setting is generally preferred.

    @type Boolean
    @default YES
  */
  useImageQueue: YES,

  /**
    A url or CSS class name.

    This is the image you want the view to display.  It should be either a
    url or css class name.  You can also set the content and
    contentValueKey properties to have this value extracted
    automatically.

    If you want to use CSS spriting, set this value to a CSS class name.  If
    you need to use multiple class names to set your icon, separate them by
    spaces.

    Note that if you provide a URL, it must contain at least one '/' as this
    is how we autodetect URLs.

    @type String
  */
  value: null,
  valueBindingDefault: SC.Binding.oneWay(),

  /**
    Recalculate our innerFrame if the outer frame has changed.

    @returns {void}
  */
  viewDidResize: function () {
    arguments.callee.base.apply(this,arguments);

    // Note: SC.View's updateLayer() will call viewDidResize() if useStaticLayout is true.  The result of this
    // is that since our display depends on the frame, when the view or parent view resizes, viewDidResize
    // notifies that the frame has changed, so we update our view, which calls viewDidResize, which notifies
    // that the frame has changed, so we update our view, etc. in an infinite loop.
    if (this.get('useStaticLayout')) {
      if (this._updatingOnce) {
        this._updatingOnce = false;
      } else {
        // Allow a single update when the view resizes to avoid an infinite loop.
        this._updatingOnce = true;
        this.updateLayerIfNeeded();
      }
    } else {
      this.updateLayerIfNeeded();
    }
  },

  // ..........................................................
  // Methods
  //

  /** @private */
  init: function () {
    arguments.callee.base.apply(this,arguments);

    // Start loading the image immediately on creation.
    this._valueDidChange();

    if (this.get('useImageCache') !== undefined) {
      

      this.set('useImageQueue', this.get('useImageCache'));
    }
  },


  // ..........................................................
  // Rendering
  //

  /**
    Called when the element is attached to the document.

    If the image uses static layout (i.e. we don't know the frame beforehand),
    then this method will call updateLayerIfNeeded in order to adjust the inner
    frame of the image according to its rendered frame.
  */
  didAppendToDocument: function () {
    // If using static layout, we can still support image scaling and aligning,
    // but we need to do it post-render.
    if (this.get('useStaticLayout')) {
      // Call updateLayer manually, because we can't have innerFrame be a
      // display property.  It causes an infinite loop with static layout.
      this.updateLayerIfNeeded();
    }
  },

  /**
    Called when the element is created.

    If the view is using a canvas element, then we can not draw to the canvas
    until it exists.  This method will call updateLayerIfNeeded in order to draw
    to the canvas.
  */
  didCreateLayer: function () {
    if (this.get('useCanvas')) {
      this.updateLayerIfNeeded();
    }
  },

  // ..........................................................
  // Value handling
  //

  /** @private
    Whenever the value changes, update the image state and possibly schedule
    an image to load.
  */
  _valueDidChange: function () {
    var value = this.get('value'),
      type = this.get('type');

    // Reset the backing image object every time.
    this.set('image', SC.BLANK_IMAGE);

    if (type == SC.IMAGE_TYPE_URL) {
      // Load the image.
      this.set('status', SC.IMAGE_STATE_LOADING);

      // order: image cache, normal load
      if (!this._loadImageUsingCache()) {
        this._loadImage();
      }
    }
  }.observes('value'),

  /** @private
    Tries to load the image value using the SC.imageQueue object. If the value is not
    a URL, it won't attempt to load it using this method.

    @returns YES if loading using SC.imageQueue, NO otherwise
  */
  _loadImageUsingCache: function () {
    var value = this.get('value'),
        type = this.get('type');

    // now update local state as needed....
    if (type === SC.IMAGE_TYPE_URL && this.get('useImageQueue')) {
      var isBackground = this.get('isVisibleInWindow') || this.get('canLoadInBackground');

      SC.imageQueue.loadImage(value, this, this._loadImageUsingCacheDidComplete, isBackground);
      return YES;
    }

    return NO;
  },

  /** @private */
  _loadImageUsingCacheDidComplete: function (url, image) {
    var value = this.get('value');

    if (value === url) {
      if (SC.ok(image)) {
        this.didLoad(image);
      } else {
        // if loading it using the cache didn't work, it's useless to try loading the image normally
        this.didError(image);
      }
    }
  },

  /** @private
    Loads an image using a normal Image object, without using the SC.imageQueue.

    @returns YES if it will load, NO otherwise
  */
  _loadImage: function () {
    var value = this.get('value'),
        type = this.get('type'),
        that = this,
        image,
        jqImage;

    if (type === SC.IMAGE_TYPE_URL) {
      image = new Image();

      var errorFunc = function () {
        SC.run(function () {
          that._loadImageDidComplete(value, SC.$error("SC.Image.FailedError", "Image", -101));
        });
      };

      var loadFunc = function () {
        SC.run(function () {
          that._loadImageDidComplete(value, image);
        });
      };

      // Don't grab the jQuery object repeatedly
      jqImage = $(image);

      // Using bind here instead of setting onabort/onerror/onload directly
      // fixes an issue with images having 0 width and height
      jqImage.bind('error', errorFunc);
      jqImage.bind('abort', errorFunc);
      jqImage.bind('load', loadFunc);

      image.src = value;
      return YES;
    }

    return NO;
  },

  /** @private */
  _loadImageDidComplete: function (url, image) {
    var value = this.get('value');

    if (value === url) {
      if (SC.ok(image)) {
        this.didLoad(image);
      } else {
        this.didError(image);
      }
    }
  },

  didLoad: function (image) {
    this.set('status', SC.IMAGE_STATE_LOADED);
    if (!image) image = SC.BLANK_IMAGE;
    this.set('image', image);
    this.displayDidChange();
  },

  didError: function (error) {
    this.set('status', SC.IMAGE_STATE_FAILED);
    this.set('image', SC.BLANK_IMAGE);
  }

});

/**
  Returns YES if the passed value looks like an URL and not a CSS class
  name.
*/
SC.ImageView.valueIsUrl = function (value) {
  return value && SC.typeOf(value) === SC.T_STRING ? value.indexOf('/') >= 0 : NO;
};

/* >>>>>>>>>> BEGIN source/views/text_field.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('views/field');
sc_require('system/text_selection');
sc_require('mixins/editable');

SC.AUTOCAPITALIZE_NONE = 'none';
SC.AUTOCAPITALIZE_SENTENCES = 'sentences';
SC.AUTOCAPITALIZE_WORDS = 'words';
SC.AUTOCAPITALIZE_CHARACTERS = 'characters';

/**
  @class

  A text field is an input element with type "text".  This view adds support
  for hinted values, etc.

  @extends SC.FieldView
  @extends SC.Editable
  @author Charles Jolley
 */
SC.TextFieldView = SC.FieldView.extend(SC.Editable,
  /** @scope SC.TextFieldView.prototype */ {

  classNames: ['sc-text-field-view'],

  /**
    Walk like a duck.

    @type Boolean
    @default true
    @readOnly
   */
  isTextField: true,

  // ..........................................................
  // PROPERTIES
  //

  /**
    When `applyImmediately` is turned on, every keystroke will set the value
    of the underlying object. Turning it off will only set the value on blur.

    @type Boolean
    @default true
   */
  applyImmediately: true,

  /**
    Flag indicating whether the editor should automatically commit if you click
    outside it.

    @type Boolean
    @default true
   */
  commitOnBlur: true,

  /**
    If `true` then allow multi-line input.  This will also change the default
    tag type from "input" to "textarea".  Otherwise, pressing return will
    trigger the default insertion handler.

    @type Boolean
    @default false
   */
  isTextArea: false,

  /**
    Whether the text field is currently focused.

    @type Boolean
    @default false
   */
  focused: false,

  /**
    The hint to display while the field is not active.

    @type String
    @default ""
   */
  hint: '',

  /**
    The type attribute of the input.

    @type String
    @default "text"
   */
  type: 'text',

  /**
    This property will set a tabindex="-1" on your view if set to false.

    This gives us control over the native tabbing behavior. When nextValidKeyView
    reaches the end of the views in the pane views tree, it won't go to a textfield
    that can accept the default tabbing behavior in any other pane. This was a
    problem when you had an alert on top of a mainPane with textfields.

    Modal panes set this to false on all textfields that don't belong to itself.
    @type Boolean
    @default true
   */
  isBrowserFocusable: true,

  /**
    Whether the browser should automatically correct the input.

    When `autoCorrect` is set to `null`, the browser will use
    the system defaults.

    @type Boolean
    @default true
   */
  autoCorrect: true,

  /**
    Specifies the autocapitalization behavior.

    Possible values are:

     - `SC.AUTOCAPITALIZE_NONE` -- Do not autocapitalize.
     - `SC.AUTOCAPITALIZE_SENTENCES` -- Autocapitalize the first letter of each
       sentence.
     - `SC.AUTOCAPITALIZE_WORDS` -- Autocapitalize the first letter of each word.
     - `SC.AUTOCAPITALIZE_CHARACTERS` -- Autocapitalize all characters.

    Boolean values are also supported, with `true` interpreted as
    `SC.AUTOCAPITALIZE_NONE` and `false` as `SC.AUTOCAPITALIZE_SENTENCES`.

    When `autoCapitalize` is set to `null`, the browser will use
    the system defaults.

    @type String SC.AUTOCAPITALIZE_NONE|SC.AUTOCAPITALIZE_SENTENCES|SC.AUTOCAPITALIZE_WORDS|SC.AUTOCAPITALIZE_CHARACTERS
    @default SC.CAPITALIZE_SENTENCES
   */
  autoCapitalize: SC.CAPITALIZE_SENTENCES,

  /**
    Whether the browser should automatically complete the input.

    When `autoComplete` is set to `null`, the browser will use
    the system defaults.

    @type Boolean
    @default null
   */
  autoComplete: null,

  /**
    Localizes and escapes the hint if necessary.

    @field
    @type String
   */
  formattedHint: function () {
    var hint = this.get('hint');
    hint = typeof(hint) === 'string' && this.get('localize') ? SC.String.loc(hint) : hint;

    // If the hint is appended via an overlay, ensure that the text is escaped in order to avoid XSS attacks.
    if (this.get('useHintOverlay')) {
      hint = this.get('escapeHTML') ? SC.RenderContext.escapeHTML(hint) : hint;
    }

    return hint;
  }.property('hint', 'localize').cacheable(),

  /**
    Whether to show the hint while the field still has focus.

    While newer versions of Safari, Firefox and Chrome will act this way using the
    placeholder attribute, other browsers will not. By setting this property
    to true, we can ensure that the hint will always appear even when the
    field has focus.

    Note: If `hintOnFocus` is false, this doesn't necessarily mean that the
    hint will disappear on focus, because some browsers will still not remove
    the placeholder on focus when empty.

    *Important:* You can not modify this property once the view has been rendered.

    @type Boolean
    @default true
   */
  hintOnFocus: true,

  /**
    Whether the hint should be localized or not.

    @type Boolean
    @default true
   */
  localize: true,

  /**
    If `true` then the text field is currently editing.

    @type Boolean
    @default false
   */
  isEditing: false,

  /**
    If you set this property to false the tab key won't trigger its default
    behavior (tabbing to the next field).

    @type Boolean
    @default true
   */
  defaultTabbingEnabled: true,

  /**
    Enabled context menu for textfields.

    @type Boolean
    @default true
   */
  isContextMenuEnabled: true,

  /**
    If no, will not allow transform or validation errors (SC.Error objects)
    to be passed to `value`.  Upon focus lost, the text field will revert
    to its previous value.

    @type Boolean
    @default true
   */
  allowsErrorAsValue: true,

  /**
    An optional view instance, or view class reference, which will be visible
    on the left side of the text field.  Visually the accessory view will look
    to be inside the field but the text editing will not overlap the accessory
    view.

    The view will be rooted to the top-left of the text field.  You should use
    a layout with 'left' and/or 'top' specified if you would like to adjust
    the offset from the top-left.

    One example use would be for a web site's icon, found to the left of the
    URL field, in many popular web browsers.

    Note:  If you set a left accessory view, the left padding of the text
    field (really, the left offset of the padding element) will automatically
    be set to the width of the accessory view, overriding any CSS you may have
    defined on the "padding" element.  If you would like to customize the
    amount of left padding used when the accessory view is visible, make the
    accessory view wider, with empty space on the right.

    @type SC.View
    @default null
   */
  leftAccessoryView: null,

  /**
    An optional view instance, or view class reference, which will be visible
    on the right side of the text field.  Visually the accessory view will
    look to be inside the field but the text editing will not overlap the
    accessory view.

    The view will be rooted to the top-right of the text field.  You should
    use a layout with 'right' and/or 'top' specified if you would like to
    adjust the offset from the top-right.  If 'left' is specified in the
    layout it will be cleared.

    One example use would be for a button to clear the contents of the text
    field.

    Note:  If you set a right accessory view, the right padding of the text
    field (really, the right offset of the padding element) will automatically
    be set to the width of the accessory view, overriding any CSS you may have
    defined on the "padding" element.  If you would like to customize the
    amount of right padding used when the accessory view is visible, make the
    accessory view wider, with empty space on the left.

    @type SC.View
    @default null
   */
  rightAccessoryView: null,

  /**
    This property will enable disable HTML5 spell checking if available on the
    browser. As of today Safari 4+, Chrome 3+ and Firefox 3+ support it.

    @type Boolean
    @default true
   */
  spellCheckEnabled: true,

  /**
    Maximum amount of characters this field will allow.

    @type Number
    @default 5096
   */
  maxLength: 5096,

  /**
    Whether to render a border or not.

    @type Boolean
    @default true
   */
  shouldRenderBorder: true,

  // ..........................................................
  // SUPPORT FOR AUTOMATIC RESIZING
  //

  /**
    Text fields support auto resizing.
    @type Boolean
    @default true
    @see SC.AutoResize#supportsAutoResize
   */
  supportsAutoResize: true,

  /**
    The layer to automatically resize.

    @type DOMElement
    @see SC.AutoResize#autoResizeLayer
   */
  autoResizeLayer: function () {
    return this.$input()[0];
  }.property('layer').cacheable(),

  /**
    The text to be used when automatically resizing the text field.

    @type String
    @see SC.AutoResize#autoResizeText
   */
  autoResizeText: function () {
    return this.get('value');
  }.property('value').cacheable(),

  /**
    How much padding should be used when automatically resizing.
    @type Number
    @default 20
    @see SC.AutoResize#autoResizePadding
   */
  autoResizePadding: SC.propertyFromRenderDelegate('autoResizePadding', 20),

  /**
    This property indicates if the value in the text field can be changed.
    If set to `false`, a `readOnly` attribute will be added to the DOM Element.

    Note if `isEnabledInPane` is `false` this property will have no effect.

    @type Boolean
    @default true
   */
  isEditable: true,

  /**
    The current selection of the text field, returned as an SC.TextSelection
    object.

    Note that if the selection changes a new object will be returned -- it is
    not the case that a previously-returned SC.TextSelection object will
    simply have its properties mutated.

    @field
    @type SC.TextSelection
   */
  selection: function (key, value) {
    var element = this.$input()[0],
        direction = 'none',
        range, start, end;

    // Are we being asked to set the value, or return the current value?
    if (value === undefined) {
      // The client is retrieving the value.
      if (element) {
        start = null;
        end = null;

        if (!element.value) {
          start = end = 0;
        } else {
          // In IE8, input elements don't have hasOwnProperty() defined.
          try {
            if (SC.platform.input.selectionStart) {
              start = element.selectionStart;
            }
            if (SC.platform.input.selectionEnd) {
              end = element.selectionEnd;
            }
            if (SC.platform.input.selectionDirection) {
              direction = element.selectionDirection;
            }
          }
          // In Firefox when you ask the selectionStart or End of a hidden
          // input, sometimes it throws a weird error.
          // Adding this to just ignore it.
          catch (e) {
            return null;
          }

          // Support Internet Explorer.
          if (start === null  ||  end === null) {
            var selection = document.selection;
            if (selection) {
              var type = selection.type;
              if (type  &&  (type === 'None'  ||  type === 'Text')) {
                range = selection.createRange();

                if (!this.get('isTextArea')) {
                  // Input tag support.  Figure out the starting position by
                  // moving the range's start position as far left as possible
                  // and seeing how many characters it actually moved over.
                  var length = range.text.length;
                  start = Math.abs(range.moveStart('character', 0 - (element.value.length + 1)));
                  end = start + length;
                } else {
                  // Textarea support.  Unfortunately, this case is a bit more
                  // complicated than the input tag case.  We need to create a
                  // "dummy" range to help in the calculations.
                  var dummyRange = range.duplicate();
                  dummyRange.moveToElementText(element);
                  dummyRange.setEndPoint('EndToStart', range);
                  start = dummyRange.text.length;
                  end = start + range.text.length;
                }
              }
            }
          }
        }

        return SC.TextSelection.create({ start: start, end: end, direction: direction });
      } else {
        return null;
      }
    } else {
      // The client is setting the value.  Make sure the new value is a text
      // selection object.
      if (!value  ||  !value.kindOf  ||  !value.kindOf(SC.TextSelection)) {
        throw new Error("When setting the selection, you must specify an SC.TextSelection instance.");
      }

      if (element) {
        if (element.setSelectionRange) {
          try {
            element.setSelectionRange(value.get('start'), value.get('end'), value.get('direction'));
          } catch (e) {
            // In Firefox & IE when you call setSelectionRange on a hidden input it will throw weird
            // errors. Adding this to just ignore it.
            return null;
          }

          if (!SC.platform.input.selectionDirection) {
            // Browser doesn't support selectionDirection, set it to 'none' so the wrong value is not cached.
            value.set('direction', 'none');
          }
        } else {
          // Support Internet Explorer.
          range = element.createTextRange();
          start = value.get('start');
          range.move('character', start);
          range.moveEnd('character', value.get('end') - start);
          range.select();
        }
      }

      return value;
    }

    // Implementation note:
    // There are certain ways users can add/remove text that we can't identify
    // via our key/mouse down/up handlers (such as the user choosing Paste
    // from a menu).  So that's why we need to update our 'selection' property
    // whenever the field's value changes.
  }.property('fieldValue').cacheable(),

  /**
    Whether or not the text field view will use an overlaid label for the hint.

    There are two conditions that will result in the text field adding an
    overlaid label for the hint. The first is when the `hintOnFocus` property is
    true. This allows the user to focus the text field and still see the hint
    text while there is no value in the field. Since some browsers clear the
    placeholder when the field has text, this is a way to ensure the same
    behavior across all browsers.

    The second is when the browser doesn't support the placeholder attribute
    (i.e. < IE 10). By using an overlaid label rather than inserting the hint
    into the input, we are able to show clear text hints over password fields.

    @field
    @type Boolean
    @default true
    @readonly
  */
  useHintOverlay: function () {
    return this.get('hintOnFocus') || !SC.platform.input.placeholder;
  }.property().cacheable(),

  // ..........................................................
  // INTERNAL SUPPORT
  //

  // Note: isEnabledInPane is required here because it is used in the renderMixin function of
  // SC.Control. It is not a display property directly in SC.Control, because the use of it in
  // SC.Control is only applied to input fields, which very few consumers of SC.Control have.
  // TODO: Pull the disabled attribute updating out of SC.Control.
  displayProperties: ['isBrowserFocusable', 'formattedHint', 'fieldValue', 'isEditing', 'isEditable', 'isEnabledInPane',
                      'leftAccessoryView', 'rightAccessoryView', 'isTextArea', 'maxLength'],

  createChildViews: function () {
    arguments.callee.base.apply(this,arguments);
    this.accessoryViewObserver();
  },

  acceptsFirstResponder: function () {
    return this.get('isEnabledInPane');
  }.property('isEnabledInPane'),

  accessoryViewObserver: function () {
    var classNames,
        viewProperties = ['leftAccessoryView', 'rightAccessoryView'],
        len = viewProperties.length, i, viewProperty, previousView,
        accessoryView;

    for (i = 0; i < len; i++) {
      viewProperty = viewProperties[i];

      // Is there an accessory view specified?
      previousView = this['_' + viewProperty];
      accessoryView = this.get(viewProperty);

      // If the view is the same, there's nothing to do.  Otherwise, remove
      // the old one (if any) and add the new one.
      if (! (previousView &&
             accessoryView &&
             (previousView === accessoryView))) {

        // If there was a previous previous accessory view, remove it now.
        if (previousView) {
          // Remove the "sc-text-field-accessory-view" class name that we had
          // added earlier.
          classNames = previousView.get('classNames');
          classNames = classNames.without('sc-text-field-accessory-view');
          previousView.set('classNames', classNames);

          if (previousView.createdByParent) {
            this.removeChildAndDestroy(previousView);
          } else {
            this.removeChild(previousView);
          }

          // Tidy up.
          previousView = this['_' + viewProperty] = this['_created' + viewProperty] = null;
        }

        // If there's a new accessory view to add, do so now.
        if (accessoryView) {
          // If the user passed in a class rather than an instance, create an
          // instance now.
          accessoryView = this.createChildView(accessoryView);

          // Fix up right accessory views to be right positioned.
          if (viewProperty === 'rightAccessoryView') {
            var layout = accessoryView.get('layout');

            accessoryView.adjust({ left: null, right: layout.right || 0 });
          }

          // Add in the "sc-text-field-accessory-view" class name so that the
          // z-index gets set correctly.
          classNames = accessoryView.get('classNames');
          var className = 'sc-text-field-accessory-view';
          if (classNames.indexOf(className) < 0) {
            classNames = SC.clone(classNames);
            classNames.push(className);
            accessoryView.set('classNames', classNames);
          }

          // Actually add the view to our hierarchy and cache a reference.
          this.appendChild(accessoryView);
          this['_' + viewProperty] = accessoryView;
        }
      }
    }
  }.observes('leftAccessoryView', 'rightAccessoryView'),

  render: function (context, firstTime) {
    var v, accessoryViewWidths, leftAdjustment, rightAdjustment;

    // always have at least an empty string
    v = this.get('fieldValue');
    if (SC.none(v)) v = '';
    v = String(v);

    // update layer classes always
    context.setClass('not-empty', v.length > 0);

    // If we have accessory views, we'll want to update the padding on the
    // hint to compensate for the width of the accessory view.  (It'd be nice
    // if we could add in the original padding, too, but there's no efficient
    // way to do that without first rendering the element somewhere on/off-
    // screen, and we don't want to take the performance hit.)
    accessoryViewWidths = this._getAccessoryViewWidths();
    leftAdjustment  = accessoryViewWidths.left;
    rightAdjustment = accessoryViewWidths.right;

    if (leftAdjustment)  leftAdjustment  += 'px';
    if (rightAdjustment) rightAdjustment += 'px';

    this._renderField(context, firstTime, v, leftAdjustment, rightAdjustment);
  },

  /** @private
    If isTextArea is changed (this might happen in inlineeditor constantly)
    force the field render to render like the firsttime to avoid writing extra
    code. This can be useful also
   */
  _forceRenderFirstTime: false,

  /** @private */
  _renderFieldLikeFirstTime: function () {
    this.set('_forceRenderFirstTime', true);
  }.observes('isTextArea'),

  /** @private */
  _renderField: function (context, firstTime, value, leftAdjustment, rightAdjustment) {
    // TODO:  The cleanest thing might be to create a sub- rendering context
    //        here, but currently SC.RenderContext will render sibling
    //        contexts as parent/child.
    var hint = this.get('formattedHint'),
      hintAttr = '',
      maxLength = this.get('maxLength'),
      isTextArea = this.get('isTextArea'),
      isEnabledInPane = this.get('isEnabledInPane'),
      isEditable = this.get('isEditable'),
      autoCorrect = this.get('autoCorrect'),
      autoCapitalize = this.get('autoCapitalize'),
      autoComplete = this.get('autoComplete'),
      isBrowserFocusable = this.get('isBrowserFocusable'),
      spellCheckString = '', autocapitalizeString = '', autocorrectString = '',
      autocompleteString = '', activeStateString = '', browserFocusableString = '',
      name, adjustmentStyle, type, paddingElementStyle,
      fieldClassNames, isOldSafari;

    context.setClass('text-area', isTextArea);

    //Adding this to differentiate between older and newer versions of safari
    //since the internal default field padding changed
    isOldSafari = SC.browser.isWebkit &&
        SC.browser.compare(SC.browser.engineVersion, '532') < 0;
    context.setClass('oldWebKitFieldPadding', isOldSafari);


    if (firstTime || this._forceRenderFirstTime) {
      this._forceRenderFirstTime = false;
      activeStateString = isEnabledInPane ? (isEditable ? '' : ' readonly="readonly"') : ' disabled="disabled"';
      name = this.get('layerId');

      spellCheckString = this.get('spellCheckEnabled') ? ' spellcheck="true"' : ' spellcheck="false"';

      if (!SC.none(autoCorrect)) {
        autocorrectString = ' autocorrect=' + (!autoCorrect ? '"off"' : '"on"');
      }

      if (!SC.none(autoCapitalize)) {
        if (SC.typeOf(autoCapitalize) === 'boolean') {
          autocapitalizeString = ' autocapitalize=' + (!autoCapitalize ? '"none"' : '"sentences"');
        } else {
          autocapitalizeString = ' autocapitalize=' + autoCapitalize;
        }
      }

      if (!SC.none(autoComplete)) {
        autocompleteString = ' autocomplete=' + (!autoComplete ? '"off"' : '"on"');
      }

      if (!isBrowserFocusable) {
        browserFocusableString = ' tabindex="-1"';
      }

      if (this.get('shouldRenderBorder')) context.push('<div class="border"></div>');

      // Render the padding element, with any necessary positioning
      // adjustments to accommodate accessory views.
      adjustmentStyle = '';
      if (leftAdjustment || rightAdjustment) {
        adjustmentStyle = 'style="';
        if (leftAdjustment)  adjustmentStyle += 'left:'  + leftAdjustment  + ';';
        if (rightAdjustment) adjustmentStyle += 'right:' + rightAdjustment + ';';
        adjustmentStyle += '"';
      }
      context.push('<div class="padding" ' + adjustmentStyle + '>');

      value = this.get('escapeHTML') ? SC.RenderContext.escapeHTML(value) : value;

      // When hintOnFocus is true or the field doesn't support placeholders, ensure that a hint appears by adding an overlay hint element.
      if (this.get('useHintOverlay')) {
        var hintOverlay = '<div aria-hidden="true" class="hint ' +
                      (isTextArea ? '':'ellipsis') + '%@">' + hint + '</div>';
        context.push(hintOverlay.fmt(value ? ' sc-hidden': ''));

      // Use the input placeholder attribute for the hint.
      } else {
        hintAttr = ' placeholder="' + hint + '"';
      }

      fieldClassNames = "field";

      // Render the input/textarea field itself, and close off the padding.
      if (isTextArea) {
        context.push('<textarea aria-label="' + hint + '" class="' + fieldClassNames + '" aria-multiline="true"' +
                      '" name="' + name + '"' + activeStateString + hintAttr +
                      spellCheckString + autocorrectString + autocapitalizeString +
                      browserFocusableString + ' maxlength="' + maxLength +
                      '">' + value + '</textarea></div>');
      } else {
        type = this.get('type');
        context.push('<input aria-label="' + hint + '" class="' + fieldClassNames + '" type="' + type +
                      '" name="' + name + '"' + activeStateString + hintAttr +
                      spellCheckString + autocorrectString + autocapitalizeString +
                      autocompleteString + browserFocusableString + ' maxlength="' + maxLength +
                      '" value="' + value + '"' + '/></div>');
      }
    } else {
      var input = this.$input(),
        element = input[0];

      // Update the hint. If the overlay hint was used, update it.
      if (this.get('useHintOverlay')) {
        context.$('.hint')[0].innerHTML = hint;
      } else {
        input.attr('placeholder', hint);
      }

      input.attr('maxLength', maxLength);

      // IE8 has problems aligning the input text in the center
      // This is a workaround for centering it.
      if (SC.browser.name === SC.BROWSER.ie && SC.browser.version <= 8 && !isTextArea) {
        input.css('line-height', this.get('frame').height + 'px');
      }

      if (!SC.none(autoCorrect)) {
        input.attr('autocorrect', !autoCorrect ? 'off' : 'on');
      } else {
        input.attr('autocorrect', null);
      }

      if (!SC.none(autoCapitalize)) {
        if (SC.typeOf(autoCapitalize) === 'boolean') {
          input.attr('autocapitalize', !autoCapitalize ? 'none' : 'sentences');
        } else {
          input.attr('autocapitalize', autoCapitalize);
        }
      } else {
        input.attr('autocapitalize', null);
      }

      if (!SC.none(autoComplete)) {
        input.attr('autoComplete', !autoComplete ? 'off' : 'on');
      } else {
        input.attr('autoComplete', null);
      }

      if (isBrowserFocusable) {
        input.removeAttr('tabindex');
      } else {
        input.attr('tabindex', '-1');
      }

      // Enable/disable the actual input/textarea as appropriate.
      if (!isEditable) {
        input.attr('readOnly', true);
      } else {
        input.attr('readOnly', null);
      }

      if (element) {
        // Adjust the padding element to accommodate any accessory views.
        paddingElementStyle = element.parentNode.style;
        if (leftAdjustment) {
          if (paddingElementStyle.left !== leftAdjustment) {
            paddingElementStyle.left = leftAdjustment;
          }
        } else {
          paddingElementStyle.left = null;
        }

        if (rightAdjustment) {
          if (paddingElementStyle.right !== rightAdjustment) {
            paddingElementStyle.right = rightAdjustment;
          }
        } else {
          paddingElementStyle.right = null;
        }
      }
    }
  },

  _getAccessoryViewWidths: function () {
    var widths = {},
        accessoryViewPositions = ['left', 'right'],
        numberOfAccessoryViewPositions = accessoryViewPositions.length, i,
        position, accessoryView, width, layout, offset, frame;
    for (i = 0;  i < numberOfAccessoryViewPositions;  i++) {
      position = accessoryViewPositions[i];
      accessoryView = this['_' + position + 'AccessoryView'];
      if (accessoryView && accessoryView.isObservable) {
        frame = accessoryView.get('frame');
        if (frame) {
          width = frame.width;
          if (width) {
            // Also account for the accessory view's inset.
            layout = accessoryView.get('layout');
            if (layout) {
              offset = layout[position];
              width += offset;
            }
            widths[position] = width;
          }
        }
      }
    }
    return widths;
  },

  // ..........................................................
  // HANDLE NATIVE CONTROL EVENTS
  //

  /**
    Override of SC.FieldView.prototype.didCreateLayer.
  */
  didCreateLayer: function () {
    arguments.callee.base.apply(this,arguments);

    // For some strange reason if we add focus/blur events to textarea
    // inmediately they won't work. However if I add them at the end of the
    // runLoop it works fine.
    if (this.get('isTextArea')) {
      this.invokeLast(this._addTextAreaEvents);
    } else {
      this._addTextAreaEvents();

      // In Firefox, for input fields only (that is, not textarea elements),
      // if the cursor is at the end of the field, the "down" key will not
      // result in a "keypress" event for the document (only for the input
      // element), although it will be bubbled up in other contexts.  Since
      // SproutCore's event dispatching requires the document to see the
      // event, we'll manually forward the event along.
      if (SC.browser.isMozilla) {
        var input = this.$input();
        SC.Event.add(input, 'keypress', this, this._firefox_dispatch_keypress);
      }
    }
  },

  /**
    SC.View view state callback.

    Once the view is appended, fix up the text layout to hint and input.
  */
  didAppendToDocument: function () {
    this._fixupTextLayout();
  },

  /** @private
    Apply proper text layout to hint and input.
   */
  _fixupTextLayout: function () {
    var height = this.get('frame').height;

    if (SC.browser.name === SC.BROWSER.ie && SC.browser.version <= 8 &&
        !this.get('isTextArea')) {
      this.$input().css('line-height', height + 'px');
    }

    if (this.get('useHintOverlay') && !this.get('isTextArea')) {
      var hintJQ = this.$('.hint');

      hintJQ.css('line-height', hintJQ.outerHeight() + 'px');
    }
  },

  /** @private
    Adds all the textarea events. This functions is called by didCreateLayer
    at different moments depending if it is a textarea or not. Appending
    events to text areas is not reliable unless the element is already added
    to the DOM.
   */
  _addTextAreaEvents: function () {
    var input = this.$input();
    SC.Event.add(input, 'focus', this, this._textField_fieldDidFocus);
    SC.Event.add(input, 'blur',  this, this._textField_fieldDidBlur);

    // There are certain ways users can select text that we can't identify via
    // our key/mouse down/up handlers (such as the user choosing Select All
    // from a menu).
    SC.Event.add(input, 'select', this, this._textField_selectionDidChange);

    // handle a "paste" from app menu and context menu
    SC.Event.add(input, 'input', this, this._textField_inputDidChange);
  },

  /**
    Removes all the events attached to the textfield
   */
  willDestroyLayer: function () {
    arguments.callee.base.apply(this,arguments);

    var input = this.$input();
    SC.Event.remove(input, 'focus',  this, this._textField_fieldDidFocus);
    SC.Event.remove(input, 'blur',   this, this._textField_fieldDidBlur);
    SC.Event.remove(input, 'select', this, this._textField_selectionDidChange);
    SC.Event.remove(input, 'keypress',  this, this._firefox_dispatch_keypress);
    SC.Event.remove(input, 'input', this, this._textField_inputDidChange);
  },

  /** @private
     This function is called by the event when the textfield gets focus
  */
  _textField_fieldDidFocus: function (evt) {
    SC.run(function () {
      this.set('focused', true);
      this.fieldDidFocus(evt);
    }, this);
  },

  /** @private
    This function is called by the event when the textfield blurs
   */
  _textField_fieldDidBlur: function (evt) {
    SC.run(function () {
      this.set('focused', false);
      // passing the original event here instead that was potentially set from
      // losing the responder on the inline text editor so that we can
      // use it for the delegate to end editing
      this.fieldDidBlur(this._origEvent || evt);
    }, this);
  },

  fieldDidFocus: function (evt) {
    this.becomeFirstResponder();

    this.beginEditing(evt);

    // We have to hide the intercept pane, as it blocks the events.
    // However, show any that we previously hid, first just in case something wacky happened.
    if (this._didHideInterceptForPane) {
      this._didHideInterceptForPane.showTouchIntercept();
      this._didHideInterceptForPane = null;
    }

    // now, hide the intercept on this pane if it has one
    var pane = this.get('pane');
    if (pane && pane.get('hasTouchIntercept')) {
      // hide
      pane.hideTouchIntercept();

      // and set our internal one so we can unhide it (even if the pane somehow changes)
      this._didHideInterceptForPane = this.get("pane");
    }
  },

  fieldDidBlur: function (evt) {
    this.resignFirstResponder(evt);

    if (this.get('commitOnBlur')) this.commitEditing(evt);

    // get the pane we hid intercept pane for (if any)
    var touchPane = this._didHideInterceptForPane;
    if (touchPane) {
      touchPane.showTouchIntercept();
      touchPane = null;
    }
  },

  /** @private */
  _field_fieldValueDidChange: function (evt) {
    if (this.get('focused')) {
      SC.run(function () {
        this.fieldValueDidChange(false);
      }, this);
    }

    this.updateHintOnFocus();
  },

  /** @private
    Context-menu paste does not trigger fieldValueDidChange normally. To do so, we'll capture the
    input event and avoid duplicating the "fieldValueDidChange" call if it was already issued elsewhere.

    I welcome someone else to find a better solution to this problem. However, please make sure that it
    works with pasting via shortcut, context menu and the application menu on *All Browsers*.
   */
  _textField_inputDidChange: function () {
    var timerNotPending = SC.empty(this._fieldValueDidChangeTimer) || !this._fieldValueDidChangeTimer.get('isValid');
    if (this.get('applyImmediately') && timerNotPending) {
      this.invokeLater(this.fieldValueDidChange, 10);
    }
  },

  /** @private
    Make sure to update visibility of hint if it changes
   */
  updateHintOnFocus: function () {
    // Fast path. If we aren't using the hind overlay, do nothing.
    if (!this.get('useHintOverlay')) return;

    // If there is a value in the field, hide the hint.
    if (this.getFieldValue()) {
      this.$('.hint').addClass('sc-hidden');
    } else {
      this.$('.hint').removeClass('sc-hidden');
      this._fixupTextLayout();
    }
  }.observes('value'),

  /** @private
    Move magic number out so it can be over-written later in inline editor
   */
  _topOffsetForFirefoxCursorFix: 3,

  /** @private
    In Firefox, as of 3.6 -- including 3.0 and 3.5 -- for input fields only
    (that is, not textarea elements), if the cursor is at the end of the
    field, the "down" key will not result in a "keypress" event for the
    document (only for the input element), although it will be bubbled up in
    other contexts.  Since SproutCore's event dispatching requires the
    document to see the event, we'll manually forward the event along.
   */
  _firefox_dispatch_keypress: function (evt) {
    var selection = this.get('selection'),
        value     = this.get('value'),
        valueLen  = value ? value.length : 0,
        responder;

    if (!selection || ((selection.get('length') === 0 && (selection.get('start') === 0) || selection.get('end') === valueLen))) {
      responder = SC.RootResponder.responder;
      if (evt.keyCode === 9) return;
      responder.keypress.call(responder, evt);
      evt.stopPropagation();
    }
  },

  /** @private */
  _textField_selectionDidChange: function () {
    this.notifyPropertyChange('selection');
  },

  // ..........................................................
  // FIRST RESPONDER SUPPORT
  //
  // When we become first responder, make sure the field gets focus and
  // the hint value is hidden if needed.

  /** @private
    When we become first responder, focus the text field if needed and
    hide the hint text.
   */
  didBecomeKeyResponderFrom: function (keyView) {
    if (this.get('isVisibleInWindow')) {
      var inp = this.$input()[0];
      try {
        if (inp) inp.focus();
      } catch (e) {}

      if (!this._txtFieldMouseDown) {
        this.invokeLast(this._selectRootElement);
      }
    }
  },

  /** @private
    In IE, you can't modify functions on DOM elements so we need to wrap the
    call to select() like this.
   */
  _selectRootElement: function () {
    var inputElem = this.$input()[0],
        isLion;
    // Make sure input element still exists, as a redraw could have remove it
    // already.
    if (inputElem) {
      // Determine if the OS is OS 10.7 "Lion"
      isLion = SC.browser.os === SC.OS.mac &&
          SC.browser.compare(SC.browser.osVersion, '10.7') === 0;

      if (!(SC.browser.name === SC.BROWSER.safari &&
            isLion && SC.buildLocale === 'ko-kr')) {
        inputElem.select();
      }
    }
    else this._textField_selectionDidChange();
  },

  /** @private
    When we lose first responder, blur the text field if needed and show
    the hint text if needed.
   */
  didLoseKeyResponderTo: function (keyView) {
    var el = this.$input()[0];
    if (el) el.blur();
    this.invokeLater("scrollToOriginIfNeeded", 100);
  },

  /** @private
    Scrolls to origin if necessary (if the pane's current firstResponder is not a text field).
   */
  scrollToOriginIfNeeded: function () {
    var pane = this.get("pane");
    if (!pane) return;

    var first = pane.get("firstResponder");
    if (!first || !first.get("isTextField")) {
      document.body.scrollTop = document.body.scrollLeft = 0;
    }
  },

  /** @private */
  keyDown: function (evt) {
    return this.interpretKeyEvents(evt) || false;
  },

  /** @private */
  insertText: function (chr, evt) {
    var which = evt.which,
        keyCode = evt.keyCode,
        maxLengthReached = false;

    // maxlength for textareas
    if (!SC.platform.input.maxlength && this.get('isTextArea')) {
      var val = this.get('value');

      // This code is nasty. It's thanks to Gecko .keycode table that has characters like '&' with the same keycode as up arrow key
      if (val && ((!SC.browser.isMozilla && which > 47) ||
                  (SC.browser.isMozilla && ((which > 32 && which < 43) || which > 47) && !(keyCode > 36 && keyCode < 41))) &&
          (val.length >= this.get('maxLength'))) {
        maxLengthReached = true;
      }
    }

    // Validate keyDown...
    if (this.performValidateKeyDown(evt) && !maxLengthReached) {
      evt.allowDefault();
    } else {
      evt.stop();
    }

    if (this.get('applyImmediately')) {
      // This has gone back and forth several times between invokeLater and setTimeout.
      // Now we're back to invokeLater, please read the code comment above
      // this._textField_inputDidChange before changing it again.
      this._fieldValueDidChangeTimer = this.invokeLater(this.fieldValueDidChange, 10);
    }

    return true;
  },

  /** @private */
  insertTab: function (evt) {
    // Don't handle if default tabbing hasn't been enabled.
    if (!this.get('defaultTabbingEnabled')) {
      evt.preventDefault();
      return false;
    }

    // Otherwise, handle.
    var view = this.get('nextValidKeyView');
    if (view) view.becomeFirstResponder();
    else evt.allowDefault();
    return true; // handled
  },

  /** @private */
  insertBacktab: function (evt) {
    // Don't handle if default tabbing hasn't been enabled.
    if (!this.get('defaultTabbingEnabled')) {
      evt.preventDefault();
      return false;
    }

    // Otherwise, handle.
    var view = this.get('previousValidKeyView');
    if (view) view.becomeFirstResponder();
    else evt.allowDefault();
    return true; // handled
  },

  /**
    @private

    Invoked when the user presses return.  If this is a multi-line field,
    then allow the newline to proceed.  Otherwise, try to commit the
    edit.
  */
  insertNewline: function (evt) {
    if (this.get('isTextArea') || evt.isIMEInput) {
      evt.allowDefault();
      return true; // handled
    }
    return false;
  },

  /** @private */
  deleteForward: function (evt) {
    evt.allowDefault();
    return true;
  },

  /** @private */
  deleteBackward: function (evt) {
    evt.allowDefault();
    return true;
  },

  /** @private */
  moveLeft: function (evt) {
    evt.allowDefault();
    return true;
  },

  /** @private */
  moveRight: function (evt) {
    evt.allowDefault();
    return true;
  },

  /** @private */
  selectAll: function (evt) {
    evt.allowDefault();
    return true;
  },

  /** @private */
  moveUp: function (evt) {
    if (this.get('isTextArea')) {
      evt.allowDefault();
      return true;
    }
    return false;
  },

  /** @private */
  moveDown: function (evt) {
    if (this.get('isTextArea')) {
      evt.allowDefault();
      return true;
    }
    return false;
  },

  keyUp: function (evt) {
    if (SC.browser.isMozilla &&
        evt.keyCode === SC.Event.KEY_RETURN) { this.fieldValueDidChange(); }

    // The caret/selection may have changed.
    // This cannot notify immediately, because in some browsers (tested Chrome 39.0 on OS X), the
    // value of `selectionStart` and `selectionEnd` won't have updated yet. Thus if we notified
    // immediately, observers of this view's `selection` property would get the old value.
    this.invokeNext(this._textField_selectionDidChange);

    evt.allowDefault();
    return true;
  },

  mouseDown: function (evt) {
    if (!this.get('isEnabledInPane')) {
      evt.stop();
      return true;
    } else {
      this._txtFieldMouseDown = true;
      this.becomeFirstResponder();

      return arguments.callee.base.apply(this,arguments);
    }
  },

  mouseUp: function (evt) {
    this._txtFieldMouseDown = false;

    if (!this.get('isEnabledInPane')) {
      evt.stop();
      return true;
    }

    // The caret/selection may have changed.
    // This cannot notify immediately, because in some browsers (tested Chrome 39.0 on OS X), the
    // value of `selectionStart` and `selectionEnd` won't have updated yet. Thus if we notified
    // immediately, observers of this view's `selection` property would get the old value.
    this.invokeNext(this._textField_selectionDidChange);

    return arguments.callee.base.apply(this,arguments);
  },

  touchStart: function (evt) {
    return this.mouseDown(evt);
  },

  touchEnd: function (evt) {
    return this.mouseUp(evt);
  },

  /**
    Adds mouse wheel support for textareas.
   */
  mouseWheel: function (evt) {
    if (this.get('isTextArea')) {
      evt.allowDefault();
      return true;
    } else return false;
  },

  /**
    Allows text selection in IE. We block the IE only event selectStart to
    block text selection in all other views.
   */
  selectStart: function (evt) {
    return true;
  },

  /** @private
    Overridden from SC.FieldView. Provides correct tag name based on the
    `isTextArea` property.
   */
  _inputElementTagName: function () {
    if (this.get('isTextArea')) {
      return 'textarea';
    } else {
      return 'input';
    }
  },

  /** @private
    This observer makes sure to hide the hint when a value is entered, or
    show it if it becomes empty.
   */
  _valueObserver: function () {
    var val = this.get('value'), max;

    if (val && val.length > 0) {
      max = this.get('maxLength');

      if (!SC.platform.input.maxlength && val.length > max) {
        this.set('value', val.substr(0, max));
      }
    }
  }.observes('value')

});

/* >>>>>>>>>> BEGIN source/views/inline_text_field.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('views/text_field') ;
sc_require('system/utils/misc') ;
sc_require('delegates/inline_text_field');
sc_require('mixins/inline_editor');

/**
  @class

  The inline text editor is used to display an editable area for controls
  that are not always editable such as label views and source list views.

  You generally will not use the inline editor directly but instead will
  invoke beginEditing() and endEditing() on the views you are
  editing. If you would like to use the inline editor for your own views,
  you can do that also by using the editing API described here.

  ## Using the Inline Editor in Your Own Views

  To use the inlineEditor on a custom view you should mixin SC.InlineEditable on
  it. SC.InlineTextFieldView is the default editor so you do not need to do any
  other setup. The class methods beginEditing, commitEditing, and discardEditing
  still exist for backwards compatibility but should not be used on new views.

      MyProject.MyView = SC.View.extend(SC.InlineEditable, {
      });

  ### Starting the Editor

  The inline editor works by positioning itself over the top of your view
  with the same offset, width, and font information.

  To start it simply call beginEditing on your view.

      myView.beginEditing();

  By default, if the inline editor is currently in use elsewhere, it will automatically
  close itself over there and begin editing for your view instead. This behavior
  is defined by the inlineEditorDelegate of your view, and can be changed by using
  one other than the default.

  ## Customizing the editor

  The editor has several parameters that can be used to customize it to your
  needs. These options should be set on the editor passed to your delegate's (or
  view's) inlineEditorWillBeginEditing method:

   - `exampleFrame` -- The editors initial frame in viewport coordinates.
   - `value` -- Initial value of the edit field.
   - `exampleElement` -- A DOM element to use when copying styles.
   - `multiline` -- If YES then the hitting return will add to the value instead
     of exiting the inline editor.
   - `commitOnBlur` -- If YES then blurring will commit the value, otherwise it
     will discard the current value.  Defaults to YES.
   - `validator` -- Validator to be attached to the field.

  For backwards compatibility, calling the class method beginEditing with an
  options hash will translate the values in the hash to the correct settings on
  the editor.

  ## Committing or Discarding Changes

  Normally the editor will automatically commit or discard its changes
  whenever the user exits the edit mode by pressing enter, escape, or clicking
  elsewhere on the page. If you need to force the editor to end editing, you can
  do so by calling commitEditing() or discardEditing():

      myView.commitEditing();
      myView.discardEditing();

  Both methods will try to end the editing context and will call the
  relevant delegate methods on the inlineEditorDelegate set on your view.

  Note that it is possible an editor may not be able to commit editing
  changes because either the delegate disallowed it or because its validator
  failed.  In this case commitEditing() will return NO.  If you want to
  end editing anyway, you can discard the editing changes instead by calling
  discardEditing().  This method will generally succeed unless your delegate
  refuses it as well.

  @extends SC.TextFieldView
  @since SproutCore 1.0
*/
SC.InlineTextFieldView = SC.TextFieldView.extend(SC.InlineEditor,
/** @scope SC.InlineTextFieldView.prototype */ {
  classNames: ['inline-editor'],

  /**
    Over-write magic number from SC.TextFieldView
  */
  _topOffsetForFirefoxCursorFix: 0,

  /**
    The default size of the inline text field is 0 x 0 so that when it is
    appended, but before it is positioned it doesn't fill the parent view
    entirely.

    This is important, because if the parent view layer allows overflow,
    we could inadvertently alter the scrollTop or scrollLeft properties
    of the layer.
    */
  layout: { height: 0, width: 0 },

  /*
    @private

    Prevents the view from taking part in child view layout plugins.
  */
  useAbsoluteLayout: YES,

  /*
  * @private
  * @method
  *
  * Scans the given element for presentation styles from css.
  *
  * @params {element} the dom element to scan
  * @returns {String} a style string that was copied from the element
  */
  _updateViewStyle: function(el) {
    var styles = '',
        s=SC.getStyle(el,'font-size');

    if(s && s.length>0) styles = styles + "font-size: "+ s + " !important; ";

    s=SC.getStyle(el,'font-family');
    if(s && s.length>0) styles = styles + "font-family: " + s + " !important; ";

    s=SC.getStyle(el,'font-weight');
    if(s && s.length>0) styles = styles + "font-weight: " + s + " !important; ";

    s=SC.getStyle(el,'z-index');
    if(s && s.length>0) styles = styles + "z-index: " + s + " !important; ";

    s=SC.getStyle(el,'line-height');
    if(s && s.length>0) styles = styles + "line-height: " + s + " !important; ";

    s=SC.getStyle(el,'text-align');
    if(s && s.length>0) styles = styles + "text-align: " + s + " !important; ";

    s=SC.getStyle(el,'top-margin');
    if(s && s.length>0) styles = styles + "top-margin: " + s + " !important; ";

    s=SC.getStyle(el,'bottom-margin');
    if(s && s.length>0) styles = styles + "bottom-margin: " + s + " !important; ";

    s=SC.getStyle(el,'left-margin');
    if(s && s.length>0) styles = styles + "left-margin: " + s + " !important; ";

    s=SC.getStyle(el,'right-margin');
    if(s && s.length>0) styles = styles + "right-margin: " + s + " !important; ";

    return styles;
  },

  /*
  * @private
  * @method
  *
  * Scans the given element for positioning styles from css.
  *
  * @params {element} the dom element to scan
  * @returns {String} a style string copied from the element
  */
  _updateViewPaddingStyle: function(el) {
    var styles = '',
    s=SC.getStyle(el,'padding-top');

    if(s && s.length>0) styles = styles + "top: "+ s + " !important; ";

    s=SC.getStyle(el,'padding-bottom');
    if(s && s.length>0) styles = styles + "bottom: " + s + " !important; ";

    s=SC.getStyle(el,'padding-left');
    if(s && s.length>0) styles = styles + "left: " + s + " !important; ";

    s=SC.getStyle(el,'padding-right');
    if(s && s.length>0) styles = styles + "right: " + s + " !important; ";

    return styles;
	},

  /*
  * @private
  * @method
  *
  * Scans the given element for styles and copies them into a style element in
  * the head. This allows the styles to be overridden by css matching classNames
  * on the editor.
  *
  * @params {element} the dom element to copy
  */
	updateStyle: function(exampleElement) {
    if(exampleElement.length) exampleElement = exampleElement[0];

    // the styles are placed into a style element so that they can be overridden
    // by your css based on the editor className
    var styleElement = document.getElementById('sc-inline-text-field-style'),
		s = this._updateViewStyle(exampleElement),
		p = this._updateViewPaddingStyle(exampleElement),

		str = ".inline-editor input{"+s+"}" +
					".inline-editor textarea{"+s+"}" +
					".inline-editor .padding{"+p+"}";

    // the style element is lazily created
    if(!styleElement) {
      var head = document.getElementsByTagName('head')[0];
      styleElement = document.createElement('style');

      styleElement.type= 'text/css';
      styleElement.media= 'screen';
      styleElement.id = 'sc-inline-text-field-style';

      head.appendChild(styleElement);
    }

    // now that we know the element exists, write the styles

    // IE method
    if(styleElement.styleSheet) styleElement.styleSheet.cssText= str;
    // other browsers
    else styleElement.innerHTML = str;
	},

  /*
  * @method
  *
  * Positions the editor over the target view.
  *
  * If you want to tweak the positioning of the editor, you may pass a custom
  * frame for it to position itself on.
  *
  * @param {SC.View} the view to be positioned over
  * @param {Hash} optional custom frame
  * @param {Boolean} if the view is a member of a collection
  */
	positionOverTargetView: function(target, exampleFrame, elem, _oldExampleFrame, _oldElem) {
    var targetLayout = target.get('layout'),
        layout = {};

    // Deprecates isCollection and pane arguments by fixing them up if they appear.
    if (!SC.none(_oldExampleFrame)) {
      exampleFrame = _oldExampleFrame;
      elem = _oldElem;

      

    }

    // In case where the label is part of an SC.ListItemView
    if (exampleFrame && elem) {
      var frame = SC.offset(elem, 'parent');

      layout.top = targetLayout.top + frame.y - exampleFrame.height/2;
      layout.left = targetLayout.left + frame.x;
      layout.height = exampleFrame.height;
      layout.width = exampleFrame.width;
    } else {
      layout = SC.copy(targetLayout);
    }

    this.set('layout', layout);
  },

  /*
  * Flag indicating whether the editor is allowed to use multiple lines.
  * If set to yes it will be rendered using a text area instead of a text input.
  *
  * @type {Boolean}
  */
  multiline: NO,

  /*
  * Translates the multiline flag into something TextFieldView understands.
  *
  * @type {Boolean}
  */
  isTextArea: function() {
    return this.get('multiline');
  }.property('multiline').cacheable(),

  /*
  * Begins editing the given view, positions the editor on top of the view, and
  * copies the styling of the view onto the editor.
  *
  * @params {SC.InlineEditable} the view being edited
  *
  * @returns {Boolean} YES on success
  */
  beginEditing: function(original, label) {
		if(!original(label)) return NO;

    var pane = label.get('pane'),
      elem = this.get('exampleElement');

    this.beginPropertyChanges();

    if (label.multiline) this.set('multiline', label.multiline);

    // if we have an exampleElement we need to make sure it's an actual
    // DOM element not a jquery object
    if (elem) {
      if(elem.length) elem = elem[0];
    }

    // if we don't have an element we need to get it from the target
    else {
      elem = label.$()[0];
    }

    this.updateStyle(elem);

    this.positionOverTargetView(label, this.get('exampleFrame'), elem);

    this._previousFirstResponder = pane ? pane.get('firstResponder') : null;
    this.becomeFirstResponder();
    this.endPropertyChanges() ;

    return YES;
  }.enhance(),

  /**
    Invoked whenever the editor loses (or should lose) first responder
    status to commit or discard editing.

    @returns {Boolean}
  */
  // TODO: this seems to do almost the same thing as fieldDidBlur
  blurEditor: function(evt) {
    if (this.get('isEditing')) {
      return this.commitOnBlur ? this.commitEditing() : this.discardEditing();
    } else {
      return true;
    }
  },

  /**
    @method
    @private

    Called by commitEditing and discardEditing to actually end editing.

  */
  _endEditing: function(original) {
    var ret = original();

    // resign first responder if not done already.  This may call us in a
    // loop but since isEditing is already NO, nothing will happen.
    if (this.get('isFirstResponder')) {
      var pane = this.get('pane');
      if (pane && this._previousFirstResponder) {
        pane.makeFirstResponder(this._previousFirstResponder);
      } else this.resignFirstResponder();
    }
    this._previousFirstResponder = null ; // clearout no matter what

    return ret;
  }.enhance(),

  // TODO: make textArea automatically resize to fit content

  /** @private */
  mouseDown: function(e) {
    arguments.callee.base.call(this, e) ;
    return this.get('isEditing');
  },

  touchStart: function(e){
    this.mouseDown(e);
  },

  _scitf_blurInput: function() {
    var el = this.$input()[0];
    if (el) el.blur();
    el = null;
  },

  // [Safari] if you don't take key focus away from an element before you
  // remove it from the DOM key events are no longer sent to the browser.
  /** @private */
  willRemoveFromParent: function() {
    return this._scitf_blurInput();
  },

  // ask owner to end editing.
  /** @private */
  willLoseFirstResponder: function(responder, evt) {
    if (responder !== this) return;

    // if we're about to lose first responder for any reason other than
    // ending editing, make sure we clear the previous first responder so
    // isn't cached
    this._previousFirstResponder = null;

    // store the original event that caused this to loose focus so that
    // it can be passed to the delegate
    this._origEvent = evt;

    // should have been covered by willRemoveFromParent, but this was needed
    // too.
    this._scitf_blurInput();
    return this.blurEditor(evt) ;
  },

  /**
    invoked when the user presses escape.  Returns true to ignore keystroke

    @returns {Boolean}
  */
  cancel: function() {
    this.discardEditing();
    return YES;
  },

  // Invoked when the user presses return.  If this is a multi-line field,
  // then allow the new line to proceed by calling the super class.
  // Otherwise, try to commit the edit.
  /** @private */
  insertNewline: function(evt) {
    if (this.get('isTextArea')) {
      return arguments.callee.base.apply(this,arguments);
    } else {
      this.commitEditing() ;
      return YES ;
    }
  },

  // Tries to find the next key view when tabbing.  If the next view is
  // editable, begins editing.
  /** @private */
  insertTab: function(evt) {
    var target = this.target; // removed by commitEditing()
    this.resignFirstResponder();
    if(target){
      var next = target.get('nextValidKeyView');
      if(next && next.beginEditing) next.beginEditing();
    }
    return YES ;
  },

  /** @private */
  insertBacktab: function(evt) {
    var target = this.target; // removed by commitEditing()
    this.resignFirstResponder();
    if(target){
      var prev = target.get('previousValidKeyView');
      if(prev && prev.beginEditing) prev.beginEditing();
    }
    return YES ;
  }
});

/* >>>>>>>>>> BEGIN source/views/label.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('mixins/inline_editable');
sc_require('mixins/inline_editor_delegate');
sc_require('delegates/inline_text_field');


/**
  @class

  Displays a static string of text.

  You use a label view anytime you need to display a static string of text
  or to display text that may need to be edited using only an inline control.

  @extends SC.View
  @extends SC.Control
  @extends SC.InlineEditable
  @extends SC.InlineEditorDelegate
  @since SproutCore 1.0
*/
SC.LabelView = SC.View.extend(SC.Control, SC.InlineEditable,
/** @scope SC.LabelView.prototype */ {

  classNames: ['sc-label-view'],

  displayProperties: ['displayTitle', 'displayHint', 'displayToolTip', 'icon'],

  /**
    The delegate that gets notified of events related to the editing process. Set
    this to the object you want to handles the lifecycle of the inline editor.

    Defaults to itself.
    @type SC.Object
  */
  inlineEditorDelegate: SC.InlineTextFieldDelegate,

  isEditable: NO,

  /**
    The exampleInlineTextFieldView property is by default a
    SC.InlineTextFieldView but it can be set to a customized inline text field
    view.

    @property
    @type {SC.View}
    @default {SC.InlineTextFieldView}
  */
  exampleEditor: SC.InlineTextFieldView,

  /**
    Whether the value, hint and toolTip will be escaped to avoid HTML injection
    attacks or not.

    You should only disable this option if you are sure you are displaying
    non-user generated text.

    Note: this is not an observed display property.  If you change it after
    rendering, you should call `displayDidChange` on the view to update the layer.

    @type Boolean
    @default true
  */
  escapeHTML: true,

  /**
    If true, then the value will be localized.
    This is a default that can be overidden by the settings in the owner view.
  */
  localize: NO,
  localizeBindingDefault: SC.Binding.oneWay().bool(),

  /**
    If set to true, the label element will include the 'ellipsis' class, which
    by default sets the 'white-space' style to 'nowrap' and the 'text-overflow'
    style to 'ellipsis'.

    Note: that this does NOT work with multi-line text.

    Note: this is not an observed display property.  If you change it after
    rendering, you should call `displayDidChange` on the view to update the layer.

    @type Boolean
    @default false
   */
  needsEllipsis: false,

  /**
    Set this to a validator or to a function and the value
    will be passed through it before being set.

    This is a default default that can be overidden by the
    settings in the owner view.
  */
  formatter: null,

  /**
    The value of the label.

    You may also set the value using a content object and a contentValueKey.

    @field {String}
  */
  value: '',

  /**
    The hint to display if no value is set.  Should be used only if isEditable
    is set to YES.
  */
  hint: null,

  /** @deprecated */
  hintEnabled: function() {
    

    return this.get('isEditable');
  }.property('isEditable').cacheable(),

  /**
    An optional icon to display to the left of the label.  Set this value
    to either a CSS class name (for spriting) or an image URL.
  */
  icon: null,

  /**
    Set the alignment of the label view.

    Note: this is not an observed display property.  If you change it after
    rendering, you should call `displayDidChange` on the view to update the layer.

    @type String SC.ALIGN_LEFT|SC.ALIGN_CENTER|SC.ALIGN_RIGHT
    @default null
    @deprecated Use CSS instead.
  */
  textAlign: null,

  //
  // SUPPORT FOR AUTOMATIC RESIZING
  //
  supportsAutoResize: YES,
  autoResizeLayer: function() { return this.get('layer'); }
  .property('layer').cacheable(),

  autoResizeText: function() { return this.get('displayTitle'); }
  .property('displayTitle').cacheable(),

  autoResizePadding: SC.propertyFromRenderDelegate('autoResizePadding', { height: 0, width: 10 }),

  /**
    The name of the theme's SC.LabelView render delegate.

    @type String
  */
  renderDelegateName: 'labelRenderDelegate',

  /**
    The value that will actually be displayed.

    This property is dynamically computed by applying localization,
    string conversion and other normalization utilities.

    @type String
  */
  displayTitle: function() {
    var value, formatter;

    value = this.get('value') ;

    // 1. apply the formatter
    formatter = this.getDelegateProperty('formatter', this.displayDelegate) ;
    if (formatter) {
      var formattedValue = (SC.typeOf(formatter) === SC.T_FUNCTION) ?
          formatter(value, this) : formatter.fieldValueForObject(value, this) ;
      if (!SC.none(formattedValue)) value = formattedValue ;
    }

    // 2. If the returned value is an array, convert items to strings and
    // join with commas.
    if (SC.typeOf(value) === SC.T_ARRAY) {
      var ary = [];
      for(var idx=0, idxLen = value.get('length'); idx< idxLen;idx++) {
        var x = value.objectAt(idx) ;
        if (!SC.none(x) && x.toString) x = x.toString() ;
        ary.push(x) ;
      }
      value = ary.join(',') ;
    }

    // 3. If value is not a string, convert to string. (handles 0)
    if (!SC.none(value) && value.toString) value = value.toString() ;

    // 4. Localize
    if (value && this.getDelegateProperty('localize', this.displayDelegate)) value = SC.String.loc(value) ;

    return value;
  }.property('value', 'localize', 'formatter').cacheable(),

  /**
    The hint that will actually be displayed depending on localization and
    sanitizing (or not).

    @type String
  */
  displayHint: function () {
    var hint = this.get('hint'),
      isEditable = this.get('isEditable');

    if (isEditable) {
      if (hint && this.getDelegateProperty('localize', this.displayDelegate)) {
        hint = SC.String.loc(hint);
      }
    } else {
      hint = null;
    }

    return hint;
  }.property('hint', 'localize', 'isEditable').cacheable(),

  /** @deprecated */
  hintValue: function() {
    

    var hintVal = this.get('hint');
    return hintVal;
  }.property('hint').cacheable(),

  /** @private */
  mouseDown: function(evt) {
    // Capture the event if it's a double click and we are editable.
    return this.get('isEditable') && evt.clickCount === 2;
  },

  /** @private If isEditable is set to true, opens the inline text editor view. */
  doubleClick: function (evt) { return this.beginEditing(); },

  /*
  * @method
  *
  * Hide the label view while the inline editor covers it.
  */
  inlineEditorDidBeginEditing: function(original, editor, value, editable) {
    this._oldOpacity = this.get('layout').opacity || 1;
    this.adjust('opacity', 0);

    original(editor, value, editable);
  }.enhance(),

  /*
  * @method
  *
  * Restore the label view when the inline editor finishes.
  */
  inlineEditorDidEndEditing: function() {
    this.adjust('opacity', this._oldOpacity);
    this._oldOpacity = null ;
  }
});


/* >>>>>>>>>> BEGIN javascript.js */
/* >>>>>>>>>> BEGIN source/core.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


/**
  If set to `NO`, then pressing backspace will NOT navigate to the previous
  page in the browser history, which is the default behavior in most browsers.
  
  Usually it is best to leave this property set to `NO` in order to prevent the
  user from inadvertently losing data by pressing the backspace key.

  @static
  @type Boolean
  @default NO
*/
SC.allowsBackspaceToPreviousPage = NO;

/**
  @type String
  @static
  @constant
*/
SC.HORIZONTAL_ORIENTATION = 'horizontal';

/**
  @type String
  @static
  @constant
*/
SC.VERTICAL_ORIENTATION = 'vertical' ;

/* >>>>>>>>>> BEGIN source/mixins/collection_group.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @namespace

  Any view you want to use as a group view in a collection must include this
  mixin.
  
  @since SproutCore 1.0
*/
SC.CollectionGroup = {
  
  /**
    @type Array
    @default ['sc-collection-group']
    @see SC.View#classNames
  */
  classNames: ['sc-collection-group']
  
};

/* >>>>>>>>>> BEGIN source/mixins/collection_row_delegate.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


/**
  @namespace

  `CollectionRowDelegate`s are consulted by collection views, such as `SC.ListView`
  that lay out items in vertical or horizontal rows, in order to determine the
  height or width of each row.
*/
SC.CollectionRowDelegate = {

  /**
    Walk like a duck.

    @type Boolean
    @default true
  */
  isCollectionRowDelegate: true,

  /** @deprecated Version 1.11. Please use the `rowSize` property instead.
    Size of an item without spacing or padding.
    Unless you implement custom row height or widths upport, this row height will be used for all items.

    @type Number
    @default 24
  */
  itemHeight: null,

  /**
    The height or width of a row before padding depending on whether the
    collection is laid out vertically or horizontally.

    Unless you implement custom row size support, this value will be used for
    all rows.

    @type Number
    @default 24
  */
  // This is a computed property in order to provide backwards compatibility for itemHeight.
  // When itemHeight is removed completely, this can become a simple `24` value.
  rowSize: function (key, value) {
    var itemHeight = this.get('itemHeight'),
      ret = 24;

    // Backwards compatibility support
    if (!SC.none(itemHeight)) {
      


      return itemHeight;
    }

    if (!SC.none(value)) { ret = value; }

    return ret;
  }.property('itemHeight').cacheable(),

  /**
    The amount of space to leave between each row.

    This is useful when you need to leave space for borders.

    @type Number
    @default 0
  */
  rowSpacing: 0,

  /**
    Padding space added to the top and bottom of each row when laid out vertically,
    or to the left and right when laid out horizontally.

    This is useful if you are using a custom item view that needs to be padded.

    @type Number
    @default 0
  */
  rowPadding: 0,

  /** @deprecated Version 1.11. Please use a combination of rowSize and rowPadding to specify the total height or width of each row.
    Total row size used for calculation. Equal to `rowSize + (2 * rowPadding)`.

    @type Number
  */
  rowHeight: function (key, value) {
    var rowPadding = this.get('rowPadding'),
      rowSize = this.get('rowSize');

    if (value !== undefined) {
      this.set('rowSize', value - rowPadding * 2);
      return value;
    }

    return rowSize + rowPadding * 2;
  }.property('rowSize', 'rowPadding'),

  /** @private - Returns the total row size based on rowSize and rowPadding for convenience. */
  _sc_totalRowSize: function () {
    // Backwards compatibility in case the rowHeight property is set directly.
    return this.get('rowHeight');
  }.property('rowHeight'),

  /** @deprecated Version 1.11. Please use the `customRowSizeIndexes` property instead.
    Index set of rows that should have a custom row height. If you need
    certain rows to have a custom row height, then set this property to a
    non-null value.  Otherwise leave it blank to disable custom row heights.

    @type SC.IndexSet
  */
  customRowHeightIndexes: null,

  /**
    Index set of rows that should have a custom row height. If you need
    certain rows to have a custom row height, then set this property to a
    non-null value.  Otherwise leave it blank to disable custom row heights.

    @type SC.IndexSet
  */
  // This is a computed property in order to provide backwards compatibility for customRowHeightIndexes.
  // When customRowHeightIndexes is removed completely, this can become a simple `null` value.
  customRowSizeIndexes: function (key, value) {
    var customRowHeightIndexes = this.get('customRowHeightIndexes'),
      ret = null;

    // Backwards compatibility support.
    if (!SC.none(customRowHeightIndexes)) {
      


      return customRowHeightIndexes;
    }

    if (!SC.none(value)) { ret = value; }

    return ret;
  }.property('customRowHeightIndexes').cacheable(),

  /** @deprecated Version 1.11. Please use the `contentIndexRowSize()` function instead.
    Called for each index in the `customRowSizeIndexes` set to get the
    actual row height for the index.  This method should return the default
    rowSize if you don't want the row to have a custom height.

    The default implementation just returns the default rowSize.

    @param {SC.CollectionView} view the calling view
    @param {Object} content the content array
    @param {Number} contentIndex the index
    @returns {Number} row height
  */
  contentIndexRowHeight: function (view, content, contentIndex) {
    return this.get('_sc_totalRowSize');
  },

  /**
    Called for each index in the `customRowSizeIndexes` set to get the
    actual row size for the index.  This method should return the default
    rowSize if you don't want the row to have a custom size.

    The default implementation just returns the default rowSize plus rowPadding.

    @param {SC.CollectionView} view the calling view
    @param {Object} content the content array
    @param {Number} contentIndex the index
    @returns {Number} row size
  */
  contentIndexRowSize: function (view, content, contentIndex) {
    // Backwards compatibility in case the contentIndexRowHeight function is overridden.
    return this.contentIndexRowHeight(view, content, contentIndex);
  }

};

/* >>>>>>>>>> BEGIN source/mixins/collection_view_delegate.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @namespace

  A Collection View Delegate is consulted by a `SC.CollectionView` to make
  policy decisions about certain behaviors such as selection control and
  drag and drop.  If you need to control other aspects of your data, you may
  also want to add the `SC.CollectionContent` mixin.
  
  To act as a Collection Delegate, just apply this mixin to your class.  You
  must then set the "delegate" property on the CollectionView to your object.
  
  Alternatively, if no delegate is set on a CollectionView, but the content 
  implements this mixin, the content object will be used as the delegate 
  instead.
  
  If you set an ArrayController or its arrangedObjects property as the content
  of a CollectionView, the ArrayController will automatically act as the 
  delegate for the view.
  
  @since SproutCore 1.0
*/
SC.CollectionViewDelegate = {

  /**
    Walk like a duck. Used to detect the mixin by SC.CollectionView.
    
    @type Boolean
    @default YES
    @constant
  */
  isCollectionViewDelegate: YES,


  // ..........................................................
  // SELECTION
  // 

  /**
    This method will be called anytime the collection view is about to
    change the selection in response to user mouse clicks or keyboard events.
    
    You can use this method to adjust the proposed selection, eliminating any
    selected objects that cannot be selected.  The default implementation of
    this method simply returns the proposed selection.
    
    @param {SC.CollectionView} view the collection view
    @param {SC.IndexSet} sel Proposed array of selected objects.
    @returns {SC.IndexSet} Actual allow selection index set
  */
  collectionViewSelectionForProposedSelection: function(view, sel) {
    return sel;
  },

  /**
    Called by the collection when attempting to select an item.  Return the
    actual indexes you want to allow to be selected.  Return null to disallow
    the change.  The default allows all selection.
    
    @param {SC.CollectionView} view the view collection view
    @param {SC.IndexSet} indexes the indexes to be selected
    @param {Boolean} extend YES if the indexes will extend existing sel
    @returns {SC.IndexSet} allowed index set
  */
  collectionViewShouldSelectIndexes: function (view, indexes, extend) {
    return indexes;
  },

  /**
    Called by the collection when attempting to deselect an item.  Return the
    actual indexes you want to allow to be deselected.  Return `null` to
    disallow the change.  The default allows all selection.
    
    Note that you should not modify the passed in IndexSet.  clone it instead.
    
    @param {SC.CollectionView} view the view collection view
    @param {SC.IndexSet} indexes the indexes to be selected
    @returns {SC.IndexSet} allowed index set
  */
  collectionViewShouldDeselectIndexes: function (view, indexes) {
    return indexes;
  },


  // ..........................................................
  // EDIT OPERATIONS
  // 

  /**
    Called by the collection view whenever the `deleteSelection()` method is
    called.  You can implement this method to get fine-grained control over
    which items can be deleted.  To prevent deletion, return null.
    
    This method is only called if canDeleteContent is `YES` on the collection
    view.
    
    @param {SC.CollectionView} view the collection view
    @param {SC.IndexSet} indexes proposed index set of items to delete.
    @returns {SC.IndexSet} index set allowed to delete or null.
  */
  collectionViewShouldDeleteIndexes: function(view, indexes) {
    return indexes;
  },

  /**
    Called by the collection view to actually delete the selected items.
    
    The default behavior will use standard array operators to delete the
    indexes from the array. You can implement this method to provide your own
    deletion method.
    
    If you simply want to control the items to be deleted, you should instead
    implement `collectionViewShouldDeleteItems()`. This method will only be
    called if canDeleteContent is `YES` and `collectionViewShouldDeleteIndexes()`
    returns a non-empty index set
    
    @param {SC.CollectionView} view collection view
    @param {SC.IndexSet} indexes the items to delete
    @returns {Boolean} YES if the deletion was a success.
  */
  collectionViewDeleteContent: function(view, content, indexes) {
    if (!content) return NO ;

    if (SC.typeOf(content.destroyAt) === SC.T_FUNCTION) {
      content.destroyAt(indexes);
      view.selectPreviousItem(NO, 1);
      return YES ;
    } else if (SC.typeOf(content.removeAt) === SC.T_FUNCTION) {
      content.removeAt(indexes);
      view.selectPreviousItem(NO, 1);
      return YES;
    } else {
      return NO;
    }
  },


  // ..........................................................
  // DRAGGING
  // 
  
  /**
    Called by the collection view just before it starts a drag to give you
    an opportunity to decide if the drag should be allowed.
    
    You can use this method to implement fine-grained control over when a
    drag will be allowed and when it will not be allowed. For example, you
    may enable content reordering but then implement this method to prevent
    reordering of certain items in the view.
    
    The default implementation always returns `YES`.
    
    @param {SC.CollectionView} view the collection view
    @returns {Boolean} YES to allow, NO to prevent it
  */
  collectionViewShouldBeginDrag: function(view) {
    return YES;
  },

  /**
    Called by the collection view just before it starts a drag so that
    you can provide the data types you would like to support in the data.
    
    You can implement this method to return an array of the data types you
    will provide for the drag data.
    
    If you return `null` or an empty array, can you have set `canReorderContent`
    to `YES` on the CollectionView, then the drag will go ahead but only
    reordering will be allowed.  If `canReorderContent` is `NO`, then the drag
    will not be allowed to start.
    
    If you simply want to control whether a drag is allowed or not, you
    should instead implement `collectionViewShouldBeginDrag()`.
    
    The default returns an empty array.
    
    @param {SC.CollectionView} view the collection view to begin dragging.
    @returns {Array} array of supported data types.
  */
  collectionViewDragDataTypes: function(view) {
    return [];
  },

  /**
    Called by a collection view when a drag concludes to give you the option
    to provide the drag data for the drop.
    
    This method should be implemented essentially as you would implement the
    `dragDataForType()` if you were a drag data source.  You will never be asked
    to provide drag data for a reorder event, only for other types of data.
    
    The default implementation returns null.
    
    @param view {SC.CollectionView} the collection view that initiated the drag
    @param dataType {String} the data type to provide
    @param drag {SC.Drag} the drag object
    @returns {Object} the data object or null if the data could not be provided.
  */
  collectionViewDragDataForType: function(view, drag, dataType) {
    return null;
  },

  /**
    Called once during a drag the first time view is entered. Return all
    possible drag operations OR'd together.
    
    @param {SC.CollectionView} view the collection view that initiated the drag
    @param {SC.Drag} drag the drag object
    @param {Number} proposedDragOperations proposed logical OR of allowed drag operations.
    @returns {Number} the allowed drag operations. Defaults to op
  */
  collectionViewComputeDragOperations: function(view, drag, proposedDragOperations) {
    return proposedDragOperations;
  },

  /**
    Called by the collection view during a drag to let you determine the
    kind and location of a drop you might want to accept.
    
    You can override this method to implement fine-grained control over how
    and when a dragged item is allowed to be dropped into a collection view.
    
    This method will be called by the collection view both to determine in
    general which operations you might support and specifically the operations
    you would support if the user dropped an item over a specific location.
    
    If the `proposedDropOperation` parameter is `SC.DROP_ON` or `SC.DROP_BEFORE`,
    then the `proposedInsertionPoint` will be a non-negative value and you
    should determine the specific operations you will support if the user
    dropped the drag item at that point.
    
    If you do not like the proposed drop operation or insertion point, you
    can override these properties as well by setting the `proposedDropOperation`
    and `proposedInsertionIndex` properties on the collection view during this
    method. These properties are ignored all other times.
    
    @param {SC.CollectionView} view the collection view
    @param {SC.Drag} drag the current drag object
    @param {Number} op proposed logical OR of allowed drag operations.
    @param {Number} proposedInsertionIndex an index into the content array representing the proposed insertion point.
    @param {String} proposedDropOperation the proposed drop operation. Will be one of SC.DROP_ON, SC.DROP_BEFORE, or SC.DROP_ANY.
    @returns the allowed drag operation. Defaults to op
  */
  collectionViewValidateDragOperation: function(view, drag, op, proposedInsertionIndex, proposedDropOperation) {
    // don't allow dropping on by default
    return (proposedDropOperation & SC.DROP_ON) ? SC.DRAG_NONE : op ;
  },
  
  /**
    Called by the collection view to actually accept a drop.  This method will
    only be invoked AFTER your `validateDrop method has been called to
    determine if you want to even allow the drag operation to go through.
    
    You should actually make changes to the data model if needed here and
    then return the actual drag operation that was performed. If you return
    `SC.DRAG_NONE` and the dragOperation was `SC.DRAG_REORDER`, then the default
    reorder behavior will be provided by the collection view.
    
    @param {SC.CollectionView} view
    @param {SC.Drag} drag the current drag object
    @param {Number} op proposed logical OR of allowed drag operations.
    @param {Number} proposedInsertionIndex an index into the content array representing the proposed insertion point.
    @param {String} proposedDropOperation the proposed drop operation.  Will be one of SC.DROP_ON, SC.DROP_BEFORE, or SC.DROP_ANY.
    @returns the allowed drag operation. Defaults to proposedDragOperation
  */
  collectionViewPerformDragOperation: function(view, drag, op, proposedInsertionIndex, proposedDropOperation) {
    return SC.DRAG_NONE;
  },
  
  /**
    Renders a drag view for the passed content indexes. If you return null
    from this, then a default drag view will be generated for you.
    
    The default implementation returns null.
    
    @param {SC.CollectionView} view
    @param {SC.IndexSet} dragContent
    @returns {SC.View} view or null
  */
  collectionViewDragViewFor: function(view, dragContent) {
    return null;
  },

  /**
    Allows the ghost view created in `collectionViewDragViewFor` to be displayed
    like a cursor instead of the default implementation. This sets the view 
    origin to be the location of the mouse cursor.
    
    @type Boolean
    @default NO
  */
  ghostActsLikeCursor: NO
  
};

/* >>>>>>>>>> BEGIN source/mixins/navigation_builder.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


/**
  @namespace
  NavigationBuilder is an implementation of the Builder protocol. It implements
  `buildIn`/`Out` (though these only relay to `buildIn`/`OutNavigation, so feel free to
  override if needed; the navigation builders will still be accessible).
  
  Building in and out animates the view in and out to and from the left and right.
*/
SC.NavigationBuilder = {

  /**
    Walk like a duck.
    
    @type Boolean
    @default YES
    @constant
  */
  isNavigationBuilder: YES,
  
  /**
    The transitions to be used for navigation; these are mixed in to the existing
    transitions hash if one exists, or become the transitions hash otherwise.
    
    If NO, it uses the (hard-coded) defaults.
    
    @type Boolean
    @default NO
  */
  navigationTransitions: NO,
  
  initMixin: function() {
    // force integrate SC.Animatable
    var animatable = SC.Animatable;
    if (animatable && !this.isAnimatable) {
      // okay, let's mix it in!
      this.mixin(animatable);
    } else if (!animatable) { 
      // check that we actually have SC.Animatable
      SC.Logger.error(
        "SC.NavigationView and SC.NavigationBuilder require SC.Animatable " + 
        "to perform animations, but it is not present. Please ensure your app or framework " +
        "references it."
      );
    }
    
    var navigationTransitions = this.get("navigationTransitions");
    if (!navigationTransitions && SC.Animatable) {
      navigationTransitions = {
        // these being identical helps us.
        left: { duration: 0.25, timing: SC.Animatable.TRANSITION_EASE_IN_OUT, action: "navigationBuildDidFinish" },
        transform: { duration: 0.25, timing: SC.Animatable.TRANSITION_EASE_IN_OUT, action: "navigationBuildDidFinish" }
      };
    }
    
    // mix in transitions (a base set will have been added by SC.Animatable alrady)
    if (SC.Animatable) SC.mixin(this.transitions, navigationTransitions);
  },
  
  /** @private
    Determines metrics of the view. This may be adapted to work with non-CSS transforms in future...
  */
  metrics: function() {
    var f = this.computeFrameWithParentFrame();
    return f;
  },
  
  /** @private
    Applies the supplied CSS transform.
  */
  transform: function(pos) {
    if (SC.platform.supportsCSS3DTransforms) {
      this.adjust("transform", "translate3d(" + pos + "px,0px,0px)");
    } else {
      this.adjust("transform", "translate(" + pos + "px,0px)");
    }
  },
  
  buildInNavigation: function() {
    // set initial state
    var metrics = this.metrics();
    this.disableAnimation();
    this.transform(this.get("buildDirection") === SC.TO_LEFT ? metrics.width : -metrics.width);
    this.enableAnimation();
    
    // now, (delayed) call transform to go to the correct spot
    this.invokeLater("transform", 10, 0);
  },
  
  buildOutNavigation: function() {
    // we already have an initial state
    var metrics = this.metrics();
    this.transform(this.get("buildDirection") === SC.TO_LEFT ? -metrics.width : metrics.width);
  },
  
  /**
    You may override this. If you do, call `buildInNavigation` to call the original functionality.
    You may need to override `navigationBuildDidFinish` as well if you call `buildInNavigation`.
  */
  buildIn: function() {
    this.buildInNavigation();
  },
  
  /**
    You may override this. If you do, call `buildOutNavigation` to call the original functionality.
    You may need to override `navigationBuildDidFinish`as well if you call `buildOutNavigation`.
  */
  buildOut: function() {
    this.buildOutNavigation();
  },
  
  /**
    This ensures that the view has a CSS transform set, even if it is added without build in, etc.
  */
  resetBuild: function() {
    this.transform(0);
  },
  
  /**
    Called when the transitions finish.
  */
  navigationBuildDidFinish: function() {
    if (this.isBuildingIn) {
      this.buildInDidFinish();
    } else if (this.isBuildingOut) {
      this.buildOutDidFinish();
    }
  }
  
} ;


/* >>>>>>>>>> BEGIN source/mixins/split_child.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2010 Sprout Systems, Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/** @private
  SC.SplitChild and SC.SplitThumb both share this code, but we don't want it
  included twice if the view mixes in both SC.SplitChild and SC.SplitThumb.
*/
SC.NeedsSplitParent = {

  /**
   * The SplitView that contains the child views to be adjusted.
   *
   * This is computed to be the first SplitView found in a search
   * up the view hierarchy. You can substitute your own SplitView
   *
   * @property SC.SplitView
  */
  splitView: function () {
    var view = this.get('parentView');
    while (view && !view.isSplitView) view = view.get('parentView');
    return view;
  }.property('parentView').cacheable(),

  /**
   * The layoutDirection of the SplitView. This is observed so that we
   * can update positioning if the layoutDirection changes but the position
   * and size properties do not.
   *
   * @type {LayoutDirection}
  */
  // NOTE: While an edge case, this is implemented because it makes it _much_
  // easier to write the sample in the Test Controls app.
  splitViewLayoutDirection: null,
  splitViewLayoutDirectionBinding: SC.Binding.oneWay('*splitView.layoutDirection')

};


/**
  @namespace
  Child views of SplitViews should use this mixin to get their positioning
  logic and default settings.

  By default, SplitView merely sets the position and size properties on its
  child views. This mixin observes the position and size properties and
  calls adjust().
*/
SC.SplitChild =
  /** @scope SC.SplitChild.prototype */{
  /**
   * Set to YES if your Split Child is a divider view.
   *
   * @type Boolean
  */
  isSplitDivider: NO,

  /**
   * The minimum size for the SC.SplitView child. This view will
   * be unable to be resized smaller than this size.
   *
   * @default 100
   *
   * @type {Number}
  */
  minimumSize: 100,

  /**
   * The maximum size for the SC.SplitView child. This view will
   * be unable to be resized to a size larger than this value.
   *
   * If undefined, there is no limit.
   *
   * @default 100
   *
   * @type {Number}
  */
  maximumSize: undefined,

  /**
   * The current size of the SC.SplitView child. Use this to set the default
   * size.
   *
   * If you specify a size, autoResizeStyle will default to SC.RESIZE_MANUAL;
   * if you don't, SplitView will assume you want it to fill the available space
   * and use SC.RESIZE_AUTOMATIC.
   *
   * @default undefined
   *
   * @type Number
  */
  size: undefined,

  /**
   * [RO] The current position of the SC.SplitView. This is read-only, and is set
   * by the SplitView as it positions the views.
   *
   * @type Number
  */
  position: 0,

  /**
   * An amount to add to the position when adjusting layout.
   *
   * For example, if SC.SplitView positions this view at 100, and
   * positionOffset is -5, the view's layout will will have a position of 95.
   *
   * This can be used in conjunction with sizeOffset to make dividers
   * overlap the other views in the SplitView to have a larger grab area.
   *
   * TODO: Get this value from theme.
   *
   * @type Number
  */
  positionOffset: SC.propertyFromRenderDelegate('splitPositionOffset', 0),

  /**
   * An amount to add to the assigned size when adjusting layout.
   *
   * For example, if SC.SplitView gives this view a size of 1, but the
   * sizeOffset is 10, the view's layout will be given a width or height of 11.
   *
   * This can be used in conjunction with positionOffset to make dividers
   * overlap the other views in the SplitView to have a larger grab area.
   *
   * TODO: Get this value from theme.
   *
   * @type Number
  */
  sizeOffset: SC.propertyFromRenderDelegate('splitSizeOffset', 0),

  /**
   * If YES, the SC.SplitView can collapse this view when the user
   * double-clicks an adjacent divider, or when the view is resized
   * to a size smaller than the collapseAtSize.
   *
   * @type {Boolean}
  */
  canCollapse: NO,

  /**
   * If the user attempts to resize the view to a size below this number,
   * the view will collapse.
   *
   * If undefined, the view cannot be collapsed due to a resize.
   *
   * @type {Number}
  */
  collapseAtSize: undefined,

  /**
   * When (and if) the view should automatically resize due to the SplitView changing size.
   *
   * - SC.RESIZE_AUTOMATIC: always resize when the SplitView changes size.
   * - SC.RESIZE_MANUAL: resize only when the user moves a divider, or all
   *   SC.RESIZE_AUTOMATIC views have already been resized as much as possible.
   * - SC.FIXED_SIZE: Never resize.
   *
   * If you specify an autoResizeStyle, it will be used. If you leave it at `undefined`,
   * it will look at `size`: if a `size` is supplied, it will use `SC.RESIZE_MANUAL`; otherwise
   * it will use `SC.RESIZE_AUTOMATIC`.
   *
   * @default based on size
   * @type {AutoResizeStyle}
  */
  autoResizeStyle: undefined,

  /**
   * If NO, moving the divider before this view will not resize the view, but
   * instead, move it—causing further views to move as well. Most SplitView
   * children will want this set to YES.
   *
   * @type Boolean
  */
  compensatesForMovement: YES,

  /**
   * When NO, the view can only be adjusted when the user drags a divider
   * immediately adjacent to it. If YES, the view can be adjusted indirectly
   * from earlier dividers as well.
   *
   * For example, assume you have a 3-pane setup. Increasing the size of left pane will
   * resize the middle one until its minimum size is reached. SplitView will then
   * try to adjust the right pane. If the right pane has allowsIndirectAdjustments
   * set to YES, SplitView will shrink the right pane to make way. If NO, the
   * left pane will be unable to resize further.
   *
   * Default: YES.
   *
   * @type {Boolean}
  */
  allowsIndirectAdjustments: YES,

  /** @private Include SC.NeedsSplitParent if it hasn't already been included. */
  initMixin: function () {
    if (!this.splitView) {
      this.mixin(SC.NeedsSplitParent);
    }
  },

  //
  // Positioning logic
  //
  _scsvc_positionOrSizeDidChange: function() {
    this.invokeOnce('splitChildLayoutDidChange');
  }.observes('position', 'size'),

  /**
   * Called when either the position or size of the child has changed, and layout
   * needs to be updated accordingly. You may override this method to take into
   * account any custom layout. The default handles the position- and sizeOffset
   * properties by adding them to the position and size, respectively.
   *
   * For instance, while the default implementation changes left/right/width/height
   * to fill in one direction and fit in the allocated position in the other, you could
   * make it only set left/width or top/height.
   *
  */
  splitChildLayoutDidChange: function() {
    var split = this.get('splitView');
    if (!split) return;

    var position = this.get('position') + this.get('positionOffset'),
        size = this.get('size') + this.get('sizeOffset');


    if (split.get('layoutDirection') === SC.LAYOUT_HORIZONTAL) {
      this.set('layout', {
        left: position,
        width: size,
        top: 0, bottom: 0
      });
    } else {
      this.set('layout', {
        top: position,
        height: size,
        right: 0, left: 0
      });
    }
  },

  splitViewLayoutDirectionDidChange: function() {
    this.invokeOnce('splitChildLayoutDidChange');
  }.observes('splitViewLayoutDirection')
};

/* >>>>>>>>>> BEGIN source/mixins/split_thumb.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2010 Sprout Systems, Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  Tells the SplitThumb to automatically choose which child of the SplitView
  to move in response to touch or mouse events in an SC.SplitThumb.
*/
SC.MOVES_AUTOMATIC_CHILD = 'moves-automatic-child';

/**
  Tells the SplitThumb to move the child of the SplitView that is
  either the SplitThumb or a parent of it.
*/
SC.MOVES_CHILD = 'moves-child';

/**
  Tells the SplitThumb to move the child of the SplitView that
  preceeds the child that is either the SplitThumb or a parent of it.
*/
SC.MOVES_PREVIOUS_CHILD = 'moves-previous-child';

/**
  Tells the SplitThumb to move the child of the SplitVie that
  comes after the child that is either the SplitThumb or a parent of it.
*/
SC.MOVES_NEXT_CHILD = 'moves-next-child';

/**
  @namespace
  A SplitThumb may be placed inside any view in a SplitView, and can even
  be a direct child of the SplitView. It forwards its events to the SplitView
  to control the movement of a divider or another child of the SplitView.

  Using a view that mixes in SplitThumb, you can place a handle that moves the
  divider anywhere inside the SplitView's view tree.

  SplitThumb will automatically choose which divider to move. It's choice will
  almost always be correct for 2-pane layouts. However, in 3-pane layouts, you
  may want to adjust the way it chooses.

  You can adjust the behavior by setting the movesSibling property to
  SC.MOVES_NEXT_CHILD or SC.MOVES_PREVIOUS_CHILD. If your ThumbView is inside
  the middle pane, for instance, this would tell it whether the ThumbView
  should move the divider to the left, or the divider to the right.
*/
SC.SplitThumb = {

  /**
   * The child which should be moved by any mouse or touch events. Should usually
   * be a divider view.
   *
   * The default implementation calculates the child by first finding
   * the ancestor of this view that is a direct child of the SplitView,
   * and then either returning it or one of its immediate siblings, depending
   * on the value of the movesSibling property.
   *
   * @property SC.View
  */
  movesChild: function () {
    var view = this, child, splitView = this.get('splitView'),
        sibling = this.get('movesSibling');
    while (view && view !== splitView) {
      child = view;
      view = view.get('parentView');
    }

    if (sibling === SC.MOVES_NEXT_CHILD) return child.nextView;
    if (sibling === SC.MOVES_PREVIOUS_CHILD) return child.previousView;

    if (sibling === SC.MOVES_AUTOMATIC_CHILD) {
      if (!child.nextView) return child.previousView;
      if (!child.previousView) return child.nextView;
    }

    return child;
  }.property('splitView', 'movesSibling').cacheable(),

  /**
   * Decides whether an ancestor of this SplitThumb view or one of its
   * siblings is to be moved in response to events.
   *
   * Usually, you want events to move a divider. If the SplitThumb is inside
   * a view which is _not_ a divider, you probably want to move one of the
   * view's siblings-one that _is_ a divider.
   *
   * You can tell SC.SplitThumb to:
   *
   * - SC.MOVES_AUTOMATIC_CHILD: if the SplitView child is either first or last,
   *   moves the adjacent child (likely a divider). Otherwise moves the child itself.
   *
   * - SC.MOVES_CHILD: moves the child itself, not one of its siblings. Divider
   *   views could use this setting.
   *
   * - SC.MOVES_PREVIOUS_CHILD: moves the previous child. For instance, in a
   *   two-pane setup, if the SplitThumb is in the rightmost child, this will
   *   move the divider between the two children.
   *
   * - SC.MOVES_NEXT_CHILD: moves the next child.
   *
   * @type TYPE
  */
  movesSibling: SC.MOVES_AUTOMATIC_CHILD,

  /**
   * The SplitView that contains the child views to be adjusted.
   *
   * This is computed to be the first SplitView found in a search
   * up the view hierarchy. You can substitute your own SplitView
   *
   * @property SC.SplitView
  */
  // splitView: function () {
  //   var view = this;
  //   while (view && !view.isSplitView) view = view.get('parentView');
  //   return view;
  // }.property('parentView').cacheable(),

  /**
   * The layoutDirection of the SplitView. This is observed so that we
   * can update positioning if the layoutDirection changes but the position
   * and size properties do not.
   *
   * NOTE: duplicated in SplitChild because both this and SplitChild use it.
   *
   * @type {LayoutDirection}
  */
  // NOTE: While an edge case, this is implemented because it makes it _much_
  // easier to write the sample in the Test Controls app.
  // splitViewLayoutDirection: null,
  // splitViewLayoutDirectionBinding: SC.Binding.oneWay('*splitView.layoutDirection'),

  /**
   * The name of the CSS cursor that should be used for splitting.
   * The containing SplitView will adopt this cursor if and when this
   * view is dragged.
   *
   * Computed based on the SplitView's layoutDirection.
   *
   * @type {String}
  */
  splitCursorStyle: function () {
    if (this.get('splitViewLayoutDirection') === SC.LAYOUT_HORIZONTAL) {
      return 'ew-resize';
    } else {
      return 'ns-resize';
    }
  }.property('splitViewLayoutDirection').cacheable(),

  splitCursorStyleDidChange: function () {
    if (this._isDragging) {
      this.get('splitView').set('splitChildCursorStyle', this.get('splitCursorStyle'));
    }

    this.$().css('cursor', this.get('splitCursorStyle'));
  }.observes('splitCursorStyle'),

  /** @private Include SC.NeedsSplitParent if it hasn't already been included. */
  initMixin: function () {
    if (!this.splitView) {
      this.mixin(SC.NeedsSplitParent);
    }
  },

  /**
   * @private
   * Renders the cursor for the view as defined by this view's splitCursor
   * property.
  */
  renderMixin: function (context) {
    context.setStyle('cursor', this.get('splitCursorStyle'));
  },

  //
  // EVENT HANDLING
  //
  touchStart: function (touch) {
    this._isDragging = YES;

    var splitView = this.get('splitView');
    splitView.beginLiveResize();

    this._scst_mouseStartPosition = splitView.get('layoutDirection') === SC.LAYOUT_HORIZONTAL ?
      touch.pageX : touch.pageY;

    this._scst_childStartPosition = splitView.getPositionForChild(this.get('movesChild'));

    return YES;
  },

  touchesDragged: function (evt) {
    var splitView = this.get('splitView');

    var mousePosition = splitView.get('layoutDirection') === SC.LAYOUT_HORIZONTAL ?
      evt.pageX : evt.pageY;

    var diff = mousePosition - this._scst_mouseStartPosition,
        start = this._scst_childStartPosition;

    splitView.adjustPositionForChild(this.get('movesChild'), start + diff);

    return YES;
  },

  touchEnd: function (touch) {
    this._isDragging = NO;

    var splitView = this.get('splitView');

    var mousePosition = splitView.get('layoutDirection') === SC.LAYOUT_HORIZONTAL ?
      touch.pageX : touch.pageY;

    var diff = mousePosition - this._scst_mouseStartPosition,
        start = this._scst_childStartPosition;

    splitView.adjustPositionForChild(this.get('movesChild'), start + diff);

    splitView.set('splitChildCursorStyle', null);
    splitView.endLiveResize();
    return YES;
  },

  mouseDown: function (evt) {
    var splitView = this.get('splitView');
    splitView.set('splitChildCursorStyle', this.get('splitCursorStyle'));

    return this.touchStart(evt);
  },

  mouseDragged: function (evt) {
    return this.touchesDragged(evt);
  },

  mouseUp: function (evt) {
    this.get('splitView').set('splitChildCursorStyle', null);

    return this.touchEnd(evt);
  }

};

/* >>>>>>>>>> BEGIN source/panes/modal.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


/** @class

  A modal pane is used to capture mouse events inside a pane that is modal.
  You normally will not work with modal panes directly, though you may set
  the modalPane property to a subclass of this pane when designing custom
  panes.

  A modal pane is automatically appended when a pane with isModal set to
  `YES` is made visible and removed when the same pane is hidden.  The only
  purpose of the `ModalPane` is to absorb mouse events so that they cannot
  filter through to the underlying content.

  @extends SC.Pane
  @since SproutCore 1.0
*/
SC.ModalPane = SC.Pane.extend(
/** @scope SC.ModalPane.prototype */{

  /**
    @type Array
    @default ['sc-modal']
    @see SC.View#classNames
  */
  classNames: 'sc-modal',

  /** @private */
  _openPaneCount: 0,

  /** @private
    Called by a pane just before it appends itself.   The modal pane can
    make itself visible first if needed.

    @param {SC.Pane} pane the pane
    @returns {SC.ModalPane} receiver
  */
  paneWillAppend: function(pane) {
    var _tmpPane;
    this._openPaneCount++;
    if (!this.get('isVisibleInWindow')) this.append();
    var panes = SC.RootResponder.responder.panes;
    for(var i=0, iLen=panes.length; i<iLen; i++ ){
      _tmpPane = panes[i];
      if(_tmpPane!==pane) {
        //_tmpPane.set('ariaHidden', YES);
        this._hideShowTextfields(_tmpPane, NO);
      }
    }
    return this ;
  },

  /** @private
    Called by a pane just after it removes itself.  The modal pane can remove
    itself if needed.   Modal panes only remove themselves when an equal
    number of `paneWillAppend()` and `paneDidRemove()` calls are received.

    @param {SC.Pane} pane the pane
    @returns {SC.ModalPane} receiver
  */
  paneDidRemove: function(pane) {
    var _tmpPane;
    this._openPaneCount--;
    var panes = SC.RootResponder.responder.panes;
    for(var i=0, iLen=panes.length; i<iLen; i++ ){
      _tmpPane = panes[i];
      if(_tmpPane!==pane) {
        //_tmpPane.set('ariaHidden', NO);
        this._hideShowTextfields(_tmpPane, YES);
      }
    }
    if (this._openPaneCount <= 0) {
      this._openPaneCount = 0 ;
      if (this.get('isVisibleInWindow')) this.remove();
    }
  },

  /** @private
    If `focusable` is NO all SC.TextFieldViews not belonging to the given
    pane will have isBrowserFocusable set to NO.  If `focusable` is YES, then
    all SC.TextFieldViews not belonging to the given pane will have
    isBrowserFocusable set to YES, unless they previously had it set explictly
    to NO.
  */
  _hideShowTextfields: function(pane, focusable){
    var view;

    for (view in SC.View.views) {
      view = SC.View.views[view];
      if (view.get('isTextField') && view !== pane && view.get('pane') === pane) {
        if (focusable) {
          // Setting isBrowserFocusable back to YES. If we cached the previous
          // value, use that instead.
          if (view._scmp_isBrowserFocusable !== undefined) {
            focusable = view._scmp_isBrowserFocusable;

            // Clean up entirely.
            delete view._scmp_isBrowserFocusable;
          }
        } else {
          // Cache the value of isBrowserFocusable. If the text field
          // already had isBrowserFocusable: NO, we don't want to
          // set it back to YES.
          view._scmp_isBrowserFocusable = view.get('isBrowserFocusable');
        }
        view.set('isBrowserFocusable', focusable);
      }
    }
  },

  /** @private */
  mouseDown: function(evt) {
    var owner = this.get('owner');
    if (owner && owner.modalPaneDidClick) owner.modalPaneDidClick(evt);
  },

  /** @private */
  touchStart: function(evt) {
    this.mouseDown(evt);
  }
});

/* >>>>>>>>>> BEGIN source/panes/panel.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('panes/modal');

/** @class

  Most SproutCore applications need modal panels. The default way to use the
  panel pane is to simply add it to your page like this:

      SC.PanelPane.create({
        layout: { width: 400, height: 200, centerX: 0, centerY: 0 },
        contentView: SC.View.extend({
        })
      }).append();

  This will cause your panel to display.  The default layout for a Panel
  is to cover the entire document window with a semi-opaque background, and to
  resize with the window.

  @extends SC.Pane
  @author Erich Ocean
  @since SproutCore 1.0
*/
SC.PanelPane = SC.Pane.extend(
/** @scope SC.PanelPane.prototype */ {

  /**
    Walk like a duck.
    @type {Boolean}
  */
  isPanelPane: YES,

  /**
    @type Array
    @default ['sc-panel']
    @see SC.View#classNames
  */
  classNames: ['sc-panel'],

  /**
    @type Boolean
    @default YES
    @see SC.Pane#acceptsKeyPane
  */
  acceptsKeyPane: YES,

  /**
    The WAI-ARIA role for panel pane.

    @type String
    @default 'dialog'
    @constant
  */
  ariaRole: 'dialog',

  /**
    The WAI-ARIA label for the panel. Screen readers will use this to tell
    the user a name for the panel.

    @type String
  */
  ariaLabel: null,

  /**
    The WAI-ARIA labelledby for the panel. Screen readers will use this to tell
    the header or name of your panel if there is no label. This should be an id
    to an element inside the panel.

    @type String
  */
  ariaLabelledBy: null,

  /**
    The WAI-ARIA describedby text. Screen readers will use this to speak the description
    of the panel. This should be an id to an element inside the panel.

    @type String
  */
  ariaDescribedBy: null,

  /**
    Indicates that a pane is modal and should not allow clicks to pass
    though to panes underneath it. This will usually cause the pane to show
    the modalPane underneath it.

    @type Boolean
    @default YES
  */
  isModal: YES,

  /**
    The modal pane to place behind this pane if this pane is modal. This
    must be a subclass or an instance of SC.ModalPane.
  */
  modalPane: SC.ModalPane.extend({
    classNames: 'for-sc-panel'
  }),

  // ..........................................................
  // CONTENT VIEW
  //

  /**
    Set this to the view you want to act as the content within the panel.

    @type SC.View
    @default null
  */
  contentView: null,
  contentViewBindingDefault: SC.Binding.single(),

  /**
    @param {SC.View} newContent
  */
  replaceContent: function(newContent) {
    this.removeAllChildren() ;
    if (newContent) this.appendChild(newContent);
  },

  /** @private */
  createChildViews: function() {
    // if contentView is defined, then create the content
    var view = this.contentView ;
    if (view) {
      view = this.contentView = this.createChildView(view) ;
      this.childViews = [view] ;
    }
  },


  /**
    Invoked whenever the content property changes. This method will simply
    call replaceContent. Override replaceContent to change how the view is
    swapped out.
  */
  contentViewDidChange: function() {
    this.replaceContent(this.get('contentView'));
  }.observes('contentView'),

  // ..........................................................
  // INTERNAL SUPPORT
  //

  /**
    The name of the theme's `SC.PanelPane` render delegate.

    @type String
    @default 'panelRenderDelegate'
  */
  renderDelegateName: 'panelRenderDelegate',

  // get the modal pane.
  _modalPane: function() {
    var pane = this.get('modalPane');

    // instantiate if needed
    if (pane && pane.isClass) {
      pane = pane.create({ owner: this });
      this.set('modalPane', pane);
    }

    return pane ;
  },

  /** @private - whenever showing on screen, deal with modal pane as well */
  appendTo: function(elem) {
    var pane ;
    if (!this.get('isVisibleInWindow') && this.get('isModal') && (pane = this._modalPane())) {
      this._isShowingModal = YES;
      pane.paneWillAppend(this);
    }
    return arguments.callee.base.apply(this,arguments);
  },

  /** @private - when removing from screen, deal with modal pane as well. */
  remove: function() {
    var pane, ret = arguments.callee.base.apply(this,arguments);

    if (this._isShowingModal) {
      this._isShowingModal = NO ;
      if (pane = this._modalPane()) pane.paneDidRemove(this);
    }
    return ret ;
  },

  destroy: function() {
    var modal = this.get('modalPane');
    if (modal && !modal.isClass) {
      modal.destroy();
    }

    arguments.callee.base.apply(this,arguments);
  },

  /** @private - if isModal state changes, update pane state if needed. */
  _isModalDidChange: function() {
    var modalPane,
        isModal = this.get('isModal');

    if (isModal) {
      if (!this._isShowingModal && (modalPane = this._modalPane())) {
        this._isShowingModal = YES;
        modalPane.paneWillAppend(this);
      }
    } else {
      if (this._isShowingModal && (modalPane = this._modalPane())) {
        this._isShowingModal = NO;
        modalPane.paneDidRemove(this);
      }
    }
  }.observes('isModal'),

  /**
    Called when the pane is shown.  Takes on key pane status.
  */
  didShowInDocument: function () {
   this.becomeKeyPane();
  },

  /**
    Called when the pane is attached.  Takes on key pane status.
  */
  didAppendToDocument: function () {
    this.becomeKeyPane();
  },

  /**
    Called when the pane is detached.  Resigns key pane status.
  */
  willRemoveFromDocument: function () {
    this.resignKeyPane();
  },

  /**
    Called when the pane is about to be hidden.  Resigns key pane status.
  */
  willHideInDocument: function () {
   this.resignKeyPane();
  },

  displayProperties: ['ariaLabel', 'ariaLabelledBy', 'ariaDescribedBy']

});

/* >>>>>>>>>> BEGIN source/views/button.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @static
  @constant
  @type String
*/
SC.TOGGLE_BEHAVIOR = 'toggle';

/**
  @static
  @constant
  @type String
*/
SC.PUSH_BEHAVIOR = 'push';

/**
  @static
  @constant
  @type String
*/
SC.TOGGLE_ON_BEHAVIOR = 'on';

/**
  @static
  @constant
  @type String
*/
SC.TOGGLE_OFF_BEHAVIOR = 'off';

/**
  @static
  @constant
  @type String
*/
SC.HOLD_BEHAVIOR = 'hold';

/** @class

  Implements a push-button-style button.  This class is used to implement
  both standard push buttons and tab-style controls.  See also SC.CheckboxView
  and SC.RadioView which are implemented as field views, but can also be
  treated as buttons.

  By default, a button uses the SC.Control mixin which will apply CSS
  classnames when the state of the button changes:

   - `active` -- when button is active
   - `sel` -- when button is toggled to a selected state

  @extends SC.View
  @extends SC.Control
  @since SproutCore 1.0
*/
SC.ButtonView = SC.View.extend(SC.ActionSupport, SC.Control,
/** @scope SC.ButtonView.prototype */ {

  /**
    Tied to the isEnabledInPane state

    @type Boolean
    @default YES
  */
  acceptsFirstResponder: function() {
    if (SC.FOCUS_ALL_CONTROLS) { return this.get('isEnabledInPane'); }
    return NO;
  }.property('isEnabledInPane'),

  /**
    The name of the method to call when the button is pressed.

    This property is used in conjunction with the `target` property to execute a method when a
    regular button is pressed. If you do not set a target, then pressing the button will cause a
    search of the responder chain for a view that implements the action named. If you do set a
    target, then the button will only try to call the method on that target.

    The action method of the target should implement the following signature:

        action: function (sender) {
          // Return value is ignored by SC.ButtonView.
        }

    Therefore, if a target needs to know which button called its action, it should look to the
    `sender` argument.

    *NOTE:* This property is not relevant when the button is used in toggle mode. Toggle mode only
    modifies the `value` of the button without triggering actions.

    @type String
    @default null
    @see SC.ActionSupport
  */
  action: null,

  /**
    @type Array
    @default ['sc-button-view']
    @see SC.View#classNames
  */
  classNames: ['sc-button-view'],

  /**
    Whether the title and toolTip will be escaped to avoid HTML injection attacks
    or not.

    You should only disable this option if you are sure you are displaying
    non-user generated text.

    Note: this is not an observed display property.  If you change it after
    rendering, you should call `displayDidChange` on the view to update the layer.

    @type Boolean
    @default true
   */
  escapeHTML: true,

  /**
    The target to invoke the action on when the button is pressed.

    If you set this target, the action will be called on the target object directly when the button
    is clicked.  If you leave this property set to `null`, then the responder chain will be
    searched for a view that implements the action when the button is pressed.

    The action method of the target should implement the following signature:

        action: function (sender) {
          // Return value is ignored by SC.ButtonView.
        }

    Therefore, if a target needs to know which button called its action, it should look to the
    `sender` argument.

    *NOTE:* This property is not relevant when the button is used in toggle mode. Toggle mode only
    modifies the `value` of the button without triggering actions.

    @type Object
    @default null
    @see SC.ActionSupport
  */
  target: null,

  /**
    The theme to apply to the button. By default, a subtheme with the name of
    'square' is created for backwards-compatibility.

    @type String
    @default 'square'
  */
  themeName: 'square',


  // ..........................................................
  // Value Handling
  //

  /**
    Used to automatically update the state of the button view for toggle style
    buttons.

    For toggle style buttons, you can set the value and it will be used to
    update the isSelected state of the button view.  The value will also
    change as the user selects or deselects.  You can control which values
    the button will treat as `isSelected` by setting the `toggleOnValue` and
    `toggleOffValue`.  Alternatively, if you leave these properties set to
    `YES` or `NO`, the button will do its best to convert a value to an
    appropriate state:

     - `null`, `false`, `0` -- `isSelected = false`
     - any other single value -- `isSelected = true`
     - array -- if all values are the same state, that state; otherwise `MIXED`.

    @type Object
    @default null
  */
  value: null,

  /**
    Value of a selected toggle button.

    For a toggle button, set this to any object value you want. The button
    will be selected if the value property equals the targetValue. If the
    value is an array of multiple items that contains the targetValue, then
    the button will be set to a mixed state.

    default is YES

    @type Boolean|Object
    @default YES
  */
  toggleOnValue: YES,

  /**
    Value of an unselected toggle button.

    For a toggle button, set this to any object value you want.  When the
    user toggle's the button off, the value of the button will be set to this
    value.

    @type Boolean|Object
    @default NO
  */
  toggleOffValue: NO,


  // ..........................................................
  // Title Handling
  //

  /**
    If YES, then the title will be localized.

    @type Boolean
    @default NO
  */
  localize: NO,

  /** @private */
  localizeBindingDefault: SC.Binding.bool(),

  /**
    The button title.  If localize is `YES`, then this should be the
    localization key to display.  Otherwise, this will be the actual string
    displayed in the title.  This property is observable and bindable.

    @type String
    @default ""
  */
  title: "",

  /**
    If set, the title property will be updated automatically
    from the content using the key you specify.

    @type String
    @default null
  */
  contentTitleKey: null,

  /**
    The button icon. Set this to either a URL or a CSS class name (for
    spriting). Note that if you pass a URL, it must contain at
    least one slash to be detected as such.

    @type String
    @default null
  */
  icon: null,

  /**
    If you set this property, the icon will be updated automatically from the
    content using the key you specify.

    @type String
    @default null
  */
  contentIconKey: null,

  /**
    If YES, button will attempt to display an ellipsis if the title cannot
    fit inside of the visible area. This feature is not available on all
    browsers.

    Note: this is not an observed display property.  If you change it after
    rendering, you should call `displayDidChange` on the view to update the layer.

    @type Boolean
    @default YES
  */
  needsEllipsis: YES,

  /**
    This is generated by localizing the title property if necessary.

    @type String
    @observes 'title'
    @observes 'localize'
  */
  displayTitle: function() {
    var ret = this.get('title');
    return (ret && this.get('localize')) ? SC.String.loc(ret) : (ret || '');
  }.property('title','localize').cacheable(),

  /**
    The key equivalent that should trigger this button on the page.

    @type String
    @default null
  */
  keyEquivalent: null,


  // ..........................................................
  // BEHAVIOR
  //

  /**
    The behavioral mode of this button.

    Possible values are:

     - `SC.PUSH_BEHAVIOR` -- Pressing the button will trigger an action tied to the
       button. Does not change the value of the button.
     - `SC.TOGGLE_BEHAVIOR` -- Pressing the button will invert the current value of
       the button. If the button has a mixed value, it will be set to true.
     - `SC.TOGGLE_ON_BEHAVIOR` -- Pressing the button will set the current state to
       true no matter the previous value.
     - `SC.TOGGLE_OFF_BEHAVIOR` -- Pressing the button will set the current state to
       false no matter the previous value.
     - `SC.HOLD_BEHAVIOR` -- Pressing the button will cause the action to repeat at a
       regular interval specified by 'holdInterval'

    @type String
    @default SC.PUSH_BEHAVIOR
  */
  buttonBehavior: SC.PUSH_BEHAVIOR,

  /*
    If buttonBehavior is `SC.HOLD_BEHAVIOR`, this specifies, in milliseconds,
    how often to trigger the action. Ignored for other behaviors.

    @type Number
    @default 100
  */
  holdInterval: 100,

  /**
    If YES, then this button will be triggered when you hit return.

    This is the same as setting the `keyEquivalent` to 'return'.  This will also
    apply the "def" classname to the button.

    @type Boolean
    @default NO
  */
  isDefault: NO,
  isDefaultBindingDefault: SC.Binding.oneWay().bool(),

  /**
    If YES, then this button will be triggered when you hit escape.
    This is the same as setting the keyEquivalent to 'escape'.

    @type Boolean
    @default NO
  */
  isCancel: NO,
  isCancelBindingDefault: SC.Binding.oneWay().bool(),

  /*
    TODO When is this property ever changed? Is this redundant with
    render delegates since it can now be turned on on a theme-by-theme
    basis? --TD
  */
  /**
    If YES, use a focus ring.

    @type Boolean
    @default NO
  */
  supportFocusRing: NO,

  // ..........................................................
  // Auto Resize Support
  //
  //
  // These properties are provided so that SC.AutoResize can be mixed in
  // to enable automatic resizing of the button.
  //

  /** @private */
  supportsAutoResize: YES,

  /*
    TODO get this from the render delegate so other elements may be used.
  */
  /** @private */
  autoResizeLayer: function() {
    var ret = this.invokeRenderDelegateMethod('getRenderedAutoResizeLayer', this.$());
    return ret || this.get('layer');
  }.property('layer').cacheable(),

  /** @private */
  autoResizeText: function() {
    return this.get('displayTitle');
  }.property('displayTitle').cacheable(),

  /**
    The padding to add to the measured size of the text to arrive at the measured
    size for the view.

    `SC.ButtonView` gets this from its render delegate, but if not supplied, defaults
    to 10.

    @default 10
    @type Number
  */
  autoResizePadding: SC.propertyFromRenderDelegate('autoResizePadding', 10),


  // TODO: What the hell is this? --TD
  _labelMinWidthIE7: 0,

  /**
    Called when the user presses a shortcut key, such as return or cancel,
    associated with this button.

    Highlights the button to show that it is being triggered, then, after a
    delay, performs the button's action.

    Does nothing if the button is disabled.

    @param {Event} evt
    @returns {Boolean} YES if successful, NO otherwise
  */
  triggerActionAfterDelay: function(evt) {
    // If this button is disabled, we have nothing to do
    if (!this.get('isEnabledInPane')) return NO;

    // Set active state of the button so it appears highlighted
    this.set('isActive', YES);

    // Invoke the actual action method after a small delay to give the user a
    // chance to see the highlight. This is especially important if the button
    // closes a pane, for example.
    this.invokeLater('triggerAction', SC.ButtonView.TRIGGER_DELAY, evt);
    return YES;
  },

  /** @private
    Called by triggerActionAfterDelay; this method actually
    performs the action and restores the button's state.

    @param {Event} evt
  */
  triggerAction: function(evt) {
    this._action(evt, YES);
    this.didTriggerAction();
    this.set('isActive', NO);
  },

  /**
    Callback called anytime the button's action is triggered.  You can
    implement this method in your own subclass to perform any cleanup needed
    after an action is performed.
  */
  didTriggerAction: function() {},


  // ................................................................
  // INTERNAL SUPPORT
  //

  /** @private - save keyEquivalent for later use */
  init: function() {
    arguments.callee.base.apply(this,arguments);

    var keyEquivalent = this.get('keyEquivalent');
    // Cache the key equivalent. The key equivalent is saved so that if,
    // for example, isDefault is changed from YES to NO, the old key
    // equivalent can be restored.
    if (keyEquivalent) {
      this._defaultKeyEquivalent = keyEquivalent;
    }

    // if value is not null, update isSelected to match value.  If value is
    // null, we assume you may be using isSelected only.
    if (!SC.none(this.get('value'))) this._button_valueDidChange();
  },

  /**
    The WAI-ARIA role of the button.

    @type String
    @default 'button'
    @readOnly
  */
  ariaRole: 'button',

  /**
    The following properties affect how `SC.ButtonView` is rendered, and will
    cause the view to be rerendered if they change.

    Note: 'value', 'isDefault', 'isCancel' are also display properties, but are
    observed separately.

    @type Array
    @default ['icon', 'displayTitle', 'displayToolTip', 'supportFocusRing', 'buttonBehavior']
  */
  displayProperties: ['icon', 'displayTitle', 'displayToolTip', 'supportFocusRing', 'buttonBehavior'],

  /**
    The name of the render delegate in the theme that should be used to
    render the button.

    In this case, the 'button' property will be retrieved from the theme and
    set to the render delegate of this view.

    @type String
    @default 'buttonRenderDelegate'
  */
  renderDelegateName: 'buttonRenderDelegate',

  contentKeys: {
    'contentValueKey': 'value',
    'contentTitleKey': 'title',
    'contentIconKey': 'icon'
  },

  /**
    Handle a key equivalent if set.  Trigger the default action for the
    button.  Depending on the implementation this may vary.

    @param {String} keystring
    @param {SC.Event} evt
    @returns {Boolean}  YES if handled, NO otherwise
  */
  performKeyEquivalent: function(keystring, evt) {
    //If this is not visible
    if (!this.get('isVisibleInWindow')) return NO;

    if (!this.get('isEnabledInPane')) return NO;
    var equiv = this.get('keyEquivalent');

    // button has defined a keyEquivalent and it matches!
    // if triggering succeeded, true will be returned and the operation will
    // be handled (i.e performKeyEquivalent will cease crawling the view
    // tree)
    if (equiv) {
      if (equiv === keystring) return this.triggerAction(evt);

    // should fire if isDefault OR isCancel.  This way if isDefault AND
    // isCancel, responds to both return and escape
    } else if ((this.get('isDefault') && (keystring === 'return')) ||
        (this.get('isCancel') && (keystring === 'escape'))) {
          return this.triggerAction(evt);
    }

    return NO; // did not handle it; keep searching
  },

  // ..........................................................
  // VALUE <-> isSelected STATE MANAGEMENT
  //

  /**
    This is the standard logic to compute a proposed isSelected state for a
    new value.  This takes into account the `toggleOnValue`/`toggleOffValue`
    properties, among other things.  It may return `YES`, `NO`, or
    `SC.MIXED_STATE`.

    @param {Object} value
    @returns {Boolean} return state
  */
  computeIsSelectedForValue: function(value) {
    var targetValue = this.get('toggleOnValue'), state, next ;

    if (SC.typeOf(value) === SC.T_ARRAY) {

      // treat a single item array like a single value
      if (value.length === 1) {
        state = (value[0] == targetValue) ;

      // for a multiple item array, check the states of all items.
      } else {
        state = null;
        value.find(function(x) {
          next = (x == targetValue) ;
          if (state === null) {
            state = next ;
          } else if (next !== state) state = SC.MIXED_STATE ;
          return state === SC.MIXED_STATE ; // stop when we hit a mixed state.
        });
      }

    // for single values, just compare to the toggleOnValue...use truthiness
    } else {
      if(value === SC.MIXED_STATE) state = SC.MIXED_STATE;
      else state = (value === targetValue) ;
    }
    return state ;
  },

  /** @private
    Whenever the button value changes, update the selected state to match.
  */
  _button_valueDidChange: function() {
    var value = this.get('value'),
        state = this.computeIsSelectedForValue(value);
    this.set('isSelected', state) ; // set new state...

    // value acts as a display property
    this.displayDidChange();
  }.observes('value'),

  /** @private
    Whenever the selected state is changed, make sure the button value is
    also updated.  Note that this may be called because the value has just
    changed.  In that case this should do nothing.
  */
  _button_isSelectedDidChange: function() {
    var newState = this.get('isSelected'),
        curState = this.computeIsSelectedForValue(this.get('value'));

    // fix up the value, but only if computed state does not match.
    // never fix up value if isSelected is set to MIXED_STATE since this can
    // only come from the value.
    if ((newState !== SC.MIXED_STATE) && (curState !== newState)) {
      var valueKey = (newState) ? 'toggleOnValue' : 'toggleOffValue' ;
      this.set('value', this.get(valueKey));
    }
  }.observes('isSelected'),


  /** @private
    Used to store the keyboard equivalent.

    Setting the isDefault property to YES, for example, will cause the
    `keyEquivalent` property to 'return'. This cached value is used to restore
    the `keyEquivalent` property if isDefault is set back to NO.

    @type String
  */
  _defaultKeyEquivalent: null,

  /** @private

    Whenever the isDefault or isCancel property changes, re-render and change
    the keyEquivalent property so that we respond to the return or escape key.
  */
  _isDefaultOrCancelDidChange: function() {
    var isDefault = !!this.get('isDefault'),
        isCancel = !isDefault && this.get('isCancel') ;

    if (isDefault) {
      this.set('keyEquivalent', 'return'); // change the key equivalent
    } else if (isCancel) {
      this.set('keyEquivalent', 'escape') ;
    } else {
      // Restore the default key equivalent
      this.set('keyEquivalent', this._defaultKeyEquivalent);
    }

    // isDefault and isCancel act as display properties
    this.displayDidChange();
  }.observes('isDefault', 'isCancel'),

  /** @private
    On mouse down, set active only if enabled.
  */
  mouseDown: function(evt) {
    // Fast path, reject secondary clicks.
    if (evt.which !== 1) return false;

    var buttonBehavior = this.get('buttonBehavior');

    if (!this.get('isEnabledInPane')) return YES ; // handled event, but do nothing
    this.set('isActive', YES);
    this._isMouseDown = YES;

    if (buttonBehavior === SC.HOLD_BEHAVIOR) {
      this._action(evt);
    } else if (!this._isFocused && (buttonBehavior!==SC.PUSH_BEHAVIOR)) {
      this._isFocused = YES ;
      this.becomeFirstResponder();
    }

    return YES;
  },

  /** @private
    Remove the active class on mouseExited if mouse is down.
  */
  mouseExited: function(evt) {
    if (this._isMouseDown) {
      this.set('isActive', NO);
    }
    return YES;
  },

  /** @private
    If mouse was down and we renter the button area, set the active state again.
  */
  mouseEntered: function(evt) {
    if (this._isMouseDown) {
      this.set('isActive', YES);
    }
    return YES;
  },

  /** @private
    ON mouse up, trigger the action only if we are enabled and the mouse was released inside of the view.
  */
  mouseUp: function(evt) {
    if (this._isMouseDown) this.set('isActive', NO); // track independently in case isEnabledInPane has changed
    this._isMouseDown = false;

    if (this.get('buttonBehavior') !== SC.HOLD_BEHAVIOR) {
      var inside = this.$().within(evt.target);
      if (inside && this.get('isEnabledInPane')) this._action(evt) ;
    }

    return YES ;
  },

  /** @private */
  touchStart: function(touch){
    var buttonBehavior = this.get('buttonBehavior');

    if (!this.get('isEnabledInPane')) return YES ; // handled event, but do nothing
    this.set('isActive', YES);

    if (buttonBehavior === SC.HOLD_BEHAVIOR) {
      this._action(touch);
    } else if (!this._isFocused && (buttonBehavior!==SC.PUSH_BEHAVIOR)) {
      this._isFocused = YES ;
      this.becomeFirstResponder();
    }

    // don't want to do whatever default is...
    touch.preventDefault();

    return YES;
  },

  /** @private */
  touchesDragged: function(evt, touches) {
    if (!this.touchIsInBoundary(evt)) {
      if (!this._touch_exited) this.set('isActive', NO);
      this._touch_exited = YES;
    } else {
      if (this._touch_exited) this.set('isActive', YES);
      this._touch_exited = NO;
    }

    evt.preventDefault();
    return YES;
  },

  /** @private */
  touchEnd: function(touch){
    this._touch_exited = NO;
    this.set('isActive', NO); // track independently in case isEnabledInPane has changed

    if (this.get('buttonBehavior') !== SC.HOLD_BEHAVIOR) {
      if (this.touchIsInBoundary(touch) && this.get('isEnabledInPane')) {
        this._action();
      }
    }

    touch.preventDefault();
    return YES ;
  },

  /** @private */
  keyDown: function(evt) {
    // handle tab key
     if(!this.get('isEnabledInPane')) return YES;
    if (evt.which === 9 || evt.keyCode === 9) {
      var view = evt.shiftKey ? this.get('previousValidKeyView') : this.get('nextValidKeyView');
      if(view) view.becomeFirstResponder();
      else evt.allowDefault();
      return YES ; // handled
    }
    if (evt.which === 13 || evt.which === 32) {
      this.triggerActionAfterDelay(evt);
      return YES ; // handled
    }

    // let other keys through to browser
    evt.allowDefault();

    return NO;
  },

  /** @private
    Perform an action based on the behavior of the button.

     - toggle behavior: switch to on/off state
     - on behavior: turn on.
     - off behavior: turn off.
     - otherwise: invoke target/action
  */
  _action: function(evt, skipHoldRepeat) {
    switch(this.get('buttonBehavior')) {

    // When toggling, try to invert like values. i.e. 1 => 0, etc.
    case SC.TOGGLE_BEHAVIOR:
      var sel = this.get('isSelected') ;
      if (sel) {
        this.set('value', this.get('toggleOffValue')) ;
      } else {
        this.set('value', this.get('toggleOnValue')) ;
      }
      break ;

    // set value to on.  change 0 => 1.
    case SC.TOGGLE_ON_BEHAVIOR:
      this.set('value', this.get('toggleOnValue')) ;
      break ;

    // set the value to false. change 1 => 0
    case SC.TOGGLE_OFF_BEHAVIOR:
      this.set('value', this.get('toggleOffValue')) ;
      break ;

    case SC.HOLD_BEHAVIOR:
      this._runHoldAction(evt, skipHoldRepeat);
      break ;

    // otherwise, just trigger an action if there is one.
    default:
      //if (this.action) this.action(evt);
      this._runAction(evt);
    }
  },

  /** @private */
  _runAction: function(evt) {
    var action = this.get('action');

    if (action) {
      // Legacy support for action functions.
      if (action && (SC.typeOf(action) === SC.T_FUNCTION)) {
        this.action(evt);

      // Use SC.ActionSupport.
      } else {
        this.fireAction();
      }
    }
  },

  /** @private */
  _runHoldAction: function(evt, skipRepeat) {
    if (this.get('isActive')) {
      this._runAction();

      if (!skipRepeat) {
        // This run loop appears to only be necessary for testing
        SC.RunLoop.begin();
        this.invokeLater('_runHoldAction', this.get('holdInterval'), evt);
        SC.RunLoop.end();
      }
    }
  },


  /** @private */
  didBecomeKeyResponderFrom: function(keyView) {
    // focus the text field.
    if (!this._isFocused) {
      this._isFocused = YES ;
      this.becomeFirstResponder();
      if (this.get('isVisibleInWindow')) {
        this.$().focus();
      }
    }
  },

  /** @private */
  willLoseKeyResponderTo: function(responder) {
    if (this._isFocused) this._isFocused = NO ;
  },

  /** @private */
  didAppendToDocument: function() {
    if(SC.browser.isIE &&
        SC.browser.compare(SC.browser.version, '7') === 0 &&
        this.get('useStaticLayout')){
      var layout = this.get('layout'),
          elem = this.$(), w=0;
      if(elem && elem[0] && (w=elem[0].clientWidth) && w!==0 && this._labelMinWidthIE7===0){
        var label = this.$('.sc-button-label'),
            paddingRight = parseInt(label.css('paddingRight'),0),
            paddingLeft = parseInt(label.css('paddingLeft'),0),
            marginRight = parseInt(label.css('marginRight'),0),
            marginLeft = parseInt(label.css('marginLeft'),0);
        if(marginRight=='auto') SC.Logger.log(marginRight+","+marginLeft+","+paddingRight+","+paddingLeft);
        if(!paddingRight && isNaN(paddingRight)) paddingRight = 0;
        if(!paddingLeft && isNaN(paddingLeft)) paddingLeft = 0;
        if(!marginRight && isNaN(marginRight)) marginRight = 0;
        if(!marginLeft && isNaN(marginLeft)) marginLeft = 0;

        this._labelMinWidthIE7 = w-(paddingRight + paddingLeft)-(marginRight + marginLeft);
        label.css('minWidth', this._labelMinWidthIE7+'px');
      }else{
        this.invokeLater(this.didAppendToDocument, 1);
      }
    }
  }

}) ;

/**
  How long to wait before triggering the action.

  @constant
  @type {Number}
*/
SC.ButtonView.TRIGGER_DELAY = 200;

/**
  The delay after which "click" behavior should transition to "click and hold"
  behavior. This is used by subclasses such as PopupButtonView and
  SelectButtonView.

  @constant
  @type Number
*/
SC.ButtonView.CLICK_AND_HOLD_DELAY = SC.browser.isIE ? 600 : 300;

SC.REGULAR_BUTTON_HEIGHT=24;



/* >>>>>>>>>> BEGIN source/panes/alert.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('panes/panel');
sc_require('views/button');

/**
  Passed to delegate when alert pane is dismissed by pressing button 1

  @static
  @type String
  @default 'button1'
*/
SC.BUTTON1_STATUS = 'button1';

/**
  Passed to delegate when alert pane is dismissed by pressing button 2

  @static
  @type String
  @default 'button2'
*/
SC.BUTTON2_STATUS = 'button2';

/**
  Passed to delegate when alert pane is dismissed by pressing button 3

  @static
  @type String
  @default 'button3'
*/
SC.BUTTON3_STATUS = 'button3';

/** @class
  Displays a preformatted modal alert pane.

  Alert panes are a simple way to provide modal messaging that otherwise
  blocks the user's interaction with your application.  Alert panes are
  useful for showing important error messages and confirmation dialogs. They
  provide a substantially better user experience than using the OS-level alert
  dialogs.

  ## Displaying an Alert Pane

  The easiest way to display an alert pane is to use one of the various
  class methods defined on `SC.AlertPane`, passing the message and an optional
  detailed description and caption.

  There are four variations of this method can you can invoke:

   - `warn({})` -- displays an alert pane with a warning icon to the left.
   - `error()` -- displays an alert with an error icon.
   - `info()` -- displays an alert with an info icon.
   - `plain()` -- displays an alert with no icon.
   - `show()` -- displays an alert with the icon class you specify.

  Each method takes a single argument: a hash of options. These options include:

  - `message` -- The alert's title message.
  - `description` -- A longer description of the alert, displayed below the title
    in a smaller font.
  - `caption` -- A third layer of alert text, displayed below the description in
    an even-smaller font.
  - `icon` -- This is set for you automatically unless you call `show`. You may
    specify any icon class you wish. The icon is displayed at the alert pane's
    left.
  - `themeName` -- A button theme that is applied to each button. The default is
    `capsule`.
  - `delegate` -- A delegate to be notified when the user reacts to your pane. See
    "Responding to User Actions" below.
  - `buttons` -- An array of up to three hashes used to customize the alert's buttons.
    See "Customizing Buttons" below.

  ## Responding to User Actions

  Often, you may wish to be notified when the user has dismissed to your alert. You
  have two options: you may specify a delegate in the options hash, or you may
  customize each button with a target & action.

  If you specify a delegate, it must implement a method with the following signature:
  `alertPaneDidDismiss(pane, buttonKey)`. When the user dismisses your alert, this
  method will be called with the pane instance and a key indicating which button was
  pressed (one of either `SC.BUTTON1_STATUS`, `SC.BUTTON2_STATUS` or `SC.BUTTON3_STATUS`).

  If you specify a target/action for a button (see "Customizing Buttons" below) and the
  user dismisses the alert with that button, that action will be triggered. If you specify
  a delegate but no target, the delegate will be used as the target. The action will
  be called with the alert pane itself as the sender (first argument).

  ## Customizing Buttons

  SC.AlertPane allows you to specify up to three buttons, arranged from right to left (as
  on Mac OS X). You can customize them by passing an array of up to three options hashes
  on the `buttons` property. By default, the first, rightmost button is the default (i.e.
  it is triggered when the user hits the enter key), and the second button is the "cancel"
  button (triggered by the escape key).

  If you don't specify any buttons, a single default "OK" button will appear.

  You may customize the following button options:

  - `title` -- The button text. Highly recommended unless you like empty buttons.
  - `localize` -- Whether to localize the title.
  - `toolTip` -- An extra hint to show when the user hovers the mouse over the button.
    Make sure that the user can get along fine without this, as tooltips are hard to
    discover and unavailable on touch devices!
  - `isDefault` -- You may specify a different button than the first, rightmost button
    to be the default (triggered by the enter key, and visually distinct in the default
    Ace theme).
  - `isCancel` -- You may specify a different button than the second, middle button
    to be the cancel button (triggered by the escape key).
  - `target` & `action` -- Supports the target/action pattern (see "Responding to User
    Actions" above).

  (You may also specify a layerId for the button if needed. As always, using custom
  layerIds is dangerous and should be avoided unless you know what you're doing.)

  ## Examples

  Show a simple AlertPane with a warning (!) icon and an OK button:

      SC.AlertPane.warn({
        message: "Could not load calendar",
        description: "Your internet connection may be unavailable or our servers may be down.",
        caption: "Try again in a few minutes."
      });

  Show an AlertPane with a customized OK button title (title will be 'Try Again'):

      SC.AlertPane.warn({
        message: "Could not load calendar",
        description: "Your internet connection may be unavailable or our servers may be down.",
        caption: "Try again in a few minutes.",
        buttons: [
          { title: "Try Again" }
        ]
      });

  Show an AlertPane with fully customized buttons:

      SC.AlertPane.show({
        message: "Could not load calendar",
        description: "Your internet connection may be unavailable or our servers may be down.",
        caption: "Try again in a few minutes.",
        buttons: [
          { title: "Try Again", toolTip: "Retry the connection", isDefault: true },
          { title: "More Info...", toolTip: "Get more info" },
          { title: "Cancel", toolTip: "Cancel the action", isCancel: true }
        ]
      });

  Show an alert pane, using the delegate pattern to respond to how the user dismisses it.

      MyApp.calendarController = SC.Object.create({
        alertPaneDidDismiss: function(pane, status) {
          switch(status) {
            case SC.BUTTON1_STATUS:
              this.tryAgain();
              break;
            case SC.BUTTON2_STATUS:
              // do nothing
              break;
            case SC.BUTTON3_STATUS:
              this.showMoreInfo();
              break;
          }
        },
        ...
      });

      SC.AlertPane.warn({
        message: "Could not load calendar",
        description: "Your internet connection may be unavailable or our servers may be down.",
        caption: "Try again in a few minutes.",
        delegate: MyApp.calendarController,
        buttons: [
          { title: "Try Again" },
          { title: "Cancel" },
          { title: "More Info…" }
        ]
      });

  Show an alert pane using the target/action pattern on each button to respond to how the user
  dismisses it.

      SC.AlertPane.warn({
        message: "Could not load calendar",
        description: "Your internet connection may be unavailable or our servers may be down.",
        caption: "Try again in a few minutes.",
        buttons: [
          {
            title: "Try Again",
            action: "doTryAgain",
            target: MyApp.calendarController
          },
          {
            title: "Cancel",
            action: "doCancel",
            target: MyApp.calendarController
          },
          {
            title: "More Info…",
            action: "doGiveMoreInfo",
            target: MyApp.calendarController
          }
        ]
      });

  @extends SC.PanelPane
  @since SproutCore 1.0
*/
SC.AlertPane = SC.PanelPane.extend(
/** @scope SC.AlertPane.prototype */{

  /**
    @type Array
    @default ['sc-alert']
    @see SC.View#classNames
  */
  classNames: ['sc-alert'],

  /**
    The WAI-ARIA role for alert pane.

    @type String
    @default 'alertdialog'
    @constant
  */
  ariaRole: 'alertdialog',

  /**
    If defined, the delegate is notified when the pane is dismissed. If you have
    set specific button actions, they will be called on the delegate object

    The method to be called on your delegate will be:

        alertPaneDidDismiss: function(pane, status) {}

    The status will be one of `SC.BUTTON1_STATUS`, `SC.BUTTON2_STATUS` or `SC.BUTTON3_STATUS`
    depending on which button was clicked.

    @type Object
    @default null
  */
  delegate: null,

  /**
    The icon URL or class name. If you do not set this, an alert icon will
    be shown instead.

    @type String
    @default 'sc-icon-alert-48'
  */
  icon: 'sc-icon-alert-48',

  /**
    The primary message to display. This message will appear in large bold
    type at the top of the alert.

    @type String
    @default ""
  */
  message: "",

  /**
    The ARIA label for the alert is the message, by default.

    @field {String}
  */
  ariaLabel: function() {
    return this.get('message');
  }.property('message').cacheable(),

  /**
    An optional detailed description. Use this string to provide further
    explanation of the condition and, optionally, ways the user can resolve
    the problem.

    @type String
    @default ""
  */
  description: "",

  /**
    An escaped and formatted version of the description property.

    @field
    @type String
    @observes description
  */
  displayDescription: function() {
    var desc = this.get('description');
    if (!desc || desc.length === 0) return desc ;

    desc = SC.RenderContext.escapeHTML(desc); // remove HTML
    return '<p class="description">' + desc.split('\n').join('</p><p class="description">') + '</p>';
  }.property('description').cacheable(),

  /**
    An optional detailed caption. Use this string to provide further
    fine print explanation of the condition and, optionally, ways the user can resolve
    the problem.

    @type String
    @default ""
  */
  caption: "",

  /**
    An escaped and formatted version of the caption property.

    @field
    @type String
    @observes caption
  */
  displayCaption: function() {
    var caption = this.get('caption');
    if (!caption || caption.length === 0) return caption ;

    caption = SC.RenderContext.escapeHTML(caption); // remove HTML
    return '<p class="caption">' + caption.split('\n').join('</p><p class="caption">') + '</p>';
  }.property('caption').cacheable(),

  /**
    The button view for button 1 (OK).

    @type SC.ButtonView
  */
  button1: SC.outlet('contentView.childViews.1.childViews.1'),

  /**
    The button view for the button 2 (Cancel).

    @type SC.ButtonView
  */
  button2: SC.outlet('contentView.childViews.1.childViews.0'),

  /**
    The button view for the button 3 (Extra).

    @type SC.ButtonView
  */
  button3: SC.outlet('contentView.childViews.2.childViews.0'),

  /**
    The view for the button 3 (Extra) wrapper.

    @type SC.View
  */
  buttonThreeWrapper: SC.outlet('contentView.childViews.2'),

  /**
    @type Hash
    @default { top : 0.3, centerX: 0, width: 500 }
    @see SC.View#layout
  */
  layout: { top : 0.3, centerX: 0, width: 500 },

  /** @private - internal view that is actually displayed */
  contentView: SC.View.extend({

    useStaticLayout: YES,

    layout: { left: 0, right: 0, top: 0, height: "auto" },

    childViews: [
      SC.View.extend({
        classNames: ['info'],
        useStaticLayout: YES,

        /** @private */
        render: function(context, firstTime) {
          var pane = this.get('pane');
          if(pane.get('icon') == 'blank') context.addClass('plain');
          context.push('<img src="'+SC.BLANK_IMAGE_URL+'" class="icon '+pane.get('icon')+'" />');
          context.begin('h1').addClass('header').text(pane.get('message') || '').end();
          context.push(pane.get('displayDescription') || '');
          context.push(pane.get('displayCaption') || '');
          context.push('<div class="separator"></div>');

        }
      }),

      SC.View.extend({
        layout: { bottom: 13, height: 24, right: 18, width: 466 },
        childViews: ['cancelButton', 'okButton'],
        classNames: ['text-align-right'],

        cancelButton: SC.ButtonView.extend({
          useStaticLayout: YES,
          actionKey: SC.BUTTON2_STATUS,
          localize: YES,
          layout: { right: 5, height: 'auto', width: 'auto', bottom: 0 },
          isCancel: YES,
          action: "dismiss",
          isVisible: NO
        }),

        okButton: SC.ButtonView.extend({
          useStaticLayout: YES,
          actionKey: SC.BUTTON1_STATUS,
          localize: YES,
          layout: { left: 0, height: 'auto', width: 'auto', bottom: 0 },
          isDefault: YES,
          action: "dismiss",
          isVisible: NO
        })
      }),

      SC.View.extend({
        layout: { bottom: 13, height: 24, left: 18, width: 150 },
        childViews: [
          SC.ButtonView.extend({
            useStaticLayout: YES,
            actionKey: SC.BUTTON3_STATUS,
            localize: YES,
            layout: { left: 0, height: 'auto', width: 'auto', bottom: 0 },
            action: "dismiss",
            isVisible: NO
          })]
      })]
  }),

  /**
    Action triggered whenever any button is pressed. Also the hides the
    alertpane itself.

    This will trigger the following chain of events:

     1. If a delegate was given, and it has alertPaneDidDismiss it will be called
     2. Otherwise it will look for the action of the button and call:
      a) The action function reference if one was given
      b) The action method on the target if one was given
      c) If both a and b are missing, call the action on the rootResponder

    @param {SC.View} sender - the button view that was clicked
  */
  dismiss: function(sender) {
    var del = this.delegate,
        rootResponder, action, target;

    if (del && del.alertPaneDidDismiss) {
      del.alertPaneDidDismiss(this, sender.get('actionKey'));
    }

    if (action = (sender && sender.get('customAction'))) {
      if (SC.typeOf(action) === SC.T_FUNCTION) {
        action.call(action);
      } else {
        rootResponder = this.getPath('pane.rootResponder');
        if(rootResponder) {
          target = sender.get('customTarget');
          rootResponder.sendAction(action, target || del, this, this, null, this);
        }
      }
    }

    this.remove(); // hide alert
  },

  /** @private
    Executes whenever one of the icon, message, description or caption is changed.
    This simply causes the UI to refresh.
  */
  alertInfoDidChange: function() {
    var v = this.getPath('contentView.childViews.0');
    if (v) v.displayDidChange(); // re-render message
  }.observes('icon', 'message', 'displayDescription', 'displayCaption')

});

SC.AlertPane.mixin(
/** @scope SC.AlertPane */{

  /**
    Show a dialog with a given set of hash attributes:

        SC.AlertPane.show({
          message: "Could not load calendar",
          description: "Your internet connection may be unavailable or our servers may be down.",
          caption: "Try again in a few minutes.",
          delegate: MyApp.calendarController
        });

    See more examples for how to configure buttons and individual actions in the
    documentation for the `SC.AlertPane` class.

    @param {Hash} args
    @return {SC.AlertPane} the pane shown
  */
  show: function (args) {
    // normalize the arguments if this is a deprecated call
    args = SC.AlertPane._argumentsCall.apply(this, arguments);

    var pane = this.create(args),
        idx,
        buttons = args.buttons,
        button, buttonView, layerId, title, toolTip, action, target, themeName,
        isDefault, isCancel, hasDefault, hasCancel;

    if (buttons) {
      


      // Determine if any button hash specifies isDefault/isCancel. If so, we need
      // to override the button views' default settings.
      hasDefault = !!buttons.findProperty('isDefault');
      hasCancel = !!buttons.findProperty('isCancel');

      for (idx = 0; idx < 3; idx++) {
        button = buttons[idx];
        if (!button) continue;

        buttonView = pane.get('button%@'.fmt(idx + 1));

        layerId = button.layerId;
        title = button.title;
        localize = button.localize;
        toolTip = button.toolTip;
        action = button.action;
        target = button.target;
        themeName = args.themeName || 'capsule';

        // If any button has the isDefault/isCancel flags set, we
        // explicitly cast the button's flag to bool, ensuring that this
        // overrides the default. Otherwise, we use undefined so we skip
        // setting the property, ensuring the default value is used.
        isDefault = hasDefault ? !!button.isDefault : undefined;
        isCancel = hasCancel ? !!button.isCancel : undefined;

        buttonView.set('title', title);
        if (localize === YES) buttonView.set('localize', YES);
        if (toolTip) buttonView.set('toolTip', toolTip);
        if (action) buttonView.set('customAction', action);
        if (target) buttonView.set('customTarget', target);
        if (layerId !== undefined) { buttonView.set('layerId', layerId); }
        if (isDefault !== undefined) { buttonView.set('isDefault', isDefault); }
        if (isCancel !== undefined) { buttonView.set('isCancel', isCancel); }
        buttonView.set('isVisible', !!title);
        buttonView.set('themeName', themeName);
      }
    } else {
      // if there are no buttons defined, just add the standard OK button
      buttonView = pane.get('button1');
      buttonView.set('title', "OK");
      buttonView.set('isVisible', YES);
    }

    var show = pane.append(); // make visible.
    pane.adjust('height', pane.childViews[0].$().height());
    pane.updateLayout();
    return show;
  },

  /**
    Same as `show()` just that it uses sc-icon-alert-48 CSS classname
    as the dialog icon

    @param {Hash} args
    @return {SC.AlertPane} the pane shown
  */
  warn: function(args) {
    // normalize the arguments if this is a deprecated call
    args = SC.AlertPane._argumentsCall.apply(this, arguments);

    args.icon = 'sc-icon-alert-48';
    return this.show(args);
  },

  /**
    Same as `show()` just that it uses sc-icon-info-48 CSS classname
    as the dialog icon

    @param {Hash} args
    @return {SC.AlertPane} the pane shown
  */
  info: function(args) {
    // normalize the arguments if this is a deprecated call
    args = SC.AlertPane._argumentsCall.apply(this, arguments);

    args.icon = 'sc-icon-info-48';
    return this.show(args);
  },

  /**
    Same as `show()` just that it uses sc-icon-error-48 CSS classname
    as the dialog icon

    @param {Hash} args
    @return {SC.AlertPane} the pane shown
  */
  error: function(args) {
    // normalize the arguments if this is a deprecated call
    args = SC.AlertPane._argumentsCall.apply(this, arguments);

    args.icon = 'sc-icon-error-48';
    return this.show(args);
  },

  /**
    Same as `show()` just that it uses blank CSS classname
    as the dialog icon

    @param {Hash} args
    @return {SC.AlertPane} the pane shown
  */
  plain: function(args) {
    // normalize the arguments if this is a deprecated call
    args = SC.AlertPane._argumentsCall.apply(this, arguments);

    args.icon = 'blank';
    return this.show(args);
  },

  /** @private
    Set properties to new structure for call that use the old arguments
    structure.

    Deprecated API but is preserved for now for backwards compatibility.

    @deprecated
  */
  _argumentsCall: function(args) {
    var ret = args;
    if(SC.typeOf(args)!==SC.T_HASH) {
      

      var normalizedArgs = this._normalizeArguments(arguments);

      // now convert it to the new format for show()
      ret = {
        message: normalizedArgs[0],
        description: normalizedArgs[1],
        caption: normalizedArgs[2],
        delegate: normalizedArgs[7],
        icon: (normalizedArgs[6] || 'sc-icon-alert-48'),
        themeName: 'capsule'
      };

      // set buttons if there are any (and check if it's a string, since last
      // argument could be the delegate object)
      if(SC.typeOf(normalizedArgs[3])===SC.T_STRING || SC.typeOf(normalizedArgs[4])===SC.T_STRING || SC.typeOf(normalizedArgs[5])===SC.T_STRING) {
        ret.buttons = [
          { title: normalizedArgs[3] },
          { title: normalizedArgs[4] },
          { title: normalizedArgs[5] }
        ];
      }

    }
    return ret;
  },

  /** @private
    internal method normalizes arguments for processing by helper methods.
  */
  _normalizeArguments: function(args) {
    args = SC.A(args); // convert to real array
    var len = args.length, delegate = args[len-1];
    if (SC.typeOf(delegate) !== SC.T_STRING) {
      args[len-1] = null;
    } else delegate = null ;
    args[7] = delegate ;
    return args ;
  }

});

/* >>>>>>>>>> BEGIN source/panes/draggable.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @namespace

  Provides drag functionality to a pane. If you need to disable dragging at certain times set the
  property isAnchored to YES and the pane will no longer move.

  See SC.PalettePane, a simple panel pane with SC.DraggablePaneSupport mixed in.
*/
SC.DraggablePaneSupport = /** @scope SC.DraggablePaneSupport.prototype */{

  /**
    Walk like a duck.

    @type Boolean
  */
  isDraggablePane: YES,

  /**
   @type Boolean
   @default NO
  */
  isAnchored: NO,

  /** @private */
  _drag_cachedMouseX: null,

  /** @private */
  _drag_cachedMouseY: null,

  /**
   To provide drag functionality enhance mouseDown, mouseDragged, touchStart, and touchesDragged if they exist.
   */
  initMixin: function() {
    if (this.mouseDown) {
      this.mouseDown = SC._enhance(this.mouseDown, function(original, evt) {
        var ret = this._drag_mouseDown(evt);
        return original(evt) || ret;
      });
    } else {
      this.mouseDown = this._drag_mouseDown;
    }

    if (this.mouseDragged) {
      this.mouseDragged = SC._enhance(this.mouseDragged, function(original, evt) {
        var ret = this._drag_mouseDragged(evt);
        return original(evt) || ret;
      });
    } else {
      this.mouseDragged = this._drag_mouseDragged;
    }

    if (this.touchStart) {
      this.touchStart = SC._enhance(this.touchStart, function(original, evt) {
        var ret = this._drag_touchStart(evt);
        return original(evt) || ret;
      });
    } else {
      this.touchStart = this._drag_touchStart;
    }

    if (this.touchesDragged) {
      this.touchesDragged = SC._enhance(this.touchesDragged, function(original, evt) {
        var ret = this._drag_touchesDragged(evt);
        return original(evt) || ret;
      });
    } else {
      this.touchesDragged = this._drag_touchesDragged;
    }
  },

  /**
    Returns true if the target view of the event exists and has a truthy isTextSelectable

    @param evt The event
    @return {Boolean}
  */
  _drag_targetHasSelectableText: function(evt) {
    var targetView = SC.RootResponder.responder.targetViewForEvent(evt);

    return !!(targetView && targetView.isTextSelectable);
  },

  /**
    Returns true if we should handle a drag.

    @param evt The event
    @return {Boolean}
  */
  _drag_shouldHandleDrag: function(evt) {
    return !this.get('isAnchored') && !this._drag_targetHasSelectableText(evt);
  },

  /**
    The drag code will modify the existing layout by the difference between each drag event so for the first one store
    the original mouse down position.

    @param evt The mouseDown event
    @return {Boolean} YES
  */
  _drag_mouseDown: function(evt) {
    this._drag_cachedMouseX = evt.pageX;
    this._drag_cachedMouseY = evt.pageY;
    return this._drag_shouldHandleDrag(evt);
  },

  /**
    Modify the current layout by the movement since the last drag event.

    @param evt The mouseDrag event
    @return {Boolean} YES if we moved the view, NO if we didn't due to isAnchored being YES
  */
  _drag_mouseDragged: function(evt) {
    var xOffset = this._drag_cachedMouseX - evt.pageX,
        yOffset = this._drag_cachedMouseY - evt.pageY,
        frame = this.get('frame'),
        // NOTE: wFrame will be incorrect if this pane is not attached to document.body (e.g. via appendTo).
        wFrame = SC.RootResponder.responder.computeWindowSize(),
        oldLayout = SC.clone(this.get('layout')),
        layout = {},
        isPercent = function(num) {
          return (num < 1 && num > 0);
        };

    //Update the cached coordinates so we can track the change between each drag event
    this._drag_cachedMouseX = evt.pageX;
    this._drag_cachedMouseY = evt.pageY;

    if (!this._drag_shouldHandleDrag(evt)) {
      return NO;
    }

    // If a layout property is in the layout no matter what other layout properties are used we need to modify it the
    // same way. For the 4 offsets we check if they've been specified as percentages and if so convert them to regular
    // offsets based on our current frame and the current window. For simplicity's sake, it is assumed that the frame
    // frame coordinates are in the browser window's coordinates (see above note on wFrame).

    if (oldLayout.hasOwnProperty('left')) {
      if (isPercent(oldLayout.left)) {
        oldLayout.left = frame.x;
      }

      layout.left = oldLayout.left - xOffset;
    }

    if (oldLayout.hasOwnProperty('right')) {
      if (isPercent(oldLayout.right)) {
        oldLayout.right = wFrame.width - (frame.x + frame.width);
      }

      layout.right = oldLayout.right + xOffset;
    }

    if (oldLayout.hasOwnProperty('centerX')) {
      layout.centerX = oldLayout.centerX - xOffset;
    }

    if (oldLayout.hasOwnProperty('top')) {
      if (isPercent(oldLayout.top)) {
        oldLayout.top = frame.y;
      }

      layout.top = oldLayout.top - yOffset;
    }

    if (oldLayout.hasOwnProperty('bottom')) {
      if (isPercent(oldLayout.bottom)) {
        oldLayout.bottom = wFrame.height - (frame.y + frame.height);
      }

      layout.bottom = oldLayout.bottom + yOffset;
    }

    if (oldLayout.hasOwnProperty('centerY')) {
      layout.centerY = oldLayout.centerY - yOffset;
    }

    this.adjust(layout);

    return YES;
  },

  /**
    Forward to our mouseDown handler.
  */
  _drag_touchStart: function(evt) {
    return this._drag_mouseDown(evt);
  },

  /**
    Forward to our mouseDragged handler.
  */
  _drag_touchesDragged: function(evt) {
    return this._drag_mouseDragged(evt);
  }
};

/* >>>>>>>>>> BEGIN source/panes/palette.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('panes/panel');

/** @class
  Displays a non-modal, default positioned, drag&drop-able palette pane.

  The simplest way to use the palette pane is to define it in an SC.Page like this:

        myPalettePane: SC.PalettePane.create({
          layout: { width: 400, height: 200, right: 0, top: 0 },
          contentView: SC.View.extend({
          })
        })

  Then get it from your page and append like this:

        MyApp.myPage.get('myPalettePane').append();

  This will cause your palette pane to instantiate lazily and display.

  Palette pane is a simple way to provide non-modal messaging that won't
  blocks the user's interaction with your application.  Palette panes are
  useful for showing important detail information with flexible position.
  They provide a better user experience than modal panel.

  @extends SC.PanelPane
  @extends SC.DraggablePaneSupport
  @since SproutCore 1.0
*/
SC.PalettePane = SC.PanelPane.extend(SC.DraggablePaneSupport,
/** @scope SC.PalettePane.prototype */ {

  /**
    @type Array
    @default ['sc-palette']
    @see SC.View#classNames
  */
  classNames: ['sc-palette'],

  /**
    Palettes are not modal by default

    @type Boolean
    @default NO
  */
  isModal: NO,

  /**
    @type SC.View
    @default SC.ModalPane
  */

  modalPane: SC.ModalPane
});

/* >>>>>>>>>> BEGIN source/panes/picker.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('panes/palette');

/**
  Popular customized picker position rules:
  default: initiated just below the anchor.
           shift x, y to optimized picker visibility and make sure top-left corner is always visible.
  menu :   same as default rule +
           default(1, 4, 3) or custom offset below the anchor for default location to fine tuned visual alignment +
           enforce min left(7px)/right(8px) padding to the window
  fixed :  default(1, 4, 3) or custom offset below the anchor for default location to cope with specific anchor and skip fitPositionToScreen
  pointer :take default [0, 1, 2, 3, 2] or custom matrix to choose one of four perfect pointer positions.Ex:
           perfect right (0) > perfect left (1) > perfect top (2) > perfect bottom (3)
           fallback to perfect top (2)
  menu-pointer :take default [3, 0, 1, 2, 3] or custom matrix to choose one of four perfect pointer positions.Ex:
          perfect bottom (3) > perfect right (0) > perfect left (1) > perfect top (2)
          fallback to perfect bottom (3)
*/

/**
  @type String
  @constant
  @static
*/
SC.PICKER_MENU = 'menu';

/**
  @type String
  @constant
  @static
*/
SC.PICKER_FIXED = 'fixed';

/**
  @type String
  @constant
  @static
*/
SC.PICKER_POINTER = 'pointer';

/**
  @type String
  @constant
  @static
*/
SC.PICKER_MENU_POINTER = 'menu-pointer';

/**
  @class

  Display a non-modal pane that automatically repositions around a view so as
  to remain visible.

  An `SC.PickerPane` repositions around the view to which it is anchored as the
  browser window is resized so as to ensure the pane's content remains visible.
  A picker pane is useful for displaying supplementary information and does not
  block the user's interaction with other UI elements. Picker panes typically
  provide a better user experience than modal panels.

  An `SC.PickerPane` repositions itself according to the optional `preferMatrix`
  argument passed in the `.popup()` method call. The `preferMatrix` either
  specifies an offset-based arrangement behavior or a position-based arrangement
  behavior depending on the `preferType` argument in the `.popup()` call.

  The simplest way to create and display a picker pane:

      SC.PickerPane.create({
        layout: { width: 400, height: 200 },
        contentView: SC.View.extend({})
      }).popup(someView);

  This displays the `SC.PickerPane` anchored to `someView`.

  ## Positioning

  Picker pane positioning can be classified into two broad categories:
  offset-based and position-based.

  ### Offset-based

  When `preferType` is unspecified, `SC.PICKER_MENU` or `SC.PICKER_FIXED`, then
  the `preferMatrix` array describes the offset that is used to position the
  pane below the anchor. The offset is described by an array of three values,
  defaulting to `[1, 4, SC.POSITION_BOTTOM]`. The first value controls the x offset and the second
  value the y offset. The third value can be `SC.POSITION_RIGHT` (0) or `SC.POSITION_BOTTOM` (3),
  controlling whether the origin of the pane is further offset by the width
  (in the case of SC.POSITION_RIGHT) or the height (in the case of SC.POSITION_BOTTOM) of the anchor.

  ### Position-based

  When `preferType` is `SC.PICKER_POINTER` or `SC.PICKER_MENU_POINTER`, then
  the `preferMatrix` specifies the sides in the order in which you want the
  `SC.PickerPane` to try to arrange itself around the view to which it is
  anchored. The fifth element in the `preferMatrix` specifies which side the
  `SC.PickerPane` should display on when there isn't enough space around any
  of the preferred sides.

  The sides may be one of:

  * SC.POSITION_RIGHT (i.e. 0) - to the right of the anchor
  * SC.POSITION_LEFT (i.e. 1)- to the left of the anchor
  * SC.POSITION_TOP (i.e. 2) - above the anchor
  * SC.POSITION_BOTTOM (i.e. 3) - below the anchor

  For example, the `preferMatrix` of,

      [SC.POSITION_BOTTOM, SC.POSITION_RIGHT, SC.POSITION_LEFT, SC.POSITION_TOP, SC.POSITION_TOP],

  indicates: Display below the anchor (SC.POSITION_BOTTOM); if there isn't enough
  space then display to the right of the anchor (SC.POSITION_RIGHT).
  If there isn't enough space either below or to the right of the anchor, then appear
  to the left (SC.POSITION_LEFT), unless there is also no space on the left, in which case display
  above the anchor (SC.POSITION_TOP).

  Note: The position constants are simply the integers 0 to 3, so a short form
  of the example above would read,

      [3, 0, 1, 2, 2]

  ## Position Rules

  When invoking `.popup()` you can optionally specify a picker position rule with
  the `preferType` argument.

  If no `preferType` is specified, the picker pane is displayed just below the anchor.
  The pane will reposition automatically for optimal visibility, ensuring the top-left
  corner is visible.

  These position rules have the following behaviors:

  ### `SC.PICKER_MENU`

  Positioning is offset-based, with `preferMatrix` defaulting to `[1, 4, SC.POSITION_BOTTOM]`.
  Furthermore, a minimum left and right padding to window, of 7px and 8px, respectively,
  is enforced.


  ### `SC.PICKER_FIXED`

  Positioning is offset-based, with `preferMatrix` defaulting to `[1, 4, SC.POSITION_BOTTOM]` and
  skipping `fitPositionToScreen`.


  ### `SC.PICKER_POINTER`

  Positioning is position-based, with `preferMatrix` defaulting to `[SC.POSITION_RIGHT, SC.POSITION_LEFT, SC.POSITION_TOP, SC.POSITION_BOTTOM, SC.POSITION_TOP]` or `[0, 1, 2, 3, 2]` for short,
  i.e. right > left > top > bottom; fallback to top.


  ### `SC.PICKER_MENU_POINTER`

  Positioning is position-based, with `preferMatrix` defaulting to `[SC.POSITION_BOTTOM, SC.POSITION_RIGHT, SC.POSITION_LEFT, SC.POSITION_TOP, SC.POSITION_BOTTOM]` or `[3, 0, 1, 2, 3]` for short,
  i.e. bottom, right, left, top; fallback to bottom.


  ## Examples

  Examples for applying popular customized picker position rules:

  ### default:

      SC.PickerPane.create({
        layout: { width: 400, height: 200 },
        contentView: SC.View.extend({})
      }).popup(anchor);

  ### menu below the anchor with default `preferMatrix` of `[1, 4, SC.POSITION_BOTTOM]`:

      SC.PickerPane.create({
        layout: { width: 400, height: 200 },
        contentView: SC.View.extend({})
      }).popup(anchor, SC.PICKER_MENU);

  ### menu on the right side of anchor with custom `preferMatrix` of `[2, 6, SC.POSITION_RIGHT]`:

      SC.PickerPane.create({
        layout: { width: 400, height: 200 },
        contentView: SC.View.extend({})
      }).popup(anchor, SC.PICKER_MENU, [2, 6, SC.POSITION_RIGHT]);

  ### fixed below the anchor with default `preferMatrix` of `[1, 4, SC.POSITION_BOTTOM]`:

      SC.PickerPane.create({
        layout: { width: 400, height: 200 },
        contentView: SC.View.extend({})
      }).popup(anchor, SC.PICKER_FIXED);

  ### fixed on the right side of anchor with `preferMatrix` of `[-22,-17, SC.POSITION_RIGHT]`:

      SC.PickerPane.create({
        layout: { width: 400, height: 200 },
        contentView: SC.View.extend({})
      }).popup(anchor, SC.PICKER_FIXED, [-22,-17, SC.POSITION_RIGHT]);

  ### pointer with default `preferMatrix` of `[SC.POSITION_RIGHT, SC.POSITION_LEFT, SC.POSITION_TOP, SC.POSITION_BOTTOM, SC.POSITION_TOP]` or `[0, 1, 2, 3, 2]`:

      SC.PickerPane.create({
        layout: { width: 400, height: 200 },
        contentView: SC.View.extend({})
      }).popup(anchor, SC.PICKER_POINTER);

  Positioning: SC.POSITION_RIGHT (0) > SC.POSITION_LEFT (1) > SC.POSITION_TOP (2) > SC.POSITION_BOTTOM (3). Fallback to SC.POSITION_TOP (2).

  ### pointer with custom `preferMatrix` of `[SC.POSITION_BOTTOM, SC.POSITION_RIGHT, SC.POSITION_LEFT, SC.POSITION_TOP, SC.POSITION_TOP]` or `[3, 0, 1, 2, 2]`:

      SC.PickerPane.create({
        layout: { width: 400, height: 200 },
        contentView: SC.View.extend({})
      }).popup(anchor, SC.PICKER_POINTER, [3, 0, 1, 2, 2]);

  Positioning: SC.POSITION_BOTTOM (3) > SC.POSITION_RIGHT (0) > SC.POSITION_LEFT (1) > SC.POSITION_TOP (2). Fallback to SC.POSITION_TOP (2).

  ### menu-pointer with default `preferMatrix` of `[SC.POSITION_BOTTOM, SC.POSITION_RIGHT, SC.POSITION_LEFT, SC.POSITION_TOP, SC.POSITION_BOTTOM]` or `[3, 0, 1, 2, 3]`:

      SC.PickerPane.create({
        layout: { width: 400, height: 200 },
        contentView: SC.View.extend({})
      }).popup(anchor, SC.PICKER_MENU_POINTER);

  Positioning: SC.POSITION_BOTTOM (3) > SC.POSITION_RIGHT (0) > SC.POSITION_LEFT (1) > SC.POSITION_TOP (2). Fallback to SC.POSITION_BOTTOM (3).

  ### Transition-In Special Handling

  This view has special behavior when used with SC.View's `transitionIn` plugin support. If the
  plugin defines `layoutProperties` of either `scale` or `rotate`, then the picker will adjust its
  transform origin X & Y position to appear to scale or rotate out of the anchor. The result is a
  very nice effect that picker panes appear to pop out of their anchors. To see it in effect,
  simply set the `transitionIn` property of the pane to one of `SC.View.SCALE_IN` or `SC.View.POP_IN`.

  @extends SC.PalettePane
  @since SproutCore 1.0
*/
SC.PickerPane = SC.PalettePane.extend(
/** @scope SC.PickerPane.prototype */ {

  


  /**
    @type Array
    @default ['sc-picker']
    @see SC.View#classNames
  */
  classNames: ['sc-picker'],

  /**
    @type Boolean
    @default YES
  */
  isAnchored: YES,

  /**
    @type Boolean
    @default YES
  */
  isModal: YES,

  /**
    @private
    TODO: Remove SC.POINTER_LAYOUT backward compatibility.
  */
  _sc_pointerLayout: SC.POINTER_LAYOUT || ['perfectRight', 'perfectLeft', 'perfectTop', 'perfectBottom'],

  /** @private
    @type String
    @default 'perfectRight'
  */
  pointerPos: 'perfectRight',

  /** @private
    @type Number
    @default 0
  */
  pointerPosX: 0,

  /** @private
    @type Number
    @default 0
  */
  pointerPosY: 0,

  /** @private
    When calling `popup`, you pass a view or element to anchor the pane. This
    property returns the anchor element. (If you've anchored to a view, this
    is its layer.) You can use this to properly position your view.

    @type HTMLElement
    @default null
  */
  anchorElement: function (key, value) {
    // Getter
    if (value === undefined) {
      if (this._anchorView) return this._anchorView.get('layer');
      else return this._anchorHTMLElement;
    }
    // Setter
    else {
      // Strip jQuery objects. (We do this first in case an empty one is passed in.)
      if (value && value.isCoreQuery) value = value[0];

      // Throw an error if a null or empty value is set. You're not allowed to go anchorless.
      // (TODO: why can't we go anchorless? positionPane happily centers an unmoored pane.)
      if (!value) {
        SC.throw("You must set 'anchorElement' to either a view or a DOM element");
      }

      // Clean up any previous anchor elements.
      this._removeScrollObservers();

      if (value.isView) {
        this._setupScrollObservers(value);
        this._anchorView        = value;
        this._anchorHTMLElement = null;
        return value.get('layer');
      }
      else {
        // TODO: We could setupScrollObservers on passed elements too, but it would
        // be a bit more complicated.
        this._anchorView        = null;
        this._anchorHTMLElement = value;
        return value;
      }
    }
  }.property().cacheable(),

  /** @private
    anchor rect calculated by computeAnchorRect from init popup

    @type Hash
    @default null
  */
  anchorCached: null,

  /**
    The type of picker pane.

    Picker panes can behave and appear in slightly differing ways
    depending on the value of `preferType`. By default, with no `preferType`
    specified, the pane will appear directly below the anchor element with
    its left side aligned to the anchor's left side.

    However, if you wish to position the pane by a specified offset to the
    right or below the anchor using the values of `preferMatrix` as an offset
    configuration, you can set `preferType` to one of `SC.PICKER_MENU` or
    `SC.PICKER_FIXED`. These two picker types both use the `preferMatrix` to
    adjust the position of the pane below or to the right of the anchor.

    The difference is that `SC.PICKER_MENU` also uses the `windowPadding`
    value to ensure that the pane doesn't go outside the bounds of the visible
    window.

    If you wish to position the pane on whichever side it will best fit and include
    a pointer, then you can use one of `SC.PICKER_POINTER` or `SC.PICKER_MENU_POINTER`
    for `preferType`. With this setting the pane will use the values of
    `preferMatrix` to indicate the preferred side of the anchor for the picker
    to appear.

    The difference between these two is that `SC.PICKER_MENU_POINTER` prefers
    to position below the anchor by default and `SC.PICKER_POINTER` prefers to
    position to the right of the anchor by default. As well, the `SC.PICKER_MENU_POINTER`
    type will resize itself if its height extends outside the visible window
    (which is useful for long menus that can scroll).

    @type String
    @default null
  */
  preferType: null,

  /**
    The configuration value for the current type of picker pane.

    This dual-purpose property controls the positioning of the pane depending
    on what the value of `preferType` is.

    ## Offset based use of `preferMatrix`

    For `preferType` of `SC.PICKER_MENU` or `SC.PICKER_FIXED`, `preferMatrix`
    determines the x and y offset of the pane from either the right or bottom
    side of the anchor. In this case, the `preferMatrix` should be an array of,

        [*x offset*, *y offset*, *offset position*]

    For example, to position the pane 10px directly below the anchor, we would
    use,

        preferMatrix: [0, 10, SC.POSITION_BOTTOM]

    To position the pane 10px down and 5px right of the anchor's right side,
    we would use,

        preferMatrix: [5, 10, SC.POSITION_RIGHT]

    ## Position based use of `preferMatrix`

    For `preferType` of `SC.PICKER_POINTER` or `SC.PICKER_MENU_POINTER`, `preferMatrix`
    determines the side of the anchor to appear on in order of preference.
    In this case, the `preferMatrix` should be an array of,

        [*preferred side*, *2nd preferred side*, *3rd preferred side*, *4th preferred side*, *fallback side if none fit*]

    Note that if the pane can't fit within the window bounds (including `windowPadding`)
    on any of the sides, then the last side is used as a fallback.

    @type Array
    @default preferType == SC.PICKER_MENU || preferType == SC.PICKER_FIXED ? [1, 4, SC.POSITION_BOTTOM] (i.e. [1, 4, 3])
    @default preferType == SC.PICKER_POINTER ? [SC.POSITION_RIGHT, SC.POSITION_LEFT, SC.POSITION_TOP, SC.POSITION_BOTTOM, SC.POSITION_TOP] (i.e. [0, 1, 2, 3, 2])
    @default preferType == SC.PICKER_MENU_POINTER ? [SC.POSITION_BOTTOM, SC.POSITION_RIGHT, SC.POSITION_LEFT, SC.POSITION_TOP, SC.POSITION_BOTTOM] (i.e. [3, 0, 1, 2, 3])
    @default null
  */
  preferMatrix: null,

  /**
    The offset of the pane from its target when positioned with `preferType` of
    `SC.PICKER_POINTER` or `SC.PICKER_MENU_POINTER`.

    When using `SC.PICKER_POINTER` or `SC.PICKER_MENU_POINTER` as the `preferType`,
    the pane will include a pointer element (ex. a small triangle on the side of
    the pane). This also means that the pane will be offset by an additional
    distance in order to make space for the pointer. The offset distance of each
    side is specified by `pointerOffset`.

    Therefore, if you are using a custom picker pane style or you would just
    like to change the default offsets, you should specify your own value like
    so:

        pointerOffset: [*right offset*, *left offset*, *top offset*, *bottom offset*]

    For example,

        // If the pane is to the right of the target, offset 15px further right for a left-side pointer.
        // If the pane is to the left of the target, offset -15px further left for a right-side pointer.
        // If the pane is above the target, offset -30px up for a bottom pointer.
        // If the pane is below the target, offset 20px down for a top pointer.
        pointerOffset: [15, -15, -30, 20]

    @type Array
    @default preferType == SC.PICKER_POINTER ? SC.PickerPane.PICKER_POINTER_OFFSET (i.e. [9, -9, -18, 18])
    @default preferType == SC.PICKER_MENU_POINTER && controlSize == SC.TINY_CONTROL_SIZE ? SC.PickerPane.TINY_PICKER_MENU_POINTER_OFFSET (i.e [9, -9, -18, 18])
    @default preferType == SC.PICKER_MENU_POINTER && controlSize == SC.SMALL_CONTROL_SIZE ? SC.PickerPane.SMALL_PICKER_MENU_POINTER_OFFSET (i.e [9, -9, -8, 8])
    @default preferType == SC.PICKER_MENU_POINTER && controlSize == SC.REGULAR_CONTROL_SIZE ? SC.PickerPane.REGULAR_PICKER_MENU_POINTER_OFFSET (i.e [9, -9, -12, 12])
    @default preferType == SC.PICKER_MENU_POINTER && controlSize == SC.LARGE_CONTROL_SIZE ? SC.PickerPane.LARGE_PICKER_MENU_POINTER_OFFSET (i.e [9, -9, -16, 16])
    @default preferType == SC.PICKER_MENU_POINTER && controlSize == SC.HUGE_CONTROL_SIZE ? SC.PickerPane.HUGE_PICKER_MENU_POINTER_OFFSET (i.e [9, -9, -18, 18])
    @default preferType == SC.PICKER_MENU_POINTER ? SC.PickerPane.REGULAR_PICKER_MENU_POINTER_OFFSET (i.e [9, -9, -12, 12])
  */
  pointerOffset: null,

  /** @deprecated Version 1.10.  Use windowPadding instead.
    default offset of extra-right pointer for picker-pointer or pointer-menu

    @type Number
    @default 0
  */
  extraRightOffset: function () {
    


    return this.get('windowPadding');
  }.property('windowPadding').cacheable(),

  /**
    The target object to invoke the remove action on when the user clicks off the
    picker that is to be removed.

    If you set this target, the action will be called on the target object
    directly when the user clicks off the picker. If you leave this property
    set to null, then the button will search the responder chain for a view that
    implements the action when the button is pressed instead.

    @type Object
    @default null
  */
  removeTarget: null,

  /**
    The name of the action you want triggered when the user clicks off the
    picker pane that is to be removed.

    This property is used in conjunction with the removeTarget property to execute
    a method when the user clicks off the picker pane.

    If you do not set a target, then clicking off the picker pane will cause the
    responder chain to search for a view that implements the action you name
    here, if one was provided.

    Note that this property is optional. If no explicit value is provided then the
    picker pane will perform the default action which is to simply remove itself.

    @type String
    @default null
  */
  removeAction: null,


  /**
    Disable repositioning as the window or size changes. It stays in the original
    popup position.

    @type Boolean
    @default NO
  */
  repositionOnWindowResize: YES,


  /** @private
    Default padding around the window's edge that the pane will not overlap.

    This value is set to the value of SC.PickerPane.WINDOW_PADDING, except when
    using preferType of SC.PICKER_MENU_POINTER, where it will be set according
    to the `controlSize` value of the pane to one of:

      SC.PickerPane.TINY_MENU_WINDOW_PADDING
      SC.PickerPane.SMALL_MENU_WINDOW_PADDING
      SC.PickerPane.REGULAR_MENU_WINDOW_PADDING
      SC.PickerPane.LARGE_MENU_WINDOW_PADDING
      SC.PickerPane.HUGE_MENU_WINDOW_PADDING

    @type Number
    @default SC.PickerPane.WINDOW_PADDING
  */
  windowPadding: null,

  


  /* @private If the pane changes size, reposition as necessary. */
  viewDidResize: function () {
    // Don't forget to call the superclass method.
    arguments.callee.base.apply(this,arguments);

    // Re-position.
    this.positionPane(true);
  },

  /**
    Displays a new picker pane.

    @param {SC.View|HTMLElement} anchorViewOrElement view or element to anchor to
    @param {String} [preferType] apply picker position rule
    @param {Array} [preferMatrix] apply custom offset or position pref matrix for specific preferType
    @param {Number} [pointerOffset]
    @returns {SC.PickerPane} receiver
  */
  popup: function (anchorViewOrElement, preferType, preferMatrix, pointerOffset) {
    this.beginPropertyChanges();
    this.setIfChanged('anchorElement', anchorViewOrElement);
    if (preferType) { this.set('preferType', preferType); }
    if (preferMatrix) { this.set('preferMatrix', preferMatrix); }
    if (pointerOffset) { this.set('pointerOffset', pointerOffset); }
    this.endPropertyChanges();
    this.positionPane();
    this._hideOverflow();

    


    return this.append();
  },

  /** @private
    The ideal position for a picker pane is just below the anchor that
    triggered it + offset of specific preferType. Find that ideal position,
    then call fitPositionToScreen to get final position. If anchor is missing,
    fallback to center.
  */
  positionPane: function (useAnchorCached) {
    var frame = this.get('borderFrame'),
      preferType = this.get('preferType'),
      preferMatrix = this.get('preferMatrix'),
      origin, adjustHash,
      anchor, anchorCached, anchorElement;

    // usually an anchorElement will be passed.  The ideal position is just
    // below the anchor + default or custom offset according to preferType.
    // If that is not possible, fitPositionToScreen will take care of that for
    // other alternative and fallback position.
    anchorCached = this.get('anchorCached');
    anchorElement = this.get('anchorElement');
    if (useAnchorCached && anchorCached) {
      anchor = anchorCached;
    } else if (anchorElement) {
      anchor = this.computeAnchorRect(anchorElement);
      this.set('anchorCached', anchor);
    } // else no anchor to use

    if (anchor) {
      origin = SC.cloneRect(anchor);

      // Adjust the origin for offset based positioning.
      switch (preferType) {
      case SC.PICKER_MENU:
      case SC.PICKER_FIXED:
        if (!preferMatrix || preferMatrix.length !== 3) {
          // default below the anchor with fine-tuned visual alignment
          // for Menu to appear just below the anchorElement.
          this.set('preferMatrix', [1, 4, 3]);
          preferMatrix = this.get('preferMatrix');
        }

        // fine-tuned visual alignment from preferMatrix
        origin.x += ((preferMatrix[2] === 0) ? origin.width : 0) + preferMatrix[0];
        origin.y += ((preferMatrix[2] === 3) ? origin.height : 0) + preferMatrix[1];
        break;
      default:
        origin.y += origin.height;
        break;
      }

      // Since we repeatedly need to know the half-width and half-height of the
      // frames, add those properties.
      anchor.halfWidth = parseInt(anchor.width * 0.5, 0);
      anchor.halfHeight = parseInt(anchor.height * 0.5, 0);

      // Don't pollute the borderFrame rect.
      frame = SC.cloneRect(frame);
      frame.halfWidth = parseInt(frame.width * 0.5, 0);
      frame.halfHeight = parseInt(frame.height * 0.5, 0);

      frame = this.fitPositionToScreen(origin, frame, anchor);

      // Create an adjustment layout from the computed position.
      adjustHash = {
        left: frame.x,
        top: frame.y
      };

      // If the computed position also constrains width or height, add it to the adjustment.
      /*jshint eqnull:true*/
      if (frame.width != null) {
        adjustHash.width = frame.width;
      }

      if (frame.height != null) {
        adjustHash.height = frame.height;
      }

      /*
        Special case behavior for transitions that include scale or rotate: notably SC.View.SCALE_IN and SC.View.POP_IN.

        We make an assumption that the picker should always scale out of the anchor, so we set the
        transform origin accordingly.
      */
      var transitionIn = this.get('transitionIn');
      if (transitionIn && (transitionIn.layoutProperties.indexOf('scale') >= 0 || transitionIn.layoutProperties.indexOf('rotate') >= 0)) {
        var transformOriginX, transformOriginY;

        switch (preferType) {
        // If the picker uses a pointer, set the origin to the pointer.
        case SC.PICKER_POINTER:
        case SC.PICKER_MENU_POINTER:
          switch (this.get('pointerPos')) {
          case 'perfectTop':
            transformOriginX = (frame.halfWidth + this.get('pointerPosX')) / frame.width;
            transformOriginY = 1;
            break;
          case 'perfectRight':
            transformOriginX = 0;
            transformOriginY = (frame.halfHeight + this.get('pointerPosY')) / frame.height;
            break;
          case 'perfectBottom':
            transformOriginX = (frame.halfWidth + this.get('pointerPosX')) / frame.width;
            transformOriginY = 0;
            break;
          case 'perfectLeft':
            transformOriginX = 1;
            transformOriginY = (frame.halfHeight + this.get('pointerPosY')) / frame.height;
            break;
          }
          break;

        // If the picker doesn't use a pointer, set the origin to the correct corner.
        case SC.PICKER_MENU:
        case SC.PICKER_FIXED:
          if (frame.x >= anchor.x) {
            transformOriginX = 0;
          } else {
            transformOriginX = 1;
          }
          if (frame.y >= anchor.y) {
            transformOriginY = 0;
          } else {
            transformOriginY = 1;
          }

          break;
        }

        adjustHash.transformOriginX = transformOriginX;
        adjustHash.transformOriginY = transformOriginY;
      }

      // Adjust.
      this.adjust(adjustHash);

    // if no anchor view has been set for some reason, just center.
    } else {
      this.adjust({
        centerX: 0,
        centerY: 0
      });
    }

    return this;
  },

  /** @private
    This method will return ret (x, y, width, height) from a rectangular element
    Notice: temp hack for calculating visible anchor height by counting height
    up to window bottom only. We do have 'clippingFrame' supported from view.
    But since our anchor can be element, we use this solution for now.
  */
  computeAnchorRect: function (anchor) {
    var bounding, ret, cq,
        wsize = SC.RootResponder.responder.computeWindowSize();
    // Some browsers natively implement getBoundingClientRect, so if it's
    // available we'll use it for speed.
    if (anchor.getBoundingClientRect) {
      // Webkit and Firefox 3.5 will get everything they need by
      // calling getBoundingClientRect()
      bounding = anchor.getBoundingClientRect();
      ret = {
        x:      bounding.left,
        y:      bounding.top,
        width:  bounding.width,
        height: bounding.height
      };
      // If width and height are undefined this means we are in IE or FF < 3.5
      // if we did not get the frame dimensions the do the calculations
      // based on an element
      if (ret.width === undefined || ret.height === undefined) {
        cq = SC.$(anchor);
        ret.width = cq.outerWidth();
        ret.height = cq.outerHeight();
      }
    } else {
      // Only really old versions will have to go through this code path.
      ret   = SC.offset(anchor); // get x & y
      cq    = SC.$(anchor);
      ret.width = cq.outerWidth();
      ret.height = cq.outerHeight();
    }
    ret.height = (wsize.height - ret.y) < ret.height ? (wsize.height - ret.y) : ret.height;

    if (!SC.browser.isIE && window.scrollX > 0 || window.scrollY > 0) {
      ret.x += window.scrollX;
      ret.y += window.scrollY;
    } else if (SC.browser.isIE && (document.documentElement.scrollTop > 0 || document.documentElement.scrollLeft > 0)) {
      ret.x += document.documentElement.scrollLeft;
      ret.y += document.documentElement.scrollTop;
    }
    return ret;
  },

  /** @private
    This method will dispatch to the correct re-position rule according to preferType
  */
  fitPositionToScreen: function (preferredPosition, frame, anchorFrame) {
    var windowSize = SC.RootResponder.responder.computeWindowSize(),
        windowFrame = { x: 0, y: 0, width: windowSize.width, height: windowSize.height };

    // if window size is smaller than the minimum size of app, use minimum size.
    var mainPane = SC.RootResponder.responder.mainPane;
    if (mainPane) {
      var minWidth = mainPane.layout.minWidth,
          minHeight = mainPane.layout.minHeight;

      if (minWidth && windowFrame.width < minWidth) {
        windowFrame.width = mainPane.layout.minWidth;
      }

      if (minHeight && windowFrame.height < minHeight) {
        windowFrame.height = mainPane.layout.minHeight;
      }
    }

    frame.x = preferredPosition.x;
    frame.y = preferredPosition.y;

    var preferType = this.get('preferType');
    if (preferType) {
      switch (preferType) {
      case SC.PICKER_MENU:
        // apply menu re-position rule
        frame = this.fitPositionToScreenMenu(windowFrame, frame, this.get('isSubMenu'));
        break;
      case SC.PICKER_MENU_POINTER:
        this.setupPointer(anchorFrame);
        frame = this.fitPositionToScreenMenuPointer(windowFrame, frame, anchorFrame);
        break;
      case SC.PICKER_POINTER:
        // apply pointer re-position rule
        this.setupPointer(anchorFrame);
        frame = this.fitPositionToScreenPointer(windowFrame, frame, anchorFrame);
        break;
      case SC.PICKER_FIXED:
        // skip fitPositionToScreen
        break;
      default:
        break;
      }
    } else {
      // apply default re-position rule
      frame = this.fitPositionToScreenDefault(windowFrame, frame, anchorFrame);
    }

    return frame;
  },

  /** @private
    re-position rule migrated from old SC.OverlayPaneView.
    shift x, y to optimized picker visibility and make sure top-left corner is always visible.
  */
  fitPositionToScreenDefault: function (windowFrame, frame, anchorFrame) {
    var maximum;

    // make sure the right edge fits on the screen.  If not, anchor to
    // right edge of anchor or right edge of window, whichever is closer.
    if (SC.maxX(frame) > windowFrame.width) {
      maximum = Math.max(SC.maxX(anchorFrame), frame.width);
      frame.x = Math.min(maximum, windowFrame.width) - frame.width;
    }

    // if the left edge is off of the screen, try to position at left edge
    // of anchor.  If that pushes right edge off screen, shift back until
    // right is on screen or left = 0
    if (SC.minX(frame) < 0) {
      frame.x = SC.minX(Math.max(anchorFrame, 0));
      if (SC.maxX(frame) > windowFrame.width) {
        frame.x = Math.max(0, windowFrame.width - frame.width);
      }
    }

    // make sure bottom edge fits on screen.  If not, try to anchor to top
    // of anchor or bottom edge of screen.
    if (SC.maxY(frame) > windowFrame.height) {
      maximum = Math.max((anchorFrame.y - frame.height), 0);
      if (maximum > windowFrame.height) {
        frame.y = Math.max(0, windowFrame.height - frame.height);
      } else { frame.y = maximum; }
    }

    // if top edge is off screen, try to anchor to bottom of anchor. If that
    // pushes off bottom edge, shift up until it is back on screen or top =0
    if (SC.minY(frame) < 0) {
      maximum = Math.min(SC.maxY(anchorFrame), (windowFrame.height - anchorFrame.height));
      frame.y = Math.max(maximum, 0);
    }

    return frame;
  },

  /** @private
    Reposition the pane in a way that is optimized for menus.

    Specifically, we want to ensure that the pane is at least 7 pixels from
    the left side of the screen, and 20 pixels from the right side.

    If the menu is a submenu, we also want to reposition the pane to the left
    of the parent menu if it would otherwise exceed the width of the viewport.
  */
  fitPositionToScreenMenu: function (windowFrame, frame, subMenu) {
    var windowPadding = this.get('windowPadding');

    // Set up init location for submenu
    if (subMenu) {
      frame.x -= this.get('submenuOffsetX');
      frame.y -= Math.floor(this.get('menuHeightPadding') / 2);
    }

    // Make sure we are at least the window padding from the left edge of the screen to start.
    if (frame.x < windowPadding) {
      frame.x = windowPadding;
    }

    // If the right edge of the pane is within the window padding of the right edge
    // of the window, we need to reposition it.
    if ((frame.x + frame.width + windowPadding) > windowFrame.width) {
      if (subMenu) {
        // Submenus should be re-anchored to the left of the parent menu
        frame.x = frame.x - (frame.width * 2);
      } else {
        // Otherwise, just shift the pane windowPadding pixels from the right edge
        frame.x = windowFrame.width - frame.width - windowPadding;
      }
    }

    // Make sure we are at least the window padding from the top edge of the screen to start.
    if (frame.y < windowPadding) {
      frame.y = windowPadding;
    }

    // If the height of the menu is bigger than the window height, shift it upward.
    if (frame.y + frame.height + windowPadding > windowFrame.height) {
      frame.y = Math.max(windowPadding, windowFrame.height - frame.height - windowPadding);
    }

    // If the height of the menu is still bigger than the window height, resize it.
    if (frame.y + frame.height + windowPadding > windowFrame.height) {
      frame.height = windowFrame.height - (2 * windowPadding);
    }

    return frame;
  },

  /** @private
    Reposition the pane in a way that is optimized for menus that have a
    point element.

    This simply calls fitPositionToScreenPointer, then ensures that the menu
    does not exceed the height of the viewport.

    @returns {Rect}
  */
  fitPositionToScreenMenuPointer: function (windowFrame, frame, anchorFrame) {
    frame = this.fitPositionToScreenPointer(windowFrame, frame, anchorFrame);

    // If the height of the menu is bigger than the window height, resize it.
    if (frame.height + frame.y + 35 >= windowFrame.height) {
      frame.height = windowFrame.height - frame.y - (SC.MenuPane.VERTICAL_OFFSET * 2);
    }

    return frame;
  },

  /** @private
    re-position rule for triangle pointer picker.
  */
  fitPositionToScreenPointer: function (windowFrame, frame, anchorFrame) {
    var curType,
        deltas,
        matrix = this.get('preferMatrix'),
        offset = this.get('pointerOffset'),
        topLefts, botRights,
        windowPadding = this.get('windowPadding');

    // Determine the top-left corner of each of the 4 perfectly positioned
    // frames, while taking the pointer offset into account.
    topLefts = [
      // Top left [x, y] if positioned evenly to the right of the anchor
      [anchorFrame.x + anchorFrame.width + offset[0], anchorFrame.y + anchorFrame.halfHeight - frame.halfHeight],

      // Top left [x, y] if positioned evenly to the left of the anchor
      [anchorFrame.x - frame.width + offset[1], anchorFrame.y + anchorFrame.halfHeight - frame.halfHeight],

      // Top left [x, y] if positioned evenly above the anchor
      [anchorFrame.x + anchorFrame.halfWidth - frame.halfWidth, anchorFrame.y - frame.height + offset[2]],

      // Top left [x, y] if positioned evenly below the anchor
      [anchorFrame.x + anchorFrame.halfWidth - frame.halfWidth, anchorFrame.y + anchorFrame.height + offset[3]]
    ];

    // Determine the bottom-right corner of each of the 4 perfectly positioned
    // frames, while taking the pointer offset into account.
    botRights = [
      // Bottom right [x, y] if positioned evenly to the right of the anchor
      [anchorFrame.x + anchorFrame.width + frame.width + offset[0], anchorFrame.y + anchorFrame.halfHeight + frame.halfHeight],

      // Bottom right [x, y] if positioned evenly to the left of the anchor
      [anchorFrame.x + offset[1], anchorFrame.y + anchorFrame.halfHeight + frame.halfHeight],

      // Bottom right [x, y] if positioned evenly above the anchor
      [anchorFrame.x + anchorFrame.halfWidth + frame.halfWidth, anchorFrame.y + offset[2]],

      // Bottom right [x, y] if positioned evenly below the anchor
      [anchorFrame.x + anchorFrame.halfWidth + frame.halfWidth, anchorFrame.y + anchorFrame.height + frame.height + offset[3]]
    ];

    // Loop through the preferred matrix, hopefully finding one that will fit
    // perfectly.
    for (var i = 0, pointerLen = this._sc_pointerLayout.length; i < pointerLen; i++) {
      // The current preferred side.
      curType = matrix[i];

      // Determine if any of the sides of the pane would go beyond the window's
      // edge for each of the 4 perfectly positioned frames; taking the amount
      // of windowPadding into account.  This is done by measuring the distance
      // from each side of the frame to the side of the window.  If the distance
      // is negative then the edge is overlapping.
      //
      // If a perfect position has no overlapping edges, then it is a viable
      // option for positioning.
      deltas = {
        top: topLefts[curType][1] - windowPadding,
        right: windowFrame.width - windowPadding - botRights[curType][0],
        bottom: windowFrame.height - windowPadding - botRights[curType][1],
        left: topLefts[curType][0] - windowPadding
      };

      // UNUSED.  It would be nice to get the picker as close as possible.
      // Cache the fallback deltas.
      // if (curType === matrix[4]) {
      //   fallbackDeltas = deltas;
      // }

      // If no edges overflow, then use this layout.
      if (deltas.top >= 0 &&
          deltas.right >= 0 &&
          deltas.bottom >= 0 &&
          deltas.left >= 0) {

        frame.x = topLefts[curType][0];
        frame.y = topLefts[curType][1];

        this.set('pointerPosX', 0);
        this.set('pointerPosY', 0);
        this.set('pointerPos', this._sc_pointerLayout[curType]);

        break;

      // If we prefer right or left and can fit right or left respectively, but
      // can't fit the top within the window top and padding, then check if by
      // adjusting the top of the pane down if it would still be beside the
      // anchor and still above the bottom of the window with padding.
      } else if (((curType === 0 && deltas.right >= 0) || // Right fits for preferred right
                 (curType === 1 &&  deltas.left >= 0)) && // or left fits for preferred left,
                 deltas.top < 0 && // but top doesn't fit,
                 deltas.top + frame.halfHeight >= 0) {  // yet it could.

        // Adjust the pane position by the amount of downward shifting.
        frame.x = topLefts[curType][0];
        frame.y = topLefts[curType][1] - deltas.top;

        // Offset the pointer position by the opposite amount of downward
        // shifting (minus half the height of the pointer).
        this.set('pointerPosX', 0);
        this.set('pointerPosY', deltas.top);
        this.set('pointerPos', this._sc_pointerLayout[curType]);
        break;

      // If we prefer right or left and can fit right or left respectively, but
      // can't fit the bottom within the window bottom and padding, then check
      // if by adjusting the top of the pane up if it would still be beside the
      // anchor and still below the top of the window with padding.
      } else if (((curType === 0 && deltas.right >= 0) || // Right fits for preferred right
                 (curType === 1 &&  deltas.left >= 0)) && // or left fits for preferred left,
                 deltas.bottom < 0 && // but bottom doesn't fit,
                 deltas.bottom + frame.halfHeight >= 0) {  // yet it could.

        // Adjust the pane position by the amount of upward shifting.
        frame.x = topLefts[curType][0];
        frame.y = topLefts[curType][1] + deltas.bottom;

        // Offset the pointer position by the opposite amount of upward
        // shifting (minus half the height of the pointer).
        this.set('pointerPosX', 0);
        this.set('pointerPosY', Math.abs(deltas.bottom));
        this.set('pointerPos', this._sc_pointerLayout[curType]);
        break;

      // If we prefer top or bottom and can fit top or bottom respectively, but
      // can't fit the right side within the window right side plus padding,
      // then check if by adjusting the pane leftwards to fit if it would still
      // be beside the anchor and still fit within the left side of the window
      // with padding.
      } else if (((curType === 2 && deltas.top >= 0) || // Top fits for preferred top
                 (curType === 3 &&  deltas.bottom >= 0)) && // or bottom fits for preferred bottom,
                 deltas.right < 0 && // but right doesn't fit,
                 deltas.right + frame.halfWidth >= 0) {  // yet it could.

        // Adjust the pane position by the amount of leftward shifting.
        frame.x = topLefts[curType][0] + deltas.right;
        frame.y = topLefts[curType][1];

        // Offset the pointer position by the opposite amount of leftward
        // shifting (minus half the width of the pointer).
        this.set('pointerPosX', Math.abs(deltas.right));
        this.set('pointerPosY', 0);
        this.set('pointerPos', this._sc_pointerLayout[curType]);
        break;

      // If we prefer top or bottom and can fit top or bottom respectively, but
      // can't fit the left side within the window left side plus padding,
      // then check if by adjusting the pane rightwards to fit if it would still
      // be beside the anchor and still fit within the right side of the window
      // with padding.
      } else if (((curType === 2 && deltas.top >= 0) || // Top fits for preferred top
                 (curType === 3 &&  deltas.bottom >= 0)) && // or bottom fits for preferred bottom,
                 deltas.left < 0 && // but left doesn't fit,
                 deltas.left + frame.halfWidth >= 0) {  // yet it could.

        // Adjust the pane position by the amount of leftward shifting.
        frame.x = topLefts[curType][0] - deltas.left;
        frame.y = topLefts[curType][1];

        // Offset the pointer position by the opposite amount of leftward
        // shifting (minus half the width of the pointer).
        this.set('pointerPosX', deltas.left);
        this.set('pointerPosY', 0);
        this.set('pointerPos', this._sc_pointerLayout[curType]);
        break;
      }

    }

    // If no arrangement was found to fit, then use the fall back preferred type.
    if (i === pointerLen) {
      if (matrix[4] === -1) {
        frame.x = anchorFrame.x + anchorFrame.halfWidth;
        frame.y = anchorFrame.y + anchorFrame.halfHeight - frame.halfHeight;

        this.set('pointerPos', this._sc_pointerLayout[0] + ' fallback');
        this.set('pointerPosY', frame.halfHeight - 40);
      } else {
        frame.x = topLefts[matrix[4]][0];
        frame.y = topLefts[matrix[4]][1];

        this.set('pointerPos', this._sc_pointerLayout[matrix[4]]);
        this.set('pointerPosY', 0);
      }

      this.set('pointerPosX', 0);
    }

    this.invokeLast(this._adjustPointerPosition);

    return frame;
  },

  /** @private Measure the pointer element and adjust it by the determined offset. */
  _adjustPointerPosition: function () {
    var pointer = this.$('.sc-pointer'),
      pointerPos = this.get('pointerPos'),
      marginLeft,
      marginTop;

    switch (pointerPos) {
    case 'perfectRight':
    case 'perfectLeft':
      marginTop = -Math.round(pointer.outerHeight() / 2);
      marginTop += this.get('pointerPosY');
      pointer.attr('style', "margin-top: " + marginTop + "px");
      break;
    case 'perfectTop':
    case 'perfectBottom':
      marginLeft = -Math.round(pointer.outerWidth() / 2);
      marginLeft += this.get('pointerPosX');
      pointer.attr('style', "margin-left: " + marginLeft + "px;");
      break;
    }
  },

  /** @private
    This method will set up pointerOffset and preferMatrix according to type
    and size if not provided explicitly.
  */
  setupPointer: function (a) {
    var pointerOffset = this.get('pointerOffset'),
        K = SC.PickerPane;

    // Set windowPadding and pointerOffset (SC.PICKER_MENU_POINTER only).
    if (!pointerOffset || pointerOffset.length !== 4) {
      if (this.get('preferType') === SC.PICKER_MENU || this.get('preferType') === SC.PICKER_MENU_POINTER) {
        switch (this.get('controlSize')) {
        case SC.TINY_CONTROL_SIZE:
          this.set('pointerOffset', K.TINY_PICKER_MENU_POINTER_OFFSET);
          this.set('windowPadding', K.TINY_MENU_WINDOW_PADDING);
          break;
        case SC.SMALL_CONTROL_SIZE:
          this.set('pointerOffset', K.SMALL_PICKER_MENU_POINTER_OFFSET);
          this.set('windowPadding', K.SMALL_MENU_WINDOW_PADDING);
          break;
        case SC.REGULAR_CONTROL_SIZE:
          this.set('pointerOffset', K.REGULAR_PICKER_MENU_POINTER_OFFSET);
          this.set('windowPadding', K.REGULAR_MENU_WINDOW_PADDING);
          break;
        case SC.LARGE_CONTROL_SIZE:
          this.set('pointerOffset', K.LARGE_PICKER_MENU_POINTER_OFFSET);
          this.set('windowPadding', K.LARGE_MENU_WINDOW_PADDING);
          break;
        case SC.HUGE_CONTROL_SIZE:
          this.set('pointerOffset', K.HUGE_PICKER_MENU_POINTER_OFFSET);
          this.set('windowPadding', K.HUGE_MENU_WINDOW_PADDING);
          break;
        default:
          this.set('pointerOffset', K.REGULAR_PICKER_MENU_POINTER_OFFSET);
          this.set('windowPadding', K.REGULAR_MENU_WINDOW_PADDING);
          

        }
      } else {
        var overlapTuningX = (a.width < 16)  ? ((a.width < 4)  ? 9 : 6) : 0,
            overlapTuningY = (a.height < 16) ? ((a.height < 4) ? 9 : 6) : 0,
            offsetKey      = K.PICKER_POINTER_OFFSET;

        var offset = [offsetKey[0] + overlapTuningX,
                      offsetKey[1] - overlapTuningX,
                      offsetKey[2] - overlapTuningY,
                      offsetKey[3] + overlapTuningY];

        this.set('pointerOffset', offset);
      }
    }

    // set up preferMatrix according to type if not provided explicitly:
    // take default [0, 1, 2, 3, 2] for picker, [3, 0, 1, 2, 3] for menu picker if
    // custom matrix not provided explicitly
    var preferMatrix = this.get('preferMatrix');
    if (!preferMatrix || preferMatrix.length !== 5) {
      // menu-picker default re-position rule :
      // perfect bottom (3) > perfect right (0) > perfect left (1) > perfect top (2)
      // fallback to perfect bottom (3)
      // picker default re-position rule :
      // perfect right (0) > perfect left (1) > perfect top (2) > perfect bottom (3)
      // fallback to perfect top (2)
      this.set('preferMatrix', this.get('preferType') === SC.PICKER_MENU_POINTER ? [3, 2, 1, 0, 3] : [0, 1, 2, 3, 2]);
    }
  },

  /**
    @type Array
    @default ['pointerPos']
    @see SC.View#displayProperties
  */
  displayProperties: ['pointerPos'],

  /**
    @type String
    @default 'pickerRenderDelegate'
  */
  renderDelegateName: 'pickerRenderDelegate',

  /** @private - click away picker. */
  modalPaneDidClick: function (evt) {
    var f = this.get('frame'),
        target = this.get('removeTarget') || null,
        action = this.get('removeAction'),
        rootResponder = this.get('rootResponder');

    if (!this.clickInside(f, evt)) {
      // We're not in the Pane so we must be in the modal
      if (action) {
        rootResponder.sendAction(action, target, this, this, null, this);
      } else {
        this.remove();
      }

      return YES;
    }

    return NO;
  },

  /** @private */
  mouseDown: function (evt) {
    return this.modalPaneDidClick(evt);
  },

  /** @private
    internal method to define the range for clicking inside so the picker
    won't be clicked away default is the range of contentView frame.
    Over-write for adjustments. ex: shadow
  */
  clickInside: function (frame, evt) {
    return SC.pointInRect({ x: evt.pageX, y: evt.pageY }, frame);
  },

  /**
    Invoked by the root responder. Re-position picker whenever the window resizes.
  */
  windowSizeDidChange: function (oldSize, newSize) {
    arguments.callee.base.apply(this,arguments);

    if (this.repositionOnWindowResize) {
      // Do this in the next run loop. This ensures that positionPane is only called once even if scroll view
      // offsets are changing at the same time as the window is resizing (see _scrollOffsetDidChange below).
      this.invokeNext(this.positionPane);
    }
  },

  remove: function () {
    if (this.get('isVisibleInWindow')) {
      this._withdrawOverflowRequest();
    }
    this._removeScrollObservers();

    return arguments.callee.base.apply(this,arguments);
  },

  /** @private
    Internal method to hide the overflow on the body to make sure we don't
    show scrollbars when the picker has shadows, as it's really annoying.
  */
  _hideOverflow: function () {
    var main = SC.$('.sc-main'),
        minWidth = parseInt(main.css('minWidth'), 0),
        minHeight = parseInt(main.css('minHeight'), 0),
        windowSize = SC.RootResponder.responder.get('currentWindowSize');

    if (windowSize.width >= minWidth && windowSize.height >= minHeight) {
      SC.bodyOverflowArbitrator.requestHidden(this);
    }
  },

  /** @private
    Internal method to show the overflow on the body to make sure we don't
    show scrollbars when the picker has shadows, as it's really annoying.
  */
  _withdrawOverflowRequest: function () {
    SC.bodyOverflowArbitrator.withdrawRequest(this);
  },

  /** @private
    Detect if view is inside a scroll view. Do this by traversing parent view
    hierarchy until you hit a scroll view or main pane.
  */
  _getScrollViewOfView: function (view) {
    var curLevel = view;
    while (curLevel) {
      if (curLevel.isScrollable) {
        break;
      }

      curLevel = curLevel.get('parentView');
    }

    return curLevel;
  },

  /** @private
    If anchor view is in a scroll view, setup observers on scroll offsets.
  */
  _setupScrollObservers: function (anchorView) {
    var scrollView = this._getScrollViewOfView(anchorView);
    if (scrollView) {
      scrollView.addObserver('canScrollHorizontal', this, this._scrollCanScrollHorizontalDidChange);
      scrollView.addObserver('canScrollVertical', this, this._scrollCanScrollVerticalDidChange);

      // Fire the observers once to initialize them.
      this._scrollCanScrollHorizontalDidChange(scrollView);
      this._scrollCanScrollVerticalDidChange(scrollView);

      this._scrollView = scrollView;
    }
  },

  /** @private Modify horizontalScrollOffset observer. */
  _scrollCanScrollHorizontalDidChange: function (scrollView) {
    if (scrollView.get('canScrollHorizontal')) {
      scrollView.addObserver('horizontalScrollOffset', this, this._scrollOffsetDidChange);
    } else {
      scrollView.removeObserver('horizontalScrollOffset', this, this._scrollOffsetDidChange);
    }
  },

  /** @private Modify verticalScrollOffset observer. */
  _scrollCanScrollVerticalDidChange: function (scrollView) {
    if (scrollView.get('canScrollVertical')) {
      scrollView.addObserver('verticalScrollOffset', this, this._scrollOffsetDidChange);
    } else {
      scrollView.removeObserver('verticalScrollOffset', this, this._scrollOffsetDidChange);
    }
  },

  /** @private Teardown observers setup in _setupScrollObservers. */
  _removeScrollObservers: function () {
    var scrollView = this._scrollView;
    if (scrollView) {
      scrollView.removeObserver('canScrollHorizontal', this, this._scrollCanScrollHorizontalDidChange);
      scrollView.removeObserver('canScrollVertical', this, this._scrollCanScrollVerticalDidChange);
      scrollView.removeObserver('horizontalScrollOffset', this, this._scrollOffsetDidChange);
      scrollView.removeObserver('verticalScrollOffset', this, this._scrollOffsetDidChange);
    }
  },

  /** @private Reposition pane whenever scroll offsets change. */
  _scrollOffsetDidChange: function () {
    // Filter the observer firing. We don't want to reposition multiple times if both horizontal and vertical
    // scroll offsets are updating.
    // Note: do this *after* the current run loop finishes. This allows the scroll view to scroll to
    // actually move so that the anchor's position is correct before we reposition.
    this.invokeNext(this.positionPane);
  },

  /** @private SC.Object */
  init: function () {
    arguments.callee.base.apply(this,arguments);

    // Set defaults that can only be configured on initialization.
    if (!this.windowPadding) { this.windowPadding = SC.PickerPane.WINDOW_PADDING; }
  },

  /** @private SC.Object */
  destroy: function () {
    this._scrollView = null;
    this._anchorView = null;
    this._anchorHTMLElement = null;
    return arguments.callee.base.apply(this,arguments);
  }

});


/** Class methods. */
SC.PickerPane.mixin( /** @scope SC.PickerPane */ {

  //---------------------------------------------------------------------------
  // Constants
  //

  /** @static */
  WINDOW_PADDING: 20,

  /** @static */
  TINY_MENU_WINDOW_PADDING: 12,

  /** @static */
  SMALL_MENU_WINDOW_PADDING: 11,

  /** @static */
  REGULAR_MENU_WINDOW_PADDING: 12,

  /** @static */
  LARGE_MENU_WINDOW_PADDING: 17,

  /** @static */
  HUGE_MENU_WINDOW_PADDING: 12,

  /** @static */
  PICKER_POINTER_OFFSET: [9, -9, -18, 18],

  /** @static */
  TINY_PICKER_MENU_POINTER_OFFSET: [9, -9, -18, 18],

  /** @static */
  SMALL_PICKER_MENU_POINTER_OFFSET: [9, -9, -8, 8],

  /** @static */
  REGULAR_PICKER_MENU_POINTER_OFFSET: [9, -9, -12, 12],

  /** @static */
  LARGE_PICKER_MENU_POINTER_OFFSET: [9, -9, -16, 16],

  /** @static */
  HUGE_PICKER_MENU_POINTER_OFFSET: [9, -9, -18, 18],

  /** @deprecated Version 1.10.  Use SC.PickerPane.WINDOW_PADDING.
    @static
  */
  PICKER_EXTRA_RIGHT_OFFSET: 20,

  /** @deprecated Version 1.10.  Use SC.PickerPane.TINY_MENU_WINDOW_PADDING.
    @static
  */
  TINY_PICKER_MENU_EXTRA_RIGHT_OFFSET: 12,

  /** @deprecated Version 1.10.  Use SC.PickerPane.SMALL_MENU_WINDOW_PADDING.
    @static
  */
  SMALL_PICKER_MENU_EXTRA_RIGHT_OFFSET: 11,

  /** @deprecated Version 1.10.  Use SC.PickerPane.REGULAR_MENU_WINDOW_PADDING.
    @static
  */
  REGULAR_PICKER_MENU_EXTRA_RIGHT_OFFSET: 12,

  /** @deprecated Version 1.10.  Use SC.PickerPane.LARGE_MENU_WINDOW_PADDING.
    @static
  */
  LARGE_PICKER_MENU_EXTRA_RIGHT_OFFSET: 17,

  /** @deprecated Version 1.10.  Use SC.PickerPane.HUGE_MENU_WINDOW_PADDING.
    @static
  */
  HUGE_PICKER_MENU_EXTRA_RIGHT_OFFSET: 12

});

/* >>>>>>>>>> BEGIN source/views/separator.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


/**
  @class

  Displays a horizontal or vertical separator line.  Simply create one of 
  these views and configure the layout direction and layout frame.
  
  @extends SC.View
  @since SproutCore 1.0
*/
SC.SeparatorView = SC.View.extend(
/** @scope SC.SeparatorView.prototype */ {

  /**
    @type Array
    @default ['sc-separator-view']
    @see SC.View#classNames
  */
  classNames: ['sc-separator-view'],
  
  /**
    @type String
    @default 'span'
    @see SC.View#tagName
  */
  tagName: 'span',

  /** 
    Select the direction of the separator line. Possible values:
    
      - SC.LAYOUT_VERTICAL
      - SC.LAYOUT_HORIZONTAL
    
    @type String
    @default SC.LAYOUT_HORIZONTAL
  */
  layoutDirection: SC.LAYOUT_HORIZONTAL,

  /** @private */
  render: function(context, firstTime) {
    if(firstTime) context.push('<span></span>');
    context.addClass(this.get('layoutDirection'));
  }

});

/* >>>>>>>>>> BEGIN source/views/menu_item.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
sc_require('views/separator');


/**
  @class

  An SC.MenuItemView is created for every item in a menu.

  @extends SC.View
  @since SproutCore 1.0
*/
SC.MenuItemView = SC.View.extend(SC.ContentDisplay,
/** @scope SC.MenuItemView.prototype */ {

  /**
    @type Array
    @default ['sc-menu-item']
    @see SC.View#classNames
  */
  classNames: ['sc-menu-item'],

  /**
    @type Array
    @default ['title', 'isEnabled', 'isSeparator', 'isChecked']
    @see SC.View#displayProperties
  */
  displayProperties: ['title', 'toolTip', 'isEnabled', 'icon', 'isSeparator', 'shortcut', 'isChecked'],

  /**
    The WAI-ARIA role for menu items.

    @type String
    @default 'menuitem'
    @readOnly
  */
  ariaRole: 'menuitem',

  /**
    @type Boolean
    @default YES
  */
  escapeHTML: YES,

  /**
    @type Boolean
    @default YES
  */
  acceptsFirstResponder: YES,

  /**
    IE only attribute to block blurring of other controls

    @type Boolean
    @default YES
  */
  blocksIEDeactivate: YES,

  /**
    @type Boolean
    @default NO
  */
  isContextMenuEnabled: NO,


  // ..........................................................
  // KEY PROPERTIES
  //

  /**
    The content object the menu view will display.

    @type Object
    @default null
  */
  content: null,

  /**
    The title from the content property.

    @type String
  */
  title: function () {
    var ret = this.getContentProperty('itemTitleKey'),
        localize = this.getPath('parentMenu.localize');

    if (localize && ret) ret = SC.String.loc(ret);

    return ret || '';
  }.property().cacheable(),

  /**
    The value from the content property.

    @type String
  */
  value: function () {
    return this.getContentProperty('itemValueKey');
  }.property().cacheable(),

  /**
    The tooltip from the content property.

    @type String
  */
  toolTip: function () {
    var ret = this.getContentProperty('itemToolTipKey'),
        localize = this.getPath('parentMenu.localize');

    if (localize && ret) ret = SC.String.loc(ret);

    return ret || '';
  }.property().cacheable(),

  /**
    Whether the item is enabled or not.

    @type Boolean
  */
  isEnabled: function () {
    return this.getContentProperty('itemIsEnabledKey') !== NO &&
           this.getContentProperty('itemSeparatorKey') !== YES;
  }.property().cacheable(),

  /**
    The icon from the content property.

    @type String
  */
  icon: function () {
    return this.getContentProperty('itemIconKey');
  }.property().cacheable(),

  /**
    YES if this menu item represents a separator, NO otherwise.

    @type Boolean
  */
  isSeparator: function () {
    return this.getContentProperty('itemSeparatorKey') === YES;
  }.property().cacheable(),

  /**
    The shortcut from the content property.

    @type String
  */
  shortcut: function () {
    return this.getContentProperty('itemShortCutKey');
  }.property().cacheable(),

  /**
    YES if the menu item should include a check next to it.

    @type Boolean
  */
  isChecked: function () {
    return this.getContentProperty('itemCheckboxKey');
  }.property().cacheable(),

  /**
    This menu item's submenu, if it exists.

    @type SC.MenuPane
  */
  subMenu: function () {
    var parentMenu = this.get('parentMenu'),
        menuItems = this.getContentProperty('itemSubMenuKey');

    if (menuItems) {
      if (SC.kindOf(menuItems, SC.MenuPane)) {
        menuItems.set('isModal', NO);
        menuItems.set('isSubMenu', YES);
        menuItems.set('parentMenu', parentMenu);
        return menuItems;
      } else {
        var subMenu = this._subMenu;
        if (subMenu) {
          if (subMenu.get('isAttached')) {
            this.invokeLast('showSubMenu');
          }
          subMenu.remove();
          subMenu.destroy();
        }

        subMenu = this._subMenu = SC.MenuPane.create({
          layout: { width: 200 },
          items: menuItems,
          isModal: NO,
          isSubMenu: YES,
          parentMenu: parentMenu,
          controlSize: parentMenu.get('controlSize'),
          exampleView: parentMenu.get('exampleView')
        });
        return subMenu;
      }
    }

    return null;
  }.property().cacheable(),

  /**
    @type Boolean
    @default NO
  */
  hasSubMenu: function () {
    return !!this.get('subMenu');
  }.property('subMenu').cacheable(),

  /** @private */
  getContentProperty: function (property) {
    var content = this.get('content'),
        menu = this.get('parentMenu');

    if (content && menu) {
      return content.get(menu.get(property));
    }
  },

  /** @private */
  init: function () {
    arguments.callee.base.apply(this,arguments);
    this.contentDidChange();
  },

  /** @private */
  destroy: function () {
    arguments.callee.base.apply(this,arguments);

    var subMenu = this._subMenu;
    if (subMenu) {
      subMenu.destroy();
      this._subMenu = null;
    }
  },

  /** SC.MenuItemView is not able to update itself in place at this time. */
  // TODO: add update: support.
  isReusable: false,

  /** @private
    Fills the passed html-array with strings that can be joined to form the
    innerHTML of the receiver element.  Also populates an array of classNames
    to set on the outer element.

    @param {SC.RenderContext} context
    @param {Boolean} firstTime
    @returns {void}
  */
  render: function (context) {
    var content = this.get('content'),
        val,
        menu = this.get('parentMenu'),
        itemWidth = this.get('itemWidth') || menu.layout.width,
        itemHeight = this.get('itemHeight') || SC.DEFAULT_MENU_ITEM_HEIGHT,
        escapeHTML = this.get('escapeHTML');

    this.set('itemWidth', itemWidth);
    this.set('itemHeight', itemHeight);

    //addressing accessibility
    if (this.get('isSeparator')) {
      //assign the role of separator
      context.setAttr('role', 'separator');
    } else if (this.get('isChecked')) {
      //assign the role of menuitemcheckbox
      context.setAttr('role', 'menuitemcheckbox');
      context.setAttr('aria-checked', true);
    }

    context = context.begin('a').addClass('menu-item');

    if (this.get('isSeparator')) {
      context.push('<span class="separator"></span>');
      context.addClass('disabled');
    } else {
      val = this.get('icon');
      if (val) {
        this.renderImage(context, val);
        context.addClass('has-icon');
      }

      val = this.get('title');
      if (SC.typeOf(val) !== SC.T_STRING) val = val.toString();
      this.renderLabel(context, val);

      val = this.get('toolTip');
      if (SC.typeOf(val) !== SC.T_STRING) val = val.toString();
      if (escapeHTML) {
        val = SC.RenderContext.escapeHTML(val);
      }
      context.setAttr('title', val);

      if (this.get('isChecked')) {
        context.push('<div class="checkbox"></div>');
      }

      if (this.get('hasSubMenu')) {
        this.renderBranch(context);
      }

      val = this.get('shortcut');
      if (val) {
        this.renderShortcut(context, val);
      }
    }

    context = context.end();
  },

  /** @private
   Generates the image used to represent the image icon. override this to
   return your own custom HTML

   @param {SC.RenderContext} context the render context
   @param {String} the source path of the image
   @returns {void}
  */
  renderImage: function (context, image) {
    // get a class name and url to include if relevant

    var url, className;
    if (image && SC.ImageView.valueIsUrl(image)) {
      url = image;
      className = '';
    } else {
      className = image;
      url = SC.BLANK_IMAGE_URL;
    }
    // generate the img element...
    context.begin('img').addClass('image').addClass(className).setAttr('src', url).end();
  },

  /** @private
   Generates the label used to represent the menu item. override this to
   return your own custom HTML

   @param {SC.RenderContext} context the render context
   @param {String} menu item name
   @returns {void}
  */

  renderLabel: function (context, label) {
    if (this.get('escapeHTML')) {
      label = SC.RenderContext.escapeHTML(label);
    }
    context.push("<span class='value ellipsis'>" + label + "</span>");
  },

  /** @private
   Generates the string used to represent the branch arrow. override this to
   return your own custom HTML

   @param {SC.RenderContext} context the render context
   @returns {void}
  */
  renderBranch: function (context) {
    context.push('<span class="has-branch"></span>');
  },

  /** @private
   Generates the string used to represent the short cut keys. override this to
   return your own custom HTML

   @param {SC.RenderContext} context the render context
   @param {String} the shortcut key string to be displayed with menu item name
   @returns {void}
  */
  renderShortcut: function (context, shortcut) {
    context.push('<span class = "shortcut">' + shortcut + '</span>');
  },

  /**
    This method will check whether the current Menu Item is still
    selected and then create a submenu accordingly.
  */
  showSubMenu: function () {
    var subMenu = this.get('subMenu');
    if (subMenu && !subMenu.get('isAttached')) {
      subMenu.set('mouseHasEntered', NO);
      subMenu.popup(this, [0, 0, 0]);
    }

    this._subMenuTimer = null;
  },

  //..........................................
  // Mouse Events Handling
  //

  /** @private */
  mouseUp: function (evt) {
    // SproutCore's event system will deliver the mouseUp event to the view
    // that got the mouseDown event, but for menus we want to track the mouse,
    // so we'll do our own dispatching.
    var targetMenuItem;

    targetMenuItem = this.getPath('parentMenu.rootMenu.targetMenuItem');

    if (targetMenuItem) targetMenuItem.performAction();
    return YES;
  },

  /** @private
    Called on mouse down to send the action to the target.

    This method will start flashing the menu item to indicate to the user that
    their selection has been received, unless disableMenuFlash has been set to
    YES on the menu item.

    @returns {Boolean}
  */
  performAction: function () {
    // Clicking on a disabled menu item should close the menu.
    if (!this.get('isEnabled')) {
      this.getPath('parentMenu.rootMenu').remove();
      return YES;
    }

    // Menus that contain submenus should ignore clicks
    if (this.get('hasSubMenu')) return NO;

    var disableFlash = this.getContentProperty('itemDisableMenuFlashKey'),
        menu;

    if (disableFlash) {
      // Menu flashing has been disabled for this menu item, so perform
      // the action immediately.
      this.sendAction();
    } else {
      // Flash the highlight of the menu item to indicate selection,
      // then actually send the action once its done.
      this._flashCounter = 0;

      // Set a flag on the root menu to indicate that we are in a
      // flashing state. In the flashing state, no other menu items
      // should become selected.
      menu = this.getPath('parentMenu.rootMenu');
      menu._isFlashing = YES;
      this.invokeLater(this.flashHighlight, 25);
      this.invokeLater(this.sendAction, 150);
    }

    return YES;
  },

  /** @private
    Actually sends the action of the menu item to the target.
  */
  sendAction: function () {
    var action = this.getContentProperty('itemActionKey'),
        target = this.getContentProperty('itemTargetKey'),
        rootMenu = this.getPath('parentMenu.rootMenu'),
        responder;

    // Close the menu
    this.getPath('parentMenu.rootMenu').remove();
    // We're no longer flashing
    rootMenu._isFlashing = NO;

    action = (action === undefined) ? rootMenu.get('action') : action;
    target = (target === undefined) ? rootMenu.get('target') : target;

    // Notify the root menu pane that the selection has changed
    rootMenu.set('selectedItem', this.get('content'));

    // Legacy support for actions that are functions
    if (SC.typeOf(action) === SC.T_FUNCTION) {
      action.apply(target, [rootMenu]);
      

    } else {
      responder = this.getPath('pane.rootResponder') || SC.RootResponder.responder;

      if (responder) {
        // Send the action down the responder chain
        responder.sendAction(action, target, rootMenu);
      }
    }

  },

  /** @private
    Toggles the focus class name on the menu item layer to quickly flash the
    highlight. This indicates to the user that a selection has been made.

    This is initially called by performAction(). flashHighlight then keeps
    track of how many flashes have occurred, and calls itself until a maximum
    has been reached.
  */
  flashHighlight: function () {
    var flashCounter = this._flashCounter, layer = this.$();
    if (flashCounter % 2 === 0) {
      layer.addClass('focus');
    } else {
      layer.removeClass('focus');
    }

    if (flashCounter <= 2) {
      this.invokeLater(this.flashHighlight, 50);
      this._flashCounter++;
    }
  },

  /** @private*/
  mouseDown: function (evt) {
    // Accept primary clicks only.
    return evt.which === 1;
  },

  /** @private */
  mouseEntered: function (evt) {
    var menu = this.get('parentMenu'),
        rootMenu = menu.get('rootMenu');

    // Ignore mouse entering if we're in the middle of
    // a menu flash.
    if (rootMenu._isFlashing) return;

    menu.set('mouseHasEntered', YES);
    this.set('mouseHasEntered', YES);
    menu.set('currentMenuItem', this);

    // Become first responder to show highlight
    if (this.get('isEnabled')) {
      this.becomeFirstResponder();
    }

    if (this.get('hasSubMenu')) {
      this._subMenuTimer = this.invokeLater(this.showSubMenu, 100);
    }

    return YES;
  },

  /** @private
    Set the focus based on whether the current menu item is selected or not.
  */
  mouseExited: function (evt) {
    var parentMenu, timer;

    // If we have a submenu, we need to give the user's mouse time to get
    // to the new menu before we remove highlight.
    if (this.get('hasSubMenu')) {
      // If they are exiting the view before we opened the submenu,
      // make sure we don't open it once they've left.
      timer = this._subMenuTimer;
      if (timer) {
        timer.invalidate();
      } else {
        this.invokeLater(this.checkMouseLocation, 100);
      }
    } else {
      parentMenu = this.get('parentMenu');

      if (parentMenu.get('currentMenuItem') === this) {
        parentMenu.set('currentMenuItem', null);
      }
    }

    return YES;
  },

  /** @private */
  touchStart: function (evt) {
    this.mouseEntered(evt);
    return YES;
  },

  /** @private */
  touchEnd: function (evt) {
    return this.mouseUp(evt);
  },

  /** @private */
  touchEntered: function (evt) {
    return this.mouseEntered(evt);
  },

  /** @private */
  touchExited: function (evt) {
    return this.mouseExited(evt);
  },

  /** @private */
  checkMouseLocation: function () {
    var subMenu = this.get('subMenu'), parentMenu = this.get('parentMenu'),
        currentMenuItem, previousMenuItem;

    if (!subMenu.get('mouseHasEntered')) {
      currentMenuItem = parentMenu.get('currentMenuItem');
      if (currentMenuItem === this || currentMenuItem === null) {
        previousMenuItem = parentMenu.get('previousMenuItem');

        if (previousMenuItem) {
          previousMenuItem.resignFirstResponder();
        }
        this.resignFirstResponder();
        subMenu.remove();
      }
    }
  },

  /** @private
    Call the moveUp function on the parent Menu
  */
  moveUp: function (sender, evt) {
    var menu = this.get('parentMenu');
    if (menu) {
      menu.moveUp(this);
    }
    return YES;
  },

  /** @private
    Call the moveDown function on the parent Menu
  */
  moveDown: function (sender, evt) {
    var menu = this.get('parentMenu');
    if (menu) {
      menu.moveDown(this);
    }
    return YES;
  },

  /** @private
    Call the function to create a branch
  */
  moveRight: function (sender, evt) {
    this.showSubMenu();
    return YES;
  },

  /** @private
    Proxies insertText events to the parent menu so items can be selected
    by typing their titles.
  */
  insertText: function (chr, evt) {
    var menu = this.get('parentMenu');
    if (menu) {
      menu.insertText(chr, evt);
    }
  },

  /** @private*/
  keyDown: function (evt) {
    return this.interpretKeyEvents(evt);
  },

  /** @private*/
  keyUp: function (evt) {
    return YES;
  },

  /** @private*/
  cancel: function (evt) {
    this.getPath('parentMenu.rootMenu').remove();
    return YES;
  },

  /** @private*/
  didBecomeFirstResponder: function (responder) {
    if (responder !== this) return;
    var parentMenu = this.get('parentMenu');
    if (parentMenu) {
      parentMenu.set('currentSelectedMenuItem', this);
    }
  },

  /** @private*/
  willLoseFirstResponder: function (responder) {
    if (responder !== this) return;
    var parentMenu = this.get('parentMenu');
    if (parentMenu) {
      parentMenu.set('currentSelectedMenuItem', null);
      parentMenu.set('previousSelectedMenuItem', this);
    }
  },

  /** @private*/
  insertNewline: function (sender, evt) {
    this.mouseUp(evt);
  },

  /**
    Close the parent Menu and remove the focus of the current Selected
    Menu Item
  */
  closeParent: function () {
    this.$().removeClass('focus');
    var menu = this.get('parentMenu');
    if (menu) {
      menu.remove();
    }
  },

  /** @private*/
  clickInside: function (frame, evt) {
    return SC.pointInRect({ x: evt.pageX, y: evt.pageY }, frame);
  },


  // ..........................................................
  // CONTENT OBSERVING
  //

  /** @private
    Add an observer to ensure that we invalidate our cached properties
    whenever the content object’s associated property changes.
  */
  contentDidChange: function () {
    var content    = this.get('content'),
        oldContent = this._content;

    if (content === oldContent) return;

    var f = this.contentPropertyDidChange;
    // remove an observer from the old content if necessary
    if (oldContent  &&  oldContent.removeObserver) oldContent.removeObserver('*', this, f);

    // add observer to new content if necessary.
    this._content = content;
    if (content  &&  content.addObserver) content.addObserver('*', this, f);

    // notify that value did change.
    this.contentPropertyDidChange(content, '*') ;
  }.observes('content'),


  /** @private
    Invalidate our cached property whenever the content object’s associated
    property changes.
  */
  contentPropertyDidChange: function (target, key) {
    // If the key that changed in the content is one of the fields for which
    // we (potentially) cache a value, update our cache.
    var menu = this.get('parentMenu');
    if (!menu) return;

    var mapping           = SC.MenuItemView._contentPropertyToMenuItemPropertyMapping,
        contentProperties = SC.keys(mapping),
        i, len, contentProperty, menuItemProperty;


    // Are we invalidating all keys?
    if (key === '*') {
      for (i = 0, len = contentProperties.length;  i < len;  ++i) {
        contentProperty  = contentProperties[i];
        menuItemProperty = mapping[contentProperty];
        this.notifyPropertyChange(menuItemProperty);
      }
    }
    else {
      for (i = 0, len = contentProperties.length;  i < len;  ++i) {
        contentProperty  = contentProperties[i];
        if (menu.get(contentProperty) === key) {
          menuItemProperty = mapping[contentProperty];
          this.notifyPropertyChange(menuItemProperty);

          // Note:  We won't break here in case the menu is set up to map
          //        multiple properties to the same content key.
        }
      }
    }
  }

});


// ..........................................................
// CLASS PROPERTIES
//

/** @private
  A mapping of the "content property key" keys to the properties we use to
  wrap them.  This hash is used in 'contentPropertyDidChange' to ensure that
  when the content changes a property that is locally cached inside the menu
  item, the cache is properly invalidated.

  Implementor note:  If you add such a cached property, you must add it to
                     this mapping.
*/
SC.MenuItemView._contentPropertyToMenuItemPropertyMapping = {
  itemTitleKey: 'title',
  itemValueKey: 'value',
  itemToolTipKey: 'toolTip',
  itemIsEnabledKey: 'isEnabled',
  itemIconKey: 'icon',
  itemSeparatorKey: 'isSeparator',
  itemShortCutKey: 'shortcut',
  itemCheckboxKey: 'isChecked',
  itemSubMenuKey: 'subMenu'
};

/* >>>>>>>>>> BEGIN source/panes/menu.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2010 Sprout Systems, Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('panes/picker');
sc_require('views/menu_item');

/**
  @class

  `SC.MenuPane` allows you to display a standard menu. Menus appear over other
  panes, and block input to other views until a selection is made or the pane
  is dismissed by clicking outside of its bounds.

  You can create a menu pane and manage it yourself, or you can use the
  `SC.SelectButtonView` and `SC.PopupButtonView` controls to manage the menu for
  you.

  ## Specifying Menu Items

  The menu pane examines the `items` property to determine what menu items
  should be presented to the user.

  In its most simple form, you can provide an array of strings. Every item
  will be converted into a menu item whose title is the string.

  If you need more control over the menu items, such as specifying a keyboard
  shortcut, enabled state, custom height, or submenu, you can provide an array
  of content objects.

  Out of the box, the menu pane has some default keys it uses to get
  information from the objects. For example, to find out the title of the menu
  item, the menu pane will ask your object for its `title` property. If you
  need to change this key, you can set the `itemTitleKey` property on the pane
  itself.

      var menuItems = [
        { title: 'Menu Item', keyEquivalent: 'ctrl_shift_n' },
        { title: 'Checked Menu Item', checkbox: YES, keyEquivalent: 'ctrl_a' },
        { title: 'Selected Menu Item', keyEquivalent: ['backspace', 'delete'] },
        { isSeparator: YES },
        { title: 'Menu Item with Icon', icon: 'inbox', keyEquivalent: 'ctrl_m' },
        { title: 'Menu Item with Icon', icon: 'folder', keyEquivalent: 'ctrl_p' }
      ];

      var menu = SC.MenuPane.create({
        items: menuItems
      });

  ## Observing User Selections

  To determine when a user clicks on a menu item, you can observe the
  `selectedItem` property for changes.

  @extends SC.PickerPane
  @since SproutCore 1.0
*/
SC.MenuPane = SC.PickerPane.extend(
/** @scope SC.MenuPane.prototype */ {

  /** @private Cache of the items array, used for clean up of observers. */
  _sc_menu_items: null,

  /**
    @type Array
    @default ['sc-menu']
    @see SC.View#classNames
  */
  classNames: ['sc-menu'],

  /**
    The WAI-ARIA role for menu pane.

    @type String
    @default 'menu'
    @constant
  */
  ariaRole: 'menu',


  // ..........................................................
  // PROPERTIES
  //

  /**
    The array of items to display. This can be a simple array of strings,
    objects or hashes. If you pass objects or hashes, you can also set the
    various itemKey properties to tell the menu how to extract the information
    it needs.

    @type Array
    @default []
  */
  items: null,

  /**
    The size of the menu. This will set a CSS style on the menu that can be
    used by the current theme to style the appearance of the control. This
    value will also determine the default `itemHeight`, `itemSeparatorHeight`,
    `menuHeightPadding`, and `submenuOffsetX` if you don't explicitly set these
    properties.

    Your theme can override the default values for each control size by specifying
    them in the `menuRenderDelegate`. For example:

        MyTheme.menuRenderDelegate = SC.BaseTheme.menuRenderDelegate.create({
          'sc-tiny-size': {
            itemHeight: 20,
            itemSeparatorHeight: 9,
            menuHeightPadding: 6,
            submenuOffsetX: 2
          }
        });

    Changing the controlSize once the menu is instantiated has no effect.

    @type String
    @default SC.REGULAR_CONTROL_SIZE
  */
  controlSize: SC.REGULAR_CONTROL_SIZE,

  /**
    The height of each menu item, in pixels.

    You can override this on a per-item basis by setting the (by default)
    `height` property on your object.

    If you don't specify a value, the item height will be inferred from
    `controlSize`.

    @type Number
    @default itemHeight from theme if present, or 20.
  */
  itemHeight: SC.propertyFromRenderDelegate('itemHeight', 20),

  /**
    The height of separator menu items.

    You can override this on a per-item basis by setting the (by default)
    `height` property on your object.

    If you don't specify a value, the height of the separator menu items will
    be inferred from `controlSize`.

    @type Number
    @default itemSeparatorHeight from theme, or 9.
  */
  itemSeparatorHeight: SC.propertyFromRenderDelegate('itemSeparatorHeight', 9),

  /**
    The height of the menu pane. This is updated every time menuItemViews
    is recalculated.

    @type Number
    @default 0
    @isReadOnly
  */
  menuHeight: 0,

  /**
    The amount of padding to add to the height of the pane.

    The first menu item is offset by half this amount, and the other half is
    added to the height of the menu, such that a space between the top and the
    bottom is created.

    If you don't specify a value, the padding will be inferred from the
    controlSize.

    @type Number
    @default menuHeightPadding from theme, or 6
  */
  menuHeightPadding: SC.propertyFromRenderDelegate('menuHeightPadding', 6),

  /**
    The amount of offset x while positioning submenu.

    If you don't specify a value, the padding will be inferred from the
    controlSize.

    @type Number
    @default submenuOffsetX from theme, or 2
  */
  submenuOffsetX: SC.propertyFromRenderDelegate('submenuOffsetX', 2),

  /**
    The last menu item to be selected by the user.

    You can place an observer on this property to be notified when the user
    makes a selection.

    @type SC.Object
    @default null
    @isReadOnly
  */
  selectedItem: null,

  /**
    The view class to use when creating new menu item views.

    The menu pane will automatically create an instance of the view class you
    set here for each item in the `items` array. You may provide your own
    subclass for this property to display the customized content.

    @type SC.View
    @default SC.MenuItemView
  */
  exampleView: SC.MenuItemView,

  /**
    The view or element to which the menu will anchor itself.

    When the menu pane is shown, it will remain anchored to the view you
    specify, even if the window is resized. You should specify the anchor as a
    parameter when calling `popup()`, rather than setting it directly.

    @type SC.View
    @isReadOnly
  */
  anchor: null,

  /**
    `YES` if this menu pane was generated by a parent `SC.MenuPane`.

    @type Boolean
    @default NO
    @isReadOnly
  */
  isSubMenu: NO,

  /**
    If true, title of menu items will be escaped to avoid scripting attacks.

    @type Boolean
    @default YES
  */
  escapeHTML: YES,

  /**
    Whether the title of menu items should be localized before display.

    @type Boolean
    @default YES
  */
  localize: YES,

  /**
    Whether or not this menu pane should accept the “current menu pane”
    designation when visible, which is the highest-priority pane when routing
    events.  Generally you want this set to `YES` so that your menu pane can
    intercept keyboard events.

    @type Boolean
    @default YES
  */
  acceptsMenuPane: YES,

  /**
    Disable context menu.

    @type Boolean
    @default NO
  */
  isContextMenuEnabled: NO,


  // ..........................................................
  // METHODS
  //

  /**
    Makes the menu visible and adds it to the HTML document.

    If you provide a view or element as the first parameter, the menu will
    anchor itself to the view, and intelligently reposition itself if the
    contents of the menu exceed the available space.

    @param {SC.View} anchorViewOrElement the view or element to which the menu
    should anchor.
    @param {Array} (preferMatrix) The prefer matrix used to position the pane.
  */
  popup: function (anchorViewOrElement, preferMatrix) {
    this.beginPropertyChanges();
    if (anchorViewOrElement) {
      if (anchorViewOrElement.isView) {
        this._anchorView = anchorViewOrElement;
        this._setupScrollObservers(anchorViewOrElement);
      } else {
        this._anchorHTMLElement = anchorViewOrElement;
      }
    }
   // this.set('anchor',anchorViewOrElement);
    if (preferMatrix) this.set('preferMatrix', preferMatrix);

    // Resize the pane's initial height to fit the height of the menu.
    // Note: SC.PickerPane's positioning code may adjust the height to fit within the window.
    this.adjust('height', this.get('menuHeight'));
    this.positionPane();

    // Because panes themselves do not receive key events, we need to set the
    // pane's defaultResponder to itself. This way key events can be
    // interpreted in keyUp.
    this.set('defaultResponder', this);
    this.endPropertyChanges();

    // Prevent body overflow (we don't want to overflow because of shadows).
    SC.bodyOverflowArbitrator.requestHidden(this, true);

    


    this.append();
  },

  // ..........................................................
  // ITEM KEYS
  //

  /**
    The name of the property that contains the title for each item.

    @type String
    @default "title"
    @commonTask Menu Item Properties
  */
  itemTitleKey: 'title',

  /**
    The name of the property that contains the value for each item.

    @type String
    @default "value"
    @commonTask Menu Item Properties
  */
  itemValueKey: 'value',

  /**
    The name of the property that contains the tooltip for each item.

    @type String
    @default "toolTip"
    @commonTask Menu Item Properties
  */
  itemToolTipKey: 'toolTip',

  /**
    The name of the property that determines whether the item is enabled.

    @type String
    @default "isEnabled"
    @commonTask Menu Item Properties
  */
  itemIsEnabledKey: 'isEnabled',

  /**
    The name of the property that contains the icon for each item.

    @type String
    @default "icon"
    @commonTask Menu Item Properties
  */
  itemIconKey: 'icon',

  /**
    The name of the property that contains the height for each item.

    @readOnly
    @type String
    @default "height"
    @commonTask Menu Item Properties
  */
  itemHeightKey: 'height',

  /**
    The name of the property that contains an optional submenu for each item.

    @type String
    @default "subMenu"
    @commonTask Menu Item Properties
  */
  itemSubMenuKey: 'subMenu',

  /**
    The name of the property that determines whether the item is a menu
    separator.

    @type String
    @default "isSeparator"
    @commonTask Menu Item Properties
  */
  itemSeparatorKey: 'isSeparator',

  /**
    The name of the property that contains the target for the action that is
    triggered when the user clicks the menu item.

    Note that this property is ignored if the menu item has a submenu.

    @type String
    @default "target"
    @commonTask Menu Item Properties
  */
  itemTargetKey: 'target',

  /**
    The name of the property that contains the action that is triggered when
    the user clicks the menu item.

    Note that this property is ignored if the menu item has a submenu.

    @type String
    @default "action"
    @commonTask Menu Item Properties
  */
  itemActionKey: 'action',

  /**
    The name of the property that determines whether the menu item should
    display a checkbox.

    @type String
    @default "checkbox"
    @commonTask Menu Item Properties
  */
  itemCheckboxKey: 'checkbox',

  /**
    The name of the property that contains the shortcut to be displayed.

    The shortcut should communicate the keyboard equivalent to the user.

    @type String
    @default "shortcut"
    @commonTask Menu Item Properties
  */
  itemShortCutKey: 'shortcut',

  /**
    The name of the property that contains the key equivalent of the menu
    item.

    The action of the menu item will be fired, and the menu pane's
    `selectedItem` property set to the menu item, if the user presses this
    key combination on the keyboard.

    @type String
    @default "keyEquivalent"
    @commonTask Menu Item Properties
  */
  itemKeyEquivalentKey: 'keyEquivalent',

  /**
    The name of the property that determines whether menu flash should be
    disabled.

    When you click on a menu item, it will flash several times to indicate
    selection to the user. Some browsers block windows from opening outside of
    a mouse event, so you may wish to disable menu flashing if the action of
    the menu item should open a new window.

    @type String
    @default "disableMenuFlash"
    @commonTask Menu Item Properties
  */
  itemDisableMenuFlashKey: 'disableMenuFlash',

  /**
    The name of the property that determines whether layerID should be applied to the item .

    @type String
    @default "layerId"
    @commonTask Menu Item Properties
  */
  itemLayerIdKey: 'layerId',

  /**
    The name of the property that determines whether a unique exampleView should be created for the item .

    @type String
    @default "exampleView"
    @commonTask Menu Item Properties
  */
  itemExampleViewKey: 'exampleView',

  /**
    The array of keys used by SC.MenuItemView when inspecting your menu items
    for display properties.

    @private
    @isReadOnly
    @type Array
  */
  menuItemKeys: ['itemTitleKey', 'itemValueKey', 'itemToolTipKey', 'itemIsEnabledKey', 'itemIconKey', 'itemSeparatorKey', 'itemActionKey', 'itemCheckboxKey', 'itemShortCutKey', 'itemHeightKey', 'itemSubMenuKey', 'itemKeyEquivalentKey', 'itemTargetKey', 'itemLayerIdKey'],

  // ..........................................................
  // DEFAULT PROPERTIES
  //

  /*
    If an item doesn't specify a target, this is used. (Only used if an action is found and is not a function.)

    @type String
    @default null
  */
  target: null,

  /*
    If an item doesn't specify an action, this is used.

    @type String
    @default null
  */
  action: null,

  // ..........................................................
  // INTERNAL PROPERTIES
  //

  /** @private */
  preferType: SC.PICKER_MENU,

  // ..........................................................
  // INTERNAL METHODS
  //

  /** @private */
  init: function () {
    // Initialize the items array.
    if (!this.items) { this.items = []; }

    // An associative array of the shortcut keys. The key is the shortcut in the
    // form 'ctrl_z', and the value is the menu item of the action to trigger.
    this._keyEquivalents = {};

    // Continue initializing now that default values exist.
    arguments.callee.base.apply(this,arguments);

    // Initialize the observer function once.
    this._sc_menu_itemsDidChange();
  },

  displayProperties: ['controlSize'],

  renderDelegateName: 'menuRenderDelegate',

  /**
    Creates the child scroll view, and sets its `contentView` to a new
    view.  This new view is saved and managed by the `SC.MenuPane`,
    and contains the visible menu items.

    @private
    @returns {SC.View} receiver
  */
  createChildViews: function () {
    var scroll, menuView;

    // Create the menu items collection view.
    // TODO: Should this not be an SC.ListView?
    menuView = this._menuView = SC.View.create({
      layout: { height: 0 }
    });

    scroll = this._menuScrollView = this.createChildView(SC.MenuScrollView, {
      controlSize: this.get('controlSize'),
      contentView: menuView
    });

    this.childViews = [scroll];

    return this;
  },

  /**
    Called when the pane is attached.  Takes on menu pane status.

    We don't call `arguments.callee.base.apply(this,arguments)` here because `PanelPane` sets the current pane to
    be the key pane when attached.
  */
  didAppendToDocument: function () {
    this.becomeMenuPane();
  },

  /**
    Called when the pane is detached.  Closes all submenus and resigns menu pane
    status.

    We don't call `arguments.callee.base.apply(this,arguments)` here because `PanelPane` resigns key pane when
    detached.
  */
  willRemoveFromDocument: function () {
    var parentMenu = this.get('parentMenu');

    this.set('currentMenuItem', null);
    this.closeOpenMenus();
    this.resignMenuPane();

    if (parentMenu) {
      parentMenu.becomeMenuPane();
    }
  },

  /**
    Make the pane the menu pane. When you call this, all key events will
    temporarily be routed to this pane. Make sure that you call
    resignMenuPane; otherwise all key events will be blocked to other panes.

    @returns {SC.Pane} receiver
  */
  becomeMenuPane: function () {
    if (this.rootResponder) this.rootResponder.makeMenuPane(this);

    return this;
  },

  /**
    Remove the menu pane status from the pane.  This will simply set the
    `menuPane` on the `rootResponder` to `null.

    @returns {SC.Pane} receiver
  */
  resignMenuPane: function () {
    if (this.rootResponder) this.rootResponder.makeMenuPane(null);

    return this;
  },

  /**
    The array of child menu item views that compose the menu.

    This computed property parses `displayItems` and constructs an
    `SC.MenuItemView` (or whatever class you have set as the `exampleView`) for every item.

    This calls createMenuItemViews. If you want to override this property, override
    that method.

    @type
    @type Array
    @readOnly
  */
  menuItemViews: function () {
    return this.createMenuItemViews();
  }.property('displayItems').cacheable(),

  /**
    Processes the displayItems and creates menu item views for each item.

    Override this method to change how menuItemViews is calculated.

    @return Array
  */
  createMenuItemViews: function () {
    var views = [], items = this.get('displayItems'),
        exampleView = this.get('exampleView'), item, itemView, view,
        exampleViewKey, itemExampleView,
        height, heightKey, separatorKey, defaultHeight, separatorHeight,
        menuHeight, menuHeightPadding, keyEquivalentKey, keyEquivalent,
        keyArray, idx, layerIdKey, propertiesHash, escapeHTML,
        len;

    if (!items) return views; // return an empty array

    heightKey = this.get('itemHeightKey');
    separatorKey = this.get('itemSeparatorKey');
    exampleViewKey = this.get('itemExampleViewKey');
    defaultHeight = this.get('itemHeight');
    keyEquivalentKey = this.get('itemKeyEquivalentKey');
    separatorHeight = this.get('itemSeparatorHeight');
    layerIdKey = this.get('itemLayerIdKey');
    escapeHTML = this.get('escapeHTML');
    menuHeightPadding = Math.floor(this.get('menuHeightPadding') / 2);
    menuHeight = menuHeightPadding;

    keyArray = this.menuItemKeys.map(SC._menu_fetchKeys, this);

    len = items.get('length');
    for (idx = 0; idx < len; idx++) {
      item = items[idx];
      height = item.get(heightKey);
      if (!height) {
        height = item.get(separatorKey) ? separatorHeight : defaultHeight;
      }

      propertiesHash = {
        layout: { height: height, top: menuHeight },
        contentDisplayProperties: keyArray,
        content: item,
        parentMenu: this,
        escapeHTML: escapeHTML
      };

      if (item.get(layerIdKey)) {
        propertiesHash.layerId = item.get(layerIdKey);
      }

      // Item has its own exampleView so use it
      itemExampleView = item.get(exampleViewKey);
      if (itemExampleView) {
        itemView = itemExampleView;
      } else {
        itemView = exampleView;
      }

      view = this._menuView.createChildView(itemView, propertiesHash);
      views[idx] = view;
      menuHeight += height;
      keyEquivalent = item.get(keyEquivalentKey);
      if (keyEquivalent) {
        // if array, apply each one for this view
        if (SC.typeOf(keyEquivalent) === SC.T_ARRAY) {
          keyEquivalent.forEach(function (keyEq) {
            this._keyEquivalents[keyEq] = view;
          }, this);
        } else {
          this._keyEquivalents[keyEquivalent] = view;
        }
      }
    }

    this.set('menuHeight', menuHeight + menuHeightPadding);
    return views;
  },

  /**
    Returns the menu item view for the content object at the specified index.

    @param Number idx the item index
    @returns {SC.MenuItemView} instantiated view
  */
  menuItemViewForContentIndex: function (idx) {
    var menuItemViews = this.get('menuItemViews');

    if (!menuItemViews) return undefined;
    return menuItemViews.objectAt(idx);
  },

  /**
    If this is a submenu, this property corresponds to the
    top-most parent menu. If this is the root menu, it returns
    itself.

    @type SC.MenuPane
    @isReadOnly
    @type
  */
  rootMenu: function () {
    if (this.get('isSubMenu')) return this.getPath('parentMenu.rootMenu');
    return this;
  }.property('isSubMenu').cacheable(),

  /** @private @see SC.Object */
  destroy: function () {
    var ret = arguments.callee.base.apply(this,arguments);

    // Clean up previous enumerable observer.
    if (this._sc_menu_items) {
      this._sc_menu_items.removeObserver('[]', this, '_sc_menu_itemPropertiesDidChange');
    }

    // Destroy the menu view we created.  The scroll view's container will NOT
    // destroy this because it receives it already instantiated.
    this._menuView.destroy();

    // Clean up caches.
    this._sc_menu_items = null;
    this._menuView = null;

    return ret;
  },

  /**
    Close the menu if the user resizes the window.

    @private
  */
  windowSizeDidChange: function () {
    this.remove();
    return arguments.callee.base.apply(this,arguments);
  },

  /**
    Returns an array of normalized display items.

    Because the items property can be provided as either an array of strings,
    or an object with key-value pairs, or an exotic mish-mash of both, we need
    to normalize it for our display logic.

    If an `items` member is an object, we can assume it is formatted properly
    and leave it as-is.

    If an `items` member is a string, we create a hash with the title value
    set to that string, and some sensible defaults for the other properties.

    A side effect of running this computed property is that the menuHeight
    property is updated.

    `displayItems` should never be set directly; instead, set `items` and
    `displayItems` will update automatically.

    @type
    @type Array
    @isReadOnly
  */
  displayItems: function () {
    var items = this.get('items'),
      len,
      ret = [], idx, item, itemType;

    if (!items) return null;

    len = items.get('length');

    // Loop through the items property and transmute as needed, then
    // copy the new objects into the ret array.
    for (idx = 0; idx < len; idx++) {
      item = items.objectAt(idx);

      // fast track out if we can't do anything with this item
      if (!item || (!ret.length && item[this.get('itemSeparatorKey')])) continue;

      itemType = SC.typeOf(item);
      if (itemType === SC.T_STRING) {
        item = SC.Object.create({ title: item,
                                  value: item,
                                  isEnabled: YES
                               });
      } else if (itemType === SC.T_HASH) {
        item = SC.Object.create(item);
      }
      item.contentIndex = idx;

      ret.push(item);
    }

    return ret;
  }.property('items').cacheable(),

  /** @private */
  _sc_menu_itemsDidChange: function () {
    var items = this.get('items');

    // Clean up previous enumerable observer.
    if (this._sc_menu_items) {
      this._sc_menu_items.removeObserver('[]', this, '_sc_menu_itemPropertiesDidChange');
    }

    // Add new enumerable observer
    if (items) {
      items.addObserver('[]', this, '_sc_menu_itemPropertiesDidChange');
    }

    // Cache the last items.
    this._sc_menu_items = items;

    var itemViews;
    itemViews = this.get('menuItemViews');
    this._menuView.replaceAllChildren(itemViews);
    this._menuView.adjust('height', this.get('menuHeight'));
  }.observes('items'),

  /** @private */
  _sc_menu_itemPropertiesDidChange: function () {
    // Indicate that the displayItems changed.
    this.notifyPropertyChange('displayItems');

    var itemViews;
    itemViews = this.get('menuItemViews');
    this._menuView.replaceAllChildren(itemViews);
    this._menuView.adjust('height', this.get('menuHeight'));
  },

  currentMenuItem: function (key, value) {
    if (value !== undefined) {
      if (this._currentMenuItem !== null) {
        this.set('previousMenuItem', this._currentMenuItem);
      }
      this._currentMenuItem = value;
      this.setPath('rootMenu.targetMenuItem', value);

      return value;
    }

    return this._currentMenuItem;
  }.property().cacheable(),

  /** @private */
  _sc_menu_currentMenuItemDidChange: function () {
    var currentMenuItem = this.get('currentMenuItem'),
        previousMenuItem = this.get('previousMenuItem');

    if (previousMenuItem) {
      if (previousMenuItem.get('hasSubMenu') && currentMenuItem === null) {

      } else {
        previousMenuItem.resignFirstResponder();
        this.closeOpenMenusFor(previousMenuItem);
      }
    }

    // Scroll to the selected menu item if it's not visible on screen.
    // This is useful for keyboard navigation and programmatically selecting
    // the selected menu item, as in `SelectButtonView`.
    if (currentMenuItem && currentMenuItem.get('isEnabled')) {
      currentMenuItem.scrollToVisible();
    }
  }.observes('currentMenuItem'),

  closeOpenMenusFor: function (menuItem) {
    if (!menuItem) return;

    var menu = menuItem.get('parentMenu');

    // Close any open menus if a root menu changes
    while (menu && menuItem) {
      menu = menuItem.get('subMenu');
      if (menu) {
        menu.remove();
        menuItem.resignFirstResponder();
        menuItem = menu.get('previousMenuItem');
      }
    }
  },

  closeOpenMenus: function () {
    this.closeOpenMenusFor(this.get('previousMenuItem'));
  },

  //Mouse and Key Events

  /** @private */
  mouseDown: function (evt) {
    this.modalPaneDidClick(evt);
    return YES;
  },

  /** @private
    Note when the mouse has entered, so that if this is a submenu,
    the menu item to which it belongs knows whether to maintain its highlight
    or not.

    @param {Event} evt
  */
  mouseEntered: function () {
    this.set('mouseHasEntered', YES);
  },

  keyUp: function (evt) {
    var ret = this.interpretKeyEvents(evt);
    return !ret ? NO : ret;
  },

  /**
    Selects the next enabled menu item above the currently
    selected menu item when the up-arrow key is pressed.

    @private
  */
  moveUp: function () {
    var currentMenuItem = this.get('currentMenuItem'),
        items = this.get('menuItemViews'),
        currentIndex, idx;

    if (!currentMenuItem) {
      idx = items.get('length') - 1;
    } else {
      currentIndex = currentMenuItem.getPath('content.contentIndex');
      if (currentIndex === 0) return YES;
      idx = currentIndex - 1;
    }

    while (idx >= 0) {
      if (items[idx].get('isEnabled')) {
        this.set('currentMenuItem', items[idx]);
        items[idx].becomeFirstResponder();
        break;
      }
      idx--;
    }

    return YES;
  },

  /**
    Selects the next enabled menu item below the currently
    selected menu item when the down-arrow key is pressed.

    @private
  */
  moveDown: function () {
    var currentMenuItem = this.get('currentMenuItem'),
        items = this.get('menuItemViews'),
        len = items.get('length'),
        currentIndex, idx;

    if (!currentMenuItem) {
      idx = 0;
    } else {
      currentIndex = currentMenuItem.getPath('content.contentIndex');
      if (currentIndex === len) return YES;
      idx = currentIndex + 1;
    }

    while (idx < len) {
      if (items[idx].get('isEnabled')) {
        this.set('currentMenuItem', items[idx]);
        items[idx].becomeFirstResponder();
        break;
      }
      idx++;
    }

    return YES;
  },

  /**
    Selects the first enabled menu item when the home key is pressed.

    @private
   */
  moveToBeginningOfDocument: function () {
    var items = this.get('menuItemViews'),
        len = items.get('length'),
        idx = 0;

    while (idx < len) {
      if (items[idx].get('isEnabled')) {
        this.set('currentMenuItem', items[idx]);
        items[idx].becomeFirstResponder();
        break;
      }
      ++idx;
    }

    return YES;
  },

  /**
    Selects the last enabled menu item when the end key is pressed.

    @private
  */
  moveToEndOfDocument: function () {
    var items = this.get('menuItemViews'),
        len = items.get('length'),
        idx = len - 1;

    while (idx >= 0) {
      if (items[idx].get('isEnabled')) {
        this.set('currentMenuItem', items[idx]);
        items[idx].becomeFirstResponder();
        break;
      }
      --idx;
    }

    return YES;
  },

  /**
    Selects the next item one page down. If that is not enabled,
    continues to move down until it finds an enabled item.

    @private
  */
  pageDown: function () {
    var currentMenuItem = this.get('currentMenuItem'),
        item, items = this.get('menuItemViews'),
        len = items.get('length'),
        idx = 0,
        foundItemIdx,
        verticalOffset = 0,
        verticalPageScroll;

    if (this._menuScrollView && this._menuScrollView.bottomScrollerView) {

      if (currentMenuItem) {
        idx = currentMenuItem.getPath('content.contentIndex');
      }

      foundItemIdx = idx;
      verticalPageScroll = this._menuScrollView.get('verticalPageScroll');
      for (idx; idx < len; idx++) {
        item = items[idx];
        verticalOffset += item.get('layout').height;

        if (verticalOffset > verticalPageScroll) {
          // We've gone further than an entire page scroll, so stop.
          break;
        } else {
          // Only accept enabled items (which also excludes separators).
          if (item.get('isEnabled')) { foundItemIdx = idx; }
        }
      }

      item = items[foundItemIdx];
      this.set('currentMenuItem', item);
      item.becomeFirstResponder();
    } else {
      this.moveToEndOfDocument();
    }

    return YES;
  },

  /**
    Selects the previous item one page up. If that is not enabled,
    continues to move up until it finds an enabled item.

    @private
  */
  pageUp: function () {
    var currentMenuItem = this.get('currentMenuItem'),
        item, items = this.get('menuItemViews'),
        len = items.get('length'),
        idx = len - 1,
        foundItemIdx,
        verticalOffset = 0,
        verticalPageScroll;

    if (this._menuScrollView && this._menuScrollView.topScrollerView) {

      if (currentMenuItem) {
        idx = currentMenuItem.getPath('content.contentIndex');
      }

      foundItemIdx = idx;
      verticalPageScroll = this._menuScrollView.get('verticalPageScroll');
      for (idx; idx >= 0; idx--) {
        item = items[idx];
        verticalOffset += item.get('layout').height;

        if (verticalOffset > verticalPageScroll) {
          // We've gone further than an entire page scroll, so stop.
          break;
        } else {
          // Only accept enabled items (which also excludes separators).
          if (item.get('isEnabled')) { foundItemIdx = idx; }
        }
      }

      item = items[foundItemIdx];
      this.set('currentMenuItem', item);
      item.becomeFirstResponder();
    } else {
      this.moveToBeginningOfDocument();
    }

    return YES;
  },

  insertText: function (chr) {
    var timer = this._timer, keyBuffer = this._keyBuffer;

    if (timer) {
      timer.invalidate();
    }
    timer = this._timer = SC.Timer.schedule({
      target: this,
      action: 'clearKeyBuffer',
      interval: 500,
      isPooled: NO
    });

    keyBuffer = keyBuffer || '';
    keyBuffer += chr.toUpperCase();

    this.selectMenuItemForString(keyBuffer);
    this._keyBuffer = keyBuffer;

    return YES;
  },

  /** @private
    Called by the view hierarchy when the menu should respond to a shortcut
    key being pressed.

    Normally, the menu will only respond to key presses when it is visible.
    However, when the menu is part of another control, such as an
    SC.PopupButtonView, the menu should still respond if it is hidden but its
    parent control is visible. In those cases, the parameter
    fromVisibleControl will be set to `YES`.

    @param keyEquivalent {String} the shortcut key sequence that was pressed
    @param fromVisibleControl Boolean if the shortcut key press was proxied
    to this menu by a visible parent control
    @returns Boolean
  */
  performKeyEquivalent: function (keyEquivalent, evt, fromVisibleControl) {
    //If menu is not visible
    if (!fromVisibleControl && !this.get('isVisibleInWindow')) return NO;

    // Look for menu item that has this key equivalent
    var menuItem = this._keyEquivalents[keyEquivalent];

    // If found, have it perform its action
    if (menuItem) {
      menuItem.performAction(YES);
      return YES;
    }

    // If escape key or the enter key was pressed and no menu item handled it,
    // close the menu pane and return YES that the event was handled
    if (keyEquivalent === 'escape' || keyEquivalent === 'return') {
      this.remove();
      return YES;
    }

    return NO;

  },

  selectMenuItemForString: function (buffer) {
    var items = this.get('menuItemViews'), item, title, idx, len, bufferLength;
    if (!items) return;

    bufferLength = buffer.length;
    len = items.get('length');
    for (idx = 0; idx < len; idx++) {
      item = items.objectAt(idx);
      title = item.get('title');

      if (!title) continue;

      title = title.replace(/ /g, '').substr(0, bufferLength).toUpperCase();
      if (title === buffer) {
        this.set('currentMenuItem', item);
        item.becomeFirstResponder();
        break;
      }
    }
  },

  /**
    Clear the key buffer if the user does not enter any text after a certain
    amount of time.

    This is called by the timer created in the `insertText` method.

    @private
  */
  clearKeyBuffer: function () {
    this._keyBuffer = '';
  },

  /**
    Close the menu and any open submenus if the user clicks outside the menu.

    Because only the root-most menu has a modal pane, this will only ever get
    called once.

    @returns Boolean
    @private
  */
  modalPaneDidClick: function () {
    this.remove();

    return YES;
  }
});


/** @private */
SC._menu_fetchKeys = function (k) {
  return this.get(k);
};

/** @private */
SC._menu_fetchItem = function (k) {
  if (!k) return null;
  return this.get ? this.get(k) : this[k];
};


/**
  Default metrics for the different control sizes.
*/
SC.MenuPane.TINY_MENU_ITEM_HEIGHT = 10;
// SC.MenuPane.TINY_MENU_ITEM_SEPARATOR_HEIGHT = 2;
// SC.MenuPane.TINY_MENU_HEIGHT_PADDING = 2;
// SC.MenuPane.TINY_SUBMENU_OFFSET_X = 0;

SC.MenuPane.SMALL_MENU_ITEM_HEIGHT = 16;
// SC.MenuPane.SMALL_MENU_ITEM_SEPARATOR_HEIGHT = 7;
// SC.MenuPane.SMALL_MENU_HEIGHT_PADDING = 4;
// SC.MenuPane.SMALL_SUBMENU_OFFSET_X = 2;

SC.MenuPane.REGULAR_MENU_ITEM_HEIGHT = 22;
// SC.MenuPane.REGULAR_MENU_ITEM_SEPARATOR_HEIGHT = 9;
// SC.MenuPane.REGULAR_MENU_HEIGHT_PADDING = 6;
// SC.MenuPane.REGULAR_SUBMENU_OFFSET_X = 2;

SC.MenuPane.LARGE_MENU_ITEM_HEIGHT = 31;
// SC.MenuPane.LARGE_MENU_ITEM_SEPARATOR_HEIGHT = 20;
// SC.MenuPane.LARGE_MENU_HEIGHT_PADDING = 0;
// SC.MenuPane.LARGE_SUBMENU_OFFSET_X = 4;

SC.MenuPane.HUGE_MENU_ITEM_HEIGHT = 20;
// SC.MenuPane.HUGE_MENU_ITEM_SEPARATOR_HEIGHT = 9;
// SC.MenuPane.HUGE_MENU_HEIGHT_PADDING = 0;
// SC.MenuPane.HUGE_SUBMENU_OFFSET_X = 0;

/* >>>>>>>>>> BEGIN source/panes/sheet.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('panes/panel');

/**
 @class

   Displays a modal sheet pane that animates from the top of the viewport.

 The default way to use the sheet pane is to simply add it to your page like this:

 SC.SheetPane.create({
        layout: { width: 400, height: 200, centerX: 0 },
        contentView: SC.View.extend({
        })
      }).append();

 This will cause your sheet panel to display.  The default layout for a Sheet
 is to cover the entire document window with a semi-opaque background, and to
 resize with the window.

 @extends SC.PanelPane
 @since SproutCore 1.0
 @author Evin Grano
 @author Tom Dale
 @author Joe Gaudet
 */
SC.SheetPane = SC.PanelPane.extend(
  /** @scope SC.SheetPane.prototype */
  {

    /**
     @type {Array}
     @default ['sc-sheet']
     @see SC.View#classNames
     */
    classNames: ['sc-sheet'],

    /**
     @type SC.View
     @default SC.ModalPane
     */
    modalPane: SC.ModalPane,

    /**
     * Duration in seconds
     * @type {Number}
     */
    duration: 0.3,

    /**
     * Timing Function
     *
     * @type {String}
     */
    timing: 'ease-in-out',

    /** @private */
    transitionIn: SC.View.SLIDE_IN,

    /** @private */
    transitionInOptions: function () {
      return {
        direction: 'down',
        duration: this.get('duration'),
        timing: this.get('timing')
      };
    }.property('timing', 'duration').cacheable(),


    /** @private */
    transitionOut: SC.View.SLIDE_OUT,

    /** @private */
    transitionOutOptions: function () {
      return {
        direction: 'up',
        duration: this.get('duration'),
        timing: this.get('timing')
      };
    }.property('timing', 'duration').cacheable()

  });


/* >>>>>>>>>> BEGIN source/render_delegates/button.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


/**
  Renders and updates the HTML representation of a button.
*/
SC.BaseTheme.buttonRenderDelegate = SC.RenderDelegate.create({
  className: 'button',

  //
  // SIZE DEFINITIONS
  //
  'sc-small-size': {
    height: 18,
    autoResizePadding: { width: 15, height: 0 }
  },

  'sc-regular-size': {
    height: 24,
    autoResizePadding: { width: 20, height: 0 }
  },

  'sc-huge-size': {
    height: 30,
    autoResizePadding: { width: 30, height: 0 }
  },

  'sc-jumbo-size': {
    height: 44,
    autoResizePadding: { width: 50, height: 0 }
  },


  //
  // RENDERING LOGIC
  //

  /**
    Called when we need to create the HTML that represents the button.

    @param {SC.Object} dataSource the object containing the information on how to render the button
    @param {SC.RenderContext} context the render context instance
  */
  render: function(dataSource, context) {
    this.addSizeClassName(dataSource, context);

    var toolTip     = dataSource.get('toolTip'),
      isSelected  = dataSource.get('isSelected') || NO,
      isActive    = dataSource.get('isActive') || NO,
      isDefault   = dataSource.get('isDefault') || NO,
      isCancel    = dataSource.get('isCancel') || NO,
      isToggle    = (dataSource.get('buttonBehavior') === SC.TOGGLE_BEHAVIOR),
      labelId     = SC.guidFor(dataSource) + '-label';

    context.setClass({
      'icon': !!dataSource.get('icon'),
      'def':  isDefault,
      'cancel': isCancel && !isDefault,
      'active': isActive,
      'sel': isSelected
    });

    // Set the toolTip.
    if (toolTip) {
      context.setAttr('title', toolTip);
    }

    this.includeSlices(dataSource, context, SC.THREE_SLICE);
    // accessibility
    if(dataSource.get('isSegment')){
      context.setAttr('aria-selected', isSelected.toString());
    }else if(isToggle) {
      context.setAttr('aria-pressed', isActive.toString());
    }

    context.setAttr('aria-labelledby', labelId);

    // Create the inner label element that contains the text and, optionally,
    // an icon.
    context = context.begin('label').addClass('sc-button-label').id(labelId);
    dataSource.get('theme').labelRenderDelegate.render(dataSource, context);
    context = context.end();

    if (dataSource.get('supportFocusRing')) {
      context = context.begin('div').addClass('focus-ring');
      this.includeSlices(dataSource, context, SC.THREE_SLICE);
      context = context.end();
    }
  },

  /**
    Called when one or more display properties have changed and we need to
    update the HTML representation with the new values.

    @param {SC.Object} dataSource the object containing the information on how to render the button
    @param {SC.RenderContext} jquery the jQuery object representing the HTML representation of the button
  */
  update: function(dataSource, jquery) {
    var isToggle = (dataSource.get('buttonBehavior') === SC.TOGGLE_BEHAVIOR),
      isDefault = dataSource.get('isDefault'),
      isCancel = dataSource.get('isCancel'),
      toolTip = dataSource.get('toolTip');

    this.updateSizeClassName(dataSource, jquery);

    if (dataSource.get('isActive')) {
      jquery.addClass('active');
    }

    if (dataSource.get('isSegment')) {
      jquery.attr('aria-selected', dataSource.get('isSelected').toString());
    } else if (isToggle) {
      jquery.attr('aria-pressed', dataSource.get('isActive').toString());
    }

    // Update the toolTip.
    if (toolTip) {
      jquery.attr('title', toolTip);
    } else {
      jquery.removeAttr('title');
    }

    jquery.setClass('icon', !!dataSource.get('icon'));
    jquery.setClass('def', !!isDefault);
    jquery.setClass('cancel', !!isCancel && !isDefault);

    dataSource.get('theme').labelRenderDelegate.update(dataSource, jquery.find('label'));
  },

  /**
    Returns the layer to be used for auto resizing.
  */
  getRenderedAutoResizeLayer: function(dataSource, jq) {
    return jq.find('.sc-button-label')[0];
  }
});

/* >>>>>>>>>> BEGIN source/render_delegates/checkbox.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


/**
  Renders and updates DOM representations of a checkbox (just the box,
  not the title).

  Note: most of the actual rendering is done in CSS. The DOM element provided
  to the checkboxRenderDelegate must have the theme class names and the
  class name 'checkbox' (the name of the render delegate).

  Parameters
  --------------------------
  Expects these properties on the data source:

   - `isSelected`
   - `isActive`
   - `title`

  Optional parameters include all parameters for the `labelRenderDelegate`.

*/
SC.BaseTheme.checkboxRenderDelegate = SC.RenderDelegate.create({
  className: 'checkbox',

  render: function(dataSource, context) {
    this.addSizeClassName(dataSource, context);

    var theme = dataSource.get('theme'),
      labelId;

    // the label id is used so we can set the aria labelledby attribute
    labelId = SC.guidFor(dataSource) + "-label";

    var isSelected = dataSource.get('isSelected') || NO;
    var isActive = dataSource.get('isActive');

    var ariaIsSelected;
    if (isSelected === SC.MIXED_STATE) ariaIsSelected = 'mixed';
    else if (isSelected) ariaIsSelected = 'true';
    else ariaIsSelected = 'false';

    context.setAttr('role', 'checkbox');
    context.setAttr('aria-checked', ariaIsSelected);
    context.setAttr('aria-labelledby', labelId);

    context.setClass({
      'sel': isSelected,
      'active': isActive
    });

    context.push('<span class = "button"></span>');

    context = context.begin('span').addClass('label').id(labelId);
    theme.labelRenderDelegate.render(dataSource, context);
    context = context.end();
  },

  update: function(dataSource, jquery) {
    this.updateSizeClassName(dataSource, jquery);

    var theme = dataSource.get('theme');

    var isSelected = dataSource.get('isSelected');
    var isActive = dataSource.get('isActive');

    var ariaIsSelected;
    if (isSelected === SC.MIXED_STATE) ariaIsSelected = 'mixed';
    else if (isSelected) ariaIsSelected = 'true';
    else ariaIsSelected = 'false';

    // address accessibility
    jquery.attr('aria-checked', ariaIsSelected);

    // NOTE: the other properties were already set in render, and should not
    // need to be changed.

    theme.labelRenderDelegate.update(dataSource, jquery.find('span.label'));

    // add class names
    jquery.setClass({
      'sel': isSelected,
      'active': isActive
    });
  }
});



/* >>>>>>>>>> BEGIN source/render_delegates/collection.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


// collections don't need their own rendering; however, in future, constants
// like the row height will likely be specified on the render delegate.
SC.BaseTheme.collectionRenderDelegate = SC.RenderDelegate.create({
  className: 'collection',

  render: function(dataSource, context) {
    context.setClass('active', dataSource.get('isActive'));
  },

  update: function(dataSource, jquery) {
    jquery.setClass('active', dataSource.get('isActive'));
  }
});

/* >>>>>>>>>> BEGIN source/render_delegates/disclosure.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


SC.BaseTheme.disclosureRenderDelegate = SC.RenderDelegate.create({
  className: 'disclosure',

  render: function(dataSource, context) {
    this.addSizeClassName(dataSource, context);

    var theme = dataSource.get('theme'),
        value = dataSource.get('value'),
        labelClassNames = ['sc-button-label', 'sc-disclosure-label'];

    var labelId = SC.guidFor(dataSource) + "-label";

    //addressing accessibility
    context.setAttr('aria-expanded', value);
    context.setAttr('aria-labelledby', labelId);

    if (dataSource.get('isSelected')) context.addClass('sel');

    var state = '';
    state += dataSource.get('isSelected') ? 'open' : 'closed';
    if (dataSource.get('isActive')) state += ' active';

    context.push('<img src = "' + SC.BLANK_IMAGE_URL + '" class = "disclosure button ' + state + '" />');

    context = context.begin('span').addClass(labelClassNames).id(labelId);
    theme.labelRenderDelegate.render(dataSource, context);
    context = context.end();
  },

  update: function(dataSource, jquery) {
    this.updateSizeClassName(dataSource, jquery);

    var theme = dataSource.get('theme'),
        value = dataSource.get('value');

    //addressing accessibility
    jquery.attr('aria-expanded', value);

    if (dataSource.get('isSelected')) jquery.addClass('sel');

    jquery.find('img').setClass({
      open: dataSource.get('isSelected'),
      closed: !dataSource.get('isSelected'),
      active: dataSource.get('isActive')
    });

    theme.labelRenderDelegate.update(dataSource, jquery.find('span.sc-disclosure-label'));
  }
});


/* >>>>>>>>>> BEGIN source/render_delegates/helpers/slicing.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


SC.THREE_SLICE = ['left', 'middle', 'right'];

SC.NINE_SLICE = [
  'top-left', 'top', 'top-right', 
  'left', 'middle', 'right', 
  'bottom-left', 'bottom', 'bottom-right'
];

SC.RenderDelegate.reopen({
  /*@scope SC.RenderDelegate.prototype*/
  
  /**
    Use this to render slices that you can match in CSS. This matches with the
    Chance @include slices directive, so that you can automatically do 
    multi-slice images for controls.

    @param {SC.Object} dataSource The data source for rendering information.
    @param {SC.RenderContext} context the render context instance
    @param {Slice Configuration} slices Instructions on how to slice. Can be a constant
    like SC.THREE_SLICE or SC.NINE_SLICE, or an array of slice names.
  */
  includeSlices: function(dataSource, context, slices) {
    for (var idx = 0, len = slices.length; idx < len; idx++) {
      context.push('<div class="' + slices[idx] + '"></div>');
    }
  }
});

/* >>>>>>>>>> BEGIN source/render_delegates/image_button.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


SC.BaseTheme.imageButtonRenderDelegate = SC.RenderDelegate.create({
  className: 'image-button',

  render: function (dataSource, context) {
    var image = dataSource.get('image'),
      toolTip = dataSource.get('toolTip');

    // render controlSize
    this.addSizeClassName(dataSource, context);

    if (toolTip) {
      context.setAttr('title', toolTip);
      context.setAttr('alt', toolTip);
    }

    if (image) {
      context.addClass(image);

      // Track the image class used so that we can remove it when it changes.
      dataSource.renderState._cachedImage = image;
    }
  },

  update: function (dataSource, jqElement) {
    var image, toolTip;

    this.updateSizeClassName(dataSource, jqElement);

    if (dataSource.didChangeFor('imageButtonRenderDelegate', 'toolTip')) {
      toolTip = dataSource.get('toolTip');

      jqElement.attr('title', toolTip);
      jqElement.attr('alt', toolTip);
    }

    if (dataSource.didChangeFor('imageButtonRenderDelegate', 'image')) {
      image = dataSource.get('image');

      // Remove the last image class
      if (dataSource.renderState._cachedImage) {
        jqElement.removeClass(dataSource.renderState._cachedImage);
      }

      if (image) {
        jqElement.addClass(image);

        // Track the image class used so that we can remove it when it changes.
        dataSource.renderState._cachedImage = image;
      }
    }
  }
});

/* >>>>>>>>>> BEGIN source/render_delegates/master_detail.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


/**
  Border between the two panes of the MasterDetail.

  Note that the border does *NOT* include any space on the sides. Space
  on left or right sides of MasterDetail, if any, should be handled by
  its layout.
 */
SC.BaseTheme.MASTER_DETAIL_DIVIDER_WIDTH = 1;

SC.BaseTheme.masterDetailRenderDelegate = SC.RenderDelegate.create({
  className: 'master-detail',
  dividerWidth: 1,
  
  render: function(dataSource, context) {
    context.setClass('round-toolbars', SC.platform.touch);
  },
  
  update: function(dataSource, jquery) {
    jquery.setClass('round-toolbars', SC.platform.touch);    
  }
  
});

/* >>>>>>>>>> BEGIN source/render_delegates/panel.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


SC.BaseTheme.panelRenderDelegate = SC.RenderDelegate.create({
  className: 'panel',

  render: function(dataSource, context) {
    context = context.begin('div').addClass('panel-background');
    this.includeSlices(dataSource, context, SC.NINE_SLICE);
    context = context.end();

    var ariaLabel = dataSource.get('ariaLabel'),
        ariaLabelledBy = dataSource.get('ariaLabelledBy'),
        ariaDescribedBy = dataSource.get('ariaDescribedBy');

    if (ariaLabel) context.setAttr('aria-label', ariaLabel);
    if (ariaLabelledBy) context.setAttr('aria-labelledby', ariaLabelledBy);
    if (ariaDescribedBy) context.setAttr('aria-describedby', ariaDescribedBy);
  },

  update: function(dataSource, jQuery) {
    // the label for the panel could change...
    var ariaLabel = dataSource.get('ariaLabel'),
        ariaLabelledBy = dataSource.get('ariaLabelledBy'),
        ariaDescribedBy = dataSource.get('ariaDescribedBy');

    if(ariaLabel) jQuery.attr('aria-label', ariaLabel);
    if(ariaLabelledBy) jQuery.attr('aria-labelledby', ariaLabelledBy);
    if(ariaDescribedBy) jQuery.attr('aria-describedby', ariaDescribedBy);
  }
});

/* >>>>>>>>>> BEGIN source/render_delegates/picker.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('render_delegates/panel');

SC.BaseTheme.pickerRenderDelegate = SC.RenderDelegate.create({
  className: 'picker',

  render: function (dataSource, context) {
    var panelRenderDelegate = dataSource.get('theme').panelRenderDelegate;

    panelRenderDelegate.render(dataSource, context);

    var preferType = dataSource.get('preferType'),
      pointerPosition = dataSource.get('pointerPos');

    if (preferType == SC.PICKER_POINTER || preferType == SC.PICKER_MENU_POINTER) {
      context.push('<div class="sc-pointer ' + pointerPosition + '"></div>');
      context.addClass(pointerPosition);

      // Track the last pointerPosition used so that we can remove it when it changes.
      dataSource.renderState._lastPointerPosition = pointerPosition;
    }
  },

  update: function (dataSource, $) {
    var panelRenderDelegate = dataSource.get('theme').panelRenderDelegate;

    panelRenderDelegate.update(dataSource, $);

    var preferType = dataSource.get('preferType'),
      pointerPosition = dataSource.get('pointerPos');

    if (preferType == SC.PICKER_POINTER || preferType == SC.PICKER_MENU_POINTER) {
      var lastPointerPosition = dataSource.renderState._lastPointerPosition;

      if (lastPointerPosition !== pointerPosition) {
        var el = $.find('.sc-pointer');

        // Totally overwrite the pointer class.
        el.attr('class', "sc-pointer " + pointerPosition);

        // Update the view layer class
        $.removeClass(lastPointerPosition);
        $.addClass(pointerPosition);

        // Track the last pointerPosition used so that we can remove it when it changes.
        dataSource.renderState._lastPointerPosition = pointerPosition;
      }
    }

  }
});

/* >>>>>>>>>> BEGIN source/render_delegates/menu.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('render_delegates/picker');

// This is the same as a pickerRenderDelegate, but is named 'menu' instead.
SC.BaseTheme.menuRenderDelegate = SC.BaseTheme.pickerRenderDelegate.create({
  className: 'menu',

  render: function(orig, dataSource, context) {
    this.addSizeClassName(dataSource, context);
    orig(dataSource, context);
  }.enhance(),

  update: function(orig, dataSource, jquery) {
    this.updateSizeClassName(dataSource, jquery);
    orig(dataSource, jquery);
  }.enhance(),

  // height for items in this menu size
  itemHeight: 20,

  // height of separator items
  itemSeparatorHeight: 9,

  // amount to add to the calculated menu height
  menuHeightPadding: 6,

  // amount to add to any calculated menu width to determine the actual width
  menuWidthPadding: 50,

  minimumMenuWidth: 50,

  submenuOffsetX: 2,
  verticalOffset: 23,

  'sc-tiny-size': {
    itemHeight: 10,
    itemSeparatorHeight: 2,
    menuHeightPadding: 2,
    submenuOffsetX: 0
  },

  'sc-small-size': {
    itemHeight: 16,
    itemSeparatorHeight: 7,
    menuHeightPadding: 4,
    submenuOffsetX: 2
  },

  'sc-large-size': {
    itemHeight: 60,
    itemSeparatorHeight: 20,
    menuHeightPadding: 0,
    submenuOffsetX: 4
  },

  // pretty sure these sizes are wrong, but I copied them from their original
  // values so... please fix.
  'sc-huge-size': {
    itemHeight: 20,
    itemSeparatorHeight: 9,
    menuHeightPadding: 0,
    submenuOffsetX: 0
  }
});

/* >>>>>>>>>> BEGIN source/render_delegates/popup_button.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


/**
 * Renders and updates the HTML representation of a popup button.
 */
SC.BaseTheme.popupButtonRenderDelegate = SC.BaseTheme.buttonRenderDelegate.create({
  render: function(dataSource, context) {
    context.setAttr('aria-haspopup', 'true');
    arguments.callee.base.apply(this,arguments);
  },

  update: function(dataSource, jQuery) {
    arguments.callee.base.apply(this,arguments);
  }
});

/* >>>>>>>>>> BEGIN source/render_delegates/progress.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

SC.BaseTheme.PROGRESS_OFFSET = 0.5;
SC.BaseTheme.PROGRESS_OFFSET_RANGE = 42;

/**
 Renders and updates DOM representations of progress bars.

 Parameters
 --------------------------
 Expects these properties on the data source:

 - `isIndeterminate`
 - `isRunning`
 - `isVisibleInWindow`
 - `value`

 Theme Constants
 -------------------------------------
 Ace's `progressRenderDelegate`'s rendering process is not affected by
 any theme constants.
 */
SC.BaseTheme.progressRenderDelegate = SC.RenderDelegate.create({
  className:'progress',

  render:function (dataSource, context) {
    this.addSizeClassName(dataSource, context);

    var isIndeterminate = dataSource.get('isIndeterminate'),
      theme = dataSource.get('theme'),
      valueMax = dataSource.get('maximum'),
      valueMin = dataSource.get('minimum'),
      valueNow = dataSource.get('ariaValue');

    var value;
    if (isIndeterminate) {
      value = 1;
    } else {
      value = dataSource.get('value');
    }

    // make accessible
    context.setAttr('aria-valuemax', valueMax);
    context.setAttr('aria-valuemin', valueMin);
    context.setAttr('aria-valuenow', valueNow);
    context.setAttr('aria-valuetext', valueNow);

    context.setClass({
      indeterminate:isIndeterminate,
      running:dataSource.get('isRunning') && isIndeterminate,
      'sc-empty':(value <= 0),
      'sc-complete':(value >= 1 && !isIndeterminate)
    });

    context = context.begin('div').addClass('track');
    this.includeSlices(dataSource, context, SC.THREE_SLICE);
    context = context.end();

    context = context.begin('div').addClass('content');
    context.setStyle('width', (value * 100) + "%");
    this.includeSlices(dataSource, context, SC.THREE_SLICE);
    context = context.end();
  },

  update:function (dataSource, jQuery) {
    this.updateSizeClassName(dataSource, jQuery);

    var theme = dataSource.get('theme'),
      value,
      valueMax = dataSource.get('maximum'),
      valueMin = dataSource.get('minimum'),
      valueNow = dataSource.get('ariaValue'),
      isIndeterminate = dataSource.get('isIndeterminate'),
      isRunning = dataSource.get('isRunning'),
      isVisibleInWindow = dataSource.get('isVisibleInWindow');

    // make accessible
    jQuery.attr('aria-valuemax', valueMax);
    jQuery.attr('aria-valuemin', valueMin);
    jQuery.attr('aria-valuenow', valueNow);
    jQuery.attr('aria-valuetext', valueNow);

    if (isIndeterminate) {
      value = 1;
    } else {
      value = dataSource.get('value');
    }

    jQuery.setClass({
      indeterminate:isIndeterminate,
      running:isRunning && isIndeterminate,
      'sc-empty':(value <= 0),
      'sc-complete':(value >= 1 && !isIndeterminate)
    });

    jQuery.find('.content').css('width', (value * 100) + "%");

    // fallback for browsers that don't support css transitions
    if(!SC.platform.supportsCSSTransitions) {
      if (!this._queue[jQuery[0].id]) {
        this._queue[jQuery[0].id] = {
          offset:0,
          element:SC.$(jQuery).find('.content .middle'),
          shouldAnimate:false
        };
      }

      if (isIndeterminate && isRunning && isVisibleInWindow) {
        // save offset in the queue and request animation
        this._queue[jQuery[0].id].shouldAnimate = true;
        this.animate(dataSource);
      } else if (!isIndeterminate) {
        // Clear out our custom background-position when isIndeterminate toggles.
        this._queue[jQuery[0].id].element.css('background-position', '');
      } else {
        this._queue[jQuery[0].id].shouldAnimate = false;
      }
    }
  },

  /** @private Queue of objects to animate: { id, offset, element } */
  _queue: {},

  /** @private Catch double calls to _animate */
  _animating: false,

  /**
    Animates the indeterminate progress view's middle background using
    JavaScript and requestAnimationFrame().
  */
  animate: function (dataSource) {
    var self = this;

    // avoid invoking the animation code multiple times if more than
    // one progress bar needs animating *and* one has already started the loop
    if (this._animating) {
      return;
    }

    function _animate() {
      var offset,
        lastOffset,
        roundedOffset,
        viewsToAnimate = self._queue,
        animations = 0,
        params;

      var id;
      for (id in viewsToAnimate) {
        if (viewsToAnimate.hasOwnProperty(id)) {
          params=viewsToAnimate[id];
          if (params.shouldAnimate) {
            self._animating = true;
            animations++;
            lastOffset = params.offset || 0;
            offset = (lastOffset + SC.BaseTheme.PROGRESS_OFFSET) % SC.BaseTheme.PROGRESS_OFFSET_RANGE;

            // Only update the style when the offset changes (this avoids making
            // the browser recalculate style in each frame).
            roundedOffset = Math.round(offset);
            if (roundedOffset > Math.round(lastOffset)) {
              params.element.css('background-position', roundedOffset + "px 0px");
            }

            params.offset = offset;
          }
        }
      }

      if (animations === 0) {
        self._animating = false;
      } else {
        window.requestAnimationFrame(_animate);
      }
    }

    // Start the animation.
    _animate();
  }
});

/* >>>>>>>>>> BEGIN source/render_delegates/radio.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  Renders and updates the DOM representation of a radio button (a single button,
  not the group).

  Expected Properties
  -----------------------------------

   - `isSelected`
   - `isActive`
   - `isMixed`
   - `title`

  Optional Properties
  -----------------------------------

   - `width` -- an optional width of the radio button
   - `labelRenderDelegate` properties

*/
SC.BaseTheme.radioRenderDelegate = SC.RenderDelegate.create({
  className: 'radio',

  render: function(dataSource, context) {
    this.addSizeClassName(dataSource, context);

    var theme = dataSource.get('theme');

    var isSelected = dataSource.get('isSelected'),
        width = dataSource.get('width'),
        labelId = SC.guidFor(dataSource) + '-label';

    context.setClass({
      active: dataSource.get('isActive'),
      mixed: dataSource.get('isMixed'),
      sel: dataSource.get('isSelected'),
      disabled: !dataSource.get('isEnabled')
    });

    //accessing accessibility
    context.setAttr('role', 'radio');
    context.setAttr('aria-checked', isSelected);
    context.setAttr('aria-labelledby', labelId);
    context.setAttr('aria-disabled', dataSource.get('isEnabled') ? 'false' : 'true');

    if (width) context.setStyle('width', width);

    context.push('<span class = "button"></span>');

    context = context.begin('span').addClass('sc-button-label').id(labelId);
    theme.labelRenderDelegate.render(dataSource, context);
    context = context.end();
  },

  update: function(dataSource, jquery) {
    this.updateSizeClassName(dataSource, jquery);

    var theme = dataSource.get('theme');

    var isSelected = dataSource.get('isSelected'),
        width = dataSource.get('width'),
        value = dataSource.get('value');

    jquery.setClass({
      active: dataSource.get('isActive'),
      mixed: dataSource.get('isMixed'),
      sel: dataSource.get('isSelected'),
      disabled: !dataSource.get('isEnabled')
    });

    jquery.attr('aria-disabled', dataSource.get('isEnabled') ? 'false' : 'true');
    jquery.attr('aria-checked', isSelected);
    jquery.css('width', width ? width : null);

    theme.labelRenderDelegate.update(dataSource, jquery.find('.sc-button-label'));
  }
});

/* >>>>>>>>>> BEGIN source/render_delegates/radio_group.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


/**
  @class
  Renders and updates the HTML representation of a group of radio buttons.

  Expects Properties
  -------------------------------

   - `items` -- a collection of data sources for radioRenderDelegates
   - `layoutDirection`
   - `isEnabled`

  Extended API
  --------------------------------
  As this encompasses an entire group, it must provide a way to determine
  which radio button is the target of an event. The indexForEvent method
  does exactly this, and all radioGroupRenderDelegates _must_ support it.

  Also, as it would be low-performance to update any but the changed radio
  button, there is a method to update a specific index.
*/
SC.BaseTheme.radioGroupRenderDelegate = SC.RenderDelegate.create({
  className: 'radio-group',

  render: function(dataSource, context) {
    this.addSizeClassName(dataSource, context);

    var theme = dataSource.get('theme'),
        name = SC.guidFor(this),
        items = dataSource.get('items'), idx, len = items.length, item;


    context.addClass(dataSource.get('layoutDirection'));
    context.setAttr('role', 'radiogroup');
    context.setAttr('aria-disabled', dataSource.get('isEnabled') ? 'false' : 'true');

    for (idx = 0; idx < len; idx++) {
      item = items[idx];
      context = context.begin('div')
        .addClass('radio-' + idx)
        .setAttr('index', idx)
        .addClass(theme.classNames)
        .addClass(theme.radioRenderDelegate.className)

        // so we can identify it in event handling
        .addClass('sc-radio-button');

      theme.radioRenderDelegate.render(item, context);

      context = context.end();
    }

    // store the radio count so we can know when to regenerate in update
    dataSource.get('renderState').radioCount = idx;
  },

  update: function(dataSource, jquery) {
    this.updateSizeClassName(dataSource, jquery);

    var theme = dataSource.get('theme'),
        name = SC.guidFor(this),
        items = dataSource.get('items'), idx, len = items.length, item;

    jquery.addClass(dataSource.get('layoutDirection'));
    jquery.attr('aria-disabled', dataSource.get('isEnabled') ? 'false' : 'true');

    if (dataSource.get('renderState').radioCount !== len) {
      // just regenerate if the count has changed. It would be better
      // to be intelligent, but that would also be rather complex
      // for such a rare case.
      var context = SC.RenderContext(jquery[0]);
      this.render(dataSource, context);
      context.update();
      return;
    }

    for (idx = 0; idx < len; idx++) {
      item = items[idx];
      theme.radioRenderDelegate.update(item, jquery.find('.radio-' + idx));
    }
  },

  /**
    Updates the radio button at the specified index.

    @param {Object} dataSource The RenderDelegate data source.
    @param {jQuery} jquery A jQuery instance with the DOM for this radio group.
    @param {Number} index The index of the radio to update.
  */
  updateRadioAtIndex: function(dataSource, jquery, index) {
    var item = dataSource.get('items')[index];
    dataSource.get('theme').radioRenderDelegate.update(item, jquery.find('.radio-' + index));
  },

  /**
    Returns the index of the radio button that was the target of the
    supplied event.

    @param {Object} dataSource The RenderDelegate data source.
    @param {jQuery} jquery A jQuery instance with the DOM for this radio group.
    @param {SC.Event SC.Touch} event The event or SC.Touch object.
  */

  indexForEvent: function(dataSource, jquery, evt) {
    var index = $(evt.target).closest('.sc-radio-button').attr('index');
    if (isNaN(index)) return undefined;
    return parseInt(index, 0);
  }
});

/* >>>>>>>>>> BEGIN source/render_delegates/segment.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


/**
  Renders and updates the HTML representation of a segment child view within
  SC.SegmentedView.
*/
SC.BaseTheme.segmentRenderDelegate = SC.RenderDelegate.create({
  className: 'segment',

  render: function (dataSource, context) {
    var theme = dataSource.get('theme'),
        buttonDelegate,
        classes;

    // Segment specific additions
    classes = {
      'sc-first-segment': dataSource.get('isFirstSegment'),
      'sc-middle-segment': dataSource.get('isMiddleSegment'),
      'sc-last-segment': dataSource.get('isLastSegment'),
      'sc-overflow-segment': dataSource.get('isOverflowSegment'),
      'vertical': dataSource.get('layoutDirection') !== SC.LAYOUT_HORIZONTAL
    };

    if (!SC.none(dataSource.get('index'))) classes['sc-segment-' + dataSource.get('index')] = YES;
    context.setClass(classes);

    // Use the SC.ButtonView render delegate for the current theme to render the segment as a button
    buttonDelegate = theme.buttonRenderDelegate;
    buttonDelegate.render(dataSource, context);
  },

  update: function (dataSource, jquery) {
    var theme = dataSource.get('theme'),
        buttonDelegate,
        classes = {};

    // Segment specific additions
    classes = {
      'sc-first-segment': dataSource.get('isFirstSegment'),
      'sc-middle-segment': dataSource.get('isMiddleSegment'),
      'sc-last-segment': dataSource.get('isLastSegment'),
      'sc-overflow-segment': dataSource.get('isOverflowSegment') || NO,
      'vertical': dataSource.get('layoutDirection') !== SC.LAYOUT_HORIZONTAL
    };
    if (!SC.none(dataSource.get('index'))) classes['sc-segment-' + dataSource.get('index')] = YES;
    jquery.setClass(classes);

    // Use the SC.ButtonView render delegate for the current theme to update the segment as a button
    buttonDelegate = theme.buttonRenderDelegate;
    buttonDelegate.update(dataSource, jquery);
  }

});

/* >>>>>>>>>> BEGIN source/render_delegates/segmented.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  Renders and updates the HTML representation of SC.SegmentedView.
*/
SC.BaseTheme.segmentedRenderDelegate = SC.RenderDelegate.create({
  className: 'segmented',

  /*
    We render everything external to the segments and let each segment use it's own render
    delegate to render its contents.

    */
  render: function(dataSource, context) {
    // Use text-align to align the segments
    this.addSizeClassName(dataSource, context);
    context.addStyle('text-align', dataSource.get('align'));
  },

  update: function(dataSource, jquery) {
    this.updateSizeClassName(dataSource, jquery);
    jquery.css('text-align', dataSource.get('align'));
  }

});

/* >>>>>>>>>> BEGIN source/render_delegates/slider.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licened under MIT license (see license.js)
// ==========================================================================

/**
  Renders and updates the DOM representation of a slider.

  Parameters
  -------------------------
  Requires the following parameters:

   - `value` -- a value from 0 to 1.
   - `frame` -- containing the frame in which the slider is being drawn.
*/

SC.BaseTheme.sliderRenderDelegate = SC.RenderDelegate.create({

  className: 'slider',

  render: function(dataSource, context) {
    this.addSizeClassName(dataSource, context);

    var valueMax = dataSource.get('maximum'),
        valueMin = dataSource.get('minimum'),
        valueNow = dataSource.get('ariaValue');

    // Add accessibility values.
    context.setAttr('aria-valuemax', valueMax);
    context.setAttr('aria-valuemin', valueMin);
    context.setAttr('aria-valuenow', valueNow);
    if(valueMin !== 0 || valueMax !== 100) context.setAttr('aria-valuetext', valueNow);
    context.setAttr('aria-orientation', 'horizontal');

    // Begin the track element.
    context = context.begin('span').addClass('track');

    // Draw the track's visual elements ("beginning", "middle" and "end").
    this.includeSlices(dataSource, context, SC.THREE_SLICE);

    // If desired, draw the step choinks.
    if (dataSource.get('markSteps')) {
      var stepPositions = dataSource.get('stepPositions');
      if (stepPositions) {
        var i, len = stepPositions.length;
        for (i = 0; i < len; i++) {
          context.begin()
            .setStyle('left', '%@%'.fmt(stepPositions[i] * 100))
            .addClass(['sc-slider-step-mark', 'sc-slider-step-mark-%@'.fmt(i)])
            .setClass({
              'sc-slider-step-mark-first': i === 0,
              'sc-slider-step-mark-last': i === len - 1
            }).end();
        }
      }
    }

    // Draw the handle.
    context.begin('img')
      .setAttr('src', SC.BLANK_IMAGE_URL)
      .addClass('sc-handle')
      .setStyle('left', '%@%'.fmt(dataSource.get('value')))
      .end();

    // End the track element.
    context = context.end();

    dataSource.get('renderState')._cachedHandle = null;
  },

  update: function(dataSource, jquery) {
    this.updateSizeClassName(dataSource, jquery);

    var valueMax = dataSource.get('maximum'),
        valueMin = dataSource.get('minimum'),
        valueNow = dataSource.get('ariaValue'),
        handle = dataSource.get('renderState')._cachedHandle;

    // Snag the handle if we haven't cached it yet.
    if (!handle) {
      handle = dataSource.get('renderState')._cachedHandle = jquery.find('.sc-handle');
    }

    // Update accessibility values.
    jquery.attr('aria-valuemax', valueMax);
    jquery.attr('aria-valuemin', valueMin);
    jquery.attr('aria-valuenow', valueNow);
    if(valueMin !== 0 || valueMax !== 100) jquery.attr('aria-valuetext', valueNow);
    jquery.attr('aria-orientation', 'horizontal');

    // If the minimum, maximum, step, or markSteps have changed, repoint the choinks.
    if (dataSource.didChangeFor('sliderRenderDelegateMinimumMaximumStepMarkSteps', 'minimum', 'maximum', 'step', 'markSteps')) {
      var marks = jquery.find('.sc-slider-step-mark'),
        markSteps = dataSource.get('markSteps'),
        stepPositions;
      // Ten years ago we had no marks, no steps and
      if (!markSteps || !(stepPositions = dataSource.get('stepPositions'))) {
        marks.remove();
      }
      // Otherwise, reposition them, adding new ones as needed.
      else {
        var choinkVal,
          i, len = stepPositions.length,
          firstLastClass,
          choinkTemplate = '<div style="left:%@%" class="sc-slider-step-mark sc-slider-step-mark-%@ %@"></div>',
          choinkMarkup;

        for (i = 0; i < len; i++) {
          if (marks[i]) {
            marks.eq(i).css('left', '%@%'.fmt(stepPositions[i] * 100)).setClass({
              'sc-slider-step-mark-first': i === 0,
              'sc-slider-step-mark-last': i === len - 1
            });
          }
          else {
            if (i === 0) firstLastClass = 'sc-slider-step-mark-first';
            else if (i === len - 1) firstLastClass = 'sc-slider-step-mark-last';
            else firstLastClass = '';
            choinkMarkup = choinkTemplate.fmt(stepPositions[i] * 100, i, firstLastClass);
            handle.before(choinkMarkup);
          }
        }
        // Remove any remaining.
        marks.slice(i).remove();
      }
    }

    // Update the value, if needed.
    if (dataSource.didChangeFor('sliderRenderDelegateValue', 'value')) {
      var value = dataSource.get('value');
      handle.css('left', value + "%");
    }
  }
});

/* >>>>>>>>>> BEGIN source/render_delegates/source_list.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

SC.BaseTheme.SourceList = SC.BaseTheme.subtheme('source-list');
/* >>>>>>>>>> BEGIN source/render_delegates/split.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2010 Sprout Systems, Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

SC.BaseTheme.splitRenderDelegate = SC.RenderDelegate.create({
  className: 'split',

  // Returns { SC.LAYOUT_VERTICAL: true/false, SC.LAYOUT_HORIZONTAL: true/false }
  // for use in setClass.
  _classesForDataSource: function(dataSource) {
    var classes = {},
      layoutDirection = dataSource.get('layoutDirection');
    classes[SC.LAYOUT_VERTICAL] = layoutDirection === SC.LAYOUT_VERTICAL;
    classes[SC.LAYOUT_HORIZONTAL] = layoutDirection === SC.LAYOUT_HORIZONTAL;
    return classes;
  },

  render: function(dataSource, context) {
    context.setClass(this._classesForDataSource(dataSource));
  },

  update: function(dataSource, jquery) {
    jquery.setClass(this._classesForDataSource(dataSource));
  }
});

/* >>>>>>>>>> BEGIN source/render_delegates/split_divider.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2010 Sprout Systems, Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

SC.BaseTheme.splitDividerRenderDelegate = SC.RenderDelegate.create({
  className: 'split-divider',
  dividerSize: 1,

  splitPositionOffset: -5,
  splitSizeOffset: 10,

  render: function(dataSource, context) {
    this.addSizeClassName(dataSource, context);

    // the divider view itself is the grabber, but the visible line
    // may be inside of it.
    context.push("<div class='line'></div>");
  },

  update: function(dataSource, jquery) {
    this.updateSizeClassName(dataSource, jquery);
  }
});

/* >>>>>>>>>> BEGIN source/render_delegates/toolbar.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

SC.BaseTheme.toolbarRenderDelegate = SC.RenderDelegate.create({
  className: 'toolbar',

  render: function(dataSource, context) {
    // toolbar has nothing in it
  },
  
  update: function() {
    // toolbar has nothing to update
  }
});

/* >>>>>>>>>> BEGIN source/render_delegates/well.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

SC.BaseTheme.wellRenderDelegate = SC.RenderDelegate.create({
  className: 'well',
  render: function(dataSource, context) {
    this.includeSlices(dataSource, context, SC.NINE_SLICE);
  },
  
  update: function() {

  }
});

/* >>>>>>>>>> BEGIN source/render_delegates/workspace.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

SC.BaseTheme.workspaceRenderDelegate = SC.RenderDelegate.create({
  className: 'workspace',
  
  render: function() {
    // No DOM to generate -- uses CSS3 to style.
  },

  update: function() {
    // No DOM to generate -- uses CSS3 to style.
  }
});
/* >>>>>>>>>> BEGIN source/system/drag.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


/**
  @static
*/
SC.DRAG_LINK = 0x0004;

/**
  @static
*/
SC.DRAG_COPY = 0x0001;

/**
  @static
*/
SC.DRAG_MOVE = 0x0002;

/**
  @static
*/
SC.DRAG_NONE = 0x0000;

/**
  @static
*/
SC.DRAG_ANY = 0x000F;

/**
  @static
*/
SC.DRAG_DATA = 0x0008; // includes SC.DRAG_REORDER

/**
  @static
*/
SC.DRAG_AUTOSCROLL_ZONE_THICKNESS = 20;

SC.View.reopen(
  /** @scope SC.View.prototype */ {

  /** @private */
  init: function (original) {
    original();

    // register for drags
    if (this.get('isDropTarget')) { SC.Drag.addDropTarget(this); }

    // register scroll views for autoscroll during drags
    if (this.get('isScrollable')) { SC.Drag.addScrollableView(this); }
  }.enhance(),

  /** @private */
  destroy: function (original) {
    // unregister for drags
    if (this.get('isDropTarget')) { SC.Drag.removeDropTarget(this); }

    // unregister for autoscroll during drags
    if (this.get('isScrollable')) { SC.Drag.removeScrollableView(this); }

    return original();
  }.enhance()
});

/**
  @class

  An instance of this object is created whenever a drag occurs.  The instance
  manages the mouse/touch events and coordinating with droppable targets until the
  user releases the mouse button.

  To initiate a drag, you should call `SC.Drag.start()` with the options below
  specified in a hash. Pass the ones you need to get the drag you want:

    - `event` -- *(req)* The mouse event/touch that triggered the drag.  This will be used
      to position the element.

    - `source` -- *(req)* The drag source object that should be consulted during
      the drag operations. This is usually the container view that initiated
      the drag.

    - `dragView` -- Optional view that will be used as the source image for the
      drag. The drag operation will clone the DOM elements for this view and
      parent them under the drag pane, which has the class name `sc-ghost-view`.
      The drag view is not moved from its original location during a drag.
      If the dragView is not provided, the source is used as dragView.

    - `ghost` -- `YES` | `NO`  If `NO`, the drag view image will show, but the source
      `dragView` will not be hidden.  Set to `YES` to make it appear that the
      `dragView` itself is being dragged around.

    - `slideBack` -- `YES` | `NO`  If `YES` and the drag operation is cancelled, the
      `dragView` will slide back to its source origin.

    - `origin` --  If passed, this will be used as the origin point for the
      ghostView when it slides back.  You normally do not need to pass this
      unless the ghost view does not appear in the main UI.

    - `data` -- Optional hash of data types and values.  You can use this to pass
      a static set of data instead of providing a dataSource.  If you provide
      a dataSource, it will be used instead.

    - `dataSource` --  Optional object that will provide the data for the drag to
      be consumed by the drop target.  If you do not pass this parameter or the
      data hash, then the source object will be used if it implements the
      SC.DragDataSourceProtocol protocol.

    - `anchorView` -- if you pass this optional view, then the drag will only be
      allowed to happen within this view.  The ghostView will actually be added
      as a child of this view during the drag.  Normally the anchorView is the
      window.

  @extends SC.Object
*/
SC.Drag = SC.Object.extend(
/** @scope SC.Drag.prototype */ {

  /**
    The source object used to coordinate this drag.

    @readOnly
    @type SC.DragSource
  */
  source: null,

  /**
    The view actually dragged around the screen. This is created automatically
    from the dragView.

    @readOnly
    @type SC.View
  */
  ghostView: null,

  /**
    If `YES`, then the `ghostView` will acts like a cursor and attach directly
    to the mouse/touch location.

    @readOnly
    @type Boolean
  */
  ghostActsLikeCursor: NO,

  /**
    The view that was used as the source of the `ghostView`.

    The drag view is not moved from its original location during a drag.
    Instead, the DOM content of the view is cloned and managed by the
    ghostView.  If you want to visually indicate that the view is being
    moved, you should set ghost to `YES`.
    If dragView is not provided the source is used instead.

    @readOnly
    @type SC.View
  */
  dragView: null,

  /**
    If `YES`, the `dragView` is automatically hidden while dragging around the
    ghost.

    @readOnly
    @type Boolean
  */
  ghost: YES,

  /**
    If `NO`, the source will not be copied, clone, no ghost view will get created,
    and it won't be moved.

    @type Boolean
  */
  sourceIsDraggable: YES,

  /**
    If `YES`, then the `ghostView` will slide back to its original location if
    drag is cancelled.

    @type Boolean
  */
  slideBack: YES,

  /**
    The origin to slide back to in the coordinate of the `dragView`'s
    containerView.

    @type Point
  */
  ghostOffset: { x: 0, y: 0 },

  /**
    The current location of the mouse pointer in window coordinates. This is
    updated as long as the mouse button is pressed or touch is active. Drop targets are
    encouraged to update this property in their `dragUpdated()` method
    implementations.

    The ghostView will be positioned at this location.

    @type Point
  */
  location: {},

  // ..........................................
  // DRAG DATA
  //

  /**
    Data types supported by this drag operation.

    Returns an array of data types supported by the drag source.  This may be
    generated dynamically depending on the data source.

    If you are implementing a drag source, you will need to provide these data
    types so that drop targets can detect if they can accept your drag data.

    If you are implementing a drop target, you should inspect this property
    on your `dragEntered()` and `prepareForDragOperation()` methods to determine
    if you can handle any of the data types offered up by the drag source.

    @type Array
  */
  dataTypes: function () {
    // first try to use the data source.
    if (this.dataSource) return this.dataSource.get('dragDataTypes') || [];

    // if that fails, get the keys from the data hash.
    var hash = this.data;
    if (hash) {
      var ret = [];
      for (var key in hash) {
        if (hash.hasOwnProperty(key)) ret.push(key);
      }
      return ret;
    }

    // if that fails, then check to see if the source object is a dataSource.
    var source = this.get('source');
    if (source && source.dragDataTypes) return source.get('dragDataTypes') || [];

    // no data types found. :(
    return [];
  }.property().cacheable(),

  /**
    Checks for a named data type in the drag.

    @param {String} dataType the data type
    @returns {Boolean} YES if data type is present in dataTypes array.
  */
  hasDataType: function (dataType) {
    return (this.get('dataTypes').indexOf(dataType) >= 0);
  },

  /**
    Retrieve the data for the specified `dataType` from the drag source.

    Drop targets can use this method during their `performDragOperation()`
    method to retrieve the actual data provided by the drag data source.  This
    data may be generated dynamically depending on the data source.

    @param {Object} dataType data type you want to retrieve.  Should be one of
      the values returned in the dataTypes property
    @returns {Object} The generated data.
  */
  dataForType: function (dataType) {
    // first try to use the data Source.
    if (this.dataSource) {
      return this.dataSource.dragDataForType(this, dataType);

    // then try to use the data hash.
    } else if (this.data) {
      return this.data[dataType];

    // if all else fails, check to see if the source object is a data source.
    } else {
      var source = this.get('source');
      if (source && SC.typeOf(source.dragDataForType) === SC.T_FUNCTION) {
        return source.dragDataForType(this, dataType);

      // no data source found. :(
      } else return null;
    }
  },

  /**
    Optional object used to provide the data for the drag.

    Drag source can designate a `dataSource` object to generate the data for
    a drag dynamically.  The data source can and often is the drag source
    object itself.

    Data Source objects must comply with the `SC.DragDataSourceProtocol` interface.  If
    you do not want to implement this interface, you can provide the data
    directly with the data property.

    If you are implementing a drop target, use the dataTypes property and
    `dataForTypes()` method to access data instead of working directly with
    these properties.

    @readOnly
    @type SC.DragDataSourceProtocol
  */
  dataSource: null,

  /**
    Optional hash of data.  Used if no dataSource was provided.

    Drag sources can provide a hash of data when the drag begins instead of
    specifying an actual dataSource.  The data is stored in this property.
    If you are implementing a drop target, use the dataTypes property and
    `dataForTypes()` method to access data instead of working directly with
    these properties.

    @readOnly
    @type Hash
  */
  data: null,

  /**
    Returns the currently allowed `dragOperations` for the drag.  This will be
    set just before any callbacks are invoked on a drop target.  The drag
    source is given an opportunity to set these operations.

    @readOnly
    @type Number
  */
  allowedDragOperations: SC.DRAG_ANY,

  /** @private required by autoscroll */
  _dragInProgress: YES,

  /** @private
    Stores the initial visibility state of the dragView so it can be restored
    after the drag
  */
  _dragViewWasVisible: null,

  /** @private
    This will actually start the drag process. Called by SC.Drag.start().
  */
  startDrag: function () {
    if (this.get('sourceIsDraggable')) {
      // create the ghost view
      this._createGhostView();
    }

    var evt = this.event;

    // compute the ghost offset from the original start location

    var loc = { x: evt.clientX, y: evt.clientY }; // [CC] pageXY => clientXY
    this.set('location', loc);

    if (this.get('sourceIsDraggable')) {
      var dv = this._getDragView();
      var pv = dv.get('parentView');

      // convert to global coordinates
      var origin = pv ? pv.convertFrameToView(dv.get('frame'), null) : dv.get('frame');

      if (this.get('ghost')) {
        // Hide the dragView
        this._dragViewWasVisible = dv.get('isVisible');
        dv.set('isVisible', NO);
      }

      if (this.ghostActsLikeCursor) this.ghostOffset = { x: 14, y: 14 };
      else this.ghostOffset = { x: (loc.x - origin.x), y: (loc.y - origin.y) };

      // position the ghost view
      if (!this._ghostViewHidden) this._positionGhostView(evt);

      if (evt.makeTouchResponder) {
        // Should use invokeLater if I can figure it out
        var self = this;
        SC.Timer.schedule({
          target: evt,
          action: function () {
            if (!evt.hasEnded) evt.makeTouchResponder(self, YES);
          },
          interval: 1
        });
      }
      else {
        // notify root responder that a drag is in process
        this.ghostView.rootResponder.dragDidStart(this, evt);
      }
    }

    var source = this.source;
    if (source && source.dragDidBegin) source.dragDidBegin(this, loc);

    // let all drop targets know that a drag has started
    var ary = this._dropTargets();

    for (var idx = 0, len = ary.length; idx < len; idx++) {
      var target = ary[idx];
      // If the target is not visible, it is not valid.
      if (!target.get('isVisibleInWindow')) continue;

      target.tryToPerform('dragStarted', this, evt);
    }
  },

  /** @private
    Cancel the drag operation.

    This is called by RootResponder's keyup method when the user presses
    escape and a drag is in progress.

    @param {Event} evt the key event
    @see SC.Drag.endDrag
  */
  cancelDrag: function (evt) {
    var target = this._lastTarget;

    if (target && target.dragExited) target.dragExited(this, this._lastMouseDraggedEvent);

    this.endDrag(evt, SC.DRAG_NONE);
  },

  /** @private
    End the drag operation.

    This notifies the data source that the drag ended and removes the
    ghost view, but does not notify the drop target of a drop.

    @param {Event} evt
    @param {DragOp} op The drag operation that was performed. One of
      SC.DRAG_COPY, SC.DRAG_MOVE, SC.DRAG_LINK, or SC.DRAG_NONE.
  */
  endDrag: function (evt, op) {
    var loc = this.get('location');

    // notify all drop targets that the drag ended
    var ary = this._dropTargets();
    for (var idx = 0, len = ary.length; idx < len; idx++) {
      try {
        ary[idx].tryToPerform('dragEnded', this, evt);
      } catch (ex2) {
        SC.Logger.error('Exception in SC.Drag.mouseUp(dragEnded on %@): %@'.fmt(ary[idx], ex2));
      }
    }

    // Trigger a slide-back if triggered and if the drag was unsuccessful.
    if (this.get('sourceIsDraggable') && this.get('slideBack') && op === SC.DRAG_NONE) {
      this._slideGhostViewBack();
    }
    // Otherwise, wrap up the drag right now.
    else {
      this._endDrag();
    }

    var source = this.get('source');
    if (source) {
      // notify the source that the drag succeeded
      if (source.dragDidSucceed && op !== SC.DRAG_NONE) source.dragDidSucceed(this, loc, op);
      // notify the source that the drag was cancelled
      else if (source.dragDidCancel && op === SC.DRAG_NONE) source.dragDidCancel(this, loc, op);

      // always notify the source that everything has completed
      if (source.dragDidEnd) source.dragDidEnd(this, loc, op);
    }
  },

  // ..........................................
  // PRIVATE PROPERTIES AND METHODS
  //

  /** @private */
  touchStart: function (evt) {
    return YES;
  },

  /** @private
    This method is called repeatedly during a mouse drag.  It updates the
    position of the ghost image, then it looks for a current drop target and
    notifies it.
  */
  mouseDragged: function (evt) {
    var scrolled = this._autoscroll(evt);
    var loc = this.get('location');
    if (!scrolled && (evt.clientX === loc.x) && (evt.clientY === loc.y)) {  // [CC] pageXY => clientXY
      return; // quickly ignore duplicate calls
    }

    // save the new location to avoid duplicate mouseDragged event processing
    loc = { x: evt.clientX, y: evt.clientY }; // [CC] pageXY => clientXY
    this.set('location', loc);
    this._lastMouseDraggedEvent = evt;

    // STEP 1: Determine the deepest drop target that allows an operation.
    // if the drop target selected the last time this method was called
    // differs from the deepest target found, then go up the chain until we
    // either hit the last one or find one that will allow a drag operation
    var source = this.source;
    var last = this._lastTarget;
    var target = this._findDropTarget(evt); // deepest drop target
    var op = SC.DRAG_NONE;

    while (target && (target !== last) && (op === SC.DRAG_NONE)) {
      // make sure the drag source will permit a drop operation on the named
      // target
      if (target && source && source.dragSourceOperationMaskFor) {
        op = source.dragSourceOperationMaskFor(this, target);
      } else op = SC.DRAG_ANY; // assume drops are allowed

      // now, let's see if the target will accept the drag
      if ((op !== SC.DRAG_NONE) && target && target.computeDragOperations) {
        op = op & target.computeDragOperations(this, evt, op);
      } else op = SC.DRAG_NONE; // assume drops AREN'T allowed

      this.allowedDragOperations = op;

      // if DRAG_NONE, then look for the next parent that is a drop zone
      if (op === SC.DRAG_NONE) target = this._findNextDropTarget(target);
    }

    // STEP 2: Refocus the drop target if needed
    if (target !== last) {
      if (last && last.dragExited) last.dragExited(this, evt);

      if (target) {
        if (target.dragEntered) target.dragEntered(this, evt);
        if (target.dragUpdated) target.dragUpdated(this, evt);
      }

      this._lastTarget = target;
    } else {
      if (target && target.dragUpdated) target.dragUpdated(this, evt);
    }

    // notify source that the drag moved
    if (source && source.dragDidMove) source.dragDidMove(this, loc);

    // reposition the ghostView
    if (this.get('sourceIsDraggable') && !this._ghostViewHidden) this._positionGhostView(evt);
  },

  touchesDragged: function (evt) {
    this.mouseDragged(evt);
  },

  /**
    @private

    Called when the mouse is released.  Performs any necessary cleanup and
    executes the drop target protocol to try to complete the drag operation.
  */
  mouseUp: function (evt) {
    var loc    = { x: evt.clientX, y: evt.clientY },  // [CC] pageXY => clientXY
        target = this._lastTarget,
        op     = this.allowedDragOperations;

    this.set('location', loc);

    // try to have the drop target perform the drop...
    try {
      if (target && target.acceptDragOperation && target.acceptDragOperation(this, op)) {
        op = target.performDragOperation ? target.performDragOperation(this, op) : SC.DRAG_NONE;
      } else {
        op = SC.DRAG_NONE;
      }
    } catch (e) {
      SC.Logger.error('Exception in SC.Drag.mouseUp(acceptDragOperation|performDragOperation): %@'.fmt(e));
    }

    this.endDrag(evt, op);
  },

  /** @private */
  touchEnd: function (evt) {
    this.mouseUp(evt);
  },

  /** @private
    Returns the dragView. If it is not set, the source is returned.
  */
  _getDragView: function () {
    if (!this.dragView) {
      if (!this.source || !this.source.isView) throw new Error("Source can't be used as dragView, because it's not a view.");
      this.dragView = this.source;
    }
    return this.dragView;
  },

  /** @private
    This will create the ghostView and add it to the document.
  */
  _createGhostView: function () {
    var dragView = this._getDragView(),
        frame = dragView.get('borderFrame'),
        ghostLayout, view;

    // Create a fixed layout for the ghost view.
    ghostLayout = { top: frame.y, left: frame.x, width: frame.width, height: frame.height };

    view = this.ghostView = SC.Pane.create({
      classNames: ['sc-ghost-view'],
      layout: ghostLayout,
      owner: this,
      wantsAcceleratedLayer: dragView.get('wantsAcceleratedLayer'),

      didCreateLayer: function () {
        if (dragView) {
          var dragLayer = dragView.get('layer');
          if (dragLayer) {
            var layer = dragLayer.cloneNode(true);

            // Canvas elements need manual copying.
            var dragCanvasses = dragView.$().find('canvas');
            if (dragCanvasses.length) {
              var ghostCanvasses = $(layer).find('canvas'),
                  len = dragCanvasses.length,
                  i, dragCanvas, ghostCanvas;
              for (i = 0; i < len; i++) {
                dragCanvas = dragCanvasses[i];
                ghostCanvas = ghostCanvasses[i];
                ghostCanvas.width = dragCanvas.width;
                ghostCanvas.height = dragCanvas.height;
                ghostCanvas.getContext('2d').drawImage(dragCanvas, 0, 0);
              }
            }

            // Make sure the layer we put in the ghostView wrapper is not displaced.
            layer.style.top = "0px";
            layer.style.left = "0px";
            layer.style.bottom = "0px";
            layer.style.right = "0px";

            // Attach the cloned layer.
            this.get('layer').appendChild(layer);
          }
        }
      }
    });

    view.append();  // add to window
  },

  /** @private
    Positions the ghost view underneath the mouse/touch with the initial offset
    recorded by when the drag started.
  */
  _positionGhostView: function (evt) {
    var ghostView = this.ghostView,
      loc;

    if (ghostView) {
      loc = this.get('location');

      loc.x -= this.ghostOffset.x;
      loc.y -= this.ghostOffset.y;
      ghostView.adjust({ top: loc.y, left: loc.x });
    }
  },

  /** @private
    YES if the ghostView has been manually hidden.

    @type Boolean
    @default NO
  */
  _ghostViewHidden: NO,

  /**
    Hide the ghostView.
  */
  hideGhostView: function () {
    if (this.ghostView && !this._ghostViewHidden) {
      this.ghostView.remove();
      this._ghostViewHidden = YES;
    }
  },

  /**
    Unhide the ghostView.
  */
  unhideGhostView: function () {
    if (this._ghostViewHidden) {
      this._ghostViewHidden = NO;
      this._createGhostView();
    }
  },

  /** @private Called instead of _destroyGhostView if slideBack is YES. */
  _slideGhostViewBack: function () {
    if (this.ghostView) {
      var dragView = this._getDragView(),
          frame = dragView.get('borderFrame'),
          dragParentView = dragView.get('parentView'),
          globalOrigin = dragParentView ? dragParentView.convertFrameToView(frame, null) : dragView.get('frame'),
          slidebackLayout;

      // Create a fixed layout for the ghost view.
      slidebackLayout = { top: globalOrigin.y, left: globalOrigin.x };

      // Animate the ghost view back to its original position; destroy after.
      this.ghostView.animate(slidebackLayout, 0.5, this, function () {
        this.invokeNext(function() {
          // notify the source that slideback has completed
          var source = this.get('source');
          if (this.get('slideBack') && source && source.dragSlideBackDidEnd) source.dragSlideBackDidEnd(this);

          this._endDrag();
        });
      });

    }
    else {
      this._endDrag();
    }
  },

  /** @private */
  _destroyGhostView: function () {
    if (this.ghostView) {
      this.ghostView.remove();
      this.ghostView = null; // this will allow the GC to collect it.
      this._ghostViewHidden = NO;
    }
  },

  /** @private */
  _endDrag: function () {
    if (this.get('sourceIsDraggable')) {
      this._destroyGhostView();
      if (this.get('ghost')) {
        // Show the dragView if it was hidden.
        if (this._dragViewWasVisible) this._getDragView().set('isVisible', YES);
        this._dragViewWasVisible = null;
      }
    }

    this._cleanUpDrag();
  },

  /** @private */
  _cleanUpDrag: function () {
    this._lastTarget = null;
    this._dragInProgress = NO;
    this._cachedDropTargets = null;
  },

  /** @private
    Return an array of drop targets, sorted with any nested drop targets
    at the top of the array.  The first time this method is called during
    a drag, it will reconstruct this array using the current set of
    drop targets.  Afterwards it uses the cached set until the drop
    completes.

    This means that if you change the view hierarchy of your drop targets
    during a drag, it will probably be wrong.
  */
  _dropTargets: function () {
    if (this._cachedDropTargets) return this._cachedDropTargets;

    // build array of drop targets
    var ret = [];
    var hash = SC.Drag._dropTargets;
    for (var key in hash) {
      if (hash.hasOwnProperty(key)) ret.push(hash[key]);
    }

    // views must be sorted so that drop targets with the deepest nesting
    // levels appear first in the array.  The getDepthFor().
    var depth = {};
    var dropTargets = SC.Drag._dropTargets;
    var getDepthFor = function (x) {
      if (!x) return 0;
      var guid = SC.guidFor(x);
      var ret = depth[guid];
      if (!ret) {
        ret = 1;
        while ((x = x.get('parentView'))) {
          if (dropTargets[SC.guidFor(x)] !== undefined) ret = ret + 1;
          if (x.isPane && x.isMainPane) ret = ret + 10000; // Arbitrary value always have the main pain on top
        }
        depth[guid] = ret;
      }
      return ret;
    };

    // sort array of drop targets
    ret.sort(function (a, b) {
      if (a === b) return 0;
      a = getDepthFor(a);
      b = getDepthFor(b);
      return (a > b) ? -1 : 1;
    });

    this._cachedDropTargets = ret;
    return ret;
  },

  /** @private
    This will search through the drop targets, looking for one in the target
    area.
  */
  _findDropTarget: function (evt) {
    var loc = { x: evt.clientX, y: evt.clientY }; // [CC] pageXY => clientXY

    var target, frame;
    var ary = this._dropTargets();
    for (var idx = 0, len = ary.length; idx < len; idx++) {
      target = ary[idx];

      // If the target is not visible, it is not valid.
      if (!target.get('isVisibleInWindow')) continue;

      // get clippingFrame, converted to the pane.
      frame = target.convertFrameToView(target.get('clippingFrame'), null);

      // check to see if loc is inside.  If so, then make this the drop target
      // unless there is a drop target and the current one is not deeper.
      if (SC.pointInRect(loc, frame)) return target;
    }
    return null;
  },

  /** @private
    Search the parent nodes of the target to find another view matching the
    drop target.  Returns null if no matching target is found.
  */
  _findNextDropTarget: function (target) {
    var dropTargets = SC.Drag._dropTargets;
    while ((target = target.get('parentView'))) {
      if (dropTargets[SC.guidFor(target)]) return target;
    }
    return null;
  },

  // ............................................
  // AUTOSCROLLING
  //

  /** @private
    Performs auto-scrolling for the drag.  This will only do anything if
    the user keeps the mouse/touch within a few pixels of one location for a little
    while.

    Returns YES if a scroll was performed.
  */
  _autoscroll: function (evt) {
    if (!evt) evt = this._lastAutoscrollEvent;

    // If drag has ended, exit
    if (!this._dragInProgress) return NO;

    // STEP 1: Find the first view that we can actually scroll.  This view
    // must be:
    // - scrollable
    // - the mouse pointer or touch must be within a scrolling hot zone
    // - there must be room left to scroll in that direction.

    // NOTE: an event is passed only when called from mouseDragged
    var loc  = evt ? { x: evt.clientX, y: evt.clientY } : this.get('location'), // [CC] pageXY => clientXY
        view = this._findScrollableView(loc),
        scrollableView = null, // become final view when found
        vscroll, hscroll, min, max, container, f;

    // hscroll and vscroll will become either 1 or -1 to indicate scroll
    // direction or 0 for no scroll.

    while (view && !scrollableView) {

      // quick check...can we scroll this view right now?
      vscroll = view.get('canScrollVertical') ? 1 : 0;
      hscroll = view.get('canScrollHorizontal') ? 1 : 0;

      // at least one direction might be scrollable.  Collect frame info
      if (vscroll || hscroll) {
        container = view.get('containerView');
        if (container) {
          f = view.convertFrameToView(container.get('frame'), null);
        } else {
          vscroll = hscroll = 0; // can't autoscroll this mother
        }
      }

      // handle vertical direction
      if (vscroll) {

        // bottom hotzone?
        max = SC.maxY(f);
        min = max - SC.DRAG_AUTOSCROLL_ZONE_THICKNESS;
        if (loc.y >= min && loc.y <= max) vscroll = 1;
        else {
          // how about top
          min = SC.minY(f);
          max = min + SC.DRAG_AUTOSCROLL_ZONE_THICKNESS;
          if (loc.y >= min && loc.y <= max) vscroll = -1;
          else vscroll = 0; // can't scroll vertical
        }
      }

      // handle horizontal direction
      if (hscroll) {

        // bottom hotzone?
        max = SC.maxX(f);
        min = max - SC.DRAG_AUTOSCROLL_ZONE_THICKNESS;
        if (loc.x >= min && loc.x <= max) hscroll = 1;
        else {
          // how about top
          min = SC.minX(f);
          max = min + SC.DRAG_AUTOSCROLL_ZONE_THICKNESS;
          if (loc.x >= min && loc.x <= max) hscroll = -1;
          else hscroll = 0; // can't scroll vertical
        }
      }

      // if we can scroll, then set this.
      if (vscroll || hscroll) scrollableView = view;
      else view = this._findNextScrollableView(view);
    }

    // STEP 2: Only scroll if the user remains within the hot-zone for a
    // period of time
    if (scrollableView && (this._lastScrollableView === scrollableView)) {
      if ((Date.now() - this._hotzoneStartTime) > 100) {
        this._horizontalScrollAmount *= 1.05;
        this._verticalScrollAmount *= 1.05; // accelerate scroll
      }

    // otherwise, reset everything and disallow scroll
    } else {
      this._lastScrollableView = scrollableView;
      this._horizontalScrollAmount = 15;
      this._verticalScrollAmount = 15;
      this._hotzoneStartTime = (scrollableView) ? Date.now() : null;
      hscroll = vscroll = 0;
    }

    // STEP 3: Scroll!
    if (scrollableView && (hscroll || vscroll)) {
      var scroll = {
        x: hscroll * this._horizontalScrollAmount,
        y: vscroll * this._verticalScrollAmount
      };
      scrollableView.scrollBy(scroll);
    }

    // If a scrollable view was found, then check later
    if (scrollableView) {
      if (evt) {
        this._lastAutoscrollEvent = { clientX: evt.clientX, clientY: evt.clientY }; // [CC] pageXY => clientXY
      }
      this.invokeLater(this._autoscroll, 100, null);
      return YES;
    } else {
      this._lastAutoscrollEvent = null;
      return NO;
    }
  },

  /** @private
    Returns an array of scrollable views, sorted with nested scrollable views
    at the top of the array.  The first time this method is called during a
    drag, it will reconstruct this array using the current state of scrollable
    views.  Afterwards it uses the cached set until the drop completes.
  */
  _scrollableViews: function () {
    if (this._cachedScrollableView) return this._cachedScrollableView;

    // build array of scrollable views
    var ret = [];
    var hash = SC.Drag._scrollableViews;
    for (var key in hash) {
      if (hash.hasOwnProperty(key)) ret.push(hash[key]);
    }

    // now resort.  This custom function will sort nested scrollable views
    // at the start of the list.
    ret = ret.sort(function (a, b) {
      var view = a;
      while ((view = view.get('parentView'))) {
        if (b === view) return -1;
      }
      return 1;
    });

    this._cachedScrollableView = ret;
    return ret;
  },

  /** @private
    This will search through the scrollable views, looking for one in the
    target area.
  */
  _findScrollableView: function (loc) {
    var ary = this._scrollableViews(),
        len = ary ? ary.length : 0,
        target, frame, idx;

    for (idx = 0; idx < len; idx++) {
      target = ary[idx];

      if (!target.get('isVisibleInWindow')) continue;

      // get clippingFrame, converted to the pane
      frame = target.convertFrameToView(target.get('clippingFrame'), null);

      // check to see if loc is inside
      if (SC.pointInRect(loc, frame)) return target;
    }
    return null;
  },

  /** @private
    Search the parent nodes of the target to find another scrollable view.
    return null if none is found.
  */
  _findNextScrollableView: function (view) {
    var scrollableViews = SC.Drag._scrollableViews;
    while ((view = view.get('parentView'))) {
      if (scrollableViews[SC.guidFor(view)]) return view;
    }
    return null;
  }

});

SC.Drag.mixin(
/** @scope SC.Drag */ {

  /**
   This is the method you use to initiate a new drag.  See class documentation
   for more info on the options taken by this method.

   @params {Hash} ops a hash of options.  See documentation above.
  */
  start: function (ops) {
    var ret = this.create(ops);
    ret.startDrag();
    return ret;
  },

  /** @private */
  _dropTargets: {},

  /** @private */
  _scrollableViews: {},

  /**
    Register the view object as a drop target.

    This method is called automatically whenever a view is created with the
    isDropTarget property set to `YES`.  You generally will not need to call it
    yourself.

    @param {SC.View} target a view implementing the SC.DropTargetProtocol protocol
  */
  addDropTarget: function (target) {
    this._dropTargets[SC.guidFor(target)] = target;
  },

  /**
    Unregister the view object as a drop target.

    This method is called automatically whenever a view is removed from the
    hierarchy.  You generally will not need to call it yourself.

    @param {SC.View} target A previously registered drop target
  */
  removeDropTarget: function (target) {
    delete this._dropTargets[SC.guidFor(target)];
  },

  /**
    Register the view object as a scrollable view.  These views will
    auto-scroll during a drag.

    @param {SC.View} target The view that should be auto-scrolled
  */
  addScrollableView: function (target) {
    this._scrollableViews[SC.guidFor(target)] = target;
  },

  /**
    Remove the view object as a scrollable view.  These views will auto-scroll
    during a drag.

    @param {SC.View} target A previously registered scrollable view
  */
  removeScrollableView: function (target) {
    delete this._scrollableViews[SC.guidFor(target)];
  }

});

/* >>>>>>>>>> BEGIN source/views/checkbox.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/** @class

  Represents a Checkbox Button.

  The view is an `SC.ButtonView` put into toggle mode and with the 'theme' property
  set to "checkbox".

  Rendering
  ----------------------------
  SC.ButtonView delegates its rendering to its theme. As the theme is set
  to "checkbox", the way the checkbox renders (including DOM) will actually
  be different than SC.ButtonView's.

  @extends SC.ButtonView
  @since SproutCore 1.0
*/
SC.CheckboxView = SC.ButtonView.extend(
/** @scope SC.CheckboxView.prototype */ {

  /**
    @type Array
    @default ['sc-checkbox-view', 'sc-checkbox-control']
    @see SC.View#classNames
  */
  classNames: ['sc-checkbox-view', 'sc-checkbox-control'],

  /**
    The WAI-ARIA role of checkbox.

    @type String
    @readOnly
  */
  ariaRole: 'checkbox',

  // no special theme for Checkbox; button defaults to 'square', so we have to stop that.
  themeName: null,

  /**
    @type String
    @default 'checkboxRenderDelegate'
  */
  renderDelegateName: 'checkboxRenderDelegate',

  /**
    Ellipsis is disabled by default to allow multiline text

    @type Boolean
    @default NO
  */
  needsEllipsis: NO,

  /**
    `YES` if `isEnabledInPane` is `YES`, `NO` otherwise

    @type Boolean
    @default NO
    @observes isEnabledInPane
  */
  acceptsFirstResponder: function() {
    if (SC.FOCUS_ALL_CONTROLS) { return this.get('isEnabledInPane'); }
    return NO;
  }.property('isEnabledInPane'),

  /** @private */
  _toggleValue: function(){
    var isOn = this.get('value') === this.get('toggleOnValue');
    this.set('value', isOn ? this.get('toggleOffValue') : this.get('toggleOnValue'));
  },

  /** @private */
  mouseDown: function(evt) {
    // Fast path, reject secondary clicks.
    if (evt.which && evt.which !== 1) return false;

    if(!this.get('isEnabledInPane')) return YES;
    this.set('isActive', YES);
    this._isMouseDown = YES;
    if (evt && this.get('acceptsFirstResponder')) evt.allowDefault();
    return YES;
  },

  /** @private */
  mouseUp: function(evt) {
    if(!this.get('isEnabledInPane')) return YES;

    this.set('isActive', NO);
    this._isMouseDown = NO;

    // fire action
    if (this.get('buttonBehavior') !== SC.HOLD_BEHAVIOR) {
      if (this.$().within(evt.target)) {
        this._toggleValue();
        this._action(evt);
      }
    }

    return YES;

  },

  /** @private */
  keyDown: function(evt) {
    // handle tab key
    if(!this.get('isEnabledInPane')) return YES;

    if (evt.which === 9 || evt.keyCode === 9) {
      var view = evt.shiftKey ? this.get('previousValidKeyView') : this.get('nextValidKeyView');
      if(view) view.becomeFirstResponder();
      else evt.allowDefault();
      return YES ; // handled
    }

    if (evt.which === 13 || evt.which === 32) {
      this._toggleValue();

      // fire action
      if (this.get('buttonBehavior') !== SC.HOLD_BEHAVIOR) {
        if (this.$().within(evt.target)) { this._action(evt); }
      }

      return YES ; // handled
    }

    // let other keys through to browser
    evt.allowDefault();

    return NO;
  },



  /** @private */
  touchStart: function(evt) {
    return this.mouseDown(evt);
  },

  /** @private */
  touchEnd: function(evt) {
    return this.mouseUp(evt);
  }

});

/* >>>>>>>>>> BEGIN source/views/collection.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('mixins/collection_view_delegate') ;

/**
  Special drag operation passed to delegate if the collection view proposes
  to perform a reorder event.

  @static
  @constant
*/
SC.DRAG_REORDER = 0x0010;

/**
  @class

  This class renders a collection of views based on the items array set
  as its content.  You will not use this class directly as it does not
  order the views in any manner.  Instead you will want to subclass
  SC.CollectionView or use one of its existing subclasses in SproutCore
  such as SC.ListView, which renders items in a vertical list or SC.GridView,
  which renders items in a grid.

  To use a CollectionView subclass, just create the view and set the 'content'
  property to an array of objects.  The collection view will create instances of
  the given exampleView class for each item in the array.  You can also bind to
  the selection property if you want to monitor the current selection.

  # Extreme Performance

  SC.CollectionView does not just naively render one view per item and
  instead is aggressively optimized to allow for collections of
  hundreds of thousands of items to perform as fast as only a few items.  In
  order to achieve this, first it only creates views and elements for the items
  currently visible.  Therefore, when overriding SC.CollectionView, it is
  critically important to implement `contentIndexesInRect` which should return
  only the indexes of those items that should appear within the visible rect.
  By returning only the indexes that are visible, SC.CollectionView can represent
  enormous collections with only a few views and elements.

  The second optimization, is that SC.CollectionView will pool and reuse the
  few views and elements that it does need to create.  Creating and destroying
  views incrementally hurts performance, so by reusing the same views over and
  over, the view can much more quickly alter the set of visible views.  As well,
  inserting and removing elements from the DOM takes more time than simply
  modifying the contents of the same elements over and over, which allows us to
  leave the DOM tree untouched.

  @extends SC.View
  @extends SC.CollectionViewDelegate
  @extends SC.CollectionContent
  @since SproutCore 0.9
*/
SC.CollectionView = SC.View.extend(SC.ActionSupport, SC.CollectionViewDelegate, SC.CollectionContent,
/** @scope SC.CollectionView.prototype */ {

  /** @private */
  _content: null,

  /** @private */
  _cv_actionTimer: null,

  /** @private */
  _cv_contentRangeObserver: null,

  /** @private */
  _cv_selection: null,

  /** @private */
  _pools: null,

  /** @private Timer used to track time immediately after a mouse up event. */
  _sc_clearMouseJustDownTimer: null,

  /** @private Flag used to track when the mouse is pressed. */
  _sc_isMouseDown: false,

  /** @private Flag used to track when mouse was just down so that mousewheel events firing as the finger is lifted don't shoot the slider over. */
  _sc_isMouseJustDown: false,

  /** @private */
  _sc_itemViews: null,


  /** @private */
  _TMP_DIFF1: SC.IndexSet.create(),

  /** @private */
  _TMP_DIFF2: SC.IndexSet.create(),

  /**
    @type Array
    @default ['sc-collection-view']
    @see SC.View#classNames
  */
  classNames: ['sc-collection-view'],

  /**
    @type Array
    @default ['isActive']
  */
  displayProperties: ['isActive'],

  /**
    @type String
    @default 'collectionRenderDelegate'
  */
  renderDelegateName: 'collectionRenderDelegate',

  /**
    @type Number
    @default 200
  */
  ACTION_DELAY: 200,

  // ......................................
  // PROPERTIES
  //

  /**
    If `YES`, uses the experimental fast `CollectionView` path.

    *Note* The performance improvements in the experimental code have been
    integrated directly into SC.CollectionView.  If you have set this property
    to true, you should set it to false and refer to the class documentation
    explaining how to modify the performance boost behavior if necessary.

    Generally, no modifications should be necessary and you should see an
    immediate performance improvement in all collections, especially on
    mobile devices.

    @type Boolean
    @deprecated Version 1.10
    @default NO
  */
  useFastPath: NO,

  /**
    An array of content objects

    This array should contain the content objects you want the collection view
    to display.  An item view (based on the `exampleView` view class) will be
    created for each content object, in the order the content objects appear
    in this array.

    If you make the collection editable, the collection view will also modify
    this array using the observable array methods of `SC.Array`.

    Usually you will want to bind this property to a controller property
    that actually contains the array of objects you to display.

    @type SC.Array
    @default null
  */
  content: null,

  /** @private */
  contentBindingDefault: SC.Binding.multiple(),

  /**
    The current length of the content.

    @readonly
    @type Number
    @default 0
  */
  length: 0,

  /**
    The set of indexes that are currently tracked by the collection view.
    This property is used to determine the range of items the collection view
    should monitor for changes.

    The default implementation of this property returns an index set covering
    the entire range of the content.  It changes automatically whenever the
    length changes.

    Note that the returned index set for this property will always be frozen.
    To change the nowShowing index set, you must create a new index set and
    apply it.

    @field
    @type SC.IndexSet
    @observes length
    @observes clippingFrame
  */
  nowShowing: function() {
    // If there is an in-scroll clipping frame, use it.
    var clippingFrame = this.get('clippingFrame');

    return this.computeNowShowing(clippingFrame);
  }.property('length', 'clippingFrame').cacheable(),

  /**
    Indexes of selected content objects.  This `SC.SelectionSet` is modified
    automatically by the collection view when the user changes the selection
    on the collection.

    Any item views representing content objects in this set will have their
    isSelected property set to `YES` automatically.

    @type SC.SelectionSet
    @default null
  */
  selection: null,

  /**
    Allow user to select content using the mouse and keyboard.

    Set this property to `NO` to disallow the user from selecting items. If you
    have items in your `selectedIndexes` property, they will still be reflected
    visually.

    @type Boolean
    @default YES
  */
  isSelectable: YES,

  /** @private */
  isSelectableBindingDefault: SC.Binding.bool(),

  /**
    Enable or disable the view.

    The collection view will set the `isEnabled` property of its item views to
    reflect the same view of this property.  Whenever `isEnabled` is false,
    the collection view will also be not selectable or editable, regardless of
    the settings for `isEditable` & `isSelectable`.

    @type Boolean
    @default YES
  */
  isEnabled: YES,

  /** @private */
  isEnabledBindingDefault: SC.Binding.bool(),

  /**
    Allow user to edit content views.

    Whenever `isEditable` is false, the user will not be able to reorder, add,
    or delete items regardless of the `canReorderContent` and `canDeleteContent`
    and `isDropTarget` properties.

    @type Boolean
    @default YES
  */
  isEditable: YES,

  /** @private */
  isEditableBindingDefault: SC.Binding.bool(),

  /**
    Allow user to reorder items using drag and drop.

    If true, the user can use drag and drop to reorder items in the list.
    If you also accept drops, this will allow the user to drop items into
    specific points in the list.  Otherwise items will be added to the end.

    When canReorderContent is true, item views will have the `isReorderable`
    property set to true (if the `isEditable` is true on the collection).

    @type Boolean
    @default NO
  */
  canReorderContent: NO,

  /** @private */
  canReorderContentBindingDefault: SC.Binding.bool(),

  /**
    Allow the user to delete items using the delete key

    If true the user will be allowed to delete selected items using the delete
    key.  Otherwise deletes will not be permitted.

    When canDeleteContent is true, item views will have the `isDeletable`
    property set to true (if the `isEditable` is true on the collection).

    @type Boolean
    @default NO
  */
  canDeleteContent: NO,

  /** @private */
  canDeleteContentBindingDefault: SC.Binding.bool(),

  /**
    Allow user to edit the content by double clicking on it or hitting return.
    This will only work if isEditable is `YES` and the item view implements
    the `beginEditing()` method.

    When canEditContent is true, item views will have the `isEditable`
    property set to true (if the `isEditable` is true on the collection).

    @type Boolean
  */
  canEditContent: NO,

  /** @private */
  canEditContentBindingDefault: SC.Binding.bool(),

  /**
    Accept drops for data other than reordering.

    Setting this property to return true when the view is instantiated will
    cause it to be registered as a drop target, activating the other drop
    machinery.

    @type Boolean
    @default NO
  */
  isDropTarget: NO,

  /**
    Use toggle selection instead of normal click behavior.

    If set to true, then selection will use a toggle instead of the normal
    click behavior.  Command modifiers will be ignored and instead clicking
    once will select an item and clicking on it again will deselect it.

    @type Boolean
    @default NO
  */
  useToggleSelection: NO,

  /**
    Trigger the action method on a single click.

    Normally, clicking on an item view in a collection will select the content
    object and double clicking will trigger the action method on the
    collection view.

    If you set this property to `YES`, then clicking on a view will both select
    it (if `isSelected` is true) and trigger the action method.

    Use this if you are using the collection view as a menu of items.

    @type Boolean
    @default NO
  */
  actOnSelect: NO,


  /**
    Select an item immediately on mouse down

    Normally as soon as you begin a click the item will be selected.

    In some UI scenarios, you might want to prevent selection until
    the mouse is released, so you can perform, for instance, a drag operation
    without actually selecting the target item.

    @type Boolean
    @default YES
  */
  selectOnMouseDown: YES,

  /**
    The view class to use when creating new item views.

    The collection view will automatically create an instance of the view
    class you set here for each item in its content array.  You should provide
    your own subclass for this property to display the type of content you
    want.

    The view you set here should understand the following properties, which
    it can use to alter its display:

    - `content` -- The content object from the content array your view should
      display.
    - `isEnabled` -- False if the view should appear disabled.
    - `isSelected` -- True if the view should appear selected.
    - `contentIndex` -- The current index of the view's content.
    - `isEditable` -- True if the view should appear editable by clicking on it
      or hitting the Return key.
    - `isReorderable` -- True if the view should appear reorderable by dragging
      it.
    - `isDeletable` -- True if the view should appear deletable, by clicking on
      a delete button within it or hitting the Delete key.

    # Working with View and Element Pooling

    As noted in the SC.CollectionView description above, by default the few
    instances that are needed of the exampleView class will be created and then
    reused.  Reusing an exampleView means that the content, isSelected, isEnabled,
    isEditable, isReorderable, isDeletable and contentIndex properties will be
    updated as an existing view is pulled from the pool to be displayed.

    If your custom exampleView class has trouble being reused, you may want to
    implement the `sleepInPool` and `awakeFromPool` methods in your exampleView.
    These two methods will be called on the view, one before it is pooled,
    sleepInPool, and the other before it is unpooled, awakeFromPool.  For
    example, if your item views have images and there is a delay for new
    images to appear, you may want to use sleepInPool to ensure the previous
    image is unloaded so it doesn't appear momentarily while the new image loads.

    Also, if the rendered output of your exampleView does not update properly you
    can disable reuse of the layer by setting `isLayerReusable` to false.  This
    will reduce the performance of your collection though and it is recommended
    that you instead look at ways to properly update the existing layer as the
    content changes.

    Finally, if you really don't want view or element reuse at all, you may
    disable them both by setting `isReusable` to false in your exampleView class.
    Your collection will still benefit greatly from incremental rendering, but
    it will perform slightly less well than with optimal re-use.

    # Event handling

    In general you do not want your child views to actually respond to mouse
    and keyboard events themselves.  It is better to let the collection view
    do that.

    If you do implement your own event handlers such as mouseDown or mouseUp,
    you should be sure to actually call the same method on the collection view
    to give it the chance to perform its own selection housekeeping.

    @type SC.View
    @default SC.View
  */
  exampleView: SC.View,

  /**
    If set, this key will be used to get the example view for a given
    content object.  The exampleView property will be ignored.

    @type String
    @default null
  */
  contentExampleViewKey: null,

  /**
    The view class to use when creating new group item views.

    The collection view will automatically create an instance of the view
    class you set here for each item in its content array.  You should provide
    your own subclass for this property to display the type of content you
    want.

    If you leave this set to null then the regular example view will be used
    with the isGroupView property set to YES on the item view.

    @type SC.View
    @default null
  */
  groupExampleView: null,

  /**
    If set, this key will be used to get the example view for a given
    content object.  The `groupExampleView` property will be ignored.

    @type String
    @default null
  */
  contentGroupExampleViewKey: null,

  /**
    Invoked when the user double clicks on an item (or single clicks of
    actOnSelect is true)

    Set this to the name of the action you want to send down the
    responder chain when the user double clicks on an item (or single clicks
    if `actOnSelect` is true).  You can optionally specify a specific target as
    well using the target property.

    If you do not specify an action, then the collection view will also try to
    invoke the action named on the target item view.

    @type String
    @default null
    @see SC.ActionSupport
  */
  action: null,

  /**
    Optional target to send the action to when the user double clicks.

    If you set the action property to the name of an action, you can
    optionally specify the target object you want the action to be sent to.
    This can be either an actual object or a property path that will resolve
    to an object at the time that the action is invoked.

    @type String|Object
    @default null
  */
  target: null,

  /**
    Invoked when the user single clicks on the right icon of an item.

    Set this to the name of the action you want to send down the
    responder chain when the user single clicks on the right icon of an item
    You can optionally specify a specific target as
    well using the rightIconTarget property.

    @type String
    @default null
  */
  rightIconAction: null,

  /**
    Optional target to send the action to when the user clicks on the right icon
    of an item.

    If you set the rightIconAction property to the name of an action, you can
    optionally specify the target object you want the action to be sent to.
    This can be either an actual object or a property path that will resolve
    to an object at the time that the action is invoked.

    @type String|Object
    @default null
  */
  rightIconTarget: null,

  /**
    Property on content items to use for display.

    Built-in item views such as the `LabelView`s and `ImageView`s will use the
    value of this property as a key on the content object to determine the
    value they should display.

    For example, if you set `contentValueKey` to 'name' and set the
    exampleView to an `SC.LabelView`, then the label views created by the
    collection view will display the value of the content.name.

    If you are writing your own custom item view for a collection, you can
    get this behavior automatically by including the SC.Control mixin on your
    view.  You can also ignore this property if you like.  The collection view
    itself does not use this property to impact rendering.

    @type String
    @default null
  */
  contentValueKey: null,

  /**
    Enables keyboard-based navigate, deletion, etc. if set to true.

    @type Boolean
    @default NO
  */
  acceptsFirstResponder: NO,

  /**
    Changing this property value by default will cause the `CollectionView` to
    add/remove an 'active' class name to the root element.

    @type Boolean
    @default NO
  */
  isActive: NO,

  /** @deprecated Version 1.11.0.  SC.ScrollView observes the frame (height/width) of the collection.

    @type Number
    @default 0
  */
  calculatedHeight: 0,

  /** @deprecated Version 1.11.0.  SC.ScrollView observes the frame (height/width) of the collection.

    @type Number
    @default 0
  */
  calculatedWidth: 0,


  // ..........................................................
  // SUBCLASS METHODS
  //

  /**
    Adjusts the layout of the view according to the computed layout.  Call
    this method to apply the computed layout to the view.
  */
  adjustLayout: function () {
    var layout = this.computeLayout();
    if (layout) { this.adjust(layout); }
  },

  /**
    Override to return the computed layout dimensions of the collection view.
    You can omit any dimensions you don't care about setting in your
    computed value.

    This layout is automatically applied whenever the content changes.

    If you don't care about computing the layout at all, you can return null.

    @returns {Hash} layout properties
  */
  computeLayout: function() {
    return null;
  },

  /**
    Override to compute the layout of the itemView for the content at the
    specified index.  This layout will be applied to the view just before it
    is rendered.

    @param {Number} contentIndex the index of content being rendered by
      itemView
    @returns {Hash} a view layout
  */
  layoutForContentIndex: function(contentIndex) {
    return null;
  },

  /**
    This computed property returns an index set selecting all content indexes.
    It will recompute anytime the length of the collection view changes.

    This is used by the default `contentIndexesInRect()` implementation.

    @field
    @type SC.IndexSet
    @observes length
  */
  allContentIndexes: function() {
    return SC.IndexSet.create(0, this.get('length')).freeze();
  }.property('length').cacheable(),

  /**
    Override to return an IndexSet with the indexes that are at least
    partially visible in the passed rectangle.  This method is used by the
    default implementation of `computeNowShowing()` to determine the new
    `nowShowing` range after a scroll.

    Override this method to implement incremental rendering.

    @param {Rect} rect the visible rect
    @returns {SC.IndexSet} now showing indexes
  */
  contentIndexesInRect: function(rect) {
    return null; // select all
  },

  /**
    Compute the nowShowing index set.  The default implementation simply
    returns the full range.  Override to implement incremental rendering.

    You should not normally call this method yourself.  Instead get the
    nowShowing property.

    @returns {SC.IndexSet} new now showing range
  */
  computeNowShowing: function (clippingFrame) {
    var r = this.contentIndexesInRect(clippingFrame);
    if (!r) r = this.get('allContentIndexes'); // default show all

    // make sure the index set doesn't contain any indexes greater than the
    // actual content.
    else {
      var len = this.get('length'),
          max = r.get('max');
      if (max > len) r = r.copy().remove(len, max-len).freeze();
    }

    return r;
  },

  /**
    Override to show the insertion point during a drag.

    Called during a drag to show the insertion point.  Passed value is the
    item view that you should display the insertion point before.  If the
    passed value is `null`, then you should show the insertion point *AFTER* that
    last item view returned by the itemViews property.

    Once this method is called, you are guaranteed to also receive a call to
    `hideInsertionPoint()` at some point in the future.

    The default implementation of this method does nothing.

    @param itemView {SC.ClassicView} view the insertion point should appear directly before. If null, show insertion point at end.
    @param dropOperation {Number} the drop operation.  will be SC.DROP_BEFORE, SC.DROP_AFTER, or SC.DROP_ON

    @returns {void}
  */
  showInsertionPoint: function(itemView, dropOperation) {},

  /**
    Override to hide the insertion point when a drag ends.

    Called during a drag to hide the insertion point.  This will be called
    when the user exits the view, cancels the drag or completes the drag.  It
    will not be called when the insertion point changes during a drag.

    You should expect to receive one or more calls to
    `showInsertionPointBefore()` during a drag followed by at least one call to
    this method at the end.  Your method should not raise an error if it is
    called more than once.

    @returns {void}
  */
  hideInsertionPoint: function() {},


  // ..........................................................
  // DELEGATE SUPPORT
  //


  /**
    Delegate used to implement fine-grained control over collection view
    behaviors.

    You can assign a delegate object to this property that will be consulted
    for various decisions regarding drag and drop, selection behavior, and
    even rendering.  The object you place here must implement some or all of
    the `SC.CollectionViewDelegate` mixin.

    If you do not supply a delegate but the content object you set implements
    the `SC.CollectionViewDelegate` mixin, then the content will be
    automatically set as the delegate.  Usually you will work with a
    `CollectionView` in this way rather than setting a delegate explicitly.

    @type SC.CollectionViewDelegate
    @default null
  */
  delegate: null,

  /**
    The delegate responsible for handling selection changes.  This property
    will be either the delegate, content, or the collection view itself,
    whichever implements the `SC.CollectionViewDelegate` mixin.

    @field
    @type Object
  */
  selectionDelegate: function() {
    var del = this.get('delegate'), content = this.get('content');
    return this.delegateFor('isCollectionViewDelegate', del, content);
  }.property('delegate', 'content').cacheable(),

  /**
    The delegate responsible for providing additional display information
    about the content.  If you bind a collection view to a controller, this
    the content will usually also be the content delegate, though you
    could implement your own delegate if you prefer.

    @field
    @type Object
  */
  contentDelegate: function() {
    var del = this.get('delegate'), content = this.get('content');
    return this.delegateFor('isCollectionContent', del, content);
  }.property('delegate', 'content').cacheable(),


  // ..........................................................
  // CONTENT CHANGES
  //

  /**
    Called whenever the content array or an item in the content array or a
    property on an item in the content array changes.  Reloads the appropriate
    item view when the content array itself changes or calls
    `contentPropertyDidChange()` if a property changes.

    Normally you will not call this method directly though you may override
    it if you need to change the way changes to observed ranges are handled.

    @param {SC.Array} content the content array generating the change
    @param {Object} object the changed object
    @param {String} key the changed property or '[]' or an array change
    @param {SC.IndexSet} indexes affected indexes or null for all items
    @returns {void}
  */
  contentRangeDidChange: function(content, object, key, indexes) {
    if (!object && (key === '[]')) {
      this.notifyPropertyChange('_contentGroupIndexes');
      this.reload(indexes); // note: if indexes == null, reloads all
    } else {
      this.contentPropertyDidChange(object, key, indexes);
    }
  },

  /**
    Called whenever a property on an item in the content array changes.  This
    is only called if you have set `observesContentProperties` to `YES`.

    Override this property if you want to do some custom work whenever a
    property on a content object changes.

    The default implementation does nothing.

    @param {Object} target the object that changed
    @param {String} key the property that changed value
    @param {SC.IndexSet} indexes the indexes in the content array affected
    @returns {void}
  */
  contentPropertyDidChange: function(target, key, indexes) {},

  /**
    Called whenever the view needs to updates its `contentRangeObserver` to
    reflect the current nowShowing index set.  You will not usually call this
    method yourself but you may override it if you need to provide some
    custom range observer behavior.

    Note that if you do implement this method, you are expected to maintain
    the range observer object yourself.  If a range observer has not been
    created yet, this method should create it.  If an observer already exists
    this method should update it.

    When you create a new range observer, the observer must eventually call
    `contentRangeDidChange()` for the collection view to function properly.

    If you override this method you probably also need to override
    `destroyRangeObserver()` to cleanup any existing range observer.

    @returns {void}
  */
  updateContentRangeObserver: function() {
    var nowShowing = this.get('nowShowing'),
        observer   = this._cv_contentRangeObserver,
        content    = this.get('content');

    if (!content) return ; // nothing to do

    if (observer) {
      content.updateRangeObserver(observer, nowShowing);
    } else {
      var func = this.contentRangeDidChange;
      observer = content.addRangeObserver(nowShowing, this, func, null);

      // Cache the range observer so we can clean it up later.
      this._cv_contentRangeObserver = observer ;
    }

  },

  /**
    Called whever the view needs to invalidate the current content range
    observer.  This is called whenever the content array changes.  You will
    not usually call this method yourself but you may override it if you
    provide your own range observer behavior.

    Note that if you override this method you should probably also override
    `updateRangeObserver()` to create or update a range observer as needed.

    @returns {void}
  */
  removeContentRangeObserver: function() {
    var content  = this.get('content'),
        observer = this._cv_contentRangeObserver ;

    if (observer) {
      if (content) content.removeRangeObserver(observer);
      this._cv_contentRangeObserver = null ;
    }
  },

  /**
    Called whenever the content length changes.  This will invalidate the
    length property of the view itself causing the `nowShowing` to recompute
    which will in turn update the UI accordingly.

    @returns {void}
  */
  contentLengthDidChange: function() {
    var content = this.get('content');
    this.set('length', content ? content.get('length') : 0);
    this.invokeOnce(this.adjustLayout);
  },

  /** @private
    Whenever content property changes to a new value:

      - remove any old observers
      - setup new observers (maybe wait until end of runloop to do this?)
      - recalc height/reload content
      - set content as delegate if delegate was old content
      - reset selection

    Whenever content array mutates:

      - possibly stop observing property changes on objects, observe new objs
      - reload effected item views
      - update layout for receiver
  */
  _cv_contentDidChange: function() {
    var content = this.get('content'),
        lfunc   = this.contentLengthDidChange ;

    if (content === this._content) return; // nothing to do

    // cleanup old content
    this.removeContentRangeObserver();
    if (this._content) {
      this._content.removeObserver('length', this, lfunc);
    }

    // Destroy all pooled views.
    if (this._pools) {
      for (var key in this._pools) {
        this._pools[key].invoke('destroy');
      }

      this._pools = null;
    }

    // cache
    this._content = content;

    // add new observers - range observer will be added lazily
    if (content) {
      content.addObserver('length', this, lfunc);
    }

    // notify all items changed
    this.contentLengthDidChange();
    this.contentRangeDidChange(content, null, '[]', null);
  }.observes('content'),

  // ..........................................................
  // ITEM VIEWS
  //

  /** @private
    The indexes that need to be reloaded.  Must be one of YES, NO, or an
    SC.IndexSet.
  */
  _invalidIndexes: NO,

  /** @private
    We need to reload if isEnabled, isEditable, canEditContent, canReorderContent or
    canDeleteContent change.
  */
  _isEnabledDidChange: function () {
    // Reload the nowShowing indexes.
    this.reload();
  }.observes('isEnabled', 'isEditable', 'canEditContent', 'canReorderContent', 'canDeleteContent'),

  /**
    Regenerates the item views for the content items at the specified indexes.
    If you pass null instead of an index set, regenerates all item views.

    This method is called automatically whenever the content array changes in
    an observable way, but you can call its yourself also if you need to
    refresh the collection view for some reason.

    Note that if the length of the content is shorter than the child views
    and you call this method, then the child views will be removed no matter
    what the index.

    @param {SC.IndexSet} indexes
    @returns {SC.CollectionView} receiver
  */
  reload: function(indexes) {
    var invalid = this._invalidIndexes,
      length;

    if (indexes && invalid !== YES) {
      if (invalid) invalid.add(indexes);
      else invalid = this._invalidIndexes = indexes.clone();

      // If the last item in the list changes, we need to reload the previous last
      // item also so that the isLast attribute updates appropriately.
      length = this.get('length');
      if (length > 1 && invalid.max === length) {
        invalid.add(length - 2);
    }
    } else {
      this._invalidIndexes = YES ; // force a total reload
    }

    if (this.get('isVisibleInWindow')) this.invokeOnce(this.reloadIfNeeded);

    return this ;
  },

  /**
    Invoked once per runloop to actually reload any needed item views.
    You can call this method at any time to actually force the reload to
    happen immediately if any item views need to be reloaded.

    @returns {SC.CollectionView} receiver
  */
  reloadIfNeeded: function() {
    var invalid = this._invalidIndexes;
    if (!invalid || !this.get('isVisibleInWindow')) return this ; // delay
    this._invalidIndexes = NO ;

    var len, existing,
        nowShowing = this.get('nowShowing'),
      itemViews = this._sc_itemViews || [],
      idx;

    // if the set is defined but it contains the entire nowShowing range, just
    // replace
    if (invalid.isIndexSet && invalid.contains(nowShowing)) invalid = YES ;

    // if an index set, just update indexes
    if (invalid.isIndexSet) {

      // Go through the invalid indexes and determine if the matching views
      // should be redrawn (exists and still showing), should be created (
      // doesn't exist and now showing) or should be destroyed (exists and no
      // longer showing).
      invalid.forEach(function(idx) {
        // Get the existing item view, if there is one.
        existing = itemViews[idx];
        if (existing) {
          // Exists so remove it (may send to pool).
          this._removeItemView(existing, idx);
        }

        // Create it (may fetch from pool).
        if (nowShowing.contains(idx)) {
          this.itemViewForContentIndex(idx, YES);
          }
      },this);

    // if set is NOT defined, replace entire content with nowShowing
    } else {

      // Process the removals.
      for (idx = 0, len = itemViews.length;  idx < len; idx++) {
        // Get the existing item view, if there is one.
        existing = itemViews ? itemViews[idx] : null;
        if (existing) {
          this._removeItemView(existing, idx);
          }
        }

      // Only after the children are removed should we create the new views.
      // We do this in order to maximize the chance of re-use should the view
      // be marked as such.
      nowShowing.forEach(function(idx) {
        this.itemViewForContentIndex(idx, YES);
      }, this);
    }

    return this ;
  },

  /** @private Use a shared object so that we are not creating objects for every item view configuration. */
  _TMP_ATTRS: {},

  /** @private
    The item view classes, cached here for performance. Note that if these ever change, they may
    also need to be updated in the isGroupView code block in _reconfigureItemView below.
  */
  _COLLECTION_CLASS_NAMES: ['sc-collection-item', 'sc-item'],

  /** @private
    The group view classes, cached here for performance. Note that if these ever change, they may
    also need to be updated in the isGroupView code block in _reconfigureItemView below.
  */
  _GROUP_COLLECTION_CLASS_NAMES: ['sc-collection-item', 'sc-group-item'],

  /**
    Returns the item view for the content object at the specified index. Call
    this method instead of accessing child views directly whenever you need
    to get the view associated with a content index.

    Although this method take two parameters, you should almost always call
    it with just the content index.  The other two parameters are used
    internally by the CollectionView.

    If you need to change the way the collection view manages item views
    you can override this method as well.  If you just want to change the
    default options used when creating item views, override createItemView()
    instead.

    Note that if you override this method, then be sure to implement this
    method so that it uses a cache to return the same item view for a given
    index unless "force" is YES.  In that case, generate a new item view and
    replace the old item view in your cache with the new item view.

    @param {Number} idx the content index
    @param {Boolean} rebuild internal use only
    @returns {SC.View} instantiated view
  */
  itemViewForContentIndex: function(idx, rebuild) {
    var ret,
      views;

    // Gatekeep! Since this method is often called directly by loops that may
    // suffer from bounds issues, we should validate the idx and return nothing
    // rather than returning an invalid item view.
    if (SC.none(idx) || idx < 0 || idx >= this.get('length')) {
      


      return null; // FAST PATH!!
    }


    // Initialize internal views cache.
    views = this._sc_itemViews;
    if (!views) { views = this._sc_itemViews = []; }

    // Use an existing view for this index if we have it and aren't rebuilding all.
    ret = views[idx];
    if (ret) {
      if (rebuild) {
        ret.destroy();
        ret = null;
    } else {
        return ret;
    }
    }

    var attrs,
      containerView = this.get('containerView') || this,
      exampleView,
      pool,
      prototype;

    // Set up the attributes for the view.
    attrs = this._attrsForContentIndex(idx);

    // If the view is reusable and there is an appropriate view inside the
    // pool, simply reuse it to avoid having to create a new view.
    exampleView = this._exampleViewForContentIndex(idx);
    prototype = exampleView.prototype;
    if (SC.none(prototype.isReusable) || prototype.isReusable) {
      pool = this._poolForExampleView(exampleView);

      // Is there a view we can re-use?
      if (pool.length > 0) {
        ret = pool.shift();

        // Reconfigure the view.
        this._reconfigureItemView(ret, attrs);

        // Awake the view.
        if (ret.awakeFromPool) { ret.awakeFromPool(this); }

        // Recreate the layer if it was destroyed.
        if (!ret.get('_isRendered')) {
          ret.invokeOnce(ret._doRender);
        }
        }
      }

    // If we weren't able to re-use a view, then create a new one.
    if (!ret) {
      ret = this.createItemView(exampleView, idx, attrs);
      containerView.insertBefore(ret, null);   // Equivalent to 'append()', but avoids one more function call
      }

    views[idx] = ret;
    return ret ;
  },

  /**
    Convenience method for getting the item view of a content object.

    @param {Object} object
  */
  itemViewForContentObject: function(object) {
    var content = this.get('content');
    if (!content) return null;
    var contentIndex = content.indexOf(object);
    if (contentIndex === -1) return null;
    return this.itemViewForContentIndex(contentIndex);
  },

  /** @private */
  _TMP_LAYERID: [],

  /**
    Primitive to instantiate an item view.  You will be passed the class
    and a content index.  You can override this method to perform any other
    one time setup.

    Note that item views may be created somewhat frequently so keep this fast.

    *IMPORTANT:* The attrs hash passed is reused each time this method is
    called.   If you add properties to this hash be sure to delete them before
    returning from this method.

    @param {Class} exampleClass example view class
    @param {Number} idx the content index
    @param {Hash} attrs expected attributes
    @returns {SC.View} item view instance
  */
  createItemView: function(exampleClass, idx, attrs) {
    return exampleClass.create(attrs);
  },

  /**
    Generates a layerId for the passed index and item.  Usually the default
    implementation is suitable.

    @param {Number} idx the content index
    @returns {String} layer id, must be suitable for use in HTML id attribute
  */
  layerIdFor: function(idx) {
    var ret = this._TMP_LAYERID;
    ret[0] = this.get('layerId');
    ret[1] = idx;
    return ret.join('-');
  },

  /**
    Extracts the content index from the passed layerId.  If the layer id does
    not belong to the receiver or if no value could be extracted, returns NO.

    @param {String} id the layer id
  */
  contentIndexForLayerId: function(id) {
    if (!id || !(id = id.toString())) return null ; // nothing to do

    var base = this.get('layerId') + '-';

    // no match
    if ((id.length <= base.length) || (id.indexOf(base) !== 0)) return null ;
    var ret = Number(id.slice(id.lastIndexOf('-')+1));
    return isNaN(ret) ? null : ret ;
  },


  /**
    Find the first content item view for the passed event.

    This method will go up the view chain, starting with the view that was the
    target of the passed event, looking for a child item.  This will become
    the view that is selected by the mouse event.

    This method only works for mouseDown & mouseUp events.  mouseMoved events
    do not have a target.

    @param {SC.Event} evt An event
    @returns {SC.View} the item view or null
  */
  itemViewForEvent: function(evt) {
    var responder = this.getPath('pane.rootResponder') ;
    if (!responder) return null ; // fast path

    var element = evt.target,
        layer   = this.get('layer'),
        contentIndex = null,
        id;

    // walk up the element hierarchy until we find this or an element with an
    // id matching the base guid (i.e. a collection item)
    while (element && element !== document && element !== layer) {
      id = element ? SC.$(element).attr('id') : null ;
      if (id && (contentIndex = this.contentIndexForLayerId(id)) !== null) {
          break;
      }
      element = element.parentNode ;
    }

    // no matching element found?
    if (contentIndex===null || (element === layer)) {
      element = layer = null; // avoid memory leaks
      return null;
    }

    // okay, found the DOM node for the view, go ahead and create it
    // first, find the contentIndex
    if (contentIndex >= this.get('length')) {
      throw new Error("layout for item view %@ was found when item view does not exist (%@)".fmt(id, this));
    }

    return this.itemViewForContentIndex(contentIndex);
  },

  // ..........................................................
  // DISCLOSURE SUPPORT
  //

  /**
    Expands any items in the passed selection array that have a disclosure
    state.

    @param {SC.IndexSet} indexes the indexes to expand
    @returns {SC.CollectionView} receiver
  */
  expand: function(indexes) {
    if (!indexes) return this; // nothing to do
    var del     = this.get('contentDelegate'),
        content = this.get('content');

    indexes.forEach(function(i) {
      var state = del.contentIndexDisclosureState(this, content, i);
      if (state === SC.BRANCH_CLOSED) del.contentIndexExpand(this,content,i);
    }, this);
    return this;
  },

  /**
    Collapses any items in the passed selection array that have a disclosure
    state.

    @param {SC.IndexSet} indexes the indexes to expand
    @returns {SC.CollectionView} receiver
  */
  collapse: function(indexes) {
    if (!indexes) return this; // nothing to do
    var del     = this.get('contentDelegate'),
        content = this.get('content');

    indexes.forEach(function(i) {
      var state = del.contentIndexDisclosureState(this, content, i);
      if (state === SC.BRANCH_OPEN) del.contentIndexCollapse(this,content,i);
    }, this);
    return this;
  },

  // ..........................................................
  // SELECTION SUPPORT
  //

  /** @private
    Called whenever the selection object is changed to a new value.  Begins
    observing the selection for changes.
  */
  _cv_selectionDidChange: function() {
    var sel  = this.get('selection'),
        last = this._cv_selection,
        func = this._cv_selectionContentDidChange;

    if (sel === last) return; // nothing to do
    if (last) last.removeObserver('[]', this, func);
    if (sel) sel.addObserver('[]', this, func);

    this._cv_selection = sel ;
    this._cv_selectionContentDidChange();
  }.observes('selection'),

  /** @private
    Called whenever the selection object or its content changes.  This will
    repaint any items that changed their selection state.
  */
  _cv_selectionContentDidChange: function() {
    var sel  = this.get('selection'),
        last = this._cv_selindexes, // clone of last known indexes
        content = this.get('content'),
        diff ;

    // save new last
    this._cv_selindexes = sel ? sel.frozenCopy() : null;

    // determine which indexes are now invalid
    if (last) last = last.indexSetForSource(content);
    if (sel) sel = sel.indexSetForSource(content);

    if (sel && last) diff = sel.without(last).add(last.without(sel));
    else diff = sel || last;

    if (diff && diff.get('length')>0) this.reloadSelectionIndexes(diff);
  },

  /** @private
    Contains the current item views that need their selection to be repainted.
    This may be either NO, YES, or an IndexSet.
  */
  _invalidSelection: NO,

  /**
    Called whenever the selection changes.  The passed index set will contain
    any affected indexes including those indexes that were previously
    selected and now should be deselected.

    Pass null to reload the selection state for all items.

    @param {SC.IndexSet} indexes affected indexes
    @returns {SC.CollectionView} receiver
  */
  reloadSelectionIndexes: function(indexes) {
    var invalid = this._invalidSelection ;
    if (indexes && (invalid !== YES)) {
      if (invalid) { invalid.add(indexes) ; }
      else { invalid = this._invalidSelection = indexes.copy(); }

    } else this._invalidSelection = YES ; // force a total reload

    if (this.get('isVisibleInWindow')) {
      this.invokeOnce(this.reloadSelectionIndexesIfNeeded);
    }

    return this ;
  },

  /**
    Reloads the selection state if needed on any dirty indexes.  Normally this
    will run once at the end of the runloop, but you can force the item views
    to reload their selection immediately by calling this method.

    You can also override this method if needed to change the way the
    selection is reloaded on item views.  The default behavior will simply
    find any item views in the nowShowing range that are affected and
    modify them.

    @returns {SC.CollectionView} receiver
  */
  reloadSelectionIndexesIfNeeded: function() {
    var invalid = this._invalidSelection;
    if (!invalid || !this.get('isVisibleInWindow')) return this ;

    var nowShowing = this.get('nowShowing'),
        reload     = this._invalidIndexes,
        content    = this.get('content'),
        sel        = this.get('selection');

    this._invalidSelection = NO; // reset invalid

    // fast path.  if we are going to reload everything anyway, just forget
    // about it.  Also if we don't have a nowShowing, nothing to do.
    if (reload === YES || !nowShowing) return this ;

    // if invalid is YES instead of index set, just reload everything
    if (invalid === YES) invalid = nowShowing;

    // if we will reload some items anyway, don't bother
    if (reload && reload.isIndexSet) invalid = invalid.without(reload);

    // iterate through each item and set the isSelected state.
    invalid.forEach(function(idx) {
      if (!nowShowing.contains(idx)) return; // not showing
      var view = this.itemViewForContentIndex(idx, NO);
      if (view) view.set('isSelected', sel ? sel.contains(content, idx) : NO);
    },this);

    return this ;
  },

  /**
    Selection primitive.  Selects the passed IndexSet of items, optionally
    extending the current selection.  If extend is NO or not passed then this
    will replace the selection with the passed value.  Otherwise the indexes
    will be added to the current selection.

    @param {Number|SC.IndexSet} indexes index or indexes to select
    @param extend {Boolean} optionally extend the selection
    @returns {SC.CollectionView} receiver
  */
  select: function(indexes, extend) {
    var content = this.get('content'),
        del     = this.get('selectionDelegate'),
        groupIndexes = this.get('_contentGroupIndexes'),
        sel;

    if (!this.get('isSelectable') || !this.get('isEnabledInPane')) return this;

    // normalize
    if (SC.typeOf(indexes) === SC.T_NUMBER) {
      indexes = SC.IndexSet.create(indexes, 1);
    }

    // if we are passed an empty index set or null, clear the selection.
    if (indexes && indexes.get('length')>0) {

      // first remove any group indexes - these can never be selected
      if (groupIndexes && groupIndexes.get('length')>0) {
        indexes = indexes.copy().remove(groupIndexes);
      }

      // give the delegate a chance to alter the items
      indexes = del.collectionViewShouldSelectIndexes(this, indexes, extend);
      if (!indexes || indexes.get('length')===0) return this; // nothing to do

    } else indexes = null;

    // build the selection object, merging if needed
    if (extend && (sel = this.get('selection'))) sel = sel.copy();
    else sel = SC.SelectionSet.create();

    if (indexes && indexes.get('length')>0) {

      // when selecting only one item, always select by content
      if (indexes.get('length') === 1 && !this.get('allowDuplicateItems')) {
        sel.addObject(content.objectAt(indexes.get('firstObject')));

      // otherwise select an index range
      } else sel.add(content, indexes);

    }

    // give delegate one last chance
    sel = del.collectionViewSelectionForProposedSelection(this, sel);
    if (!sel) sel = SC.SelectionSet.create(); // empty

    // if we're not extending the selection, clear the selection anchor
    this._selectionAnchor = null ;
    this.set('selection', sel.freeze()) ;
    return this;
  },

  /**
    Primitive to remove the indexes from the selection.

    @param {Number|SC.IndexSet} indexes index or indexes to deselect
    @returns {SC.CollectionView} receiver
  */
  deselect: function(indexes) {
    var sel     = this.get('selection'),
        content = this.get('content'),
        del     = this.get('selectionDelegate');

    if (!this.get('isSelectable') || !this.get('isEnabledInPane')) return this;
    if (!sel || sel.get('length')===0) return this; // nothing to do

    // normalize
    if (SC.typeOf(indexes) === SC.T_NUMBER) {
      indexes = SC.IndexSet.create(indexes, 1);
    }

    // give the delegate a chance to alter the items
    indexes = del.collectionViewShouldDeselectIndexes(this, indexes) ;
    if (!indexes || indexes.get('length')===0) return this; // nothing to do

    // now merge change - note we expect sel && indexes to not be null
    sel = sel.copy().remove(content, indexes);
    sel = del.collectionViewSelectionForProposedSelection(this, sel);
    if (!sel) sel = SC.SelectionSet.create(); // empty

    this.set('selection', sel.freeze()) ;
    return this ;
  },

  /** @private
   Finds the next selectable item, up to content length, by asking the
   delegate. If a non-selectable item is found, the index is skipped. If
   no item is found, selection index is returned unmodified.

   Return value will always be in the range of the bottom of the current
   selection index and the proposed index.

   @param {Number} proposedIndex the desired index to select
   @param {Number} bottom optional bottom of selection use as fallback
   @returns {Number} next selectable index.
  */
  _findNextSelectableItemFromIndex: function(proposedIndex, bottom) {
    var lim     = this.get('length'),
        range   = SC.IndexSet.create(),
        del     = this.get('selectionDelegate'),
        groupIndexes = this.get('_contentGroupIndexes'),
        ret, sel ;

    // fast path
    if (!groupIndexes && (del.collectionViewShouldSelectIndexes === this.collectionViewShouldSelectIndexes)) {
      return proposedIndex;
    }

    // loop forwards looking for an index that is allowed by delegate
    // we could alternatively just pass the whole range but this might be
    // slow for the delegate
    while (proposedIndex < lim) {
      if (!groupIndexes || !groupIndexes.contains(proposedIndex)) {
        range.add(proposedIndex);
        ret = del.collectionViewShouldSelectIndexes(this, range);
        if (ret && ret.get('length') >= 1) return proposedIndex ;
        range.remove(proposedIndex);
      }
      proposedIndex++;
    }

    // if nothing was found, return top of selection
    if (bottom === undefined) {
      sel = this.get('selection');
      bottom = sel ? sel.get('max') : -1 ;
    }
    return bottom ;
  },

  /** @private
   Finds the previous selectable item, up to the first item, by asking the
   delegate. If a non-selectable item is found, the index is skipped. If
   no item is found, selection index is returned unmodified.

   @param {Integer} proposedIndex the desired index to select
   @returns {Integer} the previous selectable index. This will always be in the range of the top of the current selection index and the proposed index.
  */
  _findPreviousSelectableItemFromIndex: function(proposedIndex, top) {
    var range   = SC.IndexSet.create(),
        del     = this.get('selectionDelegate'),
        groupIndexes = this.get('_contentGroupIndexes'),
        ret ;

    if (SC.none(proposedIndex)) proposedIndex = -1;

    // fast path
    if (!groupIndexes && (del.collectionViewShouldSelectIndexes === this.collectionViewShouldSelectIndexes)) {
      return proposedIndex;
    }

    // loop backwards looking for an index that is allowed by delegate
    // we could alternatively just pass the whole range but this might be
    // slow for the delegate
    while (proposedIndex >= 0) {
      if (!groupIndexes || !groupIndexes.contains(proposedIndex)) {
        range.add(proposedIndex);
        ret = del.collectionViewShouldSelectIndexes(this, range);
        if (ret && ret.get('length') >= 1) return proposedIndex ;
        range.remove(proposedIndex);
      }
      proposedIndex--;
    }

    // if nothing was found, return top of selection
    if (top === undefined) {
      var sel = this.get('selection');
      top = sel ? sel.get('min') : -1 ;
    }
    if (SC.none(top)) top = -1;
    return top ;
  },

  /**
    Select one or more items before the current selection, optionally
    extending the current selection.  Also scrolls the selected item into
    view.

    Selection does not wrap around.

    @param {Boolean} [extend] If true, the selection will be extended
      instead of replaced. Defaults to false.
    @param {Integer} [numberOfItems] The number of previous to be
      selected.  Defaults to 1
    @returns {SC.CollectionView} receiver
  */
  selectPreviousItem: function(extend, numberOfItems) {
    if (SC.none(numberOfItems)) numberOfItems = 1;
    if (SC.none(extend)) extend = false;

    var sel     = this.get('selection'),
        content = this.get('content');
    if (sel) sel = sel.indexSetForSource(content);

    var selTop    = sel ? sel.get('min') : -1,
        selBottom     = sel ? sel.get('max')-1 : -1,
        anchor        = this._selectionAnchor;
    if (SC.none(anchor)) anchor = selTop;

    // if extending, then we need to do some fun stuff to build the array
    if (extend) {

      // If the selBottom is after the anchor, then reduce the selection
      if (selBottom > anchor) {
        selBottom = selBottom - numberOfItems ;

      // otherwise, select the previous item from the top
      } else {
        selTop = this._findPreviousSelectableItemFromIndex(selTop - numberOfItems);
      }

      // Ensure we are not out of bounds
      if (SC.none(selTop) || (selTop < 0)) selTop = 0 ;
      if (!content.objectAt(selTop)) selTop = sel ? sel.get('min') : -1;
      if (selBottom < selTop) selBottom = selTop ;

    // if not extending, just select the item previous to the selTop
    } else {
      selTop = this._findPreviousSelectableItemFromIndex(selTop - numberOfItems);
      if (SC.none(selTop) || (selTop < 0)) selTop = 0 ;
      if (!content.objectAt(selTop)) selTop = sel ? sel.get('min') : -1;
      selBottom = selTop ;
      anchor = null ;
    }

    var scrollToIndex = selTop ;

    // now build new selection
    sel = SC.IndexSet.create(selTop, selBottom+1-selTop);

    // ensure that the item is visible and set the selection
    this.scrollToContentIndex(scrollToIndex) ;
    this.select(sel) ;
    this._selectionAnchor = anchor ;
    return this ;
  },

  /**
    Select one or more items following the current selection, optionally
    extending the current selection.  Also scrolls to selected item.

    Selection does not wrap around.

    @param {Boolean} [extend] If true, the selection will be extended
      instead of replaced. Defaults to false.
    @param {Integer} [numberOfItems] The number of items to be
      selected. Defaults to 1.
    @returns {SC.CollectionView} receiver
  */
  selectNextItem: function(extend, numberOfItems) {
    if (SC.none(numberOfItems)) numberOfItems = 1 ;
    if (SC.none(extend)) extend = false ;

    var sel     = this.get('selection'),
        content = this.get('content');
    if (sel) sel = sel.indexSetForSource(content);

    var selTop    = sel ? sel.get('min') : -1,
        selBottom = sel ? sel.get('max')-1 : -1,
        anchor    = this._selectionAnchor,
        lim       = this.get('length');

    if (SC.none(anchor)) anchor = selTop;

    // if extending, then we need to do some fun stuff to build the array
    if (extend) {

      // If the selTop is before the anchor, then reduce the selection
      if (selTop < anchor) {
        selTop = selTop + numberOfItems ;

      // otherwise, select the next item after the bottom
      } else {
        selBottom = this._findNextSelectableItemFromIndex(selBottom + numberOfItems, selBottom);
      }

      // Ensure we are not out of bounds
      if (selBottom >= lim) selBottom = lim-1;

      // we also need to check that the item exists
      if (!content.objectAt(selBottom)) selBottom = sel ? sel.get('max') - 1 : -1;

      // and if top has eclipsed bottom, handle that too.
      if (selTop > selBottom) selTop = selBottom ;

    // if not extending, just select the item next to the selBottom
    } else {
      selBottom = this._findNextSelectableItemFromIndex(selBottom + numberOfItems, selBottom);

      if (selBottom >= lim) selBottom = lim-1;
      if (!content.objectAt(selBottom)) selBottom = sel ? sel.get('max') - 1 : -1;
      selTop = selBottom ;
      anchor = null ;
    }

    var scrollToIndex = selBottom ;

    // now build new selection
    sel = SC.IndexSet.create(selTop, selBottom-selTop+1);

    // ensure that the item is visible and set the selection
    this.scrollToContentIndex(scrollToIndex) ;
    this.select(sel) ;
    this._selectionAnchor = anchor ;
    return this ;
  },

  /**
    Deletes the selected content if canDeleteContent is YES.  This will invoke
    delegate methods to provide fine-grained control.  Returns YES if the
    deletion was possible, even if none actually occurred.

    @returns {Boolean} YES if deletion is possible.
  */
  deleteSelection: function() {
    // perform some basic checks...
    if (!this.get('isEditable') || !this.get('canDeleteContent')) return NO;

    var sel     = this.get('selection'),
        content = this.get('content'),
        del     = this.get('selectionDelegate'),
        indexes = sel&&content ? sel.indexSetForSource(content) : null;

    if (!content || !indexes || indexes.get('length') === 0) return NO ;

    // let the delegate decide what to actually delete.  If this returns an
    // empty index set or null, just do nothing.
    indexes = del.collectionViewShouldDeleteIndexes(this, indexes);
    if (!indexes || indexes.get('length') === 0) return NO ;

    // now have the delegate (or us) perform the deletion. The default
    // delegate implementation just uses standard SC.Array methods to do the
    // right thing.
    del.collectionViewDeleteContent(this, this.get('content'), indexes);

    return YES ;
  },

  // ..........................................................
  // SCROLLING
  //

  /**
    Scroll the rootElement (if needed) to ensure that the item is visible.

    @param {Number} contentIndex The index of the item to scroll to
    @returns {SC.CollectionView} receiver
  */
  scrollToContentIndex: function(contentIndex) {
    var itemView = this.itemViewForContentIndex(contentIndex) ;
    if (itemView) this.scrollToItemView(itemView) ;
    return this;
  },

  /**
    Scroll to the passed item view.  If the item view is not visible on screen
    this method will not work.

    @param {SC.View} view The item view to scroll to
    @returns {SC.CollectionView} receiver
  */
  scrollToItemView: function(view) {
    if (view) view.scrollToVisible();
    return this ;
  },

  // ..........................................................
  // KEYBOARD EVENTS
  //

  /** @private */
  keyDown: function(evt) {
    var ret = this.interpretKeyEvents(evt) ;
    return !ret ? NO : ret ;
  },

  /** @private */
  keyUp: function() { return true; },

  /** @private
    Handle space key event.  Do action
  */
  insertText: function(chr, evt) {
    if (chr === ' ') {
      var sel = this.get('selection');
      if (sel && sel.get('length')>0) {
        this.invokeLater(this._cv_action, 0, null, evt);
      }
      return YES ;
    } else return NO ;
  },

  /** @private
    Handle select all keyboard event.
  */
  selectAll: function(evt) {
    var content = this.get('content'),
        del = this.delegateFor('allowsMultipleSelection', this.get('delegate'), content);

    if (del && del.get('allowsMultipleSelection')) {
      var sel = content ? SC.IndexSet.create(0, content.get('length')) : null;
    this.select(sel, NO) ;
    }
    return YES ;
  },

  /** @private
    Remove selection of any selected items.
  */
  deselectAll: function() {
    var content = this.get('content'),
        del = this.delegateFor('allowsEmptySelection', this.get('delegate'), content);

    if (del && del.get('allowsEmptySelection')) {
      var sel = content ? SC.IndexSet.create(0, content.get('length')) : null;
    this.deselect(sel, NO) ;
    }
    return YES ;
  },

  /** @private
    Handle delete keyboard event.
  */
  deleteBackward: function(evt) {
    return this.deleteSelection() ;
  },

  /** @private
    Handle delete keyboard event.
  */
  deleteForward: function(evt) {
    return this.deleteSelection() ;
  },

  /** @private
    Selects the same item on the next row or moves down one if itemsPerRow = 1
  */
  moveDown: function(sender, evt) {
    this.selectNextItem(false, this.get('itemsPerRow') || 1) ;
    this._cv_performSelectAction(null, evt, this.ACTION_DELAY);
    return true ;
  },

  /** @private
    Selects the same item on the next row or moves up one if itemsPerRow = 1
  */
  moveUp: function(sender, evt) {
    this.selectPreviousItem(false, this.get('itemsPerRow') || 1) ;
    this._cv_performSelectAction(null, evt, this.ACTION_DELAY);
    return true ;
  },

  /** @private
    Selects the previous item if itemsPerRow > 1.  Otherwise does nothing.
    If item is expandable, will collapse.
  */
  moveLeft: function(evt) {
    // If the control key is down, this may be a browser shortcut and
    // we should not handle the arrow key.
    if (evt.ctrlKey || evt.metaKey) return NO;

    if ((this.get('itemsPerRow') || 1) > 1) {
      this.selectPreviousItem(false, 1);
      this._cv_performSelectAction(null, evt, this.ACTION_DELAY);

    } else {
      var sel     = this.get('selection'),
          content = this.get('content'),
          indexes = sel ? sel.indexSetForSource(content) : null;

      // Collapse the element if it is expanded.  However, if there is exactly
      // one item selected and the item is already collapsed or is a leaf
      // node, then select the (expanded) parent element instead as a
      // convenience to the user.
      if ( indexes ) {
        var del,     // We'll load it lazily
            selectParent = false,
            index;

        if ( indexes.get('length') === 1 ) {
          index = indexes.get('firstObject');
          del = this.get('contentDelegate');
          var state = del.contentIndexDisclosureState(this, content, index);
          if (state !== SC.BRANCH_OPEN) selectParent = true;
        }

        if ( selectParent ) {
          // TODO:  PERFORMANCE:  It would be great to have a function like
          //        SC.CollectionView.selectParentItem() or something similar
          //        for performance reasons.  But since we don't currently
          //        have such a function, let's just iterate through the
          //        previous items until we find the first one with a outline
          //        level of one less than the selected item.
          var desiredOutlineLevel = del.contentIndexOutlineLevel(this, content, index) - 1;
          if ( desiredOutlineLevel >= 0 ) {
            var parentIndex = -1;
            while ( parentIndex < 0 ) {
              var previousItemIndex = this._findPreviousSelectableItemFromIndex(index - 1);
              if (previousItemIndex < 0 ) return false;    // Sanity-check.
              index = previousItemIndex;
              var outlineLevel = del.contentIndexOutlineLevel(this, content, index);
              if ( outlineLevel === desiredOutlineLevel ) {
                parentIndex = previousItemIndex;
              }
            }

            // If we found the parent, select it now.
            if ( parentIndex !== -1 ) {
              this.select(index);
            }
          }
        }
        else {
          this.collapse(indexes);
        }
      }
    }

    return true ;
  },

  /** @private
    Selects the next item if itemsPerRow > 1.  Otherwise does nothing.
  */
  moveRight: function(evt) {
    // If the control key is down, this may be a browser shortcut and
    // we should not handle the arrow key.
    if (evt.ctrlKey || evt.metaKey) return NO;

    if ((this.get('itemsPerRow') || 1) > 1) {
      this.selectNextItem(false, 1) ;
      this._cv_performSelectAction(null, evt, this.ACTION_DELAY);
    } else {
      var sel     = this.get('selection'),
          content = this.get('content'),
          indexes = sel ? sel.indexSetForSource(content) : null;
      if (indexes) this.expand(indexes);
    }

    return true ;
  },

  /** @private */
  moveDownAndModifySelection: function(sender, evt) {
    var content = this.get('content'),
        del = this.delegateFor('allowsMultipleSelection', this.get('delegate'), content);

    if (del && del.get('allowsMultipleSelection')) {
    this.selectNextItem(true, this.get('itemsPerRow') || 1) ;
    this._cv_performSelectAction(null, evt, this.ACTION_DELAY);
    }
    return true ;
  },

  /** @private */
  moveUpAndModifySelection: function(sender, evt) {
    var content = this.get('content'),
        del = this.delegateFor('allowsMultipleSelection', this.get('delegate'), content);

    if (del && del.get('allowsMultipleSelection')) {
    this.selectPreviousItem(true, this.get('itemsPerRow') || 1) ;
    this._cv_performSelectAction(null, evt, this.ACTION_DELAY);
    }
    return true ;
  },

  /** @private
    Selects the previous item if itemsPerRow > 1.  Otherwise does nothing.
  */
  moveLeftAndModifySelection: function(sender, evt) {
    if ((this.get('itemsPerRow') || 1) > 1) {
      this.selectPreviousItem(true, 1) ;
      this._cv_performSelectAction(null, evt, this.ACTION_DELAY);
    }
    return true ;
  },

  /** @private
    Selects the next item if itemsPerRow > 1.  Otherwise does nothing.
  */
  moveRightAndModifySelection: function(sender, evt) {
    if ((this.get('itemsPerRow') || 1) > 1) {
      this.selectNextItem(true, 1) ;
      this._cv_performSelectAction(null, evt, this.ACTION_DELAY);
    }
    return true ;
  },

  /** @private
    if content value is editable and we have one item selected, then edit.
    otherwise, invoke action.
  */
  insertNewline: function(sender, evt) {
    var wantsEdit = this.get('isEditable') && this.get('canEditContent'),
      canEdit = false,
        sel, content, set, idx, itemView;

    // Make sure we have a single item selected and the item view supports beginEditing
    if (wantsEdit) {
      sel     = this.get('selection') ;
      content = this.get('content');

      if (sel && sel.get('length') === 1) {
        set = sel.indexSetForSource(content);
        idx = set ? set.get('min') : -1;

    // next find itemView and ensure it supports editing
      itemView = this.itemViewForContentIndex(idx);
      canEdit = itemView && SC.typeOf(itemView.beginEditing)===SC.T_FUNCTION;
    }
    }

    // ok, we can edit..
    if (canEdit) {
      this.scrollToContentIndex(idx);
      itemView.beginEditing();

    // invoke action
    } else {
      this.invokeLater(this._cv_action, 0, itemView, null) ;
    }

    return YES ; // always handle
  },

  insertTab: function(evt) {
    var view = this.get('nextValidKeyView');
    if (view) view.becomeFirstResponder();
    else evt.allowDefault();
    return YES ; // handled
  },

  insertBacktab: function(evt) {
    var view = this.get('previousValidKeyView');
    if (view) view.becomeFirstResponder();
    else evt.allowDefault();
    return YES ; // handled
  },

  // ..........................................................
  // MOUSE EVENTS
  //

  doubleClick: function (ev) {
    var isEnabledInPane = this.get('isEnabledInPane'),
        handled = false;

    if (isEnabledInPane) {
      var action = this.get('action');

      if (action) {
        var itemView = this.itemViewForEvent(ev);

        this._cv_performSelectAction(itemView, ev, 0, ev.clickCount);
        handled = true;
      }
    }

    return handled;
  },

  /** @private
    Handles mouse down events on the collection view or on any of its
    children.

    The default implementation of this method can handle a wide variety
    of user behaviors depending on how you have configured the various
    options for the collection view.

    @param ev {Event} the mouse down event
    @returns {Boolean} Usually YES.
  */
  mouseDown: function(ev) {
    var isEnabledInPane = this.get('isEnabledInPane'),
        isSelectable = this.get('isSelectable'),
        handled = false;

    // If enabled and selectable, handle the event.
    if (isEnabledInPane && isSelectable) {
      var content = this.get('content');

      handled = true;

      if (content) {
        var itemView = this.itemViewForEvent(ev),
            allowsMultipleSel = content.get('allowsMultipleSelection'),
            didSelect = false,
            sel, isSelected,
            contentIndex;

        // Ensure that the view is first responder if possible.
        this.becomeFirstResponder();

        // Determine the content index of the item view.
        contentIndex = itemView ? itemView.get('contentIndex') : -1;

        // Toggle the selection if useToggleSelection is true.
        if (this.get('useToggleSelection')) {

          if (this.get('selectOnMouseDown') && itemView) {
            // Determine if item is selected. If so, then go on.
            sel = this.get('selection');

            isSelected = sel && sel.contains(content, contentIndex, 1);
            if (isSelected) {
              this.deselect(contentIndex);
            } else if (!allowsMultipleSel) {
              this.select(contentIndex, false);
              didSelect = true;
            } else {
              this.select(contentIndex, true);
              didSelect = true;
            }
          }

        // Normal selection behavior.
        } else {
          var info, anchor, modifierKeyPressed;

          // Received a mouseDown on the view, but not on one of the item views.
          if (!itemView) {
            // Deselect all.
            if (this.get('allowDeselectAll')) this.select(null, false);

          } else {
            // Collect some basic setup info.
            sel = this.get('selection');
            if (sel) sel = sel.indexSetForSource(content);

            info = this.mouseDownInfo = {
              event:        ev,
              itemView:     itemView,
              contentIndex: contentIndex,
              at:           Date.now()
            };

            isSelected = sel ? sel.contains(contentIndex) : NO;
            info.modifierKeyPressed = modifierKeyPressed = ev.ctrlKey || ev.metaKey;


            // holding down a modifier key while clicking a selected item should
            // deselect that item...deselect and bail.
            if (modifierKeyPressed && isSelected) {
              info.shouldDeselect = contentIndex >= 0;

            // if the shiftKey was pressed, then we want to extend the selection
            // from the last selected item
            } else if (ev.shiftKey && sel && sel.get('length') > 0 && allowsMultipleSel) {
              sel = this._findSelectionExtendedByShift(sel, contentIndex);
              anchor = this._selectionAnchor;
              this.select(sel) ;
              didSelect = true;
              this._selectionAnchor = anchor; //save the anchor

            // If no modifier key was pressed, then clicking on the selected item
            // should clear the selection and reselect only the clicked on item.
            } else if (!modifierKeyPressed && isSelected) {
              info.shouldReselect = contentIndex >= 0;

            // Otherwise, if selecting on mouse down,  simply select the clicked on
            // item, adding it to the current selection if a modifier key was pressed.
            } else {

              if ((ev.shiftKey || modifierKeyPressed) && !allowsMultipleSel) {
                this.select(null, false);
                didSelect = true;
              }

              if (this.get("selectOnMouseDown")) {
                this.select(contentIndex, modifierKeyPressed);
                didSelect = true;
              } else {
                info.shouldSelect = contentIndex >= 0;
              }
            }

            // saved for extend by shift ops.
            info.previousContentIndex = contentIndex;
          }
        }

        // Trigger select action if select occurred.
        if (didSelect && this.get('actOnSelect')) {
          this._cv_performSelectAction(itemView, ev);
        }
      }
    }

    if (handled) {
      // Track that mouse is down.
      this._sc_isMouseDown = true;
    }

    return handled;
  },

  /** @private */
  mouseUp: function(ev) {
    var isEnabledInPane = this.get('isEnabledInPane'),
        isSelectable = this.get('isSelectable');

    // If enabled and selectable, handle the event.
    if (isEnabledInPane && isSelectable) {
      var content = this.get('content');

      if (content) {
        var itemView = this.itemViewForEvent(ev),
            info = this.mouseDownInfo,
            didSelect = false,
            sel, isSelected,
            contentIndex;

        // Determine the content index of the item view.
        contentIndex = itemView ? itemView.get('contentIndex') : -1;

        // Toggle the selection if useToggleSelection is true.
        if (this.get('useToggleSelection')) {
          // If the toggle wasn't done on mouse down, handle it now.
          if (!this.get('selectOnMouseDown') && itemView) {
            var allowsMultipleSel = content.get('allowsMultipleSelection');

            // determine if item is selected. If so, then go on.
            sel = this.get('selection') ;
            isSelected = sel && sel.contains(content, contentIndex, 1);

            if (isSelected) {
              this.deselect(contentIndex) ;
            } else if (!allowsMultipleSel) {
              this.select(contentIndex, false);
              didSelect = true;
            } else {
              this.select(contentIndex, true);
              didSelect = true;
            }
          }

        } else if (info) {
          var idx = info.contentIndex;

          // This will be set if the user simply clicked on an unselected item and selectOnMouseDown was NO.
          if (info.shouldSelect) {
            this.select(idx, info.modifierKeyPressed);
            didSelect = true;
          }

          // This is true if the user clicked on a selected item with a modifier key pressed.
          if (info.shouldDeselect) this.deselect(idx);

          // This is true if the user clicked on a selected item without a modifier-key pressed.
          // When this happens we try to begin editing on the content.  If that is not allowed, then
          // simply clear the selection and reselect the clicked on item.
          if (info.shouldReselect) {

            // - contentValueIsEditable is true
            var canEdit = this.get('isEditable') && this.get('canEditContent') ;

            // - the user clicked on an item that was already selected
            //   ^ this is the only way shouldReset is set to YES

            // - is the only item selected
            if (canEdit) {
              sel = this.get('selection') ;
              canEdit = sel && (sel.get('length') === 1);
            }

            // - the item view responds to contentHitTest() and returns YES.
            // - the item view responds to beginEditing and returns YES.
            if (canEdit) {
              itemView = this.itemViewForContentIndex(idx) ;
              canEdit = itemView && (!itemView.contentHitTest || itemView.contentHitTest(ev)) ;
              canEdit = (canEdit && itemView.beginEditing) ? itemView.beginEditing() : NO ;
            }

            // if cannot edit, schedule a reselect (but give doubleClick a chance)
            if (!canEdit) {
              if (this._cv_reselectTimer) this._cv_reselectTimer.invalidate() ;
              this._cv_reselectTimer = this.invokeLater(this.select, 300, idx, false) ;
            }
          }

          // Clean up.
          this._cleanupMouseDown();
        }

        // Trigger select action if select occurred.
        if (didSelect && this.get('actOnSelect')) {
          this._cv_performSelectAction(itemView, ev);
        }
      }

      // To avoid annoying jitter from Magic Mouse (which sends mousewheel events while trying
      // to lift your finger after a drag), capture mousewheel events for a small period of time.
      this._sc_isMouseJustDown = true;
      this._sc_clearMouseJustDownTimer = this.invokeLater(this._sc_clearMouseJustDown, 250);
    }

    // Track that mouse is up no matter what (e.g. mouse went down and then view was disabled before mouse up).
    this._sc_isMouseDown = false;

    return false;  // Bubble event to allow doubleClick to be called.
  },

  /** @private */
  _cleanupMouseDown: function() {

    // delete items explicitly to avoid leaks on IE
    var info = this.mouseDownInfo, key;
    if (info) {
      for (key in info) {
        if (!info.hasOwnProperty(key)) continue;
        delete info[key];
      }
    }
    this.mouseDownInfo = null;
  },

  /** @private */
  mouseMoved: function(ev) {
    var view = this.itemViewForEvent(ev),
        last = this._lastHoveredItem ;

    // handle hover events.
    if (view !== last) {
      if (last && last.mouseExited) last.mouseExited(ev);
      if (view && view.mouseEntered) view.mouseEntered(ev);
    }
    this._lastHoveredItem = view ;

    if (view && view.mouseMoved) view.mouseMoved(ev);
    return YES;
  },

  /** @private */
  mouseExited: function(ev) {
    var view = this._lastHoveredItem ;
    this._lastHoveredItem = null ;
    if (view && view.mouseExited) view.mouseExited(ev) ;
    return YES ;
  },

  /** @private We capture mouseWheel events while the mouse is pressed, this is to prevent jitter from slight mouse wheels while pressing
    and lifting the finger (especially a problem with the Magic Mouse) */
  mouseWheel: function (evt) {
    // Capture mouse wheel events when mouse is pressed or immediately after a mouse up (to avoid
    // excessive Magic Mouse wheel events while the person lifts their finger).
    return this._sc_isMouseDown || this._sc_isMouseJustDown;
  },

  // ..........................................................
  // TOUCH EVENTS
  //

  /** @private */
  touchStart: function(touch, evt) {
    var itemView = this.itemViewForEvent(touch),
        contentIndex = itemView ? itemView.get('contentIndex') : -1;

    if (!this.get('isEnabledInPane')) return contentIndex > -1;

    // become first responder if possible.
    this.becomeFirstResponder() ;

    this._touchSelectedView = itemView;

    if (!this.get('useToggleSelection')) {
      // We're faking the selection visually here
      // Only track this if we added a selection so we can remove it later
      if (itemView && !itemView.get('isSelected')) {
        itemView.set('isSelected', YES);
      }
    }

    return YES;
  },

  /** @private */
  touchesDragged: function(evt, touches) {
    touches.forEach(function(touch){
      if (
        Math.abs(touch.pageX - touch.startX) > 5 ||
        Math.abs(touch.pageY - touch.startY) > 5
      ) {
        // This calls touchCancelled
        touch.makeTouchResponder(touch.nextTouchResponder);
      }
    }, this);

  },

  /** @private */
  touchEnd: function(touch) {
    /*
      TODO [CC] We should be using itemViewForEvent here, but because
            ListItemView re-renders itself once isSelected is called
            in touchStart, the elements attached to this event are
            getting orphaned and this event is basically a complete
            fail when using touch events.
    */
    // var itemView = this.itemViewForEvent(touch),
    var content = this.get('content'),
        itemView = this._touchSelectedView,
        contentIndex = itemView ? itemView.get('contentIndex') : -1,
        isSelected = NO, sel, shouldSelect;

    if (!this.get('isEnabledInPane')) return contentIndex > -1;

    if (contentIndex > -1) {
      if (this.get('useToggleSelection')) {
        sel = this.get('selection');
        isSelected = sel && sel.contains(content, contentIndex, 1);
        shouldSelect = !isSelected;
      }
      else
        shouldSelect = true;

      if (shouldSelect) {
        this.select(contentIndex, NO);

        // If actOnSelect is implemented, the action will be fired.
        this._cv_performSelectAction(itemView, touch, 0);
      } else {
        this.deselect(contentIndex);
      }
    }

    this._touchSelectedView = null;
  },

  /** @private */
  touchCancelled: function(evt) {
    // Remove fake selection
    if (this._touchSelectedView) {
      this._touchSelectedView.set('isSelected', NO);
      this._touchSelectedView = null;
    }
  },

  /** @private */
  _findSelectionExtendedByShift: function(sel, contentIndex) {

    // fast path.  if we don't have a selection, just select index
    if (!sel || sel.get('length')===0) {
      return SC.IndexSet.create(contentIndex);
    }

    // if we do have a selection, then figure out how to extend it.
    var min     = sel.get('min'),
        max     = sel.get('max')-1,
        anchor  = this._selectionAnchor ;
    if (SC.none(anchor)) anchor = -1;

    // clicked before the current selection set... extend it's beginning...
    if (contentIndex < min) {
      min = contentIndex;
      if (anchor<0) this._selectionAnchor = anchor = max; //anchor at end

    // clicked after the current selection set... extend it's ending...
    } else if (contentIndex > max) {
      max = contentIndex;
      if (anchor<0) this._selectionAnchor = anchor = min; // anchor at start

    // clicked inside the selection set... need to determine where the last
    // selection was and use that as an anchor.
    } else if (contentIndex >= min && contentIndex <= max) {
      if (anchor<0) this._selectionAnchor = anchor = min; //anchor at start

      if (contentIndex === anchor) min = max = contentIndex ;
      else if (contentIndex > anchor) {
        min = anchor;
        max = contentIndex ;
      } else if (contentIndex < anchor) {
        min = contentIndex;
        max = anchor ;
      }
    }

    return SC.IndexSet.create(min, max - min + 1);
  },

  // ......................................
  // DRAG AND DROP SUPPORT
  //

  /**
    When reordering its content, the collection view will store its reorder
    data using this special data type.  The data type is unique to each
    collection view instance.  You can use this data type to detect reorders
    if necessary.

    @field
    @type String
  */
  reorderDataType: function() {
    return 'SC.CollectionView.Reorder.'+SC.guidFor(this) ;
  }.property().cacheable(),

  /**
    This property is set to the IndexSet of content objects that are the
    subject of a drag whenever a drag is initiated on the collection view.
    You can consult this property when implementing your collection view
    delegate  methods, but otherwise you should not use this property in your
    code.

    @type SC.IndexSet
    @default null
  */
  dragContent: null,

  /**
    This property is set to the proposed insertion index during a call to
    collectionViewValidateDragOperation().  Your delegate implementations can
    change the value of this property to enforce a drop some in some other
    location.

    @type Number
    @default null
  */
  proposedInsertionIndex: null,

  /**
    This property is set to the proposed drop operation during a call to
    collectionViewValidateDragOperation().  Your delegate implementations can
    change the value of this property to enforce a different type of drop
    operation.

    @type Number
    @default null
  */
  proposedDropOperation: null,

  /** @private
    mouseDragged event handler.  Initiates a drag if the following conditions
    are met:

    - collectionViewShouldBeginDrag() returns YES *OR*
    - the above method is not implemented and canReorderContent is true.
    - the dragDataTypes property returns a non-empty array
    - a mouse down event was saved by the mouseDown method.
  */
  mouseDragged: function (evt) {
    var del     = this.get('selectionDelegate'),
        content = this.get('content'),
        sel     = this.get('selection'),
        info    = this.mouseDownInfo,
        groupIndexes = this.get('_contentGroupIndexes'),
        dragContent, dragDataTypes, dragView;

    // if the mouse down event was cleared, there is nothing to do; return.
    if (!info || info.contentIndex<0) return YES ;

    // Don't do anything unless the user has been dragging for 123msec
    if ((Date.now() - info.at) < 123) return YES ;

    // OK, they must be serious, decide if a drag will be allowed.
    if (this.get('isEditable') && del.collectionViewShouldBeginDrag(this)) {

      // First, get the selection to drag.  Drag an array of selected
      // items appearing in this collection, in the order of the
      // collection.
      //
      // Compute the dragContent - the indexes we will be dragging.
      // if we don't select on mouse down, then the selection has not been
      // updated to whatever the user clicked.  Instead use
      // mouse down content.
      if (!this.get("selectOnMouseDown")) {
        dragContent = SC.IndexSet.create(info.contentIndex);
      } else dragContent = sel ? sel.indexSetForSource(content) : null;

      // remove any group indexes.  groups cannot be dragged.
      if (dragContent && groupIndexes && groupIndexes.get('length')>0) {
        dragContent = dragContent.copy().remove(groupIndexes);
        if (dragContent.get('length')===0) dragContent = null;
        else dragContent.freeze();
      }

      if (!dragContent) return YES; // nothing to drag
      else dragContent = dragContent.frozenCopy(); // so it doesn't change

      dragContent = { content: content, indexes: dragContent };
      this.set('dragContent', dragContent) ;

      // Get the set of data types supported by the delegate.  If this returns
      // a null or empty array and reordering content is not also supported
      // then do not start the drag.
      dragDataTypes = this.get('dragDataTypes');
      if (dragDataTypes && dragDataTypes.get('length') > 0) {

        // Build the drag view to use for the ghost drag.  This
        // should essentially contain any visible drag items.
        dragView = del.collectionViewDragViewFor(this, dragContent.indexes);
        if (!dragView) dragView = this._cv_dragViewFor(dragContent.indexes);

        // Initiate the drag
        SC.Drag.start({
          event: info.event,
          source: this,
          dragView: dragView,
          ghost: NO,
          ghostActsLikeCursor: del.ghostActsLikeCursor,
          slideBack: YES,
          dataSource: this
        });

        // Also use this opportunity to clean up since mouseUp won't
        // get called.
        this._cleanupMouseDown() ;
        this._lastInsertionIndex = null ;

      // Drag was not allowed by the delegate, so bail.
      } else this.set('dragContent', null) ;

      return YES ;
    }
  },

  /** @private
    Compute a default drag view by grabbing the raw layers and inserting them
    into a drag view.
  */
  _cv_dragViewFor: function(dragContent) {
    // find only the indexes that are in both dragContent and nowShowing.
    var indexes = this.get('nowShowing').without(dragContent),
        dragLayer = this.get('layer').cloneNode(false),
        view = SC.View.create({ layer: dragLayer, parentView: this }),
        height=0, layout;

    indexes = this.get('nowShowing').without(indexes);

    // cleanup weird stuff that might make the drag look out of place
    SC.$(dragLayer).css('backgroundColor', 'transparent')
      .css('border', 'none')
      .css('top', 0).css('left', 0);

    indexes.forEach(function(i) {
      var itemView = this.itemViewForContentIndex(i),
          isSelected, itemViewLayer, layer;

      if (itemView) {
      // render item view without isSelected state.
        isSelected = itemView.get('isSelected');
        itemView.set('isSelected', NO);
        itemView.updateLayerIfNeeded();
        itemViewLayer = itemView.get('layer');

        if (itemViewLayer) {
          layer = itemViewLayer.cloneNode(true);

          // photocopy any canvas elements
          var itemViewCanvasses = itemView.$().find('canvas');
          if (itemViewCanvasses) {
            var layerCanvasses = $(layer).find('canvas'),
                len = itemViewCanvasses.length,
                itemViewCanvas, layerCanvas;
            for (i = 0; i < len; i++) {
              itemViewCanvas = itemViewCanvasses[i];
              layerCanvas = layerCanvasses[i];
              layerCanvas.height = itemViewCanvas.height;
              layerCanvas.width = itemViewCanvas.width;
              layerCanvas.getContext('2d').drawImage(itemViewCanvas, 0, 0);
            }
          }
        }

        // reset item view
        itemView.set('isSelected', isSelected);
        itemView.updateLayerIfNeeded();
      }

      if (layer) {
        dragLayer.appendChild(layer);
        layout = itemView.get('layout');
        if(layout.height+layout.top>height){
          height = layout.height+layout.top;
        }
      }

      layer = null;
    }, this);

    // we don't want to show the scrollbars, resize the dragview
    view.set('layout', {height:height});

    dragLayer = null;
    return view ;
  },


  /**
    Implements the drag data source protocol for the collection view.  This
    property will consult the collection view delegate if one is provided. It
    will also do the right thing if you have set canReorderContent to YES.

    @field
    @type Array
  */
  dragDataTypes: function() {
    // consult delegate.
    var del = this.get('selectionDelegate'),
        ret = del.collectionViewDragDataTypes(this),
        key ;

    if (this.get('canReorderContent')) {
      ret = ret ? ret.copy() : [];
      key = this.get('reorderDataType');
      if (ret.indexOf(key) < 0) ret.push(key);
    }

    return ret ? ret : [];
  }.property(),

  /**
    Implements the drag data source protocol method. The implementation of
    this method will consult the collection view delegate if one has been
    provided.  It also respects the canReorderContent method.
  */
  dragDataForType: function(drag, dataType) {

    // if this is a reorder, then return drag content.
    if (this.get('canReorderContent')) {
      if (dataType === this.get('reorderDataType')) {
        return this.get('dragContent') ;
      }
    }

    // otherwise, just pass along to the delegate
    var del = this.get('selectionDelegate');
    return del.collectionViewDragDataForType(this, drag, dataType);
  },

  /**
    Implements the SC.DropTargetProtocol interface.  The default implementation will
    consult the collection view delegate, if you implement those methods.

    This method is called once when the drag enters the view area.  It's
    return value will be stored on the drag object as allowedDragOperations,
    possibly further constrained by the drag source.

    @param {SC.Drag} drag the drag object
    @param {SC.Event} evt the event triggering this change, if available
    @returns {Number} logical OR'd mask of allowed drag operations.
  */
  computeDragOperations: function(drag, evt) {
    // the proposed drag operation is DRAG_REORDER only if we can reorder
    // content and the drag contains reorder content.
    var op  = SC.DRAG_NONE,
        del = this.get('selectionDelegate');

    if (this.get('canReorderContent')) {
      if (drag.get('dataTypes').indexOf(this.get('reorderDataType')) >= 0) {
        op = SC.DRAG_REORDER ;
      }
    }

    // Now pass this onto the delegate.
    op = del.collectionViewComputeDragOperations(this, drag, op);
    if (op & SC.DRAG_REORDER) op = SC.DRAG_MOVE ;

    return op ;
  },

  /** @private
    Determines the allowed drop operation insertion point, operation type,
    and the drag operation to be performed.  Used by dragUpdated() and
    performDragOperation().

    @param {SC.Drag} drag the drag object
    @param {SC.Event} evt source of this request, if available
    @param {Number} dragOp allowed drag operation mask
    Returns three params: [drop index, drop operation, allowed drag ops]
  */
  _computeDropOperationState: function(drag, evt, dragOp) {
    // get the insertion index for this location.  This can be computed
    // by a subclass using whatever method.  This method is not expected to
    // do any data validation, just to map the location to an insertion
    // index.
    var loc    = this.convertFrameFromView(drag.get('location'), null),
        dropOp = SC.DROP_BEFORE,
        del    = this.get('selectionDelegate'),
        canReorder = this.get('canReorderContent'),
        objects, content, isPreviousInDrag, isNextInDrag, len, tmp;

    // STEP 1: Try with a DROP_ON option -- send straight to delegate if
    // supported by view.

    // get the computed insertion index and possibly drop operation.
    // prefer to drop ON.
    var idx = this.insertionIndexForLocation(loc, SC.DROP_ON) ;
    if (SC.typeOf(idx) === SC.T_ARRAY) {
      dropOp = idx[1] ; // order matters here
      idx = idx[0] ;
    }

    // if the return drop operation is DROP_ON, then just check it with the
    // delegate method.  If the delegate method does not support dropping on,
    // then it will return DRAG_NONE, in which case we will try again with
    // drop before.
    if (dropOp === SC.DROP_ON) {

      // Now save the insertion index and the dropOp.  This may be changed by
      // the collection delegate.
      this.set('proposedInsertionIndex', idx) ;
      this.set('proposedDropOperation', dropOp) ;
      tmp = del.collectionViewValidateDragOperation(this, drag, dragOp, idx, dropOp) ;
      idx = this.get('proposedInsertionIndex') ;
      dropOp = this.get('proposedDropOperation') ;
      this._dropInsertionIndex = this._dropOperation = null ;

      // The delegate is OK with a drop on also, so just return.
      if (tmp !== SC.DRAG_NONE) return [idx, dropOp, tmp] ;

      // The delegate is NOT OK with a drop on, try to get the insertion
      // index again, but this time prefer SC.DROP_BEFORE, then let the
      // rest of the method run...
      else {
        dropOp = SC.DROP_BEFORE ;
        idx = this.insertionIndexForLocation(loc, SC.DROP_BEFORE) ;
        if (SC.typeOf(idx) === SC.T_ARRAY) {
          dropOp = idx[1] ; // order matters here
          idx = idx[0] ;
        }
      }
    }

    // if this is a reorder drag, set the proposed op to SC.DRAG_REORDER and
    // validate the insertion point.  This only works if the insertion point
    // is DROP_BEFORE or DROP_AFTER.  DROP_ON is not handled by reordering
    // content.
    if ((idx >= 0) && canReorder && (dropOp !== SC.DROP_ON)) {

      objects = drag.dataForType(this.get('reorderDataType')) ;
      if (objects) {
        content = this.get('content') ;

        // if the insertion index is in between two items in the drag itself,
        // then this is not allowed.  Either use the last insertion index or
        // find the first index that is not in between selections.  Stop when
        // we get to the beginning.
        if (dropOp === SC.DROP_BEFORE) {
          isPreviousInDrag = objects.indexes.contains(idx-1);
          isNextInDrag     = objects.indexes.contains(idx);
        } else {
          isPreviousInDrag = objects.indexes.contains(idx);
          isNextInDrag     = objects.indexes.contains(idx-1);
        }

        if (isPreviousInDrag && isNextInDrag) {
          if (SC.none(this._lastInsertionIndex)) {
            if (dropOp === SC.DROP_BEFORE) {
              while ((idx >= 0) && objects.indexes.contains(idx)) idx--;
            } else {
              len = content ? content.get('length') : 0;
              while ((idx < len) && objects.indexes.contains(idx)) idx++;
            }
          } else idx = this._lastInsertionIndex ;
        }

        // If we found a valid insertion point to reorder at, then set the op
        // to custom DRAG_REORDER.
        if (idx >= 0) dragOp = SC.DRAG_REORDER ;
      }
    }

    // Now save the insertion index and the dropOp.  This may be changed by
    // the collection delegate.
    this.set('proposedInsertionIndex', idx) ;
    this.set('proposedDropOperation', dropOp) ;
    dragOp = del.collectionViewValidateDragOperation(this, drag, dragOp, idx, dropOp) ;
    idx = this.get('proposedInsertionIndex') ;
    dropOp = this.get('proposedDropOperation') ;
    this._dropInsertionIndex = this._dropOperation = null ;

    // return generated state
    return [idx, dropOp, dragOp] ;
  },

  /**
    Implements the SC.DropTargetProtocol interface.  The default implementation will
    determine the drop location and then consult the collection view delegate
    if you implement those methods.  Otherwise it will handle reordering
    content on its own.

    @param {SC.Drag} drag The drag that was updated
    @param {SC.Event} evt The event for the drag
  */
  dragUpdated: function(drag, evt) {
    var op     = drag.get('allowedDragOperations'),
        state  = this._computeDropOperationState(drag, evt, op),
        idx    = state[0], dropOp = state[1], dragOp = state[2];

    // if the insertion index or dropOp have changed, update the insertion
    // point
    if (dragOp !== SC.DRAG_NONE) {
      if ((this._lastInsertionIndex !== idx) || (this._lastDropOperation !== dropOp)) {
        var itemView = this.itemViewForContentIndex(idx) ;
        this.showInsertionPoint(itemView, dropOp) ;
      }

      this._lastInsertionIndex = idx ;
      this._lastDropOperation = dropOp ;
    } else {
      this.hideInsertionPoint() ;
      this._lastInsertionIndex = this._lastDropOperation = null ;
    }

    // Normalize drag operation to the standard kinds accepted by the drag
    // system.
    return (dragOp & SC.DRAG_REORDER) ? SC.DRAG_MOVE : dragOp;
  },

  /**
    Implements the SC.DropTargetProtocol protocol.  Hides any visible insertion
    point and clears some cached values.
  */
  dragEnded: function () {
    this.hideInsertionPoint() ;
    this._lastInsertionIndex = this._lastDropOperation = null ;
  },

  /**
    Implements the SC.DropTargetProtocol protocol.

    @returns {Boolean} YES
  */
  acceptDragOperation: function(drag, op) {
    return YES;
  },

  /**
    Implements the SC.DropTargetProtocol protocol. Consults the collection view
    delegate to actually perform the operation unless the operation is
    reordering content.

    @param {SC.Drag} drag The drag to perform the operation on
    @param {Number} op The drag operation to perform
    @return {Number} The operation performed
  */
  performDragOperation: function(drag, op) {
    // Get the correct insertion point, drop operation, etc.
    var state = this._computeDropOperationState(drag, null, op),
        idx   = state[0], dropOp = state[1], dragOp = state[2],
        del   = this.get('selectionDelegate'),
        performed, objects, data, content, shift, indexes;

    // The dragOp is the kinds of ops allowed.  The drag operation must
    // be included in that set.
    if (dragOp & SC.DRAG_REORDER) {
      op = (op & SC.DRAG_MOVE) ? SC.DRAG_REORDER : SC.DRAG_NONE ;
    } else op = op & dragOp ;

    // If no allowed drag operation could be found, just return.
    if (op === SC.DRAG_NONE) return op;

    // Some operation is allowed through, give the delegate a chance to
    // handle it.
    performed = del.collectionViewPerformDragOperation(this, drag, op, idx, dropOp) ;

    // If the delegate did not handle the drag (i.e. returned SC.DRAG_NONE),
    // and the op type is REORDER, then do the reorder here.
    if ((performed === SC.DRAG_NONE) && (op & SC.DRAG_REORDER)) {

      data = drag.dataForType(this.get('reorderDataType')) ;
      if (!data) return SC.DRAG_NONE ;

      content = this.get('content') ;

      // check for special case - inserting BEFORE ourself...
      // in this case just pretend the move happened since it's a no-op
      // anyway
      indexes = data.indexes;
      if (indexes.get('length')===1) {
        if (((dropOp === SC.DROP_BEFORE) || (dropOp === SC.DROP_AFTER)) &&
            (indexes.get('min')===idx)) return SC.DRAG_MOVE;
      }

      content.beginPropertyChanges(); // suspend notifications

      // get each object, then remove it from the content. they will be
      // added again later.
      objects = [];
      shift = 0;
      data.indexes.forEach(function(i) {
        objects.push(content.objectAt(i - shift));
        content.removeAt(i-shift);
        shift++;
        if (i < idx) idx--;
      }, this);

      // now insert objects into new insertion location
      if (dropOp === SC.DROP_AFTER) idx++;
      content.replace(idx, 0, objects, dropOp);
      this.select(SC.IndexSet.create(idx, objects.length));
      content.endPropertyChanges(); // restart notifications

      // make the op into its actual value
      op = SC.DRAG_MOVE ;
    }

    return op;
  },

  /**
    Default delegate method implementation, returns YES if canReorderContent
    is also true.

    @param {SC.View} view
  */
  collectionViewShouldBeginDrag: function(view) {
    return this.get('canReorderContent');
  },


  // ..........................................................
  // INSERTION POINT
  //


  /**
    Get the preferred insertion point for the given location, including
    an insertion preference of before, after or on the named index.

    You can implement this method in a subclass if you like to perform a
    more efficient check.  The default implementation will loop through the
    item views looking for the first view to "switch sides" in the orientation
    you specify.

    This method should return an array with two values.  The first value is
    the insertion point index and the second value is the drop operation,
    which should be one of SC.DROP_BEFORE, SC.DROP_AFTER, or SC.DROP_ON.

    The preferred drop operation passed in should be used as a hint as to
    the type of operation the view would prefer to receive. If the
    dropOperation is SC.DROP_ON, then you should return a DROP_ON mode if
    possible.  Otherwise, you should never return DROP_ON.

    For compatibility, you can also return just the insertion index.  If you
    do this, then the collection view will assume the drop operation is
    SC.DROP_BEFORE.

    If an insertion is NOT allowed, you should return -1 as the insertion
    point.  In this case, the drop operation will be ignored.

    @param {Point} loc the mouse location.
    @param {DropOp} dropOperation the preferred drop operation.
    @returns {Array} format: [index, op]
  */
  insertionIndexForLocation: function(loc, dropOperation) {
    return -1;
  },

  // ..........................................................
  // INTERNAL SUPPORT
  //

  /** @private Clears the mouse just down flag. */
  _sc_clearMouseJustDown: function () {
    this._sc_isMouseJustDown = false;
  },

  /** @private - when we are about to become visible, reload if needed. */
  willShowInDocument: function () {
    if (this._invalidIndexes) this.invokeOnce(this.reloadIfNeeded);
    if (this._invalidSelection) {
      this.invokeOnce(this.reloadSelectionIndexesIfNeeded);
    }
  },

  /** @private - when we are added, reload if needed. */
  didAppendToDocument: function () {
    if (this._invalidIndexes) this.invokeOnce(this.reloadIfNeeded);
    if (this._invalidSelection) {
      this.invokeOnce(this.reloadSelectionIndexesIfNeeded);
    }
  },

  /**
    Default delegate method implementation, returns YES if isSelectable
    is also true.
  */
  collectionViewShouldSelectItem: function(view, item) {
    return this.get('isSelectable') ;
  },

  /** @private

    Whenever the nowShowing range changes, update the range observer on the
    content item and instruct the view to reload any indexes that are not in
    the previous nowShowing range.

  */
  _cv_nowShowingDidChange: function() {
    var nowShowing  = this.get('nowShowing'),
        last        = this._sccv_lastNowShowing,
        diff, diff1, diff2;

    // find the differences between the two
    // NOTE: reuse a TMP IndexSet object to avoid creating lots of objects
    // during scrolling
    if (last !== nowShowing) {
      if (last && nowShowing) {
        diff1 = this._TMP_DIFF1.add(last).remove(nowShowing);
        diff2 = this._TMP_DIFF2.add(nowShowing).remove(last);
        diff = diff1.add(diff2);
      } else diff = last || nowShowing ;
    }

    // if nowShowing has actually changed, then update
    if (diff && diff.get('length') > 0) {
      this._sccv_lastNowShowing = nowShowing ? nowShowing.frozenCopy() : null;
      this.updateContentRangeObserver();
      this.reload(diff);
    }

    // cleanup tmp objects
    if (diff1) diff1.clear();
    if (diff2) diff2.clear();

  }.observes('nowShowing'),

  /** @private */
  init: function() {
     arguments.callee.base.apply(this,arguments);

    


    


     if (this.get('canReorderContent')) this._cv_canReorderContentDidChange();
     this._sccv_lastNowShowing = this.get('nowShowing').clone();

     if (this.content) this._cv_contentDidChange();
     if (this.selection) this._cv_selectionDidChange();

     // Set our initial layout. It's important that our computed layout exist on instantiation so that containing views
     // understand in which way the collection will grow (e.g. if we compute height, then the container won't adjust height).
     this.adjustLayout();
  },

  /** @private SC.View.prototype.destroy. */
  destroy: function () {
    arguments.callee.base.apply(this,arguments);

    // All manipulations made to objects we use must be reversed!
    var content = this._content;
    if (content) {
      content.removeObserver('length', this, this.contentLengthDidChange);

      this._content = null;
    }

    var sel = this._cv_selection;
    if (sel) {
      sel.removeObserver('[]', this, this._cv_selectionContentDidChange);

      this._cv_selection = null;
    }

    var contentRangeObserver = this._cv_contentRangeObserver;
    if (contentRangeObserver) {
      if (content) content.removeRangeObserver(contentRangeObserver);

      this._cv_contentRangeObserver = null;
    }
  },

  /** @private
    Become a drop target whenever reordering content is enabled.
  */
  _cv_canReorderContentDidChange: function() {
    if (this.get('canReorderContent')) {
      if (!this.get('isDropTarget')) this.set('isDropTarget', YES);
      SC.Drag.addDropTarget(this);
    }
  }.observes('canReorderContent'),

  /** @private
    Fires an action after a selection if enabled.

    if actOnSelect is YES, then try to invoke the action, passing the
    current selection (saved as a separate array so that a change in sel
    in the meantime will not be lost)
  */
  _cv_performSelectAction: function(view, ev, delay, clickCount) {
    var sel;
    if (delay === undefined) delay = 0 ;
    if (clickCount === undefined) clickCount = 1;
    if ((clickCount>1) || this.get('actOnSelect')) {
      if (this._cv_reselectTimer) this._cv_reselectTimer.invalidate() ;
      sel = this.get('selection');
      sel = sel ? sel.toArray() : [];
      if (this._cv_actionTimer) this._cv_actionTimer.invalidate();
      this._cv_actionTimer = this.invokeLater(this._cv_action, delay, view, ev, sel) ;
    }
  },

  /** @private
    Perform the action.  Supports legacy behavior as well as newer style
    action dispatch.
  */
  _cv_action: function(view, evt, context) {
    var action = this.get('action');

    this._cv_actionTimer = null;
    if (action) {

      // Legacy support for action functions.
      if (action && (SC.typeOf(action) === SC.T_FUNCTION)) {
        return this.action(view, evt);

      // Use SC.ActionSupport.
      } else {
        return this.fireAction(context);
      }

    // if no action is specified, then trigger the support action,
    // if supported.
    } else if (!view) {
      return ; // nothing to do

    // if the target view has its own internal action handler,
    // trigger that.
    } else if (SC.typeOf(view._action) === SC.T_FUNCTION) {
      return view._action(evt) ;

    // otherwise call the action method to support older styles.
    } else if (SC.typeOf(view.action) === SC.T_FUNCTION) {
      return view.action(evt) ;
    }
  },

  /** @private */
  _attrsForContentIndex: function (idx) {
    var attrs = this._TMP_ATTRS, // NOTE: This is a shared object so every property of it must be set for each use.
      del = this.get('contentDelegate'),
      items = this.get('content'),
      isGroupView = this._contentIndexIsGroup(idx),
      isEditable = this.get('isEditable') && this.get('canEditContent'),
      isReorderable = this.get('isEditable') && this.get('canReorderContent'),
      isDeletable = this.get('isEditable') && this.get('canDeleteContent'),
      isEnabled = del.contentIndexIsEnabled(this, items, idx),
      isSelected = del.contentIndexIsSelected(this, items, idx),
      outlineLevel = del.contentIndexOutlineLevel(this, items, idx),
      disclosureState = del.contentIndexDisclosureState(this, items, idx);

    attrs.contentIndex = idx;
    attrs.content = items.objectAt(idx);
    attrs.disclosureState = disclosureState;
    attrs.isEnabled = isEnabled;
    attrs.isEditable = isEditable;
    attrs.isReorderable = isReorderable;
    attrs.isDeletable = isDeletable;
    attrs.isSelected = isSelected;
    attrs.isGroupView = isGroupView;
    attrs.layerId = this.layerIdFor(idx);
    attrs.owner = attrs.displayDelegate = this;
    attrs.page = this.page;
    attrs.outlineLevel = outlineLevel;
    attrs.isLast = idx === items.get('length') - 1;

    if (isGroupView) attrs.classNames = this._GROUP_COLLECTION_CLASS_NAMES;
    else attrs.classNames = this._COLLECTION_CLASS_NAMES;

    // Layout may be calculated by the collection view beforehand. If so,
    // assign it to the attributes. If the collection view doesn't calculate
    // layout or defers calculating layout, then we shouldn't force a layout
    // on the child view.
    var layout = this.layoutForContentIndex(idx);
    if (layout) { attrs.layout = layout; }
    else { delete attrs.layout; }

    return attrs;
  },

  /** @private
    A cache of the `contentGroupIndexes` value returned by the delegate.  This
    is frequently accessed and usually involves creating an `SC.IndexSet`
    object, so it's worthwhile to cache.
  */
  _contentGroupIndexes: function () {
    return this.get('contentDelegate').contentGroupIndexes(this, this.get('content'));
  }.property('contentDelegate').cacheable(),

  /** @private
    Rather than calling contentIndexIsGroup on the delegate each time, first
    check if there are even any contentGroupIndexes.
  */
  _contentIndexIsGroup: function (idx) {
    var groupIndexes = this.get('_contentGroupIndexes');

    // If there are groupIndexes and the given index is within them, check
    // with the delegate.
    if (groupIndexes && groupIndexes.contains(idx)) {
      var del = this.get('contentDelegate'),
        items = this.get('content');

      return del.contentIndexIsGroup(this, items, idx);
    } else {
      return false;
  }
  },

  /** @private
    Determines the example view for a content index.
  */
  _exampleViewForContentIndex: function (idx) {
    var key,
      ExampleView,
      items = this.get('content'),
      item = items.objectAt(idx);

    if (this._contentIndexIsGroup(idx)) {
      // so, if it is indeed a group view, we go that route to get the example view
      key = this.get('contentGroupExampleViewKey');
      if (key && item) ExampleView = item.get(key);
      if (!ExampleView) ExampleView = this.get('groupExampleView') || this.get('exampleView');
    } else {
      // otherwise, we go through the normal example view
      key = this.get('contentExampleViewKey');
      if (key && item) ExampleView = item.get(key);
      if (!ExampleView) ExampleView = this.get('exampleView');
    }

    return ExampleView;
  },

  /** @private
    Returns the pool for a given example view.

    The pool is calculated based on the guid for the example view class.

    @param {SC.View} exampleView
  */
  _poolForExampleView: function (exampleView) {
    var poolKey = SC.guidFor(exampleView);
    if (!this._pools) { this._pools = {}; }
    if (!this._pools[poolKey]) this._pools[poolKey] = [];
    return this._pools[poolKey];
  },

  /** @private
    Override to compute the hidden layout of the itemView for the content at the
    specified idnex.  This layout will be applied when it is moved to the
    pool for reuse and should be completely outside the visible portion
    of the collection.

    By default this layout is determined using the normal layout for the item.
    If the regular layout has a height, the pooled layout will be one height
    off the top (for top positioned) or off the bottom (for bottom positioned)
    and if the regular layout has a width, the pooled layout will be one
    width off the left (for left positioned) or off the right (for right
    positioned).

    @param Number contentIndex the index of the item in the content
    @returns Object a view layout
  */
  _poolLayoutForContentIndex: function (contentIndex) {
    var layout = this.layoutForContentIndex(contentIndex);

    if (layout && layout.height) {
      // Handle both top aligned and bottom aligned layouts.
      if (layout.top) { layout.top = -layout.height; }
      else { layout.bottom = -layout.height; }
    } else if (layout && layout.width) {
      // Handle both left aligned and right aligned layouts.
      if (layout.left) { layout.left = -layout.width; }
      else { layout.right = -layout.width; }
    }

    return layout;
  },

  /** @private
    Configures an existing item view with new attributes.

    @param {SC.View} itemView
    @param {Hash} attrs
  */
  _reconfigureItemView: function (itemView, attrs) {
    itemView.beginPropertyChanges();

    // Update the view with the new properties.
    itemView.set('content', attrs.content);
    itemView.set('contentIndex', attrs.contentIndex);
    itemView.set('isEnabled', attrs.isEnabled);
    itemView.set('isEditable', attrs.isEditable);
    itemView.set('isReorderable', attrs.isReorderable);
    itemView.set('isDeletable', attrs.isDeletable);
    itemView.set('isSelected', attrs.isSelected);
    itemView.set('layerId', attrs.layerId);
    itemView.set('outlineLevel', attrs.outlineLevel);
    itemView.set('disclosureState', attrs.disclosureState);
    itemView.set('isLast', attrs.isLast);

    // Don't assign null/undefined layouts.
    if (attrs.layout) { itemView.set('layout', attrs.layout); }

    // If the view's isGroupView property is changing, the associated CSS classes need to
    // be updated.
    var isCurrentlyGroupView = itemView.get('isGroupView'),
        shouldBeGroupView = attrs.isGroupView;
    if (isCurrentlyGroupView !== shouldBeGroupView) {
      itemView.set('isGroupView', shouldBeGroupView);
      var classNames = itemView.get('classNames'),
          elem = itemView.$();
      // Going from group view to item view...
      if (isCurrentlyGroupView && !shouldBeGroupView) {
        classNames.pushObject('sc-item');
        classNames.removeObject('sc-group-item');
        elem.setClass({ 'sc-item': YES, 'sc-group-item': NO });
      }
      // Going from item view to group view...
      else {
        classNames.removeObject('sc-item');
        classNames.pushObject('sc-group-item');
        elem.setClass({ 'sc-item': NO, 'sc-group-item': YES });
      }
    }
    // Wrap up.
    itemView.endPropertyChanges();
  },

  /** @private
    Removes the item view, pooling it for re-use if possible.
  */
  _removeItemView: function (itemView, idx) {
    var exampleView,
      items = this.get('content'),
      canPoolView, canPoolLayer,
      poolLayout,
      pool,
      prototype,
      wasPooled = false;

    // Don't pool views whose content has changed, because if the example
    // view used is different than the new content, we would pool the wrong
    // type of view.
    if (items && itemView.get('content') === items.objectAt(idx)) {

      exampleView = this._exampleViewForContentIndex(idx);
      prototype = exampleView.prototype;
      canPoolView = SC.none(prototype.isReusable) || prototype.isReusable;
      if (canPoolView) {
        // If the exampleView is reusable, send the view to its pool.
        pool = this._poolForExampleView(exampleView);

        


        // Give the view a chance to do some clean up before sleeping.
        if (itemView.sleepInPool) { itemView.sleepInPool(this); }

        pool.push(itemView);

        // If the exampleView's layer isn't reusable, destroy it.
        poolLayout = this._poolLayoutForContentIndex(idx);
        canPoolLayer = poolLayout && (SC.none(prototype.isLayerReusable) || prototype.isLayerReusable);
        if (canPoolLayer) {
          // If the layer is sticking around, be sure to move it out of view.
          itemView.set('layout', poolLayout);
        } else {
          // We can't pool layers that are prohibited or that cannot be moved out of view (i.e. no poolLayout)
          itemView.destroyLayer();
        }

        // Ensure that the id of views in the pool don't clash with ids that
        // are used outside of it.
        itemView.set('layerId', SC.generateGuid(null, 'pool-'));

        wasPooled = true;
      }
    }

    if (!wasPooled) {
      itemView.destroy();
    }

    // Remove the cached view (can still exist in the pool)
    delete this._sc_itemViews[idx];
  }

});

/* >>>>>>>>>> BEGIN source/views/date_field.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
/*globals Shared */

/** @class

  A Date field add behaviour to the Text Field to support date management,
  for example, disabling deletion, and special behaviour to tabs commands.

  This field view is tightly integrated with SC.DateTime

  By default the Date Field View show Date only, but if you need to show the Time do:

      dateAndTime: Shared.DateFieldView.design({
        showTime: YES,
        valueBinding: '...'
      }),

  and if you only need to show time:

      timeOnly: Shared.DateFieldView.design({
        showTime: YES,
        showDate: NO,
        valueBinding: '...'
      })

  Example usage with special format:

      specialDate: Shared.DateFieldView.design({
        formatDate: '%d %b of %Y',
        valueBinding: '...'
      }),

  You can override these format as you like, but has some limitations,
  actually only support these KEY from SC.DateTime:

  %a %b %d %H %I %j %m %M %p %S %U %W %y %Y

  These are keys that has FIXED length, so we can control the selection and tabing.

  @extends SC.TextFieldView
  @since SproutCore 1.0
  @author Juan Pablo Goldfinger
*/
SC.DateFieldView = SC.TextFieldView.extend(
/** @scope SC.DateFieldView.prototype */ {

  /**
    @type String
    @default null
  */
  value: null,

  /**
    @type Boolean
    @default YES
  */
  showDate: YES,

  /**
    @type Boolean
    @default NO
  */
  showTime: NO,

  /**
    Set this to NO to disallow the default keyboard handling, which attempts to convert
    numeric keystrokes into valid dates.

    @type Boolean
    @default YES
  */
  allowNumericInput: YES,

  /**
    @type String
    @default '%I:%M %p'
  */
  formatTime: '%I:%M %p',

  /**
    @type String
    @default '%d/%m/%Y'
  */
  formatDate: '%d/%m/%Y',

  /**
    @type String
    @default '%d/%m/%Y %I:%M %p'
  */
  formatDateTime: '%d/%m/%Y %I:%M %p',

  // DateTime constants (with fixed width, like numbers or abbs with fixed length)
  // original: '%a %A %b %B %c %d %h %H %i %I %j %m %M %p %S %U %W %x %X %y %Y %Z %%'.w(),
  // NOTE: I think that %a and %b aren't useful because is more adequate to represent day
  // with 1..31 without zeros at start, but causes the length not to be fixed)

  /** @private*/
  _dtConstants: ['%a', '%b', '%d', '%H', '%I', '%j', '%m', '%M', '%p', '%S', '%U', '%W', '%y', '%Y'],
  // Width constants for each representation %@.

  /** @private */
  _wtConstants: [3,3,2,2,2,3,2,2,2,2,2,2,2,4],

  /** @private */
  activeSelection: 0,

  /*
  FUTURE: DatePickerSupport.
  createChildViews: function() {
    arguments.callee.base.apply(this,arguments);
    if (SC.browser.isWebkit) {
      // ON MOZILLA DON'T WORK
      var view = Shared.DatePickerView.extend({
        layout: { right: 0, centerY: 0, width: 18, height: 15 }
      });
      view.bind('value', [this, 'value']);
      view.bind('isVisible', [this, 'isEnabled']);
      this.set('rightAccessoryView', view);
    }
  },
  */

  /**
    The current format to apply for Validator and to show.

    @field
    @type String
    @observes showTime
    @observes showDate
  */
  format: function() {
    var st = this.get('showTime');
    var sd = this.get('showDate');
    if (st === YES && sd === YES) return this.get('formatDateTime');
    if (st === YES) return this.get('formatTime');
    return this.get('formatDate');
  }.property('showTime', 'showDate', 'formatDateTime', 'formatDate', 'formatTime').cacheable(),

  /**
    The current validator to format the Date to the input field and vice versa.

    @field
    @type SC.Validator.DateTime
    @observes format
  */
  validator: function() {
    return SC.Validator.DateTime.extend({ format: this.get('format') });
  }.property('format').cacheable(),

  /**
    Array of Key/TextSelection found for the current format.

    @field
    @type SC.Array
  */
  tabsSelections: function() {
    var arr = [];
    var ft = this.get('format');
    var _dt = this.get('_dtConstants');
    var _wt = this.get('_wtConstants');

    // Parse the string format to retrieve and build
    // a TextSelection array ordered to support tabs behaviour
    if (SC.empty(ft)) {
      throw new Error('The format string is empty, and must be a valid string.');
    }

    var pPos, key, keyPos, startAt = 0, nPos = 0, oPos = 0;
    while(startAt < ft.length && ft.indexOf('%', startAt) !== -1) {
      pPos = ft.indexOf('%', startAt);
      key = ft.substring(pPos, pPos + 2);
      startAt = pPos + 2;

      keyPos = _dt.indexOf(key);
      if (keyPos === -1) {
        throw new Error("SC.DateFieldView: The format's key '%@' is not supported.".fmt(key));
      }
      nPos = nPos + pPos - oPos;
      arr.push(SC.Object.create({
        key: key,
        textSelection: SC.TextSelection.create({ start: nPos, end: nPos + _wt[keyPos] })
      }));
      nPos = nPos + _wt[keyPos];
      oPos = startAt;
    }
    pPos = key = keyPos = null;

    return arr;
  }.property('format').cacheable(),

  /** @private
    If the activeSelection changes or the value changes, update the "TextSelection" to show accordingly.
  */
  updateTextSelectionObserver: function() {
    var as = this.get('activeSelection');
    var ts = this.get('tabsSelections');
    if (this.get('isEditing')) {
      this.selection(null, ts[as].get('textSelection'));
    }
  }.observes('activeSelection', 'value'),

  /** @private
    Updates the value according the key.
  */
  updateValue: function(key, upOrDown) {
    // 0 is DOWN - 1 is UP
    var newValue = (upOrDown === 0) ? -1 : 1;
    var value = this.get('value'), hour;
    switch(key) {
      case '%a': case '%d': case '%j': this.set('value', value.advance({ day: newValue })); break;
      case '%b': case '%m': this.set('value', value.advance({ month: newValue })); break;
      case '%H': case '%I': this.set('value', value.advance({ hour: newValue })); break;
      case '%M': this.set('value', value.advance({ minute: newValue })); break;
      case '%p': {
        hour = value.get('hour') >= 12 ? -12 : 12;
        this.set('value', value.advance({ hour: hour }));
        break;
      }
      case '%S': this.set('value', value.advance({ second: newValue })); break;
      case '%U': this.set('value', value.advance({ week1: newValue })); break;
      case '%W': this.set('value', value.advance({ week0: newValue })); break;
      case '%y': case '%Y': this.set('value', value.advance({ year: newValue })); break;
    }
  },


  /** @private */
  _lastValue: null,

  /** @private */
  _lastKey: null,

  _selectRootElement: function() {
    // TODO: This is a solution while I don't found how we
    // receive the last key from the last input.
    // (to see if is entering with Tab or backTab)
    /*if (this.get('activeSelection') === -1) {
    }*/
  },


  // ..........................................................
  // Key Event Support
  //

  /** @private */
  keyDown: function(evt) {
    if (this.interpretKeyEvents(evt)) {
      evt.stop();
      return YES;
    }
    return arguments.callee.base.apply(this,arguments);
  },

  /** @private */
  ctrl_a: function() {
    return YES;
  },

  /** @private */
  moveUp: function(evt) {
    var as = this.get('activeSelection');
    var ts = this.get('tabsSelections');
    this.updateValue(ts[as].get('key'), 1);
    return YES;
  },

  /** @private */
  moveDown: function(evt) {
    var as = this.get('activeSelection');
    var ts = this.get('tabsSelections');
    this.updateValue(ts[as].get('key'), 0);
    return YES;
  },

  /** @private */
  moveRight: function(evt) {
    var ts = this.get('tabsSelections');
    var ns = this.get('activeSelection') + 1;
    if (ns === ts.length) {
      ns = 0;
    }
    this.set('activeSelection', ns);
    return YES;
  },

  /** @private */
  moveLeft: function(evt) {
    var ts = this.get('tabsSelections');
    var ns = this.get('activeSelection') - 1;
    if (ns === -1) {
      ns = ts.length - 1;
    }
    this.set('activeSelection', ns);
    return YES;
  },

  /** @private */
  insertTab: function(evt) {
    var ts = this.get('tabsSelections');
    var ns = this.get('activeSelection') + 1;
    if (ns < ts.length) {
      this.set('activeSelection', ns);
      return YES;
    }
    return NO;
  },

  /** @private */
  insertBacktab: function(evt) {
    var ns = this.get('activeSelection') - 1;
    if (ns !== -1) {
      this.set('activeSelection', ns);
      return YES;
    }
    return NO;
  },

  /** @private */
  mouseUp: function(evt) {
    var ret = arguments.callee.base.apply(this,arguments);
    var cs = this.get('selection');
    if (SC.none(cs)) {
      this.set('activeSelection', 0);
    } else {
      var caret = cs.get('start');
      var ts = this.get('tabsSelections');
      var _tsLen = ts.length, cts;
      for(var i=0; i<_tsLen; i++) {
        cts = ts[i].get('textSelection');
        if (caret >= cts.get('start') && caret <= cts.get('end')) {
          this.set('activeSelection', i);
        }
      }
    }
    return ret;
  },

  /** @private */
  deleteBackward: function(evt) {
    return YES;
  },

  /** @private */
  deleteForward: function(evt) {
    return YES;
  },

  /** @private */
  _numericCharacters: ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9'],
  /** @private */
  _nonnumericCharacters: [' ', '-', '/', ':'],
  /** @private Validates and applies supported keystrokes. */
  insertText: function(chr, evt) {
    // If it's a nonnumeric "advance" character, advance.
    // TODO: instead of having a list of possible delimiter characters, we should actually look
    // at what the next separator character is and only advance on that one.
    if (this._nonnumericCharacters.contains(chr)) this.moveRight();

    // If it's a numeric character (and we're doing those), validate and apply it.
    if (this.get('allowNumericInput') && this._numericCharacters.contains(chr)) {
      var as = this.get('activeSelection'),
          ts = this.get('tabsSelections'),
          key = ts[as].get('key');

      var value = this.get('value'),
          lastValue = this._lastValue,
          length = 2,
          min = 0,
          max, key, newValue;

      switch(key) {
        case '%Y':
          key = 'year';
          min = 1000;
          max = 9999;
          length = 4;
        break;
        case '%y':
          key = 'year';
          max = 99;
        break;
        case '%m':
          key = 'month';
          min = 1;
          max = 12;
        break;
        case '%d':
          key = 'day';
          min = 1;
          max = value.advance({ month: 1 }).adjust({ day: 0 }).get('day');
        break;
        case '%H':
          key = 'hour';
          max = 23;
        break;
        case '%I':
          key = 'hour';
          max = 11;
        break;
        case '%M':
          key = 'minute';
          max = 59;
        break;
        case '%S':
          key = 'second';
          max = 59;
        break;
      }

      if (SC.none(lastValue) || this._lastKey !== key) {
        lastValue = value.get(key);
        lastValue = (lastValue < 10 ? '0' : '') + lastValue;
      }

      if (lastValue.length > length) lastValue = lastValue.substr(-length);

      // Removes the first character and adds the new one at the end of the string
      lastValue = lastValue.slice(1) + chr;
      newValue = parseInt(lastValue, 10);

      // If the value is allow, updates the value
      if (newValue <= max && newValue >= min) {
        var hash = {};
        hash[key] = newValue;

        this.set('value', value.adjust(hash, NO));
      }

      this._lastValue = lastValue;
      this._lastKey = key;
    }

    // Regardless, we handled the event.
    return YES;
  }
});

/* >>>>>>>>>> BEGIN source/views/disclosure.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @class
  
  Disclosure triangle button. As a subclass of SC.ButtonView, this view
  takes a lot of the same properties as a button:
  
    - isEnabled: whether disclosure triangle is clickable or not
    - value: `YES` or `NO` (where `YES` implies expanded/open)
  
  A disclosure view also supports expanding and collapsing via
  the keyboard.
  
  @extends SC.ButtonView
  @since SproutCore 1.0
*/
SC.DisclosureView = SC.ButtonView.extend(
/** @scope SC.DisclosureView.prototype */ {
  
  /**
    @type Array
    @default ['sc-disclosure-view']
    @see SC.View#classNames
  */
  classNames: ['sc-disclosure-view'],

  /**
    @type String
    @default 'disclosureRenderDelegate'
  */
  renderDelegateName: 'disclosureRenderDelegate',

  /**
    @type String
    @default SC.TOGGLE_BEHAVIOR
    @see SC.ButtonView#buttonBehavior
  */
  buttonBehavior: SC.TOGGLE_BEHAVIOR,
  
  /**
    This is the value that will be set when the disclosure triangle is toggled
    open.
    
    @type Boolean
    @default YES
  */
  toggleOnValue: YES,
  
  /**
    The value that will be set when the disclosure triangle is toggled closed.
    
    @type Boolean
    @default YES
  */
  toggleOffValue: NO,
  
  /** @private */
  valueBindingDefault: SC.Binding.bool(),

  /** @private

    Allows toggling of the value with the right and left arrow keys.
    Extends the behavior inherited from SC.ButtonView.
    @param evt
  */
  keyDown: function(evt) {
    if (evt.which === 37 || evt.which === 38) {
      this.set('value', this.get('toggleOffValue')) ;
      return YES;
    }

    if (evt.which === 39 || evt.which === 40) {
      this.set('value', this.get('toggleOnValue')) ;
      return YES;
    }
    arguments.callee.base.apply(this,arguments);
  }

});

/* >>>>>>>>>> BEGIN source/views/list_item.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


/**
  @static
  @constant
*/
SC.LIST_ITEM_ACTION_CANCEL = 'sc-list-item-cancel-action';

/**
  @static
  @constant
*/
SC.LIST_ITEM_ACTION_REFRESH = 'sc-list-item-cancel-refresh';

/**
  @static
  @constant
*/
SC.LIST_ITEM_ACTION_EJECT = 'sc-list-item-cancel-eject';

/**
  @class

  Many times list items need to display a lot more than just a label of text.
  You often need to include checkboxes, icons, right icons, extra counts and
  an action or warning icon to the far right.

  A ListItemView can implement all of this for you in a more efficient way
  than you might get if you simply put together a list item on your own using
  views.

  @extends SC.View
  @extends SC.Control
  @extends SC.InlineEditable
  @since SproutCore 1.0
*/
SC.ListItemView = SC.View.extend(SC.InlineEditable, SC.Control,
/** @scope SC.ListItemView.prototype */ {

  /**
    @type Array
    @default ['sc-list-item-view']
    @see SC.View#classNames
  */
  classNames: ['sc-list-item-view'],

  /**
    @type Array
    @default ['disclosureState', 'escapeHTML']
    @see SC.View#displayProperties
  */
  displayProperties: ['disclosureState', 'escapeHTML', 'isDropTarget'],


  // ..........................................................
  // KEY PROPERTIES
  //

  /**
    The index of the content object in the ListView to which this
    ListItemView belongs.

    For example, if this ListItemView represents the first object
    in a ListView, this property would be 0.

    @type Number
    @default null
    @readOnly
  */
  contentIndex: null,

  /**
    (displayDelegate) True if you want the item view to display an icon.

    If false, the icon on the list item view will be hidden.  Otherwise,
    space will be left for the icon next to the list item view.

    @type Boolean
    @default NO
  */
  hasContentIcon: NO,

  /**
    (displayDelegate) True if you want the item view to display a right icon.

    If false, the icon on the list item view will be hidden.  Otherwise,
    space will be left for the icon next to the list item view.

    @type Boolean
    @default NO
  */
  hasContentRightIcon: NO,

  /**
    (displayDelegate) True if you want space to be allocated for a branch
    arrow.

    If false, the space for the branch arrow will be collapsed.

    @type Boolean
    @default NO
  */
  hasContentBranch: NO,

  /**
    (displayDelegate) The name of the property used for the checkbox value.

    The checkbox will only be visible if this key is not null.

    @type String
    @default null
  */
  contentCheckboxKey: null,

  /**
    The URL or CSS class name to use for the icon. This is only used if
    contentIconKey is null, or returns null from the delegate.

    @type String
    @default null
  */
  icon: null,

  /**
    Whether this item is the drop target of a drag operation.

    If the list view supports the SC.DROP_ON operation, it will set this
    property on whichever list item view is the current target of the drop.

    When true, the 'drop-target' class is added to the element.

    @type Boolean
    @default false
  */
  isDropTarget: NO,

  /**
    (displayDelegate) Property key to use for the icon url

    This property will be checked on the content object to determine the
    icon to display.  It must return either a URL or a CSS class name.

    @type String
    @default NO
  */
  contentIconKey: null,

  /**
    The URL or CSS class name to use for the right icon. This is only used if
    contentRightIconKey is null, or returns null from the delegate.

    @type String
    @default null
  */
  rightIcon: null,

  /**
    (displayDelegate) Property key to use for the right icon url

    This property will be checked on the content object to determine the
    icon to display.  It must return either a URL or a CSS class name.

    @type String
    @default null
  */
  contentRightIconKey: null,

  /**
    (displayDelegate) The name of the property used for label itself

    If null, then the content object itself will be used..

    @type String
    @default null
  */
  contentValueKey: null,

  /**
    IF true, the label value will be escaped to avoid HTML injection attacks.
    You should only disable this option if you are sure you will only
    display content that is already escaped and you need the added
    performance gain.

    @type Boolean
    @default YES
  */
  escapeHTML: YES,

  /**
    (displayDelegate) The name of the property used to find the count of
    unread items.

    The count will only be visible if this property is not null and the
    returned value is not 0.

    @type String
    @default null
  */
  contentUnreadCountKey: null,

  /**
    (displayDelegate) The name of the property used to determine if the item
    is a branch or leaf (i.e. if the branch icon should be displayed to the
    right edge.)

    If this is null, then the branch view will be completely hidden.
    Otherwise space will be allocated for it.

    @type String
    @default null
  */
  contentIsBranchKey: null,

  /**
    Indent to use when rendering a list item with an outline level > 0.  The
    left edge of the list item will be indented by this amount for each
    outline level.

    @type Number
    @default 16
  */
  outlineIndent: 16,

  /**
    Outline level for this list item.  Usually set by the collection view.

    @type Number
    @default 0
  */
  outlineLevel: 0,

  /**
    Disclosure state for this list item.  Usually set by the collection view
    when the list item is created. Possible values:

      - SC.LEAF_NODE
      - SC.BRANCH_OPEN
      - SC.BRANCH_CLOSED

    @type String
    @default SC.LEAF_NODE
  */
  disclosureState: SC.LEAF_NODE,

  /**
    The validator to use for the inline text field created when the list item
    is edited.
  */
  validator: null,

  contentKeys: {
    contentValueKey: 'title',
    contentCheckboxKey: 'checkbox',
    contentIconKey:  'icon',
    contentRightIconKey: 'rightIcon',
    contentUnreadCountKey: 'count',
    contentIsBranchKey: 'branch'
  },

  /** @private */
  contentPropertyDidChange: function () {
    //if (this.get('isEditing')) this.discardEditing();
    if (this.get('contentIsEditable') !== this.contentIsEditable()) {
      this.notifyPropertyChange('contentIsEditable');
    }

    this.displayDidChange();
  },

  /**
    Determines if content is editable or not. Checkboxes and other related
    components will render disabled if an item is not editable.

    @field
    @type Boolean
    @observes content
  */
  contentIsEditable: function () {
    var content = this.get('content');
    return content && (content.get ? content.get('isEditable') !== NO : NO);
  }.property('content').cacheable(),

  /**
    @type Object
    @default SC.InlineTextFieldDelegate
  */
  inlineEditorDelegate: SC.InlineTextFieldDelegate,

  /**
    Finds and retrieves the element containing the label.  This is used
    for inline editing.  The default implementation returns a CoreQuery
    selecting any label elements.   If you override renderLabel() you
    probably need to override this as well.

    @returns {jQuery} jQuery object selecting label elements
  */
  $label: function () {
    return this.$('label');
  },

  /** @private
    Determines if the event occurred inside an element with the specified
    classname or not.
  */
  _isInsideElementWithClassName: function (className, evt) {
    var layer = this.get('layer');
    if (!layer) return NO; // no layer yet -- nothing to do

    var el = SC.$(evt.target);
    var ret = NO;
    while (!ret && el.length > 0 && (el[0] !== layer)) {
      if (el.hasClass(className)) ret = YES;
      el = el.parent();
    }
    el = layer = null; //avoid memory leaks
    return ret;
  },

  /** @private
    Returns YES if the list item has a checkbox and the event occurred
    inside of it.
  */
  _isInsideCheckbox: function (evt) {
    var del = this.displayDelegate;
    var checkboxKey = this.getDelegateProperty('contentCheckboxKey', del);
    return checkboxKey && this._isInsideElementWithClassName('sc-checkbox-view', evt);
  },

  /** @private
    Returns YES if the list item has a disclosure triangle and the event
    occurred inside of it.
  */
  _isInsideDisclosure: function (evt) {
    if (this.get('disclosureState') === SC.LEAF_NODE) return NO;
    return this._isInsideElementWithClassName('sc-disclosure-view', evt);
  },

  /** @private
    Returns YES if the list item has a right icon and the event
    occurred inside of it.
  */
  _isInsideRightIcon: function (evt) {
    var del = this.displayDelegate;
    var rightIconKey = this.getDelegateProperty('hasContentRightIcon', del) || !SC.none(this.rightIcon);
    return rightIconKey && this._isInsideElementWithClassName('right-icon', evt);
  },

  /** @private
    mouseDown is handled only for clicks on the checkbox view or or action
    button.
  */
  mouseDown: function (evt) {
    // Fast path, reject secondary clicks.
    if (evt.which && evt.which !== 1) return false;

    // if content is not editable, then always let collection view handle the
    // event.
    if (!this.get('contentIsEditable')) return NO;

    // if occurred inside checkbox, item view should handle the event.
    if (this._isInsideCheckbox(evt)) {
      this._addCheckboxActiveState();
      this._isMouseDownOnCheckbox = YES;
      this._isMouseInsideCheckbox = YES;
      return YES; // listItem should handle this event

    } else if (this._isInsideDisclosure(evt)) {
      this._addDisclosureActiveState();
      this._isMouseDownOnDisclosure = YES;
      this._isMouseInsideDisclosure = YES;
      return YES;
    } else if (this._isInsideRightIcon(evt)) {
      this._addRightIconActiveState();
      this._isMouseDownOnRightIcon = YES;
      this._isMouseInsideRightIcon = YES;
      return YES;
    }

    return NO; // let the collection view handle this event
  },

  /** @private */
  mouseUp: function (evt) {
    var ret = NO, del, checkboxKey, content, state, idx, set;

    // if mouse was down in checkbox -- then handle mouse up, otherwise
    // allow parent view to handle event.
    if (this._isMouseDownOnCheckbox) {

      // update only if mouse inside on mouse up...
      if (this._isInsideCheckbox(evt)) {
        del = this.displayDelegate;
        checkboxKey = this.getDelegateProperty('contentCheckboxKey', del);
        content = this.get('content');
        if (content && content.get) {
          var value = content.get(checkboxKey);
          value = (value === SC.MIXED_STATE) ? YES : !value;
          content.set(checkboxKey, value); // update content
          this.displayDidChange(); // repaint view...
        }
      }

      this._removeCheckboxActiveState();
      ret = YES;

    // if mouse as down on disclosure -- handle mouse up.  otherwise pass on
    // to parent.
    } else if (this._isMouseDownOnDisclosure) {
      if (this._isInsideDisclosure(evt)) {
        state = this.get('disclosureState');
        idx   = this.get('contentIndex');
        set   = (!SC.none(idx)) ? SC.IndexSet.create(idx) : null;
        del = this.get('displayDelegate');

        if (state === SC.BRANCH_OPEN) {
          if (set && del && del.collapse) del.collapse(set);
          else this.set('disclosureState', SC.BRANCH_CLOSED);
          this.displayDidChange();

        } else if (state === SC.BRANCH_CLOSED) {
          if (set && del && del.expand) del.expand(set);
          else this.set('disclosureState', SC.BRANCH_OPEN);
          this.displayDidChange();
        }
      }

      this._removeDisclosureActiveState();
      ret = YES;
    // if mouse was down in right icon -- then handle mouse up, otherwise
    // allow parent view to handle event.
    } else if (this._isMouseDownOnRightIcon) {
      this._removeRightIconActiveState();
      ret = YES;
    }

    // clear cached info
    this._isMouseInsideCheckbox = this._isMouseDownOnCheckbox = NO;
    this._isMouseDownOnDisclosure = this._isMouseInsideDisclosure = NO;
    this._isMouseInsideRightIcon = this._isMouseDownOnRightIcon = NO;
    return ret;
  },

  /** @private */
  mouseMoved: function (evt) {
    if (this._isMouseDownOnCheckbox && this._isInsideCheckbox(evt)) {
      this._addCheckboxActiveState();
      this._isMouseInsideCheckbox = YES;
    } else if (this._isMouseDownOnCheckbox) {
      this._removeCheckboxActiveState();
      this._isMouseInsideCheckbox = NO;
    } else if (this._isMouseDownOnDisclosure && this._isInsideDisclosure(evt)) {
      this._addDisclosureActiveState();
      this._isMouseInsideDisclosure = YES;
    } else if (this._isMouseDownOnDisclosure) {
      this._removeDisclosureActiveState();
      this._isMouseInsideDisclosure = NO;
    } else if (this._isMouseDownOnRightIcon && this._isInsideRightIcon(evt)) {
      this._addRightIconActiveState();
      this._isMouseInsideRightIcon = YES;
    } else if (this._isMouseDownOnRightIcon) {
      this._removeRightIconActiveState();
      this._isMouseInsideRightIcon = NO;
    }

    return NO;
  },

  /** @private */
  touchStart: function (evt) {
    return this.mouseDown(evt);
  },

  /** @private */
  touchEnd: function (evt) {
    return this.mouseUp(evt);
  },

  /** @private */
  touchEntered: function (evt) {
    return this.mouseEntered(evt);
  },

  /** @private */
  touchExited: function (evt) {
    return this.mouseExited(evt);
  },


  /** @private */
  _addCheckboxActiveState: function () {
    if (this.get('isEnabled')) {
      if (this._checkboxRenderDelegate) {
        var source = this._checkboxRenderSource;

        source.set('isActive', YES);

        this._checkboxRenderDelegate.update(source, this.$('.sc-checkbox-view'));
      } else {
        // for backwards-compatibility.
        this.$('.sc-checkbox-view').addClass('active');
      }
    }
  },

  /** @private */
  _removeCheckboxActiveState: function () {
    if (this._checkboxRenderer) {
      var source = this._checkboxRenderSource;

      source.set('isActive', NO);

      this._checkboxRenderDelegate.update(source, this.$('.sc-checkbox-view'));
    } else {
      // for backwards-compatibility.
      this.$('.sc-checkbox-view').removeClass('active');
    }
  },

  /** @private */
  _addDisclosureActiveState: function () {
    if (this.get('isEnabled')) {
      if (this._disclosureRenderDelegate) {
        var source = this._disclosureRenderSource;
        source.set('isActive', YES);

        this._disclosureRenderDelegate.update(source, this.$('.sc-disclosure-view'));
      } else {
        // for backwards-compatibility.
        this.$('.sc-disclosure-view').addClass('active');
      }

    }
  },

  /** @private */
  _removeDisclosureActiveState: function () {
    if (this._disclosureRenderer) {
      var source = this._disclosureRenderSource;
      source.set('isActive', NO);

      this._disclosureRenderDelegate.update(source, this.$('.sc-disclosure-view'));
    } else {
      // for backwards-compatibility.
      this.$('.sc-disclosure-view').addClass('active');
    }
  },

  /** @private */
  _addRightIconActiveState: function () {
    this.$('img.right-icon').setClass('active', YES);
  },

  /** @private */
  _removeRightIconActiveState: function () {
    this.$('img.right-icon').removeClass('active');

    var pane = this.get('pane'),
        del = this.displayDelegate,
        target = this.getDelegateProperty('rightIconTarget', del),
        action = this.getDelegateProperty('rightIconAction', del);

    if (action && pane) {
       pane.rootResponder.sendAction(action, target, this, pane);
    }

  },

  /** @private
    Returns true if a click is on the label text itself to enable editing.

    Note that if you override renderLabel(), you probably need to override
    this as well, or just $label() if you only want to control the element
    returned.

    @param evt {Event} the mouseUp event.
    @returns {Boolean} YES if the mouse was on the content element itself.
  */
  contentHitTest: function (evt) {
    // if not content value is returned, not much to do.
    var del = this.displayDelegate;
    var labelKey = this.getDelegateProperty('contentValueKey', del);
    if (!labelKey) return NO;

    // get the element to check for.
    var el = this.$label()[0];
    if (!el) return NO; // no label to check for.

    var cur = evt.target, layer = this.get('layer');
    while (cur && (cur !== layer) && (cur !== window)) {
      if (cur === el) return YES;
      cur = cur.parentNode;
    }

    return NO;
  },

  /*
    Edits the label portion of the list item. If scrollIfNeeded is YES, will
    scroll to the item before editing it.

    @params {Boolean} if the parent scroll view should be scrolled to this item
      before editing begins
    @returns {Boolean} YES if successful
  */
  beginEditing: function (original, scrollIfNeeded) {
    var el        = this.$label(),
        parent    = this.get('parentView');

    // if possible, find a nearby scroll view and scroll into view.
    // HACK: if we scrolled, then wait for a loop and get the item view again
    // and begin editing.  Right now collection view will regenerate the item
    // view too often.
    if (scrollIfNeeded && this.scrollToVisible()) {
      var collectionView = this.get('owner'),
        idx = this.get('contentIndex');

      this.invokeLast(function () {
        var item = collectionView.itemViewForContentIndex(idx);
        if (item && item.beginEditing) item.beginEditing(NO);
      });
      return YES; // let the scroll happen then begin editing...
    }

    else if (!parent || !el || el.get('length') === 0) return NO;

    else return original();
  }.enhance(),

  /*
    Configures the editor to overlay the label properly.
  */
  inlineEditorWillBeginEditing: function (editor, editable, value) {
    var content   = this.get('content'),
        del       = this.get('displayDelegate'),
        labelKey  = this.getDelegateProperty('contentValueKey', del),
        el        = this.$label(),
        validator = this.get('validator'),
        f, v, offset, fontSize, top, lineHeight, escapeHTML,
        lineHeightShift, targetLineHeight;

    v = (labelKey && content) ? (content.get ? content.get(labelKey) : content[labelKey]) : content;

    f = this.computeFrameWithParentFrame(null);

    // if the label has a large line height, try to adjust it to something
    // more reasonable so that it looks right when we show the popup editor.
    lineHeight = this._oldLineHeight = el.css('lineHeight');
    fontSize = el.css('fontSize');
    top = this.$().css('top');

    if (top) top = parseInt(top.substring(0, top.length - 2), 0);
    else top = 0;

    lineHeightShift = 0;

    if (fontSize && lineHeight) {
      targetLineHeight = fontSize * 1.5;
      if (targetLineHeight < lineHeight) {
        el.css({ lineHeight: '1.5' });
        lineHeightShift = (lineHeight - targetLineHeight) / 2;
      } else this._oldLineHeight = null;
    }

    el = el[0];
    offset = SC.offset(el);

    f.x = offset.x;
    f.y = offset.y + top + lineHeightShift;
    f.height = el.offsetHeight;
    f.width = el.offsetWidth;

    escapeHTML = this.get('escapeHTML');

    editor.set({
      value: v,
      exampleFrame: f,
      exampleElement: el,
      multiline: NO,
      validator: validator,
      escapeHTML: escapeHTML
    });
  },

  /** @private
    Allow editing.
  */
  inlineEditorShouldBeginEditing: function (inlineEditor) {
    return YES;
  },

  /** @private
   Hide the label view while the inline editor covers it.
  */
  inlineEditorDidBeginEditing: function (original, inlineEditor, value, editable) {
    original(inlineEditor, value, editable);

    var el = this.$label();
    this._oldOpacity = el.css('opacity');
    el.css('opacity', 0.0);

    // restore old line height for original item if the old line height
    // was saved.
    if (this._oldLineHeight) el.css({ lineHeight: this._oldLineHeight });
  }.enhance(),

  /** @private
   Update the field value and make it visible again.
  */
  inlineEditorDidCommitEditing: function (editor, finalValue, editable) {
    var content = this.get('content');
    var del = this.displayDelegate;
    var labelKey = this.getDelegateProperty('contentValueKey', del);

    if (labelKey && content) {
      if (content.set) content.set(labelKey, finalValue);
      else content[labelKey] = finalValue;
    }

    else this.set('content', finalValue);

    this.displayDidChange();

    this._endEditing();
  },

  _endEditing: function (original) {
    this.$label().css('opacity', this._oldOpacity);

    original();
  }.enhance(),

  /** SC.ListItemView is not able to update itself in place at this time. */
  // TODO: add update: support.
  isReusable: false,

  /** @private
    Fills the passed html-array with strings that can be joined to form the
    innerHTML of the receiver element.  Also populates an array of classNames
    to set on the outer element.

    @param {SC.RenderContext} context
    @param {Boolean} firstTime
    @returns {void}
  */
  render: function (context, firstTime) {
    var content = this.get('content'),
        del     = this.displayDelegate,
        level   = this.get('outlineLevel'),
        indent  = this.get('outlineIndent'),
        key, value, working, classArray = [];

    // add alternating row classes
    classArray.push((this.get('contentIndex') % 2 === 0) ? 'even' : 'odd');
    context.setClass('disabled', !this.get('isEnabled'));
    context.setClass('drop-target', this.get('isDropTarget'));

    // outline level wrapper
    working = context.begin("div").addClass("sc-outline");
    if (level >= 0 && indent > 0) working.addStyle("left", indent * (level + 1));

    // handle disclosure triangle
    value = this.get('disclosureState');
    if (value !== SC.LEAF_NODE) {
      this.renderDisclosure(working, value);
      classArray.push('has-disclosure');
    } else if (this._disclosureRenderSource) {
      // If previously rendered a disclosure, clean up.
      context.removeClass('has-disclosure');
      this._disclosureRenderSource.destroy();

      this._disclosureRenderSource = this._disclosureRenderDelegate = null;
    }

    // handle checkbox
    key = this.getDelegateProperty('contentCheckboxKey', del);
    if (key) {
      value = content ? (content.get ? content.get(key) : content[key]) : NO;
      if (value !== null) {
        this.renderCheckbox(working, value);
        classArray.push('has-checkbox');
      } else if (this._checkboxRenderSource) {
        // If previously rendered a checkbox, clean up.
        context.removeClass('has-checkbox');
        this._checkboxRenderSource.destroy();

        this._checkboxRenderSource = this._checkboxRenderDelegate = null;
      }
    }

    // handle icon
    if (this.getDelegateProperty('hasContentIcon', del)) {
      key = this.getDelegateProperty('contentIconKey', del);
      value = (key && content) ? (content.get ? content.get(key) : content[key]) : null;

      if (value) {
        this.renderIcon(working, value);
        classArray.push('has-icon');
      }
    } else if (this.get('icon')) {
      value = this.get('icon');
      this.renderIcon(working, value);
      classArray.push('has-icon');
    }

    // handle label -- always invoke
    key = this.getDelegateProperty('contentValueKey', del);
    value = (key && content) ? (content.get ? content.get(key) : content[key]) : content;
    if (value && SC.typeOf(value) !== SC.T_STRING) value = value.toString();
    if (this.get('escapeHTML')) value = SC.RenderContext.escapeHTML(value);
    this.renderLabel(working, value);

    // handle right icon
    if (this.getDelegateProperty('hasContentRightIcon', del)) {
      key = this.getDelegateProperty('contentRightIconKey', del);
      value = (key && content) ? (content.get ? content.get(key) : content[key]) : null;

      if (value) {
        this.renderRightIcon(working, value);
        classArray.push('has-right-icon');
      }
    } else if (this.get('rightIcon')) {
      value = this.get('rightIcon');
      this.renderRightIcon(working, value);
      classArray.push('has-right-icon');
    }

    // handle unread count
    key = this.getDelegateProperty('contentUnreadCountKey', del);
    value = (key && content) ? (content.get ? content.get(key) : content[key]) : null;
    if (!SC.none(value) && (value !== 0)) {
      this.renderCount(working, value);
      var digits = ['zero', 'one', 'two', 'three', 'four', 'five'];
      var valueLength = value.toString().length;
      var digitsLength = digits.length;
      var digit = (valueLength < digitsLength) ? digits[valueLength] : digits[digitsLength - 1];
      classArray.push('has-count', digit + '-digit');
    } else {
      // If previously rendered a count, clean up.
      context.removeClass('has-count');
    }

    // handle action
    key = this.getDelegateProperty('listItemActionProperty', del);
    value = (key && content) ? (content.get ? content.get(key) : content[key]) : null;
    if (value) {
      this.renderAction(working, value);
      classArray.push('has-action');
    }

    // handle branch
    if (this.getDelegateProperty('hasContentBranch', del)) {
      key = this.getDelegateProperty('contentIsBranchKey', del);
      value = (key && content) ? (content.get ? content.get(key) : content[key]) : NO;
      this.renderBranch(working, value);
      classArray.push('has-branch');
    }
    context.addClass(classArray);
    context = working.end();
  },

  /** @private
    Adds a disclosure triangle with the appropriate display to the content.
    This method will only be called if the disclosure state of the view is
    something other than SC.LEAF_NODE.

    @param {SC.RenderContext} context the render context
    @param {Boolean} state YES, NO or SC.MIXED_STATE
    @returns {void}
  */
  renderDisclosure: function (context, state) {
    var renderer = this.get('theme').disclosureRenderDelegate;

    context = context.begin('div')
      .addClass('sc-disclosure-view')
      .addClass('sc-regular-size')
      .addClass(this.get('theme').classNames)
      .addClass(renderer.get('className'));

    var source = this._disclosureRenderSource;
    if (!source) {
      this._disclosureRenderSource = source =
      SC.Object.create({ renderState: {}, theme: this.get('theme') });
    }

    source
      .set('isSelected', state === SC.BRANCH_OPEN)
      .set('isEnabled', this.get('isEnabled'))
      .set('title', '');

    renderer.render(source, context);

    context = context.end();
    this._disclosureRenderDelegate = renderer;
  },

  /** @private
    Adds a checkbox with the appropriate state to the content.  This method
    will only be called if the list item view is supposed to have a
    checkbox.

    @param {SC.RenderContext} context the render context
    @param {Boolean} state YES, NO or SC.MIXED_STATE
    @returns {void}
  */
  renderCheckbox: function (context, state) {
    var renderer = this.get('theme').checkboxRenderDelegate;

    // note: checkbox-view is really not the best thing to do here; we should do
    // sc-list-item-checkbox; however, themes expect something different, unfortunately.
    context = context.begin('div')
      .addClass('sc-checkbox-view')
      .addClass('sc-regular-size')
      .addClass(this.get('theme').classNames)
      .addClass(renderer.get('className'));

    var source = this._checkboxRenderSource;
    if (!source) {
      source = this._checkboxRenderSource =
      SC.Object.create({ renderState: {}, theme: this.get('theme') });
    }

    source
      .set('isSelected', state && (state !== SC.MIXED_STATE))
      .set('isEnabled', this.get('isEnabled') && this.get('contentIsEditable'))
      .set('isActive', this._checkboxIsActive)
      .set('title', '');

    renderer.render(source, context);
    context = context.end();

    this._checkboxRenderDelegate = renderer;
  },

  /** @private
    Generates an icon for the label based on the content.  This method will
    only be called if the list item view has icons enabled.  You can override
    this method to display your own type of icon if desired.

    @param {SC.RenderContext} context the render context
    @param {String} icon a URL or class name.
    @returns {void}
  */
  renderIcon: function (context, icon) {
    // get a class name and url to include if relevant
    var url = null, className = null, classArray = [];
    if (icon && SC.ImageView.valueIsUrl(icon)) {
      url = icon;
      className = '';
    } else {
      className = icon;
      url = SC.BLANK_IMAGE_URL;
    }

    // generate the img element...
    classArray.push(className, 'icon');
    context.begin('img')
            .addClass(classArray)
            .setAttr('src', url)
            .end();
  },

  /** @private
   Generates a label based on the content.  You can override this method to
   display your own type of icon if desired.

   @param {SC.RenderContext} context the render context
   @param {String} label the label to display, already HTML escaped.
   @returns {void}
  */
  renderLabel: function (context, label) {
    context.push('<label>', label || '', '</label>');
  },

  /** @private
    Generates a right icon for the label based on the content.  This method will
    only be called if the list item view has icons enabled.  You can override
    this method to display your own type of icon if desired.

    @param {SC.RenderContext} context the render context
    @param {String} icon a URL or class name.
    @returns {void}
  */
  renderRightIcon: function (context, icon) {
    // get a class name and url to include if relevant
    var url = null,
      className = null,
      classArray = [];
    if (icon && SC.ImageView.valueIsUrl(icon)) {
      url = icon;
      className = '';
    } else {
      className = icon;
      url = SC.BLANK_IMAGE_URL;
    }

    // generate the img element...
    classArray.push('right-icon', className);
    context.begin('img')
      .addClass(classArray)
      .setAttr('src', url)
    .end();
  },

  /** @private
   Generates an unread or other count for the list item.  This method will
   only be called if the list item view has counts enabled.  You can
   override this method to display your own type of counts if desired.

   @param {SC.RenderContext} context the render context
   @param {Number} count the count
   @returns {void}
  */
  renderCount: function (context, count) {
    context.push('<span class="count"><span class="inner">',
                  count.toString(), '</span></span>');
  },

  /** @private
    Generates the html string used to represent the action item for your
    list item.  override this to return your own custom HTML

    @param {SC.RenderContext} context the render context
    @param {String} actionClassName the name of the action item
    @returns {void}
  */
  renderAction: function (context, actionClassName) {
    context.push('<img src="', SC.BLANK_IMAGE_URL, '" class="action" />');
  },

  /** @private
   Generates the string used to represent the branch arrow. override this to
   return your own custom HTML

   @param {SC.RenderContext} context the render context
   @param {Boolean} hasBranch YES if the item has a branch
   @returns {void}
  */
  renderBranch: function (context, hasBranch) {
    var classArray = [];
    classArray.push('branch', hasBranch ? 'branch-visible' : 'branch-hidden');
    context.begin('span')
          .addClass(classArray)
          .push('&nbsp;')
          .end();
  }

});

SC.ListItemView._deprecatedRenderWarningHasBeenIssued = false;

/* >>>>>>>>>> BEGIN source/views/list.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('views/collection');
sc_require('views/list_item');
sc_require('mixins/collection_row_delegate');

/** @class

  A list view renders vertical or horizontal lists of items.  It is a specialized
  form of collection view that is simpler than a table view, but more refined than
  a generic collection.

  You can use a list view just like any collection view, except that often you
  provide the rowSize, which will be either the height of each row when laying
  out rows vertically (the default) or the widht of each row when laying out
  the rows horizontally.

  ## Variable Row Heights

  Normally you set the row height or width through the rowSize property, but
  you can also support custom row sizes by assigning the `customRowSizeIndexes`
  property to an index set of all custom sized rows.

  ## Using ListView with Very Large Data Sets

  ListView implements incremental rendering, which means it will only render
  HTML for the items that are currently visible on the screen.  This means you
  can use it to efficiently render lists with 100K+ items or more very efficiently.

  If you need to work with very large lists of items however, be aware that
  calculating variable row sizes can become very expensive since the list
  view will essentially have to iterate over every item in the collection to
  determine each the total height or width.

  Therefore, to work with very large lists, you should consider using a design
  that allows your row sizes to remain uniform.  This will allow the list view
  to much more efficiently render content.

  Alternatively, to support differently sized and incrementally rendered item
  views, you may want to consider overriding the `offsetForRowAtContentIndex()`
  and `rowSizeForContentIndex()` methods to perform some specialized faster
  calculations that do not require inspecting every item in the collection.

  Note: row sizes and offsets are cached so once they are calculated
  the list view will be able to display very quickly.

  ## Dragging and Dropping

  When the list view is configured to accept drops onto its items, it
  will set the `isDropTarget` property on the target item accordingly.  This
  allows you to modify the appearance of the drop target list item accordingly
  (@see SC.ListItemView#isDropTarget).

  @extends SC.CollectionView
  @extends SC.CollectionRowDelegate
  @since SproutCore 1.0
*/
// (Can we also have an 'estimate row heights' property that will simply
// cheat for very long data sets to make rendering more efficient?)
SC.ListView = SC.CollectionView.extend(SC.CollectionRowDelegate,
/** @scope SC.ListView.prototype */ {

  /** @private */
  _sc_customRowSizeIndexes: null,

  /** @private */
  _sc_insertionPointView: null,

  /** @private */
  _sc_lastDropOnView: null,

  /** @private */
  _sc_layout: null,

  /** @private */
  _sc_sizeCache: null,

  /** @private */
  _sc_offsetCache: null,

  /** @private */
  _sc_rowDelegate: null,

  /** @private */
  _sc_rowSize: null,

  /**
    @type Array
    @default ['sc-list-view']
    @see SC.View#classNames
  */
  classNames: ['sc-list-view'],

  /**
    @type Boolean
    @default true
  */
  acceptsFirstResponder: true,

  /** @private SC.CollectionView.prototype */
  exampleView: SC.ListItemView,

  /**
    Determines the layout direction of the rows of items, either vertically or
    horizontally. Possible values:

      - SC.LAYOUT_HORIZONTAL
      - SC.LAYOUT_VERTICAL

    @type String
    @default SC.LAYOUT_VERTICAL
  */
  layoutDirection: SC.LAYOUT_VERTICAL,

  /**
    If set to true, the default theme will show alternating rows
    for the views this ListView created through exampleView property.

    @type Boolean
    @default false
  */
  showAlternatingRows: false,

  // ..........................................................
  // METHODS
  //

  /** @private */
  init: function () {
    arguments.callee.base.apply(this,arguments);

    this._sc_rowDelegateDidChange();
  },

  /** @private SC.CollectionView.prototype.destroy. */
  destroy: function () {
    arguments.callee.base.apply(this,arguments);

    // All manipulations made to objects we use must be reversed!
    var del = this._sc_rowDelegate;
    if (del) {
      del.removeObserver('_sc_totalRowSize', this, this._sc_rowSizeDidChange);
      del.removeObserver('customRowSizeIndexes', this, this._sc_customRowSizeIndexesDidChange);

      this._sc_rowDelegate = null;
    }

    var customRowSizeIndexes = this._sc_customRowSizeIndexes;
    if (customRowSizeIndexes) {
      customRowSizeIndexes.removeObserver('[]', this, this._sc_customRowSizeIndexesContentDidChange);

      this._sc_customRowSizeIndexes = null;
    }
  },

  /** @private */
  render: function (context, firstTime) {
    context.setClass('alternating', this.get('showAlternatingRows'));

    return arguments.callee.base.apply(this,arguments);
  },

  // ..........................................................
  // COLLECTION ROW DELEGATE SUPPORT
  //

  /**
    @field
    @type Object
    @observes 'delegate'
    @observes 'content'
  */
  rowDelegate: function () {
    var del = this.delegate,
      content = this.get('content');

    return this.delegateFor('isCollectionRowDelegate', del, content);
  }.property('delegate', 'content').cacheable(),

  /** @private - Whenever the rowDelegate changes, begin observing important properties */
  _sc_rowDelegateDidChange: function () {
    var last = this._sc_rowDelegate,
      del  = this.get('rowDelegate'),
      func = this._sc_rowSizeDidChange,
      func2 = this._sc_customRowSizeIndexesDidChange;

    if (last === del) return this; // nothing to do
    this._sc_rowDelegate = del;

    // last may be null on a new object
    if (last) {
      last.removeObserver('_sc_totalRowSize', this, func);
      last.removeObserver('customRowSizeIndexes', this, func2);
    }

    


    // Add the new observers.
    del.addObserver('_sc_totalRowSize', this, func);
    del.addObserver('customRowSizeIndexes', this, func2);

    // Trigger once to initialize.
    this._sc_rowSizeDidChange()._sc_customRowSizeIndexesDidChange();

    return this;
  }.observes('rowDelegate'),

  /** @private - Called whenever the _sc_totalRowSize changes. If the property actually changed then invalidate all row sizes. */
  _sc_rowSizeDidChange: function () {
    var del = this.get('rowDelegate'),
      totalRowSize = del.get('_sc_totalRowSize'),
      indexes;

    if (totalRowSize === this._sc_rowSize) return this; // nothing to do
    this._sc_rowSize = totalRowSize;

    indexes = SC.IndexSet.create(0, this.get('length'));
    this.rowSizeDidChangeForIndexes(indexes);

    return this;
  },

  /** @private - Called whenever the customRowSizeIndexes changes. If the property actually changed then invalidate affected row sizes. */
  _sc_customRowSizeIndexesDidChange: function () {
    var del   = this.get('rowDelegate'),
      indexes = del.get('customRowSizeIndexes'),
      last    = this._sc_customRowSizeIndexes,
      func    = this._sc_customRowSizeIndexesContentDidChange;

    // nothing to do
    if ((indexes === last) || (last && last.isEqual(indexes))) return this;

    // if we were observing the last index set, then remove observer
    if (last && this._sc_isObservingCustomRowSizeIndexes) {
      last.removeObserver('[]', this, func);
    }

    // only observe new index set if it exists and it is not frozen.
    this._sc_isObservingCustomRowSizeIndexes = indexes;
    if (indexes && !indexes.get('isFrozen')) {
      indexes.addObserver('[]', this, func);
    }

    // Trigger once to initialize.
    this._sc_customRowSizeIndexesContentDidChange();

    return this;
  },

  /** @private - Called whenever the customRowSizeIndexes set is modified. */
  _sc_customRowSizeIndexesContentDidChange: function () {
    var del     = this.get('rowDelegate'),
      indexes = del.get('customRowSizeIndexes'),
      last    = this._sc_customRowSizeIndexes,
      changed;

    // compute the set to invalidate.  the union of cur and last set
    if (indexes && last) {
      changed = indexes.copy().add(last);
    } else {
      changed = indexes || last;
    }

    this._sc_customRowSizeIndexes = indexes ? indexes.frozenCopy() : null;

    // invalidate
    this.rowSizeDidChangeForIndexes(changed);

    return this;
  },


  // ..........................................................
  // ROW PROPERTIES
  //

  /**
    Returns the top or left offset for the specified content index.  This will take
    into account any custom row sizes and group views.

    @param {Number} idx the content index
    @returns {Number} the row offset
  */
  rowOffsetForContentIndex: function (idx) {
    if (idx === 0) return 0; // Fast path!

    var del = this.get('rowDelegate'),
      totalRowSize = del.get('_sc_totalRowSize'),
      rowSpacing = del.get('rowSpacing'),
      ret, custom, cache, delta, max;

    ret = idx * totalRowSize;

		if (rowSpacing) {
      ret += idx * rowSpacing;
    }

    if (del.customRowSizeIndexes && (custom = del.get('customRowSizeIndexes'))) {

      // prefill the cache with custom rows.
      cache = this._sc_offsetCache;
      if (!cache) {
        cache = [];
        delta = max = 0;
        custom.forEach(function (idx) {
          delta += this.rowSizeForContentIndex(idx) - totalRowSize;
          cache[idx + 1] = delta;
          max = idx;
        }, this);
        this._sc_max = max + 1;

        // moved down so that the cache is not marked as initialized until it actually is
        this._sc_offsetCache = cache;
      }

      // now just get the delta for the last custom row before the current
      // idx.
      delta = cache[idx];
      if (delta === undefined) {
        delta = cache[idx] = cache[idx - 1];
        if (delta === undefined) {
          max = this._sc_max;
          if (idx < max) max = custom.indexBefore(idx) + 1;
          delta = cache[idx] = cache[max] || 0;
        }
      }

      ret += delta;
    }

    return ret;
  },

  /** @deprecated Version 1.11. Please use the `rowSizeForContentIndex()` function instead.
    Not implemented by default.

    @field
    @param {Number} idx content index
    @returns {Number} the row height
  */
  rowHeightForContentIndex: null,

  /**
    Returns the row size for the specified content index.  This will take
    into account custom row sizes and group rows.

    @param {Number} idx content index
    @returns {Number} the row height
  */
  rowSizeForContentIndex: function (idx) {
    var del = this.get('rowDelegate'),
        ret, cache, content, indexes;

    if (this.rowHeightForContentIndex) {
      

      return this.rowHeightForContentIndex(idx);
    }

    if (del.customRowSizeIndexes && (indexes = del.get('customRowSizeIndexes'))) {
      cache = this._sc_sizeCache;
      if (!cache) {
        cache = [];
        content = this.get('content');
        indexes.forEach(function (idx) {
          cache[idx] = del.contentIndexRowSize(this, content, idx);
        }, this);

        // moved down so that the cache is not marked as initialized until it actually is.
        this._sc_sizeCache = cache;
      }

      ret = cache[idx];
      if (ret === undefined) ret = del.get('_sc_totalRowSize');
    } else {
      ret = del.get('_sc_totalRowSize');
    }

    return ret;
  },

  /** @deprecated Version 1.11. Please use the `rowSizeDidChangeForIndexes()` function instead.
    Call this method whenever a row height has changed in one or more indexes.
    This will invalidate the row height cache and reload the content indexes.
    Pass either an index set or a single index number.

    This method is called automatically whenever you change the rowSize, rowPadding
    or customRowSizeIndexes properties on the collectionRowDelegate.

    @param {SC.IndexSet|Number} indexes
    @returns {SC.ListView} receiver
  */
  rowHeightDidChangeForIndexes: function (indexes) {
    

    return this.rowSizeDidChangeForIndexes(indexes);
  },

  /**
    Call this method whenever a row size has changed in one or more indexes.
    This will invalidate the row size cache and reload the content indexes.
    Pass either an index set or a single index number.

    This method is called automatically whenever you change the rowSize, rowPadding
    or customRowSizeIndexes properties on the collectionRowDelegate.

    @param {SC.IndexSet|Number} indexes
    @returns {SC.ListView} receiver
  */
  rowSizeDidChangeForIndexes: function (indexes) {
    var len = this.get('length');

    // clear any cached offsets
    this._sc_sizeCache = this._sc_offsetCache = null;

    // find the smallest index changed; invalidate everything past it
    if (indexes && indexes.isIndexSet) indexes = indexes.get('min');
    this.reload(SC.IndexSet.create(indexes, len - indexes));

    // If the row height changes, our entire layout needs to change.
    this.invokeOnce('adjustLayout');

    return this;
  },

  // ..........................................................
  // SUBCLASS IMPLEMENTATIONS
  //

  /**
    The layout for a ListView is computed from the total number of rows
    along with any custom row heights.
  */
  computeLayout: function () {
    // default layout
    var ret = this._sc_layout,
      layoutDirection = this.get('layoutDirection'),
      del = this.get('rowDelegate'),
      rowSpacing = del.get('rowSpacing');

    // Initialize lazily.
    if (!ret) ret = this._sc_layout = {};

    // Support both vertical and horizontal lists.
    if (layoutDirection === SC.LAYOUT_HORIZONTAL) {
      // Don't include the row spacing after the last item in the width.
      ret.width = Math.max(this.rowOffsetForContentIndex(this.get('length')) - rowSpacing, 0);
    } else {
      // Don't include the row spacing after the last item in the height.
      ret.height = Math.max(this.rowOffsetForContentIndex(this.get('length')) - rowSpacing, 0);
    }
    return ret;
  },

  /**
    Computes the layout for a specific content index by combining the current
    row heights.

    @param {Number} contentIndex
    @returns {Hash} layout hash for the index provided
  */
  layoutForContentIndex: function (contentIndex) {
    var del = this.get('rowDelegate'),
      layoutDirection = this.get('layoutDirection'),
      offset, size;

    offset = this.rowOffsetForContentIndex(contentIndex);
    size = this.rowSizeForContentIndex(contentIndex) - del.get('rowPadding') * 2;

    // Support both vertical and horizontal lists.
    if (layoutDirection === SC.LAYOUT_HORIZONTAL) {
      return {
        left: offset,
        width: size,
        top: 0,
        bottom: 0
      };
    } else {
      return {
        top: offset,
        height: size,
        left: 0,
        right: 0
      };
    }
  },

  /**
    Override to return an IndexSet with the indexes that are at least
    partially visible in the passed rectangle.  This method is used by the
    default implementation of computeNowShowing() to determine the new
    nowShowing range after a scroll.

    Override this method to implement incremental rendering.

    The default simply returns the current content length.

    @param {Rect} rect the visible rect or a point
    @returns {SC.IndexSet} now showing indexes
  */
  contentIndexesInRect: function (rect) {
    var del = this.get('rowDelegate'),
      totalRowSize = del.get('_sc_totalRowSize'),
      rowSpacing = del.get('rowSpacing'),
      totalRowSizeWithSpacing = totalRowSize + rowSpacing,
      layoutDirection = this.get('layoutDirection'),
      len = this.get('length'),
      offset, start, end,
      firstEdge, lastEdge,
      size;

    // Support both vertical and horizontal lists.
    if (layoutDirection === SC.LAYOUT_HORIZONTAL) {
      firstEdge = SC.minX(rect);
      lastEdge = SC.maxX(rect);
      size = rect.width || 0;
    } else {
      firstEdge = SC.minY(rect);
      lastEdge = SC.maxY(rect);
      size = rect.height || 0;
    }

    // estimate the starting row and then get actual offsets until we are
    // right.
    start = (firstEdge - (firstEdge % totalRowSizeWithSpacing)) / totalRowSizeWithSpacing;
    offset = this.rowOffsetForContentIndex(start);

    // go backwards until offset of row is before first edge
    while (start > 0 && offset > firstEdge) {
      start--;
      offset -= (this.rowSizeForContentIndex(start) + rowSpacing);
    }

    // go forwards until offset plus size of row is after first edge
    offset += this.rowSizeForContentIndex(start);
    while (start < len && offset <= firstEdge) {
      start++;
      offset += this.rowSizeForContentIndex(start) + rowSpacing;
    }
    if (start < 0) start = 0;
    if (start >= len) start = len;


    // estimate the final row and then get the actual offsets until we are
    // right. - look at the offset of the _following_ row
    end = start + ((size - (size % totalRowSizeWithSpacing)) / totalRowSizeWithSpacing);
    if (end > len) end = len;
    offset = this.rowOffsetForContentIndex(end);

    // walk backwards until offset of row is before or at last edge
    while (end >= start && offset >= lastEdge) {
      end--;
      offset -= (this.rowSizeForContentIndex(end) + rowSpacing);
    }

    // go forwards until offset plus size of row is after last edge
    offset += this.rowSizeForContentIndex(end) + rowSpacing;
    while (end < len && offset < lastEdge) {
      end++;
      offset += this.rowSizeForContentIndex(end) + rowSpacing;
    }

    end++; // end should be after start

    if (end < start) end = start;
    if (end > len) end = len;

    // convert to IndexSet and return
    return SC.IndexSet.create(start, end - start);
  },


  // ..........................................................
  // DRAG AND DROP SUPPORT
  //

  /**
    Default view class used to draw an insertion point, which uses CSS
    styling to show a horizontal line.

    This view's position (top & left) will be automatically adjusted to the
    point of insertion.

    @field
    @type SC.View
  */
  insertionPointView: SC.View.extend({
    classNames: 'sc-list-insertion-point',

    layout: function (key, value) {
      var layoutDirection = this.get('layoutDirection');

      key = layoutDirection === SC.LAYOUT_HORIZONTAL ? 'width' : 'height';

      // Getter – create layout hash.
      if (value === undefined) {
        value = {};
      }

      // Either way, add the narrow dimension to the layout if needed.
      if (SC.none(value[key])) value[key] = 2;

      return value;
    }.property('layoutDirection').cacheable(),

    /**
      The direction of layout of the SC.ListView.
      This property will be set by the list view when this view is created.
      */
    layoutDirection: SC.LAYOUT_VERTICAL,

    /** @private */
    render: function (context, firstTime) {
      if (firstTime) context.push('<div class="anchor"></div>');
    }
  }),

  /**
    Default implementation will show an insertion point
    @see SC.CollectionView#showInsertionPoint
  */
  showInsertionPoint: function (itemView, dropOperation) {
    // FAST PATH: If we're dropping on the item view itself... (Note: support for this
    // should be built into CollectionView's calling method and not the unrelated method
    // for showing an insertion point.)
    if (dropOperation & SC.DROP_ON) {
      if (itemView && itemView !== this._sc_lastDropOnView) {
        this.hideInsertionPoint();

        // If the drag is supposed to drop onto an item, notify the item that it
        // is the current target of the drop.
        itemView.set('isDropTarget', YES);

        // Track the item so that we can clear isDropTarget when the drag changes;
        // versus having to clear it from all items.
        this._sc_lastDropOnView = itemView;
      }
      return;
    }

    // Otherwise, we're actually inserting.

    // TODO: CollectionView's notes on showInsertionPoint specify that if no itemView
    // is passed, this should try to get the last itemView. (Note that ListView's
    // itemViewForContentIndex creates a new view on demand, so make sure that we
    // have content items before getting the last view.) This is a change in established
    // behavior however, so proceed carefully.

    // If there was an item that was the target of the drop previously, be
    // sure to clear it.
    if (this._sc_lastDropOnView) {
      this._sc_lastDropOnView.set('isDropTarget', NO);
      this._sc_lastDropOnView = null;
    }

    var len = this.get('length'),
      index, level, indent;

    // Get values from itemView, if present.
    if (itemView) {
      index = itemView.get('contentIndex');
      level = itemView.get('outlineLevel');
      indent = itemView.get('outlineIndent');
    }

    // Set defaults.
    index = index || 0;
    if (SC.none(level)) level = -1;
    indent = indent || 0;

    // Show item indented if we are inserting at the end and the last item
    // is a group item.  This is a special case that should really be
    // converted into a more general protocol.
    if ((index >= len) && index > 0) {
      var previousItem = this.itemViewForContentIndex(len - 1);
      if (previousItem.get('isGroupView')) {
        level = 1;
        indent = previousItem.get('outlineIndent');
      }
    }

    // Get insertion point.
    var insertionPoint = this._sc_insertionPointView,
      layoutDirection = this.get('layoutDirection');

    if (!insertionPoint) {
      insertionPoint = this._sc_insertionPointView = this.get('insertionPointView').create({
        layoutDirection: layoutDirection
      });
    }

    // Calculate where it should go.
    var itemViewLayout = itemView ? itemView.get('layout') : { top: 0, left: 0 },
      top, left;

    // Support both vertical and horizontal lists.
    if (layoutDirection === SC.LAYOUT_HORIZONTAL) {
      left = itemViewLayout.left;
      if (dropOperation & SC.DROP_AFTER) { left += itemViewLayout.width; }
      top = ((level + 1) * indent) + 12;
    } else {
      top = itemViewLayout.top;
      if (dropOperation & SC.DROP_AFTER) { top += itemViewLayout.height; }
      left = ((level + 1) * indent) + 12;
    }

    // Put it there.
    insertionPoint.adjust({ top: top, left: left });

    this.appendChild(insertionPoint);
  },

  /** @see SC.CollectionView#hideInsertionPoint */
  hideInsertionPoint: function () {
    // If there was an item that was the target of the drop previously, be
    // sure to clear it.
    if (this._sc_lastDropOnView) {
      this._sc_lastDropOnView.set('isDropTarget', NO);
      this._sc_lastDropOnView = null;
    }

    var view = this._sc_insertionPointView;
    if (view) view.removeFromParent().destroy();
    this._sc_insertionPointView = null;
  },

  /**
    Compute the insertion index for the passed location.  The location is
    a point, relative to the top/left corner of the receiver view.  The return
    value is an index plus a dropOperation, which is computed as such:

      - if outlining is not used and you are within 5px of an edge, DROP_BEFORE
        the item after the edge.
      - if outlining is used and you are within 5px of an edge and the previous
        item has a different outline level then the next item, then DROP_AFTER
        the previous item if you are closer to that outline level.
      - if dropOperation = SC.DROP_ON and you are over the middle of a row, then
        use DROP_ON.

    @see SC.CollectionView.insertionIndexForLocation
  */
  insertionIndexForLocation: function (loc, dropOperation) {
    var locRect = { x: loc.x, y: loc.y, width: 1, height: 1 },
      indexes = this.contentIndexesInRect(locRect),
      index   = indexes.get('min'),
      len     = this.get('length'),
      min, max, diff, clevel, cindent, plevel, pindent, itemView;

    // if there are no indexes in the rect, then we need to either insert
    // before the top item or after the last item.  Figure that out by
    // computing both.
    if (SC.none(index) || index < 0) {
      if ((len === 0) || (loc.y <= this.rowOffsetForContentIndex(0))) index = 0;
      else if (loc.y >= this.rowOffsetForContentIndex(len)) index = len;
    }

    // figure the range of the row the location must be within.
    min = this.rowOffsetForContentIndex(index);
    max = min + this.rowSizeForContentIndex(index);

    // now we know which index we are in.  if dropOperation is DROP_ON, figure
    // if we can drop on or not.
    if (dropOperation === SC.DROP_ON) {
      // editable size - reduce height by a bit to handle dropping
      if (this.get('isEditable')) diff = Math.min(Math.floor((max - min) * 0.2), 5);
      else diff = 0;

      // if we're inside the range, then DROP_ON
      if (loc.y >= (min + diff) || loc.y <= (max + diff)) {
        return [index, SC.DROP_ON];
      }
    }

    // finally, let's decide if we want to actually insert before/after.  Only
    // matters if we are using outlining.
    if (index > 0) {

      itemView = this.itemViewForContentIndex(index - 1);
      pindent  = (itemView ? itemView.get('outlineIndent') : 0) || 0;
      plevel   = itemView ? itemView.get('outlineLevel') : 0;

      if (index < len) {
        itemView = this.itemViewForContentIndex(index);
        clevel   = itemView ? itemView.get('outlineLevel') : 0;
        cindent  = (itemView ? itemView.get('outlineIndent') : 0) || 0;
        cindent  *= clevel;
      } else {
        clevel = itemView.get('isGroupView') ? 1 : 0; // special case...
        cindent = pindent * clevel;
      }

      pindent *= plevel;

      // if indent levels are different, then try to figure out which level
      // it should be on.
      if ((clevel !== plevel) && (cindent !== pindent)) {

        // use most inner indent as boundary
        if (pindent > cindent) {
          index--;
          dropOperation = SC.DROP_AFTER;
        }
      }
    }

    // we do not support dropping before a group item.  If dropping before
    // a group item, always try to instead drop after the previous item.  If
    // the previous item is also a group then, well, dropping is just not
    // allowed.  Note also that dropping at 0, first item must not be group
    // and dropping at length, last item must not be a group
    //
    if (dropOperation === SC.DROP_BEFORE) {
      itemView = (index < len) ? this.itemViewForContentIndex(index) : null;
      if (!itemView || itemView.get('isGroupView')) {
        if (index > 0) {
          itemView = this.itemViewForContentIndex(index - 1);

          // don't allow a drop if the previous item is a group view and we're
          // insert before the end.  For the end, allow the drop if the
          // previous item is a group view but OPEN.
          if (!itemView.get('isGroupView') || (itemView.get('disclosureState') === SC.BRANCH_OPEN)) {
            index = index - 1;
            dropOperation = SC.DROP_AFTER;
          } else index = -1;

        } else index = -1;
      }

      if (index < 0) dropOperation = SC.DRAG_NONE;
    }

    // return whatever we came up with
    return [index, dropOperation];
  }

});

/* >>>>>>>>>> BEGIN source/views/grid.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
sc_require('views/list');


/** @class

  A grid view renders a collection of items in a grid of rows and columns.

  ## Dropping on an Item

  When the grid view is configured to accept drags and drops onto its items, it
  will set the isDropTarget property on the target item accordingly.  This
  allows you to modify the appearance of the drop target grid item accordingly
  (@see SC.ListItemView#isDropTarget).

  @extends SC.ListView
  @author Charles Jolley
  @version 1.0
*/
SC.GridView = SC.ListView.extend(
/** @scope SC.GridView.prototype */ {

  /** @private */
  _lastFrameWidth: null,

  /**
    @type Array
    @default ['sc-grid-view']
    @see SC.View#classNames
  */
  classNames: ['sc-grid-view'],

  /**
    @type Hash
    @default { left:0, right:0, top:0, bottom:0 }
    @see SC.View#layout
  */
  layout: { left: 0, right: 0, top: 0, bottom: 0 },

  /**
    The common row height for grid items.

    The value should be an integer expressed in pixels.

    @type Number
    @default 48
  */
  rowHeight: 48,

  /**
    The minimum column width for grid items.  Items will actually
    be laid out as needed to completely fill the space, but the minimum
    width of each item will be this value.

    @type Number
    @default 64
  */
  columnWidth: 64,

  /**
    The default example item view will render text-based items.

    You can override this as you wish.

    @type SC.View
    @default SC.LabelView
  */
  exampleView: SC.LabelView,

  /**
    Possible values:

      - SC.HORIZONTAL_ORIENTATION
      - SC.VERTICAL_ORIENTATION

    @type String
    @default SC.HORIZONTAL_ORIENTATION
  */
  insertionOrientation: SC.HORIZONTAL_ORIENTATION,

  /** @private */
  itemsPerRow: function () {
    var frameWidth = this.get('frame').width,
      columnWidth = this.get('columnWidth') || 0;

    return (columnWidth < 1) ? 1 : Math.floor(frameWidth / columnWidth);
  }.property('columnWidth', '_frameWidth').cacheable(),

  /** @private
    Find the contentIndexes to display in the passed rect. Note that we
    ignore the width of the rect passed since we need to have a single
    contiguous range.
  */
  contentIndexesInRect: function (rect) {
    var rowHeight = this.get('rowHeight') || 48,
        itemsPerRow = this.get('itemsPerRow'),
        min = Math.floor(SC.minY(rect) / rowHeight) * itemsPerRow,
        max = Math.ceil(SC.maxY(rect) / rowHeight) * itemsPerRow;
    return SC.IndexSet.create(min, max - min);
  },

  /** @private */
  layoutForContentIndex: function (contentIndex) {
    var rowHeight = this.get('rowHeight') || 48,
        frameWidth = this.get('frame').width,
        itemsPerRow = this.get('itemsPerRow'),
        columnWidth = Math.floor(frameWidth / itemsPerRow),
        row = Math.floor(contentIndex / itemsPerRow),
        col = contentIndex - (itemsPerRow * row);

    // If the frame is not ready, then just return an empty layout.
    // Otherwise, NaN will be entered into layout values.
    if (frameWidth === 0 || itemsPerRow === 0) {
      return {};
    }

    return {
      left: col * columnWidth,
      top: row * rowHeight,
      height: rowHeight,
      width: columnWidth
    };
  },

  /** @private
    Overrides default CollectionView method to compute the minimum height
    of the list view.
  */
  computeLayout: function () {
    var content = this.get('content'),
      count = (content) ? content.get('length') : 0,
      rowHeight = this.get('rowHeight') || 48,
      itemsPerRow = this.get('itemsPerRow'),
      // Check that itemsPerRow isn't 0 to prevent Infinite rows.
      rows = itemsPerRow ? Math.ceil(count / itemsPerRow) : 0;

    // use this cached layout hash to avoid allocing memory...
    var ret = this._cachedLayoutHash;
    if (!ret) ret = this._cachedLayoutHash = {};

    ret.height = rows * rowHeight;

    return ret;
  },

  /**
    Default view class used to draw an insertion point, which uses CSS
    styling to show a horizontal line.

    This view's position (top & left) will be automatically adjusted to the
    point of insertion.

    @field
    @type SC.View
  */
  insertionPointClass: SC.View.extend({
    classNames: ['sc-grid-insertion-point'],

    layout: { width: 2 },

    render: function (context, firstTime) {
      if (firstTime) context.push('<div class="anchor"></div>');
    }
  }),

  /** @private */
  showInsertionPoint: function (itemView, dropOperation) {
    if (!itemView) return;

    // if drop on, then just add a class...
    if (dropOperation & SC.DROP_ON) {
      if (itemView !== this._lastDropOnView) {
        this.hideInsertionPoint();

        // If the drag is supposed to drop onto an item, notify the item that it
        // is the current target of the drop.
        itemView.set('isDropTarget', YES);

        // Track the item so that we can clear isDropTarget when the drag changes;
        // versus having to clear it from all items.
        this._lastDropOnView = itemView;
      }

    } else {
      if (this._lastDropOnView) {
        // If there was an item that was the target of the drop previously, be
        // sure to clear it.
        this._lastDropOnView.set('isDropTarget', NO);
        this._lastDropOnView = null;
      }

      var insertionPoint = this._insertionPointView,
        layout = itemView.get('layout'),
        top, left;

      if (!insertionPoint) {
        insertionPoint = this._insertionPointView = this.insertionPointClass.create();
      }

      // Adjust the position of the insertion point.
      top = layout.top;
      left = layout.left;
      if (dropOperation & SC.DROP_AFTER) left += layout.width;
      var height = layout.height;

      // Adjust the position of the insertion point.
      insertionPoint.adjust({ top: top, left: left, height: height });
      this.appendChild(insertionPoint);
    }
  },

  /** @see SC.CollectionView#hideInsertionPoint */
  hideInsertionPoint: function () {
    // If there was an item that was the target of the drop previously, be
    // sure to clear it.
    if (this._lastDropOnView) {
      this._lastDropOnView.set('isDropTarget', NO);
      this._lastDropOnView = null;
    }

    var view = this._insertionPointView;
    if (view) view.removeFromParent().destroy();
    this._insertionPointView = null;
  },

  /** @private */
  insertionIndexForLocation: function (loc, dropOperation) {
    var f = this.get('frame'),
        sf = this.get('clippingFrame'),
        itemsPerRow = this.get('itemsPerRow'),
        columnWidth = Math.floor(f.width / itemsPerRow),
        row = Math.floor((loc.y - f.y - sf.y) / this.get('rowHeight'));

    var retOp = SC.DROP_BEFORE,
        offset = (loc.x - f.x - sf.x),
        col = Math.floor(offset / columnWidth),
        percentage = (offset / columnWidth) - col;

    // if the dropOperation is SC.DROP_ON and we are in the center 60%
    // then return the current item.
    if (dropOperation === SC.DROP_ON) {
      if (percentage > 0.80) col++;
      if ((percentage >= 0.20) && (percentage <= 0.80)) {
        retOp = SC.DROP_ON;
      }
    } else {
      if (percentage > 0.45) col++;
    }

    // convert to index
    var ret = (row * itemsPerRow) + col;
    return [ret, retOp];
  },

  /** @private
    Since GridView lays out items evenly from left to right, if the width of the
    frame changes, all of the item views on screen are potentially in
    the wrong position.

    Update all of their layouts if necessary.
  */
  _gv_frameDidChange: function () {
    var frame = this.get('frame'),
      lastFrameWidth = this._lastFrameWidth,
      width = frame.width;

    // A change to the width of the frame is the only variable that
    // alters the layout of item views and our computed layout.
    if (!SC.none(lastFrameWidth) && width !== lastFrameWidth) {
      var itemView,
        nowShowing = this.get('nowShowing');

      // Internal property used to indicate a possible itemsPerRow change.  This
      // is better than having itemsPerRow dependent on frame which changes frequently.
      this.set('_frameWidth', width);

      // Only loop through the now showing indexes, if the content was sparsely
      // loaded we would inadvertently load all the content.
      nowShowing.forEach(function (idx) {
        itemView = this.itemViewForContentIndex(idx);
        itemView.adjust(this.layoutForContentIndex(idx));
      }, this);
    }

    this._lastFrameWidth = width;
  }.observes('frame'),

  /** @private Recompute our layout if itemsPerRow actually changes. */
  _gv_itemsPerRowDidChange: function () {
    var itemsPerRow = this.get('itemsPerRow'),
      lastItemsPerRow = this._lastItemsPerRow || 0;

    if (itemsPerRow !== lastItemsPerRow) {
      this.invokeOnce('adjustLayout');
    }

    this._lastItemsPerRow = itemsPerRow;
  }.observes('itemsPerRow')

});

/* >>>>>>>>>> BEGIN source/views/image_button.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/** @class

  Provides a button that displays an image instead of the standard button
  user interface.

  It behaves the same as an SC.ButtonView, but has an image property that
  should be set to a unique class name.

  For example:

      SC.ImageButtonView.create({
        action: 'imageButtonWasClicked',

        image: 'my-image-button-icon'
      });

  You could then add some CSS rule for a normal state:

      $theme.image-button .my-image-button-icon {
        @include slice('my-image-button-image.png');

        // and an active state:
        &.active {
          @include slice('my-image-button-image-active.png');
        }
      }

  Note: in addition to using SCSS and the Chance directives shown above, you
  can use normal CSS syntax and sc_static.

  @extends SC.View
  @extends SC.Control
  @extends SC.ButtonView
  @since SproutCore 1.5
*/
SC.ImageButtonView = SC.ButtonView.extend(
/** @scope SC.ImageButtonView.prototype */ {

  /**
    @type Array
    @default ['sc-image-button-view']
    @see SC.View#classNames
  */
  classNames: ['sc-image-button-view'],

  /**
    Unlike SC.ButtonView, SC.ImageButtonView does not have a default theme
    that needs to be applied for backwards compatibility.

    @type String
    @default null
  */
  themeName: null,

  /**
    @type String
    @default 'imageButtonRenderDelegate'
  */
  renderDelegateName: 'imageButtonRenderDelegate',

  /**
    @type Array
    @default ['image']
  */
  displayProperties: ['image'],

  /**
    A class name that will be applied to the img tag of the button.

    @type String
    @default null
  */
  image: null

});

/* >>>>>>>>>> BEGIN source/views/link_view.js */
// ==========================================================================
// Project:   SproutCore
// Copyright: ©2014 7x7 Software, Inc.
// License:   Licensed under MIT license
// ==========================================================================


/**
  @class

  This view creates a link (i.e. HTML anchor) to a remote resource.  You should
  use this view to create programmatic HTML links, such as links to a PDF or to
  an external site.

  For example,

      //...

      // A link to download the selected employee's resume.
      link: SC.LinkView.extend({

        body: "Current Resume",

        // Compute the fileName on the fly.
        fileNameBinding: SC.Binding.oneWay('MyApp.employeeController.fullName')
          .transform(function (fullName) {
            // ex. "Resume - Tyler Keating.pdf"
            return "Resume - " + fullName + ".pdf";
          }),

        // Compute the href on the fly.
        hrefBinding: SC.Binding.oneWay('MyApp.employeeController.resumePath'),

        toolTip: "Link to current resume"
      }),

      //...

  The example above generates something like the following,

      <a href="/users/22/cur-resume.pdf" class="sc-view sc-link-view" download="Resume - Tyler Keating.pdf" title="Link to current resume">Current Resume</a>

  Note that you can localize the `body` and the `toolTip` by setting the `localize`
  property to true.

  @since SproutCore 1.11
*/
SC.LinkView = SC.View.extend({

  /**
    The WAI-ARIA role for link views.

    @type String
    @default 'link'
    @readOnly
  */
  ariaRole: 'link',

  /**
    The content of the anchor, such as text or an image.

    Note that this will be escaped by default, so any HTML tags will appear
    as text.  To render the body as HTML, set `escapeHTML` to `false` and
    remember to *NEVER* allow user generated content unescaped in your app.

    If you are using text, you may also want to provide localized versions and
    should set the `localize` property to true.

    @type String
    @default ""
   */
  body: "",

  /**
    The class names for the view.

    Note: this is not an observed display property and as such must be predefined on the
    view (You can update class names using `classNameBindings`).

    Note: this is a concatenated property and as such all subclasses will inherit
    the current class names.

    @type Array
    @default ['sc-view', 'sc-link-view']
   */
  classNames: ['sc-link-view'],

  /**
    This is generated by localizing the body property if necessary.

    @readonly
    @type String
    @observes 'body'
    @observes 'localize'
  */
  displayBody: function () {
    var ret = this.get('body');

    return (ret && this.get('localize')) ? SC.String.loc(ret) : (ret || '');
  }.property('body', 'localize').cacheable(),

  /**
    The observed properties that will cause the view to be rerendered if they
    change.

    Note: this is a concatenated property and as such all subclasses will inherit
    the current display properties.

    @type Array
    @default ['displayBody', 'displayToolTip', 'fileName', 'href', 'hreflang']
   */
  displayProperties: ['displayBody', 'displayToolTip', 'fileName', 'href', 'hreflang'],

  /**
    The default file name to use for the linked resource if it will be
    downloaded.

    For example,

        //...

        // The linked resource (/students/2013/list-copy.xml) will be downloaded
        // with the name 'Student List.xml' by default.
        fileName: 'Student List.xml',

        href: '/students/2013/list-copy.xml'

        //...

    This property is observed, allowing you to programmatically set the download
    file name.

    For example as a computed property,

        //...

        // The download file name is computed from the linked resource URL.
        fileName: function () {
          var href = this.get('href'),
            linkedYear,
            ret;

          if (href) {
            // ex. href == "/reports/2012/annual-report.pdf"
            linkedYear = href.match(/\/(\d*)\//)[1];
            ret = "Annual Report " + linkedYear + '.pdf';
          }

          return ret;
        }.property('href').cacheable(),

        hrefBinding: SC.Binding.oneWay('MyApp.reportController.hardlink'),

        //...

    Note: There are no restrictions on allowed values, but authors are cautioned
    that most file systems have limitations with regard to what punctuation is
    supported in file names, and user agents are likely to adjust file names
    accordingly. Also, support for this attribute varies widely between browsers.

    @see http://caniuse.com/#feat=download
    @see http://www.whatwg.org/specs/web-apps/current-work/multipage/links.html#attr-hyperlink-download
   */
  fileName: null,

  /**
    Whether the body and toolTip will be escaped to avoid HTML injection attacks
    or not.

    You should only disable this option if you are sure you are displaying
    non-user generated text.

    Note: this is not an observed display property.  If you change it after
    rendering, you should call `displayDidChange` on the view to update the layer.

    @type Boolean
    @default true
   */
  escapeHTML: true,

  /**
    The linked resource URL.

    @type String
    @default '#'
   */
  href: '#',

  /**
    The alternate language for the linked resource.

    Set this value to modify the 'hreflang' attribute for the linked resource,
    which would otherwise be the current locale's language.

    @type String
    @default null
    @see http://www.whatwg.org/specs/web-apps/current-work/multipage/links.html#attr-hyperlink-hreflang
   */
  language: null,

  /**
    The language attribute of the linked resource.

    This is the current locale's language by default, but may be overridden to
    a specific other language by setting the `language` property.

    @readonly
    @type String
    @observes 'language'
    @observes 'localize'
    @default SC.Locale.currentLocale.language
    @see http://www.whatwg.org/specs/web-apps/current-work/multipage/links.html#attr-hyperlink-hreflang
  */
  hreflang: function () {
    var language = this.get('language'),
      ret;

    ret = language || SC.Locale.currentLocale.language;

    return ret;
  }.property('language', 'localize').cacheable(),

  /**
    An array of URLs to ping when the link is clicked.

    For example, this can be used for tracking the use of off-site links without
    JavaScript or page redirects,

        //...

        // Whenever anyone downloads this resource, we ping our analytics site.
        ping: ['http://tracker.my-app.com/?action="Downloaded PDF Version"'],

        //...

    Note: this is not an updateable display property.  It must be defined before
    creating the layer.

    @type Array
    @default null
    @see http://www.whatwg.org/specs/web-apps/current-work/multipage/links.html#ping
   */
  ping: null,

  /**
    A list of space separated non-case sensitive link type tokens.

    For example,

        //...

        // This link is to the author of the article and the result should be loaded in the browser's sidebar if it has one.
        rel: ['author', 'sidebar'],

        //...

    Note: this is not an updateable display property.  It must be defined before
    creating the layer.

    @type Array
    @default null
    @see http://www.whatwg.org/specs/web-apps/current-work/multipage/links.html#attr-hyperlink-rel
    @see http://www.whatwg.org/specs/web-apps/current-work/multipage/links.html#linkTypes
   */
  rel: null,

  /**
    The tag type to use.

    Note: this is not an updateable display property.  It must be defined before
    creating the layer.

    @type String
    @default 'a'
   */
  tagName: 'a',

  /**
    The target for loading the resource.

    The following keywords have special meanings:

    * _self: Load the response into the same HTML4 frame (or HTML5 browsing context) as the current one.
    * _blank: Load the response into a new unnamed HTML4 window or HTML5 browsing context.
    * _parent: Load the response into the HTML4 frameset parent of the current frame or HTML5 parent browsing context of the current one. If there is no parent, this option behaves the same way as _self.
    * _top: In HTML4: Load the response into the full, original window, canceling all other frames. In HTML5: Load the response into the top-level browsing context (that is, the browsing context that is an ancestor of the current one, and has no parent). If there is no parent, this option behaves the same way as _self.

    Note: this is not an updateable display property.  It must be defined before
    creating the layer.

    @type String
    @default '_blank'
    @see http://www.whatwg.org/specs/web-apps/current-work/multipage/links.html#attr-hyperlink-target
   */
  target: '_blank',

  /**
    The mime type of the link.

    This has little effect, but certain browsers may add display information
    pertaining to the type, such as a small icon for the linked resource type.

    Note: this is not an updateable display property.  It must be defined before
    creating the layer.

    @type String
    @default null
    @see http://www.whatwg.org/specs/web-apps/current-work/multipage/links.html#attr-hyperlink-type
   */
  type: null,

  // ------------------------------------------------------------------------
  // Methods
  //

  /** @private */
  render: function (context) {
    var displayBody = this.get('displayBody'),
      displayToolTip = this.get('displayToolTip'),
      fileName = this.get('fileName'),
      escapeHTML = this.get('escapeHTML'),
      href = this.get('href'),
      hreflang = this.get('hreflang'),
      ping = this.get('ping'),
      rel = this.get('rel'),
      target = this.get('target'),
      type = this.get('type');

    // Escape the title of the anchor if needed. This prevents potential XSS attacks.
    if (displayToolTip && escapeHTML) {
      displayToolTip = SC.RenderContext.escapeHTML(displayToolTip);
    }

    // Set attributes
    context.setAttr({
      'download': fileName,
      'href': href,
      'hreflang': hreflang,
      'ping': ping ? ping.join(' ') : null,
      'rel': rel ? rel.join(' ') : null,
      'target': target,
      'title': displayToolTip,
      'type': type
    });

    // Escape the body of the anchor if needed. This prevents potential XSS attacks.
    if (displayBody && escapeHTML) {
      displayBody = SC.RenderContext.escapeHTML(displayBody);
    }

    // Insert the body
    context.push(displayBody);
  },

  /** @private */
  mouseDown: function (evt) {
    evt.allowDefault();
    return true;
  },

  /** @private */
  mouseUp: function (evt) {
    evt.allowDefault();
    return true;
  },

  /** @private */
  touchStart: function (touch) {
    touch.allowDefault();
    return true;
  },

  /** @private */
  touchEnd: function (touch) {
    touch.allowDefault();
    return true;
  },

  /** @private */
  update: function (jqEl) {
    var displayBody = this.get('displayBody'),
      displayToolTip = this.get('displayToolTip'),
      fileName = this.get('fileName'),
      escapeHTML = this.get('escapeHTML'),
      href = this.get('href'),
      hreflang = this.get('hreflang');

    jqEl.attr('download', fileName);
    jqEl.attr('href', href);
    jqEl.attr('hreflang', hreflang);

    // Escape the title of the anchor if needed. This prevents potential XSS attacks.
    if (displayToolTip && escapeHTML) {
      displayToolTip = SC.RenderContext.escapeHTML(displayToolTip);
    }

    jqEl.attr('title', displayToolTip);

    // Escape the body of the anchor if needed. This prevents potential XSS attacks.
    if (displayBody && escapeHTML) {
      displayBody = SC.RenderContext.escapeHTML(displayBody);
    }
    jqEl.html(displayBody);
  }

});

/* >>>>>>>>>> BEGIN source/views/toolbar.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  Layout properties needed to anchor a view to the top.

  @static
  @constant
  @type Hash
  @default `{ top: 0 }`
*/
SC.ANCHOR_TOP = { top: 0 };

/**
  Layout properties needed to anchor a view to the left.

  @static
  @constant
  @type Hash
  @default `{ left: 0 }`
*/
SC.ANCHOR_LEFT = { left: 0 };

/*
  Layout properties to anchor a view to the top left

  @static
  @constant
  @type Hash
  @default `{ top: 0, left: 0 }`
*/
SC.ANCHOR_TOP_LEFT = { top: 0, left: 0 };

/**
  Layout properties to anchoe view to the bottom.

  @static
  @constant
  @type Hash
  @default `{ bottom: 0 }`
*/
SC.ANCHOR_BOTTOM = { bottom: 0 };

/**
  Layout properties to anchor a view to the right.

  @static
  @constant
  @type Hash
  @default `{ right: 0 }`
*/
SC.ANCHOR_RIGHT = { right: 0 };

/**
  Layout properties to anchor a view to the bottom right.

  @static
  @constant
  @type Hash
  @default `{ top: 0, right: 0 }`
*/
SC.ANCHOR_BOTTOM_RIGHT = { bottom: 0, right: 0 };

/** @class

  SC.ToolbarView is a simple horizontal view that has been styled like a
  toolbar and can be easily anchored at the top or bottom of a parent view.

  To anchor to the top of the parent view, set `anchorLocation` to
  `SC.ANCHOR_TOP` or to anchor to the bottom, set `anchorLocation` to
  `SC.ANCHOR_BOTTOM`.  The default layout of SC.Toolbar is
  `{ left: 0, right: 0, height: 32, zIndex: 10 }` and so by setting the value of
  `anchorLocation`, the layout will be modified to either:

  `SC.ANCHOR_TOP:`
      { borderBottom: 1, top: 0, left: 0, right: 0, height: 32, zIndex: 10 }

  `SC.ANCHOR_BOTTOM:`
      { borderTop: 1, bottom: 0, left: 0, right: 0, height: 32, zIndex: 10 }

  Of course, you can always override the layout property yourself in order to
  adjust the height, border and zIndex values.

  @extends SC.View
  @since SproutCore 1.0
*/
SC.ToolbarView = SC.View.extend(
/** @scope SC.ToolbarView.prototype */ {

  /**
    @type Array
    @default ['sc-toolbar-view']
    @see SC.View#classNames
  */
  classNames: ['sc-toolbar-view'],

  /**
    The WAI-ARIA role for toolbar view.

    @type String
    @default 'toolbar'
    @readOnly
  */
  ariaRole: 'toolbar',

  /**
    @type String
    @default 'toolbarRenderDelegate'
  */
  renderDelegateName: 'toolbarRenderDelegate',

  /**
    Default anchor location.  This will be applied automatically to the
    toolbar layout if you set it. Possible values:

      - SC.ANCHOR_TOP
      - SC.ANCHOR_LEFT
      - SC.ANCHOR_TOP_LEFT
      - SC.ANCHOR_BOTTOM
      - SC.ANCHOR_RIGHT
      - SC.ANCHOR_BOTTOM_RIGHT

    @type String
    @default null
  */
  anchorLocation: null,

  // ..........................................................
  // INTERNAL SUPPORT
  //

  /** @private */
  layout: { left: 0, right: 0, height: 32, zIndex: 10 },

  /** @private */
  init: function () {
    // apply anchor location before setting up the rest of the view.
    if (this.anchorLocation) {
      this.layout = SC.merge(this.layout, this.anchorLocation);

      switch (this.anchorLocation) {
      case SC.ANCHOR_TOP:
      case SC.ANCHOR_TOP_LEFT:
        this.layout.borderBottom = 1;
        break;
      case SC.ANCHOR_BOTTOM:
      case SC.ANCHOR_BOTTOM_RIGHT:
        this.layout.borderTop = 1;
        break;
      default:
      }
    }

    arguments.callee.base.apply(this,arguments);
  }

});


/* >>>>>>>>>> BEGIN source/views/workspace.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require("views/toolbar");

/** @class
  WorkspaceView manages a content view and two optional toolbars (top and bottom).
  You want to use WorkspaceView in one of two situations: iPhone apps where the toolbars
  need to change size automatically based on orientation (this does that, isn't that
  handy!) and iPad apps where you would like the masterIsHidden property to pass through.

  @since SproutCore 1.2
  @extends SC.View
  @author Alex Iskander
*/
SC.WorkspaceView = SC.View.extend(
/** @scope SC.WorkspaceView.prototype */ {

  /**
    @type Array
    @default ['sc-workspace-view']
    @see SC.View#classNames
  */
  classNames: ["sc-workspace-view"],

  /**
    @type Array
    @default "hasTopToolbar hasBottomToolbar".w()
    @see SC.View#displayProperties
  */
  displayProperties: ["hasTopToolbar", "hasBottomToolbar"],

  /**
    @type String
    @default 'workspaceRenderDelegate'
  */
  renderDelegateName: 'workspaceRenderDelegate',

  /**
    @type SC.View
    @default SC.ToolbarView
  */
  topToolbar: SC.ToolbarView.extend(),

  /**
    @type SC.View
    @default null
  */
  bottomToolbar: null,

  /**
    The content. Must NOT be null.

    @type SC.View
    @default SC.View
  */
  contentView: SC.View.extend(),

  /**
    If you want to automatically resize the toolbars like iPhone
    apps should, set to YES.

    @type Boolean
    @default NO
  */
  autoResizeToolbars: NO,

  /**
    @type Number
    @default 44
  */
  defaultToolbarSize: 44,

  /**
    @type Number
    @default 44
  */
  largeToolbarSize: 44,

  /**
    @type Number
    @default 30
  */
  smallToolbarSize: 30,

  /**
    @field
    @type Number
  */
  toolbarSize: function() {
    if (!this.get("autoResizeToolbars")) return this.get("defaultToolbarSize");
    if (this.get("orientation") === SC.HORIZONTAL_ORIENTATION) return this.get("smallToolbarSize");
    return this.get("largeToolbarSize");
  }.property("autoHideMaster", "orientation"),

  /**
    Tracks the orientation of the view. Possible values:

      - SC.HORIZONTAL_ORIENTATION
      - SC.PORTRAIT_ORIENTATION

    @field
    @type String
    @default SC.HORIZONTAL_ORIENTATION
  */
  orientation: function() {
    var f = this.get("frame");
    if (f.width > f.height) return SC.HORIZONTAL_ORIENTATION;
    else return SC.VERTICAL_ORIENTATION;
  }.property("frame").cacheable(),

  /**
    @type Boolean
    @default NO
  */
  masterIsHidden: NO,

  /** @private */
  masterIsHiddenDidChange: function() {
    var t, mih = this.get("masterIsHidden");
    if (t = this.get("topToolbar")) t.set("masterIsHidden", mih);
    if (t = this.get("bottomToolbar")) t.set("masterIsHidden", mih);
  }.observes("masterIsHidden"),

  /// INTERNAL CODE. HERE, THERE BE MONSTERS!

  /**
    @private
    Whenever something that affects the tiling changes (for now, just toolbarSize, but if
    we allow dynamic changing of toolbars in future, this could include toolbars themselves),
    we need to update the tiling.
  */
  _scmd_tilePropertyDidChange: function() {
    this.invokeOnce("_scws_tile");
  }.observes("toolbarSize"),

  /** @private
    Creates the child views. Specifically, instantiates master and detail views.
  */
  createChildViews: function() {
    arguments.callee.base.apply(this,arguments);

    var topToolbar = this.get("topToolbar");
    if (topToolbar) {
      topToolbar = this.topToolbar = this.activeTopToolbar = this.createChildView(topToolbar);
      this.appendChild(topToolbar);
    }

    var bottomToolbar = this.get("bottomToolbar");
    if (bottomToolbar) {
      bottomToolbar = this.bottomToolbar = this.activeBottomToolbar = this.createChildView(bottomToolbar);
      this.appendChild(bottomToolbar);
    }

    var content = this.get("contentView");
    content = this.contentView = this.activeContentView = this.createChildView(content);
    this.appendChild(content);

    this.invokeOnce("_scws_tile");
  },

  /**
    @private
    Tiles the views as necessary.
  */
  _scws_tile: function() {
    var contentTop = 0, contentBottom = 0,
        topToolbar = this.get("topToolbar"),
        bottomToolbar = this.get("bottomToolbar"),
        content = this.get("contentView"),
        toolbarSize = this.get("toolbarSize");

      // basically, if there is a top toolbar, we position it and change contentTop.
    if (topToolbar) {
      topToolbar.set("layout", {
        left: 0, right: 0, top: 0, height: toolbarSize
      });
      contentTop += toolbarSize;
    }

    // same for bottom
    if (bottomToolbar) {
      bottomToolbar.set("layout", {
        left: 0, right: 0, bottom: 0, height: toolbarSize
      });
      contentBottom += toolbarSize;
    }

    // finally, position content
    this.contentView.set("layout", {
      left: 0, right: 0, top: contentTop, bottom: contentBottom
    });
  },

  /** @private
    Returns YES if a top toolbar is present.
  */
  hasTopToolbar: function() {
    if (this.get("topToolbar")) return YES;
    return NO;
  }.property("topToolbar").cacheable(),

  /** @private
    Returns YES if a bottom toolbar is present.
  */
  hasBottomToolbar: function() {
    if (this.get("bottomToolbar")) return YES;
    return NO;
  }.property("bottomToolbar").cacheable(),

  /** @private
    Called by the individual toolbar/contentView observers at runloop end when the toolbars change.
  */
  childDidChange: function() {
    this._scws_tile();
  },

  /** @private
    For subclassing, this is the currently displaying top toolbar.
  */
  activeTopToolbar: null,

  /** @private
    For subclassing, this is the currently displaying bottom toolbar.
  */
  activeBottomToolbar: null,

  /** @private
    For subclassing, this is the currently displaying content view.
  */
  activeContentView: null,

  /** @private
    Called when the top toolbar changes. It appends it, removes any old ones, and calls toolbarsDidChange.

    You may want to override this if, for instance, you want to add transitions of some sort (should be trivial).
  */
  topToolbarDidChange: function() {
    var active = this.activeTopToolbar, replacement = this.get("topToolbar");
    if (active) {
      if (active.createdByParent) {
        container.removeChildAndDestroy(active);
      } else {
        container.removeChild(active);
      }
    }
    if (replacement) {
      this.appendChild(replacement);
    }

    this.activeTopToolbar = replacement;
    this.invokeLast("childDidChange");
  }.observes("topToolbar"),

  /**
    @private
  */
  bottomToolbarDidChange: function() {
    var active = this.activeBottomToolbar, replacement = this.get("bottomToolbar");
    if (active) {
      if (active.createdByParent) {
        container.removeChildAndDestroy(active);
      } else {
        container.removeChild(active);
      }
    }
    if (replacement) {
      this.appendChild(replacement);
    }

    this.activeBottomToolbar = replacement;
    this.invokeLast("childDidChange");
  }.observes("bottomToolbar"),

  /** @private */
  contentViewDidChange: function() {
    var active = this.activeContentView, replacement = this.get("contentView");
    if (active) {
      if (active.createdByParent) {
        container.removeChildAndDestroy(active);
      } else {
        container.removeChild(active);
      }
    }
    if (replacement) {
      this.appendChild(replacement);
    }

    this.activeContentView = replacement;
    this.invokeLast("childDidChange");
  }.observes("contentView")

});

/* >>>>>>>>>> BEGIN source/views/master_detail.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require("views/workspace");
sc_require("views/toolbar");


/** @class
  Master/Detail view is a simple view which manages a master view and a detail view.
  This is not all that different from a SplitView, except that, for the moment (this
  will hopefully change when SplitView becomes more palatable) the split point is not
  actually changeable and the split is always vertical.

  So, why use it when it is limited? Well, simple: it can hide the left side. Completely.
  As in, there will be no split divider anymore. There will be no nothing. It will be gone.
  Removed from DOM. Gone on to meet its maker, bereft of life, it rests in peace. If it weren't
  for the possibility of opening it up in a picker it would be pushing up the daisies!

  Yes, it has a built-in option for opening the master portion in a PickerPane. This is THE KILLER
  FEATURES. It is a command on the view: popupMasterPicker. And it is really really easy to call:
  make a toolbar button with an action "popupMasterPicker". That's it.

  An interesting feature is that it sets the master and detail views' masterIsVisible settings,
  allowing them to know if the master is visible.

  @since SproutCore 1.2
*/
SC.MasterDetailView = SC.View.extend(
/** @scope SC.MasterDetailView.prototype */ {

  /**
    @type Array
    @default ['sc-master-detail-view']
    @see SC.View#classNames
  */
  classNames: ["sc-master-detail-view"],

  /**
    @type String
    @default 'masterDetailRenderDelegate'
  */
  renderDelegateName: 'masterDetailRenderDelegate',


  // ..........................................................
  // Properties
  //

  /**
    The master view. For your development pleasure, it defaults to a
    WorkspaceView with a top toolbar.

    @type SC.View
    @default SC.WorkspaceView
  */
  masterView: SC.WorkspaceView.extend({
    topToolbar: SC.ToolbarView.extend({
    }),
    contentView: SC.View.extend({ backgroundColor: "white" })
  }),

  /**
    The detail view. For your development experience, it defaults to holding
    a top toolbar view with a button that closes/shows master. Come take a peek at
    the code to see what it looks like--it is so simple.

    @type SC.View
    @default SC.WorkspaceView
  */
  detailView: SC.WorkspaceView.extend({
    topToolbar: SC.ToolbarView.extend({
      childViews: ["showHidePicker"],
      showHidePicker: SC.ButtonView.extend({
        layout: { left: 7, centerY: 0, height: 30, width: 100 },
        controlSize: SC.AUTO_CONTROL_SIZE,
        title: "Picker",
        action: "toggleMasterPicker",
        isVisible: NO,
        isVisibleBinding: ".parentView.masterIsHidden"
      })
    })
  }),

  /**
    Whether to automatically hide the master panel in portrait orientation.

    By default, this property is a computed property based on whether the browser is a touch
    browser. Your purpose in overriding it is either to disable it from automatically
    disappearing on iPad and other touch devices, or force it to appear when a desktop
    browser changes.

    @field
    @type Boolean
    @default NO
  */
  autoHideMaster: function() {
    if (SC.platform.touch) return YES;
    return NO;
  }.property().cacheable(),

  /**
    The width of the 'master' side of the master/detail view.

    @type Number
    @default 250
  */
  masterWidth: 250,

  /**
    The width of the divider between the master and detail views.

    @type Number
    @default From theme, or 1.
  */
  dividerWidth: SC.propertyFromRenderDelegate('dividerWidth', 1),

  /**
    A property (computed) that says whether the master view is hidden.

    @field
    @type Boolean
    @default NO
    @observes autoHideMaster
    @observes orientation
  */
  masterIsHidden: function() {
    if (!this.get("autoHideMaster")) return NO;
    if (this.get("orientation") === SC.HORIZONTAL_ORIENTATION) return NO;
    return YES;
  }.property("autoHideMaster", "orientation"),

  /**
    Tracks the orientation of the view. Possible values:

      - SC.VERTICAL_ORIENTATION
      - SC.HORIZONTAL_ORIENTATION

    @type String
    @default SC.VERTICAL_ORIENTATION
  */
  orientation: SC.VERTICAL_ORIENTATION,

  /** @private */
  _scmd_frameDidChange: function() {
    var f = this.get("frame"), ret;
    if (f.width > f.height) ret = SC.HORIZONTAL_ORIENTATION;
    else ret = SC.VERTICAL_ORIENTATION;

    this.setIfChanged('orientation', ret);
  }.observes('frame'),

  /** @private */
  init: function() {
    arguments.callee.base.apply(this,arguments);
    this._scmd_frameDidChange();
    this._scmd_masterIsHiddenDidChange();
  },

  /**
    If the master is hidden, this toggles the master picker pane.
    Of course, since pickers are modal, this actually only needs to handle showing.

    @param {SC.View} view The view to anchor the picker to
  */
  toggleMasterPicker: function(view) {
    if (!this.get("masterIsHidden")) return;
    if (this._picker && this._picker.get("isVisibleInWindow")) {
      this.hideMasterPicker();
    } else {
      this.showMasterPicker(view);
    }
  },

  /**
    @param {SC.View} view The view to anchor the picker to
  */
  showMasterPicker: function(view) {
    if (this._picker && this._picker.get("isVisibleInWindow")) return;
    if (!this._picker) {
      var pp = this.get("pickerPane");
      this._picker = pp.create({ });
    }

    this._picker.set("contentView", this.get("masterView"));
    this._picker.set("extraRightOffset", this.get("pointerDistanceFromEdge"));

    this.showPicker(this._picker, view);
  },

  hideMasterPicker: function() {
    if (this._picker && this._picker.get("isVisibleInWindow")) {
      this.hidePicker(this._picker);
    }
  },

  /**
    @param {SC.PickerPane} picker The picker to popup
    @param {SC.View} view The view to anchor the picker to
  */
  showPicker: function(picker, view) {
    picker.popup(view, SC.PICKER_POINTER, [3, 0, 1, 2, 3], [9, -9, -18, 18]);
  },

  /**
    @param {SC.PickerPane} picker The picker to popup
  */
  hidePicker: function(picker) {
    picker.remove();
  },

  /**
    The picker pane class from which to create a picker pane.

    This defaults to one with a special theme.

    @type SC.PickerPane
    @default SC.PickerPane
  */
  pickerPane: SC.PickerPane.extend({
    layout: { width: 250, height: 480 },
    themeName: 'popover'
  }),


  // ..........................................................
  // Internal Support
  //

  /** @private */
  _picker: null,

  /** @private */
  pointerDistanceFromEdge: 46,

  /** @private
    Updates masterIsHidden in child views.
  */
  _scmd_masterIsHiddenDidChange: function() {
    var mih = this.get("masterIsHidden");
    this.get("masterView").set("masterIsHidden", mih);
    this.get("detailView").set("masterIsHidden", mih);
  }.observes("masterIsHidden"),

  /** @private
    When the frame changes, we don't need to do anything. We use smart positioning.
    However, if the orientation were to change, well, then we might need to do something.
  */
  _scmd_orientationDidChange: function() {
    this.invokeOnce("_scmd_tile");
  }.observes("orientation"),

  /** @private
    Observes properties which require retiling.
  */
  _scmd_retileProperties: function() {
    this.invokeOnce("_scmd_tile");
  }.observes("masterIsHidden", "masterWidth"),

  /** @private
    Instantiates master and detail views.
  */
  createChildViews: function() {
    var master = this.get("masterView");
    master = this.masterView = this.createChildView(master);

    var detail = this.get("detailView");
    detail = this.detailView = this.createChildView(detail);
    this.appendChild(detail);

    this.invokeOnce("_scmd_tile");
  },

  /** @private */
  _masterIsDrawn: NO, // whether the master is in the view

  /** @private
    Tiles the views as necessary.
  */
  _scmd_tile: function() {
    // first, determine what is and is not visible.
    var masterIsVisible = !this.get('masterIsHidden');

    // now, tile
    var masterWidth = this.get('masterWidth'),
        master = this.get('masterView'),
        detail = this.get('detailView');

    if (masterIsVisible) {
      // hide picker if needed
      this.hideMasterPicker();

      // draw master if needed
      if (!this._masterIsDrawn) {
        if (this._picker) this._picker.set('contentView', null);
        this.appendChild(master);
        this._masterIsDrawn = YES;
      }

      // set master layout
      master.set('layout', {
        left: 0, top: 0, bottom: 0, width: masterWidth
      });

      // and child, naturally
      var extra = this.get('dividerWidth');
      detail.set("layout", { left: masterWidth + extra, right: 0, top: 0, bottom: 0 });
    } else {
      // remove master if needed
      if (this._masterIsDrawn) {
        // Removes the child from the document, but doesn't destroy it or its layer.
        this.removeChild(master);
        this._masterIsDrawn = NO;
      }

      // and child, naturally
      detail.set('layout', { left: 0, right: 0, top: 0, bottom: 0 });
    }
  }

});

/* >>>>>>>>>> BEGIN source/views/scroller.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/** @class

  Displays a horizontal or vertical scroller.  You will not usually need to
  work with scroller views directly, but you may override this class to
  implement your own custom scrollers.

  Because the scroller uses the dimensions of its constituent elements to
  calculate layout, you may need to override the default display metrics.

  You can either create a subclass of ScrollerView with the new values, or
  provide your own in your theme:

      SC.ScrollerView = SC.ScrollerView.extend({
        scrollbarThickness: 14,
        capLength: 18,
        capOverlap: 14,
        buttonOverlap: 11,
        buttonLength: 41
      });

  You can change whether scroll buttons are displayed by setting the
  `hasButtons` property.

  By default, `SC.ScrollerView` has a persistent gutter. If you would like a
  gutterless scroller that supports fading, see `SC.OverlayScrollerView`.

  @extends SC.View
  @since SproutCore 1.0
*/
SC.ScrollerView = SC.View.extend(
/** @scope SC.ScrollerView.prototype */ {

  /** @private
    @type Array
    @default ['sc-scroller-view']
    @see SC.View#classNames
  */
  classNames: ['sc-scroller-view'],

  /** @private
    @type Array
    @default ['thumbPosition', 'thumbLength', 'controlsHidden']
    @see SC.View#displayProperties
  */
  displayProperties: ['thumbPosition', 'thumbLength', 'controlsHidden'],

  /** @private
    The WAI-ARIA role for scroller view.

    @type String
    @default 'scrollbar'
    @readOnly
  */
  ariaRole: 'scrollbar',


  // ..........................................................
  // PROPERTIES
  //

  /**
    If YES, a click on the track will cause the scrollbar to scroll to that position.
    Otherwise, a click on the track will cause a page down.

    In either case, alt-clicks will perform the opposite behavior.

    @type Boolean
    @default NO
  */
  shouldScrollToClick: NO,

  /**
    The value of the scroller.

    The value represents the position of the scroller's thumb.

    @field
    @type Number
    @default null
  */
  value: null,

  /**
    The displayed value of the scroller.

    This is the value of the scroller constrained within the minimum and maximum values.

    @type Number
    @observes value
  */
  displayValue: function () {
    return Math.max(Math.min(this.get("value"), this.get('maximum')), this.get('minimum'));
  }.property("value", 'minimum', 'maximum').cacheable(),

  /**
    The portion of the track that the thumb should fill. Usually the
    proportion will be the ratio of the size of the scroll view's content view
    to the size of the scroll view.

    Should be specified as a value between 0.0 (minimal size) and 1.0 (fills
    the slot). Note that if the proportion is 1.0 then the control will be
    disabled.

    @type Number
    @default 0.0
  */
  proportion: 0,

  /**
    The maximum offset value for the scroller.  This will be used to calculate
    the internal height/width of the scroller itself.

    When set less than the height of the scroller, the scroller is disabled.

    @type Number
    @default 0
  */
  maximum: 0,

  /**
    The minimum offset value for the scroller.  This will be used to calculate
    the internal height/width of the scroller itself.

    @type Number
    @default 0
  */
  minimum: 0,

  /**
    YES to enable scrollbar, NO to disable it.  Scrollbars will automatically
    disable if the maximum scroll width does not exceed their capacity.

    @field
    @type Boolean
    @default YES
    @observes proportion
  */
  isEnabled: function (key, value) {
    if (value !== undefined) {
      this._scsv_isEnabled = value;
    }

    if (this._scsv_isEnabled !== undefined) {
      return this._scsv_isEnabled;
    }

    return this.get('proportion') < 1;
  }.property('proportion').cacheable(),

  /** @private */
  _scsv_isEnabled: undefined,

  /**
    Determine the layout direction.  Determines whether the scrollbar should
    appear horizontal or vertical.  This must be set when the view is created.
    Changing this once the view has been created will have no effect. Possible
    values:

      - SC.LAYOUT_VERTICAL
      - SC.LAYOUT_HORIZONTAL

    @type String
    @default SC.LAYOUT_VERTICAL
  */
  layoutDirection: SC.LAYOUT_VERTICAL,

  /**
    Whether or not the scroller should display scroll buttons

    @type Boolean
    @default YES
  */
  hasButtons: YES,


  // ..........................................................
  // DISPLAY METRICS
  //

  /**
    The width (if vertical scroller) or height (if horizontal scroller) of the
    scrollbar.

    @type Number
    @default 14
  */
  scrollbarThickness: 14,

  /**
    The width or height of the cap that encloses the track.

    @type Number
    @default 18
  */
  capLength: 18,

  /**
    The amount by which the thumb overlaps the cap.

    @type Number
    @default 14
  */
  capOverlap: 14,

  /**
    The width or height of the up/down or left/right arrow buttons. If the
    scroller is not displaying arrows, this is the width or height of the end
    cap.

    @type Number
    @defaut 41
  */
  buttonLength: 41,

  /**
    The amount by which the thumb overlaps the arrow buttons. If the scroller
    is not displaying arrows, this is the amount by which the thumb overlaps
    the end cap.

    @type Number
    @default 9
  */
  buttonOverlap: 9,

  /**
    The minimium length that the thumb will be, regardless of how much content
    is in the scroll view.

    @type Number
    @default 20
  */
  minimumThumbLength: 20,

  // ..........................................................
  // INTERNAL SUPPORT
  //


  /** @private
    Generates the HTML that gets displayed to the user.

    The first time render is called, the HTML will be output to the DOM.
    Successive calls will reposition the thumb based on the value property.

    @param {SC.RenderContext} context the render context
    @param {Boolean} firstTime YES if this is creating a layer
    @private
  */
  render: function (context, firstTime) {
    var ariaOrientation = 'vertical',
      classNames = {},
      parentView = this.get('parentView'),
      layoutDirection = this.get('layoutDirection'),
      thumbPosition, thumbLength, thumbElement;

    // We set a class name depending on the layout direction so that we can
    // style them differently using CSS.
    switch (layoutDirection) {
    case SC.LAYOUT_VERTICAL:
      classNames['sc-vertical'] = YES;
      break;
    case SC.LAYOUT_HORIZONTAL:
      classNames['sc-horizontal'] = YES;
      ariaOrientation = 'horizontal';
      break;
    }

    // The appearance of the scroller changes if disabled
    // Whether to hide the thumb and buttons
    classNames['controls-hidden'] = this.get('controlsHidden');

    // Change the class names of the DOM element all at once to improve
    // performance
    context.setClass(classNames);

    // Calculate the position and size of the thumb
    thumbLength = this.get('thumbLength');
    thumbPosition = this.get('thumbPosition');

    // If this is the first time, generate the actual HTML
    if (firstTime) {
      context.push('<div class="track"></div>',
                    '<div class="cap"></div>');
      this.renderButtons(context, this.get('hasButtons'));
      this.renderThumb(context, layoutDirection, thumbLength, thumbPosition);

      //addressing accessibility
      context.setAttr('aria-orientation', ariaOrientation);

      //addressing accessibility
      context.setAttr('aria-valuemax', this.get('maximum'));
      context.setAttr('aria-valuemin', this.get('minimum'));
      context.setAttr('aria-valuenow', this.get('value'));
      context.setAttr('aria-controls', parentView.getPath('contentView.layerId'));
    } else {
      // The HTML has already been generated, so all we have to do is
      // reposition and resize the thumb

      // If we aren't displaying controls don't bother
      if (this.get('controlsHidden')) return;

      thumbElement = this.$('.thumb');

      this.adjustThumb(thumbElement, thumbPosition, thumbLength);

      //addressing accessibility
      context.setAttr('aria-valuenow', this.get('value'));
      if (this.didChangeFor('render-min', 'minimum')) context.setAttr('aria-valuemin', this.get('minimum'));
      if (this.didChangeFor('render-max', 'maximum')) context.setAttr('aria-valuemax', this.get('maximum'));
    }
  },

  renderThumb: function (context, layoutDirection, thumbLength, thumbPosition) {
    var styleString;
    if (layoutDirection === SC.LAYOUT_HORIZONTAL) styleString = 'width: ' + thumbLength + 'px; left: ' + thumbPosition + 'px;';
    else styleString = 'height: ' + thumbLength + 'px; top: ' + thumbPosition + 'px;';

    context.push('<div class="thumb" style="%@">'.fmt(styleString),
                 '<div class="thumb-center"></div>',
                 '<div class="thumb-top"></div>',
                 '<div class="thumb-bottom"></div></div>');

  },

  renderButtons: function (context, hasButtons) {
    if (hasButtons) {
      context.push('<div class="button-bottom"></div><div class="button-top"></div>');
    } else {
      context.push('<div class="endcap"></div>');
    }
  },

  // ..........................................................
  // THUMB MANAGEMENT
  //

  /** @private
    Adjusts the thumb (for backwards-compatibility calls adjustThumbPosition+adjustThumbSize by default)
  */
  adjustThumb: function (thumb, position, length) {
    this.adjustThumbPosition(thumb, position);
    this.adjustThumbSize(thumb, length);
  },

  /** @private
    Updates the position of the thumb DOM element.

    @param {Number} position the position of the thumb in pixels
  */
  adjustThumbPosition: function (thumb, thumbPosition) {
    var transformAttribute = SC.browser.experimentalCSSNameFor('transform'),
        thumbEl = thumb[0];

    // Don't touch the DOM if the position hasn't changed.
    if (this._thumbPosition !== thumbPosition) {
      // Consider that the parent view may be animating its final position, then we need to also animate
      // our final position.
      var parentView = this.get('parentView'),
        parentIsAnimating = parentView._sc_isAnimating;

      if (SC.platform.supportsCSSTransitions) {
        var transitionStyle = SC.browser.experimentalStyleNameFor('transition');

        if (parentIsAnimating) {
          var duration = parentView._sc_animationDuration,
            timing = parentView._sc_animationTiming.toString();

          // Will use translation transform to position thumb.
          if (SC.platform.supportsCSSTransforms) {
            thumbEl.style[transitionStyle] = transformAttribute + ' ' + duration + 's ' + timing;

          // Will use top/left style to position thumb.
          } else {
            switch (this.get('layoutDirection')) {
            case SC.LAYOUT_VERTICAL:
              thumbEl.style[transitionStyle] = 'top ' + duration + 's ' + timing;
              break;
            case SC.LAYOUT_HORIZONTAL:
              thumbEl.style[transitionStyle] = 'left ' + duration + 's ' + timing;
              break;
            }
          }

        // No duration, clear any previous transition.
        } else {
          thumbEl.style[transitionStyle] = '';
        }
      }


      // Position the thumb.
      var transformStyle;
      switch (this.get('layoutDirection')) {
      case SC.LAYOUT_VERTICAL:

        // Use translation transform to position thumb.
        if (SC.platform.supportsCSSTransforms) {
          transformStyle = 'translateX(0px) translateY(' + thumbPosition + 'px)';

          // TODO: Is this a necessary check?
          if (SC.platform.supportsCSS3DTransforms) { transformStyle += ' translateZ(0px)'; }

          thumbEl.style[transformAttribute] = transformStyle;

        // Use top style to position thumb.
        } else {
          thumbEl.style.top = thumbPosition;
        }

        break;

      case SC.LAYOUT_HORIZONTAL:
        // Use translation transform to position thumb.
        if (SC.platform.supportsCSSTransforms) {

          transformStyle = 'translateX(' + thumbPosition + 'px) translateY(0px)';

          // TODO: Is this a necessary check?
          if (SC.platform.supportsCSS3DTransforms) { transformStyle += ' translateZ(0px)'; }

          thumbEl.style[transformAttribute] = transformStyle;

        // Use left style to position thumb.
        } else {
          thumbEl.style.left = thumbPosition;
        }

        break;
      }
    }

    // Cache these values to check for changes.
    this._thumbPosition = thumbPosition;
  },

  /** @private */
  adjustThumbSize: function (thumb, size) {
    // Don't touch the DOM if the size hasn't changed
    if (this._thumbSize === size) return;

    switch (this.get('layoutDirection')) {
    case SC.LAYOUT_VERTICAL:
      thumb.css('height', Math.max(size, this.get('minimumThumbLength')));
      break;
    case SC.LAYOUT_HORIZONTAL:
      thumb.css('width', Math.max(size, this.get('minimumThumbLength')));
      break;
    }

    this._thumbSize = size;
  },

  // ..........................................................
  // SCROLLER DIMENSION COMPUTED PROPERTIES
  //

  /** @private
    Returns the total length of the track in which the thumb sits.

    The length of the track is the height or width of the scroller, less the
    cap length and the button length. This property is used to calculate the
    position of the thumb relative to the view.

    @property
  */
  trackLength: function () {
    var scrollerLength = this.get('scrollerLength');

    // Subtract the size of the top/left cap
    scrollerLength -= this.get('capLength') - this.get('capOverlap');

    // Subtract the size of the scroll buttons, or the end cap if they are
    // not shown.
    scrollerLength -= this.buttonLength - this.buttonOverlap;

    return scrollerLength;
  }.property('scrollerLength').cacheable(),

  /** @private
    Returns the height of the view if this is a vertical scroller or the width
    of the view if this is a horizontal scroller. This is used when scrolling
    up and down by page, as well as in various layout calculations.

    @type Number
  */
  scrollerLength: function () {
    switch (this.get('layoutDirection')) {
    case SC.LAYOUT_VERTICAL:
      return this.get('frame').height;
    case SC.LAYOUT_HORIZONTAL:
      return this.get('frame').width;
    }

    return 0;
  }.property('frame').cacheable(),

  /** @private
    The total length of the thumb. The size of the thumb is the
    length of the track times the content proportion.

    @property
  */
  thumbLength: function () {
    var value = this.get('value'),
        maximum = this.get('maximum'),
        minimum = this.get('minimum'),
        proportion = this.get('proportion'),
        length;

    // If the value is beyond the minimum or maximums, shrink our thumb length to represent the amount
    // of over scroll. Do this proportionally for the best effect!
    if (value < minimum) {
      proportion -= (minimum - value) / maximum;
    } else if (value > maximum) {
      proportion -= (value - maximum) / maximum;
    }

    length = Math.floor(this.get('trackLength') * proportion);
    length = isNaN(length) ? 0 : length;

    return Math.max(length, this.get('minimumThumbLength'));
  }.property('value', 'minimum', 'maximum', 'trackLength', 'proportion').cacheable(),

  /** @private
    The position of the thumb in the track.

    @type Number
    @isReadOnly
  */
  thumbPosition: function () {
    var displayValue = this.get('displayValue'),
        maximum = this.get('maximum'),
        trackLength = this.get('trackLength'),
        thumbLength = this.get('thumbLength'),
        capLength = this.get('capLength'),
        capOverlap = this.get('capOverlap'), position;

    position = (displayValue / maximum) * (trackLength - thumbLength);
    position += capLength - capOverlap; // account for the top/left cap

    return Math.floor(isNaN(position) ? 0 : position);
  }.property('displayValue', 'maximum', 'trackLength', 'thumbLength').cacheable(),

  /** @private
    YES if the maximum value exceeds the frame size of the scroller.  This
    will hide the thumb and buttons.

    @type Boolean
    @isReadOnly
  */
  controlsHidden: function () {
    return this.get('proportion') >= 1;
  }.property('proportion').cacheable(),

  // ..........................................................
  // FADE SUPPORT
  // Controls how the scroller fades in and out. Override these methods to implement
  // different fading.
  //

  /*
    Implement to support ScrollView's overlay fade procedure.

    @param {Number} duration
  */
  fadeIn: null,

  /*
    Implement to support ScrollView's overlay fade procedure.

    @param {Number} duration
  */
  fadeOut: null,

  // ..........................................................
  // MOUSE EVENTS
  //

  /** @private
    Returns the value for a position within the scroller's frame.
  */
  valueForPosition: function (pos) {
    var max = this.get('maximum'),
        trackLength = this.get('trackLength'),
        thumbLength = this.get('thumbLength'),
        capLength = this.get('capLength'),
        capOverlap = this.get('capOverlap'), value;

    value = pos - (capLength - capOverlap);
    value = value / (trackLength - thumbLength);
    value = value * max;
    return value;
  },

  // [CC] scroll bar supports touch events
  touchStart: function (evt) {
    evt.which = 1;
    return this.mouseDown(evt);
  },

  touchesDragged: function (evt) {
    return this.mouseDragged(evt);
  },

  touchEnd: function (evt) {
    return this.mouseUp(evt);
  },
  // [/CC]

  /** @private
    Handles mouse down events and adjusts the value property depending where
    the user clicked.

    If the control is disabled, we ignore all mouse input.

    If the user clicks the thumb, we note the position of the mouse event but
    do not take further action until they begin to drag.

    If the user clicks the track, we adjust the value a page at a time, unless
    alt is pressed, in which case we scroll to that position.

    If the user clicks the buttons, we adjust the value by a fixed amount, unless
    alt is pressed, in which case we adjust by a page.

    If the user clicks and holds on either the track or buttons, those actions
    are repeated until they release the mouse button.

    @param evt {SC.Event} the mousedown event
  */
  mouseDown: function (evt) {
    // Fast path, reject secondary clicks.
    if (evt.which !== 1) return false;

    if (!this.get('isEnabledInPane')) return NO;

    // keep note of altIsDown for later.
    this._altIsDown = evt.altKey;
    this._shiftIsDown = evt.shiftKey;

    var target = evt.target,
        thumbPosition = this.get('thumbPosition'),
        clickLocation,
        scrollerLength = this.get('scrollerLength');

    // Determine the subcontrol that was clicked
    if (target.className.indexOf('thumb') >= 0) {
      // Convert the mouseDown coordinates to the view's coordinates
      clickLocation = this.convertFrameFromView({ x: evt.pageX, y: evt.pageY });

      clickLocation.x -= thumbPosition;
      clickLocation.y -= thumbPosition;

      // Store the starting state so we know how much to adjust the
      // thumb when the user drags
      this._thumbDragging = YES;
      this._thumbOffset = clickLocation;
      this._mouseDownLocation = { x: evt.pageX, y: evt.pageY };
      this._thumbPositionAtDragStart = this.get('thumbPosition');
      this._valueAtDragStart = this.get("value");
    } else if (target.className.indexOf('button-top') >= 0) {
      // User clicked the up/left button
      // Decrement the value by a fixed amount or page size
      this.decrementProperty('value', (this._altIsDown ? scrollerLength : 30));
      this.makeButtonActive('.button-top');
      // start a timer that will continue to fire until mouseUp is called
      this.startMouseDownTimer('scrollUp');
      this._isScrollingUp = YES;
    } else if (target.className.indexOf('button-bottom') >= 0) {
      // User clicked the down/right button
      // Increment the value by a fixed amount
      this.incrementProperty('value', (this._altIsDown ? scrollerLength : 30));
      this.makeButtonActive('.button-bottom');
      // start a timer that will continue to fire until mouseUp is called
      this.startMouseDownTimer('scrollDown');
      this._isScrollingDown = YES;
    } else {
      // User clicked in the track
      var scrollToClick = this.get("shouldScrollToClick");
      if (evt.altKey) scrollToClick = !scrollToClick;

      var thumbLength = this.get('thumbLength'),
          frame = this.convertFrameFromView({ x: evt.pageX, y: evt.pageY }),
          mousePosition;

      switch (this.get('layoutDirection')) {
      case SC.LAYOUT_VERTICAL:
        this._mouseDownLocation = mousePosition = frame.y;
        break;
      case SC.LAYOUT_HORIZONTAL:
        this._mouseDownLocation = mousePosition = frame.x;
        break;
      }

      if (scrollToClick) {
        this.set('value', Math.min(this.get('maximum'), Math.max(this.get('minimum'), this.valueForPosition(mousePosition - (thumbLength / 2)))));

        // and start a normal mouse down
        thumbPosition = this.get('thumbPosition');

        this._thumbDragging = YES;
        this._thumbOffset = { x: frame.x - thumbPosition, y: frame.y - thumbPosition };
        this._mouseDownLocation = { x: evt.pageX, y: evt.pageY };
        this._thumbPositionAtDragStart = thumbPosition;
        this._valueAtDragStart = this.get("value");
      } else {
        // Move the thumb up or down a page depending on whether the click
        // was above or below the thumb
        if (mousePosition < thumbPosition) {
          this.decrementProperty('value', scrollerLength);
          this.startMouseDownTimer('page');
        } else {
          this.incrementProperty('value', scrollerLength);
          this.startMouseDownTimer('page');
        }
      }

    }

    return YES;
  },

  /** @private
    When the user releases the mouse button, remove any active
    state from the button controls, and cancel any outstanding
    timers.

    @param evt {SC.Event} the mousedown event
  */
  mouseUp: function (evt) {
    var active = this._scs_buttonActive, ret = NO, timer;

    // If we have an element that was set as active in mouseDown,
    // remove its active state
    if (active) {
      active.removeClass('active');
      ret = YES;
    }

    // Stop firing repeating events after mouseup
    timer = this._mouseDownTimer;
    if (timer) {
      timer.invalidate();
      this._mouseDownTimer = null;
    }

    this._thumbDragging = NO;
    this._isScrollingDown = NO;
    this._isScrollingUp = NO;

    return ret;
  },

  /** @private
    If the user began the drag on the thumb, we calculate the difference
    between the mouse position at click and where it is now.  We then
    offset the thumb by that amount, within the bounds of the track.

    If the user began scrolling up/down using the buttons, this will track
    what component they are currently over, changing the scroll direction.

    @param evt {SC.Event} the mousedragged event
  */
  mouseDragged: function (evt) {
    if (!this.get('isEnabledInPane')) return NO;

    var length, delta, thumbPosition,
        thumbPositionAtDragStart = this._thumbPositionAtDragStart,
        isScrollingUp = this._isScrollingUp,
        isScrollingDown = this._isScrollingDown,
        active = this._scs_buttonActive;

    // Only move the thumb if the user clicked on the thumb during mouseDown
    if (this._thumbDragging) {

      switch (this.get('layoutDirection')) {
      case SC.LAYOUT_VERTICAL:
        delta = (evt.pageY - this._mouseDownLocation.y);
        break;
      case SC.LAYOUT_HORIZONTAL:
        delta = (evt.pageX - this._mouseDownLocation.x);
        break;
      }

      // if we are in alt now, but were not before, update the old thumb position to the new one
      if (evt.altKey) {
        if (!this._altIsDown || (this._shiftIsDown !== evt.shiftKey)) {
          thumbPositionAtDragStart = this._thumbPositionAtDragStart = thumbPositionAtDragStart + delta;
          delta = 0;
          this._mouseDownLocation = { x: evt.pageX, y: evt.pageY };
          this._valueAtDragStart = this.get("value");
        }

        // because I feel like it. Probably almost no one will find this tiny, buried feature.
        // Too bad.
        if (evt.shiftKey) delta = -delta;

        this.set('value', Math.min(this.get('maximum'), Math.max(this.get('minimum'), Math.round(this._valueAtDragStart + delta * 2))));
      } else {
        thumbPosition = thumbPositionAtDragStart + delta;
        length = this.get('trackLength') - this.get('thumbLength');
        this.set('value', Math.min(this.get('maximum'), Math.max(this.get('minimum'), Math.round((thumbPosition / length) * this.get('maximum')))));
      }

    } else if (isScrollingUp || isScrollingDown) {
      var nowScrollingUp = NO, nowScrollingDown = NO;

      var topButtonRect = this.$('.button-top')[0].getBoundingClientRect();

      switch (this.get('layoutDirection')) {
      case SC.LAYOUT_VERTICAL:
        if (evt.clientY < topButtonRect.bottom) nowScrollingUp = YES;
        else nowScrollingDown = YES;
        break;
      case SC.LAYOUT_HORIZONTAL:
        if (evt.clientX < topButtonRect.right) nowScrollingUp = YES;
        else nowScrollingDown = YES;
        break;
      }

      if ((nowScrollingUp || nowScrollingDown) && nowScrollingUp !== isScrollingUp) {
        //
        // STOP OLD
        //

        // If we have an element that was set as active in mouseDown,
        // remove its active state
        if (active) {
          active.removeClass('active');
        }

        // Stop firing repeating events after mouseup
        this._mouseDownTimerAction = nowScrollingUp ? "scrollUp" : "scrollDown";

        if (nowScrollingUp) {
          this.makeButtonActive('.button-top');
        } else if (nowScrollingDown) {
          this.makeButtonActive('.button-bottom');
        }

        this._isScrollingUp = nowScrollingUp;
        this._isScrollingDown = nowScrollingDown;
      }
    }


    this._altIsDown = evt.altKey;
    this._shiftIsDown = evt.shiftKey;
    return YES;
  },

  /** @private
    Starts a timer that fires after 300ms.  This is called when the user
    clicks a button or inside the track to move a page at a time. If they
    continue holding the mouse button down, we want to repeat that action
    after a small delay.  This timer will be invalidated in mouseUp.

    Specify "immediate" as YES if it should not wait.
  */
  startMouseDownTimer: function (action, immediate) {
    this._mouseDownTimerAction = action;
    this._mouseDownTimer = SC.Timer.schedule({
      target: this,
      action: this.mouseDownTimerDidFire,
      interval: immediate ? 0 : 300
    });
  },

  /** @private
    Called by the mousedown timer.  This method determines the initial
    user action and repeats it until the timer is invalidated in mouseUp.
  */
  mouseDownTimerDidFire: function () {
    var scrollerLength = this.get('scrollerLength'),
        mouseLocation = SC.device.get('mouseLocation'),
        thumbPosition = this.get('thumbPosition'),
        thumbLength = this.get('thumbLength'),
        timerInterval = 50;

    switch (this.get('layoutDirection')) {
    case SC.LAYOUT_VERTICAL:
      mouseLocation = this.convertFrameFromView(mouseLocation).y;
      break;
    case SC.LAYOUT_HORIZONTAL:
      mouseLocation = this.convertFrameFromView(mouseLocation).x;
      break;
    }

    switch (this._mouseDownTimerAction) {
    case 'scrollDown':
      this.incrementProperty('value', this._altIsDown ? scrollerLength : 30);
      break;
    case 'scrollUp':
      this.decrementProperty('value', this._altIsDown ? scrollerLength : 30);
      break;
    case 'page':
      timerInterval = 150;
      if (mouseLocation < thumbPosition) {
        this.decrementProperty('value', scrollerLength);
      } else if (mouseLocation > thumbPosition + thumbLength) {
        this.incrementProperty('value', scrollerLength);
      }
    }

    this._mouseDownTimer = SC.Timer.schedule({
      target: this,
      action: this.mouseDownTimerDidFire,
      interval: timerInterval
    });
  },

  /** @private
    Given a selector, finds the corresponding DOM element and adds
    the 'active' class name.  Also stores the returned element so that
    the 'active' class name can be removed during mouseup.

    @param {String} the selector to find
  */
  makeButtonActive: function (selector) {
    this._scs_buttonActive = this.$(selector).addClass('active');
  }
});

/**
  A fading, transparent-backed scroll bar. Suitable for use as an overlaid scroller. (Note
  that to achieve the overlay effect, you must still set `verticalOverlay` and
  `horizontalOverlay` on your `ScrollView`.)

  @class
  @extends SC.ScrollerView
*/
SC.OverlayScrollerView = SC.ScrollerView.extend(
/** @scope SC.OverlayScrollerView.prototype */{

  // ..........................................................
  // FADE SUPPORT
  // Controls how the scroller fades in and out. Override these methods to implement
  // different fading.
  //

  /*
    Supports ScrollView's overlay fade procedure.
  */
  fadeIn: function () {
    this.$().toggleClass('fade-in', true);
    this.$().toggleClass('fade-out', false);
  },

  /*
    Supports ScrollView's overlay fade procedure.
  */
  fadeOut: function () {
    this.$().toggleClass('fade-in', false);
    this.$().toggleClass('fade-out', true);
  },

  /**
    @type Array
    @default ['sc-touch-scroller-view', 'sc-overlay-scroller-view]
    @see SC.View#classNames
  */
  classNames: ['sc-touch-scroller-view', 'sc-overlay-scroller-view'],

  /**
    @type Number
    @default 12
  */
  scrollbarThickness: 12,

  /**
    @type Number
    @default 3
  */
  capLength: 3,

  /**
    @type Number
    @default 0
  */
  capOverlap: 0,

  /**
    @type Number
    @default 3
  */
  buttonLength: 3,

  /**
    @type Number
    @default 0
  */
  buttonOverlap: 0,

  /**
    @type Boolean
    @default NO
  */
  hasButtons: NO,

  /** @private */
  adjustThumb: function (thumb, thumbPosition, thumbLength) {
    var transformAttribute = SC.browser.experimentalCSSNameFor('transform'),
        thumbEl = thumb[0],
        thumbInner = this.$('.thumb-inner'),
        thumbInnerEl = thumbInner[0];

    // Don't touch the DOM if the position hasn't changed.
    if (this._thumbPosition !== thumbPosition) {
      // Consider that the parent view may be animating its final position, then we need to also animate
      // our final position.
      var parentView = this.get('parentView'),
        parentIsAnimating = parentView._sc_isAnimating;

      if (SC.platform.supportsCSSTransitions) {
        var transitionStyle = SC.browser.experimentalStyleNameFor('transition');

        if (parentIsAnimating) {
          var duration = parentView._sc_animationDuration,
            timing = parentView._sc_animationTiming.toString();

          // Will use translation transform to position thumb.
          if (SC.platform.supportsCSSTransforms) {
            thumbEl.style[transitionStyle] = transformAttribute + ' ' + duration + 's ' + timing;

            if (this._thumbSize !== thumbLength) {
              thumbInnerEl.style[transitionStyle] = transformAttribute + ' ' + duration + 's ' + timing;
            }

          // Will use top/left style to position thumb.
          } else {
            switch (this.get('layoutDirection')) {
            case SC.LAYOUT_VERTICAL:
              thumbEl.style[transitionStyle] = 'top ' + duration + 's ' + timing;

              if (this._thumbSize !== thumbLength) {
                thumbInnerEl.style[transitionStyle] = 'top ' + duration + 's ' + timing;
              }

              break;
            case SC.LAYOUT_HORIZONTAL:
              thumbEl.style[transitionStyle] = 'left ' + duration + 's ' + timing;

              if (this._thumbSize !== thumbLength) {
                thumbInnerEl.style[transitionStyle] = 'left ' + duration + 's ' + timing;
              }

              break;
            }
          }

        // No duration, clear any previous transition.
        } else {
          thumbEl.style[transitionStyle] = '';
          thumbInnerEl.style[transitionStyle] = '';
        }
      }


      // Position the thumb.
      var transformStyle;
      switch (this.get('layoutDirection')) {
      case SC.LAYOUT_VERTICAL:

        // Use translation transform to position thumb.
        if (SC.platform.supportsCSSTransforms) {
          transformStyle = 'translateX(0px) translateY(' + thumbPosition + 'px)';

          // TODO: Is this a necessary check?
          if (SC.platform.supportsCSS3DTransforms) { transformStyle += ' translateZ(0px)'; }

          thumbEl.style[transformAttribute] = transformStyle;
          // thumb.css(transformCSS, 'translate3d(0px,' + thumbPosition + 'px,0px)');

          if (this._thumbSize !== thumbLength) {
            transformStyle = 'translateX(0px) translateY(' + Math.round(thumbLength - 1044) + 'px)';

            // TODO: Is this a necessary check?
            if (SC.platform.supportsCSS3DTransforms) { transformStyle += ' translateZ(0px)'; }

            // thumbInner.css(transformCSS, 'translate3d(0px,' + Math.round(thumbLength - 1044) + 'px,0px)');
            thumbInnerEl.style[transformAttribute] = transformStyle;
          }

        // Use top style to position thumb.
        } else {
          thumbEl.style.top = thumbPosition;

          if (this._thumbSize !== thumbLength) {
            thumbInnerEl.style.top = Math.round(thumbLength - 1044);
          }
        }

        break;

      case SC.LAYOUT_HORIZONTAL:
        // Use translation transform to position thumb.
        if (SC.platform.supportsCSSTransforms) {

          transformStyle = 'translateX(' + thumbPosition + 'px) translateY(0px)';

          // TODO: Is this a necessary check?
          if (SC.platform.supportsCSS3DTransforms) { transformStyle += ' translateZ(0px)'; }

          thumbEl.style[transformAttribute] = transformStyle;
          // thumb.css(transformCSS, 'translate3d(0px,' + thumbPosition + 'px,0px)');

          if (this._thumbSize !== thumbLength) {
            transformStyle = 'translateX(' + Math.round(thumbLength - 1044) + 'px) translateY(0px)';

            // TODO: Is this a necessary check?
            if (SC.platform.supportsCSS3DTransforms) { transformStyle += ' translateZ(0px)'; }

            // thumbInner.css(transformCSS, 'translate3d(0px,' + Math.round(thumbLength - 1044) + 'px,0px)');
            thumbInnerEl.style[transformAttribute] = transformStyle;
          }

        // Use left style to position thumb.
        } else {
          thumbEl.style.left = thumbPosition;

          if (this._thumbSize !== thumbLength) {
            thumbInnerEl.style.left = Math.round(thumbLength - 1044);
          }
        }

        break;
      }
    }

    // Cache these values to check for changes.
    this._thumbPosition = thumbPosition;
    this._thumbSize = thumbLength;
  },

  /** @private */
  render: function (context, firstTime) {
    var classNames = [],
      thumbPosition, thumbLength, thumbElement;

    // We set a class name depending on the layout direction so that we can
    // style them differently using CSS.
    switch (this.get('layoutDirection')) {
    case SC.LAYOUT_VERTICAL:
      classNames.push('sc-vertical');
      break;
    case SC.LAYOUT_HORIZONTAL:
      classNames.push('sc-horizontal');
      break;
    }

    // Whether to hide the thumb and buttons
    if (this.get('controlsHidden')) classNames.push('controls-hidden');

    // Change the class names of the DOM element all at once to improve
    // performance
    context.addClass(classNames);

    // Calculate the position and size of the thumb
    thumbLength = this.get('thumbLength');
    thumbPosition = this.get('thumbPosition');

    // If this is the first time, generate the actual HTML
    if (firstTime) {
      context.push('<div class="track"></div>' +
                    '<div class="cap"></div>');
      this.renderButtons(context, this.get('hasButtons'));
      this.renderThumb(context, thumbPosition, thumbLength);

    // The HTML has already been generated, so all we have to do is
    // reposition and resize the thumb
    } else {

      // If we aren't displaying controls don't bother
      if (this.get('controlsHidden')) return;

      thumbElement = this.$('.thumb');

      this.adjustThumb(thumbElement, thumbPosition, thumbLength);
    }
  },

  /** @private */
  renderThumb: function (context, thumbPosition, thumbLength) {
    var transformCSS = SC.browser.experimentalCSSNameFor('transform'),
      thumbPositionStyle, thumbSizeStyle;

    switch (this.get('layoutDirection')) {
    case SC.LAYOUT_VERTICAL:
      thumbPositionStyle = transformCSS + ': translate3d(0px,' + thumbPosition + 'px,0px)';
      // where is this magic number from?
      thumbSizeStyle = transformCSS + ': translateY(' + (thumbLength - 1044) + 'px)'.fmt();
      break;
    case SC.LAYOUT_HORIZONTAL:
      thumbPositionStyle = transformCSS + ': translate3d(' + thumbPosition + 'px,0px,0px)';
      thumbSizeStyle = transformCSS + ': translateX(' + (thumbLength - 1044) + 'px)'.fmt();
      break;
    }

    context.push('<div class="thumb" style="%@;">'.fmt(thumbPositionStyle) +
                 '<div class="thumb-top"></div>' +
                 '<div class="thumb-clip">' +
                 '<div class="thumb-inner" style="%@;">'.fmt(thumbSizeStyle) +
                 '<div class="thumb-center"></div>' +
                 '<div class="thumb-bottom"></div></div></div></div>');

    // Cache these values to check for changes.
    this._thumbPosition = thumbPosition;
    this._thumbSize = thumbLength;
  }
});


/* @private Old inaccurate name retained for backward compatibility. */
SC.TouchScrollerView = SC.OverlayScrollerView.extend({
  

});

/* >>>>>>>>>> BEGIN source/views/scroll_view.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2014 7x7 Software Inc. All rights reserved.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
sc_require('views/scroller');


SC.SCROLL = {

  /**
    The rate of deceleration in pixels per square millisecond after scrolling from a drag gesture.

    @static
    @type Number
    @default 3.0
  */
  DRAG_SCROLL_DECELERATION: 3.0,

  /**
    The number of pixels a gesture needs to move before it should be considered a scroll gesture.

    @static
    @type Number
    @default 5
  */
  SCROLL_GESTURE_THRESHOLD: 5,

  /**
    The number of pixels a gesture needs to move in only a single direction, before it should be
    considered as a locked scrolling direction (i.e. no gestures in the other direction will scroll
    in that direction).

    @static
    @type Number
    @default 50
  */
  SCROLL_LOCK_GESTURE_THRESHOLD: 50,

  /**
    The number of pixels a gesture needs to expand or contract before it should be considered a scale gesture.

    @static
    @type Number
    @default 3
  */
  SCALE_GESTURE_THRESHOLD: 3

};


/** @class
  Implements a complete scroll view. SproutCore implements its own JS-based scrolling in order
  to unify scrolling behavior across platforms, and to enable progressive rendering (via the
  clipping frame) during scroll on all devices.

  Important Properties
  -----

  ScrollView positions its contentView according to three properties: `verticalScrollOffset`,
  `horizontalScrollOffset`, and `scale`. These properties are bindable and observable, but you
  should not override them.

  Gutter vs. Overlaid Scrollers
  -----

  Scroll views use swappable scroll-bar views with various behavior (see `verticalScrollerView`
  and `horizontalScrollerView`). `SC.ScrollerView` is a gutter-based scroller which persists and
  takes up fourteen pixels. (By default, no scroller is shown for content that is too small to
  scroll; see `autohidesHorizontalScroller` and `autohidesVerticalScroller`.) `SC.OverlayScrollerView`
  is a gutterless view which fades when not scrolling. If you would like your view to always have
  OS X-style fading overlaid scrollers, you can use the following:

        SC.ScrollView.extend({
          horizontalOverlay: true,
          verticalOverlay: true
        });

  @extends SC.View
  @since SproutCore 1.0
*/
SC.ScrollView = SC.View.extend({
/** @scope SC.ScrollView.prototype */

  // ---------------------------------------------------------------------------------------------
  // Properties
  //

  /** @private Flag used to determine whether to animate the adjustment. */
  _sc_animationDuration: null,

  /** @private The animation timing to use. */
  _sc_animationTiming: null,

  /** @private The cached height of the container. */
  _sc_containerHeight: 0,

  /** @private The cached offset of the container. */
  _sc_containerOffset: null,

  /** @private The cached width of the container. */
  _sc_containerWidth: 0,

  /** @private The cached height of the content. */
  _sc_contentHeight: 0,

  /** @private Flag used to react accordingly when the content's height changes. */
  _sc_contentHeightDidChange: false,

  /** @private The cached scale of the content. */
  _sc_contentScale: undefined,

  /** @private Flag used to react accordingly when the content's scale changes. */
  _sc_contentScaleDidChange: false,

  /** @private The cached width of the content. */
  _sc_contentWidth: 0,

  /** @private Flag used to react accordingly when the content's width changes. */
  _sc_contentWidthDidChange: false,

  /** @private The anchor horizontal offset of the touch gesture. */
  _sc_gestureAnchorHOffset: null,

  /** @private The anchor position of the initial touch gesture. */
  _sc_gestureAnchorTotalD: null,

  /** @private The anchor position of the initial touch gesture. */
  _sc_gestureAnchorTotalX: null,

  /** @private The anchor position of the initial touch gesture. */
  _sc_gestureAnchorTotalY: null,

  /** @private The anchor vertical offset of the touch gesture. */
  _sc_gestureAnchorVOffset: null,

  /** @private The anchor position of the last touch gesture. */
  _sc_gestureAnchorX: null,

  /** @private The anchor position of the last touch gesture. */
  _sc_gestureAnchorY: null,

  /** @private The anchor distance from center of the last touch gesture. */
  _sc_gestureAnchorD: null,

  /** @private The original scale before a touch gesture. */
  _sc_gestureAnchorScale: null,

  /** @private The timer used to fade out this scroller. */
  _sc_horizontalFadeOutTimer: null,

  /** @private The actual horizontal scroll offset. */
  _sc_horizontalScrollOffset: null,

  /** @private The percentage offset scrolled horizontally. Used to maintain the horizontal position when the content size changes. */
  _sc_horizontalPct: null,

  /** @private Flag is true when scaling. Used in capturing touches. */
  _sc_isTouchScaling: false,

  /** @private Flag is true when scrolling horizontally. Used in capturing touches. */
  _sc_isTouchScrollingH: false,

  /** @private Flag is true when scrolling is locked to horizontal. */
  _sc_isTouchScrollingHOnly: false,

  /** @private Flag is true when scrolling vertically. Used in capturing touches. */
  _sc_isTouchScrollingV: false,

  /** @private Flag is true when scrolling is locked to vertical. */
  _sc_isTouchScrollingVOnly: false,

  /** @private The minimum delay before applying a fade transition. */
  _sc_minimumFadeOutDelay: function () {
    // The fade out delay is never less than 100ms (so that the current run loop can complete) and is never less than the fade in duration (so that it can fade fully in).
    return Math.max(Math.max(this.get('fadeOutDelay') || 0, 0.1), this.get('fadeInDuration') || 0) * 1000;
  }.property('fadeOutDelay').cacheable(),

  /** @private The amount of slip while over dragging (drag past bounds). 1.0 or 100% would slip completely, and 0.0 or 0% would not slip at all.  */
  _sc_overDragSlip: 0.5,

  /** @private Timer used to pass a touch through to its content if we don't start scrolling in that time. */
  _sc_passTouchToContentTimer: null,

  /** @private The actual scale. */
  _sc_scale: 1,

  /** @private Flag used to indicate when we should resize the content width manually. */
  // _sc_shouldResizeContentWidth: false,

  /** @private Flag used to indicate when we should resize the content height manually. */
  // _sc_shouldResizeContentHeight: false,

  /** @private The offset center x of a multi-touch gesture. */
  _sc_touchCenterX: null,

  /** @private The offset center y of a multi-touch gesture. */
  _sc_touchCenterY: null,

  /** @private The timer used to fade out this scroller. */
  _sc_verticalFadeOutTimer: null,

  /** @private The actual vertical scroll offset. */
  _sc_verticalScrollOffset: null,

  /** @private The percentage offset scrolled vertically. Used to maintain the vertical position when the content size changes. */
  _sc_verticalPct: null,

  /** @see SC.View.prototype.acceptsMultitouch

    @type Boolean
    @default true
  */
  acceptsMultitouch: true,

  /** @private Animation curves. Kept private b/c it will likely become a computed property. */
  animationCurveDecelerate: SC.easingCurve(0.35,0.34,0.84,1), // 'cubic-bezier(.35,.34,.84,1)',  // http://cubic-bezier.com

  /** @private Animation curves. Kept private b/c it will likely become a computed property. */
  animationCurveReverse: SC.easingCurve(0.45,-0.47,0.73,1.3), // 'cubic-bezier(0.45,-0.47,0.73,1.3)',

  /** @private Animation curves. Kept private b/c it will likely become a computed property. */
  animationCurveSnap: SC.easingCurve(0.28,0.36,0.52,1), // 'cubic-bezier(.28,.36,.52,1)',

  /**
    If true, the horizontal scroller will automatically hide if the contentView is smaller than the
    visible area.  The `hasHorizontalScroller` property must be set to true in order for this property
    to have any effect.

    @type Boolean
    @default true
  */
  autohidesHorizontalScroller: true,

  /**
    If true, the vertical scroller will automatically hide if the contentView is smaller than the
    visible area.  The `hasVerticalScroller` property must be set to true in order for this property
    to have any effect.

    @type Boolean
    @default true
  */
  autohidesVerticalScroller: true,

  /**
    Determines whether scaling is allowed.

    @type Boolean
    @default false
  */
  canScale: false,

  /**
    Returns true if the view has both a horizontal scroller and the scroller is visible.

    @field
    @type Boolean
    @readonly
  */
  canScrollHorizontal: function () {
    return !!(this.get('hasHorizontalScroller') && // This property isn't bindable.
      this.get('horizontalScrollerView') && // This property isn't bindable.
      this.get('isHorizontalScrollerVisible'));
  }.property('isHorizontalScrollerVisible').cacheable(),

  /**
    Returns true if the view has both a vertical scroller and the scroller is visible.

    @field
    @type Boolean
    @readonly
  */
  canScrollVertical: function () {
    return !!(this.get('hasVerticalScroller') && // This property isn't bindable.
      this.get('verticalScrollerView') && // This property isn't bindable.
      this.get('isVerticalScrollerVisible'));
  }.property('isVerticalScrollerVisible').cacheable(),

  /**
    @type Array
    @default ['sc-scroll-view']
    @see SC.View#classNames
  */
  classNames: ['sc-scroll-view'],

  /**
    The container view that will wrap your content view.  You can replace this property with your own
    custom class if you prefer.

    @type SC.ContainerView
    @default SC.ContainerView
  */
  containerView: SC.ContainerView,

  /**
    The content view you want the scroll view to manage.

    @type SC.View
    @default null
  */
  contentView: null,

  /**
    The scroll deceleration rate.

    @type Number
    @default SC.SCROLL.DRAG_SCROLL_DECELERATION
  */
  decelerationRate: SC.SCROLL.DRAG_SCROLL_DECELERATION,

  /** @private
    Whether to delay touches from passing through to the content. By default, if the touch moves enough to
    trigger a scroll within 150ms, this view will retain control of the touch, and content views will not
    have a chance to handle it. This is generally the behavior you want.

    If you set this to NO, the touch will not trigger a scroll until you pass control back to this view via
    `touch.restoreLastTouchResponder`, for example when the touch has dragged by a certain amount. You should
    use this option only if you know what you're doing.

    @type Boolean
    @default true
  */
  delaysContentTouches: true,

  /**
    Determines how long (in seconds) scrollbars wait before fading out.

    @property Number
    @default 0.4
   */
  fadeOutDelay: 0.4,

  /**
    True if the view should maintain a horizontal scroller.   This property must be set when the
    view is created.

    @type Boolean
    @default true
  */
  hasHorizontalScroller: true,

  /**
    True if the view should maintain a vertical scroller.   This property must be set when the
    view is created.

    @type Boolean
    @default true
  */
  hasVerticalScroller: true,

  /**
    The horizontal alignment for non-filling content inside of the ScrollView. Possible values:

      - SC.ALIGN_LEFT
      - SC.ALIGN_RIGHT
      - SC.ALIGN_CENTER

    @type String
    @default SC.ALIGN_CENTER
  */
  horizontalAlign: SC.ALIGN_CENTER,

  /**
    Determines whether the horizontal scroller should fade out while in overlay mode. Has no effect
    if `horizontalOverlay` is set to false.

    @property Boolean
    @default true
   */
  horizontalFade: true,

  /**
    Amount to scroll one horizontal line.

    Used by the default implementation of scrollLeftLine() and
    scrollRightLine().

    @type Number
    @default 20
  */
  horizontalLineScroll: 20,

  /**
    Use this to overlay the horizontal scroller.

    This ensures that the content container will not resize to accommodate the horizontal scroller,
    hence overlaying the scroller on top of the container.

    @field
    @type Boolean
    @default true
  */
  horizontalOverlay: false,

  /**
    Amount to scroll one horizontal page.

    Used by the default implementation of scrollLeftPage() and scrollRightPage().

    @field
    @type Number
    @default value of frame.width
    @observes frame
  */
  horizontalPageScroll: function () {
    return this.get('frame').width;
  }.property('frame'),

  /**
    The current horizontal scroll offset. Changing this value will update both the position of the
    contentView and the horizontal scroller, if there is one.

    @field
    @type Number
    @default 0
  */
  horizontalScrollOffset: function (key, value) {
    var containerWidth = this._sc_containerWidth,
        contentWidth = this._sc_contentWidth,
        min = this.get('minimumHorizontalScrollOffset'),
        max = this.get('maximumHorizontalScrollOffset');

    /* jshint eqnull:true */
    if (value != null) {
      // When touch scrolling, we allow scroll to pass the limits by a small amount.
      if (!this._sc_isTouchScrollingH) {
        // Constrain to the set limits.
        value = Math.max(min, Math.min(max, value));
      }

      // Record the relative percentage offset for maintaining position while scaling.
      if (contentWidth > 0) {
        this._sc_horizontalPct = (value + (containerWidth / 2)) / contentWidth;
      }

    // Use the cached value.
    } else {
      value = this._sc_horizontalScrollOffset;

      // Default value.
      if (value == null) {
        var horizontalAlign = this.get('initialHorizontalAlign');

        value = this._sc_alignedHorizontalOffset(horizontalAlign, containerWidth, contentWidth);
      }
    }

    // Update the actual value.
    this._sc_horizontalScrollOffset = value;

    return value;
  }.property().cacheable(),

  /**
    Use to control the positioning of the horizontal scroller. If you do not set 'horizontalOverlay' to
    true, then the content view will be automatically sized to meet the left edge of the vertical
    scroller, wherever it may be.

    This allows you to easily, for example, have “one pixel higher and one pixel lower” scroll bars
    that blend into their parent views.

    If you do set 'horizontalOverlay' to true, then the scroller view will “float on top” of the content view.

    Example: { left: -1, bottom: 0, right: -1 }

    @type Object
    @default null
  */
  horizontalScrollerLayout: null,

  /**
    The horizontal scroller view class. This will be replaced with a view instance when the
    ScrollView is created unless `hasHorizontalScroller` is false.

    If `horizontalOverlay` is `true`, the default view used will be an SC.OverlayScrollerView,
    otherwise SC.ScrollerView will be used.

    @type SC.View
    @default SC.ScrollerView | SC.OverlayScrollerView
  */
  horizontalScrollerView: null,

  /**
    Your content view's initial horizontal alignment, if wider than the container. This allows you to e.g.
    center the content view when zoomed out, but begin with it zoomed in and left-aligned. If not specified,
    defaults to value of `horizontalAlign`. May be:

      - SC.ALIGN_LEFT
      - SC.ALIGN_RIGHT
      - SC.ALIGN_CENTER

    @type String
    @default SC.ALIGN_LEFT
  */
  initialHorizontalAlign: SC.outlet('horizontalAlign'),

  /**
    Your content view's initial vertical alignment, if taller than the container. This allows you to e.g.
    center the content view when zoomed out, but begin with it zoomed in and top-aligned. If not specified,
    defaults to the value of `verticalAlign`. May be:

      - SC.ALIGN_TOP
      - SC.ALIGN_BOTTOM
      - SC.ALIGN_MIDDLE

    @type String
    @default SC.ALIGN_TOP
  */
  initialVerticalAlign: SC.outlet('verticalAlign'),

  /**
    True if the horizontal scroller should be visible. You can change this property value anytime to
    show or hide the horizontal scroller.  If you do not want to use a horizontal scroller at all, you
    should instead set `hasHorizontalScroller` to false to avoid creating a scroller view in the first
    place.

    @type Boolean
    @default true
  */
  isHorizontalScrollerVisible: true,

  /**
    Walk like a duck.

    @type Boolean
    @default true
    @readOnly
  */
  isScrollable: true,

  /**
    True if the vertical scroller should be visible. You can change this property value anytime to
    show or hide the vertical scroller.  If you do not want to use a vertical scroller at all, you
    should instead set `hasVerticalScroller` to false to avoid creating a scroller view in the first
    place.

    @type Boolean
    @default true
  */
  isVerticalScrollerVisible: true,

  /**
    The maximum horizontal scroll offset allowed given the current contentView size and the size of
    the scroll view.  If horizontal scrolling is disabled, this will always return 0.

    @field
    @type Number
    @default 0
  */
  maximumHorizontalScrollOffset: function () {
    return Math.max(this._sc_contentWidth - this._sc_containerWidth, 0);
  }.property('_sc_containerWidth', '_sc_contentWidth').cacheable(),

  /**
    The maximum scale.

    @type Number
    @default 2.0
  */
  maximumScale: 2.0,

  /**
    The maximum vertical scroll offset allowed given the current contentView size and the size of
    the scroll view.  If vertical scrolling is disabled, this will always return 0 (or whatever
    alignment dictates).

    @field
    @type Number
    @default 0
  */
  maximumVerticalScrollOffset: function () {
    return Math.max(this._sc_contentHeight - this._sc_containerHeight, 0);
  }.property('_sc_containerHeight', '_sc_contentHeight').cacheable(),

  /**
    The minimum horizontal scroll offset allowed given the current contentView size and the size of
    the scroll view.  If horizontal scrolling is disabled, this will always return 0 (or whatever alignment dictates).

    @field
    @type Number
    @default 0
  */
  minimumHorizontalScrollOffset: function () {
    return Math.min(this._sc_contentWidth - this._sc_containerWidth, 0);
  }.property('_sc_containerWidth', '_sc_contentWidth').cacheable(),

  /**
    The minimum scale.

    @type Number
    @default 0.25
  */
  minimumScale: 0.25,

  /**
    The minimum vertical scroll offset allowed given the current contentView size and the size of
    the scroll view.  If vertical scrolling is disabled, this will always return 0 (or whatever alignment dictates).

    @field
    @type Number
    @default 0
  */
  minimumVerticalScrollOffset: function () {
    return Math.min(this._sc_contentHeight - this._sc_containerHeight, 0);
  }.property('_sc_containerHeight', '_sc_contentHeight').cacheable(),

  /**
    The current scale. Setting this will adjust the scale of the contentView.

    If the contentView implements the SC.Scalable protocol, it will instead pass the scale to the contentView's
    `applyScale` method instead.

    Note that on platforms that allow bounce, setting scale outside of the minimum/maximumScale bounds will
    result in a bounce. It is up to the developer to alert this view when the action is over and it should
    bounce back.

    @field
    @type Number
    @default 1.0
  */
  scale: function (key, value) {
    /* jshint eqnull:true */
    if (value != null) {
      if (!this.get('canScale')) {
        value = 1;
      } else {
        var min = this.get('minimumScale'),
          max = this.get('maximumScale');

        // When touch scaling, we allow scaling to pass the limits by a small amount.
        if (this._sc_isTouchScaling) {
          min = min - (min * 0.1);
          max = max + (max * 0.1);
          if ((value < min || value > max)) {
            value = Math.min(Math.max(min, value), max);
          }

        // Constrain to the set limits.
        } else {
          if ((value < min || value > max)) {
            value = Math.min(Math.max(min, value), max);
          }
        }
      }
    } else {
      value = this._sc_scale;
    }

    // Update the actual value.
    this._sc_scale = value;

    return value;
  }.property('canScale', 'minimumScale', 'maximumScale').cacheable(),

  /**
    This determines how much a gesture must pinch or spread apart (in pixels) before it is registered as a scale action.

    You can change this value for all instances of SC.ScrollView in your application by overriding
    `SC.SCROLL.SCALE_GESTURE_THRESHOLD` at launch time.

    @type Number
    @default SC.SCROLL.SCALE_GESTURE_THRESHOLD
  */
  scaleGestureThreshold: SC.SCROLL.SCALE_GESTURE_THRESHOLD,

  /**
    This determines how far (in pixels) a gesture must move before it is registered as a scroll.

    You can change this value for all instances of SC.ScrollView in your application by overriding
    `SC.SCROLL.SCROLL_THRESHOLD` at launch time.

    @type Number
    @default SC.SCROLL.SCROLL_GESTURE_THRESHOLD
  */
  scrollGestureThreshold: SC.SCROLL.SCROLL_GESTURE_THRESHOLD,

  /**
    Once a vertical or horizontal scroll has been triggered, this determines how far (in pixels) the gesture
    must move on the other axis to trigger a two-axis scroll. If your scroll view's content is omnidirectional
    (e.g. a map) you should set this value to 0.

    You can change this value for all instances of SC.ScrollView in your application by overriding
    `SC.SCROLL.SCROLL_LOCK_GESTURE_THRESHOLD` at launch time.

    @type Number
    @default SC.SCROLL.SCROLL_LOCK_GESTURE_THRESHOLD
  */
  scrollLockGestureThreshold: SC.SCROLL.SCROLL_LOCK_GESTURE_THRESHOLD,

  /** @private
    Once a vertical or horizontal scroll has been triggered, this determines how far (in pixels) the gesture
    must move on the other axis to trigger a two-axis scroll. If your scroll view's content is omnidirectional
    (e.g. a map) you should set this value to 0.

    You can change this value for all instances of SC.ScrollView in your application by overriding
    `SC.SCROLL.TOUCH.DEFAULT_SECONDARY_SCROLL_THRESHOLD` at launch time.

    @type Number
    @default SC.SCROLL.TOUCH.DEFAULT_SECONDARY_SCROLL_THRESHOLD
  */
  // scrollSecondaryGestureThreshold: SC.SCROLL.TOUCH.DEFAULT_SECONDARY_SCROLL_THRESHOLD,

  /**
    The vertical alignment for non-filling content inside of the ScrollView. Possible values:

      - SC.ALIGN_TOP
      - SC.ALIGN_BOTTOM
      - SC.ALIGN_MIDDLE

    @type String
    @default SC.ALIGN_TOP
  */
  verticalAlign: SC.ALIGN_TOP,

  /**
    Determines whether the vertical scroller should fade out while in overlay mode. Has no effect if
    `verticalOverlay` is set to false.

    @property Boolean
    @default true
   */
  verticalFade: true,

  /**
    Amount to scroll one vertical line.

    Used by the default implementation of scrollDownLine() and scrollUpLine().

    @type Number
    @default 20
  */
  verticalLineScroll: 20,

  /**
    Use this to overlay the vertical scroller.

    This ensures that the content container will not resize to accommodate the vertical scroller,
    hence overlaying the scroller on top of the container.

    @field
    @type Boolean
    @default true
  */
  verticalOverlay: false,

  /**
    Amount to scroll one vertical page.

    Used by the default implementation of scrollUpPage() and scrollDownPage().

    @field
    @type Number
    @default value of frame.height
    @observes frame
  */
  verticalPageScroll: function () {
    return this.get('frame').height;
  }.property('frame'),

  /**
    The current vertical scroll offset. Changing this value will update both the position of the
    contentView and the vertical scroller, if there is one.

    @field
    @type Number
    @default 0
  */
  verticalScrollOffset: function (key, value) {
    var containerHeight = this._sc_containerHeight,
      contentHeight = this._sc_contentHeight,
      min = this.get('minimumVerticalScrollOffset'),
      max = this.get('maximumVerticalScrollOffset');

    /* jshint eqnull:true */
    if (value != null) {

      // When touch scrolling, we allow scroll to pass the limits by a small amount.
      if (!this._sc_isTouchScrollingV) {
        // Constrain to the set limits.
        value = Math.max(min, Math.min(max, value));
      }

      // Record the relative percentage offset for maintaining position while scaling.
      if (contentHeight > 0) {
        this._sc_verticalPct = (value + (containerHeight / 2)) / contentHeight;
      }

    // Use the cached value.
    } else {
      value = this._sc_verticalScrollOffset;

      // Default value.
      if (value == null) {
        var verticalAlign = this.get('initialVerticalAlign');

        value = this._sc_alignedVerticalOffset(verticalAlign, containerHeight, contentHeight);
      }
    }

    // Update the actual value.
    this._sc_verticalScrollOffset = value;

    return value;
  }.property().cacheable(),

  /**
    Use to control the positioning of the vertical scroller. If you do not set 'verticalOverlay' to
    true, then the content view will be automatically sized to meet the left edge of the vertical
    scroller, wherever it may be.

    This allows you to easily, for example, have “one pixel higher and one pixel lower” scroll bars
    that blend into their parent views.

    If you do set 'verticalOverlay' to true, then the scroller view will “float on top” of the content view.

    Example: { top: -1, bottom: -1, right: 0 }

    @type Object
    @default null
  */
  verticalScrollerLayout: null,

  /**
    The vertical scroller view class. This will be replaced with a view instance when the
    ScrollView is created unless `hasVerticalScroller` is false.

    If `verticalOverlay` is `true`, the default view used will be an SC.OverlayScrollerView,
    otherwise SC.ScrollerView will be used.

    @type SC.View
    @default SC.ScrollerView | SC.OverlayScrollerView
  */
  verticalScrollerView: null,

  // ---------------------------------------------------------------------------------------------
  // Methods
  //

  /** @private Aligns the content horizontally. */
  _sc_alignedHorizontalOffset: function (horizontalAlign, containerWidth, contentWidth) {
    switch (horizontalAlign) {
    case SC.ALIGN_RIGHT:
      return 0 - (containerWidth - contentWidth);
    case SC.ALIGN_CENTER:
      return 0 - ((containerWidth - contentWidth) / 2);
    default: // SC.ALIGN_LEFT
      return 0;
    }
  },

  /** @private Aligns the content vertically. */
  _sc_alignedVerticalOffset: function (verticalAlign, containerHeight, contentHeight) {
    switch (verticalAlign) {
    case SC.ALIGN_BOTTOM:
      return 0 - (containerHeight - contentHeight);
    case SC.ALIGN_MIDDLE:
      return 0 - ((containerHeight - contentHeight) / 2);
    default: // SC.ALIGN_TOP
      return 0;
    }
  },

  /** @private Manually animates the content view. */
  _sc_animateContentView: function (contentAdjustMap) {
    var easingCurve = this._sc_animationTiming,
      totalDuration = this._sc_animationDuration * 1000,
      start = new Date(),
      contentView = this.get('contentView'),
      contentViewLayout = contentView.get('layout'),
      leftStart = contentViewLayout.left,
      leftDelta = contentAdjustMap.left - leftStart,
      scaleStart = contentViewLayout.scale == null ? 1 : contentViewLayout.scale,
      scaleDelta = contentAdjustMap.scale - scaleStart,
      topStart = contentViewLayout.top,
      topDelta = contentAdjustMap.top - topStart,
      self = this;

    function animationFrame() {
      if (self._sc_isAnimating) {
        var duration = new Date() - start,
            percent = Math.min(duration / totalDuration, 1); // Capped at 100%

        SC.run(function () {
          var currentLeft = leftStart + leftDelta * easingCurve.value(percent),
              currentScale = scaleStart + scaleDelta * easingCurve.value(percent),
              currentTop = topStart + topDelta * easingCurve.value(percent);

          contentAdjustMap.left = currentLeft;
          contentAdjustMap.top = currentTop;
          contentAdjustMap.scale = currentScale;

          contentView.adjust(contentAdjustMap);
        });

        // Keep animating as long as we haven't hit 100%.
        if (percent < 1) {
          window.requestAnimationFrame(animationFrame);
        } else {
          // Clear out the animation flags.
          self._sc_isAnimating = false;
          self._sc_animationDuration = null;
          self._sc_animationTiming = null;
        }
      }
    }

    // Start the animation.
    self._sc_isAnimating = true;
    animationFrame();
  },

  /* @private Cancels any content view animation if it exists. */
  _sc_cancelAnimation: function () {
    if (this._sc_isAnimating) {
      var contentView = this.get('contentView');

    // UNUSED. Animate using SC.View.prototype.animate. Cancelling the animation in place proved problematic.
    // if (contentView.get('viewState') === SC.CoreView.ATTACHED_SHOWN_ANIMATING) {
    //   // Stop the animation in place.
    //   contentView.cancelAnimation(SC.LayoutState.CURRENT);

      var curLayout = contentView.get('layout');

      // Update offsets to match actual placement.
      this.set('horizontalScrollOffset', -curLayout.left);
      this.set('verticalScrollOffset', -curLayout.top);
      this.set('scale', curLayout.scale);

      // Clear out the animation flags.
      this._sc_isAnimating = false;
      this._sc_animationDuration = null;
      this._sc_animationTiming = null;
    }

  },

  /** @private Reposition our content view if necessary according to aligment. */
  _sc_containerViewFrameDidChange: function () {
    // Run the content view size change code (updates min & max offsets, sets content alignment if necessary, shows scrollers if necessary)
    var containerFrame = this.getPath('containerView.frame'),
      contentView = this.get('contentView'),
      lastMaximumHorizontalScrollOffset = this.get('maximumHorizontalScrollOffset'),
      lastMaximumVerticalScrollOffset = this.get('maximumVerticalScrollOffset'),
      lastMinimumHorizontalScrollOffset = this.get('minimumHorizontalScrollOffset'),
      lastMinimumVerticalScrollOffset = this.get('minimumVerticalScrollOffset');

    // Cache the current height and width of the container view, so we can only watch for size changes.
    // This will update the maximum scroll offsets when they are requested.
    this.set('_sc_containerHeight', containerFrame.height);
    this.set('_sc_containerWidth', containerFrame.width);

    if (contentView) {
      // var didAdjust = false;

      // if (this._sc_shouldResizeContentHeight) {
      //   contentView.adjust('height', containerFrame.height);
      //   didAdjust = true;
      // }

      // if (this._sc_shouldResizeContentWidth) {
      //   contentView.adjust('width', containerFrame.width);
      //   didAdjust = true;
      // }

      // Update the scrollers regardless.
      // if (!didAdjust) {
      this._sc_contentViewSizeDidChange(lastMinimumHorizontalScrollOffset, lastMaximumHorizontalScrollOffset, lastMinimumVerticalScrollOffset, lastMaximumVerticalScrollOffset);
      // }
    }

  },

  /** @private Whenever the contentView of the container changes, set up new observers and clean up old observers. */
  _sc_contentViewDidChange: function () {
    var newView = this.get('contentView'), // Our content view.
      containerView = this.get('containerView'),
      frameChangeFunc = this._sc_contentViewFrameDidChange;

    // Clean up observers on the previous content view.
    this._sc_removeContentViewObservers();

    // Reset caches.
    // this._sc_shouldResizeContentWidth = false;
    // this._sc_shouldResizeContentHeight = false;
    this._sc_contentHeight = 0;
    this._sc_contentWidth = 0;
    this._sc_contentScale = undefined;

    // Assign the content view to our container view. This ensures that it is instantiated.
    containerView.set('contentView', newView);
    newView = this.contentView = containerView.get('contentView'); // Actual content view.

    if (newView) {
      /* jshint eqnull:true */

      // Be wary of content views that replace their layers.
      // newView.addObserver('layer', this, layerChangeFunc);

      if (!newView.useStaticLayout) {
        // When a view wants an accelerated layer and isn't a fixed size, we convert it to a fixed
        // size and resize it when our container resizes.
        // if (newView.get('wantsAcceleratedLayer') && !newView.get('isFixedSize')) {
        //   var contentViewLayout = newView.get('layout');

        //   // Fix the width.
        //   if (contentViewLayout.width == null) {
        //     this._sc_shouldResizeContentWidth = true; // Flag to indicate that when the container's width changes, we should update the content's width.

        //     newView.adjust({
        //       right: null,
        //       width: this._sc_containerWidth
        //     });
        //   }

        //   // Fix the height.
        //   if (contentViewLayout.height == null) {
        //     this._sc_shouldResizeContentHeight = true; // Flag to indicate that when the container's height changes, we should update the content's height.

        //     newView.adjust({
        //       bottom: null,
        //       height: this._sc_containerHeight
        //     });
        //   }
        // }
      }

      // TODO: Can we remove this if a calculated property exists?
      newView.addObserver('frame', this, frameChangeFunc);

      // Initialize once.
      this._sc_contentViewFrameDidChange();
    }

    // Cache the current content view so that we can properly clean up when it changes.
    this._sc_contentView = newView;
  },

  /** @private */
  // _sc_contentViewLayerDidChange: function () {
  //   ???
  // },

  /** @private Check frame changes for size changes. */
  _sc_contentViewFrameDidChange: function () {
    var lastHeight = this._sc_contentHeight,
        lastScale = this._sc_contentScale,
        lastWidth = this._sc_contentWidth,
        newFrame = this.getPath('contentView.borderFrame'),
        lastMaximumHorizontalScrollOffset = this.get('maximumHorizontalScrollOffset'),
        lastMaximumVerticalScrollOffset = this.get('maximumVerticalScrollOffset'),
        lastMinimumHorizontalScrollOffset = this.get('minimumHorizontalScrollOffset'),
        lastMinimumVerticalScrollOffset = this.get('minimumVerticalScrollOffset');

    if (newFrame) {
      // Determine whether the scale has changed.
      if (lastScale !== newFrame.scale) {
        this._sc_contentScaleDidChange = true;
        this.set('_sc_contentScale', newFrame.scale);
      }

      if (lastWidth !== newFrame.width) {
        this._sc_contentWidthDidChange = true;
        this.set('_sc_contentWidth', newFrame.width);
      }

      if (lastHeight !== newFrame.height) {
        this._sc_contentHeightDidChange = true;
        this.set('_sc_contentHeight', newFrame.height);
      }

      // If any of the size values changed, update.
      if (this._sc_contentScaleDidChange || this._sc_contentWidthDidChange || this._sc_contentHeightDidChange) {
        this._sc_contentViewSizeDidChange(lastMinimumHorizontalScrollOffset, lastMaximumHorizontalScrollOffset, lastMinimumVerticalScrollOffset, lastMaximumVerticalScrollOffset);
      }
    }
  },

  /** @private When the content view's size changes, we need to update our scroll offset properties. */
  _sc_contentViewSizeDidChange: function (lastMinimumHorizontalScrollOffset, lastMaximumHorizontalScrollOffset, lastMinimumVerticalScrollOffset, lastMaximumVerticalScrollOffset) {
    var maximumHorizontalScrollOffset = this.get('maximumHorizontalScrollOffset'),
      maximumVerticalScrollOffset = this.get('maximumVerticalScrollOffset'),
      containerHeight, containerWidth,
      contentHeight, contentWidth;

    containerHeight = this._sc_containerHeight;
    containerWidth = this._sc_containerWidth;
    contentHeight = this._sc_contentHeight;
    contentWidth = this._sc_contentWidth;

    var value;
    if (contentWidth) {
      if (maximumHorizontalScrollOffset === 0) {
        // Align horizontally.
        value = this._sc_alignedHorizontalOffset(this.get('horizontalAlign'), containerWidth, contentWidth);
        this.set('horizontalScrollOffset', value); // Note: Trigger for _sc_scrollOffsetHorizontalDidChange

      } else {
        /* jshint eqnull:true */
        // If the horizontal position has never been set, use the initial alignment.
        if (this._sc_horizontalPct == null) {
          this._sc_horizontalScrollOffset = null;
          this.notifyPropertyChange('horizontalScrollOffset');

        // If the scale of the content view changes, we want to maintain relative position so that zooming remains centered.
        } else if (this._sc_contentScaleDidChange) {
          if (this._sc_touchCenterX != null) {
            value = (this._sc_horizontalPct * contentWidth) - this._sc_touchCenterX;
          } else {
            value = (this._sc_horizontalPct * contentWidth) - (containerWidth / 2);
          }
          this.set('horizontalScrollOffset', value); // Note: Trigger for _sc_scrollOffsetHorizontalDidChange

          // Live scale gesture. Update the anchor so that the scroll deltas are calculated correctly.
          if (this._sc_gestureAnchorHOffset != null) {
            this._sc_gestureAnchorHOffset = value;
          }
        } else if (this.get('canScrollHorizontal')) {
          // Take alignment into account.
          var horizontalAlign = this.get('horizontalAlign'),
              horizontalScrollOffset = this._sc_horizontalScrollOffset,
              minimumHorizontalScrollOffset = this.get('minimumHorizontalScrollOffset');

          switch (horizontalAlign) {
          case SC.ALIGN_CENTER:
            // Switched to scrolling horizontally, stick to center OR was scrolled at center and size changed.
            if ((lastMinimumHorizontalScrollOffset < 0 && minimumHorizontalScrollOffset === 0) ||
              (horizontalScrollOffset === lastMaximumHorizontalScrollOffset / 2)) {
              this.set('horizontalScrollOffset', maximumHorizontalScrollOffset / 2);
            }

            break;
          case SC.ALIGN_RIGHT:
            // Switched to scrolling horizontally, stick to right side OR was scrolled to right and size changed.
            if ((lastMinimumHorizontalScrollOffset < 0 && minimumHorizontalScrollOffset === 0) ||
              (horizontalScrollOffset === lastMaximumHorizontalScrollOffset)) {
              this.set('horizontalScrollOffset', maximumHorizontalScrollOffset);
            }

            break;
          }

          // Was at right side and size shrunk.
          if (horizontalScrollOffset > maximumHorizontalScrollOffset) {
            this.set('horizontalScrollOffset', maximumHorizontalScrollOffset);
          }
        }
      }
    }

    if (contentHeight) {
      if (maximumVerticalScrollOffset === 0) {
        // Align vertically.
        value = this._sc_alignedVerticalOffset(this.get('verticalAlign'), containerHeight, contentHeight);
        this.set('verticalScrollOffset', value); // Note: Trigger for _sc_scrollOffsetHorizontalDidChange

      } else {
        /* jshint eqnull:true */
        // If the vertical position has never been set, use the initial alignment.
        if (this._sc_verticalPct == null) {
          this._sc_verticalScrollOffset = null;
          this.notifyPropertyChange('verticalScrollOffset');

        // If the scale of the content view changes, we want to maintain relative position so that zooming remains centered.
        } else if (this._sc_contentScaleDidChange) {
          if (this._sc_touchCenterY != null) {
            value = (this._sc_verticalPct * contentHeight) - this._sc_touchCenterY;
          } else {
            value = (this._sc_verticalPct * contentHeight) - (containerHeight / 2);
          }
          this.set('verticalScrollOffset', value); // Note: Trigger for _sc_scrollOffsetVerticalDidChange

          // Live scale gesture. Update the anchor so that the scroll deltas are calculated correctly.
          if (this._sc_gestureAnchorVOffset != null) {
            this._sc_gestureAnchorVOffset = value;
          }
        } else if (this.get('canScrollVertical')) {
          var verticalAlign = this.get('verticalAlign'),
              verticalScrollOffset = this._sc_verticalScrollOffset,
              minimumVerticalScrollOffset = this.get('minimumVerticalScrollOffset');

          switch (verticalAlign) {
          case SC.ALIGN_MIDDLE:
            // Switched to scrolling vertically, stick to middle OR was scrolled at middle and size changed.
            if ((lastMinimumVerticalScrollOffset < 0 && minimumVerticalScrollOffset === 0) ||
              (verticalScrollOffset === lastMaximumVerticalScrollOffset / 2)) {
              this.set('verticalScrollOffset', maximumVerticalScrollOffset / 2);
            }

            break;
          case SC.ALIGN_BOTTOM:
            // Switched to scrolling vertically, stick to bottom side OR was scrolled to bottom and size changed.
            if ((lastMinimumVerticalScrollOffset < 0 && minimumVerticalScrollOffset === 0) ||
              (verticalScrollOffset === lastMaximumVerticalScrollOffset)) {
              this.set('verticalScrollOffset', maximumVerticalScrollOffset);
            }

            break;
          }

          // Was at bottom side and size shrunk.
          if (verticalScrollOffset > maximumVerticalScrollOffset) {
            this.set('verticalScrollOffset', maximumVerticalScrollOffset);
          }
        }
      }
    }

    // Reset our flags.
    this._sc_contentScaleDidChange = false;
    this._sc_contentHeightDidChange = false;
    this._sc_contentWidthDidChange = false;

    // TODO: Updating scrollers may change the container size, which will cause this to run again. Can we bring
    // this into a single call?
    this._sc_updateScrollers();
  },

  /** @private Fade in the horizontal scroller. Each scroller fades in/out independently. */
  _sc_fadeInHorizontalScroller: function () {
    var canScrollHorizontal = this.get('canScrollHorizontal'),
      horizontalScroller = this.get('horizontalScrollerView'),
      delay;

    if (canScrollHorizontal && horizontalScroller && horizontalScroller.get('fadeIn')) {
      if (this._sc_horizontalFadeOutTimer) {
        // Reschedule the current timer (avoid creating a new instance).
        this._sc_horizontalFadeOutTimer.startTime = null;
        this._sc_horizontalFadeOutTimer.schedule();
      } else {
        // Fade in.
        horizontalScroller.fadeIn();

        // Wait the minimum time before fading out again.
        delay = this.get('_sc_minimumFadeOutDelay');
        this._sc_horizontalFadeOutTimer = this.invokeLater(this._sc_fadeOutHorizontalScroller, delay);
      }
    }
  },

  /** @private Fade in the vertical scroller. Each scroller fades in/out independently. */
  _sc_fadeInVerticalScroller: function () {
    var canScrollVertical = this.get('canScrollVertical'),
      verticalScroller = this.get('verticalScrollerView'),
      delay;

    if (canScrollVertical && verticalScroller && verticalScroller.get('fadeIn')) {
      if (this._sc_verticalFadeOutTimer) {
        // Reschedule the current timer (avoid creating a new instance).
        this._sc_verticalFadeOutTimer.startTime = null;
        this._sc_verticalFadeOutTimer.schedule();

      } else {
        // Fade in.
        verticalScroller.fadeIn();

        // Wait the minimum time before fading out again.
        delay = this.get('_sc_minimumFadeOutDelay');
        this._sc_verticalFadeOutTimer = this.invokeLater(this._sc_fadeOutVerticalScroller, delay);
      }
    }
  },

  /** @private Fade out the horizontal scroller. */
  _sc_fadeOutHorizontalScroller: function () {
    var horizontalScroller = this.get('horizontalScrollerView');

    if (horizontalScroller && horizontalScroller.get('fadeOut')) {
      // Fade out.
      horizontalScroller.fadeOut();
    }

    this._sc_horizontalFadeOutTimer = null;
  },

  /** @private Fade out the vertical scroller. */
  _sc_fadeOutVerticalScroller: function () {
    var verticalScroller = this.get('verticalScrollerView');

    if (verticalScroller && verticalScroller.get('fadeOut')) {
      // Fade out.
      verticalScroller.fadeOut();
    }

    this._sc_verticalFadeOutTimer = null;
  },

  /** @private Adjust the content alignment horizontally on change. */
  _sc_horizontalAlignDidChange: function () {
    var maximumHorizontalScrollOffset = this.get('maximumHorizontalScrollOffset');

    // Align horizontally (Unless content width is zero).
    if (maximumHorizontalScrollOffset === 0 && this._sc_contentWidth) {
      var horizontalAlign = this.get('horizontalAlign'),
          value;

      value = this._sc_alignedHorizontalOffset(horizontalAlign, this._sc_containerWidth, this._sc_contentWidth);
      this.set('horizontalScrollOffset', value);
    }
  },

  /** @private
    Calculates the maximum offset given content and container sizes, and the
    alignment.
  */
  _sc_maximumScrollOffset: function (contentSize, containerSize, align, canScroll) {
    // If we can't scroll, we pretend our content size is no larger than the container.
    if (canScroll === NO) contentSize = Math.min(contentSize, containerSize);

    // if our content size is larger than or the same size as the container, it's quite
    // simple to calculate the answer. Otherwise, we need to do some fancy-pants
    // alignment logic (read: simple math)
    if (contentSize >= containerSize) return contentSize - containerSize;

    // alignment, yeah
    if (align === SC.ALIGN_LEFT || align === SC.ALIGN_TOP) {
      // if we left-align something, and it is smaller than the view, does that not mean
      // that it's maximum (and minimum) offset is 0, because it should be positioned at 0?
      return 0;
    } else if (align === SC.ALIGN_MIDDLE || align === SC.ALIGN_CENTER) {
      // middle align means the difference divided by two, because we want equal parts on each side.
      return 0 - Math.round((containerSize - contentSize) / 2);
    } else {
      // right align means the entire difference, because we want all that space on the left
      return 0 - (containerSize - contentSize);
    }
  },

  /** @private
    Calculates the minimum offset given content and container sizes, and the
    alignment.
  */
  _sc_minimumScrollOffset: function (contentSize, containerSize, align, canScroll) {
    // If we can't scroll, we pretend our content size is no larger than the container.
    if (canScroll === NO) contentSize = Math.min(contentSize, containerSize);

    // if the content is larger than the container, we have no need to change the minimum
    // away from the natural 0 position.
    if (contentSize > containerSize) return 0;

    // alignment, yeah
    if (align === SC.ALIGN_LEFT || align === SC.ALIGN_TOP) {
      // if we left-align something, and it is smaller than the view, does that not mean
      // that it's maximum (and minimum) offset is 0, because it should be positioned at 0?
      return 0;
    } else if (align === SC.ALIGN_MIDDLE || align === SC.ALIGN_CENTER) {
      // middle align means the difference divided by two, because we want equal parts on each side.
      return 0 - Math.round((containerSize - contentSize) / 2);
    } else {
      // right align means the entire difference, because we want all that space on the left
      return 0 - (containerSize - contentSize);
    }
  },

  /** @private Registers/deregisters view with SC.Drag for autoscrolling. */
  _sc_registerAutoscroll: function () {
    if (this.get('isVisibleInWindow') && this.get('isEnabledInPane')) {
      SC.Drag.addScrollableView(this);
    } else {
      SC.Drag.removeScrollableView(this);
    }
  },

  /** @private Reposition the content view to match the current scroll offsets and scale. */
  _sc_repositionContentView: function () {
    var contentView = this.get('contentView');

    if (contentView) {
      this.invokeOnce(this._sc_repositionContentViewUnfiltered);
    }
  },

  /** @private Reposition the content view to match the current scroll offsets and scale. */
  _sc_repositionContentViewUnfiltered: function () {
    var containerView = this.get('containerView'),
        contentView = this.get('contentView'),
        horizontalScrollOffset = this.get('horizontalScrollOffset'),
        verticalScrollOffset = this.get('verticalScrollOffset'),
        scale = this.get('scale');

    // If the content is statically laid out, use margins in the container layer to move it.
    // TODO: Remove static layout support.
    if (contentView.useStaticLayout) {
      var containerViewLayer = containerView.get('layer');

      // Set the margins on the layer.
      containerViewLayer.style.marginLeft = -horizontalScrollOffset + 'px';
      containerViewLayer.style.marginTop = -verticalScrollOffset + 'px';

    // Otherwise call adjust on the content.
    } else {
      // Constrain the offsets to full (actual) pixels to prevent blurry text et cetera. Note that this assumes
      // that the scroll view itself is living at a scale of 1, and may give blurry subpixel results if scaled.
      var horizontalAlign = this.get('horizontalAlign'),
        verticalAlign = this.get('verticalAlign'),
        left, top;

      left = -horizontalScrollOffset;

      // Round according to the alignment to avoid jitter at the edges. For example, we don't want 0.55 rounding up to 1 when left aligned. This also prevents implied percentage values (i.e. 0.0 > value > 1.0 == %)!
      switch (horizontalAlign) {
      case SC.ALIGN_CENTER:
        left = Math.round(left);
        break;
      case SC.ALIGN_RIGHT:
        left = Math.ceil(left);
        break;
      default: // SC.ALIGN_LEFT
        left = Math.floor(left);
      }

      top = -verticalScrollOffset;

      switch (verticalAlign) {
      case SC.ALIGN_MIDDLE:
        top = Math.round(top);
        break;
      case SC.ALIGN_BOTTOM:
        top = Math.ceil(top);
        break;
      default: // SC.ALIGN_TOP
        top = Math.floor(top);
      }

      // Cancel any active animation in place.
      // this._sc_cancelAnimation();

      var contentAdjustMap = SC.ScrollView._SC_CONTENT_ADJUST_MAP; // Shared object used to avoid continually initializing/destroying objects.

      // Create the content adjust map once. Note: This is a shared object, all properties must be overwritten each time.
      if (!contentAdjustMap) {
        contentAdjustMap = SC.ScrollView._SC_CONTENT_ADJUST_MAP = {
          // Ensure that scale transforms occur from the top-left corner (per our math).
          transformOriginX: 0,
          transformOriginY: 0
        };
      }

      contentAdjustMap.left = left;
      contentAdjustMap.top = top;
      contentAdjustMap.scale = scale;

      if (this._sc_animationDuration) {
        // UNUSED. Animate using SC.View.prototype.animate. Cancelling the animation in place proved problematic.
        // contentView.animate({ left: left, top: top, scale: scale }, {
        //   duration: this._sc_animationDuration,
        //   timing: this._sc_animationTiming
        // });

        // // Run the animation immediately (don't wait for next Run Loop).
        // // Note: The next run loop will be queued none-the-less, so we may want to avoid that entirely in the future.
        // contentView._animate();
        this._sc_animateContentView(contentAdjustMap);

      } else {
        contentView.adjust(contentAdjustMap);
      }
    }
  },

  /** @private Re-position the scrollers and content depending on the need to scroll or not. */
  _sc_repositionScrollers: function () {
    this.invokeOnce(this._sc_repositionScrollersUnfiltered);
  },

  /** @private Re-position the scrollers and content depending on the need to scroll or not. */
  _sc_repositionScrollersUnfiltered: function () {
    var hasHorizontalScroller = this.get('hasHorizontalScroller'),
      hasVerticalScroller = this.get('hasVerticalScroller'),
      canScrollHorizontal = this.get('canScrollHorizontal'),
      canScrollVertical = this.get('canScrollVertical'),
      containerLayoutMap = SC.ScrollView._SC_CONTAINER_LAYOUT_MAP, // Shared object used to avoid continually initializing/destroying objects.
      horizontalScrollerView = this.get('horizontalScrollerView'),
      horizontalScrollerHeight = horizontalScrollerView && canScrollHorizontal ? horizontalScrollerView.get('scrollbarThickness') : 0,
      verticalScrollerView = this.get('verticalScrollerView'),
      verticalScrollerWidth = verticalScrollerView && canScrollVertical ? verticalScrollerView.get('scrollbarThickness') : 0,
      layout; // The new layout to be applied to each scroller.

    // Create the container layout map once. Note: This is a shared object, all properties must be overwritten each time.
    if (!containerLayoutMap) { containerLayoutMap = SC.ScrollView._SC_CONTAINER_LAYOUT_MAP = {}; }

    // Set the standard.
    containerLayoutMap.bottom = 0;
    containerLayoutMap.right = 0;

    // Adjust the horizontal scroller.
    if (hasHorizontalScroller) {
      var horizontalOverlay = this.get('horizontalOverlay'),
        horizontalScrollerLayout = this.get('horizontalScrollerLayout');

      // Adjust the scroller view accordingly. Allow for a custom default scroller layout to be set.
      if (horizontalScrollerLayout) {
        layout = {
          left: horizontalScrollerLayout.left,
          bottom: horizontalScrollerLayout.bottom,
          right: horizontalScrollerLayout.right + verticalScrollerWidth,
          height: horizontalScrollerHeight
        };
      } else {
        layout = {
          left: 0,
          bottom: 0,
          right: verticalScrollerWidth,
          height: horizontalScrollerHeight
        };
      }
      horizontalScrollerView.set('layout', layout);

      // Adjust the content view accordingly.
      if (canScrollHorizontal && !horizontalOverlay) {
        containerLayoutMap.bottom = horizontalScrollerHeight;
      }

      // Set the visibility of the scroller immediately.
      horizontalScrollerView.set('isVisible', canScrollHorizontal);
      this._sc_fadeInHorizontalScroller();
    }

    // Adjust the vertical scroller.
    if (hasVerticalScroller) {
      var verticalOverlay = this.get('verticalOverlay'),
        verticalScrollerLayout = this.get('verticalScrollerLayout');

      // Adjust the scroller view accordingly. Allow for a custom default scroller layout to be set.
      if (verticalScrollerLayout) {
        layout = {
          top: verticalScrollerLayout.top,
          right: verticalScrollerLayout.right,
          bottom: verticalScrollerLayout.bottom + horizontalScrollerHeight,
          width: verticalScrollerWidth
        };
      } else {
        layout = {
          top: 0,
          right: 0,
          bottom: horizontalScrollerHeight,
          width: verticalScrollerWidth
        };
      }
      verticalScrollerView.set('layout', layout);

      // Prepare to adjust the content view accordingly.
      if (canScrollVertical && !verticalOverlay) {
        containerLayoutMap.right = verticalScrollerWidth;
      }

      // Set the visibility of the scroller immediately.
      verticalScrollerView.set('isVisible', canScrollVertical);
      this._sc_fadeInVerticalScroller();
    }

    // Adjust the container view accordingly (i.e. to make space for scrollers or take space back).
    var containerView = this.get('containerView');
    containerView.adjust(containerLayoutMap);
  },

  /** @private Clean up observers on the content view. */
  _sc_removeContentViewObservers: function () {
    var oldView = this._sc_contentView,
      frameChangeFunc = this._sc_contentViewFrameDidChange;
      // layerChangeFunc = this._sc_contentViewLayerDidChange;

    if (oldView) {
      oldView.removeObserver('frame', this, frameChangeFunc);
      // oldView.removeObserver('layer', this, layerChangeFunc);

      // this._sc_shouldResizeContentWidth = false;
      // this._sc_shouldResizeContentHeight = false;
    }
  },

  /** @private Whenever the scale changes, update the scrollers and adjust the location of the content view. */
  _sc_scaleDidChange: function () {
    var contentView = this.get('contentView'),
      scale = this.get('scale');

    // If the content is statically laid out, use margins in the container layer to move it.
    // TODO: Remove static layout support.
    if (contentView) {
      if (contentView.useStaticLayout) {
        


      // Reposition the content view to apply the scale.
      } else {
        // Apply this change.
        this._sc_repositionContentView();
      }
    }
  },

  /** @private Whenever the scroll offsets change, update the scrollers and adjust the location of the content view. */
  _sc_scrollOffsetHorizontalDidChange: function () {
    this._sc_repositionContentView();
    this.invokeLast(this._sc_fadeInHorizontalScroller);
  },

  /** @private Whenever the scroll offsets change, update the scrollers and adjust the location of the content view. */
  _sc_scrollOffsetVerticalDidChange: function () {
    this._sc_repositionContentView();
    this.invokeLast(this._sc_fadeInVerticalScroller);
  },

  /** @private Update the scrollers. */
  _sc_updateScrollers: function () {
    var horizontalScrollerView = this.get('horizontalScrollerView'),
      verticalScrollerView = this.get('verticalScrollerView'),
      minimumHorizontalScrollOffset = this.get('minimumHorizontalScrollOffset'),
      minimumVerticalScrollOffset = this.get('minimumVerticalScrollOffset'),
      maximumHorizontalScrollOffset = this.get('maximumHorizontalScrollOffset'),
      maximumVerticalScrollOffset = this.get('maximumVerticalScrollOffset'),
      containerHeight, containerWidth,
      contentHeight, contentWidth;

    containerHeight = this._sc_containerHeight;
    containerWidth = this._sc_containerWidth;
    contentHeight = this._sc_contentHeight;
    contentWidth = this._sc_contentWidth;

    // Update the minimum and maximum scrollable distance on the scrollers as well as their visibility.
    var proportion;
    if (horizontalScrollerView) {
      horizontalScrollerView.set('minimum', minimumHorizontalScrollOffset);
      horizontalScrollerView.set('maximum', maximumHorizontalScrollOffset);

      if (this.get('autohidesHorizontalScroller')) {
        this.setIfChanged('isHorizontalScrollerVisible', contentWidth > containerWidth);
      }

      // Constrain the proportion to 100%.
      proportion = Math.min(containerWidth / contentWidth, 1.0);
      horizontalScrollerView.setIfChanged('proportion', proportion);
    }

    if (verticalScrollerView) {
      verticalScrollerView.set('minimum', minimumVerticalScrollOffset);
      verticalScrollerView.set('maximum', maximumVerticalScrollOffset);

      if (this.get('autohidesVerticalScroller')) {
        this.setIfChanged('isVerticalScrollerVisible', contentHeight > containerHeight);
      }

      // Constrain the proportion to 100%.
      proportion = Math.min(containerHeight / contentHeight, 1.0);
      verticalScrollerView.setIfChanged('proportion', proportion);
    }
  },

  /** @private Adjust the content alignment vertically on change. */
  _sc_verticalAlignDidChange: function () {
    var maximumVerticalScrollOffset = this.get('maximumVerticalScrollOffset');

    // Align vertically (Unless content height is zero).
    if (maximumVerticalScrollOffset === 0 && this._sc_contentHeight) {
      var verticalAlign = this.get('verticalAlign'),
        value;

      value = this._sc_alignedVerticalOffset(verticalAlign, this._sc_containerHeight, this._sc_contentHeight);
      this.set('verticalScrollOffset', value);
    }
  },

  /** @private Instantiate the container view and the scrollers as needed. */
  createChildViews: function () {
    var childViews = [];

    // Set up the container view.
    var containerView = this.get('containerView');

    


    containerView = this.containerView = this.createChildView(containerView, {
      contentView: this.contentView // Initialize the view with the currently set container view.
    });
    this.contentView = containerView.get('contentView'); // Replace our content view with the instantiated version.
    childViews.push(containerView);

    // Set up the scrollers.
    var scrollerView;

    // Create a horizontal scroller view if needed.
    if (!this.get('hasHorizontalScroller')) {
      // Remove the class entirely.
      this.horizontalScrollerView = null;
    } else {
      scrollerView = this.get('horizontalScrollerView');

      // Use a default scroller view.
      /* jshint eqnull:true */
      if (scrollerView == null) {
        scrollerView = this.get('horizontalOverlay') ? SC.OverlayScrollerView : SC.ScrollerView;
      }

      // Replace the class property with an instance.
      scrollerView = this.horizontalScrollerView = this.createChildView(scrollerView, {
        isVisible: !this.get('autohidesHorizontalScroller'),
        layoutDirection: SC.LAYOUT_HORIZONTAL,
        value: this.get('horizontalScrollOffset'),
        valueBinding: '.parentView.horizontalScrollOffset', // Bind the value of the scroller to our horizontal offset.
        minimum: this.get('minimumHorizontalScrollOffset'),
        maximum: this.get('maximumHorizontalScrollOffset')
      });

      // Add the scroller view to the child views array.
      childViews.push(scrollerView);
    }

    // Create a vertical scroller view if needed.
    if (!this.get('hasVerticalScroller')) {
      // Remove the class entirely.
      this.verticalScrollerView = null;
    } else {
      scrollerView = this.get('verticalScrollerView');

      // Use a default scroller view.
      /* jshint eqnull:true */
      if (scrollerView == null) {
        scrollerView = this.get('verticalOverlay') ? SC.OverlayScrollerView : SC.ScrollerView;
      }

      // Replace the class property with an instance.
      scrollerView = this.verticalScrollerView = this.createChildView(scrollerView, {
        isVisible: !this.get('autohidesVerticalScroller'),
        layoutDirection: SC.LAYOUT_VERTICAL,
        value: this.get('verticalScrollOffset'),
        valueBinding: '.parentView.verticalScrollOffset', // Bind the value of the scroller to our vertical offset.
        minimum: this.get('minimumVerticalScrollOffset'),
        maximum: this.get('maximumVerticalScrollOffset')
      });

      // Add the scroller view to the child views array.
      childViews.push(scrollerView);
    }

    // Set the childViews array.
    this.childViews = childViews;
  },

  /** @private */
  destroy: function() {
    // Clean up.
    this._sc_removeContentViewObservers();
    this.removeObserver('contentView', this, this._sc_contentViewDidChange);

    this.removeObserver('horizontalAlign', this, this._sc_horizontalAlignDidChange);
    this.removeObserver('verticalAlign', this, this._sc_verticalAlignDidChange);

    arguments.callee.base.apply(this,arguments);
  },

  /** @private SC.View */
  didCreateLayer: function () {
    // Observe the scroll offsets for changes and initialize once.
    this.addObserver('horizontalScrollOffset', this, this._sc_scrollOffsetHorizontalDidChange);
    this.addObserver('verticalScrollOffset', this, this._sc_scrollOffsetVerticalDidChange);
    this._sc_scrollOffsetHorizontalDidChange();
    this._sc_scrollOffsetVerticalDidChange();

    // Observe the scroller visibility properties for changes and initialize once.
    this.addObserver('isHorizontalScrollerVisible', this, this._sc_repositionScrollers);
    this.addObserver('isVerticalScrollerVisible', this, this._sc_repositionScrollers);
    this._sc_repositionScrollers();

    // Observe the scale for changes and initialize once.
    this.addObserver('scale', this, this._sc_scaleDidChange);
    this._sc_scaleDidChange();

    // Observe our container view frame for changes and initialize once.
    var containerView = this.get('containerView');
    containerView.addObserver('frame', this, this._sc_containerViewFrameDidChange);
    this._sc_containerViewFrameDidChange();

    // Observe for changes in enablement and visibility for registering with SC.Drag auto-scrolling and initialize once.
    this.addObserver('isVisibleInWindow', this, this._sc_registerAutoscroll);
    this.addObserver('isEnabledInPane', this, this._sc_registerAutoscroll);
    this._sc_registerAutoscroll();
  },

  /** SC.Object.prototype */
  init: function () {
    arguments.callee.base.apply(this,arguments);

    // Observe the content view for changes and initialize once.
    this.addObserver('contentView', this, this._sc_contentViewDidChange);
    this._sc_contentViewDidChange();

    // Observe the alignment properties for changes. No need to initialize, the default alignment property
    // will be used.
    this.addObserver('horizontalAlign', this, this._sc_horizontalAlignDidChange);
    this.addObserver('verticalAlign', this, this._sc_verticalAlignDidChange);
  },

  /**
    Scrolls the receiver in the horizontal and vertical directions by the amount specified, if
    allowed.  The actual scroll amount will be constrained by the current scroll minimums and
    maximums. (If you wish to scroll outside of those bounds, you should call `scrollTo` directly.)

    If you only want to scroll in one direction, pass null or 0 for the other direction.

    @param {Number} x change in the x direction (or hash)
    @param {Number} y change in the y direction
    @returns {SC.ScrollView} receiver
  */
  scrollBy: function (x, y) {
    // Normalize (deprecated).
    if (y === undefined && SC.typeOf(x) === SC.T_HASH) {
      


      y = x.y;
      x = x.x;
    }

    // If null, undefined, or 0, pass null; otherwise just add current offset.
    x = (x) ? this.get('horizontalScrollOffset') + x : null;
    y = (y) ? this.get('verticalScrollOffset') + y : null;

    // Constrain within min and max. (Calls to scrollBy are generally convenience calls that should not have to
    // worry about exceeding bounds and making the followup call. Features that want to allow overscroll should call
    // scrollTo directly.)
    if (x !== null) {
      x = Math.min(Math.max(this.get('minimumHorizontalScrollOffset'), x), this.get('maximumHorizontalScrollOffset'));
    }

    if (y !== null) {
      y = Math.min(Math.max(this.get('minimumVerticalScrollOffset'), y), this.get('maximumVerticalScrollOffset'));
    }

    return this.scrollTo(x, y);
  },

  /**
    Scrolls the receiver down one or more lines if allowed.  If number of
    lines is not specified, scrolls one line.

    @param {Number} lines number of lines
    @returns {SC.ScrollView} receiver
  */
  scrollDownLine: function (lines) {
    if (lines === undefined) lines = 1;
    return this.scrollBy(null, this.get('verticalLineScroll') * lines);
  },

  /**
    Scrolls the receiver down one or more page if allowed.  If number of
    pages is not specified, scrolls one page.  The page size is determined by
    the verticalPageScroll value.  By default this is the size of the current
    scrollable area.

    @param {Number} pages number of lines
    @returns {SC.ScrollView} receiver
  */
  scrollDownPage: function (pages) {
    if (pages === undefined) pages = 1;
    return this.scrollBy(null, this.get('verticalPageScroll') * pages);
  },

  /**
    Scrolls the receiver left one or more lines if allowed.  If number of
    lines is not specified, scrolls one line.

    @param {Number} lines number of lines
    @returns {SC.ScrollView} receiver
  */
  scrollLeftLine: function (lines) {
    if (lines === undefined) lines = 1;
    return this.scrollTo(0 - this.get('horizontalLineScroll') * lines, null);
  },

  /**
    Scrolls the receiver left one or more page if allowed.  If number of
    pages is not specified, scrolls one page.  The page size is determined by
    the verticalPageScroll value.  By default this is the size of the current
    scrollable area.

    @param {Number} pages number of lines
    @returns {SC.ScrollView} receiver
  */
  scrollLeftPage: function (pages) {
    if (pages === undefined) pages = 1;
    return this.scrollBy(0 - (this.get('horizontalPageScroll') * pages), null);
  },

  /**
    Scrolls the receiver right one or more lines if allowed.  If number of
    lines is not specified, scrolls one line.

    @param {Number} lines number of lines
    @returns {SC.ScrollView} receiver
  */
  scrollRightLine: function (lines) {
    if (lines === undefined) lines = 1;
    return this.scrollTo(this.get('horizontalLineScroll') * lines, null);
  },

  /**
    Scrolls the receiver right one or more page if allowed.  If number of
    pages is not specified, scrolls one page.  The page size is determined by
    the verticalPageScroll value.  By default this is the size of the current
    scrollable area.

    @param {Number} pages number of lines
    @returns {SC.ScrollView} receiver
  */
  scrollRightPage: function (pages) {
    if (pages === undefined) pages = 1;
    return this.scrollBy(this.get('horizontalPageScroll') * pages, null);
  },

  /**
    Scrolls to the specified x,y coordinates.  This should be the offset into the contentView that
    you want to appear at the top-left corner of the scroll view.

    This method will contain the actual scroll based on whether the view can scroll in the named
    direction and the maximum distance it can scroll.

    If you only want to scroll in one direction, pass null for the other direction.

    @param {Number} x the x scroll location
    @param {Number} y the y scroll location
    @returns {SC.ScrollView} receiver
  */
  scrollTo: function (x, y) {
    // Normalize (deprecated).
    if (y === undefined && SC.typeOf(x) === SC.T_HASH) {
      


      y = x.y;
      x = x.x;
    }

    if (!SC.none(x)) {
      this.set('horizontalScrollOffset', x);
    }

    if (!SC.none(y)) {
      this.set('verticalScrollOffset', y);
    }

    return this;
  },

  /**
    Scroll to the supplied rectangle.

    If the rectangle is bigger than the viewport, the top-left
    will be preferred.

    (Note that if your content is scaled, the rectangle must be
    relative to the contentView's scale, not the ScrollView's.)

    @param {Rect} rect Rectangle to which to scroll.
    @returns {Boolean} YES if scroll position was changed.
  */
  scrollToRect: function (rect) {
    // find current visible frame.
    var vo = SC.cloneRect(this.get('containerView').get('frame')),
        origX = this.get('horizontalScrollOffset'),
        origY = this.get('verticalScrollOffset'),
        scale = this.get('scale');

    vo.x = origX;
    vo.y = origY;

    // Scale rect.
    if (scale !== 1) {
      rect = SC.cloneRect(rect);
      rect.x *= scale;
      rect.y *= scale;
      rect.height *= scale;
      rect.width *= scale;
    }

    // if bottom edge is not visible, shift origin
    vo.y += Math.max(0, SC.maxY(rect) - SC.maxY(vo));
    vo.x += Math.max(0, SC.maxX(rect) - SC.maxX(vo));

    // if top edge is not visible, shift origin
    vo.y -= Math.max(0, SC.minY(vo) - SC.minY(rect));
    vo.x -= Math.max(0, SC.minX(vo) - SC.minX(rect));

    // scroll to that origin.
    if ((origX !== vo.x) || (origY !== vo.y)) {
      this.scrollTo(vo.x, vo.y);
      return YES;
    } else {
      return NO;
    }
  },

  /**
    Scrolls the receiver up one or more lines if allowed.  If number of
    lines is not specified, scrolls one line.

    @param {Number} lines number of lines
    @returns {SC.ScrollView} receiver
  */
  scrollUpLine: function (lines) {
    if (lines === undefined) lines = 1;
    return this.scrollBy(null, 0 - this.get('verticalLineScroll') * lines);
  },

  /**
    Scrolls the receiver up one or more page if allowed.  If number of
    pages is not specified, scrolls one page.  The page size is determined by
    the verticalPageScroll value.  By default this is the size of the current
    scrollable area.

    @param {Number} pages number of lines
    @returns {SC.ScrollView} receiver
  */
  scrollUpPage: function (pages) {
    if (pages === undefined) pages = 1;
    return this.scrollBy(null, 0 - (this.get('verticalPageScroll') * pages));
  },

  /**
    Scroll the view to make the view's frame visible.  For this to make sense,
    the view should be a subview of the contentView.  Otherwise the results
    will be undefined.

    @param {SC.View} view view to scroll or null to scroll receiver visible
    @returns {Boolean} YES if scroll position was changed
  */
  scrollToVisible: function (view) {

    // if no view is passed, do default
    if (arguments.length === 0) return arguments.callee.base.apply(this,arguments);

    var contentView = this.get('contentView');
    if (!contentView) return NO; // nothing to do if no contentView.

    // get the frame for the view - should work even for views with static
    // layout, assuming it has been added to the screen.
    var viewFrame = view.get('borderFrame');
    if (!viewFrame) return NO; // nothing to do

    // convert view's frame to an offset from the contentView origin.  This
    // will become the new scroll offset after some adjustment.
    viewFrame = contentView.convertFrameFromView(viewFrame, view.get('parentView'));

    return this.scrollToRect(viewFrame);
  },

  /** @private SC.View */
  willDestroyLayer: function () {
    // Clean up.
    this.removeObserver('horizontalScrollOffset', this, this._sc_scrollOffsetHorizontalDidChange);
    this.removeObserver('verticalScrollOffset', this, this._sc_scrollOffsetVerticalDidChange);
    this.removeObserver('isHorizontalScrollerVisible', this, this._sc_repositionScrollers);
    this.removeObserver('isVerticalScrollerVisible', this, this._sc_repositionScrollers);

    this.removeObserver('scale', this, this._sc_scaleDidChange);

    var containerView = this.get('containerView');
    containerView.removeObserver('frame', this, this._sc_containerViewFrameDidChange);

    // Be sure to remove this view as a scrollable view for SC.Drag.
    this.removeObserver('isVisibleInWindow', this, this._sc_registerAutoscroll);
    this.removeObserver('isEnabledInPane', this, this._sc_registerAutoscroll);
    SC.Drag.removeScrollableView(this);
  },

  // ---------------------------------------------------------------------------------------------
  // Interaction
  //

  /** @private
    This method gives our descendent views a chance to capture the touch via captureTouch, and subsequently to handle the
    touch, via touchStart. If no view elects to do so, control is returned to the scroll view for standard scrolling.
  */
  _sc_beginTouchesInContent: function (touch) {
    // Clean up.
    this._sc_passTouchToContentTimer = null;

    // If the touch is not a scroll or scale, see if any of our descendent views want to handle the touch. If not,
    // we keep our existing respondership and all is well.
    if (!touch.captureTouch(this, true)) {
      touch.makeTouchResponder(touch.targetView, true, this);
    }
  },

  /** @private */
  _sc_touchEnded: function (touch, wasCancelled) {
    // When the last touch ends, we stop touch scrolling.
    var hasTouch = this.get('hasTouch');
    if (hasTouch) {
      // Update the average distance to center of the touch to include the new touch. This is used to recognize pinch/zoom movement of the touch.
      var avgTouch = touch.averagedTouchesForView(this);

      this._sc_gestureAnchorD = this._sc_gestureAnchorTotalD = avgTouch.d;
      this._sc_gestureAnchorX = this._sc_gestureAnchorTotalX = avgTouch.x;
      this._sc_gestureAnchorY = this._sc_gestureAnchorTotalY = avgTouch.y;

      if (this._sc_containerOffset) {
        this._sc_touchCenterX = avgTouch.x - this._sc_containerOffset.x;
        this._sc_touchCenterY = avgTouch.y - this._sc_containerOffset.y;
      }

    } else {

      // If we were scrolling, continue scrolling at present velocity with deceleration.
      if (this._sc_isTouchScrollingV || this._sc_isTouchScrollingH || this._sc_isTouchScaling) {
        var decelerationRate = this.get('decelerationRate'),
          containerHeight = this._sc_containerHeight,
          containerWidth = this._sc_containerWidth,
          durationH = 0,
          durationV = 0,
          c2x, c2y;

        if (this._sc_isTouchScrollingH) {
          var horizontalScrollOffset = this.get('horizontalScrollOffset'),
            maximumHorizontalScrollOffset = this.get('maximumHorizontalScrollOffset'),
            minimumHorizontalScrollOffset = this.get('minimumHorizontalScrollOffset'),
            horizontalVelocity = this._sc_touchVelocityH;

          // Past the maximum.
          if (horizontalScrollOffset > maximumHorizontalScrollOffset) {
            this.set('horizontalScrollOffset', maximumHorizontalScrollOffset);

            // Moving away from maximum. Change direction.
            if (horizontalVelocity < 0.2) {
              this._sc_animationTiming = this.get('animationCurveReverse');

            // Stopped or moving back towards maximum. Maintain direction, snap at the end.
            } else {
              this._sc_animationTiming = this.get('animationCurveSnap');
            }

            // 0.8 seconds for a full screen animation (most will be 50% or less of screen)
            durationH = 0.8 * (horizontalScrollOffset - maximumHorizontalScrollOffset) / containerWidth;

          // Bounce back from min.
          } else if (horizontalScrollOffset < minimumHorizontalScrollOffset) {
            this.set('horizontalScrollOffset', minimumHorizontalScrollOffset);

            // Moving away from minimum. Change direction.
            if (horizontalVelocity > 0.2) {
              this._sc_animationTiming = this.get('animationCurveReverse');

            // Stopped or moving back towards minimum. Maintain direction, snap at the end.
            } else {
              this._sc_animationTiming = this.get('animationCurveSnap');
            }

            // 0.8 seconds for a full screen animation (most will be 50% or less of screen)
            durationH = 0.8 * (minimumHorizontalScrollOffset - horizontalScrollOffset) / containerWidth;

          // Slide.
          } else {
            // Set the final position we should slide to as we decelerate based on last velocity.
            horizontalScrollOffset -= (Math.abs(horizontalVelocity) * horizontalVelocity * 1000) / (2 * decelerationRate);

            // Constrain within bounds.
            if (horizontalScrollOffset > maximumHorizontalScrollOffset) {
              // Generate an animation curve that bounces past the end point.
              c2x = (horizontalScrollOffset - maximumHorizontalScrollOffset) / containerWidth;
              c2y = 2 * c2x;
              this._sc_animationTiming = SC.easingCurve(0.0,0.5,c2x.toFixed(1),c2y.toFixed(1)); // 'cubic-bezier(0.0,0.5,%@,%@)'.fmt(c2x.toFixed(1), c2y.toFixed(1));

              horizontalScrollOffset = maximumHorizontalScrollOffset;

            } else if (horizontalScrollOffset < minimumHorizontalScrollOffset) {
              // Generate an animation curve that bounces past the end point.
              c2x = (minimumHorizontalScrollOffset - horizontalScrollOffset) / containerWidth;
              c2y = 2 * c2x;
              this._sc_animationTiming = SC.easingCurve(0.0,0.5,c2x.toFixed(1),c2y.toFixed(1)); // 'cubic-bezier(0.0,0.5,%@,%@)'.fmt(c2x.toFixed(1), c2y.toFixed(1));

              horizontalScrollOffset = minimumHorizontalScrollOffset;

            } else {
              this._sc_animationTiming = this.get('animationCurveDecelerate');
            }

            this.set('horizontalScrollOffset', horizontalScrollOffset);

            durationH = Math.abs(horizontalVelocity / decelerationRate);
          }
        }

        if (this._sc_isTouchScrollingV) {
          var verticalScrollOffset = this.get('verticalScrollOffset'),
            maximumVerticalScrollOffset = this.get('maximumVerticalScrollOffset'),
            minimumVerticalScrollOffset = this.get('minimumVerticalScrollOffset'),
            verticalVelocity = this._sc_touchVelocityV;

          // Past the maximum.
          if (verticalScrollOffset > maximumVerticalScrollOffset) {
            this.set('verticalScrollOffset', maximumVerticalScrollOffset);

            // Moving away from maximum. Change direction.
            if (verticalVelocity < 0.2) {
              this._sc_animationTiming = this.get('animationCurveReverse');

            // Stopped or moving back towards maximum. Maintain direction, snap at the end.
            } else {
              this._sc_animationTiming = this.get('animationCurveSnap');
            }

            // 0.8 seconds for a full screen animation (most will be 50% or less of screen)
            durationV = 0.8 * (verticalScrollOffset - maximumVerticalScrollOffset) / containerHeight;

          // Bounce back from min.
          } else if (verticalScrollOffset < minimumVerticalScrollOffset) {
            this.set('verticalScrollOffset', minimumVerticalScrollOffset);

            // Moving away from minimum. Change direction.
            if (verticalVelocity > 0.2) {
              this._sc_animationTiming = this.get('animationCurveReverse');

            // Stopped or moving back towards minimum. Maintain direction, snap at the end.
            } else {
              this._sc_animationTiming = this.get('animationCurveSnap');
            }

            // 0.8 seconds for a full screen animation (most will be 50% or less of screen)
            durationV = 0.8 * (minimumVerticalScrollOffset - verticalScrollOffset) / containerHeight;

          // Slide.
          } else {
            // Set the final position we should slide to as we decelerate based on last velocity.
            verticalScrollOffset -= (Math.abs(verticalVelocity) * verticalVelocity * 1000) / (2 * decelerationRate);

            // Constrain within bounds.
            if (verticalScrollOffset > maximumVerticalScrollOffset) {
              // Generate an animation curve that bounces past the end point.
              c2x = (verticalScrollOffset - maximumVerticalScrollOffset) / containerHeight;
              c2y = 2 * c2x;
              this._sc_animationTiming = SC.easingCurve(0.0, 0.5,c2x.toFixed(1), c2y.toFixed(1)); 'cubic-bezier(0.0,0.5,%@,%@)'.fmt(c2x.toFixed(1), c2y.toFixed(1));

              verticalScrollOffset = maximumVerticalScrollOffset;

            } else if (verticalScrollOffset < minimumVerticalScrollOffset) {
              // Generate an animation curve that bounces past the end point.
              c2x = (minimumVerticalScrollOffset - verticalScrollOffset) / containerHeight;
              c2y = 2 * c2x;
              this._sc_animationTiming = SC.easingCurve(0.0, 0.5,c2x.toFixed(1), c2y.toFixed(1)); 'cubic-bezier(0.0,0.5,%@,%@)'.fmt(c2x.toFixed(1), c2y.toFixed(1));

              verticalScrollOffset = minimumVerticalScrollOffset;

            } else {
              this._sc_animationTiming = this.get('animationCurveDecelerate');
            }

            this.set('verticalScrollOffset', verticalScrollOffset);

            durationV = Math.abs(verticalVelocity / decelerationRate);
          }
        }

        var scale = this.get('scale'),
          maximumScale = this.get('maximumScale'),
          minimumScale = this.get('minimumScale'),
          durationS = 0;

        // Bounce back from max.
        if (scale > maximumScale) {
          this.set('scale', maximumScale);
          durationS = 0.25;

        // Bounce back from min.
        } else if (scale < minimumScale) {
          this.set('scale', minimumScale);
          durationS = 0.25;

        // Slide.
        } else {

        }

        // Determine how long the deceleration should take (we can't animate left/top separately, so use the largest duration for both).
        // This variable also acts as a flag so that when the content view is repositioned, it will be animated.
        this._sc_animationDuration = Math.max(Math.max(durationH, durationV), durationS);

        // Clear up all caches from touchesDragged.
        this._sc_touchVelocityH = null;
        this._sc_touchVelocityV = null;

      // Pass the initial touch on to the content view if it hasn't tried yet (i.e. a tap) and the touch wasn't cancelled.
      } else if (this._sc_passTouchToContentTimer) {
        // Clean up.
        this._sc_passTouchToContentTimer.invalidate();
        this._sc_passTouchToContentTimer = null;

        if (!wasCancelled) {
          // If the content has handled the touch, then immediately end it.
          if (touch.makeTouchResponder(touch.targetView, true, this)) {
            touch.end();
          }
        }
      }

      // Clean up all caches from touchStart & touchesDragged
      this._sc_gestureAnchorX = this._sc_gestureAnchorY = this._sc_gestureAnchorD = null;
      this._sc_gestureAnchorTotalX = this._sc_gestureAnchorTotalY = this._sc_gestureAnchorTotalD = null;
      this._sc_gestureAnchorScale = null;
      this._sc_gestureAnchorHOffset = null;
      this._sc_gestureAnchorVOffset = null;
      this._sc_containerOffset = null;
      this._sc_touchCenterX = null;
      this._sc_touchCenterY = null;
    }

    // Force recalculation of scrolling and scaling.
    this._sc_isTouchScrollingH = false;
    this._sc_isTouchScrollingHOnly = false;
    this._sc_isTouchScrollingV = false;
    this._sc_isTouchScrollingVOnly = false;
    this._sc_isTouchScaling = false;

    // TODO: What happens when isEnabledInPane goes false while interacting? Statechart would help solve this.
    return true;
  },

  /** @private @see SC.RootResponder.prototype.captureTouch */
  captureTouch: function (touch) {
    // Capture the touch and begin determination of actual scroll or not.
    if (this.get('delaysContentTouches')) {
      return true;

    // Otherwise, suggest ourselves as a reasonable fallback responder. If none of our children capture
    // the touch or handle touchStart, we'll get another crack at it in touchStart.
    } else {
      touch.stackCandidateTouchResponder(this);

      return false;
    }
  },

  /** @private */
  mouseWheel: function (evt) {
    var handled = false,
      contentView = this.get('contentView');

    // Ignore it if not enabled.
    if (contentView && this.get('isEnabledInPane')) {

      var horizontalScrollOffset = this.get('horizontalScrollOffset'),
        minimumHorizontalScrollOffset = this.get('minimumHorizontalScrollOffset'),
        minimumVerticalScrollOffset = this.get('minimumVerticalScrollOffset'),
        maximumHorizontalScrollOffset = this.get('maximumHorizontalScrollOffset'),
        maximumVerticalScrollOffset = this.get('maximumVerticalScrollOffset'),
        verticalScrollOffset = this.get('verticalScrollOffset'),
        wheelDeltaX = evt.wheelDeltaX,
        wheelDeltaY = evt.wheelDeltaY;

      // If we can't scroll in one direction, limit that direction.
      if (!this.get('canScrollHorizontal')) { // Don't allow inverted scrolling for now.
        wheelDeltaX = 0;
      }

      if (!this.get('canScrollVertical')) { // Don't allow inverted scrolling for now.
        wheelDeltaY = 0;
      }

      // Only attempt to scroll if we are allowed to scroll in the direction and have room to scroll
      // in the direction. Otherwise, ignore the event so that an outer ScrollView may capture it.
      handled = ((wheelDeltaX < 0 && horizontalScrollOffset > minimumHorizontalScrollOffset) ||
                 (wheelDeltaX > 0 && horizontalScrollOffset < maximumHorizontalScrollOffset)) ||
                ((wheelDeltaY < 0 && verticalScrollOffset > minimumVerticalScrollOffset) ||
                  (wheelDeltaY > 0 && verticalScrollOffset < maximumVerticalScrollOffset));

      if (handled) {
        this.scrollBy(wheelDeltaX, wheelDeltaY);
      }
    }

    return handled;
  },

  /** @private */
  touchesDragged: function (evt, touchesForView) {
    var avgTouch = evt.averagedTouchesForView(this),
        canScale = this.get('canScale'),
        canScrollHorizontal = this.get('canScrollHorizontal'),
        canScrollVertical = this.get('canScrollVertical'),
        scrollThreshold = this.get('scrollGestureThreshold'),
        scaleThreshold = this.get('scaleGestureThreshold'),
        scrollLockThreshold = this.get('scrollLockGestureThreshold'),
        horizontalScrollOffset,
        verticalScrollOffset;


    // Determine if we've moved enough to claim horizontal or vertical scrolling.
    if (!(this._sc_isTouchScrollingH && this._sc_isTouchScrollingV) &&
      !this._sc_isTouchScrollingHOnly && !this._sc_isTouchScrollingVOnly) {

      if (canScrollHorizontal) {
        var totalAbsDeltaX = Math.abs(this._sc_gestureAnchorTotalX - avgTouch.x);

        if (!this._sc_isTouchScrollingH) {
          this._sc_isTouchScrollingH = totalAbsDeltaX >= scrollThreshold;

        // Determine if we've moved enough to lock scrolling to only this direction.
        } else {
          this._sc_isTouchScrollingHOnly = totalAbsDeltaX >= scrollLockThreshold;
        }
      }

      if (canScrollVertical) {
        var totalAbsDeltaY = Math.abs(this._sc_gestureAnchorTotalY - avgTouch.y);

        if (!this._sc_isTouchScrollingV) {
          this._sc_isTouchScrollingV = totalAbsDeltaY >= scrollThreshold;

        // Determine if we've moved enough to lock scrolling to only this direction.
        } else {
          this._sc_isTouchScrollingVOnly = totalAbsDeltaY >= scrollLockThreshold;
        }
      }
    }

    var touchDeltaX = this._sc_gestureAnchorX - avgTouch.x,
        absDeltaX = Math.abs(touchDeltaX);

    // Adjust scroll.
    if (canScrollHorizontal && absDeltaX >= 1 && !this._sc_isTouchScrollingVOnly) {
      // Record the last velocity.
      this._sc_touchVelocityH = avgTouch.velocityX;

      var minimumHorizontalScrollOffset = this.get('minimumHorizontalScrollOffset'),
        maximumHorizontalScrollOffset = this.get('maximumHorizontalScrollOffset');

      horizontalScrollOffset = this._sc_gestureAnchorHOffset + touchDeltaX;

      // Reset the anchor. Note: Do this before degrading the offset.
      this._sc_gestureAnchorX = avgTouch.x;
      this._sc_gestureAnchorHOffset = horizontalScrollOffset;

      // Degrade the offset as we pass maximum.
      if (horizontalScrollOffset > maximumHorizontalScrollOffset) {
        horizontalScrollOffset = horizontalScrollOffset - this._sc_overDragSlip * (horizontalScrollOffset - maximumHorizontalScrollOffset);

      // Degrade the offset as we pass minimum.
      } else if (horizontalScrollOffset < minimumHorizontalScrollOffset) {
        horizontalScrollOffset = horizontalScrollOffset + this._sc_overDragSlip * (minimumHorizontalScrollOffset - horizontalScrollOffset);
      }

      // Update the scroll offset.
      this.set('horizontalScrollOffset', horizontalScrollOffset);
    }

    var touchDeltaY = this._sc_gestureAnchorY - avgTouch.y,
        absDeltaY = Math.abs(touchDeltaY);

    if (canScrollVertical && absDeltaY > 0 && !this._sc_isTouchScrollingHOnly) {
      // Record the last velocity.
      this._sc_touchVelocityV = avgTouch.velocityY;

      var minimumVerticalScrollOffset = this.get('minimumVerticalScrollOffset'),
          maximumVerticalScrollOffset = this.get('maximumVerticalScrollOffset');

      verticalScrollOffset = this._sc_gestureAnchorVOffset + touchDeltaY;

      // Reset the anchor. Note: Do this before degrading the offset.
      this._sc_gestureAnchorY = avgTouch.y;
      this._sc_gestureAnchorVOffset = verticalScrollOffset;

      // Degrade the offset as we pass maximum.
      if (verticalScrollOffset > maximumVerticalScrollOffset) {
        verticalScrollOffset = verticalScrollOffset - this._sc_overDragSlip * (verticalScrollOffset - maximumVerticalScrollOffset);

      // Degrade the offset as we pass minimum.
      } else if (verticalScrollOffset < minimumVerticalScrollOffset) {
        verticalScrollOffset = verticalScrollOffset + this._sc_overDragSlip * (minimumVerticalScrollOffset - verticalScrollOffset);
      }

      // Update the scroll offset.
      this.set('verticalScrollOffset', verticalScrollOffset);
    }

    // Adjust scale.
    if (canScale) {

      // Determine if we've moved enough to claim scaling.
      if (!this._sc_isTouchScaling) {
        var totalAbsDeltaD = Math.abs(this._sc_gestureAnchorTotalD - avgTouch.d);
        this._sc_isTouchScaling = !!avgTouch.d && totalAbsDeltaD > scaleThreshold;
      }

      var touchDeltaD = this._sc_gestureAnchorD - avgTouch.d,
          absDeltaD = Math.abs(touchDeltaD);
      if (absDeltaD > 0) {
        // The percentage difference in touch distance.
        var scalePercentChange = avgTouch.d / this._sc_gestureAnchorD,
            scale = this._sc_gestureAnchorScale * scalePercentChange;

        // Adjust the center of the zoom to the center of the gesture.
        horizontalScrollOffset = this._sc_horizontalScrollOffset;
        verticalScrollOffset = this._sc_verticalScrollOffset;

        // Cache the current offset of the container view in the document. Calculated each time touch scaling begins.
        if (!this._sc_containerOffset) {
          var el = this.getPath('containerView.layer');

          this._sc_containerOffset = SC.offset(el);
          this._sc_touchCenterX = avgTouch.x - this._sc_containerOffset.x;
          this._sc_touchCenterY = avgTouch.y - this._sc_containerOffset.y;
        }

        // Compute the relative center of the scale gesture.
        this._sc_horizontalPct = (horizontalScrollOffset + this._sc_touchCenterX) / this._sc_contentWidth;
        this._sc_verticalPct = (verticalScrollOffset + this._sc_touchCenterY) / this._sc_contentHeight;

        this.set('scale', scale);

        // Reset the anchor.
        this._sc_gestureAnchorD = avgTouch.d;
        this._sc_gestureAnchorScale = scale;
      }
    }

    // No longer pass the initial touch on to the content view if it was still about to.
    if (this._sc_passTouchToContentTimer && (this._sc_isTouchScrollingV || this._sc_isTouchScrollingH || this._sc_isTouchScaling)) {
      this._sc_passTouchToContentTimer.invalidate();
      this._sc_passTouchToContentTimer = null;
    }

    // Note: If the content view has already accepted the initial touch, it will be sent a touchCancelled event.
  },

  /** @private
    If we're in hand-holding mode and our content claims the touch, we will receive a touchCancelled
    event at its completion. We still need to do most of our touch-ending wrap up, for example to finish
    bouncing back from a previous gesture.
  */
  touchCancelled: function (touch) {
    return this._sc_touchEnded(touch, true);
  },

  /** @private
    If we are the touch's responder at its completion, we'll get a touchEnd event. If this is the
    gesture's last touch, we wrap up in spectacular fashion.
  */
  touchEnd: function (touch) {
    return this._sc_touchEnded(touch, false);
  },

  // /** @private */
  touchStart: function (touch) {
    var handled = false,
      contentView = this.get('contentView');

    if (contentView && this.get('isEnabledInPane')) {
      var hasTouch = this.get('hasTouch');

      // Additional touches can be used for pinching gestures.
      if (hasTouch) {

        // If a new touch has appeared, force scrolling to recalculate.
        this._sc_isTouchScrollingV = this._sc_isTouchScrollingH = false;
        this._sc_isTouchScrollingHOnly = this._sc_isTouchScrollingHOnly = false;

        // No longer pass the initial touch on to the content view if it was still about to.
        if (this._sc_passTouchToContentTimer) {
          this._sc_passTouchToContentTimer.invalidate();
          this._sc_passTouchToContentTimer = null;
        }

      // The first touch is used to set up initial state.
      } else {
        // Cancel any active animation in place.
        this._sc_cancelAnimation();

        // If we have captured the touch and are not yet scrolling, we may want to delay a moment to test for
        // scrolling and if not scrolling, we will pass the touch through to the content.
        // If configured to do so, delay 150ms to verify that the user is not scrolling before passing touches through to the content.
        if (this.get('delaysContentTouches')) {
          this._sc_passTouchToContentTimer = this.invokeLater(this._sc_beginTouchesInContent, 150, touch);
        } // Else do nothing.
      }

      // Update the average distance to center of the touch, which is used to recognize pinch/zoom movement of the touch.
      var avgTouch = touch.averagedTouchesForView(this, true);

      /* A note on these variables:

        _sc_gestureAnchorX: the last x position (so that we don't update horizontal scroll if the change since last is 0)
        _sc_gestureAnchorTotalX: the initial x position (so that we can determine whether to take total control of touches and possibly lock the position)
      */
      this._sc_gestureAnchorX = this._sc_gestureAnchorTotalX = avgTouch.x;
      this._sc_gestureAnchorY = this._sc_gestureAnchorTotalY = avgTouch.y;
      this._sc_gestureAnchorD = this._sc_gestureAnchorTotalD = avgTouch.d;
      this._sc_gestureAnchorScale = this.get('scale');
      this._sc_gestureAnchorHOffset = this.get('horizontalScrollOffset');
      this._sc_gestureAnchorVOffset = this.get('verticalScrollOffset');

      handled = true;
    }

    return handled;
  }

});


SC.ScrollView.mixin(
/** @scope SC.ScrollView */ {

  /** @private Shared object used to avoid continually initializing/destroying objects. */
  _SC_CONTAINER_LAYOUT_MAP: null,

  /** @private Shared object used to avoid continually initializing/destroying objects. */
  _SC_CONTENT_ADJUST_MAP: null

});

/* >>>>>>>>>> BEGIN source/views/menu_scroll.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
sc_require('views/scroll_view');


/** @class

  Implements a scroll view for menus.  This class extends SC.ScrollView for
  menus.

  The main difference with SC.ScrollView is that there is only vertical
  scrolling. Value Syncing between SC.MenuScrollView and SC.MenuScrollerView
  is done using valueBinding.

  @extends SC.ScrollView
  @since SproutCore 1.0
*/
SC.MenuScrollView = SC.ScrollView.extend(
/** @scope SC.MenuScrollView.prototype */{

  // ---------------------------------------------------------------------------------------------
  // Properties
  //

  /**
    The bottom scroller view class. This will be replaced with a view instance when the
    MenuScrollView is created unless hasVerticalScroller is false.

    @type SC.View
    @default SC.MenuScrollerView
  */
  bottomScrollerView: SC.MenuScrollerView,

  /**
    Returns true if the view has both a vertical scroller and the scroller is visible.

    @field
    @type Boolean
    @readonly
    @see SC.ScrollView
  */
  canScrollVertical: function () {
    return !!(this.get('hasVerticalScroller') && // This property isn't bindable.
      this.get('bottomScrollerView') && // This property isn't bindable.
      this.get('topScrollerView') && // This property isn't bindable.
      this.get('isVerticalScrollerVisible'));
  }.property('isVerticalScrollerVisible').cacheable(),

  /** SC.View.prototype
    @type Array
    @default ['sc-menu-scroll-view']
    @see SC.View#classNames
  */
  classNames: ['sc-menu-scroll-view'],

  /**
    Control Size for Menu content: change verticalLineScroll

    @type String
    @default SC.REGULAR_CONTROL_SIZE
    @see SC.Control
  */
  controlSize: SC.REGULAR_CONTROL_SIZE,

  /**
    YES if the view should maintain a horizontal scroller. This property must be set when the view
    is created.

    @type Boolean
    @default false
    @see SC.ScrollView
  */
  hasHorizontalScroller: false,

  /**
    The top scroller view class. This will be replaced with a view instance when the MenuScrollView
    is created unless hasVerticalScroller is false.

    @type SC.View
    @default SC.MenuScrollerView
  */
  topScrollerView: SC.MenuScrollerView,

  // ---------------------------------------------------------------------------------------------
  // Methods
  //

  /** @private @see SC.ScrollView. Check frame changes for size changes. */
  _sc_contentViewFrameDidChange: function () {
    arguments.callee.base.apply(this,arguments);

    // Unlike a normal SC.ScrollView, the visibility of the top & bottom scrollers changes as the
    // scrolling commences. For example, once the user scrolls a tiny bit, we need to show the
    // top scroller.
    this._sc_repositionScrollers();
  },

  /** @private @see SC.ScrollView. When the content view's size changes, we need to update our scroll offset properties. */
  _sc_repositionContentViewUnfiltered: function () {
    var hasVerticalScroller = this.get('hasVerticalScroller'),
        // UNUSED. minimumVerticalScrollOffset = this.get('minimumVerticalScrollOffset'),
        maximumVerticalScrollOffset = this.get('maximumVerticalScrollOffset');

    if (hasVerticalScroller) {
      var bottomScrollerView = this.get('bottomScrollerView'),
          topScrollerView = this.get('topScrollerView');

      topScrollerView.set('maximum', maximumVerticalScrollOffset);
      bottomScrollerView.set('maximum', maximumVerticalScrollOffset);

      // Update if the visibility of the scrollers has changed now.
      var containerHeight = this._sc_containerHeight,
          contentHeight = this._sc_contentHeight;

      if (this.get('autohidesVerticalScroller')) {
        this.setIfChanged('isVerticalScrollerVisible', contentHeight > containerHeight);
      }
    }

    arguments.callee.base.apply(this,arguments);
  },

  /** @private @see SC.ScrollView. Re-position the scrollers and content depending on the need to scroll or not. */
  _sc_repositionScrollersUnfiltered: function () {
    var hasScroller = this.get('hasVerticalScroller'),
        containerView = this.get('containerView');

    if (hasScroller && this.get('autohidesVerticalScroller')) {
      var bottomScrollerView = this.get('bottomScrollerView'),
          bottomScrollerThickness = bottomScrollerView.get('scrollerThickness'),
          maximumVerticalScrollOffset = this.get('maximumVerticalScrollOffset'),
          topScrollerView = this.get('topScrollerView'),
          topScrollerThickness = topScrollerView.get('scrollerThickness'),
          verticalOffset = this.get('verticalScrollOffset'),
          isBottomScrollerVisible = bottomScrollerView.get('isVisible'),
          isTopScrollerVisible = topScrollerView.get('isVisible');

      // This asymetric update moves the container view out of the way of the scrollers (essentially
      // so that the scroller views can be transparent). What's important is that as the container
      // view is adjusted, the vertical scroll offset is adjusted properly so that the content view
      // position doesn't jump around.
      if (isTopScrollerVisible) {
        if (verticalOffset <= topScrollerThickness) {
          topScrollerView.set('isVisible', false);
          containerView.adjust('top', 0);
          this.decrementProperty('verticalScrollOffset', topScrollerThickness);
        }
      } else if (verticalOffset > 0) {
        topScrollerView.set('isVisible', true);
        containerView.adjust('top', topScrollerThickness);
        this.incrementProperty('verticalScrollOffset', topScrollerThickness);
      }

      if (isBottomScrollerVisible) {
        if (verticalOffset >= maximumVerticalScrollOffset - bottomScrollerThickness) {
          bottomScrollerView.set('isVisible', false);
          containerView.adjust('bottom', 0);
          this.incrementProperty('verticalScrollOffset', bottomScrollerThickness);
        }
      } else if (verticalOffset < maximumVerticalScrollOffset) {
        bottomScrollerView.set('isVisible', true);
        containerView.adjust('bottom', bottomScrollerThickness);
        this.decrementProperty('verticalScrollOffset', bottomScrollerThickness);
      }
    }
  },

  /** @private
    Instantiate scrollers & container views as needed.  Replace their classes
    in the regular properties.
  */
  createChildViews: function () {
    var childViews = [],
      autohidesVerticalScroller = this.get('autohidesVerticalScroller');

    // Set up the container view.
    var containerView = this.get('containerView');

    


    containerView = this.containerView = this.createChildView(containerView, {
      contentView: this.contentView // Initialize the view with the currently set container view.
    });
    this.contentView = containerView.get('contentView'); // Replace our content view with the instantiated version.
    childViews.push(containerView);

    // Set up the scrollers.
    if (!this.get('hasVerticalScroller')) {
      // Remove the class entirely.
      this.topScrollerView = null;
      this.bottomScrollerView = null;
    } else {
      var controlSize = this.get('controlSize'),
          topScrollerView = this.get('topScrollerView');

      // Use a default scroller view.
      /* jshint eqnull:true */
      if (topScrollerView == null) {
        topScrollerView = SC.MenuScrollerView;
      }

      // Replace the class property with an instance.
      topScrollerView = this.topScrollerView = this.createChildView(topScrollerView, {
        controlSize: controlSize,
        scrollDown: false,
        isVisible: !autohidesVerticalScroller,
        layout: { height: 0 },

        value: this.get('verticalScrollOffset'),
        valueBinding: '.parentView.verticalScrollOffset', // Bind the value of the scroller to our vertical offset.
        minimum: this.get('minimumVerticalScrollOffset'),
        maximum: this.get('maximumVerticalScrollOffset')
      });

      var topScrollerThickness = topScrollerView.get('scrollerThickness');
      topScrollerView.adjust('height', topScrollerThickness);

      // Add the scroller view to the child views array.
      childViews.push(topScrollerView);


      var bottomScrollerView = this.get('bottomScrollerView');

      // Use a default scroller view.
      /* jshint eqnull:true */
      if (bottomScrollerView == null) {
        bottomScrollerView = SC.MenuScrollerView;
      }

      // Replace the class property with an instance.
      bottomScrollerView = this.bottomScrollerView = this.createChildView(bottomScrollerView, {
        controlSize: controlSize,
        scrollDown: true,
        isVisible: !autohidesVerticalScroller,
        layout: { bottom: 0, height: 0 },

        value: this.get('verticalScrollOffset'),
        valueBinding: '.parentView.verticalScrollOffset', // Bind the value of the scroller to our vertical offset.
        minimum: this.get('minimumVerticalScrollOffset'),
        maximum: this.get('maximumVerticalScrollOffset')
      });

      var bottomScrollerThickness = bottomScrollerView.get('scrollerThickness');
      bottomScrollerView.adjust('height', bottomScrollerThickness);

      // Add the scroller view to the child views array.
      childViews.push(bottomScrollerView);

      // If the scrollers aren't initially hidden, adjust the container.
      if (!autohidesVerticalScroller) {
        containerView.adjust('top', topScrollerThickness);
        containerView.adjust('bottom', bottomScrollerThickness);
      }
    }

    // Set the childViews array.
    this.childViews = childViews;
  }

});

/* >>>>>>>>>> BEGIN source/views/menu_scroller_view.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
sc_require('views/scroller');

/** @class

  Implements a complete scroller view for menus.  This class implements the
  arrows displayed in a menu to scroll.

  The main difference with SC.ScrollerView is that there is only vertical
  scrollers. Value Syncing between SC.MenuScrollView and SC.MenuScrollerView
  is done using valueBinding.

  @extends SC.ScrollerView
  @since SproutCore 1.0
*/
SC.MenuScrollerView = SC.ScrollerView.extend(
/** @scope SC.MenuScrollerView.prototype */ {

  // ---------------------------------------------------------------------------------------------
  // Properties
  //

  /**
    @type Array
    @default ['sc-menu-scroller-view']
    @see SC.View#classNames
  */
  classNames: ['sc-menu-scroller-view'],

  /**
    Used to set the scrolling direction of the scroller.

    @type Boolean
    @default false
  */
  scrollDown: false,

  /**
     Amount to scroll one vertical line.

     @type Number
     @default 20
  */
  verticalLineScroll: 20,


  // ..........................................................
  // INTERNAL SUPPORT
  //

  /** @private */
  init: function () {
    // Set the scrollerThickness based on controlSize
    switch (this.get('controlSize')) {
    case SC.TINY_CONTROL_SIZE:
      this.set('scrollerThickness', SC.MenuScrollerView.TINY_SCROLLER_THICKNESS);
      break;
    case SC.SMALL_CONTROL_SIZE:
      this.set('scrollerThickness', SC.MenuScrollerView.SMALL_SCROLLER_THICKNESS);
      break;
    case SC.REGULAR_CONTROL_SIZE:
      this.set('scrollerThickness', SC.MenuScrollerView.REGULAR_SCROLLER_THICKNESS);
      break;
    case SC.LARGE_CONTROL_SIZE:
      this.set('scrollerThickness', SC.MenuScrollerView.LARGE_SCROLLER_THICKNESS);
      break;
    case SC.HUGE_CONTROL_SIZE:
      this.set('scrollerThickness', SC.MenuScrollerView.HUGE_SCROLLER_THICKNESS);
      break;
    }

    return arguments.callee.base.apply(this,arguments);
  },

  /** @private */
  render: function (context, firstTime) {
    context.addClass('sc-vertical');
    context.addClass(this.get('controlSize'));
    if (firstTime) {
      var direction = this.get('scrollDown') ? 'arrowDown' : 'arrowUp';
      context.push('<span class="scrollArrow ' + direction + '">&nbsp;</span>');
    }
  },

  /** @private */
  mouseEntered: function (evt) {
    this.set('isMouseOver', YES);
    this._invokeScrollOnMouseOver();
  },

  /** @private */
  mouseExited: function (evt) {
    this.set('isMouseOver', NO);
  },

  /** @private
    Scroll the menu if it is is an up or down arrow. This is called by
    the function that simulates mouseOver.
  */
  _scrollMenu: function () {
    var value = this.get('value');

    if (this.get('scrollDown')) {
      value = value + this.verticalLineScroll;
      value = Math.min(value, this.get('maximum'));
    } else {
      value = value - this.verticalLineScroll;
      value = Math.max(value, this.get('minimum'));
    }

    this.set('value', value);

    return YES;
  },

  /** @private

    We use this function to simulate mouseOver. It checks for the flag
    isMouseOver which is turned on when mouseEntered is called and turned off
    when mouseExited is called.
  */
  _invokeScrollOnMouseOver: function () {
    this._scrollMenu();
    if (this.get('isMouseOver')) {
      this.invokeLater(this._invokeScrollOnMouseOver, 50);
    }
  }

});


/**
  @static
  @type Number
  @default 18
*/
SC.MenuScrollerView.REGULAR_SCROLLER_THICKNESS = 18;

/**
  @static
  @type Number
  @default 10
*/
SC.MenuScrollerView.TINY_SCROLLER_THICKNESS    = 10;

/**
  @static
  @type Number
  @default 14
*/
SC.MenuScrollerView.SMALL_SCROLLER_THICKNESS   = 14;

/**
  @static
  @type Number
  @default 23
*/
SC.MenuScrollerView.LARGE_SCROLLER_THICKNESS   = 23;

/**
  @static
  @type Number
  @default 26
*/
SC.MenuScrollerView.HUGE_SCROLLER_THICKNESS    = 26;

/* >>>>>>>>>> BEGIN source/views/navigation.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require("views/workspace");

/**
  @static
  @type String
  @constant
*/
SC.TO_LEFT = "TOLEFT";

/**
  @static
  @type String
  @constant
*/
SC.TO_RIGHT = "TORIGHT";


/** @class

  NavigationView is very loosely based on UINavigationController:
  that is, it implements a push/pop based API. 
  
  NavigationView checks if the view is NavigationBuildable--that is, if it has 
  
  Views may specify a topToolbar or bottomToolbar property. These will become the
  top or bottom toolbars of the NavigationView (which is, incidentally, a WorkspaceView).
  
  Of course, this process is animated...
  
  @author Alex Iskander
  @extends SC.WorkspaceView
  @since SproutCore 1.4
*/
SC.NavigationView = SC.WorkspaceView.extend(
/** @scope SC.NavigationView.prototype */ {
  
  /** @private */
  _views: null,
  
  /** @private */
  _current: null,
  
  /**
    @type SC.View
    @default SC.View
  */
  navigationContentView: SC.View,
  
  /** @private */
  init: function() {
    arguments.callee.base.apply(this,arguments);
    this._views = [];
  },
  
  /** @private */
  createChildViews: function() {
    arguments.callee.base.apply(this,arguments);
    
    // get the content
    var content = this.get("navigationContentView");
    
    // instantiate if needed
    if (content.isClass) content = this.createChildView(content);
    
    // set internal values
    this._defaultContent = this.navigationContentView = content;
    
    // append to the content view
    this.contentView.appendChild(content);
  },
  
  /** @private */
  changeNavigationContent: function(view) {
    var top = null, bottom = null;
    
    // find top and bottom toolbars if we are setting it to a view
    if (view) {
      top = view.get("topToolbar"); 
      bottom = view.get("bottomToolbar");
    }
    
    // instantiate top if needed
    if (top && top.isClass) {
      view.set("topToolbar", top = top.create());
    }
    
    // and now bottom
    if (bottom && bottom.isClass) {
      view.set("bottomToolbar", bottom = bottom.create());
    }
    
    
    // batch property changes for efficiency
    this.beginPropertyChanges();
    
    // update current, etc. etc.
    this._current = view;
    this.set("navigationContentView", view ? view : this._defaultContent);
    
    // set the top/bottom appropriately
    this.set("topToolbar", top);
    this.set("bottomToolbar", bottom);
    
    // and we are done
    this.endPropertyChanges();
  },
  
  /**
    Pushes a view into the navigation view stack. The view may have topToolbar and bottomToolbar properties.
    
    @param {SC.View} view The view to display
  */
  push: function(view) {
    this._currentDirection = this._current ? SC.TO_LEFT : null;
    
    // add current view to the stack (if needed)
    if (this._current) this._views.push(this._current);
    
    // update content now...
    this.changeNavigationContent(view);
  },
  
  /**
    Pops the current view off the navigation view stack.
  */
  pop: function() {
    this._currentDirection = SC.TO_RIGHT;
    
    // pop the view
    var view = this._views.pop();
    
    // set new (old) content view
    this.changeNavigationContent(view);
  },
  
  /**
    Pops to the specified view on the navigation view stack; the view you pass will become the current view.
    
    @param {SC.View} toView The view to display
  */
  popToView: function(toView) {
    this._currentDirection = SC.TO_RIGHT;
    var views = this._views,
        idx = views.length - 1, 
        view = views[idx];
    
    // loop back from end
    while (view && view !== toView) {
      this._views.pop();
      idx--;
      view = views[idx];
    }
    
    // and change the content
    this.changeNavigationContent(view);
  },
  
  /** @private */
  topToolbarDidChange: function() {
    var active = this.activeTopToolbar, replacement = this.get("topToolbar");
    
    // if we have an active toolbar, set the build direction and build out
    if (active) {
      if (this._currentDirection !== null) {
        active.set("buildDirection", this._currentDirection);
        this.buildOutChild(active);
      } else {
        this.removeChild(active);
      }
    }
    
    // if we have a new toolbar, set the build direction and build in
    if (replacement) {
      if (this._currentDirection !== null) {
        replacement.set("buildDirection", this._currentDirection);
        this.buildInChild(replacement);
      } else {
        this.appendChild(replacement);
      }
    }
    
    // update, and queue retiling
    this.activeTopToolbar = replacement;
    this.invokeOnce("childDidChange");
  }.observes("topToolbar"),
  
  /** @private */
  bottomToolbarDidChange: function() {
    var active = this.activeBottomToolbar, replacement = this.get("bottomToolbar");
    
    if (active) {
      if (this._currentDirection !== null) {
        active.set("buildDirection", this._currentDirection);
        this.buildOutChild(active);
      } else {
        this.removeChild(active);
      }
    }
    if (replacement) {
      if (this._currentDirection !== null) {
        replacement.set("buildDirection", this._currentDirection);
        this.buildInChild(replacement);
      } else {
        this.appendChild(replacement);
      }
    }
    
    this.activeBottomToolbar = replacement;
    this.invokeOnce("childDidChange");
  }.observes("topToolbar"),
  
  /** @private */
  contentViewDidChange: function() {
    var active = this.activeNavigationContentView, replacement = this.get("navigationContentView");
    
    // mix in navigationbuilder if needed
    if (!replacement.isNavigationBuilder) {
      replacement.mixin(SC.NavigationBuilder);
    }
    
    // tiling really needs to happen _before_ animation
    // so, we set "pending" and queue tiling.
    this._pendingBuildOut = active;
    this._pendingBuildIn = replacement;
    
    this.activeNavigationContentView = replacement;
    this.invokeOnce("childDidChange");
  }.observes("navigationContentView"),
  
  /** @private */
  childDidChange: function() {
    var replacement = this._pendingBuildIn, active = this._pendingBuildOut;
    if (active) {
      if (this._currentDirection !== null) {
        active.set("buildDirection", this._currentDirection);
        this.contentView.buildOutChild(active);
      } else {
        this.contentView.removeChild(active);
      }
    }

    this._scws_tile();
    
    if (replacement) {
      if (this._currentDirection !== null) {
        replacement.set("buildDirection", this._currentDirection);
        this.contentView.buildInChild(replacement);
      } else {
        this.contentView.appendChild(replacement);
      }
    }
  }
  
});

/* >>>>>>>>>> BEGIN source/views/navigation_bar.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require("views/toolbar");

/** @class
  NavigationBars do Great Things. They transition themselves (fade in/out) and
  all children (swoosh left/right). They accept isSwipeLeft and isSwipeRight views
  that handle, well, swiping. In short, they are neat.
  
  @extends SC.ToolbarView
  @extends SC.Gesturable
  @since SproutCore 1.0
*/
SC.NavigationBarView = SC.ToolbarView.extend(SC.Gesturable,
/** @scope SC.NavigationBarView.prototype */{

  /** @private */
  init: function() {
    arguments.callee.base.apply(this,arguments);
    
    if (!SC.Animatable) {
      SC.Logger.error(
        "NavigationBarView requires SC.Animatable. " +
        "Please make your app or framework require the animation framework. CRASH."
      );
    }
  },

  /** @private */
  mixinAnimatable: function() {
    this.mixin(SC.Animatable);
    this.transitions = this.navigationTransitions;
  },
  
  /**
    The default navigation transitions.
  */
  navigationTransitions: { 
    opacity: {
      duration: 0.25, action: "didFinishTransition"
    } 
  },
  
  /**
    The default style (opacity is 1)
  */
  style: {
    opacity: 1
  },
  

  // ..........................................................
  // Gesture Support
  // 
  
  /** @private */
  gestures: ["swipeGesture"],
  
  /** @private */
  swipeGesture: SC.SwipeGesture,

  /** @private */
  swipe: function(gesture, touch, direction) {
    var lookingFor = (direction === SC.SWIPE_LEFT) ? "isSwipeLeft" : "isSwipeRight",
        cv = this.get("childViews"), 
        child, idx, len = cv.get("length");
    
    // loop through the children
    for (idx = 0; idx < len; idx++) {
      child = cv[idx];
      
      // see if this is the view we are looking for
      if (child.get(lookingFor)) {
        // just give it touch responder and end right away, just like ScrollView. Good times, eh?
        touch.makeTouchResponder(child);
        touch.end();
        return;
      }
    }
    
  },
  
  
  // ..........................................................
  // View Build Support
  // 
  
  /** @private */
  resetBuild: function() {
    if (!this.isAnimatable) this.mixinAnimatable();
  },
  
  /** @private */
  didFinishTransition: function() {
    if (this.isBuildingIn) {
      // and please continue
      this.buildInDidFinish();
    } else if (this.isBuildingOut) this.buildOutDidFinish();
  },
  
  /** @private */
  preBuildIn: function() {
    // first, fade this view out
    this.disableAnimation();
    this.adjust("opacity", 0).updateLayout();
    this.enableAnimation();
    
    // now, loop over child views
    var cv = this.get("childViews"), child, idx, len = cv.get("length");
    for (idx = 0; idx < len; idx++) {
      child = cv[idx];
      
      // if the child disables navigation transitions, skip
      if (child.disableNavigationTransition) continue;
      
      // make sure the navigation stuff is mixed in as needed
      if (!child._nv_mixedIn) this.mixinNavigationChild(child);
      
      // now, set the initial state, which is either to the left or to the right 100px.
      child.disableAnimation();
      child.transform(this.buildDirection === SC.TO_LEFT ? 100  : -100);
      child.enableAnimation();
    }
  },
  
  /** @private */
  buildIn: function() {
    // first, we do the precursor
    this.preBuildIn();
    
    // then, we queue the actual animation
    this.invokeLater("startBuildIn", 10);
  },
  
  /** @private */
  startBuildIn: function() {
    this.adjust("opacity", 1);

    // get our frame, because we use it when computing child frames.
    var cv = this.get("childViews"), child, idx, len = cv.get("length");
    for (idx = 0; idx < len; idx++) {
      child = cv[idx];
      if (child.disableNavigationTransition) continue;
      child.transform(0);
    }
  },

  /** @private */
  buildOut: function() {
    this.adjust("opacity", 0);
    
    var cv = this.get("childViews"), child, idx, len = cv.get("length");
    for (idx = 0; idx < len; idx++) {
      child = cv[idx];
      if (child.disableNavigationTransition) continue;
      if (!child._nv_mixedIn) this.mixinNavigationChild(child);
      child.transform(this.buildDirection === SC.TO_LEFT ? -100  : 100);
    }
  },
  
  /** @private */
  mixinNavigationChild: function(child) {
    if (child.isAnimatable) return;
    
    // mix in animatable
    child.mixin(SC.Animatable);
    
    // mix in the transitions (and the "natural" layout)
    child.mixin({
      transitions: {
        transform: {timing: SC.Animatable.TRANSITION_EASE_IN_OUT, duration: 0.25}
      },
      naturalLayout: child.get("layout"),
      transform: function(pos) {
        if (SC.platform.supportsCSS3DTransforms) {
          this.adjust("transform", "translate3d(" + pos + "px,0px,0px)");
        } else {
          this.adjust("transform", "translate(" + pos + "px,0px)");          
        }
      }
    });
    
    // and mark as having mixed in.
    child._nv_mixedIn = YES;
  }
});
/* >>>>>>>>>> BEGIN source/views/popup_button.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('views/button');

/** @class

  SC.PopupButtonView displays a pop-up menu when clicked, from which the user
  can select an item.

  To use, create the SC.PopupButtonView as you would a standard SC.ButtonView,
  then set the menu property to an instance of SC.MenuPane. For example:

      SC.PopupButtonView.design({
        layout: { width: 200, height: 18 },
        menuBinding: 'MyApp.menuController.menuPane'
      });

  You would then have your MyApp.menuController return an instance of the menu
  to display.

  @extends SC.ButtonView
  @author Santosh Shanbhogue
  @author Tom Dale
  @copyright 2008-2011, Strobe Inc. and contributors.
  @version 1.0
*/
SC.PopupButtonView = SC.ButtonView.extend(
/** @scope SC.PopupButtonView.prototype */ {

  /**
    @type Array
    @default ['sc-popup-button']
    @see SC.View#classNames
  */
  classNames: ['sc-popup-button'],

  /**
    @type String
    @default 'popupButtonRenderDelegate'
  */
  renderDelegateName: 'popupButtonRenderDelegate',


  // ..........................................................
  // PROPERTIES
  //

  /**
    The prefer matrix to use when displaying the menu.

    @property
  */
  preferMatrix: null,

  /**
    The SC.MenuPane that should be displayed when the button is clicked.

    @type {SC.MenuPane}
    @default null
  */
  menu: null,

  /**
    If YES and the menu is a class, this will cause a task that will instantiate the menu
    to be added to SC.backgroundTaskQueue.

    @type Boolean
    @default NO
  */
  shouldLoadInBackground: NO,

  // ..........................................................
  // INTERNAL SUPPORT
  //

  /** @private
    If necessary, adds the loading of the menu to the background task queue.
  */
  init: function() {
    arguments.callee.base.apply(this,arguments);
    this._setupMenu();
    if (this.get('shouldLoadInBackground')) {
      SC.backgroundTaskQueue.push(SC.PopupButtonMenuLoader.create({ popupButton: this }));
    }
  },

  /** @private
    Sets up binding on the menu, removing any old ones if necessary.
  */
  _setupMenu: function() {
    var menu = this.get('instantiatedMenu');

    // clear existing bindings
    if (this.isActiveBinding) this.isActiveBinding.disconnect();
    this.isActiveBinding = null;

    // if there is a menu
    if (menu && !menu.isClass) {
      this.isActiveBinding = this.bind('isActive', menu, 'isVisibleInWindow');
    }
  },

  /** @private
    Setup the bindings for menu...
  */
  _popup_menuDidChange: function() {
    this._setupMenu();
  }.observes('menu'),

  /** @private
    isActive is NO, but when the menu is instantiated, it is bound to the menu's isVisibleInWindow property.
  */
  isActive: NO,

  /** @private
    Instantiates the menu if it is not already instantiated.
  */
  _instantiateMenu: function() {
    // get menu
    var menu = this.get('menu');

    // if it is already instantiated or does not exist, we cannot do anything
    if (!menu || !menu.isClass) return;

    // create
    this.menu = menu.create();

    // setup
    this._setupMenu();
  },

  /** @private
    The guaranteed-instantiated menu.
  */
  instantiatedMenu: function() {
    // get the menu
    var menu = this.get('menu');

    // if it is a class, we need to instantiate it
    if (menu && menu.isClass) {
      // do so
      this._instantiateMenu();

      // get the new version of the local
      menu = this.get('menu');
    }

    // return
    return menu;
  }.property('menu').cacheable(),

  /** @private
    Displays the menu.

    @param {SC.Event} evt
  */
  action: function(evt) {
    var menu = this.get('instantiatedMenu') ;

    if (!menu) {
      

      return NO ;
    }

    menu.popup(this, this.get('preferMatrix')) ;
    return YES;
  },

  /** @private
    On mouse down, we set the state of the button, save some state for further
    processing, then call the button's action method.

    @param {SC.Event} evt
    @returns {Boolean}
  */
  mouseDown: function(evt) {
    // Fast path, reject secondary clicks.
    if (evt.which && evt.which !== 1) return false;

    // If disabled, handle mouse down but ignore it.
    if (!this.get('isEnabledInPane')) return YES ;

    this._isMouseDown = YES;

    this._action() ;

    // Store the current timestamp. We register the timestamp after a setTimeout
    // so that the menu has been rendered, in case that operation
    // takes more than a few hundred milliseconds.

    // One mouseUp, we'll use this value to determine how long the mouse was
    // pressed.

    // we need to keep track that we opened it just now in case we get the
    // mouseUp before render finishes. If it is 0, then we know we have not
    // waited long enough.
    this._menuRenderedTimestamp = 0;

    var self = this;

    // setTimeout guarantees that all rendering is done. The browser will even
    // have rendered by this point.
    setTimeout(function() {
      SC.run(function(){
        // a run loop might be overkill here but what if Date.now fails?
        self._menuRenderedTimestamp = Date.now();
      });
    }, 1);

    this.becomeFirstResponder();

    return YES ;
  },

  /** @private
    Because we responded YES to the mouseDown event, we have responsibility
    for handling the corresponding mouseUp event.

    However, the user may click on this button, then drag the mouse down to a
    menu item, and release the mouse over the menu item. We therefore need to
    delegate any mouseUp events to the menu's menu item, if one is selected.

    We also need to differentiate between a single click and a click and hold.
    If the user clicks and holds, we want to close the menu when they release.
    Otherwise, we should wait until they click on the menu's modal pane before
    removing our active state.

    @param {SC.Event} evt
    @returns {Boolean}
  */
  mouseUp: function(evt) {
    var timestamp = new Date().getTime(),
        previousTimestamp = this._menuRenderedTimestamp,
        menu = this.get('instantiatedMenu'),
        touch = SC.platform.touch,
        targetMenuItem;

    // normalize the previousTimestamp: if it is 0, it might as well be now.
    // 0 means that we have not even triggered the nearly-immediate saving of timestamp.
    if (previousTimestamp === 0) previousTimestamp = Date.now();

    if (menu) {
      // Get the menu item the user is currently hovering their mouse over
      targetMenuItem = menu.getPath('rootMenu.targetMenuItem');

      if (targetMenuItem) {
        // Have the menu item perform its action.
        // If the menu returns NO, it had no action to
        // perform, so we should close the menu immediately.
        if (!targetMenuItem.performAction()) menu.remove();
      } else {
        // If the user waits more than certain amount of time between
        // mouseDown and mouseUp, we can assume that they are clicking and
        // dragging to the menu item, and we should close the menu if they
        //mouseup anywhere not inside the menu.
        if (!touch && (timestamp - previousTimestamp > SC.ButtonView.CLICK_AND_HOLD_DELAY)) {
          menu.remove();
        }
      }
    }

    // Reset state.
    this._isMouseDown = NO;
    arguments.callee.base.apply(this,arguments);
    return YES;
  },

  /** @private
    Overrides ButtonView's mouseExited method to remove the behavior where the
    active state is removed on mouse exit. We want the button to remain active
    as long as the menu is visible.

    @param {SC.Event} evt
    @returns {Boolean}
  */
  mouseExited: function(evt) {
    return YES;
  },

  /** @private
    Overrides performKeyEquivalent method to pass any keyboard shortcuts to
    the menu.

    @param {String} charCode string corresponding to shortcut pressed (e.g.,
    alt_shift_z)
    @param {SC.Event} evt
  */
  performKeyEquivalent: function(charCode, evt) {
    if (!this.get('isEnabledInPane')) return NO ;
    var menu = this.get('instantiatedMenu') ;

    return (!!menu && menu.performKeyEquivalent(charCode, evt, YES)) ;
  },

  /** @private */
  touchStart: function(evt) {
    return this.mouseDown(evt);
  },

  /** @private */
  touchEnd: function(evt) {
    return this.mouseUp(evt);
  }

});

/**
  @private
  Handles lazy instantiation of popup button menu.
*/
SC.PopupButtonMenuLoader = SC.Task.extend({
  popupButton: null,
  run: function() {
    if (this.popupButton) this.popupButton._instantiateMenu();
  }
});

/* >>>>>>>>>> BEGIN source/views/progress.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


/**
  @class

  Displays a progress bar.  You can display both a defined and an
  indeterminate progressbar.  The progress bar itself is designed to be styled
  using CSS classes with the following structure:

      <div class="sc-progress-view"><div class="inner"></div></div>

  The outer can form the boundary of the bar while the inner will be adjusted
  to fit the percentage of the progress.

  Creating a ProgressView accepts a number of properties, for example:

      progressView: SC.ProgressView.design({
        value: 50,
        minimum: 0,
        maximum: 100,
        isIndeterminate: NO,
        isEnabled: YES
      })

  @extends SC.View
  @extends SC.Control
  @since SproutCore 1.0
*/
SC.ProgressView = SC.View.extend(SC.Control,
/** @scope SC.ProgressView.prototype */{

  /**
    @type Array
    @default ['sc-progress-view']
    @see SC.View#classNames
  */
  classNames: ['sc-progress-view'],

  /**
    @type Array
    @default ['displayValue', 'ariaValue', 'minimum', 'maximum', 'isIndeterminate', 'isRunning', 'isVisibleInWindow']
    @see SC.View#displayProperties
  */
  displayProperties: ['displayValue', 'ariaValue', 'minimum', 'maximum', 'isIndeterminate', 'isRunning', 'isVisibleInWindow'],

  /**
    @type String
    @default 'progressRenderDelegate'
  */
  renderDelegateName: 'progressRenderDelegate',

  // ........................................
  // PROPERTIES
  //

  /**
    Bind this to the current value of the progress bar.  Note that by default
    an empty value will disable the progress bar and a multiple value will make
    it indeterminate.

    @type Number
    @default 0.50
  */
  value: 0.50,

  /** @private */
  valueBindingDefault: SC.Binding.single().notEmpty(),

  /**
    @field
    @type Number
    @observes value
    @observes maximum
    @observes minimum
  */
  displayValue: function(){
    var minimum = this.get('minimum') || 0.0,
        maximum = this.get('maximum') || 1.0,
        value = this.get('value') || 0.0;

    // Percent value.
    value = (value - minimum) / (maximum - minimum);

    if (isNaN(value)) value = 0.0;
    // cannot be smaller then minimum
    if (value < 0.0) value = 0.0;
    // cannot be larger then maximum
    if (value > 1.0) value = 1.0;

    return value;
  }.property('value', 'maximum', 'minimum').cacheable(),

  /**
    The WAI-ARIA role for progress view.

    @type String
    @default 'progressbar'
    @readOnly
  */
  ariaRole: 'progressbar',

  /**
    The WAI-ARIA value for the progress view. This value will be passed to any
    rendering code as-is, not converted into percentages, etc. It is computed
    based on the original value property.

    @property
  */
  ariaValue: function() {
    return this.get('value');
  }.property('value').cacheable(),

  /**
    The minimum value of the progress.

    @type Number
    @default 0
  */
  minimum: 0,

  /** @private */
  minimumBindingDefault: SC.Binding.single().notEmpty(),

  /**
    Optionally specify the key used to extract the minimum progress value
    from the content object.  If this is set to null then the minimum value
    will not be derived from the content object.

    @type String
    @default null
  */
  contentMinimumKey: null,

  /**
    The maximum value of the progress bar.

    @type Number
    @default 1.0
  */
  maximum: 1.0,

  /** @private */
  maximumBindingDefault: SC.Binding.single().notEmpty(),

  /**
    Optionally specify the key used to extract the maximum progress value
    from the content object.  If this is set to null then the maximum value
    will not be derived from the content object.

    @type String
    @default null
  */
  contentMaximumKey: null,

  /**
    Set to true if the item in progress is indeterminate.  This may be
    overridden by the actual value.

    @type Boolean
    @default NO
  */
  isIndeterminate: NO,

  /** @private */
  isIndeterminateBindingDefault: SC.Binding.bool(),

  /**
    Set to YES when the process is currently running.  This will cause the
    progress bar to animate, especially if it is indeterminate.

    @type Boolean
    @default NO
  */
  isRunning: NO,

  /** @private */
  isRunningBindingDefault: SC.Binding.bool(),

  /**
    Optionally specify the key used to extract the isIndeterminate value
    from the content object.  If this is set to null then the isIndeterminate
    value will not be derived from the content object.

    @type String
    @default null
  */
  contentIsIndeterminateKey: null,

  // ........................................
  // INTERNAL SUPPORT
  //

  /** @private */
  contentPropertyDidChange: function(target, key) {
    var content = this.get('content');
    this.beginPropertyChanges()
      .updatePropertyFromContent('value', key, 'contentValueKey', content)
      .updatePropertyFromContent('minimum', key, 'contentMinimumKey', content)
      .updatePropertyFromContent('maximum', key, 'contentMaximumKey', content)
      .updatePropertyFromContent('isIndeterminate', key, 'contentIsIndeterminateKey', content)
    .endPropertyChanges();
  },

  /** @private */
  didCreateLayer: function() {
    // When using the JavaScript animation, we cannot start until the layer is
    // created.  Then if we are indeterminate, running and visible in the
    // window already, start animating.
    if (this.get('isIndeterminate') && this.get('isRunning') && this.get('isVisibleInWindow')) {
      this.displayDidChange();
    }
  }

});


/* >>>>>>>>>> BEGIN source/views/radio.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================


/** @class

  A RadioView is used to create a group of radio buttons.  The user can use
  these buttons to pick from a choice of options.

  This view renders simulated radio buttons that can display a mixed state and
  has other features not found in platform-native controls.

  The radio buttons themselves are designed to be styled using CSS classes with
  the following structure:

      <label class="sc-radio-button">
        <img class="button" src="some_image.gif"/>
        <input type="radio" name="<sc-guid>" value=""/>
        <span class="sc-button-label">Label for button1</span>
      </label>

  Setting up a RadioView accepts a number of properties, for example:

      radio: SC.RadioView.design({
        items: [
          {
            title: "Red",
            value: "red",
            enabled: YES,
            icon: "button_red"
          },{
            title: "Green",
            value: "green",
            enabled: YES,
            icon: 'button_green'
          }
        ],
        value: 'red',
        itemTitleKey: 'title',
        itemValueKey: 'value',
        itemIconKey: 'icon',
        itemIsEnabledKey: 'enabled',
        isEnabled: YES,
        layoutDirection: SC.LAYOUT_HORIZONTAL
      })

  The items array can contain either strings, or as in the example above a
  hash. When using a hash, make sure to also specify the itemTitleKey
  and itemValueKey you are using. Similarly, you will have to provide
  itemIconKey if you are using icons radio buttons. The individual items
  enabled property is YES by default, and the icon is optional.

  @extends SC.View
  @extends SC.Control
  @since SproutCore 1.0
*/
SC.RadioView = SC.View.extend(SC.Control,
/** @scope SC.RadioView.prototype */{

  /**
    @field
    @type Boolean
    @default YES
    @observes isEnabled
  */
  acceptsFirstResponder: function() {
    if (SC.FOCUS_ALL_CONTROLS) { return this.get('isEnabledInPane'); }
    return NO;
  }.property('isEnabledInPane'),

  /**
    @type Array
    @default ['sc-radio-view']
    @see SC.View#classNames
  */
  classNames: ['sc-radio-view'],

  /**
    The WAI-ARIA role for a group of radio buttons.

    @type String
    @default 'radiogroup'
    @readOnly
  */
  ariaRole: 'radiogroup',

  /**
    @type Array
    @default ['displayItems', 'layoutDirection']
    @see SC.View#displayProperties
  */
  displayProperties: ['displayItems', 'layoutDirection'],

  /**
    @type String
    @default 'radioGroupRenderDelegate'
  */
  renderDelegateName: 'radioGroupRenderDelegate',

  // ..........................................................
  // Properties
  //

  /**
    If items property is a hash, specify which property will function as
    the ariaLabeledBy with this itemAriaLabeledByKey property.ariaLabeledBy is used
    as the WAI-ARIA attribute for the radio view. This property is assigned to
    'aria-labelledby' attribute, which defines a string value that labels the
    element. Used to support voiceover.  It should be assigned a non-empty string,
    if the 'aria-labelledby' attribute has to be set for the element.

    @type String
    @default null
  */
  itemAriaLabeledByKey: null,

  /**
    If items property is a hash, specify which property will function as
    the ariaLabeled with this itemAriaLabelKey property.ariaLabel is used
    as the WAI-ARIA attribute for the radio view. This property is assigned to
    'aria-label' attribute, which defines a string value that labels the
    element. Used to support voiceover.  It should be assigned a non-empty string,
    if the 'aria-label' attribute has to be set for the element.

    @type String
    @default null
  */
  itemAriaLabelKey: null,

  /**
    The value of the currently selected item, and which will be checked in the
    UI. This can be either a string or an array with strings for checking
    multiple values.

    @type Object|String
    @default null
  */
  value: null,

  /**
    This property indicates how the radio buttons are arranged. Possible values:

      - SC.LAYOUT_VERTICAL
      - SC.LAYOUT_HORIZONTAL

    @type String
    @default SC.LAYOUT_VERTICAL
  */
  layoutDirection: SC.LAYOUT_VERTICAL,

  /**
    @type Boolean
    @default YES
  */
  escapeHTML: YES,

  /**
    The items property can be either an array with strings, or a
    hash. When using a hash, make sure to also specify the appropriate
    itemTitleKey, itemValueKey, itemIsEnabledKey and itemIconKey.

    @type Array
    @default []
  */
  items: [],

  /**
    If items property is a hash, specify which property will function as
    the title with this itemTitleKey property.

    @type String
    @default null
  */
  itemTitleKey: null,

  /**
    If items property is a hash, specify which property will function as
    the item width with this itemWidthKey property. This is only used when
    layoutDirection is set to SC.LAYOUT_HORIZONTAL and can be used to override
    the default value provided by the framework or theme CSS.

    @type String
    @default null
  */
  itemWidthKey: null,

  /**
    If items property is a hash, specify which property will function as
    the value with this itemValueKey property.

    @type String
    @default null
  */
  itemValueKey: null,

  /**
    If items property is a hash, specify which property will function as
    the value with this itemIsEnabledKey property.

    @type String
    @default null
  */
  itemIsEnabledKey: null,

  /**
    If items property is a hash, specify which property will function as
    the value with this itemIconKey property.

    @type String
    @default null
  */
  itemIconKey: null,

  /**  @private
    If the items array itself changes, add/remove observer on item...
  */
  itemsDidChange: function() {
    if (this._items) {
      this._items.removeObserver('[]', this, this.itemContentDidChange);
    }
    this._items = this.get('items');
    if (this._items) {
      this._items.addObserver('[]', this, this.itemContentDidChange);
    }
    this.itemContentDidChange();
  }.observes('items'),

  /** @private
    Invoked whenever the item array or an item in the array is changed.
    This method will regenerate the list of items.
  */
  itemContentDidChange: function() {
    // Force regeneration of buttons
    this._renderAsFirstTime = YES;

    this.notifyPropertyChange('displayItems');
  },

  // ..........................................................
  // PRIVATE SUPPORT
  //

  /** @private
    Data Sources for radioRenderDelegates, as required by radioGroupRenderDelegate.
  */
  displayItems: function() {
    var items = this.get('items'),
        viewValue = this.get('value'),
        isArray = SC.isArray(viewValue),
        loc = this.get('localize'),
        titleKey = this.get('itemTitleKey'),
        valueKey = this.get('itemValueKey'),
        widthKey = this.get('itemWidthKey'),
        isHorizontal = this.get('layoutDirection') === SC.LAYOUT_HORIZONTAL,
        isEnabledKey = this.get('itemIsEnabledKey'),
        iconKey = this.get('itemIconKey'),
        ariaLabeledByKey = this.get('itemAriaLabeledByKey'),
        ariaLabelKey = this.get('itemAriaLabelKey'),
        ret = this._displayItems || [], max = (items)? items.get('length') : 0,
        item, title, width, value, idx, isEnabled, icon, sel, active,
        ariaLabeledBy, ariaLabel;

    for(idx=0;idx<max;idx++) {
      item = items.objectAt(idx);

      // if item is an array, just use the items...
      if (SC.typeOf(item) === SC.T_ARRAY) {
        title = item[0];
        value = item[1];

        // otherwise, possibly use titleKey,etc.
      } else if (item) {
        // get title.  either use titleKey or try to convert the value to a
        // string.
        if (titleKey) {
          title = item.get ? item.get(titleKey) : item[titleKey];
        } else title = (item.toString) ? item.toString() : null;

        if (widthKey && isHorizontal) {
          width = item.get ? item.get(widthKey) : item[widthKey];
        }

        if (valueKey) {
          value = item.get ? item.get(valueKey) : item[valueKey];
        } else value = item;

        if (isEnabledKey) {
          isEnabled = item.get ? item.get(isEnabledKey) : item[isEnabledKey];
        } else isEnabled = YES;

        if (iconKey) {
          icon = item.get ? item.get(iconKey) : item[iconKey];
        } else icon = null;

        if (ariaLabeledByKey) {
          ariaLabeledBy = item.get ? item.get(ariaLabeledByKey) : item[ariaLabeledByKey];
        } else ariaLabeledBy = null;

        if (ariaLabelKey) {
          ariaLabel = item.get ? item.get(ariaLabelKey) : item[ariaLabelKey];
        } else ariaLabel = null;

        // if item is nil, use some defaults...
      } else {
        title = value = icon = null;
        isEnabled = NO;
      }

      // it can only be enabled if the radio view itself is enabled
      isEnabled = isEnabled && this.get('isEnabled');

      if (item) {
        sel = (isArray) ? (viewValue.indexOf(value) >= 0) : (viewValue === value);
      } else {
        sel = NO;
      }

      // localize title if needed
      if (loc) title = SC.String.loc(title);
      ret.push(SC.Object.create({
        title: title,
        icon: icon,
        width: width,
        value: value,

        isEnabled: isEnabled,
        isSelected: (isArray && viewValue.indexOf(value) >= 0 && viewValue.length === 1) || (viewValue === value),
        isMixed: (isArray && viewValue.indexOf(value) >= 0),
        isActive: this._activeRadioButton === idx,
        theme: this.get('theme'),
        renderState: {}
      }));
    }

    return ret; // done!
  }.property('isEnabled', 'value', 'items', 'itemTitleKey', 'itemWidthKey', 'itemValueKey', 'itemIsEnabledKey', 'localize', 'itemIconKey','itemAriaLabeledByKey', 'itemAriaLabelKey').cacheable(),

  /** @private
    If the user clicks on of the items mark it as active on mouseDown unless
    is disabled.

    Save the element that was clicked on so we can remove the active state on
    mouseUp.
  */
  mouseDown: function(evt) {
    // Fast path, reject secondary clicks.
    if (evt.which && evt.which !== 1) return false;

    if (!this.get('isEnabledInPane')) return YES;

    var delegate = this.get('renderDelegate'), proxy = this.get('renderDelegateProxy'),
        elem = this.$(),
        index = delegate.indexForEvent(proxy, elem, evt);

    this._activeRadioButton = index;

    if (index !== undefined) {
      var item = this.get('displayItems')[index];
      if (item.get('isEnabled')) {
        item.set('isActive', YES);
        delegate.updateRadioAtIndex(proxy, elem, index);
      }
    }

    // even if radiobuttons are not set to get firstResponder, allow default
    // action, that way textfields loose focus as expected.
    evt.allowDefault();
    return YES;
  },

  /** @private
    If we have a radio element that was clicked on previously, make sure we
    remove the active state. Then update the value if the item clicked is
    enabled.
  */
  mouseUp: function(evt) {
    if (!this.get('isEnabledInPane')) return YES;

    var delegate = this.get('renderDelegate'), proxy = this.get('renderDelegateProxy'),
        elem = this.$(),
        displayItems = this.get('displayItems'),
        index = delegate.indexForEvent(proxy, elem, evt);

    if (this._activeRadioButton !== undefined && index !== this._activeRadioButton) {
      displayItems[this._activeRadioButton].set('isActive', NO);
      delegate.updateRadioAtIndex(proxy, elem, this._activeRadioButton);
    }

    this._activeRadioButton = undefined;

    if (index !== undefined) {
      var item = this.get('displayItems')[index];
      if (item.get('isEnabled')) {
        item.set('isActive', NO);
        delegate.updateRadioAtIndex(proxy, elem, index);
        this.set('value', item.value);
      }
    }

    evt.allowDefault();
    return YES;
  },

  keyDown: function(evt) {
    if(!this.get('isEnabledInPane')) return YES;
    // handle tab key
    if (evt.which === 9 || evt.keyCode === 9) {
      var view = evt.shiftKey ? this.get('previousValidKeyView') : this.get('nextValidKeyView');
      if(view) view.becomeFirstResponder();
      else evt.allowDefault();
      return YES ; // handled
    }
    if (evt.which >= 37 && evt.which <= 40){

      var delegate = this.get('renderDelegate'), proxy = this.get('renderDelegateProxy'),
          elem = this.$(),
          displayItems = this.get('displayItems'),
          val = this.get('value');
      for(var i= 0, iLen = displayItems.length; i<iLen; i++){
        if(val === displayItems[i].value) break;
      }


      if (evt.which === 37 || evt.which === 38 ){
        if(i<=0) i = displayItems.length-1;
        else i--;
      }
      if (evt.which === 39 || evt.which === 40 ){
        if(i>=displayItems.length-1) i = 0;
        else i++;
      }
      delegate.updateRadioAtIndex(proxy, elem, i);
      this.set('value', displayItems[i].value);
    }
    evt.allowDefault();

    return NO;
  },


  /** @private */
  touchStart: function(evt) {
    return this.mouseDown(evt);
  },

  /** @private */
  touchEnd: function(evt) {
    return this.mouseUp(evt);
  }

});

/* >>>>>>>>>> BEGIN source/views/scene.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/** @class

  Displays several views as scenes that can slide on and off the screen.  The
  scene view is a nice way to provide a simple effect of moving from a
  higher level screen to a more detailed level screen.  You will be able to
  optionally choose the kind of animation used to transition the two scenes
  as well if supported on the web browser.

  # Using SC.SceneView

  To setup the scene view, you should define the 'scenes' property with an
  array of scene names.  These will be the properties on the scene view that
  you can shift in an out of view as needed.  You can edit the scenes property
  at any time.  It will only be used when you start to transition from one
  scene to another.

  Next you should set your nowShowing property to the name of the scene you
  would like to display.  This will cause the view to transition scenes if it
  is visible on screen.  Otherwise, it will simply make the new scene view
  the current content view and that's it.

  @extends SC.ContainerView
  @since Version 1.0
*/
SC.SceneView = SC.ContainerView.extend(
/** @scope SC.SceneView.prototype */ {

  /**
    Array of scene names.  Scenes will slide on and off screen in the order
    that you specify them here.  That is, if you shift from a scene at index
    2 to a scene at index 1, the scenes will animate backwards.  If you
    shift to a scene at index 3, the scenes will animate forwards.

    @type Array
    @default null
  */
  scenes: null,

  /**
    The transitionSwap plugin to use when animating backwards.

    @type Object (SC.SwapTransitionProtocol)
    @default null
    @see SC.ContainerView#transitionSwap
  */
  transitionBackward: SC.ContainerView.PUSH,

  /**
    The options for the given transitionSwap plugin when animating backwards.

    @type Object
    @default { duration: .25, direction: 'right' }
    @see SC.ContainerView#transitionBackwardOptions
  */
  transitionBackwardOptions: { duration: .25, direction: 'right' },

  /**
    The transitionSwap plugin to use when animating forwards.

    @type Object (SC.SwapTransitionProtocol)
    @default null
    @see SC.ContainerView#transitionSwap
  */
  transitionForward: SC.ContainerView.PUSH,

  /**
    The options for the given transitionSwap plugin when animating forwards.

    @type Object
    @default { duration: .25, direction: 'left' }
    @see SC.ContainerView#transitionBackwardOptions
  */
  transitionForwardOptions: { duration: .25, direction: 'left' },

  /** @private
    @param {SC.View} newContent the new content view or null.
    @see SC.ContainerView#replaceContent
  */
  replaceContent: function(newContent) {
    var scenes = this.get('scenes'),
      nowShowing = this.get('nowShowing'),
      outIdx = scenes ? scenes.indexOf(this._lastNowShowingView) : -1,
      inIdx = scenes ? scenes.indexOf(nowShowing) : -1;

    this._lastNowShowingView = nowShowing;

    if (outIdx < inIdx) {
      this.transitionSwap = this.transitionForward;
      this.transitionSwapOptions = this.transitionForwardOptions;
    } else {
      this.transitionSwap = this.transitionBackward;
      this.transitionSwapOptions = this.transitionBackwardOptions;
    }

    arguments.callee.base.apply(this,arguments);
  },

});

/* >>>>>>>>>> BEGIN source/views/segment.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
/**
  @class

  SegmentViews are the views used and arranged by SC.SegmentedView and are very similar to a SC.ButtonView
  without any event handling.  The event handling is done by the parent view.

  @extends SC.View
  @since SproutCore 1.5
*/
SC.SegmentView = SC.View.extend(SC.Control,
/** @scope SC.SegmentView.prototype */{

  /**
    @type String
    @default 'tab'
    @readOnly
  */
  //ariaRole: 'tab',
  ariaRole: 'button', // workaround for <rdar://problem/10444670>; switch back to 'tab' later with <rdar://problem/10463928> (also see segmented.js)

  /**
    @type Boolean
    @default YES
    @readOnly
  */
  isSegment: YES,

  /**
    @type Array
    @default ['sc-segment-view']
    @see SC.View#classNames
  */
  classNames: ['sc-segment-view'],

  /**
    @type String
    @default null
    @see SC.View#toolTip
  */
  toolTip: null,

  /**
    @type Boolean
    @default NO
    @see SC.Control#isActive
  */
  isActive: NO,

  /**
    @type Boolean
    @default NO
    @see SC.Control#isSelected
  */
  isSelected: NO,

  /**
    Change the layout direction to make this a vertical segment instead of horizontal ones.
    Possible values:

      - SC.LAYOUT_HORIZONTAL
      - SC.LAYOUT_VERTICAL

    @type String
    @default SC.LAYOUT_HORIZONTAL
  */
  layoutDirection: SC.LAYOUT_HORIZONTAL,

  /**
    @type String
    @default null
    @see SC.Control#controlSize
  */
  controlSize: null,

  /**
    @type Boolean
    @default NO
    @see SC.ButtonView#supportFocusRing
  */
  supportFocusRing: NO,

  // TODO: isDefault, isCancel, value not really used by render delegate
  displayProperties: ['icon', 'displayTitle', 'value', 'displayToolTip', 'isDefault', 'isCancel', 'width', 'isSegment','isFirstSegment', 'isMiddleSegment', 'isLastSegment', 'isOverflowSegment', 'index', 'layoutDirection'],

  /**
    @type String
    @default 'segmentRenderDelegate'
  */
  renderDelegateName: 'segmentRenderDelegate',

  /**
    @type Boolean
    @default YES
  */
  useStaticLayout: YES,


  // ..........................................................
  // Properties
  //

  /**
    @type String
    @default ""
  */
  title: "",

  /**
    @type Object
    @default null
  */
  value: null,

  /**
    @type String
    @default null
  */
  icon: null,

  /**
    @type Boolean
    @default null
  */
  localize: NO,

  /**
    @type String
    @default null
  */
  keyEquivalent: null,

  // TODO: Modification currently unsupported in SegmentedView
  /**
    @type Boolean
    @default YES
  */
  escapeHTML: YES,

  // TODO: Modification currently unsupported in SegmentedView
  /**
    @type Boolean
    @default YES
  */
  needsEllipsis: YES,

  /**
    Localized title.

    @field
    @type String
    @default ""
  */
  displayTitle: function() {
    var ret = this.get('title');
    if (this.get('localize')) ret = SC.String.loc(ret);
    return ret;
  }.property('title', 'localize').cacheable(),

  /**
    @type Number
    @default null
  */
  width: null,

  /**
    The item represented by this view.

    @type Object
    @default null
  */
  localItem: null,

  /** @private
    Whenever the width property changes, adjust our layout accordingly.
  */
  widthDidChange: function() {
    this.adjust('width', this.get('width'));
  }.observes('width'),

  /** @private
    Update our properties according to our matching item.
  */
  updateItem: function(parentView, item) {
    var itemKeys = parentView.get('itemKeys'),
        itemKey,
        viewKeys = parentView.get('viewKeys'),
        viewKey,
        i;

    for (i = itemKeys.get('length') - 1; i >= 0; i--) {
      itemKey = parentView.get(itemKeys.objectAt(i));
      viewKey = viewKeys.objectAt(i);

      // Don't overwrite the default value if none exists in the item
      if (!SC.none(item.get(itemKey))) this.set(viewKey, item.get(itemKey));
    }

    this.set('localItem', item);
  }
});

/* >>>>>>>>>> BEGIN source/views/segmented.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('views/segment');

/**
  @class

  SegmentedView is a special type of button that can display multiple
  segments.  Each segment has a value assigned to it.  When the user clicks
  on the segment, the value of that segment will become the new value of
  the control.

  You can also optionally configure a target/action that will fire whenever
  the user clicks on an item.  This will give your code an opportunity to take
  some action depending on the new value.  (of course, you can always bind to
  the value as well, which is generally the preferred approach.)

  # Defining Your Segments

  You define your segments by providing a items array, much like you provide
  to a RadioView.  Your items array can be as simple as an array of strings
  or as complex as full model objects.  Based on how you configure your
  itemKey properties, the segmented view will read the properties it needs
  from the array and construct the button.

  You can define the following properties on objects you pass in:

    - *itemTitleKey* - the title of the button
    - *itemValueKey* - the value of the button
    - *itemWidthKey* - the preferred width. if omitted, it autodetects
    - *itemIconKey*  - an icon
    - *itemActionKey* - an optional action to fire when pressed
    - *itemTargetKey* - an optional target for the action
    - *itemLayerIdKey* - an optional target for the action
    - *segmentViewClass* - class to be used for creating segments

  @extends SC.View
  @extends SC.Control
  @since SproutCore 1.0
*/
SC.SegmentedView = SC.View.extend(SC.Control,
/** @scope SC.SegmentedView.prototype */ {

  /** @private
    @ field
    @type Boolean
    @default YES
  */
  acceptsFirstResponder: function () {
    if (SC.FOCUS_ALL_CONTROLS) { return this.get('isEnabledInPane'); }
    return NO;
  }.property('isEnabledInPane').cacheable(),

  /** @private
    @type String
    @default 'tablist'
    @readOnly
  */
  //ariaRole: 'tablist',
  ariaRole: 'group', // workaround for <rdar://problem/10444670>; switch back to 'tablist' later with <rdar://problem/10463928> (also see segment.js)

  /** @private
    @type Array
    @default ['sc-segmented-view']
    @see SC.View#classNames
  */
  classNames: ['sc-segmented-view'],

  /**
    @type String
    @default 'square'
    @see SC.ButtonView#theme
  */
  theme: 'square',

  /**
    The value of the segmented view.

    The SegmentedView's value will always be the value of the currently
    selected button or buttons.  Setting this value will change the selected
    button or buttons.

    If you set this value to something that has no matching button, then
    no buttons will be selected.

    Note: if allowsMultipleSelection is set to true, then the value must be
    an Array.

    @type Object | Array
    @default null
  */
  value: null,

  /**
    If YES, clicking a selected button again will deselect it, setting the
    segmented views value to null.

    @type Boolean
    @default NO
  */
  allowsEmptySelection: NO,

  /**
    If YES, then clicking on a tab will not deselect the other segments, it
    will simply add or remove it from the selection.

    @type Boolean
    @default NO
  */
  allowsMultipleSelection: NO,

  /**
    If YES, it will set the segment value even if an action is defined.

    @type Boolean
    @default NO
  */
  selectSegmentWhenTriggeringAction: NO,

  /**
    @type Boolean
    @default YES
  */
  localize: YES,

  /**
    Aligns the segments of the segmented view within its frame horizontally.
    Possible values:

      - SC.ALIGN_LEFT
      - SC.ALIGN_RIGHT
      - SC.ALIGN_CENTER

    @type String
    @default SC.ALIGN_CENTER
  */
  align: SC.ALIGN_CENTER,

  /**
    Change the layout direction to make this a vertical set of tabs instead
    of horizontal ones. Possible values:

      - SC.LAYOUT_HORIZONTAL
      - SC.LAYOUT_VERTICAL

    @type String
    @default SC.LAYOUT_HORIZONTAL
  */
  layoutDirection: SC.LAYOUT_HORIZONTAL,


  // ..........................................................
  // SEGMENT DEFINITION
  //

  /**
    The array of items to display.  This may be a simple array of strings, objects
    or SC.Objects.  If you pass objects or SC.Objects, you must also set the
    various itemKey properties to tell the SegmentedView how to extract the
    information it needs.

    Note: only SC.Object items support key-value coding and therefore may be
    observed by the view for changes to titles, values, icons, widths,
    isEnabled values & tooltips.

    @type Array
    @default null
  */
  items: null,

  /**
    The key that contains the title for each item.

    @type String
    @default null
  */
  itemTitleKey: null,

  /**
    The key that contains the value for each item.

    @type String
    @default null
  */
  itemValueKey: null,

  /**
    A key that determines if this item in particular is enabled.  Note if the
    control in general is not enabled, no items will be enabled, even if the
    item's enabled property returns YES.

    @type String
    @default null
  */
  itemIsEnabledKey: null,

  /**
    The key that contains the icon for each item.  If omitted, no icons will
    be displayed.

    @type String
    @default null
  */
  itemIconKey: null,

  /**
    The key that contains the desired width for each item.  If omitted, the
    width will autosize.

    @type String
    @default null
  */
  itemWidthKey: null,

  /**
    The key that contains the action for this item.  If defined, then
    selecting this item will fire the action in addition to changing the
    value.  See also itemTargetKey.

    @type String
    @default null
  */
  itemActionKey: null,

  /**
    The key that contains the target for this item.  If this and itemActionKey
    are defined, then this will be the target of the action fired.

    @type String
    @default null
  */
  itemTargetKey: null,

  /**
    The key that contains the layerId for each item.
    @type String
  */
  itemLayerIdKey: null,

  /**
    The key that contains the key equivalent for each item.  If defined then
    pressing that key equivalent will be like selecting the tab.  Also,
    pressing the Alt or Option key for 3 seconds will display the key
    equivalent in the tab.

    @type String
    @default null
  */
  itemKeyEquivalentKey: null,

  /**
    If YES, overflowing items are placed into a menu and an overflow segment is
    added to popup that menu.

    @type Boolean
    @default YES
  */
  shouldHandleOverflow: YES,

  /**
    The title to use for the overflow segment if it appears.

    NOTE: This will not be HTML escaped and must never be assigned to user inserted text!

    @type String
    @default '&raquo;'
  */
  overflowTitle: '&raquo;',

  /**
    The toolTip to use for the overflow segment if it appears.

    @type String
    @default 'More&hellip;'
  */
  overflowToolTip: 'More…',

  /**
    The icon to use for the overflow segment if it appears.

    @type String
    @default null
  */
  overflowIcon: null,

  /**
    The view class used when creating segments.

    @type SC.View
    @default SC.SegmentView
  */
  segmentViewClass: SC.SegmentView,

  /**
    Set to YES if you would like your SegmentedView to size itself based on its
    visible segments. Useful if you're using SegmentedView in a flowed context
    (for example if its parent view has `childViewLayout: SC.View.HORIZONTAL_STACK`).

    The view will not auto-resize unless you define an initial value for the layout
    property which will be auto-resized (i.e. `width` when in the default horizontal
    orientation). This is to prevent the view from inappropriately adding width to a
    flexible (`{ left: 0, right: 0 }`) layout.

    Has no effect if `shouldHandleOverflow` is NO.

    @type Boolean
    @default NO
   */
  shouldAutoResize: NO,

  /** @private
    The following properties are used to map items to child views. Item keys
    are looked up on the item based on this view's value for each 'itemKey'.
    If a value in the item is found, then that value is mapped to a child
    view using the matching viewKey.

    @type Array
  */
  itemKeys: ['itemTitleKey', 'itemValueKey', 'itemIsEnabledKey', 'itemIconKey', 'itemWidthKey', 'itemToolTipKey', 'itemKeyEquivalentKey', 'itemLayerIdKey'],

  /** @private */
  viewKeys: ['title', 'value', 'isEnabled', 'icon', 'width', 'toolTip', 'keyEquivalent', 'layerId'],

  /** @private
    Call itemsDidChange once to initialize segment child views for the items that exist at
    creation time.
  */
  init: function () {
    arguments.callee.base.apply(this,arguments);

    // Initialize.
    this.shouldHandleOverflowDidChange();
    this.itemsDidChange();
  },

  shouldHandleOverflowDidChange: function () {
    var overflowView = this.get('overflowView');

    if (this.get('shouldHandleOverflow')) {
      var title = this.get('overflowTitle'),
          toolTip = this.get('overflowToolTip'),
          icon = this.get('overflowIcon');

      overflowView = this.get('segmentViewClass').create({
        controlSize: this.get('controlSize'),
        escapeHTML: false,
        localize: this.get('localize'),
        title: title,
        toolTip: toolTip,
        icon: icon,
        isLastSegment: YES,
        isOverflowSegment: YES,
        layoutDirection: this.get('layoutDirection')
      });
      this.appendChild(overflowView);
      this.set('overflowView', overflowView);

      // remeasure should show/hide it as needed
      this.invokeLast(this.remeasure);
    } else {
      if (overflowView) { // There will not be an overflow view on initialization.
        this.removeChildAndDestroy(overflowView);
        this.set('overflowView', null);
      }
    }
  }.observes('shouldHandleOverflow'),

  /** @private
    Called whenever the number of items changes.  This method populates SegmentedView's childViews, taking
    care to re-use existing childViews if possible.
  */
  itemsDidChange: function () {
    var items = this.get('items') || [],
        localItem,                        // Used to avoid altering the original items
        previousItem,
        childViews = this.get('childViews'),
        childView,
        overflowView = this.get('overflowView'),
        value = this.get('value'),        // The value can change if items that were once selected are removed
        isSelected,
        itemKeys = this.get('itemKeys'),
        itemKey,
        segmentViewClass = this.get('segmentViewClass'),
        i, j;

    // Update childViews
    var childViewsLength = this.get('shouldHandleOverflow') ? childViews.get('length') - 1 : childViews.get('length');
    if (childViewsLength > items.get('length')) {   // We've lost segments (ie. childViews)

      // Remove unneeded segments from the end back
      for (i = childViewsLength - 1; i >= items.get('length'); i--) {
        childView = childViews.objectAt(i);
        localItem = childView.get('localItem');

        // Remove observers from items we are losing off the end
        if (localItem instanceof SC.Object) {

          for (j = itemKeys.get('length') - 1; j >= 0; j--) {
            itemKey = this.get(itemKeys.objectAt(j));

            if (itemKey) {
              localItem.removeObserver(itemKey, this, this.itemContentDidChange);
            }
          }
        }

        // If a selected childView has been removed then update our value
        if (SC.isArray(value)) {
          value.removeObject(localItem);
        } else if (value === localItem) {
          value = null;
        }

        this.removeChildAndDestroy(childView);
      }

      // Update our value which may have changed
      this.set('value', value);

    } else if (childViewsLength < items.get('length')) {  // We've gained segments

      // Create the new segments
      for (i = childViewsLength; i < items.get('length'); i++) {

        // We create a default SC.ButtonView-like object for each segment
        childView = segmentViewClass.create({
          controlSize: this.get('controlSize'),
          localize: this.get('localize'),
          layoutDirection: this.get('layoutDirection')
        });

        // Attach the child
        this.insertBefore(childView, overflowView);
      }
    }

    // Because the items array can be altered with insertAt or removeAt, we can't be sure that the items
    // continue to match 1-to-1 the existing views, so once we have the correct number of childViews,
    // simply update them all
    childViews = this.get('childViews');

    for (i = 0; i < items.get('length'); i++) {
      localItem = items.objectAt(i);
      childView = childViews.objectAt(i);
      previousItem = childView.get('localItem');

      if (previousItem instanceof SC.Object && !items.contains(previousItem)) {
        // If the old item is no longer in the view, remove its observers
        for (j = itemKeys.get('length') - 1; j >= 0; j--) {
          itemKey = this.get(itemKeys.objectAt(j));

          if (itemKey) {
            previousItem.removeObserver(itemKey, this, this.itemContentDidChange);
          }
        }
      }

      // Skip null/undefined items (but don't skip empty strings)
      if (SC.none(localItem)) continue;

      // Normalize the item (may be a String, Object or SC.Object)
      if (SC.typeOf(localItem) === SC.T_STRING) {

        localItem = SC.Object.create({
          'title': localItem.humanize().titleize(),
          'value': localItem
        });

        // Update our keys accordingly
        this.set('itemTitleKey', 'title');
        this.set('itemValueKey', 'value');
      } else if (SC.typeOf(localItem) === SC.T_HASH) {

        localItem = SC.Object.create(localItem);
      } else if (localItem instanceof SC.Object)  {

        // We don't need to make any changes to SC.Object items, but we can observe them
        for (j = itemKeys.get('length') - 1; j >= 0; j--) {
          itemKey = this.get(itemKeys.objectAt(j));

          if (itemKey) {
            localItem.removeObserver(itemKey, this, this.itemContentDidChange);
            localItem.addObserver(itemKey, this, this.itemContentDidChange, i);
          }
        }
      } else {
        SC.Logger.error('SC.SegmentedView items may be Strings, Objects (ie. Hashes) or SC.Objects only');
      }

      // Determine whether this segment is selected based on the view's existing value(s)
      isSelected = NO;
      if (SC.isArray(value) ? value.indexOf(localItem.get(this.get('itemValueKey'))) >= 0 : value === localItem.get(this.get('itemValueKey'))) {
        isSelected = YES;
      }
      childView.set('isSelected', isSelected);

      // Assign segment specific properties based on position
      childView.set('index', i);
      childView.set('isFirstSegment', i === 0);
      childView.set('isMiddleSegment',  i < items.get('length') - 1 && i > 0);
      childView.set('isLastSegment', i === items.get('length') - 1);

      // Be sure to update the view's properties for the (possibly new) matched item
      childView.updateItem(this, localItem);
    }

    // Force a segment remeasure to check overflow
    if (this.get('shouldHandleOverflow')) {
      this.invokeLast(this.remeasure);
    }
  }.observes('*items.[]'),

  /** @private
    This observer method is called whenever any of the relevant properties of an item change.  This only applies
    to SC.Object based items that may be observed.
  */
  itemContentDidChange: function (item, key, alwaysNull, index) {
    var childViews = this.get('childViews'),
        childView;

    childView = childViews.objectAt(index);
    if (childView) {

      // Update the childView
      childView.updateItem(this, item);

      // Reset our measurements (which depend on width/height or title) and adjust visible views
      if (this.get('shouldHandleOverflow')) {
        this.invokeLast(this.remeasure);
      }
    }
  },

  /** @private
    Whenever the view resizes, we need to check to see if we're overflowing.
  */
  viewDidResize: function () {
    this._sc_viewFrameDidChange();

    var isHorizontal = this.get('layoutDirection') === SC.LAYOUT_HORIZONTAL,
      visibleDim = isHorizontal ? this.$().width() : this.$().height();

    // Only overflow if we've gone below the minimum dimension required to fit all the segments
    if (this.get('shouldHandleOverflow') && (this.get('isOverflowing') || visibleDim <= this.cachedMinimumDim)) {
      this.invokeLast(this.remeasure);
    }
  },

  /** @private
    Whenever visibility changes, we need to check to see if we're overflowing.
  */
  isVisibleInWindowDidChange: function () {
    if (this.get('shouldHandleOverflow')) {
      this.invokeLast(this.remeasure);
    }
  }.observes('isVisibleInWindow'),

  /** @private
    Calling this method forces the segments to be remeasured and will also adjust the
    segments for overflow if necessary.
  */
  remeasure: function () {
    if (!this.get('shouldHandleOverflow')) { return; }

    var childViews = this.get('childViews'),
        overflowView;

    if (this.get('isVisibleInWindow')) {
      // Make all the views visible so that they can be measured
      overflowView = this.get('overflowView');
      overflowView.set('isVisible', YES);

      for (var i = childViews.get('length') - 1; i >= 0; i--) {
        childViews.objectAt(i).set('isVisible', YES);
      }

      this.cachedDims = this.segmentDimensions();
      this.cachedOverflowDim = this.overflowSegmentDim();

      this.adjustOverflow();
    }
  },

  /** @private
    This method is called to adjust the segment views to see if we need to handle for overflow.
   */
  adjustOverflow: function () {
    if (!this.get('shouldHandleOverflow')) { return; }

    var childViews = this.get('childViews'),
        childView,
        value = this.get('value'),
        overflowView = this.get('overflowView'),
        isHorizontal = this.get('layoutDirection') === SC.LAYOUT_HORIZONTAL,
        visibleDim = isHorizontal ? this.$().width() : this.$().height(),  // The inner width/height of the div
        curElementsDim = 0,
        dimToFit, length, i,
        isOverflowing = NO,
        wantsAutoResize = this.get('shouldAutoResize'),
        layoutProperty = isHorizontal ? 'width' : 'height',
        canAutoResize = !SC.none(this.getPath('layout.%@'.fmt(layoutProperty))),
        willAutoResize = wantsAutoResize && canAutoResize;

    // If child views and cachedDims lengths are out of sync here, it means adjustOverflow
    // got called in between itemsDidChange and remeasure. Since we know that the remeasure is
    // scheduled, just return and let the remeasure + adjustOverflow happen later.
    if (childViews.get('length') !== this.cachedDims.length + 1) { return; }

    // This variable is useful to optimize when we are overflowing
    isOverflowing = NO;
    overflowView.set('isSelected', NO);

    // Clear out the overflow items (these are the items not currently visible)
    this.overflowItems = [];

    length = this.cachedDims.length;
    for (i = 0; i < length; i++) {
      childView = childViews.objectAt(i);
      curElementsDim += this.cachedDims[i];

      // Check and see if this item kicks us over into overflow.
      if (!isOverflowing && !willAutoResize) {
        // (don't leave room for the overflow segment on the last item)
        dimToFit = (i === length - 1) ? curElementsDim : curElementsDim + this.cachedOverflowDim;
        if (dimToFit > visibleDim) isOverflowing = YES;
      }

      // Update the view depending on overflow state.
      if (isOverflowing) {
        // Add the localItem to the overflowItems
        this.overflowItems.pushObject(childView.get('localItem'));

        childView.set('isVisible', NO);

        // If the first item is already overflowed, make the overflowView first segment
        if (i === 0) overflowView.set('isFirstSegment', YES);

        // If the overflowed segment was selected, show the overflowView as selected instead
        if (SC.isArray(value) ? value.indexOf(childView.get('value')) >= 0 : value === childView.get('value')) {
          overflowView.set('isSelected', YES);
        }
      } else {
        childView.set('isVisible', YES);

        // If the first item is not overflowed, don't make the overflowView first segment
        if (i === 0) overflowView.set('isFirstSegment', NO);
      }
    }

    // Show/hide the overflow view as needed.
    overflowView.set('isVisible', isOverflowing);

    // Set the overflowing property.
    this.setIfChanged('isOverflowing', isOverflowing);

    // Autosize if needed.
    if (willAutoResize) {
      this.adjust(layoutProperty, this.isOverflowing ? this.cachedMinimumDim : curElementsDim);
    }

    // Store the minimum dimension (height/width) before overflow
    this.cachedMinimumDim = curElementsDim + this.cachedOverflowDim;
  },

  /**
    Return the dimensions (either heights or widths depending on the layout direction) of the DOM
    elements of the segments.  This will be measured by the view to determine which segments should
    be overflowed.

    It ignores the last segment (the overflow segment).
  */
  segmentDimensions: function () {
    var cv = this.get('childViews'),
        v, f,
        dims = [],
        isHorizontal = this.get('layoutDirection') === SC.LAYOUT_HORIZONTAL;

    for (var i = 0, length = cv.length; i < length - 1; i++) {
      v = cv[i];
      f = v.get('frame');
      dims[i] = isHorizontal ? f.width : f.height;
    }

    return dims;
  },

  /**
    Return the dimension (height or width depending on the layout direction) over the overflow segment.
  */
  overflowSegmentDim: function () {
    var cv = this.get('childViews'),
        v, f,
        isHorizontal = this.get('layoutDirection') === SC.LAYOUT_HORIZONTAL;

    v = cv.length && cv[cv.length - 1];
    if (v) {
      f = v.get('frame');
      return isHorizontal ? f.width : f.height;
    }

    return 0;
  },

  /**
    Return the index of the segment view that is the target of the mouse click.
  */
  indexForClientPosition: function (x, y) {
    var cv = this.get('childViews'),
        length, i,
        v, rect,
        point;

    point = { x: x, y: y };
    for (i = 0, length = cv.length; i < length; i++) {
      v = cv[i];

      rect = v.get('layer').getBoundingClientRect();
      rect = {
        x: rect.left,
        y: rect.top,
        width: (rect.right - rect.left),
        height: (rect.bottom - rect.top)
      };

      // Return the index early if found
      if (SC.pointInRect(point, rect)) return i;
    }

    // Default not found
    return -1;
  },

  // ..........................................................
  // RENDERING/DISPLAY SUPPORT
  //

  /**
    @type Array
    @default ['align']
    @see SC.View#displayProperties
  */
  displayProperties: ['align'],

  /**
    @type String
    @default 'segmentedRenderDelegate'
  */
  renderDelegateName: 'segmentedRenderDelegate',

  // ..........................................................
  // EVENT HANDLING
  //

  /** @private
    Determines the index into the displayItems array where the passed mouse
    event occurred.
  */
  displayItemIndexForEvent: function (evt) {
    var el = evt.target,
        x = evt.clientX,
        y = evt.clientY,
        ret = -1;

    if (el && el !== this.get('layer')) {
      // Accessibility workaround: WebKit sends all event coords as 0,0 for all AXPress-triggered events.
      // For example, triggering an element with VoiceOver in OS X.
      // Note: by ensuring that the event target wasn't our own layer, we avoid the situation where an
      // actual mouse clicked at 0,0 and hit only our layer.
      if (x === 0 && y === 0) {
        var offset = SC.offset(el);

        // Generate point coordinates in the middle of the target element.
        x = offset.x + Math.round(el.offsetWidth / 2);
        y = offset.y + Math.round(el.offsetHeight / 2);
      }

      var renderDelegate = this.get('renderDelegate');
      if (renderDelegate && renderDelegate.indexForClientPosition) {
        ret = renderDelegate.indexForClientPosition(this, x, y);
      } else {
        ret = this.indexForClientPosition(x, y);
      }
    }

    return ret;
  },

  /** @private */
  keyDown: function (evt) {
    var childViews,
        childView,
        i, length,
        value, isArray;

    // handle tab key
    if (evt.which === 9 || evt.keyCode === 9) {
      var view = evt.shiftKey ? this.get('previousValidKeyView') : this.get('nextValidKeyView');
      if (view) view.becomeFirstResponder();
      else evt.allowDefault();
      return YES; // handled
    }

    // handle arrow keys
    if (!this.get('allowsMultipleSelection')) {
      childViews = this.get('childViews');

      length = childViews.get('length');
      value = this.get('value');
      isArray = SC.isArray(value);

      // Select from the left to the right
      if (evt.which === 39 || evt.which === 40) {

        if (value) {
          for (i = 0; i < length - 2; i++) {
            childView = childViews.objectAt(i);
            if (isArray ? (value.indexOf(childView.get('value')) >= 0) : (childView.get('value') === value)) {
              this.triggerItemAtIndex(i + 1);
            }
          }
        } else {
          this.triggerItemAtIndex(0);
        }
        return YES; // handled

      // Select from the right to the left
      } else if (evt.which === 37 || evt.which === 38) {

        if (value) {
          for (i = 1; i < length - 1; i++) {
            childView = childViews.objectAt(i);
            if (isArray ? (value.indexOf(childView.get('value')) >= 0) : (childView.get('value') === value)) {
              this.triggerItemAtIndex(i - 1);
            }
          }
        } else {
          this.triggerItemAtIndex(length - 2);
        }

        return YES; // handled
      }
    }

    return NO;
  },

  /** @private */
  mouseDown: function (evt) {
    // Fast path, reject secondary clicks.
    if (evt.which !== 1) return false;

    var childViews = this.get('childViews'),
        childView,
        index;

    if (!this.get('isEnabledInPane')) return YES; // nothing to do // TODO: return NO?

    index = this.displayItemIndexForEvent(evt);
    if (index >= 0) {
      childView = childViews.objectAt(index);
      if (childView.get('isEnabled')) childView.set('isActive', YES);
      this.activeChildView = childView;

      // if mouse was pressed on the overflow segment, popup the menu
      var overflowIndex = this.get('shouldHandleOverflow') ? childViews.get('length') - 1 : null;
      if (index === overflowIndex) this.showOverflowMenu();
      else this._isMouseDown = YES;

      return YES;
    }
    // If this event originated outside of a segment, pass the event along up.
    else {
      return NO;
    }
  },

  /** @private */
  mouseUp: function (evt) {
    var activeChildView,
        index;

    index = this.displayItemIndexForEvent(evt);
    if (this._isMouseDown && (index >= 0)) {

      this.triggerItemAtIndex(index);

      // Clean up
      activeChildView = this.activeChildView;
      if (activeChildView) {
        activeChildView.set('isActive', NO);
        this.activeChildView = null;
      }
    }

    this._isMouseDown = NO;
    return YES;
  },

  /** @private */
  mouseMoved: function (evt) {
    var childViews = this.get('childViews'),
        activeChildView,
        childView,
        index;

    if (this._isMouseDown) {
      // Update the last segment
      index = this.displayItemIndexForEvent(evt);

      activeChildView = this.activeChildView;
      childView = childViews.objectAt(index);

      if (childView && childView !== activeChildView) {
        // Changed
        if (activeChildView) activeChildView.set('isActive', NO);
        if (childView.get('isEnabled')) childView.set('isActive', YES);
        this.activeChildView = childView;

        var overflowIndex = this.get('shouldHandleOverflow') ? childViews.get('length') - 1 : null;
        if (index === overflowIndex) {
          this.showOverflowMenu();
          this._isMouseDown = NO;
        }
      }
    }
    return YES;
  },

  /** @private */
  mouseEntered: function (evt) {
    var childViews = this.get('childViews'),
        childView,
        index;

    // if mouse was pressed down initially, start detection again
    if (this._isMouseDown) {
      index = this.displayItemIndexForEvent(evt);

      // if mouse was pressed on the overflow segment, popup the menu
      var overflowIndex = this.get('shouldHandleOverflow') ? childViews.get('length') - 1 : null;
      if (index === overflowIndex) {
        this.showOverflowMenu();
        this._isMouseDown = NO;
      } else if (index >= 0) {
        childView = childViews.objectAt(index);
        if (childView.get('isEnabled')) childView.set('isActive', YES);

        this.activeChildView = childView;
      }
    }
    return YES;
  },

  /** @private */
  mouseExited: function (evt) {
    var activeChildView;

    // if mouse was down, hide active index
    if (this._isMouseDown) {
      activeChildView = this.activeChildView;
      if (activeChildView) activeChildView.set('isActive', NO);

      this.activeChildView = null;
    }

    return YES;
  },

  /** @private */
  touchStart: function (touch) {
    var childViews = this.get('childViews'),
        childView,
        index;

    if (!this.get('isEnabledInPane')) return YES; // nothing to do

    index = this.displayItemIndexForEvent(touch);

    if (index >= 0) {
      childView = childViews.objectAt(index);
      childView.set('isActive', YES);
      this.activeChildView = childView;

      // if touch was on the overflow segment, popup the menu
      var overflowIndex = this.get('shouldHandleOverflow') ? childViews.get('length') - 1 : null;
      if (index === overflowIndex) this.showOverflowMenu();
      else this._isTouching = YES;
    }

    return YES;
  },

  /** @private */
  touchEnd: function (touch) {
    var activeChildView,
        index;

    index = this.displayItemIndexForEvent(touch);

    if (this._isTouching && (index >= 0)) {
      this.triggerItemAtIndex(index);

      // Clean up
      activeChildView = this.activeChildView;
      activeChildView.set('isActive', NO);
      this.activeChildView = null;

      this._isTouching = NO;
    }

    return YES;
  },

  /** @private */
  touchesDragged: function (evt, touches) {
    var isTouching = this.touchIsInBoundary(evt),
        childViews = this.get('childViews'),
        activeChildView,
        childView,
        index;

    if (isTouching) {
      if (!this._isTouching) {
        this._touchDidEnter(evt);
      }
      index = this.displayItemIndexForEvent(evt);

      activeChildView = this.activeChildView;
      childView = childViews[index];

      if (childView && childView !== activeChildView) {
        // Changed
        if (activeChildView) activeChildView.set('isActive', NO);
        childView.set('isActive', YES);

        this.activeChildView = childView;

        var overflowIndex = this.get('shouldHandleOverflow') ? childViews.get('length') - 1 : null;
        if (index === overflowIndex) {
          this.showOverflowMenu();
          this._isMouseDown = NO;
        }
      }
    } else {
      if (this._isTouching) this._touchDidExit(evt);
    }

    this._isTouching = isTouching;

    return YES;
  },

  /** @private */
  _touchDidExit: function (evt) {
    var activeChildView;

    if (this.isTouching) {
      activeChildView = this.activeChildView;
      activeChildView.set('isActive', NO);
      this.activeChildView = null;
    }

    return YES;
  },

  /** @private */
  _touchDidEnter: function (evt) {
    var childViews = this.get('childViews'),
        childView,
        index;

    index = this.displayItemIndexForEvent(evt);

    var overflowIndex = this.get('shouldHandleOverflow') ? childViews.get('length') - 1 : null;
    if (index === overflowIndex) {
      this.showOverflowMenu();
      this._isTouching = NO;
    } else if (index >= 0) {
      childView = childViews.objectAt(index);
      childView.set('isActive', YES);
      this.activeChildView = childView;
    }

    return YES;
  },

  /** @private
    Simulates the user clicking on the segment at the specified index. This
    will update the value if possible and fire the action.
  */
  triggerItemAtIndex: function (index) {
    var childViews = this.get('childViews'),
        childView,
        childValue, value, allowEmpty, allowMult;

    childView = childViews.objectAt(index);

    if (!childView.get('isEnabled')) return this; // nothing to do!

    allowEmpty = this.get('allowsEmptySelection');
    allowMult = this.get('allowsMultipleSelection');

    // get new value... bail if not enabled. Also save original for later.
    childValue = childView.get('value');
    value = this.get('value');

    // if we do not allow multiple selection, either replace the current
    // selection or deselect it
    if (!allowMult) {
      // if we allow empty selection and the current value is the same as
      // the selected value, then deselect it.
      if (allowEmpty && value === childValue) {
        value = null;
      } else {
        // otherwise, simply replace the value.
        value = childValue;
      }
    } else {
      // Lazily create the value array.
      if (!value) {
        value = [];
      } else if (!SC.isArray(value)) {
        value = [value];
      }

      // if we do allow multiple selection, then add or remove item to the array.
      if (value.indexOf(childValue) >= 0) {
        if (value.get('length') > 1 || (value.objectAt(0) !== childValue) || allowEmpty) {
          value = value.without(childValue);
        }
      } else {
        value = value.concat(childValue);
      }
    }

    // also, trigger target if needed.
    var actionKey = this.get('itemActionKey'),
        targetKey = this.get('itemTargetKey'),
        action, target = null,
        resp = this.getPath('pane.rootResponder'),
        item;

    if (actionKey && (item = this.get('items').objectAt(index))) {
      // get the source item from the item array.  use the index stored...
      action = item.get ? item.get(actionKey) : item[actionKey];
      if (targetKey) {
        target = item.get ? item.get(targetKey) : item[targetKey];
      }
      if (resp) resp.sendAction(action, target, this, this.get('pane'), value);
    }

    if (value !== undefined && (!action || this.get('selectSegmentWhenTriggeringAction'))) {
      this.set('value', value);
    }

    // if an action/target is defined on self use that also
    action = this.get('action');
    if (action && resp) {
      resp.sendAction(action, this.get('target'), this, this.get('pane'), value);
    }
  },

  /** @private
    Invoked whenever an item is selected in the overflow menu.
  */
  selectOverflowItem: function (menu) {
    var item = menu.get('selectedItem');

    this.triggerItemAtIndex(item.get('index'));

    // Cleanup
    menu.removeObserver('selectedItem', this, 'selectOverflowItem');

    this.activeChildView.set('isActive', NO);
    this.activeChildView = null;
  },

  /** @private
    Presents the popup menu containing overflowed segments.
  */
  showOverflowMenu: function () {
    var self = this,
        childViews = this.get('childViews'),
        itemValueKey = this.get('itemValueKey'),
        itemLayerIdKey = this.get('itemLayerIdKey'),
        overflowItems = this.overflowItems,
        overflowItemsLength,
        startIndex,
        isArray,
        value,
        item,
        layerId,
        layer,
        overflowElement;

    // Check the currently selected item if it is in overflowItems
    overflowItemsLength = overflowItems.get('length');
    startIndex = childViews.get('length') - 1 - overflowItemsLength;

    value = this.get('value');
    isArray = SC.isArray(value);
    for (var i = 0; i < overflowItemsLength; i++) {
      item = overflowItems.objectAt(i);

      if (isArray ? value.indexOf(item.get(itemValueKey)) >= 0 : value === item.get(itemValueKey)) {
        item.set('isChecked', YES);
      } else {
        item.set('isChecked', NO);
      }

      // Track the matching segment index
      item.set('index', startIndex + i);

      // Add '-overflow-menu-item' to the existing layer id (if set),
      // and use that as the layer id on the menu. This prevents the original
      // segment from being removed when the menu closes.
      layerId = item.get(itemLayerIdKey);
      if (layerId) {
        item.set('overflowLayerId', layerId + '-overflow-menu-item');
      }
    }

    // TODO: we can't pass a shortcut key to the menu, because it isn't a property of SegmentedView (yet?)
    var menu = SC.MenuPane.create({
      layout: { width: 200 },
      items: overflowItems,
      itemTitleKey: this.get('itemTitleKey'),
      itemIconKey: this.get('itemIconKey'),
      itemIsEnabledKey: this.get('itemIsEnabledKey'),
      itemKeyEquivalentKey: this.get('itemKeyEquivalentKey'),
      itemCheckboxKey: 'isChecked',
      itemLayerIdKey: 'overflowLayerId',

      // We need to be able to update our overflow segment even if the user clicks outside of the menu.  Since
      // there is no callback method or observable property when the menu closes, override modalPaneDidClick().
      modalPaneDidClick: function () {
        arguments.callee.base.apply(this,arguments);

        // Cleanup
        this.removeObserver('selectedItem', self, 'selectOverflowItem');

        self.activeChildView.set('isActive', NO);
        self.activeChildView = null;
      }
    });

    layer = this.get('layer');
    overflowElement = layer.childNodes[layer.childNodes.length - 1];
    menu.popup(overflowElement);

    menu.addObserver("selectedItem", this, 'selectOverflowItem');
  },

  /** @private
    Whenever the value changes, update the segments accordingly.
  */
  valueDidChange: function () {
    var value = this.get('value'),
        overflowItemsLength,
        childViews = this.get('childViews'),
        childViewsLength = this.get('shouldHandleOverflow') ? childViews.get('length') - 1 : childViews.get('length'),
        overflowIndex = Infinity,
        overflowView = this.get('overflowView'),
        childView;

    // The index where childViews are all overflowed
    if (this.overflowItems) {
      overflowItemsLength = this.overflowItems.get('length');
      overflowIndex = childViewsLength - overflowItemsLength;

      // Clear out the selected value of the overflowView (if it's set)
      overflowView.set('isSelected', NO);
    }

    for (var i = childViewsLength - 1; i >= 0; i--) {
      childView = childViews.objectAt(i);
      if (SC.isArray(value) ? value.indexOf(childView.get('value')) >= 0 : value === childView.get('value')) {
        childView.set('isSelected', YES);

        // If we've gone over the overflow index, the child view is represented in overflow items
        if (i >= overflowIndex) overflowView.set('isSelected', YES);
      } else {
        childView.set('isSelected', NO);
      }
    }
  }.observes('value')

});

/* >>>>>>>>>> BEGIN source/views/select.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('views/button');

/**
  @class

  SelectView has a functionality similar to that of SelectField

  Clicking the SelectView button displays a menu pane with a
  list of items. The selected item will be displayed on the button.
  User has the option of enabling checkbox for the selected menu item.

  @extends SC.ButtonView
  @version 1.0
  @author Alex Iskander, Mohammed Ashik
*/
SC.SelectView = SC.ButtonView.extend(
/** @scope SC.SelectView.prototype */ {

  /**
    @field
    @type Boolean
    @default YES
  */
  acceptsFirstResponder: function () {
    return this.get('isEnabledInPane');
  }.property('isEnabledInPane'),

  /**
    If true, titles will be escaped to avoid scripting attacks.

    @type Boolean
    @default YES
  */
  escapeHTML: YES,
  escapeHTMLBindingDefault: SC.Binding.oneWay().bool(),

  /**
    An array of items that will be form the menu you want to show.

    @type Array
    @default []
  */
  items: [],

  /** @private */
  itemsBindingDefault: SC.Binding.multiple(),

  /**
    If you set this to a non-null value, then the name shown for each
    menu item will be pulled from the object using the named property.
    if this is null, the collection items themselves will be used.

    @type String
    @default null
  */
  itemTitleKey: null,

  /**
    If you set this to a non-null value, then the value of this key will
    be used to sort the items.  If this is not set, then itemTitleKey will
    be used.

    @type String
    @default null
  */
  itemSortKey: null,

  /**
     Set this to a non-null value to use a key from the passed set of items
     as the value for the options popup.  If you don't set this, then the
     items themselves will be used as the value.

     @type String
     @default null
  */
  itemValueKey: null,

  /**
     Key used to extract icons from the items array

     @type String
     @default null
  */
  itemIconKey: null,

  /**
    Key to use to identify separators.

    @type String
    @default "isSeparator"
  */
  itemSeparatorKey: "isSeparator",

  /**
    Key used to indicate if the item is to be enabled.

    @type String
    @default "isEnabled"
  */
  itemIsEnabledKey: "isEnabled",

  /**
    @type Boolean
    @default YES
  */
  localize: YES,

  /**
    if true, it means that no sorting will occur, items will appear
    in the same order as in the array

    @type Boolean
    @default YES
  */
  disableSort: YES,

  /**
    @type Array
    @default ['sc-select-button']
    @see SC.View#classNames
  */
  classNames: ['sc-select-view'],

  /**
    Menu attached to the SelectView.

    @type SC.View
    @default SC.MenuView
  */
  menu: null,

  /**
    List of actual menu items, handed off to the menu view.

    @property
    @private
    @type:{Array}
  */
  _itemList: [],

  /**
    Property to set the index of the selected menu item. This in turn
    is used to calculate the preferMatrix.

    @property
    @type Number
    @default null
    @private
  */
  _itemIdx: null,

  /**
     Current Value of the SelectView

     @type Object
     @default null
  */
  value: null,

  /**
    if this property is set to 'YES', a checkbox is shown next to the
    selected menu item.

    @type Boolean
    @default YES
  */
  checkboxEnabled: YES,

  /**
    if this property is set to 'YES', a checkbox is shown next to the
    selected menu item.

    @type Boolean
    @default YES
  */
  showCheckbox: YES,

  /**
    Set this to non-null to place an empty option at the top of the menu.

    @property
    @type String
    @default null
  */
  emptyName: null,

  /**
    Default value of the select button.
     This will be the first item from the menu item list.

    @private
  */
  _defaultVal: null,

  /**
    Default title of the select button.
     This will be the title corresponding to the _defaultVal.

    @private
  */
  _defaultTitle: null,

  /**
    Default icon of the select button.
     This will be the icon corresponding to the _defaultVal.

    @private
  */
  _defaultIcon: null,

  /**
    The button theme will be popup

    @type String
    @default 'popup'
    @readOnly
  */
  theme: 'popup',

  /**
    @type SC.Array
    @default ['icon', 'value','controlSize']
    @see SC.View#displayProperties
  */
  displayProperties: ['icon', 'value','controlSize', 'escapeHTML', 'emptyName'],

  /**
    Prefer matrix to position the select button menu such that the
    selected item for the menu item will appear aligned to the
    the button. The value at the second index(0) changes based on the
    position(index) of the menu item in the menu pane.

    @type Array
    @default null
  */
  preferMatrix: null,

  /**
    Property to set the menu item height. This in turn is used for
    the calculation of prefMatrix.

    @type Number
    @default 20
  */
  CUSTOM_MENU_ITEM_HEIGHT: 20,

  /**
    Binds the button's selection state to the menu's visibility.

    @private
  */
  isActiveBinding: '*menu.isVisibleInWindow',

  /**
    If this property is set to 'YES', the menu pane will be positioned
    below the anchor.

    @type Boolean
    @default NO
  */
  isDefaultPosition: NO,

  /**
    lastMenuWidth is the width of the last menu which was created from
    the items of this select button.

    @private
  */
  lastMenuWidth: null,

  /**
    Example view used for menu items.

    @type SC.View
    @default null
  */
  exampleView: null,

  /**
    customView menu offset width

    @type Number
    @default 0
  */
  customViewMenuOffsetWidth: 0,

  /**
    This is a property for enabling/disabling ellipsis

    @type Boolean
    @default YES
  */
  needsEllipsis: YES,

  /**
    This property allows you at add extra padding to the height
    of the menu pane.

    @type Number
    @default 0
  */
  menuPaneHeightPadding: 0,

  /**
    The amount of space to add to the calculated width of the menu item strings to
    determine the width of the menu pane.

    @type Number
    @default 35
  */
  menuItemPadding: 35,

  /**
    @type Boolean
    @default NO
  */
  isContextMenuEnabled: NO,

  /**
    This is a property to enable/disable focus rings in buttons.
    For select_button, we are making it a default.

    @type Boolean
    @default YES
    @see SC.ButtonView#supportFocusRing
  */
  supportFocusRing: YES,

  /**
  * @private
  * Overwritten to calculate the content corresponding to items configured at creation
  */
  init: function() {
    arguments.callee.base.apply(this,arguments);

    this.itemsDidChange();
  },

  /**
    Left Alignment based on the size of the button

    @private
  */
  leftAlign: function () {
    switch (this.get('controlSize')) {
      case SC.TINY_CONTROL_SIZE:
        return SC.SelectView.TINY_OFFSET_X;
      case SC.SMALL_CONTROL_SIZE:
        return SC.SelectView.SMALL_OFFSET_X;
      case SC.REGULAR_CONTROL_SIZE:
        return SC.SelectView.REGULAR_OFFSET_X;
      case SC.LARGE_CONTROL_SIZE:
        return SC.SelectView.LARGE_OFFSET_X;
      case SC.HUGE_CONTROL_SIZE:
        return SC.SelectView.HUGE_OFFSET_X;
    }
    return 0;
  }.property('controlSize'),

  /**
    override this method to implement your own sorting of the menu. By
    default, menu items are sorted using the value shown or the sortKey

    @param {SC.Array} objects the unsorted array of objects to display.
    @returns {SC.Array} sorted array of objects
  */
  sortObjects: function (objects) {
    if (!this.get('disableSort')){
      var nameKey = this.get('itemSortKey') || this.get('itemTitleKey');
      objects = objects.sort(function (a,b) {
        if (nameKey) {
          a = a.get ? a.get(nameKey) : a[nameKey];
          b = b.get ? b.get(nameKey) : b[nameKey];
        }
        return (a<b) ? -1 : ((a>b) ? 1 : 0);
      });
    }
    return objects;
  },

  /**
    Observer called whenever the items collection or an element of this collection changes

    @private
  */
  itemsDidChange: function() {
    var escapeHTML, items, len, nameKey, iconKey, valueKey, separatorKey, showCheckbox,
      currentSelectedVal, shouldLocalize, isSeparator, itemList, isChecked,
      idx, name, icon, value, item, itemEnabled, isEnabledKey, emptyName, isSameRecord;

    items = this.get('items') || [];
    items = this.sortObjects(items);
    len = items.length;

    //Get the nameKey, iconKey and valueKey set by the user
    nameKey = this.get('itemTitleKey');
    iconKey = this.get('itemIconKey');
    valueKey = this.get('itemValueKey');
    separatorKey = this.get('itemSeparatorKey');
    showCheckbox = this.get('showCheckbox');
    isEnabledKey = this.get('itemIsEnabledKey');
    escapeHTML = this.get('escapeHTML');

    //get the current selected value
    currentSelectedVal = this.get('value');

    // get the localization flag.
    shouldLocalize = this.get('localize');

    //itemList array to set the menu items
    itemList = [];

    //to set the 'checkbox' property of menu items
    isChecked = YES;

    //index for finding the first item in the list
    idx = 0;

    // Add the empty name to the list if applicable
    emptyName = this.get('emptyName');

    if (!SC.none(emptyName)) {
      emptyName = shouldLocalize ? SC.String.loc(emptyName) : emptyName;
      emptyName = escapeHTML ? SC.RenderContext.escapeHTML(emptyName) : emptyName;

      item = SC.Object.create({
        isSeparator: NO,
        title: emptyName,
        icon: null,
        value: null,
        isEnabled: YES,
        checkbox: NO,
        target: this,
        action: 'displaySelectedItem'
      });

      if (SC.none(currentSelectedVal)) {
        this.set('title', emptyName);
      }

      //Set the items in the itemList array
      itemList.push(item);
    }

    items.forEach(function (object) {
      if (object || object === 0) {
        


        // get the separator
        isSeparator = separatorKey ? (object.get ? object.get(separatorKey) : object[separatorKey]) : NO;

        if (isSeparator) {
          item = SC.Object.create({
            isSeparator: true,
            value: '_sc_separator_item'
          });
        } else {
          //Get the name value. If value key is not specified convert obj
          //to string
          name = nameKey ? (object.get ?
            object.get(nameKey) : object[nameKey]) : object.toString();

          

          // localize name if specified.
          name = shouldLocalize ? SC.String.loc(name) : name;
          name = escapeHTML ? SC.RenderContext.escapeHTML(name) : name;

          //Get the icon value
          icon = iconKey ? (object.get ?
            object.get(iconKey) : object[iconKey]) : null;
          if (SC.none(object[iconKey])) icon = null;

          // get the value using the valueKey or the object
          value = valueKey ? (object.get ?
            object.get(valueKey) : object[valueKey]) : object;

          if (!SC.none(currentSelectedVal) && !SC.none(value)) {

            // If the objects in question are records, we should just their storeKeys
            isSameRecord = false;
            if (SC.kindOf(currentSelectedVal, SC.Record) && SC.kindOf(value, SC.Record)) {
              isSameRecord = currentSelectedVal.get('storeKey') === value.get('storeKey');
            }

            if (currentSelectedVal === value || isSameRecord) {
              this.set('title', name);
              this.set('icon', icon);
            }
          }

          //Check if the item is currentSelectedItem or not
          if (value === this.get('value')) {

            //set the _itemIdx - To change the prefMatrix accordingly.
            this.set('_itemIdx', idx);
            isChecked = !showCheckbox ? NO : YES;
          } else {
            isChecked = NO;
          }

          // Check if the item is enabled
          itemEnabled = (object.get ? object.get(isEnabledKey) : object[isEnabledKey]);
          if (NO !== itemEnabled) itemEnabled = YES;

          // Set the first non-separator selectable item from the list as the
          // default selected item
          if (SC.none(this._defaultVal) && itemEnabled) {
            this._defaultVal = value;
            this._defaultTitle = name;
            this._defaultIcon = icon;
          }

          item = SC.Object.create({
            action: 'displaySelectedItem',
            title: name,
            icon: icon,
            value: value,
            isEnabled: itemEnabled,
            checkbox: isChecked,
            target: this
          });
        }

        //Set the items in the itemList array
        itemList.push(item);

      }

      idx += 1;

    }, this );

    this.set('_itemList', itemList);

    var value = this.get('value');
    if (SC.none(value)) {
      if (SC.none(emptyName)) {
        this.set('value', this._defaultVal);
        this.set('title', this._defaultTitle);
        this.set('icon', this._defaultIcon);
      }
      else this.set('title', emptyName);
    }

    //Set the preference matrix for the menu pane
    this.changeSelectPreferMatrix();
  }.observes( '*items.[]' ),

  /**
    @private
    @param {DOMMouseEvent} evt mouseup event that triggered the action
  */
  _action: function (evt) {
    var buttonLabel, menuWidth, scrollWidth, lastMenuWidth, offsetWidth,
      items, elementOffsetWidth, largestMenuWidth, item, idx,
      value, itemList, menuControlSize, menuHeightPadding, customView,
      menu, itemsLength, itemIdx, escapeHTML;

    buttonLabel = this.$('.sc-button-label')[0];

    var menuWidthOffset = SC.SelectView.MENU_WIDTH_OFFSET;
    if (!this.get('isDefaultPosition')) {
      switch (this.get('controlSize')) {
        case SC.TINY_CONTROL_SIZE:
          menuWidthOffset += SC.SelectView.TINY_POPUP_MENU_WIDTH_OFFSET;
          break;
        case SC.SMALL_CONTROL_SIZE:
          menuWidthOffset += SC.SelectView.SMALL_POPUP_MENU_WIDTH_OFFSET;
          break;
        case SC.REGULAR_CONTROL_SIZE:
          menuWidthOffset += SC.SelectView.REGULAR_POPUP_MENU_WIDTH_OFFSET;
          break;
        case SC.LARGE_CONTROL_SIZE:
          menuWidthOffset += SC.SelectView.LARGE_POPUP_MENU_WIDTH_OFFSET;
          break;
        case SC.HUGE_CONTROL_SIZE:
          menuWidthOffset += SC.SelectView.HUGE_POPUP_MENU_WIDTH_OFFSET;
          break;
      }
    }
    // Get the length of the text on the button in pixels
    menuWidth = this.get('layer').offsetWidth + menuWidthOffset;

    // Get the length of the text on the button in pixels
    menuWidth = this.get('layer').offsetWidth;
    scrollWidth = buttonLabel.scrollWidth;
    lastMenuWidth = this.get('lastMenuWidth');
    if (scrollWidth) {
       // Get the original width of the label in the button
       offsetWidth = buttonLabel.offsetWidth;
       if (scrollWidth && offsetWidth) {
          menuWidth = menuWidth + scrollWidth - offsetWidth;
       }
    }
    if (!lastMenuWidth || (menuWidth > lastMenuWidth)) {
      lastMenuWidth = menuWidth;
    }

    items = this.get('_itemList');

    var customViewClassName = this.get('customViewClassName');
    // var customViewMenuOffsetWidth = this.get('customViewMenuOffsetWidth');
    var className = 'sc-view sc-pane sc-panel sc-palette sc-picker sc-menu select-button sc-scroll-view sc-menu-scroll-view sc-container-view menuContainer sc-button-view sc-menu-item sc-regular-size';
    className = customViewClassName ? (className + ' ' + customViewClassName) : className;

    SC.prepareStringMeasurement("", className);
    for (idx = 0, itemsLength = items.length; idx < itemsLength; ++idx) {
      //getting the width of largest menu item
      item = items.objectAt(idx);
      elementOffsetWidth = SC.measureString(item.title).width;

      if (!largestMenuWidth || (elementOffsetWidth > largestMenuWidth)) {
        largestMenuWidth = elementOffsetWidth;
      }
    }
    SC.teardownStringMeasurement();

    lastMenuWidth = (largestMenuWidth + this.menuItemPadding > lastMenuWidth) ?
                      largestMenuWidth + this.menuItemPadding : lastMenuWidth;

    // Get the window size width and compare with the lastMenuWidth.
    // If it is greater than windows width then reduce the maxwidth by 25px
    // so that the ellipsis property is enabled by default
    var maxWidth = SC.RootResponder.responder.get('currentWindowSize').width;
    if (lastMenuWidth > maxWidth) {
      lastMenuWidth = (maxWidth - 25);
    }

    this.set('lastMenuWidth',lastMenuWidth);
    value = this.get('value');
    itemList = this.get('_itemList');
    menuControlSize = this.get('controlSize');
    menuHeightPadding = this.get('menuPaneHeightPadding');
    escapeHTML = this.get('escapeHTML');

    // get the user defined custom view
    customView = this.get('exampleView') || SC.MenuItemView.extend({ escapeHTML: escapeHTML });

    menu  = SC.MenuPane.create({

      /**
        Class name - select-button-item
      */
      classNames: ['select-button'],

      /**
        The menu items are set from the itemList property of SelectView

        @property
      */
      items: itemList,

      /**
        Example view which will be used to create the Menu Items

        @default SC.MenuItemView
        @type SC.View
      */
      exampleView: customView,

      /**
        This property enables all the items and makes them selectable.

        @property
      */
      isEnabled: YES,

      menuHeightPadding: menuHeightPadding,

      preferType: SC.PICKER_MENU,
      itemHeightKey: 'height',
      layout: { width: lastMenuWidth },
      controlSize: menuControlSize,
      itemWidth: lastMenuWidth
    });

    // no menu to toggle... bail...
    if (!menu) return NO;
    menu.popup(this, this.preferMatrix);
    this.set('menu', menu);

    itemIdx = this._itemIdx;
    if (!SC.empty(itemIdx) && itemIdx > -1) {
    // if there is an item selected, make it the first responder
      customView = menu.menuItemViewForContentIndex(itemIdx);
      if (customView) { customView.becomeFirstResponder(); }
    }

    this.set('isActive', YES);
    return YES;
  },

  /** @private
     Action method for the select button menu items
  */
  displaySelectedItem: function (menuView) {
    var currentItem = menuView.get("selectedItem");

    this.set("value", currentItem.get("value"));
  },

  /** @private Each time the value changes, update each item's checkbox property and update our display properties. */
  valueDidChange: function () {
    var itemList = this._itemList,
      showCheckbox = this.get('showCheckbox'),
      value = this.get('value');

    // Find the newly selected item (if any).
    for (var i = 0, len = itemList.length; i < len; i++) {
      var item = itemList[i],
        isChecked = false;

      if (value === item.get('value')) {
        isChecked = showCheckbox;
        this.set("title", item.get("title"));
        this.set("icon", item.get("icon"));
        this.set("_itemIdx", item.get("contentIndex"));
      }

      item.set('checkbox', isChecked);
    }

  }.observes('value'),

  /** @private
     Set the "top" attribute in the prefer matrix property which will
     position menu such that the selected item in the menu will be
     place aligned to the item on the button when menu is opened.
  */
  changeSelectPreferMatrix: function () {
    var controlSizeTuning = 0, customMenuItemHeight = 0;
    switch (this.get('controlSize')) {
      case SC.TINY_CONTROL_SIZE:
        controlSizeTuning = SC.SelectView.TINY_OFFSET_Y;
        customMenuItemHeight = SC.MenuPane.TINY_MENU_ITEM_HEIGHT;
        break;
      case SC.SMALL_CONTROL_SIZE:
        controlSizeTuning = SC.SelectView.SMALL_OFFSET_Y;
        customMenuItemHeight = SC.MenuPane.SMALL_MENU_ITEM_HEIGHT;
        break;
      case SC.REGULAR_CONTROL_SIZE:
        controlSizeTuning = SC.SelectView.REGULAR_OFFSET_Y;
        customMenuItemHeight = SC.MenuPane.REGULAR_MENU_ITEM_HEIGHT;
        break;
      case SC.LARGE_CONTROL_SIZE:
        controlSizeTuning = SC.SelectView.LARGE_OFFSET_Y;
        customMenuItemHeight = SC.MenuPane.LARGE_MENU_ITEM_HEIGHT;
        break;
      case SC.HUGE_CONTROL_SIZE:
        controlSizeTuning = SC.SelectView.HUGE_OFFSET_Y;
        customMenuItemHeight = SC.MenuPane.HUGE_MENU_ITEM_HEIGHT;
        break;
    }

    var preferMatrixAttributeTop = controlSizeTuning,
      itemIdx = this.get('_itemIdx'),
      leftAlign = this.get('leftAlign'), defPreferMatrix, tempPreferMatrix;

    if (this.get('isDefaultPosition')) {
      defPreferMatrix = [1, 0, 3];
      this.set('preferMatrix', defPreferMatrix);
    } else {
      if (itemIdx) {
        preferMatrixAttributeTop = itemIdx * customMenuItemHeight +
          controlSizeTuning;
      }
      tempPreferMatrix = [leftAlign, -preferMatrixAttributeTop, 2];
      this.set('preferMatrix', tempPreferMatrix);
    }
  },

  /**
    @private
    Holding down the button should display the menu pane.
  */
  mouseDown: function (evt) {
    // Fast path, reject secondary clicks.
    if (evt.which !== 1) return false;

    if (!this.get('isEnabledInPane')) return YES; // handled event, but do nothing
    this.set('isActive', YES);
    this._isMouseDown = YES;
    this.becomeFirstResponder();
    this._action();
    return YES;
  },

  /** @private
    Because we responded YES to the mouseDown event, we have responsibility
    for handling the corresponding mouseUp event.

    However, the user may click on this button, then drag the mouse down to a
    menu item, and release the mouse over the menu item. We therefore need to
    delegate any mouseUp events to the menu's menu item, if one is selected.

    We also need to differentiate between a single click and a click and hold.
    If the user clicks and holds, we want to close the menu when they release.
    Otherwise, we should wait until they click on the menu's modal pane before
    removing our active state.

    @param {SC.Event} evt
    @returns {Boolean}
  */
  mouseUp: function (evt) {
    var menu = this.get('menu'), targetMenuItem;

    if (menu) {
      targetMenuItem = menu.getPath('rootMenu.targetMenuItem');

      if (targetMenuItem && menu.get('mouseHasEntered')) {
        // Have the menu item perform its action.
        // If the menu returns NO, it had no action to
        // perform, so we should close the menu immediately.
        if (!targetMenuItem.performAction()) menu.remove();
      } else {
        // If the user waits more than 200ms between mouseDown and mouseUp,
        // we can assume that they are clicking and dragging to the menu item,
        // and we should close the menu if they mouseup anywhere not inside
        // the menu.
        if (evt.timeStamp - this._mouseDownTimestamp > 400) {
          menu.remove();
        }
      }
    }

    // Reset state.
    this._isMouseDown = NO;
    this.set("isActive", NO);
    return YES;
  },

  /** @private
    Override mouseExited to not remove the active state on mouseexit.
  */
  mouseExited: function () {
    return YES;
  },

  /**
    @private
    Handle Key event - Down arrow key
  */
  keyDown: function (event) {
    if ( this.interpretKeyEvents(event) ) {
      return YES;
    }
    else {
      return arguments.callee.base.apply(this,arguments);
    }
  },

  /**
    @private
    Pressing the Up or Down arrow key should display the menu pane. Pressing escape should
    resign first responder.
  */
  moveUp: function(evt) {
    this._action();
    return YES;
  },
  /** @private */
  moveDown: function(evt) {
    this._action();
    return YES;
  },
  cancel: function(evt) {
    this.resignFirstResponder();
  },

  /** @private
    Override the button isSelectedDidChange function in order to not perform any action
    on selecting the select_button
  */
  _button_isSelectedDidChange: function () {

  }.observes('isSelected')

});

/**
  @static
  @type Number
  @default 0
*/
SC.SelectView.TINY_OFFSET_X = 0;

/**
  @static
  @type Number
  @default 0
*/
SC.SelectView.TINY_OFFSET_Y = 0;

/**
  @static
  @type Number
  @default 0
*/
SC.SelectView.TINY_POPUP_MENU_WIDTH_OFFSET = 0;


/**
  @static
  @type Number
  @default -18
*/
SC.SelectView.SMALL_OFFSET_X = -18;

/**
  @static
  @type Number
  @default 3
*/
SC.SelectView.SMALL_OFFSET_Y = 3;

/**
  @static
  @type Number
  @default 7
*/
SC.SelectView.SMALL_POPUP_MENU_WIDTH_OFFSET = 7;


/**
  @static
  @type Number
  @default -17
*/
SC.SelectView.REGULAR_OFFSET_X = -17;

/**
  @static
  @type Number
  @default 1
*/
SC.SelectView.REGULAR_OFFSET_Y = 0;

/**
  @static
  @type Number
  @default 4
*/
SC.SelectView.REGULAR_POPUP_MENU_WIDTH_OFFSET = 4;


/**
  @static
  @type Number
  @default -17
*/
SC.SelectView.LARGE_OFFSET_X = -17;

/**
  @static
  @type Number
  @default 6
*/
SC.SelectView.LARGE_OFFSET_Y = 6;

/**
  @static
  @type Number
  @default 3
*/
SC.SelectView.LARGE_POPUP_MENU_WIDTH_OFFSET = 3;


/**
  @static
  @type Number
  @default 0
*/
SC.SelectView.HUGE_OFFSET_X = 0;

/**
  @static
  @type Number
  @default 0
*/
SC.SelectView.HUGE_OFFSET_Y = 0;

/**
  @static
  @type Number
  @default 0
*/
SC.SelectView.HUGE_POPUP_MENU_WIDTH_OFFSET = 0;


/**
  @static
  @type Number
  @default -2
*/
SC.SelectView.MENU_WIDTH_OFFSET = -2;

/* >>>>>>>>>> BEGIN source/views/slider.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/** @class

  SliderView displays a horizontal slider control that you can use to choose
  from a spectrum (or a sequence) of values.

  The property `value` holds the slider's current value. You can set the
  `minimum`, `maximum` and `step` properties as well.

  @extends SC.View
  @extends SC.Control
  @since SproutCore 1.0
*/
SC.SliderView = SC.View.extend(SC.Control,
/** @scope SC.SliderView.prototype */ {

  /** @private */
  classNames: 'sc-slider-view',

  /** @private
    The WAI-ARIA role for slider view. This property's value should not be
    changed.

    @type String
  */
  ariaRole: 'slider',

  /**
    The current value of the slider.
  */
  value: 0.50,
  valueBindingDefault: SC.Binding.single().notEmpty(),

  /**
    The minimum value of the slider.

    @type Number
    @default 0
  */
  minimum: 0,
  minimumBindingDefault: SC.Binding.single().notEmpty(),

  /**
    Optionally specify the key used to extract the minimum slider value
    from the content object.  If this is set to null then the minimum value
    will not be derived from the content object.

    @type String
  */
  contentMinimumKey: null,

  /**
    The maximum value of the slider bar.

    @type Number
    @default 1
  */
  maximum: 1,
  maximumBindingDefault: SC.Binding.single().notEmpty(),

  /**
    Optionally specify the key used to extract the maximum slider value
    from the content object.  If this is set to null then the maximum value
    will not be derived from the content object.

    @type String
  */
  contentMaximumKey: null,

  /**
    Optionally set to the minimum step size allowed.

    All values will be rounded to this step size when displayed.

    @type Number
    @default 0.1
  */
  step: 0.1,

  /*
    When set to true, this draws and positions an element for each step, giving
    your theme the opportunity to show a mark at each step.

    @type Boolean
    @default false
  */
  markSteps: false,

  /*
    When set to true, this view handles mouse-wheel scroll events by changing the
    value. Set to false to prevent a slider in a scroll view from hijacking scroll
    events mid-scroll, for example.

    @type Boolean
    @default true
  */
  updateOnScroll: true,

  // ..........................................................
  // INTERNAL
  //

  /* @private The full list includes min, max, and stepPositions, but those are redundant with displayValue. */
  displayProperties: ['displayValue', 'markSteps'],

  /** @private
   @type Number
   The raw, unchanged value to be provided to screen readers and the like.
  */
  ariaValue: function() {
    return this.get('value');
  }.property('value').cacheable(),

  /* @private
    The name of the render delegate which is creating and maintaining
    the DOM associated with instances of this view.
  */
  renderDelegateName: 'sliderRenderDelegate',

  /*
    The value, converted to a percent out of 100 between maximum and minimum.

    @type Number
    @readonly
  */
  displayValue: function() {
    return this._displayValueForValue(this.get('value'));
  }.property('value', 'minimum', 'maximum', 'step').cacheable(),

  /*
    If a nonzero step is specified, this property contains an array of each step's value between
    min and max (inclusive).

    @type Array
    @default null
    @readonly
  */
  steps: function() {
    var step = this.get('step');
    // FAST PATH: No step.
    if (!step) return null;
    var min = this.get('minimum'),
      max = this.get('maximum'),
      cur = min,
      ret = [];
    while (cur < max) {
      ret.push(cur);
      cur += step;
      cur = Math.round(cur / step) * step;
    }
    ret.push(max);
    return ret;
  }.property('minimum', 'maximum', 'step').cacheable(),

  /*
    If a nonzero step is specified, this property contains an array of each step's position,
    expressed as a fraction between 0 and 1 (inclusive). You can use these values to generate
    and position labels for each step, for example.

    @type Array
    @default null
    @readonly
  */
  stepPositions: function() {
    var steps = this.get('steps');
    // FAST PATH: No steps.
    if (!steps) return null;
    var min = steps[0],
      max = steps[steps.length - 1],
      ret = [],
      len = steps.length, i;
    for (i = 0; i < len; i++) {
      ret[i] = Math.round((steps[i] - min) / (max - min) * 1000) / 1000;
    }
    return ret;
  }.property('steps').cacheable(),

  /** @private Given a particular value, returns the percentage value. */
  _displayValueForValue: function(value) {
    var min = this.get('minimum'),
        max = this.get('maximum'),
        step = this.get('step');

    // determine the constrained value.  Must fit within min & max
    value = Math.min(Math.max(value, min), max);

    // limit to step value
    if (!SC.none(step) && step !== 0) {
      value = Math.round(value / step) * step;
    }

    // determine the percent across
    value = Math.round((value - min) / (max - min) * 100);

    return value;
  },

  /** @private Clears the mouse just down flag. */
  _sc_clearMouseJustDown: function () {
    this._sc_isMouseJustDown = NO;
  },

  /** @private Flag used to track when the mouse is pressed. */
  _isMouseDown: NO,

  /** @private Flag used to track when mouse was just down so that mousewheel events firing as the finger is lifted don't shoot the slider over. */
  _sc_isMouseJustDown: NO,

  /** @private Timer used to track time immediately after a mouse up event. */
  _sc_clearMouseJustDownTimer: null,

  /* @private */
  mouseDown: function(evt) {
    // Fast path, reject secondary clicks.
    if (evt.which && evt.which !== 1) return false;

    if (!this.get('isEnabledInPane')) return YES; // nothing to do...
    this.set('isActive', YES);
    this._isMouseDown = YES ;

    // Clear existing mouse just down timer.
    if (this._sc_clearMouseJustDownTimer) {
      this._sc_clearMouseJustDownTimer.invalidate();
      this._sc_clearMouseJustDownTimer = null;
    }

    this._sc_isMouseJustDown = NO;

    return this._triggerHandle(evt, YES);
  },

  /* @private mouseDragged uses same technique as mouseDown. */
  mouseDragged: function(evt) {
    return this._isMouseDown ? this._triggerHandle(evt) : YES;
  },

  /* @private remove active class */
  mouseUp: function(evt) {
    if (this._isMouseDown) this.set('isActive', NO);
    var ret = this._isMouseDown ? this._triggerHandle(evt) : YES ;
    this._isMouseDown = NO;

    // To avoid annoying jitter from Magic Mouse (which sends mousewheel events while trying
    // to lift your finger after a drag), ignore mousewheel events for a small period of time.
    this._sc_isMouseJustDown = YES;
    this._sc_clearMouseJustDownTimer = this.invokeLater(this._sc_clearMouseJustDown, 250);

    return ret ;
  },

  /* @private */
  mouseWheel: function(evt) {
    if (!this.get('isEnabledInPane')) return NO;
    if (!this.get('updateOnScroll')) return NO;

    // If the Magic Mouse is pressed, it still sends mousewheel events rapidly, we don't want errant wheel
    // events to move the slider.
    if (this._isMouseDown || this._sc_isMouseJustDown) return NO;

    var min = this.get('minimum'),
        max = this.get('maximum'),
        step = this.get('step') || ((max - min) / 20),
        newVal = this.get('value') + ((evt.wheelDeltaX+evt.wheelDeltaY)*step),
        value = Math.round(newVal / step) * step;
    if (newVal< min) this.setIfChanged('value', min);
    else if (newVal> max) this.setIfChanged('value', max);
    else this.setIfChanged('value', newVal);
    return YES ;
  },

  /* @private */
  touchStart: function(evt){
    return this.mouseDown(evt);
  },

  /* @private */
  touchEnd: function(evt){
    return this.mouseUp(evt);
  },

  /* @private */
  touchesDragged: function(evt){
    return this.mouseDragged(evt);
  },

  /** @private
    Updates the handle based on the mouse location of the handle in the
    event.
  */
  _triggerHandle: function(evt, firstEvent) {
    var width = this.get('frame').width,
        min = this.get('minimum'), max=this.get('maximum'),
        step = this.get('step'), v=this.get('value'), loc;

    if(firstEvent){
      loc = this.convertFrameFromView({ x: evt.pageX }).x;
      this._evtDiff = evt.pageX - loc;
    }else{
      loc = evt.pageX-this._evtDiff;
    }

    // convert to percentage
    loc = Math.max(0, Math.min(loc / width, 1));

    // if the location is NOT in the general vicinity of the slider, we assume
    // that the mouse pointer or touch is in the center of where the knob should be.
    // otherwise, if we are starting, we need to do extra to add an offset
    if (firstEvent) {
      var value = this.get("value");
      value = (value - min) / (max - min);

      // if the value and the loc are within 16px
      if (Math.abs(value * width - loc * width) < 16) this._offset = value - loc;
      else this._offset = 0;
    }

    // add offset and constrain
    loc = Math.max(0, Math.min(loc + this._offset, 1));

    // convert to value using minimum/maximum then constrain to steps
    loc = min + ((max-min)*loc);
    if (!SC.none(step) && step !== 0) loc = Math.round(loc / step) * step ;

    // if changes by more than a rounding amount, set v.
    if (Math.abs(v-loc)>=0.01) {
      this.set('value', loc); // adjust
    }

    return YES ;
  },

  /** @private tied to the isEnabledInPane state */
  acceptsFirstResponder: function() {
    if (SC.FOCUS_ALL_CONTROLS) { return this.get('isEnabledInPane'); }
    return NO;
  }.property('isEnabledInPane'),

  /* @private TODO: Update to use interpretKeyEvents. */
  keyDown: function(evt) {
     // handle tab key
     if (evt.which === 9 || evt.keyCode === 9) {
       var view = evt.shiftKey ? this.get('previousValidKeyView') : this.get('nextValidKeyView');
       if(view) view.becomeFirstResponder();
       else evt.allowDefault();
       return YES ; // handled
     }
     if (evt.which >= 33 && evt.which <= 40){
       var min = this.get('minimum'),max=this.get('maximum'),
          step = this.get('step'),
          size = max-min, val=0, calculateStep, current=this.get('value');

       if (evt.which === 37 || evt.which === 38 || evt.which === 34 ){
         if (SC.none(step) || step === 0) {
           if(size<100){
             val = current-1;
           }else{
             calculateStep = Math.abs(size/100);
             if(calculateStep<2) calculateStep = 2;
             val = current-calculateStep;
           }
         }else{
           val = current-step;
         }
       }
       if (evt.which === 39 || evt.which === 40 || evt.which === 33 ){
           if (SC.none(step) || step === 0) {
              if(size<100){
                val = current + 2;
              }else{
                calculateStep = Math.abs(size/100);
                if(calculateStep<2) calculateStep =2;
                val = current+calculateStep;
              }
            }else{
              val = current+step;
            }
       }
       if (evt.which === 36){
         val=max;
       }
       if (evt.which === 35){
          val=min;
       }
       if(val>=min && val<=max) this.set('value', val);
     }else{
       evt.allowDefault();
       return NO;
     }
     return YES;
   },

  /* @private */
   contentKeys: {
     'contentValueKey': 'value',
     'contentMinimumKey': 'minimum',
     'contentMaximumKey': 'maximum',
     'contentIsIndeterminateKey': 'isIndeterminate'
   }
});

/* >>>>>>>>>> BEGIN source/views/source_list_group.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('mixins/collection_group');
sc_require('views/disclosure');

/**
  @class
  
  Displays a group view in a source list.  Handles displaying a disclosure
  triangle which can be used to show/hide children.
  
  @extends SC.View
  @extends SC.Control
  @extends SC.CollectionGroup
  @author Charles Jolley
  @author Erich Ocean
  @version 1.0
  @since 0.9
*/
SC.SourceListGroupView = SC.View.extend(SC.Control, SC.CollectionGroup,
/** @scope SC.SourceListGroupView.prototype */ {
  
  /**
    @type Array
    @default ['sc-source-list-group']
    @see SC.View#classNames
  */
  classNames: ['sc-source-list-group'],
  
  // ..........................................................
  // KEY PROPERTIES
  // 
  
  /**
    The content object the source list group will display.
    
    @type SC.Object
    @default null
  */
  content: null,
  
  /**
    The current group visibility.  Used by the source list to determine the 
    layout size of the group.
    
    @type Boolean
    @default YES
  */
  isGroupVisible: YES,
  
  /** 
    YES if group is showing its titlebar.
    
    Group views will typically hide their header if the content is set to 
    null.  You can also override this method to always hide the header if 
    you want and the SourceListView will not leave room for it.
    
    @type Boolean
    @default YES
  */
  hasGroupTitle: YES,
  
  /**
    The content property key to use as the group view's title.
    
    @type String
    @default null
  */
  groupTitleKey: null,
  
  /**
    The content property key to use to determine if the group's children are 
    visible or not.
    
    @type String
    @default null
  */
  groupVisibleKey: null,
  
  /** @private */
  render: function(context, firstTime) {
    context.push('<div role="button" class="sc-source-list-label sc-disclosure-view sc-button-view button disclosure no-disclosure">',
              '<img src="'+SC.BLANK_IMAGE_URL+'" class="button" />',
              '<span class="label"></span></div>') ;
  },
  
  /** @private */
  createChildViews: function() {
    
  },
  
  /** @private */
  contentPropertyDidChange: function(target, key) {
    var content = this.get('content') ;
    var labelView = this.outlet('labelView') ;
    
    // hide labelView if content is null.
    if (content === null) {
      labelView.setIfChanged('isVisible', NO) ;
      this.setIfChanged('hasGroupTitle', NO) ;
      return ;
    } else {
      labelView.setIfChanged('isVisible', YES) ;
      this.setIfChanged('hasGroupTitle', YES) ;
    }
    
   // set the title if that changed.
    var groupTitleKey = this.getDelegateProperty('groupTitleKey', this.displayDelegate) ;
    if ((key == '*') || (groupTitleKey && (key == groupTitleKey))) {
      var title = (content && content.get && groupTitleKey) ? content.get(groupTitleKey) : content;
      if (title != this._title) {
        this._title = title ;
        if (title) title = title.capitalize() ;
        labelView.set('title', title) ;
      }
    }
    
    // set the group visibility if changed
    var groupVisibleKey = this.getDelegateProperty('groupVisibleKey', this.displayDelegate) ;
    if ((key == '*') || (groupVisibleKey && (key == groupVisibleKey))) {
      if (groupVisibleKey) {
        labelView.removeClassName('no-disclosure') ;
        
        var isVisible = (content && content.get) ?
          !!content.get(groupVisibleKey) :
          YES ;
        if (isVisible != this.get('isGroupVisible')) {
          this.set('isGroupVisible', isVisible) ;
          labelView.set('value', isVisible) ;
        }
      } else labelView.addClassName('no-disclosure') ;
    }
  },
  
  /** @private
    Called when the user clicks on the disclosure triangle
  */
  disclosureValueDidChange: function(newValue) {
    if (newValue == this.get('isGroupVisible')) return; // nothing to do
    
    // update group if necessary
    var group = this.get('content') ;
    var groupVisibleKey = this.getDelegateProperty('groupVisibleKey', this.displayDelegate) ;
    if (group && group.set && groupVisibleKey) {
      group.set(groupVisibleKey, newValue) ;
    }
    
    // update my own value and then update my collection view.
    this.set('isGroupVisible', newValue) ;
    if (this.owner && this.owner.updateChildren) this.owner.updateChildren(true) ;
    
  },
  
  /** @private */
  labelView: SC.DisclosureView.extend({
    
    /** @private */
    value: YES,
    
    /** @private
      If the disclosure value changes, call the owner's method.  Note
      normally you would do this with a binding, but since this is a semi-
      private class anyway, there is no reason to go to all that trouble.
    */
    _valueObserver: function() {
      if (this.owner) this.owner.disclosureValueDidChange(this.get('value')) ;
    }.observes('value')
    
  })
  
});

/* >>>>>>>>>> BEGIN source/views/source_list.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('views/list');
sc_require('views/source_list_group');

/** @class
  
  Displays a source list like the source list in iTunes.  SourceList views
  are very similar to ListView's but come preconfigured with the correct
  appearance and default behaviors of a source list.
  
  @extends SC.ListView
  @since SproutCore 1.0
*/
SC.SourceListView = SC.ListView.extend(
/** @scope SC.SourceListView.prototype */ {
  
  theme: 'source-list',

  /**
    @type Array
    @default ['sc-source-list']
    @see SC.View#classNames
  */
  classNames: ['sc-source-list'],
  
  /**
    Default row height for source list items is larger.
    
    @type Number
    @default 32
    @see SC.ListView#rowHeight
  */
  rowHeight: 32,

  /**
    By default source lists should not select on mouse down since you will
    often want to drag an item instead of selecting it.
    
    @type Boolean
    @default NO
    @see SC.ListView#selectOnMouseDown
  */
  selectOnMouseDown: NO,
  
  /**
    By default, SourceListView's trigger any action you set whenever the user
    clicks on an item.  This gives the SourceList a "menu" like behavior.
    
    @type Boolean
    @default YES
    @see SC.ListView#actOnSelect
  */
  actOnSelect: YES

});

/* >>>>>>>>>> BEGIN source/views/split_divider.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2010 Sprout Systems, Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('mixins/split_child');
sc_require('mixins/split_thumb');

/**
  @class

  A SplitDividerView sits between any two other views in a SplitView.
  The SplitDivider mixes in SC.SplitThumb to allow the user to drag
  it around. The dragging process will cause SC.SplitView to adjust
  other children as needed.

  @extends SC.View
  @author Alex Iskander
*/
SC.SplitDividerView = SC.View.extend(SC.SplitChild, SC.SplitThumb,
/** @scope SC.SplitDividerView.prototype */ {

  /** @private */
  classNames: ['sc-split-divider-view'],

  /** @private */
  classNameBindings: ['layoutDirection'],
  
  /**
    Walks like a duck. Used and maintained by SC.SplitView to keep track
    of which of its childViews are dividers.

    @type Boolean
  */
  isSplitDivider: YES,

  /**
    The layout direction of the parent SplitView. May be SC.LAYOUT_VERTICAL
    or SC.LAYOUT_HORIZONTAL. This property is also added as a class on this
    view.
    
    You generally will not set this property yourself; it is managed by the
    parent SplitView.

    @type String
    @default SC.LAYOUT_HORIZONTAL
   */
  layoutDirection: SC.LAYOUT_HORIZONTAL,

  /** @private
    This indicates that the view should not resize while being dragged; this
    is generally the desired behavior.

    (NOTE: SC.FIXED_SIZE is hard-coded here. It is defined on SC.SplitView,
    which requires this file.)
   */
  autoResizeStyle: 'sc-fixed-size',

  movesSibling: SC.MOVES_CHILD,
  
  size: SC.propertyFromRenderDelegate('dividerSize', 10),

  renderDelegateName: 'splitDividerRenderDelegate'
});

/* >>>>>>>>>> BEGIN source/views/split.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2010 Sprout Systems, Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('views/split_divider');

/**
  Prevents the view from getting resized when the SplitView is resized,
  or the user resizes or moves an adjacent child view.
*/
SC.FIXED_SIZE = 'sc-fixed-size';

/**
  Prevents the view from getting resized when the SplitView is resized
  (unless the SplitView has resized all other views), but allows it to
  be resized when the user resizes or moves an adjacent child view.
*/
SC.RESIZE_MANUAL = 'sc-manual-size';

/**
  Allows the view to be resized when the SplitView is resized or due to
  the user resizing or moving an adjacent child view.
*/
SC.RESIZE_AUTOMATIC = 'sc-automatic-resize';


/**
  @class

  SC.SplitView arranges multiple views side-by-side or on top of each
  other.

  By default, SC.SplitView sets `size` and `position` properties on the
  child views, leaving it up to the child view to adjust itself. For good
  default behavior, mix SC.SplitChild into your child views.

  SplitView can resize its children to fit (the default behavior),
  or resize itself to fit its children--allowing you to build column-
  based file browsers and the like. As one child (a divider, most likely)
  is moved, SplitView can move additional children to get them out of the way.

  Setting Up SplitViews
  =======================================
  You can set up a split view like any other view in SproutCore:

      SplitView.design({
        childViews: ['leftPanel', 'rightPanel'],

        leftPanel: SC.View.design(SC.SplitChild, {
          minimumSize: 200
        }),

        rightPanel: SC.View.design(SC.SplitChild, {
          // it is usually the right panel you want to resize
          // as the SplitView resizes:
          autoResizeStyle: SC.RESIZE_AUTOMATIC
        })
      })

  Dividers
  =======================================
  Dividers are automatically added between every child view.

  You can specify what dividers to create in two ways:

  - Set splitDividerView to change the default divider view class to use.

  - Override splitViewDividerBetween(splitView, view1, view2), either in
    your subclass of SC.SplitView or in a delegate, and return the divider
    view instance that should go between the two views.

  As far as SplitView is concerned, dividers are actually just ordinary
  child views. They usually have an autoResizeStyle of SC.FIXED_SIZE, and
  usually mixin SC.SplitThumb to relay mouse and touch events to the SplitView.
  To prevent adding dividers between dividers and views or dividers and dividers,
  SC.SplitView marks all dividers with an isSplitDivider property.

  If you do not want to use split dividers at all, or wish to set them up
  manually in your childViews array, set splitDividerView to null.

  @extends SC.View
  @author Alex Iskander
*/
SC.SplitView = SC.View.extend({
  /**@scope SC.SplitView.prototype*/

  /**
    @type Array
    @default ['topLeftView', 'bottomRightView']
    @readonly
    @see SC.View#childViews
  */
  childViews: ['topLeftView', 'bottomRightView'],

  /**
    @type Array
    @default ['sc-split-view']
    @readonly
    @see SC.View#classNames
   */
  classNames: ['sc-split-view'],

  /**
    Used by the splitView computed property to find the nearest SplitView.

    @type Boolean
    @default true
    @readonly
   */
  isSplitView: YES,

  /**
   The class of view to create for the divider views. Override this to use a subclass of
   SC.SplitDividerView, or to implment your own.

   @type SC.View
   @default SC.SplitDividerView
  */
  splitDividerView: SC.SplitDividerView,

  /**
   Determines whether the SplitView should lay out its children
   horizontally or vertically.

   Possible values:

     - SC.LAYOUT_HORIZONTAL: side-by-side
     - SC.LAYOUT_VERTICAL: on top of each other

   @type LayoutDirection
   @default SC.LAYOUT_HORIZONTAL
  */
  layoutDirection: SC.LAYOUT_HORIZONTAL,

  /**
   * Determines whether the SplitView should attempt to resize its
   * child views to fit within the SplitView's own frame (the default).
   *
   * If NO, the SplitView will decide its own size based on its children.
   *
   * @type Boolean
   * @default true
  */
  shouldResizeChildrenToFit: YES,

  /**
   * The cursor of the child view currently being dragged (if any).
   * This allows the cursor to be used even if the user drags "too far",
   * past the child's own boundaries.
   *
   * @type String
   * @default null
  */
  splitChildCursorStyle: null,

  /** @private
    Only occurs during drag, which only happens after render, so we
    update directly.
  */
  _scsv_splitChildCursorDidChange: function() {
    this.get('cursor').set('cursorStyle', this.get('splitChildCursorStyle'));
  }.observes('splitChildCursorStyle'),

  /** @private */
  init: function() {
    // set up the SC.Cursor instance that this view and all the subviews
    // will share.
    this.cursor = SC.Cursor.create();
    arguments.callee.base.apply(this,arguments);
  },

  // RENDERING
  // Things like layoutDirection must be rendered as class names.
  // We delegate to a render delegate.
  //
  displayProperties: ['layoutDirection'],
  renderDelegateName: 'splitRenderDelegate',

  //
  // UTILITIES
  //
  /**
   * @private
   * Returns either the width or the height of the SplitView's frame,
   * depending on the value of layoutDirection. If layoutDirection is
   * SC.LAYOUT_HORIZONTAL, this will return the SplitView's width; otherwise,
   * the SplitView's height.
   *
   * @property
   * @type {Number}
  */
  _frameSize: function(){
    if (this.get('layoutDirection') === SC.LAYOUT_HORIZONTAL) {
      return this.get('frame').width;
    } else {
      return this.get('frame').height;
    }
  }.property('frame', 'layoutDirection').cacheable(),

  /** @private */
  viewDidResize: function () {
    this.scheduleTiling();

    arguments.callee.base.apply(this,arguments);
  },

  /** @private */
  layoutDirectionDidChange: function() {
    // Schedule tiling.
    this.scheduleTiling();
    // Propagate to dividers.
    var layoutDirection = this.get('layoutDirection'),
        childViews = this.get('childViews'),
        len = childViews ? childViews.get('length') : 0,
        i, view;
    for (i = 0; i < len; i++) {
      view = childViews[i];
      if (view.get('isSplitDivider')) view.setIfChanged('layoutDirection', layoutDirection);
    }
  }.observes('layoutDirection'),

  //
  // PUBLIC CHILD VIEW ADJUSTMENT API
  //
  /**
   * Attempts to adjust the position of a child view, such as a divider.
   *
   * The implementation for this may be overridden in the delegate method
   * splitViewAdjustPositionForChild.
   *
   * You may use this method to automatically collapse the view by setting
   * the view's position to the position of the next or previous view (accessible
   * via the child's nextView and previousView properties and the
   * getPositionForChild method).
   *
   * @param {SC.View} child The child to move.
   * @param {Number} position The position to move the child to.
   * @returns {Number} The position to which the child was actually moved.
  */
  adjustPositionForChild: function(child, position){
    return this.invokeDelegateMethod(this.get('delegate'), 'splitViewAdjustPositionForChild', this, child, position);
  },

  /**
   * Returns the position within the split view for a child view,
   * such as a divider. This position is not necessarily identical
   * to the view's actual layout 'left' or 'right'; that position could
   * be offset--for instance, to give a larger grab area to the divider.
   *
   * The implementation for this is in the delegate method
   * splitViewGetPositionForChild.
   *
   * @param {SC.View} child The child whose position to find.
   * @returns {Number} The position.
  */
  getPositionForChild: function(child){
    return this.invokeDelegateMethod(this.get('delegate'), 'splitViewGetPositionForChild', this, child);
  },

  //
  // CHILD VIEW MANAGEMENT
  //

  // When children are added and removed, we must re-run the setup process that
  // sets the SplitView child properties such as nextView, previousView, etc.,
  // and which adds dividers.
  didAddChild: function() {
    // we have to add a guard because _scsv_setupChildViews may add or remove
    // dividers, causing this method to be called again uselessly.
    // this is purely for performance. The guard goes here, rather than in
    // setupChildViews, because of the invokeOnce.
    if (this._scsv_settingUpChildViews) return;
    this._scsv_settingUpChildViews = YES;

    this.invokeOnce('_scsv_setupChildViews');

    this._scsv_settingUpChildViews = NO;
  },

  didRemoveChild: function() {
    // we have to add a guard because _scsv_setupChildViews may add or remove
    // dividers, causing this method to be called again uselessly.
    // this is purely for performance. The guard goes here, rather than in
    // setupChildViews, because of the invokeOnce.
    if (this._scsv_settingUpChildViews) return;
    this._scsv_settingUpChildViews = YES;

    this.invokeOnce('_scsv_setupChildViews');

    this._scsv_settingUpChildViews = NO;
  },

  createChildViews: function() {
    arguments.callee.base.apply(this,arguments);

    if (this._scsv_settingUpChildViews) return;
    this._scsv_settingUpChildViews = YES;

    this.invokeOnce('_scsv_setupChildViews');

    this._scsv_settingUpChildViews = NO;
  },

  /**
   * @private
   * During initialization and whenever the child views change, SplitView needs
   * to set some helper properties on the children and create any needed dividers.
   *
   * Note: If dividers are added, childViews changes, causing this to be called again;
   * this is proper, because this updates the nextView, etc. properties appropriately.
   *
   * The helper properties are: previousView, nextView, viewIndex.
  */
  _scsv_setupChildViews: function() {
    var del = this.get('delegate'),
        layoutDirection = this.get('layoutDirection'),

        children = this.get('childViews').copy(), len = children.length, idx,
        child, lastChild, lastNonDividerChild,

        oldDividers = this._scsv_dividers || {}, newDividers = {}, divider, dividerId;

    // loop through all children, keeping track of the previous child
    // as we loop using the lastChild variable.
    for (idx = 0; idx < len; idx++) {
      child = children[idx];

      // do initial setup of things like autoResizeStyle:
      if (!child.get('autoResizeStyle')) {
        if (child.get('size') !== undefined) {
          child.set('autoResizeStyle', SC.RESIZE_MANUAL);
        } else {
          child.set('autoResizeStyle', SC.RESIZE_AUTOMATIC);
        }
      }

      // we initialize the size first thing in case the size is empty (fill)
      // if it is empty, the way we position the views would lead to inconsistent
      // sizes. In addition, we will constrain all initial sizes so they'll be valid
      // when/if we auto-resize them.
      var size = this.invokeDelegateMethod(del, 'splitViewGetSizeForChild', this, child);
      size = this.invokeDelegateMethod(del, 'splitViewConstrainSizeForChild', this, child, size);
      this.invokeDelegateMethod(del, 'splitViewSetSizeForChild', this, child, size);

      child.previousView = lastChild;
      child.nextView = undefined;
      child.viewIndex = idx;

      if (lastChild) {
        lastChild.nextView = child;
      }

      if (lastNonDividerChild && !child.isSplitDivider) {
        dividerId = SC.guidFor(lastNonDividerChild) + "-" + SC.guidFor(child);

        // Try to re-use an existing divider.
        divider = oldDividers[dividerId];
        if (!divider) {
          divider = this.invokeDelegateMethod(del, 'splitViewDividerBetween', this, lastNonDividerChild, child);
        }

        if (divider) {
          divider.setIfChanged('isSplitDivider', YES);
          divider.setIfChanged('layoutDirection', layoutDirection);

          newDividers[dividerId] = divider;

          if (oldDividers[dividerId]) {
            delete oldDividers[dividerId];
          } else {
            this.insertBefore(divider, child);
          }
        }
      }


      lastChild = child;
      if (!child.isSplitDivider) lastNonDividerChild = child;
    }

    // finally, remove all dividers that we didn't keep
    for (dividerId in oldDividers) {
      oldDividers[dividerId].destroy();
    }

    this._scsv_dividers = newDividers;

    // retile immediately.
    this._scsv_tile();
  },

  //
  // BASIC LAYOUT CODE
  //

  /**
    Whether the SplitView needs to be re-laid out. You can change this by
    calling scheduleTiling.
  */
  needsTiling: YES,

  /**
    Schedules a retile of the SplitView.
  */
  scheduleTiling: function() {
    this.set('needsTiling', YES);
    this.invokeOnce('_scsv_tile');
  },

  tileIfNeeded: function() {
    if (!this.get('needsTiling')) return;
    this._scsv_tile();
  },

  /**
   * @private
   * Tiling is the simpler of two layout paths. Tiling lays out all of the
   * children according to their size, and, if shouldResizeChildrenToFit is
   * YES, attempts to resize the children to fit in the SplitView.
   *
   * It is called when the child views are initializing or have changed, and
   * when the SplitView is resized.
   *
  */
  _scsv_tile: function() {
    var del = this.get('delegate');

    // LOGIC:
    //
    // - Call splitViewLayoutChildren delegate method to position views and
    //   find total size.
    //
    // - If meant to automatically resize children to fit, run the
    //   splitViewResizeChildrenToFit delegate method.
    //
    // - Call splitViewLayoutChildren again if splitViewResizeChildrenToFit was called.
    //
    // - If not meant to automatically resize children to fit, change the SplitView
    //   size to match the total size of all children.

    var size, frameSize = this.get('_frameSize');

    size = this.invokeDelegateMethod(del, 'splitViewLayoutChildren', this);

    if (this.get('shouldResizeChildrenToFit') && size !== frameSize) {
      this.invokeDelegateMethod(del, 'splitViewResizeChildrenToFit', this, size);
      size = this.invokeDelegateMethod(del, 'splitViewLayoutChildren', this);
    }

    if (!this.get('shouldResizeChildrenToFit')) {
      if (this.get('layoutDirection') === SC.LAYOUT_HORIZONTAL) {
        this.adjust('width', size);
      } else {
        this.adjust('height', size);
      }
    }

    this.set('needsTiling', NO);
  },

  /**
   * Lays out the children one next to each other or one on top of the other,
   * based on their sizes. It returns the total size.
   *
   * You may override this method in a delegate.
   *
   * @param {SC.SplitView} splitView The SplitView whose children need layout.
   * @returns {Number} The total size of all the SplitView's children.
  */
  splitViewLayoutChildren: function(splitView) {
    var del = this.get('delegate');

    var children = this.get('childViews'), len = children.length, idx,
        child, pos = 0;

    for (idx = 0; idx < len; idx++) {
      child = children[idx];

      this.invokeDelegateMethod(del, 'splitViewSetPositionForChild', this, children[idx], pos);
      pos += this.invokeDelegateMethod(del, 'splitViewGetSizeForChild', this, children[idx]);
    }

    return pos;
  },

  /**
   * Attempts to resize the child views of the split view to fit in the SplitView's
   * frame. So it may proportionally adjust the child views, the current size of the
   * SplitView's content is passed.
   *
   * You may override this method in a delegate.
   *
   * @param {SC.SplitView} splitView The SC.SplitView whose children should be resized.
   * @param {Number} contentSize The current not-yet-resized size of the SplitView's content.
  */
  splitViewResizeChildrenToFit: function(splitView, contentSize) {
    var del = this.get('delegate');

    // LOGIC:
    //
    //   - 1) Size auto-resizable children in proportion to their existing sizes to attempt
    //     to fit within the target size— auto-resizable views have autoResizeStyle set
    //     to SC.RESIZE_AUTOMATIC.
    //
    //   - 2) Size non-auto-resizable children in proportion to their existing sizes—these
    //     views will _not_ have an autoResizeStyle of SC.RESIZE_AUTOMATIC.
    //

    var frameSize = this.get('_frameSize');
    var children = this.get('childViews'), len = children.length, idx,
        child, resizableSize = 0, nonResizableSize = 0, childSize;

    // To do this sizing while keeping things proportionate, the total size of resizable
    // views and the total size of non-auto-resizable views must be calculated independently.
    for (idx = 0; idx < len; idx++) {
      child = children[idx];

      childSize = this.invokeDelegateMethod(del, 'splitViewGetSizeForChild', this, child);

      if (this.invokeDelegateMethod(del, 'splitViewShouldResizeChildToFit', this, child)) {
        resizableSize += childSize;
      } else {
        nonResizableSize += childSize;
      }
    }

    var runningSize = contentSize;

    // we run through each twice: non-aggressively, then aggressively. This is controlled by providing
    // a -1 for the outOfSize. This tells the resizing to not bother with proportions and just resize
    // whatever it can.
    runningSize = this._resizeChildrenForSize(runningSize, frameSize, YES, resizableSize);
    runningSize = this._resizeChildrenForSize(runningSize, frameSize, YES, -1);
    runningSize = this._resizeChildrenForSize(runningSize, frameSize, NO, nonResizableSize);
    runningSize = this._resizeChildrenForSize(runningSize, frameSize, NO, -1);
  },

  /**
   * @private
   * Utility method used by splitViewResizeChildrenToFit to do the proportionate
   * sizing of child views.
   *
   * @returns {Number} The new runningSize.
  */
  _resizeChildrenForSize: function(runningSize, targetSize, useResizable, outOfSize) {
    var del = this.get('delegate');

    var children = this.get('childViews'), idx, len = children.length, child;

    var diff = targetSize - runningSize;
    for (idx = 0; idx < len; idx++) {
      child = children[idx];

      var originalChildSize = this.invokeDelegateMethod(del, 'splitViewGetSizeForChild', this, child),
          size = originalChildSize;

      var isResizable = this.invokeDelegateMethod(del, 'splitViewShouldResizeChildToFit', this, child);
      if (isResizable === useResizable) {
        // if outOfSize === -1 then we are aggressively resizing (not resizing proportionally)
        if (outOfSize === -1) size += diff;
        else size += (size / outOfSize) * diff;

        size = Math.round(size);

        size = this.invokeDelegateMethod(del, 'splitViewConstrainSizeForChild', this, child, size);
        this.invokeDelegateMethod(del, 'splitViewSetSizeForChild', this, child, size);


        // we remove the original child size—but we don't add it back.
        // we don't add it back because the load is no longer shared.
        if (outOfSize !== -1) outOfSize -= originalChildSize;
      }

      // We modify the old size to account for our changes so we can keep a running diff
      runningSize -= originalChildSize;
      runningSize += size;
      diff = targetSize - runningSize;
    }

    return runningSize;
  },

  /**
   * Determines whether the SplitView should attempt to resize the specified
   * child view when the SplitView's size changes.
   *
   * You may override this method in a delegate.
   *
   * @param {SC.SplitView} splitView The SplitView that owns the child.
   * @param {SC.View} child The child view.
   * @returns {Boolean}
  */
  splitViewShouldResizeChildToFit: function(splitView, child) {
    return (
      this.get('shouldResizeChildrenToFit')  &&
      child.get('autoResizeStyle') === SC.RESIZE_AUTOMATIC
    );
  },

  /**
   * Attempts to move a single child from its current position to
   * a desired position.
   *
   * You may override the behavior on a delegate.
   *
   * @param {SC.SplitView} splitView The splitView whose child should be moved.
   * @param {SC.View} child The child which should be moved.
   * @param {Number} position The position to attempt to move the child to.
   * @returns {Number} The final position of the child.
  */
  splitViewAdjustPositionForChild: function(splitView, child, position) {
    // var del = this.get('delegate');
    // Unlike tiling, the process of moving a child view is much more sophisticated.
    //
    // The basic sequence of events is simple:
    //
    //  - resize previous child
    //  - resize the child itself to compensate for its movement if
    //    child.compensatesForMovement is YES.
    //  - adjust position of next child.
    //
    // As the process is recursive in both directions (resizing a child may attempt
    // to move it if it cannot be resized further), adjusting one child view could
    // affect many _if not all_ of the SplitView's children.
    //
    // For safety, sanity, and stability, the recursive chain-reactions only travel
    // in one direction; for instance, resizing the previous view may attempt to adjust
    // its position, but that adjustment will not propagate to views after it.
    //
    // This process, while powerful, has one complication: if you change a bunch of views
    // before a view, and then _fail_ to move views after it, the views before must be
    // moved back to their starting points. But if their positions were changed directly,
    // this would be impossible.
    //
    // As such, the positions are not changed directly. Rather, the changes are written
    // to a _plan_, and changes only committed once everything is finalized.
    //
    // splitViewAdjustPositionForChild is the entry point, and as such is responsible
    // for triggering the creation of the plan, the needed modifications, and the
    // finalizing of it.
    var plan = this._scsv_createPlan();
    var finalPosition = this._scsv_adjustPositionForChildInPlan(plan, child, position, child);
    this._scsv_commitPlan(plan);

    return finalPosition;
  },

  /**
   * @private
   * Creates a plan in which to prepare changes to the SplitView's children.
   *
   * A plan is an array with the same number of elements as the SplitView has children.
   * Each element is a hash containing these properties:
   *
   * - child: the view the hash represents
   * - originalPosition: the position before the planning process
   * - position: the planned new position.
   * - originalSize: the size before the planning process
   * - size: the planned new size.
   *
   * The repositioning and resizing logic can, at any time, reset part of the plan
   * to its original state, allowing layout processes to be run non-destructively.
   * In addition, storing the original positions and sizes is more performant
   * than looking them up each time.
   *
   * @returns {Plan}
  */
  _scsv_createPlan: function() {
    var del = this.get('delegate'),
        plan = [], children = this.get('childViews'), idx, len = children.length,
        child, childPosition, childSize;

    for (idx = 0; idx < len; idx++) {
      child = children[idx];
      childPosition = this.invokeDelegateMethod(del, 'splitViewGetPositionForChild', this, child);
      childSize = this.invokeDelegateMethod(del, 'splitViewGetSizeForChild', this, child);

      plan[idx] = {
        child: child,
        originalPosition: childPosition,
        position: childPosition,
        originalSize: childSize,
        size: childSize
      };
    }

    return plan;
  },

  /**
    * @private
    * Resets a range of the plan to its original settings.
    *
    * @param {Plan} plan The plan.
    * @param {Number} first The first item in the range.
    * @param {Number} last The last item in the range.
   */
   _scsv_resetPlanRange: function(plan, first, last) {
     for (var idx = first; idx <= last; idx++) {
       plan[idx].position = plan[idx].originalPosition;
       plan[idx].size = plan[idx].originalSize;
     }
   },

  /**
   * @private
   * Commits the changes specified in the plan to the child views.
   *
   * @param {Plan} plan The plan with the changes.
  */
  _scsv_commitPlan: function(plan) {
    var del = this.get('delegate'), len = plan.length, idx, item, end = 0;

    for (idx = 0; idx < len; idx++) {
      item = plan[idx];
      if (item.size !== item.originalSize) {
        this.invokeDelegateMethod(del, 'splitViewSetSizeForChild', this, item.child, item.size);
      }

      if (item.position !== item.originalPosition) {
        this.invokeDelegateMethod(del, 'splitViewSetPositionForChild', this, item.child, item.position);
      }

      end = item.position + item.size;
    }


    if (!this.get('shouldResizeChildrenToFit')) {
      if (this.get('layoutDirection') === SC.LAYOUT_HORIZONTAL) {
        this.adjust('width', end);
      } else {
        this.adjust('height', end);
      }
    }
  },

  /**
   * Moves the specified child view as close as it can to the specified
   * position, saving all changes this causes into the plan.
   *
   * The "directness" of the action also comes into play. An action is direct if:
   *
   * - The child being modified is the originating child (the one being dragged, most likely)
   * - The child is being _positioned_ as is immediately _after_ the originating child.
   * - The child is being _sized_ and is immediately _before_ the originating child.
   *
   * This means that direct actions modify the originating child or the border between
   * it and a sibling. Some child views don't like to accept indirect actions, as the
   * indirect actions may confuse or annoy users in some cases.
   *
   * @param {Plan} plan The plan write changes to (and get some data from).
   * @param {SC.View} child The child to move.
   * @param {Number} position The position to attempt to move the child to.
   * @param {Boolean} source The child from which the attempt to adjust originated—used
   * to determine directness.
   *
   * @returns {Number} The final position of the child.
  */
  _scsv_adjustPositionForChildInPlan: function(plan, child, position, source) {
    var del = this.get('delegate');

    if (
      !child.get('allowsIndirectAdjustments') &&
      source !== child && source !== child.previousView
    ) {
      return plan[child.viewIndex].position;
    }

    // since the process is recursive, we need to prevent the processing from
    // coming back in this direction.
    if (child._splitViewIsAdjusting) {
      return plan[child.viewIndex].position;
    }

    child._splitViewIsAdjusting = YES;

    //
    // STEP 1: attept to resize the previous child.
    //
    var previousChild = child.previousView, nextChild = child.nextView,
        previousChildPosition, previousChildSize,
        nextChildPosition, nextChildSize,
        size = plan[child.viewIndex].size;

    if (previousChild && !previousChild._splitViewIsAdjusting) {
      // we determine the size we would like it to be by subtracting its position
      // from the position _we_ would like to have.
      previousChildPosition = plan[previousChild.viewIndex].position;
      previousChildSize = position - previousChildPosition;

      previousChildSize = this._scsv_adjustSizeForChildInPlan(
        plan, previousChild, previousChildSize, source
      );

      // the child may not have resized/moved itself all the way, so we will
      // recalculate the target position based on how much it _was_ able to.
      position = previousChildPosition + previousChildSize;
    } else if (!previousChild) {
      // if there is no previous child view, then this is the first view and
      // as such _must_ be at 0.
      position = 0;
    }

    // further steps deal with children _after_ this one; these steps should
    // not be performed if those children are already being taken care of.
    if (nextChild && nextChild._splitViewIsAdjusting) {
      child._splitViewIsAdjusting = NO;
      plan[child.viewIndex].position = position;
      return position;
    }


    //
    // STEP 2: attempt to resize this view to avoid moving the next one.
    // Only occurs if the view's settings tell it to compensate _and_ there is a
    // next view to compensate for, or we are resizing to fit and there _is no_ next child.
    //
    if (child.get('compensatesForMovement') && nextChild) {
      nextChildPosition = plan[nextChild.viewIndex].position;
      size = this._scsv_adjustSizeForChildInPlan(plan, child, nextChildPosition - position);
    } else if (!nextChild && this.get('shouldResizeChildrenToFit')) {
      nextChildPosition = this.get('_frameSize');
      size = this._scsv_adjustSizeForChildInPlan(plan, child, nextChildPosition - position);
      position = nextChildPosition - size;
    }

    // STEP 3: attempt to move the next child to account for movement of this one.
    if (nextChild) {
      nextChildPosition = position + size;
      nextChildPosition = this._scsv_adjustPositionForChildInPlan(plan, nextChild, nextChildPosition, source);
    }

    // if we were unable to position the next child, or there is no next
    // child but we need to resize children to fit, we have to undo some
    // of our previous work.
    if (nextChildPosition && position !== nextChildPosition - size) {
      position = nextChildPosition - size;

      // then, for whatever is left, we again resize the previous view, after throwing
      // away the previous calculations.
      if (previousChild && !previousChild._splitViewIsAdjusting) {
        this._scsv_resetPlanRange(plan, 0, previousChild.viewIndex);
        previousChildSize = position - plan[previousChild.viewIndex].position;
        this._scsv_adjustSizeForChildInPlan(plan, previousChild, previousChildSize, child);
      }

    }


    plan[child.viewIndex].position = position;
    child._splitViewIsAdjusting = NO;
    return position;
  },

  _scsv_adjustSizeForChildInPlan: function(plan, child, size, source) {
    var del = this.get('delegate');

    if (
      source &&
      !child.get('allowsIndirectAdjustments') &&
      source !== child && source !== child.nextView && source !== child.previousView
    ) {
      return plan[child.viewIndex].size;
    }

    // First, see if resizing alone will do the job.
    var actualSize = this.invokeDelegateMethod(del, 'splitViewConstrainSizeForChild', this, child, size);

    plan[child.viewIndex].size = actualSize;

    if (size === actualSize) return size;

    // if not, attempt to move the view.
    var currentPosition = plan[child.viewIndex].position,
        targetPosition = currentPosition + size - actualSize;

    var position = this._scsv_adjustPositionForChildInPlan(plan, child, targetPosition, source);

    // the result is the new right edge minus the old left edge—that is,
    // the size we can pretend we are for the caller, now that we have
    // resized some other views.
    return position + actualSize - currentPosition;
  },

  /**
   * Returns a view instance to be used as a divider between two other views,
   * or null if no divider should be used.
   *
   * The value of the 'splitDividerView' property will be instantiated. The default
   * value of this property is 'SC.SplitDividerView'. If the value is null or undefined,
   * null will be returned, and the SplitView will not automatically create dividers.
   *
   * You may override this method in a delegate.
   *
   * @param {SC.SplitView} splitView The split view that is hte parent of the
   * two views.
   * @param {SC.View} view1 The first view.
   * @param {SC.View} view2 The second view.
   * @returns {SC.View} The view instance to use as a divider.
  */
  splitViewDividerBetween: function(splitView, view1, view2){
    if (!this.get('splitDividerView')) return null;

    return this.get('splitDividerView').create();
  },

  /**
   * Returns the current position for the specified child.
   *
   * You may override this in a delegate.
   *
   * @param {SC.SplitView} splitView The SplitView which owns the child.
   * @param {SC.View} child The child.
   * @returns Number
  */
  splitViewGetPositionForChild: function(splitView, child) {
    return child.get('position');
  },

  /**
   * Sets the position for the specified child.
   *
   * You may override this in a delegate.
   *
   * @param {SC.SplitView} splitView The SplitView which owns the child.
   * @param {SC.View} child The child.
   * @param {Number} position The position to move the child to.
  */
  splitViewSetPositionForChild: function(splitView, child, position) {
    child.set('position', position);
  },

  /**
   * Returns the current size for the specified child.
   *
   * You may override this in a delegate.
   *
   * @param {SC.SplitView} splitView The SplitView which owns the child.
   * @param {SC.View} child The child.
   * @returns Number
  */
  splitViewGetSizeForChild: function(splitView, child) {
    var size = child.get('size');
    if (SC.none(size)) return 100;

    return size;
  },

  /**
   * Sets the size for the specified child.
   *
   * You may override this in a delegate.
   *
   * @param {SC.SplitView} splitView The SplitView which owns the child.
   * @param {SC.View} child The child.
   * @param {Number} position The size to give the child.
  */
  splitViewSetSizeForChild: function(splitView, child, size) {
    child.set('size', size);
  },

  /**
   * Returns the nearest valid size to a proposed size for a child view.
   * By default, constrains the size to the range specified by the child's
   * minimumSize and maximumSize properties, and returns 0 if the child
   * has canCollapse set and the size is less than the child's collapseAtSize.
   *
   * You may override this in a delegate.
   *
   * @param {SC.SplitView} splitView The SplitView which owns the child.
   * @param {SC.View} child The child.
   * @param {Number} position The proposed size for the child.
   * @returns Number
  */
  splitViewConstrainSizeForChild: function(splitView, child, size) {
    if (child.get('autoResizeStyle') === SC.FIXED_SIZE) {
      return this.invokeDelegateMethod(this.get('delegate'), 'splitViewGetSizeForChild', this, child);
    }

    if (child.get('canCollapse')) {
      var collapseAtSize = child.get('collapseAtSize');
      if (collapseAtSize && size < collapseAtSize) return 0;
    }

    var minSize = child.get('minimumSize') || 0;
    if (minSize !== undefined && minSize !== null) size = Math.max(minSize, size);

    var maxSize = child.get('maximumSize');
    if (maxSize !== undefined && maxSize !== null) size = Math.min(maxSize, size);

    return size;
  }
});

/* >>>>>>>>>> BEGIN source/views/stacked.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('views/collection');

/**
  @class

  A StackedView is a CollectionView that expects its content to use static
  layout to stack vertically.  This type of collection view is not designed
  for use with large size collections, but it can be very useful for
  collections with complex displays and variable heights such as comments or
  small notification queues.

  ## Static Layout

  This view makes no attempt to size or position your child views.  It assumes
  you are using StaticLayout for your child views.  If you don't enable static
  layout your views will probably overlay on top of each other and will look
  incorrect.

  Note also that the default layout for this view set's the height to "auto".
  This is usually the behavior you will want.

  @extends SC.CollectionView
  @since SproutCore 0.9
*/
SC.StackedView = SC.CollectionView.extend(
/** @scope SC.StackedView.prototype */ {

  /**
    @type Array
    @default ['sc-stacked-view']
    @see SC.View#classNames
  */
  classNames: ['sc-stacked-view'],

  /**
    Default layout for a stacked view will fill the parent view but auto-
    adjust the height of the view.

    @type Hash
    @default `{ top: 0, left: 0, right: 0, height: 1 }`
    @see SC.View#layout
  */
  layout: { top: 0, left: 0, right: 0, height: 1 },

  /**
    Return full range of its indexes for nowShowing

    @param {Rect} rect
    @returns {SC.IndexSet} full range of indexes
  */
  computeNowShowing: function () {
    return this.get('allContentIndexes');
  },

  /**
    Updates the height of the stacked view to reflect the current content of
    the view.  This is called automatically whenever an item view is reloaded.
    You can also call this method directly if the height of one of your views
    has changed.

    The height will be recomputed based on the actual location and dimensions
    of the last child view.

    Note that normally this method will defer actually updating the height
    of the view until the end of the run loop.  You can force an immediate
    update by passing YES to the "immediately" parameter.

    @param {Boolean} immediately YES to update immediately
    @returns {SC.StackedView} receiver
  */
  updateHeight: function (immediately) {
    if (immediately) this._updateHeight();
    else this.invokeLast(this._updateHeight);
    // ^ use invokeLast() here because we need to wait until all rendering has
    //   completed.

    return this;
  },

  /** @private */
  _updateHeight: function () {

    var childViews = this.get('childViews'),
        len        = childViews.get('length'),
        view, layer, height;

    if (len === 0) {
      height = 1;
    } else {
      view = childViews.objectAt(len - 1);
      layer = view ? view.get('layer') : null;
      height = layer ? (layer.offsetTop + layer.offsetHeight) : 1;
      layer = null; // avoid memory leaks
    }
    this.adjust('minHeight', height);
    this.set('calculatedHeight', height);
  },

  // ..........................................................
  // INTERNAL SUPPORT
  //

  /** @private
    Whenever the collection view reloads some views, reset the cache on the
    frame as well so that it will recalculate.
  */
  reloadIfNeeded: function () {
    arguments.callee.base.apply(this,arguments);

    return this.updateHeight();
  },

  /** @private
    When layer is first created, make sure we update the height using the
    newly calculated value.
  */
  didCreateLayer: function () { return this.updateHeight(); }

});

/* >>>>>>>>>> BEGIN source/views/static_content.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/** @class

  StaticContentView allows you to display arbitrary HTML content inside your
  view hierarchy.

  Normally, views in SproutCore are absolutely positioned. Their width and
  height are either pre-determined, or specified relative to their enclosing
  view. Occasionally, you may want to display content that is laid out by
  the browser. For example, if you were writing a documentation browser, you
  may want to display the table of contents as an SC.ListView, but the actual
  pages as HTML content.

  This class is most useful when placed inside a ScrollView.

  To use it, simply set the `content` property to a string of the HTML you
  would like to display.

  @extends SC.View
  @since SproutCore 1.2
  @author Tom Dale
*/
SC.StaticContentView = SC.View.extend(
/** @scope SC.StaticContentView.prototype */ {

  /**
    @type Array
    @default ['sc-static-content-view']
    @see SC.View#classNames
  */
  classNames: ['sc-static-content-view'],

  /**
    @type Array
    @default ['content']
    @see SC.View#displayProperties
  */
  displayProperties: ['content'],


  // ..........................................................
  // PROPERTIES
  //

  /**
    The HTML content you wish to display. This will be inserted directly into
    the DOM, so ensure that any user-generated content has been escaped.

    @type String
    @default null
  */
  content: null,

  // ..........................................................
  // METHODS
  //

  /**
    Because SproutCore has no way of knowing when the size of the content
    inside a StaticContentView has changed, you should call this method
    whenever an event that may change the size of the content occurs.

    Note that if you change the content property, this will be recalculated
    automatically.
  */
  contentLayoutDidChange: function() {
    this._sc_viewFrameDidChange();
  },

  // ..........................................................
  // INTERNAL SUPPORT
  //

  /** @private
    Disable SproutCore management of view positioning.
  */
  useStaticLayout: YES,

  /** @private
    Overrides SC.View's frame computed property, and returns a value from the
    DOM. This value is cached to improve performance.

    If the size of the content inside the view changes, you should call
    contentLayoutDidChange().

    @property
  */
  frame: function() {
    var layer = this.get('layer'), rect;

    if (!layer) return { x: 0, y: 0, width: 0, height: 0 };

    if (layer.getBoundingClientRect && !SC.browser.isIE8OrLower) {
      rect = layer.getBoundingClientRect();

      return {
        x: 0,
        y: 0,
        width: rect.width,
        height: rect.height
      };
    } else {
      return {
        x: 0,
        y: 0,
        width: layer.clientWidth,
        height: layer.clientHeight
      };
    }
  }.property('content').cacheable(),

  /** @private
    Recalculate content frame if our parent view resizes.
  */
  parentViewDidResize: function() {
    this.contentLayoutDidChange();
  },

  /** @private
    If the layer changes, make sure we recalculate the frame.
  */
  didUpdateLayer: function() {
    this.contentLayoutDidChange();
  },

  /** @private
    Outputs the content property to the DOM.

    @param {SC.RenderContext} context
    @param {Boolean} firstTime
  */
  render: function(context, firstTime) {
    var content = this.get('content');

    context.push(content || '');
  },

  /** @private */
  touchStart: function(evt){
    evt.allowDefault();
    return YES;
  },

  /** @private */
  touchEnd: function(evt){
    evt.allowDefault();
    return YES;
  }

});

/* >>>>>>>>>> BEGIN source/views/tab.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('views/segmented');

/**
  @static
  @type String
  @constant
*/
SC.TOP_LOCATION = 'top';

/**
  @static
  @type String
  @constant
*/
SC.TOP_TOOLBAR_LOCATION = 'top-toolbar';

/**
  @static
  @type String
  @constant
*/
SC.BOTTOM_LOCATION = 'bottom';

/**
  @class

  Incorporates a segmented view and a container view to display the selected
  tab.  Provide an array of items, which will be passed onto the segmented
  view.

  @extends SC.View
  @since SproutCore 1.0
*/
SC.TabView = SC.View.extend(
/** @scope SC.TabView.prototype */ {

  /** @private
    @type Array
    @default ['sc-tab-view']
    @see SC.View#classNames
  */
  classNames: ['sc-tab-view'],

  /** @private
    @type Array
    @default ['nowShowing']
    @see SC.View#displayProperties
  */
  displayProperties: ['nowShowing'],

  // ..........................................................
  // PROPERTIES
  //

 /**
    Set nowShowing with the view you want to display. (You may specify globally-accessible views
    like `MyApp.tabsPage.myTabView`, local views defined on the TabView itself like `myLocalTabView`,
    or deep local views like `.myLocalPage.myTabView`.)

    @type String
    @default null
  */
  nowShowing: null,

  /**
    The list of items for the SegmentedView, and specifying the associated view to display. For example:

        items: [
          { title: "Tab 1", value: "MyApp.tabsPage.view1" },
          { title: "Tab 2", value: "MyApp.tabsPage.view2" }
        ]

    (Note that if needed you can specify the item keys by specifying `itemTitleKey`, `itemValueKey`, et
    cetera, on your TabView.)

    @type Array
    @default []
  */
  items: [],

  /**
    @type String
    @default null
  */
  itemTitleKey: null,

  /**
    @type String
    @default null
  */
  itemValueKey: null,

  /**
    @type String
    @default null
  */
  itemIsEnabledKey: null,

  /**
    @type String
    @default null
  */
  itemIconKey: null,

  /**
    @type String
    @default null
  */
  itemWidthKey: null,

  /**
    @type String
    @default null
  */
  itemToolTipKey: null,

  /**
    @type Number
    @default SC.REGULAR_BUTTON_HEIGHT
  */
  tabHeight: SC.REGULAR_BUTTON_HEIGHT,

  /**
    Possible values:

      - SC.TOP_LOCATION
      - SC.TOP_TOOLBAR_LOCATION
      - SC.BOTTOM_LOCATION

    @type String
    @default SC.TOP_LOCATION
  */
  tabLocation: SC.TOP_LOCATION,

  /**
    If set, then the tab location will be automatically saved in the user
    defaults.  Browsers that support localStorage will automatically store
    this information locally.

    @type String
    @default null
  */
  userDefaultKey: null,


  // ..........................................................
  // FORWARDING PROPERTIES
  //

  /** @private Sync important changes with the child views. */
  _tab_nowShowingDidChange: function() {
    var content = this.get('nowShowing');

    // Sync the segmented view.
    this.get('segmentedView').set('value', content);

    // If the user default is set, save it.
    var defaultKey = this.get('userDefaultKey');
    if (defaultKey) {
      SC.userDefaults.set([defaultKey,'nowShowing'].join(':'), content);
    }

    // If it's a string, try to turn it into the object it references...
    if (SC.typeOf(content) === SC.T_STRING && content.length > 0) {
      var dotspot = content.indexOf('.');
      // No dot means a local property, either to this view or this view's page.
      if (dotspot === -1) {
        var tempContent = this.get(content);
        content = SC.kindOf(tempContent, SC.CoreView) ? tempContent : SC.objectForPropertyPath(content, this.get('page'));
      }
      // Dot at beginning means local property path.
      else if (dotspot === 0) {
        content = this.getPath(content.slice(1));
      }
      // Dot after the beginning
      else {
        content = SC.objectForPropertyPath(content);
      }
    }

    // Sync the container view.
    this.get('containerView').set('nowShowing', content);

    return this;
  }.observes('nowShowing'),

  /** @private */
  _tab_itemsDidChange: function() {
    this.get('segmentedView').set('items', this.get('items'));
    return this ;
  }.observes('items'),

  /** @private
    Restore userDefault key if set.
  */
  init: function() {
    arguments.callee.base.apply(this,arguments);
    this._tab_nowShowingDidChange()._tab_itemsDidChange();
    // Wake up the userDefaults support, if in use.
    var defaultKey = this.get('userDefaultKey');
    if (defaultKey) {
      defaultKey = [defaultKey,'nowShowing'].join(':');
      var nowShowing = SC.userDefaults.get(defaultKey);
      if (!SC.none(nowShowing)) this.set('nowShowing', nowShowing);
    }
  },

  /** @private */
  createChildViews: function() {
    var childViews  = [], containerView, layout,
        tabLocation = this.get('tabLocation'),
        tabHeight   = this.get('tabHeight'),
        controlSize = this.get('controlSize');

    if (tabLocation === SC.TOP_LOCATION) {
      layout = { top: tabHeight/2+1, left: 0, right: 0, bottom: 0, border: 1 };
    } else if (tabLocation === SC.TOP_TOOLBAR_LOCATION) {
      layout = { top: tabHeight+1, left: 0, right: 0, bottom: 0, border: 1 };
    } else {
      layout = { top: 0, left: 0, right: 0, bottom: (tabHeight/2) - 1, border: 1 };
    }

    containerView = this.containerView.extend({
      layout: layout,
      //adding the role
      ariaRole: 'tabpanel'
    });

    this.containerView = this.createChildView(containerView) ;

    //  The segmentedView managed by this tab view.  Note that this TabView uses
    //  a custom segmented view.  You can access this view but you cannot change
    // it.
    layout = (tabLocation === SC.TOP_LOCATION ||
              tabLocation === SC.TOP_TOOLBAR_LOCATION) ?
             { height: tabHeight, left: 0, right: 0, top: 0 } :
             { height: tabHeight, left: 0, right: 0, bottom: 0 } ;

    this.segmentedView = this.get('segmentedView').extend({
      layout: layout,

      controlSize: controlSize,

      /** @private
        When the value changes, update the parentView's value as well.
      */
      _sc_tab_segmented_valueDidChange: function() {
        var pv = this.get('parentView');
        if (pv) pv.set('nowShowing', this.get('value'));
      }.observes('value'),

      /** @private */
      init: function() {
        // before we setup the rest of the view, copy key config properties
        // from the owner view...
        var pv = this.get('parentView');
        if (pv) {
          SC._TAB_ITEM_KEYS.forEach(function(k) { this[k] = pv.get(k); }, this);
        }
        return arguments.callee.base.apply(this,arguments);
      }
    });

    this.segmentedView = this.createChildView(this.segmentedView);

    childViews.push(this.containerView);
    childViews.push(this.segmentedView);

    this.set('childViews', childViews);
    return this;
  },

  // ..........................................................
  // COMPONENT VIEWS
  //

  /**
    The containerView managed by this tab view.  Note that TabView uses a
    custom container view.  You can access this view but you cannot change
    it.

    @type SC.View
    @default SC.ContainerView
    @readOnly
  */
  containerView: SC.ContainerView.extend({ renderDelegateName: 'wellRenderDelegate' }),

  /**
    @type SC.View
    @default SC.SegmentedView
  */
  segmentedView: SC.SegmentedView

}) ;

SC._TAB_ITEM_KEYS = ['itemTitleKey', 'itemValueKey', 'itemIsEnabledKey', 'itemIconKey', 'itemWidthKey', 'itemToolTipKey', 'itemActionKey', 'itemTargetKey'];

/* >>>>>>>>>> BEGIN source/views/thumb.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2010 Sprout Systems, Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @class
  @deprecated Use a normal view and mix-in SC.SplitThumb.

  Kept to allow a modicum of backwards-compatibility. Please use
  a normal view and mix in SC.SplitThumb instead.

  @extends SC.View
  @author Alex Iskander
  @test in split
*/
SC.ThumbView = SC.View.extend(SC.SplitThumb,
/** @scope SC.ThumbView.prototype */ {
  classNames: ['sc-thumb-view'],
  
  init: function() {
    arguments.callee.base.apply(this,arguments);
    console.warn("SC.ThumbView is deprecated. Please use a normal view and mix in SC.SplitThumb instead.");
  }
});

/* >>>>>>>>>> BEGIN source/views/web.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/** @class

  Used to display an iframe. The source, (specified by the value property) of
  the iFrame should be from the same domain. (i.e. the src / value should be
  from the same domain) if you want to access the contents of the iframe.

  @extends SC.View
  @extends SC.Control
  @since SproutCore 1.0
*/
SC.WebView = SC.View.extend(SC.Control, {/** @scope SC.WebView.prototype */
  classNames: 'sc-web-view',

  /**
    @type Array
    @default ['value', 'shouldAutoResize']
    @see SC.View#displayProperties
  */
  displayProperties: ['value', 'shouldAutoResize'],

  /**
    The content of the iframe can be bigger than the size specified when creating
    the view. If you want the view to be auto-resized to the dimensions of the
    iframe, then set the value of this property to YES.
    The web view can be auto resized only if the contents are from the same
    domain as the parent domain.

    @type Boolean
    @default NO
  */
  shouldAutoResize: NO,

  /**
    @param {SC.RenderContext} context
    @param {Boolean} firstTime
  */
  render: function(context, firstTime) {
    var src = this.get('value') || '',
      iframe;

    if (firstTime) {
      context.push('<iframe src="' + src +
      '" style="position: absolute; width: 100%; height: 100%; border: 0px; margin: 0px; padding: 0px;"></iframe>');
    }
    else if(src!==this._lastSrc) {
      iframe = this.$('iframe');
      // clear out the previous src, to force a reload
      iframe.attr('src', 'javascript:;');
      iframe.attr('src', src);
    }

    this._lastSrc = src;
  },

  /**
    Called when the layer gets created.
  */
  didCreateLayer: function() {
    var f = this.$('iframe');
    // Attach an onload event to the iframe.
    SC.Event.add(f, 'load', this, this.iframeDidLoad);
  },

  /**
    Called before the layer gets destroyed.
  */
  willDestroyLayer: function() {
    var f = this.$('iframe');
    // Remove the onload event so that the iframe can be released
    SC.Event.remove(f, 'load', this, this.iframeDidLoad);
  },

  /**  @private
    Called when iframe onload event is fired.
    1. Resizes the view to fit the contents of the iframe using the
    scroll width and scroll height of the contents of the iframe

    The iframe contents can be accessed only when the src is from the same
    domain as the parent document
  */
  iframeDidLoad: function() {

    //fit the iframe to size of the contents.
    if (this.get('shouldAutoResize') === YES) {
      var contentWindow;
      var iframeElt = this.$('iframe')[0];
      if(iframeElt && iframeElt.contentWindow) {
        contentWindow = iframeElt.contentWindow;
        if(contentWindow && contentWindow.document && contentWindow.document.documentElement){
          var docElement = contentWindow.document.documentElement;
          // setting the width before the height gives more accurate results..
          // at least for the test iframe content i'm using.
          //TODO: try out document flows other than top to bottom.
          if (!SC.browser.isIE) {
            this.$().width(docElement.scrollWidth);
            this.$().height(docElement.scrollHeight);
          }
          else {
            this.$().width(docElement.scrollWidth + 12);
            this.$().height(docElement.scrollHeight + 5);
          }
        }
      }
    }
  }

});

/* >>>>>>>>>> BEGIN source/views/well.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @static
  @constant
  @type Number
  @default 15
*/
SC.WELL_CONTAINER_PADDING = 15;

/** @class

  A WellView is a ContainerView with a border. It's useful when you want to
  group a set of views. It allows you to easily switch its contents too.

  It has a default contentLayout that will replace the layout of the contentView.

  @extends SC.ContainerView
  @since SproutCore 1.0
  @test in progress
*/
SC.WellView = SC.ContainerView.extend(
/** @scope SC.WellView.prototype */ {

  /**
    @type Array
    @default ['sc-well-view']
    @see SC.View#classNames
  */
  classNames: 'sc-well-view',

  /**
    Layout for the content of the container view.
    @type Hash
  */
  contentLayout: {
    top: SC.WELL_CONTAINER_PADDING,
    bottom: SC.WELL_CONTAINER_PADDING,
    left: SC.WELL_CONTAINER_PADDING,
    right: SC.WELL_CONTAINER_PADDING
  },

  /**
    @type String
    @default 'wellRenderDelegate'
  */
  renderDelegateName: 'wellRenderDelegate',

  /** @private
     Overrides createChildViews and replaces the layout of the contentView
     with the one in contentLayout.
   */
  createChildView: function (view, attrs) {
    view = arguments.callee.base.apply(this,arguments);

    view.set('layout', this.contentLayout);
    return view;
  },

  /** @private
     Invoked whenever the content property changes.  This method will simply set the contentLayout
     in the new contentView.
   */
  _sc_contentViewDidChange: function () {
    var contentView = this.get('contentView');
    if (contentView) {  // [CC] add null test [/CC]
      contentView.set('layout', this.contentLayout);
    }

    arguments.callee.base.apply(this,arguments);
  }

});


/* >>>>>>>>>> BEGIN javascript.js */
/* >>>>>>>>>> BEGIN source/object_keys_polyfill.js */
/** @scope Object
  Polyfill for Object.keys().

  Supports using `Object.keys()` on browsers prior to the following:

  * Chrome 5
  * Firefox 4.0 (Gecko 2.0)
  * Internet Explorer 9
  * Opera 12
  * Safari 5
*/
// From https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object/keys
if (!Object.keys) {
  Object.keys = (function() {
    var hasOwnProperty = Object.prototype.hasOwnProperty,
        hasDontEnumBug = !({ toString: null }).propertyIsEnumerable('toString'),
        dontEnums = [
          'toString',
          'toLocaleString',
          'valueOf',
          'hasOwnProperty',
          'isPrototypeOf',
          'propertyIsEnumerable',
          'constructor'
        ],
        dontEnumsLength = dontEnums.length;

    return function(obj) {
      if (typeof obj !== 'object' && (typeof obj !== 'function' || obj === null)) {
        throw new TypeError('Object.keys called on non-object');
      }

      var result = [], prop, i;

      for (prop in obj) {
        if (hasOwnProperty.call(obj, prop)) {
          result.push(prop);
        }
      }

      if (hasDontEnumBug) {
        for (i = 0; i < dontEnumsLength; i++) {
          if (hasOwnProperty.call(obj, dontEnums[i])) {
            result.push(dontEnums[i]);
          }
        }
      }
      return result;
    };
  }());
}

/* >>>>>>>>>> BEGIN source/request_animation_frame_polyfill.js */
/** @scope window
  Polyfill for cross-browser backwards compatible window.requestAnimationFrame support.

  Supports using `window.requestAnimationFrame` on browsers prior to the following:

  * Chrome 10
  * Firefox 4.0 (Gecko 2.0)
  * Internet Explorer 10.0
  * Opera 15
  * Safari 6.0

  Modified from Erik Möller:
  http://my.opera.com/emoller/blog/2011/12/20/requestanimationframe-for-smart-er-animating
*/
(function() {
  var lastTime = 0;
  var vendors = ['ms', 'moz', 'webkit', 'o'];
  for (var x = 0; x < vendors.length && !window.requestAnimationFrame; ++x) {
    window.requestAnimationFrame = window[vendors[x]+'RequestAnimationFrame'];
    window.cancelRequestAnimationFrame = window[vendors[x]+
      'CancelRequestAnimationFrame'];
  }

  if (!window.requestAnimationFrame) {
    window.requestAnimationFrame = function(callback) {
      var currTime = new Date().getTime();
      var timeToCall = Math.max(0, 16 - (currTime - lastTime));
      var id = window.setTimeout(function() { callback(window.performance.now()); }, timeToCall);
      lastTime = currTime + timeToCall;
      return id;
    };
  }

  if (!window.cancelAnimationFrame) {
    window.cancelAnimationFrame = function(id) { clearTimeout(id); };
  }
}());


/* >>>>>>>>>> BEGIN javascript.js */
/* >>>>>>>>>> BEGIN source/core.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

// Place any global constants here

/* >>>>>>>>>> BEGIN source/data_sources/data_source.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  Indicates a value has a mixed state of both on and off.

  @type String
*/
SC.MIXED_STATE = '__MIXED__';

/** @class

  A DataSource connects an in-memory store to one or more server backends.
  To connect to a data backend on a server, subclass `SC.DataSource`
  and implement the necessary data source methods to communicate with the
  particular backend.

  ## Create a Data Source

  To implement the data source, subclass `SC.DataSource` in a file located
  either in the root level of your app or framework, or in a directory
  called "data_sources":

      MyApp.DataSource = SC.DataSource.extend({
        // implement the data source API...
      });

  ## Connect to a Data Source

  New SproutCore applications are wired up to fixtures as their data source.
  When you are ready to connect to a server, swap the use of fixtures with a
  call to the desired data source.

  In core.js:

      // change...
      store: SC.Store.create().from(SC.Record.fixtures)

      // to...
      store: SC.Store.create().from('MyApp.DataSource')

  Note that the data source class name is referenced by string since the file
  in which it is defined may not have been loaded yet. The first time a
  data store tries to access its data source it will look up the class name
  and instantiate that data source.

  ## Implement the Data Source API

  There are three methods that a data store invokes on its data source:

   * `fetch()` &mdash; called the first time you try to `find()` a query
     on a store or any time you refresh the record array after that.
   * `retrieveRecords()` &mdash; called when you access an individual
     record that has not been loaded yet
   * `commitRecords()` &mdash; called if the the store has changes
     pending and its `commitRecords()` method is invoked.

  The data store will call the `commitRecords()` method when records
  need to be created, updated, or deleted. If the server that the data source
  connects to handles these three actions in a uniform manner, it may be
  convenient to implement the `commitRecords()` to handle record
  creation, updating, and deletion.

  However, if the calls the data source will need to make to the server to
  create, update, and delete records differ from each other to a significant
  enough degree, it will be more convenient to rely on the default behavior
  of `commitRecords()` and instead implement the three methods that
  it will call by default:

   * `createRecords()` &mdash; called with a list of records that are new
     and need to be created on the server.
   * `updateRecords()` &mdash; called with a list of records that already
      exist on the server but that need to be updated.
   * `destroyRecords()` &mdash; called with a list of records that should
     be deleted on the server.

  ### Multiple records

  The `retrieveRecords()`, `createRecords()`, `updateRecords()` and
  `destroyRecords()` methods all work on multiple records. If your server
  API accommodates calls where you can  pass a list of records, this might
  be the best level at which to implement the Data Source API. On the other
  hand, if the server requires that you send commands for it for individual
  records, you can rely on the default implementation of these four methods,
  which will call the following for each individual record, one at a time:

   - `retrieveRecord()` &mdash; called to retrieve a single record.
   - `createRecord()` &mdash; called to create a single record.
   - `updateRecord()` &mdash; called to update a single record.
   - `destroyRecord()` &mdash; called to destroy a single record.


  ### Return Values

  All of the methods you implement must return one of three values:
   - `YES` &mdash; all the records were handled.
   - `NO` &mdash; none of the records were handled.
   - `SC.MIXED_STATE` &mdash; some, but not all of the records were handled.


  ### Store Keys

  Whenever a data store invokes one of the data source methods it does so
  with a storeKeys or storeKey argument. Store keys are transient integers
  assigned to each data hash when it is first loaded into the store. It is
  used to track data hashes as they move up and down nested stores (even if
  no associated record is ever created from it).

  When passed a storeKey you can use it to retrieve the status, data hash,
  record type, or record ID, using the following data store methods:

   * `readDataHash(storeKey)` &mdash; returns the data hash associated with
     a store key, if any.
   * `readStatus(storeKey)` &mdash; returns the current record status
     associated with the store key. May be `SC.Record.EMPTY`.
   * `SC.Store.recordTypeFor(storeKey)` &mdash; returns the record type for
     the associated store key.
   * `recordType.idFor(storeKey)` &mdash; returns the record ID for
     the associated store key. You must call this method on `SC.Record`
     subclass itself, not on an instance of `SC.Record`.

  These methods are safe for reading data from the store. To modify data
  in the data store you must use the store callbacks described below. The
  store callbacks will ensure that the record states remain consistent.

  ### Store Callbacks

  When a data store calls a data source method, it puts affected records into
  a `BUSY` state. To guarantee data integrity and consistency, these records
  cannot be modified by the rest of the application while they are in the `BUSY`
  state.

  Because records are "locked" while in the `BUSY` state, it is the data source's
  responsibility to invoke a callback on the store for each record or query that
  was passed to it and that the data source handled. To reduce the amount of work
  that a data source must do, the data store will automatically unlock the relevant
  records if the the data source method returned `NO`, indicating that the records
  were unhandled.

  Although a data source can invoke callback methods at any time, they should
  usually be invoked after receiving a response from the server. For example, when
  the data source commits a change to a record by issuing a command to the server,
  it waits for the server to acknowledge the command before invoking the
  `dataSourceDidComplete()` callback.

  In some cases a data source may be able to assume a server's response and invoke
  the callback on the store immediately. This can improve performance because the
  record can be unlocked right away.


  ### Record-Related Callbacks

  When `retrieveRecords()`, `commitRecords()`, or any of the related methods are
  called on a data source, the store puts any records to be handled by the data
  store in a `BUSY` state. To release the records the data source must invoke one
  of the record-related callbacks on the store:

   * `dataSourceDidComplete(storeKey, dataHash, id)` &mdash; the most common
     callback. You might use this callback when you have retrieved a record to
     load its contents into the store. The callback tells the store that the data
     source is finished with the storeKey in question. The `dataHash` and `id`
     arguments are optional and will replace the current dataHash and/or id. Also
     see "Loading Records" below.
   * `dataSourceDidError(storeKey, error)` &mdash; a data source should call this
     when a request could not be completed because an error occurred. The error
     argument is optional and can contain more information about the error.
   * `dataSourceDidCancel(storeKey)` &mdash; a data source should call this when
     an operation is cancelled for some reason. This could be used when the user
     is able to cancel an operation that is in progress.

  ### Loading Records into the Store

  Instead of orchestrating multiple `dataSourceDidComplete()` callbacks when loading
  multiple records, a data source can call the `loadRecords()` method on the store,
  passing in a `recordType`, and array of data hashes, and optionally an array of ids.
  The `loadRecords()` method takes care of looking up storeKeys and calling the
  `dataSourceDidComplete()` callback as needed.

  `loadRecords()` is often the most convenient way to get large blocks of data into
  the store, especially in response to a `fetch()` or `retrieveRecords()` call.


  ### Query-Related Callbacks

  Like records, queries that are passed through the `fetch()` method also have an
  associated status property; accessed through the `status`  property on the record
  array returned from `find()`. To properly reset this status, a data source must
  invoke an appropriate query-related callback on the store. The callbacks for
  queries are similar to those for records:

   * `dataSourceDidFetchQuery(query)` &mdash; the data source must call this when
     it has completed fetching any related data for the query. This returns the
     query results (i.e. the record array) status into a `READY` state. If the query is a 'remote'
     type, the ordered array of store keys representing the results from the server must be passed
     as a second argument.
   * `dataSourceDidErrorQuery(query, error)` &mdash; the data source should call
     this if it encounters an error in executing the query. This puts the query
     results into an `ERROR` state.
   * `dataSourceDidCancelQuery(query)` &mdash; the data source should call this
     if loading the results is cancelled.

  @extend SC.Object
  @since SproutCore 1.0
*/
SC.DataSource = SC.Object.extend( /** @scope SC.DataSource.prototype */ {

  // ..........................................................
  // SC.STORE ENTRY POINTS
  //


  /**

    Invoked by the store whenever it needs to retrieve data matching a
    specific query, triggered by find().  This method is called anytime
    you invoke SC.Store#find() with a query or SC.RecordArray#refresh().  You
    should override this method to actually retrieve data from the server
    needed to fulfill the query.  If the query is a remote query, then you
    will also need to provide the contents of the query as well.

    ### Handling Local Queries

    Most queries you create in your application will be local queries.  Local
    queries are populated automatically from whatever data you have in memory.
    When your fetch() method is called on a local queries, all you need to do
    is load any records that might be matched by the query into memory.

    The way you choose which queries to fetch is up to you, though usually it
    can be something fairly straightforward such as loading all records of a
    specified type.

    When you finish loading any data that might be required for your query,
    you should always call SC.Store#dataSourceDidFetchQuery() to put the query
    back into the READY state.  You should call this method even if you choose
    not to load any new data into the store in order to notify that the store
    that you think it is ready to return results for the query.

    ### Handling Remote Queries

    Remote queries are special queries whose results will be populated by the
    server instead of from memory.  Usually you will only need to use this
    type of query when loading large amounts of data from the server.

    Like local queries, to fetch a remote query you will need to load any data
    you need to fetch from the server and add the records to the store.  Once
    you are finished loading this data, however, you must also call
    SC.Store#dataSourceDidFetchQuery() with the array of storeKeys that
    represent the latest results from the server.

    If you want to support incremental loading from the server for remote
    queries, you can do so by passing a SC.SparseArray instance instead of
    a regular array of storeKeys and then populate the sparse array on demand.

    ### Handling Errors and Cancellations

    If you encounter an error while trying to fetch the results for a query
    you can call SC.Store#dataSourceDidErrorQuery() instead.  This will put
    the query results into an error state.

    If you had to cancel fetching a query before the results were returned,
    you can instead call SC.Store#dataSourceDidCancelQuery().  This will set
    the query back into the state it was in previously before it started
    loading the query.

    ### Return Values

    When you return from this method, be sure to return a Boolean.  YES means
    you handled the query, NO means you can't handle the query.  When using
    a cascading data source, returning NO will mean the next data source will
    be asked to fetch the same results as well.

    @param {SC.Store} store the requesting store
    @param {SC.Query} query query describing the request
    @returns {Boolean} YES if you can handle fetching the query, NO otherwise
  */
  fetch: function(store, query) {
    return NO ; // do not handle anything!
  },

  /**
    Called by the store whenever it needs to load a specific set of store
    keys.  The default implementation will call retrieveRecord() for each
    storeKey.

    You should implement either retrieveRecord() or retrieveRecords() to
    actually fetch the records referenced by the storeKeys .

    @param {SC.Store} store the requesting store
    @param {Array} storeKeys
    @param {Array} ids - optional
    @returns {Boolean} YES if handled, NO otherwise
  */
  retrieveRecords: function(store, storeKeys, ids) {
    return this._handleEach(store, storeKeys, this.retrieveRecord, ids);
  },

  /**
    Invoked by the store whenever it has one or more records with pending
    changes that need to be sent back to the server.  The store keys will be
    separated into three categories:

     - `createStoreKeys`: records that need to be created on server
     - `updateStoreKeys`: existing records that have been modified
     - `destroyStoreKeys`: records need to be destroyed on the server

    If you do not override this method yourself, this method will actually
    invoke `createRecords()`, `updateRecords()`, and `destroyRecords()` on the
    dataSource, passing each array of storeKeys.  You can usually implement
    those methods instead of overriding this method.

    However, if your server API can sync multiple changes at once, you may
    prefer to override this method instead.

    To support cascading data stores, be sure to return `NO` if you cannot
    handle any of the keys, `YES` if you can handle all of the keys, or
    `SC.MIXED_STATE` if you can handle some of them.

    @param {SC.Store} store the requesting store
    @param {Array} createStoreKeys keys to create
    @param {Array} updateStoreKeys keys to update
    @param {Array} destroyStoreKeys keys to destroy
    @param {Hash} params to be passed down to data source. originated
      from the commitRecords() call on the store
    @returns {Boolean} YES if data source can handle keys
  */
  commitRecords: function(store, createStoreKeys, updateStoreKeys, destroyStoreKeys, params) {
    var uret, dret, ret;
    if (createStoreKeys.length>0) {
      ret = this.createRecords.call(this, store, createStoreKeys, params);
    }

    if (updateStoreKeys.length>0) {
      uret = this.updateRecords.call(this, store, updateStoreKeys, params);
      ret = SC.none(ret) ? uret : (ret === uret) ? ret : SC.MIXED_STATE;
    }

    if (destroyStoreKeys.length>0) {
      dret = this.destroyRecords.call(this, store, destroyStoreKeys, params);
      ret = SC.none(ret) ? dret : (ret === dret) ? ret : SC.MIXED_STATE;
    }

    return ret || NO;
  },

  /**
    Invoked by the store whenever it needs to cancel one or more records that
    are currently in-flight.  If any of the storeKeys match records you are
    currently acting upon, you should cancel the in-progress operation and
    return `YES`.

    If you implement an in-memory data source that immediately services the
    other requests, then this method will never be called on your data source.

    To support cascading data stores, be sure to return `NO` if you cannot
    retrieve any of the keys, `YES` if you can retrieve all of the, or
    `SC.MIXED_STATE` if you can retrieve some of the.

    @param {SC.Store} store the requesting store
    @param {Array} storeKeys array of storeKeys to retrieve
    @returns {Boolean} YES if data source can handle keys
  */
  cancel: function(store, storeKeys) {
    return NO;
  },

  // ..........................................................
  // BULK RECORD ACTIONS
  //

  /**
    Called from `commitRecords()` to commit modified existing records to the
    store.  You can override this method to actually send the updated
    records to your store.  The default version will simply call
    `updateRecord()` for each storeKey.

    To support cascading data stores, be sure to return `NO` if you cannot
    handle any of the keys, `YES` if you can handle all of the keys, or
    `SC.MIXED_STATE` if you can handle some of them.

    @param {SC.Store} store the requesting store
    @param {Array} storeKeys keys to update
    @param {Hash} params
      to be passed down to data source. originated from the commitRecords()
      call on the store

    @returns {Boolean} YES, NO, or SC.MIXED_STATE

  */
  updateRecords: function(store, storeKeys, params) {
    return this._handleEach(store, storeKeys, this.updateRecord, null, params);
  },

  /**
    Called from `commitRecords()` to commit newly created records to the
    store.  You can override this method to actually send the created
    records to your store.  The default version will simply call
    `createRecord()` for each storeKey.

    To support cascading data stores, be sure to return `NO` if you cannot
    handle any of the keys, `YES` if you can handle all of the keys, or
    `SC.MIXED_STATE` if you can handle some of them.

    @param {SC.Store} store the requesting store
    @param {Array} storeKeys keys to update

    @param {Hash} params
      to be passed down to data source. originated from the commitRecords()
      call on the store

    @returns {Boolean} YES, NO, or SC.MIXED_STATE

  */
  createRecords: function(store, storeKeys, params) {
    return this._handleEach(store, storeKeys, this.createRecord, null, params);
  },

  /**
    Called from `commitRecords()` to commit destroyed records to the
    store.  You can override this method to actually send the destroyed
    records to your store.  The default version will simply call
    `destroyRecord()` for each storeKey.

    To support cascading data stores, be sure to return `NO` if you cannot
    handle any of the keys, `YES` if you can handle all of the keys, or
    `SC.MIXED_STATE` if you can handle some of them.

    @param {SC.Store} store the requesting store
    @param {Array} storeKeys keys to update
    @param {Hash} params to be passed down to data source. originated
      from the commitRecords() call on the store

    @returns {Boolean} YES, NO, or SC.MIXED_STATE

  */
  destroyRecords: function(store, storeKeys, params) {
    return this._handleEach(store, storeKeys, this.destroyRecord, null, params);
  },

  /** @private
    invokes the named action for each store key.  returns proper value
  */
  _handleEach: function(store, storeKeys, action, ids, params) {
    var len = storeKeys.length, idx, ret, cur, idOrParams;

    for(idx=0;idx<len;idx++) {
      idOrParams = ids ? ids[idx] : params;

      cur = action.call(this, store, storeKeys[idx], idOrParams);
      if (ret === undefined) {
        ret = cur ;
      } else if (ret === YES) {
        ret = (cur === YES) ? YES : SC.MIXED_STATE ;
      } else if (ret === NO) {
        ret = (cur === NO) ? NO : SC.MIXED_STATE ;
      }
    }
    return !SC.none(ret) ? ret : null ;
  },


  // ..........................................................
  // SINGLE RECORD ACTIONS
  //

  /**
    Called from `updatesRecords()` to update a single record.  This is the
    most basic primitive to can implement to support updating a record.

    To support cascading data stores, be sure to return `NO` if you cannot
    handle the passed storeKey or `YES` if you can.

    @param {SC.Store} store the requesting store
    @param {Array} storeKey key to update
    @param {Hash} params to be passed down to data source. originated
      from the commitRecords() call on the store
    @returns {Boolean} YES if handled
  */
  updateRecord: function(store, storeKey, params) {
    return NO ;
  },

  /**
    Called from `retrieveRecords()` to retrieve a single record.

    @param {SC.Store} store the requesting store
    @param {Array} storeKey key to retrieve
    @param {String} id the id to retrieve
    @returns {Boolean} YES if handled
  */
  retrieveRecord: function(store, storeKey, id) {
    return NO ;
  },

  /**
    Called from `createdRecords()` to created a single record.  This is the
    most basic primitive to can implement to support creating a record.

    To support cascading data stores, be sure to return `NO` if you cannot
    handle the passed storeKey or `YES` if you can.

    @param {SC.Store} store the requesting store
    @param {Array} storeKey key to update
    @param {Hash} params to be passed down to data source. originated
      from the commitRecords() call on the store
    @returns {Boolean} YES if handled
  */
  createRecord: function(store, storeKey, params) {
    return NO ;
  },

  /**
    Called from `destroyRecords()` to destroy a single record.  This is the
    most basic primitive to can implement to support destroying a record.

    To support cascading data stores, be sure to return `NO` if you cannot
    handle the passed storeKey or `YES` if you can.

    @param {SC.Store} store the requesting store
    @param {Array} storeKey key to update
    @param {Hash} params to be passed down to data source. originated
      from the commitRecords() call on the store
    @returns {Boolean} YES if handled
  */
  destroyRecord: function(store, storeKey, params) {
    return NO ;
  }

});

/* >>>>>>>>>> BEGIN source/data_sources/cascade.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('data_sources/data_source');

/** @class

  A cascading data source will actually forward requests onto an array of
  additional data sources, stopping when one of the data sources returns YES,
  indicating that it handled the request.

  You can use a cascading data source to tie together multiple data sources,
  treating them as a single namespace.

  ## Configuring a Cascade Data Source

  You will usually define your cascading data source in your main method after
  all the classes you have are loaded.

      MyApp.dataSource = SC.CascadeDataSource.create({
        dataSources: "prefs youtube photos".w(),

        prefs:   MyApp.PrefsDataSource.create({ root: "/prefs" }),
        youtube: YouTube.YouTubeDataSource.create({ apiKey: "123456" }),
        photos:  MyApp.PhotosDataSource.create({ root: "photos" })

      });

      MyApp.store.set('dataSource', MyApp.dataSource);

  Note that the order you define your dataSources property will determine the
  order in which requests will cascade from the store.

  Alternatively, you can use a more jQuery-like API for defining your data
  sources:

      MyApp.dataSource = SC.CascadeDataSource.create()
        .from(MyApp.PrefsDataSource.create({ root: "/prefs" }))
        .from(YouTube.YouTubeDataSource.create({ apiKey: "123456" }))
        .from(MyApp.PhotosDataSource.create({ root: "photos" }));

      MyApp.store.set('dataSource', MyApp.dataSource);

  In this case, the order you call from() will determine the order the request
  will cascade.

  @extends SC.DataSource
  @since SproutCore 1.0
*/
SC.CascadeDataSource = SC.DataSource.extend(
  /** @scope SC.CascadeDataSource.prototype */ {

  /**
    The data sources used by the cascade, in the order that they are to be
    followed.  Usually when you define the cascade, you will define this
    array.

    @type Array
  */
  dataSources: null,

  /**
    Add a data source to the list of sources to use when cascading.  Used to
    build the data source cascade effect.

    @param {SC.DataSource} dataSource a data source instance to add.
    @returns {SC.CascadeDataSource} receiver
  */
  from: function(dataSource) {
    var dataSources = this.get('dataSources');
    if (!dataSources) this.set('dataSources', dataSources = []);
    dataSources.push(dataSource);
    return this ;
  },

  // ..........................................................
  // SC.STORE ENTRY POINTS
  //

  /** @private - just cascades */
  fetch: function(store, query) {
    var sources = this.get('dataSources'),
        len     = sources ? sources.length : 0,
        ret     = NO,
        cur, source, idx;

    for(idx=0; (ret !== YES) && idx<len; idx++) {
      source = sources.objectAt(idx);
      cur = source.fetch ? source.fetch.apply(source, arguments) : NO;
      ret = this._handleResponse(ret, cur);
    }

    return ret ;
  },


  /** @private - just cascades */
  retrieveRecords: function(store, storeKeys, ids) {
    var sources = this.get('dataSources'),
        len     = sources ? sources.length : 0,
        ret     = NO,
        cur, source, idx;

    for(idx=0; (ret !== YES) && idx<len; idx++) {
      source = sources.objectAt(idx);
      cur = source.retrieveRecords.apply(source, arguments);
      ret = this._handleResponse(ret, cur);
    }

    return ret ;
  },

  /** @private - just cascades */
  commitRecords: function(store, createStoreKeys, updateStoreKeys, destroyStoreKeys, params) {
    var sources = this.get('dataSources'),
        len     = sources ? sources.length : 0,
        ret     = NO,
        cur, source, idx;

    for(idx=0; (ret !== YES) && idx<len; idx++) {
      source = sources.objectAt(idx);
      cur = source.commitRecords.apply(source, arguments);
      ret = this._handleResponse(ret, cur);
    }

    return ret ;
  },

  /** @private - just cascades */
  cancel: function(store, storeKeys) {
    var sources = this.get('dataSources'),
        len     = sources ? sources.length : 0,
        ret     = NO,
        cur, source, idx;

    for(idx=0; (ret !== YES) && idx<len; idx++) {
      source = sources.objectAt(idx);
      cur = source.cancel.apply(source, arguments);
      ret = this._handleResponse(ret, cur);
    }

    return ret ;
  },

  // ..........................................................
  // INTERNAL SUPPORT
  //

  /** @private */
  init: function() {
    arguments.callee.base.apply(this,arguments);

    // if a dataSources array is defined, look for any strings and lookup
    // the same on the data source.  Replace.
    var sources = this.get('dataSources'),
        idx     = sources ? sources.get('length') : 0,
        source;
    while(--idx>=0) {
      source = sources[idx];
      if (SC.typeOf(source) === SC.T_STRING) sources[idx] = this.get(source);
    }

  },

  /** @private - Determine the proper return value. */
  _handleResponse: function(current, response) {
    if (response === YES) return YES ;
    else if (current === NO) return (response === NO) ? NO : SC.MIXED_STATE ;
    else return SC.MIXED_STATE ;
  }

});

/* >>>>>>>>>> BEGIN source/system/query.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('core') ;
sc_require('models/record');

/**
  @class

  This class permits you to perform queries on your data store or a remote data store. Here is a
  simple example of a *local* (see below) query,

      query = SC.Query.create({
        conditions: "firstName = 'Johnny' AND lastName = 'Cash'"
      });

  This query, when used with the store, will return all records which have record attributes of
  `firstName` equal to 'Johnny' and `lastName` equal to 'Cash'. To use the query with the store
  simple pass it to `find` like so,

      records = MyApp.store.find(query);

  In this example, `records` will be an `SC.RecordArray` array containing all matching records. The
  amazing feature of record arrays backed by *local* queries is that they update automatically
  whenever the records in the store change. This means that once we've run the query once, any time
  data is loaded or unloaded from the store, the results of the query (i.e. `records`) will
  update automatically. This allows for truly powerful and dynamic uses, such as having a list of
  filtered results that continually updates instantly as data pages in or out in the background.

  To limit the query to a record type of `MyApp.MyModel`, you can specify the type as a property of
  the query like this,

      query = SC.Query.create({
        conditions: "firstName = 'Johnny' AND lastName = 'Cash'",
        recordType: MyApp.MyModel
      });

  Calling `find()` like above will now return only records of type MyApp.MyModel. It is recommended
  to limit your query to a record type, since the query will have to look for matching records in
  the whole store if no record type is given.

  You can also give an order for *local* queries, which the resulting records will use,

      query = SC.Query.create({
        conditions: "firstName = 'Johnny' AND lastName = 'Cash'",
        recordType: MyApp.MyModel,
        orderBy: "lastName, year DESC"
      });

  The default order direction is ascending. You can change it to descending by writing `'DESC'`
  behind the property name as was done in the example above. If no order is given, or records are
  equal in respect to a given order, records will be ordered by their storeKeys which increment
  depending on load order.

  Note, you can check if a certain record matches the query by calling `query.contains(record)`.

  ## Local vs. Remote Queries

  The default type for queries is 'local', but there is another type we can use called 'remote'.
  The distinction between local and remote queries is a common tripping point for new SproutCore
  developers, but hopefully the following description helps keep it clear. The terms local and
  remote refer to the *location of the data where the query is performed and by whom*. A local query
  will be run by the client against the store of data within the client, while a remote query will
  be run on by the server against some remote store of data. This seems simple enough, but it can
  lead to a few misconceptions.

  The first misconception is that local queries don't ever result in a call to a server. This is
  not the case; when a local query is first used with the store it will generally result in a call
  to the server, but whether or not it does depends on your store's data source. Keep this in mind,
  local queries *only run against the data loaded in the client's store*. If the client store is
  empty, the results of the query will be empty even though there may be thousands of matching
  records on a server somewhere. That's why when a query is first used, the store will look for a
  data source that implements the `fetch(store, query)` method. Your data source can then decide
  whether additional data should be loaded into the store first in order to better fulfill the
  query.

  This is entirely up to your client/server implementation, but a common use case is to have a
  general query trigger the load of a large set of data and then any more specific queries will only
  run against what was already loaded. For more details, @see SC.DataSource.prototype.fetch. So to
  recap, local queries are passed to the data source fetch method the first time they are used so
  that the data source has a chance to load additional data that the query may need.

  Once we get past the first misconception; local queries are actually pretty easy to understand and
  to work with. We run the queries, get the resulting record array and watch as the results almost
  magically update as the data in the client changes. Local queries are the default type, and
  typically we will use local queries almost exclusively in SproutCore apps. So why do we have a
  remote type?

  In a previous paragraph, we considered how a local query would be empty if the local store was
  empty even though there may be thousands of matching records on a server. Well what if there were
  millions of records on the server? When dealing with extremely large datasets, it's not feasible
  to load all of the records into the client so that the client can run a query against them. This
  is the role of the 'remote' type. Remote queries are not actually "run" by the client at all,
  which is the next misconception; you cannot run a remote query.

  This misconception is another way of saying that you can't set conditions or order on a remote
  query. The 'remote' SC.Query type is simply a reflection of some database query that was run
  against a data store somewhere outside of the client. For example, say we want to still find all
  the records on the server with `firstName` equal to 'Johnny' and `lastName` equal to 'Cash', but
  now there are millions of records. This type of query is best left to a MySQL or other database on
  a server and thus the server will have exposed an API endpoint that will return the results of
  such a search when passed some search terms.

  Again, this is entirely up to your client/server configuration, but the way it is handled by the
  data source is nearly identical to how local queries will be handled. In both situations, the
  data source is passed the query the first time it is run and when the data source is done it calls
  the same method on the store, `dataSourceDidFetchQuery`. In both situations too, any data that the
  data source receives should be loaded into the client store using `loadRecords`. However, because
  there may be lots of other data in the client store, the 'remote' query must also be told which
  records pertain to it and in what order, which is done by passing the store keys of the new data
  also to `dataSourceDidFetchQuery`.

  So to recap, use 'local' queries to filter the data currently in the client store and use 'remote'
  queries to represent results filtered by a remote server. Both may be used by a data source to
  load data from a server.

  ## SproutCore Query Language

  Features of the query language:

  Primitives:

   - record properties
   - `null`, `undefined`
   - `true`, `false`
   - numbers (integers and floats)
   - strings (double or single quoted)

  Parameters:

   - `%@` (wild card)
   - `{parameterName}` (named parameter)

  Wild cards are used to identify parameters by the order in which they appear
  in the query string. Named parameters can be used when tracking the order
  becomes difficult. Both types of parameters can be used by giving the
  parameters as a property to your query object:

      yourQuery.parameters = yourParameters

  where yourParameters should have one of the following formats:

   * for wild cards: `[firstParam, secondParam, thirdParam]`
   * for named params: `{name1: param1, mane2: parma2}`

  You cannot use both types of parameters in a single query!

  ### Operators:

   - `=`
   - `!=`
   - `<`
   - `<=`
   - `>`
   - `>=`
   - `BEGINS_WITH` -- (checks if a string starts with another one)
   - `ENDS_WITH` --   (checks if a string ends with another one)
   - `CONTAINS` --    (checks if a string contains another one, or if an
                      object is in an array)
   - `MATCHES` --     (checks if a string is matched by a regexp,
                      you will have to use a parameter to insert the regexp)
   - `ANY` --         (checks if the thing on its left is contained in the array
                      on its right, you will have to use a parameter
                      to insert the array)
   - `TYPE_IS` --     (unary operator expecting a string containing the name
                      of a Model class on its right side, only records of this
                      type will match)

  ### Boolean Operators:

   - `AND`
   - `OR`
   - `NOT`

  Parenthesis for grouping:

   - `(` and `)`


  ## Adding Your Own Query Handlers

  You can extend the query language with your own operators by calling:

      SC.Query.registerQueryExtension('your_operator', your_operator_definition);

  See details below. As well you can provide your own comparison functions
  to control ordering of specific record properties like this:

      SC.Query.registerComparison(property_name, comparison_for_this_property);

  @extends SC.Object
  @extends SC.Copyable
  @extends SC.Freezable
  @since SproutCore 1.0
*/
// TODO: Rename local vs. remote to avoid confusion.
SC.Query = SC.Object.extend(SC.Copyable, SC.Freezable,
  /** @scope SC.Query.prototype */ {

  


  // ..........................................................
  // PROPERTIES
  //

  /**
    Walk like a duck.

    @type Boolean
  */
  isQuery: YES,

  /**
    Unparsed query conditions.  If you are handling a query yourself, then
    you will find the base query string here.

    @type String
  */
  conditions:  null,

  /**
    Optional orderBy parameters.  This can be a string of keys, optionally
    ending with the strings `" DESC"` or `" ASC"` to select descending or
    ascending order.

    Alternatively, you can specify a comparison function, in which case the
    two records will be sent to it.  Your comparison function, as with any
    other, is expected to return -1, 0, or 1.

    @type String | Function
  */
  orderBy: null,

  /**
    The base record type or types for the query.  This must be specified to
    filter the kinds of records this query will work on.  You may either
    set this to a single record type or to an array or set of record types.

    @type SC.Record
  */
  recordType:  null,

  /**
    Optional array of multiple record types.  If the query accepts multiple
    record types, this is how you can check for it.

    @type SC.Enumerable
  */
  recordTypes: null,

  /**
    Returns the complete set of `recordType`s matched by this query.  Includes
    any named `recordType`s plus their subclasses.

    @property
    @type SC.Enumerable
  */
  expandedRecordTypes: function() {
    var ret = SC.CoreSet.create(), rt, q  ;

    if (rt = this.get('recordType')) this._scq_expandRecordType(rt, ret);
    else if (rt = this.get('recordTypes')) {
      rt.forEach(function(t) { this._scq_expandRecordType(t, ret); }, this);
    } else this._scq_expandRecordType(SC.Record, ret);

    // save in queue.  if a new recordtype is defined, we will be notified.
    q = SC.Query._scq_queriesWithExpandedRecordTypes;
    if (!q) {
      q = SC.Query._scq_queriesWithExpandedRecordTypes = SC.CoreSet.create();
    }
    q.add(this);

    return ret.freeze() ;
  }.property('recordType', 'recordTypes').cacheable(),

  /** @private
    expands a single record type into the set. called recursively
  */
  _scq_expandRecordType: function(recordType, set) {
    if (set.contains(recordType)) return; // nothing to do
    set.add(recordType);

    if (SC.typeOf(recordType)===SC.T_STRING) {
      recordType = SC.objectForPropertyPath(recordType);
    }

    recordType.subclasses.forEach(function(t) {
      this._scq_expandRecordType(t, set);
    }, this);
  },

  /**
    Optional hash of parameters.  These parameters may be interpolated into
    the query conditions.  If you are handling the query manually, these
    parameters will not be used.

    @type Hash
  */
  parameters:  null,

  /**
    Indicates the location where the result set for this query is stored.
    Currently the available options are:

     - `SC.Query.LOCAL` -- indicates that the query results will be
       automatically computed from the in-memory store.
     - `SC.Query.REMOTE` -- indicates that the query results are kept on a
       remote server and hence must be loaded from the `DataSource`.

    The default setting for this property is `SC.Query.LOCAL`.

    Note that even if a query location is `LOCAL`, your `DataSource` will
    still have its `fetch()` method called for the query.  For `LOCAL`
    queries, you  won't need to explicitly provide the query result set; you
    can just load records into the in-memory store as needed and let the query
    recompute automatically.

    If your query location is `REMOTE`, then your `DataSource` will need to
    provide the actual set of query results manually.  Usually you will only
    need to use a `REMOTE` query if you are retrieving a large data set and you
    don't want to pay the cost of computing the result set client side.

    @type String
  */
  location: 'local', // SC.Query.LOCAL

  /**
    Another query that will optionally limit the search of records.  This is
    usually configured for you when you do `find()` from another record array.

    @type SC.Query
  */
  scope: null,


  /**
    Returns `YES` if query location is Remote.  This is sometimes more
    convenient than checking the location.

		@property
    @type Boolean
  */
  isRemote: function() {
    return this.get('location') === SC.Query.REMOTE;
  }.property('location').cacheable(),

  /**
    Returns `YES` if query location is Local.  This is sometimes more
    convenient than checking the location.

		@property
    @type Boolean
  */
  isLocal: function() {
    return this.get('location') === SC.Query.LOCAL;
  }.property('location').cacheable(),

  /**
    Indicates whether a record is editable or not.  Defaults to `NO`.  Local
    queries should never be made editable.  Remote queries may be editable or
    not depending on the data source.
  */
  isEditable: NO,

  // ..........................................................
  // PRIMITIVE METHODS
  //

  /**
    Returns `YES` if record is matched by the query, `NO` otherwise.  This is
    used when computing a query locally.

    @param {SC.Record} record the record to check
    @param {Hash} parameters optional override parameters
    @returns {Boolean} YES if record belongs, NO otherwise
  */
  contains: function(record, parameters) {

    // check the recordType if specified
    var rtype, ret = YES ;
    if (rtype = this.get('recordTypes')) { // plural form
      ret = rtype.find(function(t) { return SC.kindOf(record, t); });
    } else if (rtype = this.get('recordType')) { // singular
      ret = SC.kindOf(record, rtype);
    }

    if (!ret) return NO ; // if either did not pass, does not contain

    // if we have a scope - check for that as well
    var scope = this.get('scope');
    if (scope && !scope.contains(record)) return NO ;

    // now try parsing
    if (!this._isReady) this.parse(); // prepare the query if needed
    if (!this._isReady) return NO ;
    if (parameters === undefined) parameters = this.parameters || this;

    // if parsing worked we check if record is contained
    // if parsing failed no record will be contained
    return this._tokenTree.evaluate(record, parameters);
  },

  /**
    Returns `YES` if the query matches one or more of the record types in the
    passed set.

    @param {SC.Set} types set of record types
    @returns {Boolean} YES if record types match
  */
  containsRecordTypes: function(types) {
    var rtype = this.get('recordType');
    if (rtype) {
      return !!types.find(function(t) { return SC.kindOf(t, rtype); });

    } else if (rtype = this.get('recordTypes')) {
      return !!rtype.find(function(t) {
        return !!types.find(function(t2) { return SC.kindOf(t2,t); });
      });

    } else return YES; // allow anything through
  },

  /**
    Returns the sort order of the two passed records, taking into account the
    orderBy property set on this query.  This method does not verify that the
    two records actually belong in the query set or not; this is checked using
    `contains()`.

    @param {SC.Record} record1 the first record
    @param {SC.Record} record2 the second record
    @returns {Number} -1 if record1 < record2,
                      +1 if record1 > record2,
                      0 if equal
  */
  compare: function(record1, record2) {
    var result = 0,
        propertyName, order, len, i, methodName;

    // fast cases go here
    if (record1 === record2) return 0;

    // if called for the first time we have to build the order array
    if (!this._isReady) this.parse();
    if (!this._isReady) { // can't parse, so use storeKey.  Not proper, but consistent.
      return SC.compare(record1.get('storeKey'),record2.get('storeKey'));
    }

    // For every property specified in orderBy until non-eql result is found.
    // Or, if orderBy is a comparison function, simply invoke it with the
    // records.
    order = this._order;
    if (SC.typeOf(order) === SC.T_FUNCTION) {
      result = order.call(null, record1, record2);
    }
    else {
      len   = order ? order.length : 0;
      for (i=0; result===0 && (i < len); i++) {
        propertyName = order[i].propertyName;
        methodName   = /\./.test(propertyName) ? 'getPath' : 'get';
        // if this property has a registered comparison use that
        if (SC.Query.comparisons[propertyName]) {
          result = SC.Query.comparisons[propertyName](
                    record1[methodName](propertyName), record2[methodName](propertyName));

        // if not use default SC.compare()
        } else {
          result = SC.compare(
                    record1[methodName](propertyName), record2[methodName](propertyName));
        }

        if ((result!==0) && order[i].descending) result = (-1) * result;
      }
    }

    // return result or compare by storeKey
    if (result !== 0) return result ;
    else return SC.compare(record1.get('storeKey'), record2.get('storeKey'));
  },

  /** @private
      Becomes YES once the query has been successfully parsed
  */
  _isReady:     NO,

  /**
    This method has to be called before the query object can be used.
    You will normally not have to do this; it will be called automatically
    if you try to evaluate a query.
    You can, however, use this function for testing your queries.

    @returns {Boolean} true if parsing succeeded, false otherwise
  */
  parse: function() {
    var conditions = this.get('conditions'),
        lang       = this.get('queryLanguage'),
        tokens, tree;

    tokens = this._tokenList = this.tokenizeString(conditions, lang);
    tree = this._tokenTree = this.buildTokenTree(tokens, lang);
    this._order = this.buildOrder(this.get('orderBy'));

    this._isReady = !!tree && !tree.error;
    if (tree && tree.error) SC.throw(tree.error);
    return this._isReady;
  },

  /**
    Returns the same query but with the scope set to the passed record array.
    This will copy the receiver.  It also stores these queries in a cache to
    reuse them if possible.

    @param {SC.RecordArray} recordArray the scope
    @returns {SC.Query} new query
  */
  queryWithScope: function(recordArray) {
    // look for a cached query on record array.
    var key = SC.keyFor('__query__', SC.guidFor(this)),
        ret = recordArray[key];

    if (!ret) {
      recordArray[key] = ret = this.copy();
      ret.set('scope', recordArray);
      ret.freeze();
    }

    return ret ;
  },

  // ..........................................................
  // PRIVATE SUPPORT
  //

  /** @private
    Properties that need to be copied when cloning the query.
  */
  copyKeys: ['conditions', 'orderBy', 'recordType', 'recordTypes', 'parameters', 'location', 'scope'],

  /** @private */
  concatenatedProperties: ['copyKeys'],

  /** @private
    Implement the Copyable API to clone a query object once it has been
    created.
  */
  copy: function() {
    var opts = {},
        keys = this.get('copyKeys'),
        loc  = keys ? keys.length : 0,
        key, value, ret;

    while(--loc >= 0) {
      key = keys[loc];
      value = this.get(key);
      if (value !== undefined) opts[key] = value ;
    }

    ret = this.constructor.create(opts);
    opts = null;
    return ret ;
  },

  // ..........................................................
  // QUERY LANGUAGE DEFINITION
  //


  /**
    This is the definition of the query language. You can extend it
    by using `SC.Query.registerQueryExtension()`.
  */
  queryLanguage: {

    'UNKNOWN': {
      firstCharacter:   /[^\s'"\w\d\(\)\{\}]/,
      notAllowed:       /[\-\s'"\w\d\(\)\{\}]/
    },

    'PROPERTY': {
      firstCharacter:   /[a-zA-Z_]/,
      notAllowed:       /[^a-zA-Z_0-9\.]/,
      evalType:         'PRIMITIVE',

      /** @ignore */
      evaluate:         function (r,w) {
                          var tokens = this.tokenValue.split('.');

                          var len = tokens.length;
                          if (len < 2) return r.get(this.tokenValue);

                          var ret = r;
                          for (var i = 0; i < len; i++) {
                            if (!ret) return;
                            if (ret.get) {
                              ret = ret.get(tokens[i]);
                            } else {
                              ret = ret[tokens[i]];
                            }
                          }
                          return ret;
                        }
    },

    'NUMBER': {
      firstCharacter:   /[\d\-]/,
      notAllowed:       /[^\d\-\.]/,
      format:           /^-?\d+$|^-?\d+\.\d+$/,
      evalType:         'PRIMITIVE',

      /** @ignore */
      evaluate:         function (r,w) { return parseFloat(this.tokenValue); }
    },

    'STRING': {
      firstCharacter:   /['"]/,
      delimited:        true,
      evalType:         'PRIMITIVE',

      /** @ignore */
      evaluate:         function (r,w) { return this.tokenValue; }
    },

    'PARAMETER': {
      firstCharacter:   /\{/,
      lastCharacter:    '}',
      delimited:        true,
      evalType:         'PRIMITIVE',

      /** @ignore */
      evaluate:         function (r,w) { return w[this.tokenValue]; }
    },

    '%@': {
      rememberCount:    true,
      reservedWord:     true,
      evalType:         'PRIMITIVE',

      /** @ignore */
      evaluate:         function (r,w) { return w[this.tokenValue]; }
    },

    'OPEN_PAREN': {
      firstCharacter:   /\(/,
      singleCharacter:  true
    },

    'CLOSE_PAREN': {
      firstCharacter:   /\)/,
      singleCharacter:  true
    },

    'AND': {
      reservedWord:     true,
      leftType:         'BOOLEAN',
      rightType:        'BOOLEAN',
      evalType:         'BOOLEAN',

      /** @ignore */
      evaluate:         function (r,w) {
                          var left  = this.leftSide.evaluate(r,w);
                          var right = this.rightSide.evaluate(r,w);
                          return left && right;
                        }
    },

    'OR': {
      reservedWord:     true,
      leftType:         'BOOLEAN',
      rightType:        'BOOLEAN',
      evalType:         'BOOLEAN',

      /** @ignore */
      evaluate:         function (r,w) {
                          var left  = this.leftSide.evaluate(r,w);
                          var right = this.rightSide.evaluate(r,w);
                          return left || right;
                        }
    },

    'NOT': {
      reservedWord:     true,
      rightType:        'BOOLEAN',
      evalType:         'BOOLEAN',

      /** @ignore */
      evaluate:         function (r,w) {
                          var right = this.rightSide.evaluate(r,w);
                          return !right;
                        }
    },

    '=': {
      reservedWord:     true,
      leftType:         'PRIMITIVE',
      rightType:        'PRIMITIVE',
      evalType:         'BOOLEAN',

      /** @ignore */
      evaluate:         function (r,w) {
                          var left  = this.leftSide.evaluate(r,w);
                          var right = this.rightSide.evaluate(r,w);
                          return SC.isEqual(left, right);
                        }
    },

    '!=': {
      reservedWord:     true,
      leftType:         'PRIMITIVE',
      rightType:        'PRIMITIVE',
      evalType:         'BOOLEAN',

      /** @ignore */
      evaluate:         function (r,w) {
                          var left  = this.leftSide.evaluate(r,w);
                          var right = this.rightSide.evaluate(r,w);
                          return !SC.isEqual(left, right);
                        }
    },

    '<': {
      reservedWord:     true,
      leftType:         'PRIMITIVE',
      rightType:        'PRIMITIVE',
      evalType:         'BOOLEAN',

      /** @ignore */
      evaluate:         function (r,w) {
                          var left  = this.leftSide.evaluate(r,w);
                          var right = this.rightSide.evaluate(r,w);
                          return SC.compare(left, right) === -1; //left < right;
                        }
    },

    '<=': {
      reservedWord:     true,
      leftType:         'PRIMITIVE',
      rightType:        'PRIMITIVE',
      evalType:         'BOOLEAN',

      /** @ignore */
      evaluate:         function (r,w) {
                          var left  = this.leftSide.evaluate(r,w);
                          var right = this.rightSide.evaluate(r,w);
                          return SC.compare(left, right) !== 1; //left <= right;
                        }
    },

    '>': {
      reservedWord:     true,
      leftType:         'PRIMITIVE',
      rightType:        'PRIMITIVE',
      evalType:         'BOOLEAN',

      /** @ignore */
      evaluate:         function (r,w) {
                          var left  = this.leftSide.evaluate(r,w);
                          var right = this.rightSide.evaluate(r,w);
                          return SC.compare(left, right) === 1; //left > right;
                        }
    },

    '>=': {
      reservedWord:     true,
      leftType:         'PRIMITIVE',
      rightType:        'PRIMITIVE',
      evalType:         'BOOLEAN',

      /** @ignore */
      evaluate:         function (r,w) {
                          var left  = this.leftSide.evaluate(r,w);
                          var right = this.rightSide.evaluate(r,w);
                          return SC.compare(left, right) !== -1; //left >= right;
                        }
    },

    'BEGINS_WITH': {
      reservedWord:     true,
      leftType:         'PRIMITIVE',
      rightType:        'PRIMITIVE',
      evalType:         'BOOLEAN',

      /** @ignore */
      evaluate:         function (r,w) {
                          var all   = this.leftSide.evaluate(r,w);
                          var start = this.rightSide.evaluate(r,w);
                          return ( all && all.indexOf(start) === 0 );
                        }
    },

    'ENDS_WITH': {
      reservedWord:     true,
      leftType:         'PRIMITIVE',
      rightType:        'PRIMITIVE',
      evalType:         'BOOLEAN',

      /** @ignore */
      evaluate:         function (r,w) {
                          var all = this.leftSide.evaluate(r,w);
                          var end = this.rightSide.evaluate(r,w);
                          return ( all && all.length >= end.length && all.lastIndexOf(end) === (all.length - end.length));
                        }
    },

    'CONTAINS': {
      reservedWord:     true,
      leftType:         'PRIMITIVE',
      rightType:        'PRIMITIVE',
      evalType:         'BOOLEAN',

      /** @ignore */
        evaluate:       function (r,w) {
                          var all    = this.leftSide.evaluate(r,w) || [];
                          var value = this.rightSide.evaluate(r,w);

                          var allType = SC.typeOf(all);
                          if (allType === SC.T_STRING) {
                            return (all.indexOf(value) !== -1);
                          } else if (allType === SC.T_ARRAY || all.toArray) {
                            if (allType !== SC.T_ARRAY) all = all.toArray();
                            var found  = false;
                            var i      = 0;
                            while ( found === false && i < all.length ) {
                              if ( value == all[i] ) found = true;
                              i++;
                            }
                            return found;
                          }
                        }
    },

    'ANY': {
      reservedWord:     true,
      leftType:         'PRIMITIVE',
      rightType:        'PRIMITIVE',
      evalType:         'BOOLEAN',

      /** @ignore */
      evaluate:         function (r,w) {
                          var prop   = this.leftSide.evaluate(r,w);
                          var values = this.rightSide.evaluate(r,w);
                          var found  = false;
                          var i      = 0;
                          while ( found===false && i<values.length ) {
                            if ( prop == values[i] ) found = true;
                            i++;
                          }
                          return found;
                        }
    },

    'MATCHES': {
      reservedWord:     true,
      leftType:         'PRIMITIVE',
      rightType:        'PRIMITIVE',
      evalType:         'BOOLEAN',

      /** @ignore */
      evaluate:         function (r,w) {
                          var toMatch = this.leftSide.evaluate(r,w);
                          var matchWith = this.rightSide.evaluate(r,w);
                          return matchWith.test(toMatch);
                        }
    },

    'TYPE_IS': {
      reservedWord:     true,
      rightType:        'PRIMITIVE',
      evalType:         'BOOLEAN',

      /** @ignore */
      evaluate:         function (r,w) {
                          var actualType = SC.Store.recordTypeFor(r.storeKey);
                          var right      = this.rightSide.evaluate(r,w);
                          var expectType = SC.objectForPropertyPath(right);
                          return actualType == expectType;
                        }
    },

    'null': {
      reservedWord:     true,
      evalType:         'PRIMITIVE',

      /** @ignore */
      evaluate:         function (r,w) { return null; }
    },

    'undefined': {
      reservedWord:     true,
      evalType:         'PRIMITIVE',

      /** @ignore */
      evaluate:         function (r,w) { return undefined; }
    },

    'false': {
      reservedWord:     true,
      evalType:         'PRIMITIVE',

      /** @ignore */
      evaluate:         function (r,w) { return false; }
    },

    'true': {
      reservedWord:     true,
      evalType:         'PRIMITIVE',

      /** @ignore */
      evaluate:         function (r,w) { return true; }
    },

    'YES': {
      reservedWord:     true,
      evalType:         'PRIMITIVE',

      /** @ignore */
      evaluate:         function (r,w) { return true; }
    },

    'NO': {
      reservedWord:     true,
      evalType:         'PRIMITIVE',

      /** @ignore */
      evaluate:         function (r,w) { return false; }
    }

  },


  // ..........................................................
  // TOKENIZER
  //


  /**
    Takes a string and tokenizes it based on the grammar definition
    provided. Called by `parse()`.

    @param {String} inputString the string to tokenize
    @param {Object} grammar the grammar definition (normally queryLanguage)
    @returns {Array} list of tokens
  */
  tokenizeString: function (inputString, grammar) {


    var tokenList           = [],
        c                   = null,
        t                   = null,
        token               = null,
        currentToken        = null,
        currentTokenType    = null,
        currentTokenValue   = null,
        currentDelimiter    = null,
        endOfString         = false,
        endOfToken          = false,
        skipThisCharacter   = false,
        rememberCount       = {};


    // helper function that adds tokens to the tokenList

    function addToken (tokenType, tokenValue) {
      t = grammar[tokenType];
      //tokenType = t.tokenType;

      // handling of special cases
      // check format
      if (t.format && !t.format.test(tokenValue)) tokenType = "UNKNOWN";
      // delimited token (e.g. by ")
      if (t.delimited) skipThisCharacter = true;

      // reserved words
      if ( !t.delimited ) {
        for ( var anotherToken in grammar ) {
          if (grammar[anotherToken].reservedWord &&
              anotherToken == tokenValue ) {
            tokenType = anotherToken;
          }
        }
      }

      // reset t
      t = grammar[tokenType];
      // remembering count type
      if ( t && t.rememberCount ) {
        if (!rememberCount[tokenType]) rememberCount[tokenType] = 0;
        tokenValue = rememberCount[tokenType];
        rememberCount[tokenType] += 1;
      }

      // push token to list
      tokenList.push( {tokenType: tokenType, tokenValue: tokenValue} );

      // and clean up currentToken
      currentToken      = null;
      currentTokenType  = null;
      currentTokenValue = null;
    }


    // stepping through the string:

    if (!inputString) return [];

    var iStLength = inputString.length;

    for (var i=0; i < iStLength; i++) {

      // end reached?
      endOfString = (i===iStLength-1);

      // current character
      c = inputString.charAt(i);

      // set true after end of delimited token so that
      // final delimiter is not caught again
      skipThisCharacter = false;


      // if currently inside a token

      if ( currentToken ) {

        // some helpers
        t = grammar[currentToken];
        endOfToken = t.delimited ? c===currentDelimiter : t.notAllowed.test(c);

        // if still in token
        if ( !endOfToken ) currentTokenValue += c;

        // if end of token reached
        if (endOfToken || endOfString) {
          addToken(currentToken, currentTokenValue);
        }

        // if end of string don't check again
        if ( endOfString && !endOfToken ) skipThisCharacter = true;
      }

      // if not inside a token, look for next one

      if ( !currentToken && !skipThisCharacter ) {
        // look for matching tokenType
        for ( token in grammar ) {
          t = grammar[token];
          if (t.firstCharacter && t.firstCharacter.test(c)) {
            currentToken = token;
          }
        }

        // if tokenType found
        if ( currentToken ) {
          t = grammar[currentToken];
          currentTokenValue = c;
          // handling of special cases
          if ( t.delimited ) {
            currentTokenValue = "";
            if ( t.lastCharacter ) currentDelimiter = t.lastCharacter;
            else currentDelimiter = c;
          }

          if ( t.singleCharacter || endOfString ) {
            addToken(currentToken, currentTokenValue);
          }
        }
      }
    }

    return tokenList;
  },



  // ..........................................................
  // BUILD TOKEN TREE
  //

  /**
    Takes an array of tokens and returns a tree, depending on the
    specified tree logic. The returned object will have an error property
    if building of the tree failed. Check it to get some information
    about what happend.
    If everything worked, the tree can be evaluated by calling

        tree.evaluate(record, parameters)

    If `tokenList` is empty, a single token will be returned which will
    evaluate to true for all records.

    @param {Array} tokenList the list of tokens
    @param {Object} treeLogic the logic definition (normally queryLanguage)
    @returns {Object} token tree
  */
  buildTokenTree: function (tokenList, treeLogic) {

    var l                    = tokenList.slice();
    var i                    = 0;
    var openParenthesisStack = [];
    var shouldCheckAgain     = false;
    var error                = [];


    // empty tokenList is a special case
    if (!tokenList || tokenList.length === 0) {
      return { evaluate: function(){ return true; } };
    }


    // some helper functions

    function tokenLogic (position) {
      var p = position;
      if ( p < 0 ) return false;

      var tl = treeLogic[l[p].tokenType];

      if ( ! tl ) {
        error.push("logic for token '"+l[p].tokenType+"' is not defined");
        return false;
      }

      // save evaluate in token, so that we don't have
      // to look it up again when evaluating the tree
      l[p].evaluate = tl.evaluate;
      return tl;
    }

    function expectedType (side, position) {
      var p = position;
      var tl = tokenLogic(p);
      if ( !tl )            return false;
      if (side === 'left')   return tl.leftType;
      if (side === 'right')  return tl.rightType;
    }

    function evalType (position) {
      var p = position;
      var tl = tokenLogic(p);
      if ( !tl )  return false;
      else        return tl.evalType;
    }

    function removeToken (position) {
      l.splice(position, 1);
      if ( position <= i ) i--;
    }

    function preceedingTokenExists (position) {
      var p = position || i;
      if ( p > 0 )  return true;
      else          return false;
    }

    function tokenIsMissingChilds (position) {
      var p = position;
      if ( p < 0 )  return true;
      return (expectedType('left',p) && !l[p].leftSide) ||
             (expectedType('right',p) && !l[p].rightSide);
    }

    function typesAreMatching (parent, child) {
      var side = (child < parent) ? 'left' : 'right';
      if ( parent < 0 || child < 0 )                      return false;
      if ( !expectedType(side,parent) )                   return false;
      if ( !evalType(child) )                             return false;
      if ( expectedType(side,parent) == evalType(child) ) return true;
      else                                                return false;
    }

    function preceedingTokenCanBeMadeChild (position) {
      var p = position;
      if ( !tokenIsMissingChilds(p) )   return false;
      if ( !preceedingTokenExists(p) )  return false;
      if ( typesAreMatching(p,p-1) )    return true;
      else                              return false;
    }

    function preceedingTokenCanBeMadeParent (position) {
      var p = position;
      if ( tokenIsMissingChilds(p) )    return false;
      if ( !preceedingTokenExists(p) )  return false;
      if ( !tokenIsMissingChilds(p-1) ) return false;
      if ( typesAreMatching(p-1,p) )    return true;
      else                              return false;
    }

    function makeChild (position) {
      var p = position;
      if (p<1) return false;
      l[p].leftSide = l[p-1];
      removeToken(p-1);
    }

    function makeParent (position) {
      var p = position;
      if (p<1) return false;
      l[p-1].rightSide = l[p];
      removeToken(p);
    }

    function removeParenthesesPair (position) {
      removeToken(position);
      removeToken(openParenthesisStack.pop());
    }

    // step through the tokenList

    for (i = 0; i < l.length; i++) {
      shouldCheckAgain = false;

      if ( l[i].tokenType === 'UNKNOWN' ) {
        error.push('found unknown token: '+l[i].tokenValue);
      }

      if ( l[i].tokenType === 'OPEN_PAREN' ) openParenthesisStack.push(i);
      if ( l[i].tokenType === 'CLOSE_PAREN' ) removeParenthesesPair(i);

      if ( preceedingTokenCanBeMadeChild(i) ) makeChild(i);

      if ( preceedingTokenCanBeMadeParent(i) ){
        makeParent(i);
        shouldCheckAgain = true;
      }

      if ( shouldCheckAgain ) i--;

    }

    // error if tokenList l is not a single token now
    if (l.length === 1) l = l[0];
    else error.push('string did not resolve to a single tree');

    // If we have errors, return an error object.
    if (error.length > 0) {
      return {
        error: error.join(',\n'),
        tree: l,
        // Conform to SC.Error.
        isError: YES,
        errorVal: function() { return this.error; }
      };
    }
    // Otherwise the token list is now a tree and can be returned.
    else {
      return l;
    }

  },


  // ..........................................................
  // ORDERING
  //

  /**
    Takes a string containing an order statement and returns an array
    describing this order for easier processing.
    Called by `parse()`.

    @param {String | Function} orderOp the string containing the order statement, or a comparison function
    @returns {Array | Function} array of order statement, or a function if a function was specified
  */
  buildOrder: function (orderOp) {
    if (!orderOp) {
      return [];
    }
    else if (SC.typeOf(orderOp) === SC.T_FUNCTION) {
      return orderOp;
    }
    else {
      


      var o = orderOp.split(',');
      for (var i=0; i < o.length; i++) {
        var p = o[i];
        p = p.replace(/^\s+|\s+$/,'');
        p = p.replace(/\s+/,',');
        p = p.split(',');
        o[i] = {propertyName: p[0]};
        if (p[1] && p[1] === 'DESC') o[i].descending = true;
      }

      return o;
    }

  }

});


// Class Methods
SC.Query.mixin( /** @scope SC.Query */ {

  /**
    Constant used for `SC.Query#location`

    @type String
  */
  LOCAL: 'local',

  /**
    Constant used for `SC.Query#location`

    @type String
  */
  REMOTE: 'remote',

  /**
    Given a query, returns the associated `storeKey`.  For the inverse of this
    method see `SC.Store.queryFor()`.

    @param {SC.Query} query the query
    @returns {Number} a storeKey.
  */
  storeKeyFor: function(query) {
    return query ? query.get('storeKey') : null;
  },

  /**
    Will find which records match a give `SC.Query` and return an array of
    store keys. This will also apply the sorting for the query.

    @param {SC.Query} query to apply
    @param {SC.RecordArray} records to search within
    @param {SC.Store} store to materialize record from
    @returns {Array} array instance of store keys matching the SC.Query (sorted)
  */
  containsRecords: function(query, records, store) {
    var ret = [];
    for(var idx=0,len=records.get('length');idx<len;idx++) {
      var record = records.objectAt(idx);
      if(record && query.contains(record)) {
        ret.push(record.get('storeKey'));
      }
    }

    ret = SC.Query.orderStoreKeys(ret, query, store);

    return ret;
  },

  /**
    Sorts a set of store keys according to the orderBy property
    of the `SC.Query`.

    @param {Array} storeKeys to sort
    @param {SC.Query} query to use for sorting
    @param {SC.Store} store to materialize records from
    @returns {Array} sorted store keys.  may be same instance as passed value
  */
  orderStoreKeys: function(storeKeys, query, store) {
    // apply the sort if there is one
    if (storeKeys) {
      storeKeys.sort(function(a, b) {
        return SC.Query.compareStoreKeys(query, store, a, b);
      });
    }

    return storeKeys;
  },

  /**
    Default sort method that is used when calling `containsStoreKeys()`
    or `containsRecords()` on this query. Simply materializes two records
    based on `storekey`s before passing on to `compare()`.

    @param {Number} storeKey1 a store key
    @param {Number} storeKey2 a store key
    @returns {Number} -1 if record1 < record2,  +1 if record1 > record2, 0 if equal
  */
  compareStoreKeys: function(query, store, storeKey1, storeKey2) {
    var record1     = store.materializeRecord(storeKey1),
        record2     = store.materializeRecord(storeKey2);

    return query.compare(record1, record2);
  },

  /**
    Returns a `SC.Query` instance reflecting the passed properties.  Where
    possible this method will return cached query instances so that multiple
    calls to this method will return the same instance.  This is not possible
    however, when you pass custom parameters or set ordering. All returned
    queries are frozen.

    Usually you will not call this method directly.  Instead use the more
    convenient `SC.Query.local()` and `SC.Query.remote()`.

    Examples

    There are a number of different ways you can call this method.

    The following return local queries selecting all records of a particular
    type or types, including any subclasses:

        var people = SC.Query.local(Ab.Person);
        var peopleAndCompanies = SC.Query.local([Ab.Person, Ab.Company]);

        var people = SC.Query.local('Ab.Person');
        var peopleAndCompanies = SC.Query.local('Ab.Person Ab.Company'.w());

        var allRecords = SC.Query.local(SC.Record);

    The following will match a particular type of condition:

        var married = SC.Query.local(Ab.Person, "isMarried=YES");
        var married = SC.Query.local(Ab.Person, "isMarried=%@", [YES]);
        var married = SC.Query.local(Ab.Person, "isMarried={married}", {
          married: YES
        });

    You can also pass a hash of options as the second parameter.  This is
    how you specify an order, for example:

        var orderedPeople = SC.Query.local(Ab.Person, { orderBy: "firstName" });

    @param {String} location the query location.
    @param {SC.Record|Array} recordType the record type or types.
    @param {String} [conditions] The conditions string.
    @param {Object} [parameters] The parameters object.
    @returns {SC.Query}
  */
  build: function(location, recordType, conditions, parameters) {

    var opts = null,
        ret, cache, key, tmp;

    // fast case for query objects.
    if (recordType && recordType.isQuery) {
      if (recordType.get('location') === location) return recordType;
      else return recordType.copy().set('location', location).freeze();
    }

    // normalize recordType
    if (typeof recordType === SC.T_STRING) {
      ret = SC.objectForPropertyPath(recordType);
      if (!ret) throw new Error("%@ did not resolve to a class".fmt(recordType));
      recordType = ret ;
    } else if (recordType && recordType.isEnumerable) {
      ret = [];
      recordType.forEach(function(t) {
        if (typeof t === SC.T_STRING) t = SC.objectForPropertyPath(t);
        if (!t) throw new Error("cannot resolve record types: %@".fmt(recordType));
        ret.push(t);
      }, this);
      recordType = ret ;
    } else if (!recordType) recordType = SC.Record; // find all records

    if (parameters === undefined) parameters = null;
    if (conditions === undefined) conditions = null;

    // normalize other parameters. if conditions is just a hash, treat as opts
    if (!parameters && (typeof conditions !== SC.T_STRING)) {
      opts = conditions;
      conditions = null ;
    }

    // special case - easy to cache.
    if (!parameters && !opts) {

      tmp = SC.Query._scq_recordTypeCache;
      if (!tmp) tmp = SC.Query._scq_recordTypeCache = {};
      cache = tmp[location];
      if (!cache) cache = tmp[location] = {};

      if (recordType.isEnumerable) {
        key = recordType.map(function(k) { return SC.guidFor(k); });
        key = key.sort().join(':');
      } else key = SC.guidFor(recordType);

      if (conditions) key = [key, conditions].join('::');

      ret = cache[key];
      if (!ret) {
        if (recordType.isEnumerable) {
          opts = { recordTypes: recordType.copy() };
        } else opts = { recordType: recordType };

        opts.location = location ;
        opts.conditions = conditions ;
        ret = cache[key] = SC.Query.create(opts).freeze();
      }
    // otherwise parse extra conditions and handle them
    } else {

      if (!opts) opts = {};
      if (!opts.location) opts.location = location ; // allow override

      // pass one or more recordTypes.
      if (recordType && recordType.isEnumerable) {
        opts.recordTypes = recordType;
      } else opts.recordType = recordType;

      // set conditions and parameters if needed
      if (conditions) opts.conditions = conditions;
      if (parameters) opts.parameters = parameters;

      ret = SC.Query.create(opts).freeze();
    }

    return ret ;
  },

  /**
    Returns a `LOCAL` query with the passed properties.

    For example,

        // Show all the accounts with a value greater than 100.
        query = SC.Query.local(MyApp.Account, {
          conditions: 'value > {amt}',
          parameters: { amt: 100 },
          orderBy: 'value DESC'
        });

    @param {SC.Record|Array} recordType the record type or types.
    @param {Object} [properties] Additional properties to be added to the query.
    @returns {SC.Query}
  */
  local: function(recordType, properties, oldParameters) {
    

    return this.build(SC.Query.LOCAL, recordType, properties, oldParameters);
  },

  /**
    Returns a `REMOTE` query with the passed properties.

    For example,

        // The data source can alter its remote request using the value of
        // `query.beginsWith`.
        query = SC.Query.remote(MyApp.Person, { beginsWith: 'T' });

    @param {SC.Record|Array} recordType the record type or types.
    @param {Object} [properties] Additional properties to be added to the query.
    @returns {SC.Query}
  */
  remote: function(recordType, properties, oldParameters) {
    // This used to have arguments: conditions and params.  Because both
    // conditions and params are optional, the developer may be passing in null
    // conditions with a params object in order to use query.parameters or they
    // may be passing a conditions object which ended up becoming direct
    // properties of the query.
    // Long story short, argument overloading continues to suck ass!
    

    return this.build(SC.Query.REMOTE, recordType, properties, oldParameters);
  },

  /** @private
    called by `SC.Record.extend()`. invalidates `expandedRecordTypes`
  */
  _scq_didDefineRecordType: function() {
    var q = SC.Query._scq_queriesWithExpandedRecordTypes;
    if (q) {
      q.forEach(function(query) {
        query.notifyPropertyChange('expandedRecordTypes');
      }, this);
      q.clear();
    }
  }

});


/** @private
  Hash of registered comparisons by property name.
*/
SC.Query.comparisons = {};

/**
  Call to register a comparison for a specific property name.
  The function you pass should accept two values of this property
  and return -1 if the first is smaller than the second,
  0 if they are equal and 1 if the first is greater than the second.

  @param {String} name of the record property
  @param {Function} custom comparison function
  @returns {SC.Query} receiver
*/
SC.Query.registerComparison = function(propertyName, comparison) {
  SC.Query.comparisons[propertyName] = comparison;
};


/**
  Call to register an extension for the query language.
  You should provide a name for your extension and a definition
  specifying how it should be parsed and evaluated.

  Have a look at `queryLanguage` for examples of definitions.

  TODO add better documentation here

  @param {String} tokenName name of the operator
  @param {Object} token extension definition
  @returns {SC.Query} receiver
*/
SC.Query.registerQueryExtension = function(tokenName, token) {
  SC.Query.prototype.queryLanguage[tokenName] = token;
};

// shorthand
SC.Q = SC.Query.from ;


/* >>>>>>>>>> BEGIN source/models/record.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('system/query');

/**
  @class

  A Record is the core model class in SproutCore. It is analogous to
  NSManagedObject in Core Data and EOEnterpriseObject in the Enterprise
  Objects Framework (aka WebObjects), or ActiveRecord::Base in Rails.

  To create a new model class, in your SproutCore workspace, do:

      $ sc-gen model MyApp.MyModel

  This will create MyApp.MyModel in clients/my_app/models/my_model.js.

  The core attributes hash is used to store the values of a record in a
  format that can be easily passed to/from the server.  The values should
  generally be stored in their raw string form.  References to external
  records should be stored as primary keys.

  Normally you do not need to work with the attributes hash directly.
  Instead you should use get/set on normal record properties.  If the
  property is not defined on the object, then the record will check the
  attributes hash instead.

  You can bulk update attributes from the server using the
  `updateAttributes()` method.

  # Polymorphic Records

  SC.Record also supports polymorphism, which allows subclasses of a record type to share a common
  identity. Polymorphism is similar to inheritance (i.e. a polymorphic subclass inherits its parents
  properties), but differs in that polymorphic subclasses can be considered to be "equal" to each
  other and their superclass. This means that any memmber of the polymorphic class group should be
  able to stand in for any other member.

  These examples may help identify the difference. First, let's look at the classic inheritance
  model,

    // This is the "root" class. All subclasses of MyApp.Person will be unique from MyApp.Person.
    MyApp.Person = SC.Record.extend({});

    // As a subclass, MyApp.Female inherits from a MyApp.Person, but is not "equal" to it.
    MyApp.Female = MyApp.Person.extend({
      isFemale: true
    });

    // As a subclass, MyApp.Male inherits from a MyApp.Person, but is not "equal" to it.
    MyApp.Male = MyApp.Person.extend({
      isMale: true
    });

    // Load two unique records into the store.
    MyApp.store.createRecord(MyApp.Female, { guid: '1' });
    MyApp.store.createRecord(MyApp.Male, { guid: '2' });

    // Now we can see that these records are isolated from each other.
    var female = MyApp.store.find(MyApp.Person, '1'); // Returns an SC.Record.EMPTY record.
    var male = MyApp.store.find(MyApp.Person, '2'); // Returns an SC.Record.EMPTY record.

    // These records are MyApp.Person only.
    SC.kindOf(female, MyApp.Female); // false
    SC.kindOf(male, MyApp.Male); // false

  Next, let's make MyApp.Person a polymorphic class,

    // This is the "root" polymorphic class. All subclasses of MyApp.Person will be able to stand-in as a MyApp.Person.
    MyApp.Person = SC.Record.extend({
      isPolymorphic: true
    });

    // As a polymorphic subclass, MyApp.Female is "equal" to a MyApp.Person.
    MyApp.Female = MyApp.Person.extend({
      isFemale: true
    });

    // As a polymorphic subclass, MyApp.Male is "equal" to a MyApp.Person.
    MyApp.Male = MyApp.Person.extend({
      isMale: true
    });

    // Load two unique records into the store.
    MyApp.store.createRecord(MyApp.Female, { guid: '1' });
    MyApp.store.createRecord(MyApp.Male, { guid: '2' });

    // Now we can see that these records are in fact "equal" to each other. Which means that if we
    // search for "people", we will get "males" & "females".
    var female = MyApp.store.find(MyApp.Person, '1'); // Returns record.
    var male = MyApp.store.find(MyApp.Person, '2'); // Returns record.

    // These records are MyApp.Person as well as their unique subclass.
    SC.kindOf(female, MyApp.Female); // true
    SC.kindOf(male, MyApp.Male); // true

  @extends SC.Object
  @see SC.RecordAttribute
  @since SproutCore 1.0
*/
SC.Record = SC.Object.extend(
/** @scope SC.Record.prototype */ {

  


  /**
    Walk like a duck

    @type Boolean
    @default YES
  */
  isRecord: YES,

  // ----------------------------------------------------------------------------------------------
  // Properties
  //

  /**
    Returns the id for the record instance.  The id is used to uniquely
    identify this record instance from all others of the same type.  If you
    have a `primaryKey set on this class, then the id will be the value of the
    `primaryKey` property on the underlying JSON hash.

    @type String
    @property
    @dependsOn storeKey
  */
  id: function(key, value) {
    if (value !== undefined) {
      this.writeAttribute(this.get('primaryKey'), value);
      return value;
    } else {
      return SC.Store.idFor(this.storeKey);
    }
  }.property('storeKey').cacheable(),

  /**
    If you have nested records

    @type Boolean
    @default NO
  */
  isParentRecord: NO,

  /**
    This is the primary key used to distinguish records.  If the keys
    match, the records are assumed to be identical.

    @type String
    @default 'guid'
  */
  primaryKey: 'guid',

  /**
    All records generally have a life cycle as they are created or loaded into
    memory, modified, committed and finally destroyed.  This life cycle is
    managed by the status property on your record.

    The status of a record is modelled as a finite state machine.  Based on the
    current state of the record, you can determine which operations are
    currently allowed on the record and which are not.

    In general, a record can be in one of five primary states:
    `SC.Record.EMPTY`, `SC.Record.BUSY`, `SC.Record.READY`,
    `SC.Record.DESTROYED`, `SC.Record.ERROR`.  These are all described in
    more detail in the class mixin (below) where they are defined.

    @type Number
    @property
    @dependsOn storeKey
  */
  status: function() {
    return this.store.readStatus(this.storeKey);
  }.property('storeKey').cacheable(),

  /**
    The store that owns this record.  All changes will be buffered into this
    store and committed to the rest of the store chain through here.

    This property is set when the record instance is created and should not be
    changed or else it will break the record behavior.

    @type SC.Store
    @default null
  */
  store: null,

  /**
    This is the store key for the record, it is used to link it back to the
    dataHash. If a record is reused, this value will be replaced.

    You should not edit this store key but you may sometimes need to refer to
    this store key when implementing a Server object.

    @type Number
    @default null
  */
  storeKey: null,

  /**
    YES when the record has been destroyed

    @type Boolean
    @property
    @dependsOn status
  */
  isDestroyed: function() {
    return !!(this.get('status') & SC.Record.DESTROYED);
  }.property('status').cacheable(),

  /**
    `YES` when the record is in an editable state.  You can use this property to
    quickly determine whether attempting to modify the record would raise an
    exception or not.

    This property is both readable and writable.  Note however that if you
    set this property to `YES` but the status of the record is anything but
    `SC.Record.READY`, the return value of this property may remain `NO`.

    @type Boolean
    @property
    @dependsOn status
  */
  isEditable: function(key, value) {
    if (value !== undefined) this._screc_isEditable = value;
    if (this.get('status') & SC.Record.READY) return this._screc_isEditable;
    else return NO;
  }.property('status').cacheable(),

  /**
    @private

    Backing value for isEditable
  */
  _screc_isEditable: YES, // default

  /**
    `YES` when the record's contents have been loaded for the first time.  You
    can use this to quickly determine if the record is ready to display.

    @type Boolean
    @property
    @dependsOn status
  */
  isLoaded: function() {
    var K = SC.Record,
        status = this.get('status');
    return !((status===K.EMPTY) || (status===K.BUSY_LOADING) || (status===K.ERROR));
  }.property('status').cacheable(),

  /**
    If set, this should be an array of active relationship objects that need
    to be notified whenever the underlying record properties change.
    Currently this is only used by toMany relationships, but you could
    possibly patch into this yourself also if you are building your own
    relationships.

    Note this must be a regular Array - NOT any object implementing SC.Array.

    @type Array
    @default null
  */
  relationships: null,

  /**
    This will return the raw attributes that you can edit directly.  If you
    make changes to this hash, be sure to call `beginEditing()` before you get
    the attributes and `endEditing()` afterwards.

    @type Hash
    @property
  **/
  attributes: function() {
    var store    = this.get('store'),
        storeKey = this.storeKey;
    return store.readEditableDataHash(storeKey);
  }.property(),

  /**
    This will return the raw attributes that you cannot edit directly.  It is
    useful if you want to efficiently look at multiple attributes in bulk.  If
    you would like to edit the attributes, see the `attributes` property
    instead.

    @type Hash
    @property
  **/
  readOnlyAttributes: function() {
    var store    = this.get('store'),
        storeKey = this.storeKey,
        ret      = store.readDataHash(storeKey);

    if (ret) ret = SC.clone(ret, YES);

    return ret;
  }.property(),

  /**
    The namespace which to retrieve the childRecord Types from

    @type String
    @default null
  */
  nestedRecordNamespace: null,

  /**
    Whether or not this is a nested Record.

    @type Boolean
    @property
  */
  isNestedRecord: function(){
    var store = this.get('store'), ret,
        sk = this.get('storeKey'),
        prKey = store.parentStoreKeyExists(sk);

    ret = prKey ? YES : NO;
    return ret;
  }.property().cacheable(),

  /**
    The parent record if this is a nested record.

    @type Boolean
    @property
  */
  parentRecord: function(){
    var sk = this.storeKey, store = this.get('store');
    return store.materializeParentRecord(sk);
  }.property(),

  // ...............................
  // CRUD OPERATIONS
  //

  /**
    Refresh the record from the persistent store.  If the record was loaded
    from a persistent store, then the store will be asked to reload the
    record data from the server.  If the record is new and exists only in
    memory then this call will have no effect.

    @param {boolean} recordOnly optional param if you want to only THIS record
      even if it is a child record.
    @param {Function} callback optional callback that will fire when request finishes

    @returns {SC.Record} receiver
  */
  refresh: function(recordOnly, callback) {
    var store = this.get('store'), rec, ro,
        sk = this.get('storeKey'),
        prKey = store.parentStoreKeyExists();

    // If we only want to commit this record or it doesn't have a parent record
    // we will commit this record
    ro = recordOnly || (SC.none(recordOnly) && SC.none(prKey));
    if (ro){
      store.refreshRecord(null, null, sk, callback);
    } else if (prKey){
      rec = store.materializeRecord(prKey);
      rec.refresh(recordOnly, callback);
    }

    return this;
  },

  /**
    Deletes the record along with any dependent records.  This will mark the
    records destroyed in the store as well as changing the isDestroyed
    property on the record to YES.  If this is a new record, this will avoid
    creating the record in the first place.

    @param {boolean} recordOnly optional param if you want to only THIS record
      even if it is a child record.

    @returns {SC.Record} receiver
  */
  destroy: function(recordOnly) {
    var store = this.get('store'), rec, ro,
        sk = this.get('storeKey'),
        prKey = store.parentStoreKeyExists();

    // If we only want to commit this record or it doesn't have a parent record
    // we will commit this record
    ro = recordOnly || (SC.none(recordOnly) && SC.none(prKey));
    if (ro){
      store.destroyRecord(null, null, sk);
      this.notifyPropertyChange('status');
      // If there are any aggregate records, we might need to propagate our new
      // status to them.
      this.propagateToAggregates();

    } else if (prKey){
      rec = store.materializeRecord(prKey);
      rec.destroy(recordOnly);
    }

    return this;
  },

  /**
    You can invoke this method anytime you need to make the record as dirty.
    This will cause the record to be committed when you `commitChanges()`
    on the underlying store.

    If you use the `writeAttribute()` primitive, this method will be called
    for you.

    If you pass the key that changed it will ensure that observers are fired
    only once for the changed property instead of `allPropertiesDidChange()`

    @param {String} key key that changed (optional)
    @returns {SC.Record} receiver
  */
  recordDidChange: function(key) {

    // If we have a parent, they changed too!
    var p = this.get('parentRecord');
    if (p) p.recordDidChange();

    this.get('store').recordDidChange(null, null, this.get('storeKey'), key);
    this.notifyPropertyChange('status');

    // If there are any aggregate records, we might need to propagate our new
    // status to them.
    this.propagateToAggregates();

    return this;
  },

  toJSON: function(){
    return this.get('attributes');
  },

  // ...............................
  // ATTRIBUTES
  //

  /** @private
    Current edit level.  Used to defer editing changes.
  */
  _editLevel: 0 ,

  /**
    Defers notification of record changes until you call a matching
    `endEditing()` method.  This method is called automatically whenever you
    set an attribute, but you can call it yourself to group multiple changes.

    Calls to `beginEditing()` and `endEditing()` can be nested.

    @returns {SC.Record} receiver
  */
  beginEditing: function() {
    this._editLevel++;
    return this;
  },

  /**
    Notifies the store of record changes if this matches a top level call to
    `beginEditing()`.  This method is called automatically whenever you set an
    attribute, but you can call it yourself to group multiple changes.

    Calls to `beginEditing()` and `endEditing()` can be nested.

    @param {String} key key that changed (optional)
    @returns {SC.Record} receiver
  */
  endEditing: function(key) {
    if(--this._editLevel <= 0) {
      this._editLevel = 0;
      this.recordDidChange(key);
    }
    return this;
  },

  /**
    Reads the raw attribute from the underlying data hash.  This method does
    not transform the underlying attribute at all.

    @param {String} key the attribute you want to read
    @returns {Object} the value of the key, or undefined if it doesn't exist
  */
  readAttribute: function(key) {
    var store = this.get('store'), storeKey = this.storeKey;
    var attrs = store.readDataHash(storeKey);
    return attrs ? attrs[key] : undefined;
  },

  /**
    Updates the passed attribute with the new value.  This method does not
    transform the value at all.  If instead you want to modify an array or
    hash already defined on the underlying json, you should instead get
    an editable version of the attribute using `editableAttribute()`.

    @param {String} key the attribute you want to read
    @param {Object} value the value you want to write
    @param {Boolean} ignoreDidChange only set if you do NOT want to flag
      record as dirty
    @returns {SC.Record} receiver
  */
  writeAttribute: function(key, value, ignoreDidChange) {
    var store    = this.get('store'),
        storeKey = this.storeKey,
        attrs;

    attrs = store.readEditableDataHash(storeKey);
    if (!attrs) SC.Record.BAD_STATE_ERROR.throw();

    // if value is the same, do not flag record as dirty
    if (value !== attrs[key]) {
      if(!ignoreDidChange) this.beginEditing();
      attrs[key] = value;

      // If the key is the primaryKey of the record, we need to tell the store
      // about the change.
      if (key === this.get('primaryKey')) {
        SC.Store.replaceIdFor(storeKey, value);
        this.propertyDidChange('id'); // Reset computed value
      }

      if(!ignoreDidChange) { this.endEditing(key); }
      else {
        // We must still inform the store of the change so that it can track the change across stores.
        store.dataHashDidChange(storeKey, null, undefined, key);
      }
    }
    return this;
  },

  /**
    This will also ensure that any aggregate records are also marked dirty
    if this record changes.

    Should not have to be called manually.
  */
  propagateToAggregates: function() {
    var storeKey   = this.get('storeKey'),
        recordType = SC.Store.recordTypeFor(storeKey),
        aggregates = recordType.__sc_aggregate_keys,
        idx, len, key, prop, val, recs;

    // if recordType aggregates are not set up yet, make sure to
    // create the cache first
    if (!aggregates) {
      aggregates = [];
      for (key in this) {
        prop = this[key];
        if (prop  &&  prop.isRecordAttribute  &&  prop.aggregate === YES) {
          aggregates.push(key);
        }
      }
      recordType.__sc_aggregate_keys = aggregates;
    }

    // now loop through all aggregate properties and mark their related
    // record objects as dirty
    var K          = SC.Record,
        dirty      = K.DIRTY,
        readyNew   = K.READY_NEW,
        destroyed  = K.DESTROYED,
        readyClean = K.READY_CLEAN,
        iter;

    /**
      @private

      If the child is dirty, then make sure the parent gets a dirty
      status.  (If the child is created or destroyed, there's no need,
      because the parent will dirty itself when it modifies that
      relationship.)

      @param {SC.Record} record to propagate to
    */
    iter =  function(rec) {
      var childStatus, parentStore, parentStoreKey, parentStatus;

      if (rec) {
        childStatus = this.get('status');
        if ((childStatus & dirty)  ||
            (childStatus & readyNew)  ||  (childStatus & destroyed)) {

          // Since the parent can cache 'status', and we might be called before
          // it has been invalidated, we'll read the status directly rather than
          // trusting the cache.
          parentStore    = rec.get('store');
          parentStoreKey = rec.get('storeKey');
          parentStatus   = parentStore.peekStatus(parentStoreKey);
          if (parentStatus === readyClean) {
            // Note:  storeDidChangeProperties() won't put it in the
            //        changelog!
            rec.get('store').recordDidChange(rec.constructor, null, rec.get('storeKey'), null, YES);
          }
        }
      }
    };

    for(idx=0,len=aggregates.length;idx<len;++idx) {
      key = aggregates[idx];
      val = this.get(key);
      recs = SC.kindOf(val, SC.ManyArray) ? val : [val];
      recs.forEach(iter, this);
    }
  },

  /**
    Called by the store whenever the underlying data hash has changed.  This
    will notify any observers interested in data hash properties that they
    have changed.

    @param {Boolean} statusOnly changed
    @param {String} key that changed (optional)
    @returns {SC.Record} receiver
  */
  storeDidChangeProperties: function(statusOnly, keys) {
    // TODO:  Should this function call propagateToAggregates() at the
    //        appropriate times?
    if (statusOnly) this.notifyPropertyChange('status');
    else {
      if (keys) {
        this.beginPropertyChanges();
        keys.forEach(function(k) { this.notifyPropertyChange(k); }, this);
        this.notifyPropertyChange('status');
        this.endPropertyChanges();

      } else {
        this.allPropertiesDidChange();
      }

      // also notify manyArrays
      var manyArrays = this.relationships,
          loc        = manyArrays ? manyArrays.length : 0;
      while(--loc>=0) manyArrays[loc].recordPropertyDidChange(keys);
    }
  },

  /**
    Normalizing a record will ensure that the underlying hash conforms
    to the record attributes such as their types (transforms) and default
    values.

    This method will write the conforming hash to the store and return
    the materialized record.

    By normalizing the record, you can use `.attributes()` and be
    assured that it will conform to the defined model. For example, this
    can be useful in the case where you need to send a JSON representation
    to some server after you have used `.createRecord()`, since this method
    will enforce the 'rules' in the model such as their types and default
    values. You can also include null values in the hash with the
    includeNull argument.

    @param {Boolean} includeNull will write empty (null) attributes
    @returns {SC.Record} the normalized record
  */

  normalize: function(includeNull) {
    var primaryKey = this.primaryKey,
        store      = this.get('store'),
        storeKey   = this.get('storeKey'),
        keysToKeep = {},
        key, valueForKey, typeClass, recHash, attrValue, isRecord,
        isChild, defaultVal, keyForDataHash, attr;

    var dataHash = store.readEditableDataHash(storeKey) || {};
    recHash = store.readDataHash(storeKey);

    // For now we're going to be agnostic about whether ids should live in the
    // hash or not.
    keysToKeep[primaryKey] = YES;

    for (key in this) {
      // make sure property is a record attribute.
      valueForKey = this[key];
      if (valueForKey) {
        typeClass = valueForKey.typeClass;
        if (typeClass) {
          keyForDataHash = valueForKey.get('key') || key; // handle alt keys

          // As we go, we'll build up a key —> attribute mapping table that we
          // can use when purging keys from the data hash that are not defined
          // in the schema, below.
          keysToKeep[keyForDataHash] = YES;

          isRecord = SC.typeOf(typeClass.call(valueForKey))===SC.T_CLASS;
          isChild  = valueForKey.isNestedRecordTransform;
          if (!isRecord && !isChild) {
            attrValue = this.get(key);
            if(attrValue!==undefined && (attrValue!==null || includeNull)) {
              attr = this[key];
              // if record attribute, make sure we transform with the fromType
              if(SC.kindOf(attr, SC.RecordAttribute)) {
                attrValue = attr.fromType(this, key, attrValue);
              }
              dataHash[keyForDataHash] = attrValue;
            }
            else if(!includeNull) {
              keysToKeep[keyForDataHash] = NO;
            }

          } else if (isChild) {
            attrValue = this.get(key);

            // Sometimes a child attribute property does not refer to a child record.
            // Catch this and don't try to normalize.
            if (attrValue && attrValue.normalize) {
              attrValue.normalize();
            }
          } else if (isRecord) {
            attrValue = recHash[keyForDataHash];
            if (attrValue !== undefined) {
              // write value already there
              dataHash[keyForDataHash] = attrValue;
            } else {
              // or write default
              defaultVal = valueForKey.get('defaultValue');

              // computed default value
              if (SC.typeOf(defaultVal)===SC.T_FUNCTION) {
                dataHash[keyForDataHash] = defaultVal(this, key, defaultVal);
              } else {
                // plain value
                dataHash[keyForDataHash] = defaultVal;
              }
            }
          }
        }
      }
    }

    // Finally, we'll go through the underlying data hash and remove anything
    // for which no appropriate attribute is defined.  We can do this using
    // the mapping table we prepared above.
    for (key in dataHash) {
      if (!keysToKeep[key]) {
        // Deleting a key doesn't seem too common unless it's a mistake, so
        // we'll log it in debug mode.
        SC.debug("%@:  Deleting key from underlying data hash due to normalization:  %@", this, key);
        delete dataHash[key];
      }
    }

    return this;
  },



  /**
    If you try to get/set a property not defined by the record, then this
    method will be called. It will try to get the value from the set of
    attributes.

    This will also check is `ignoreUnknownProperties` is set on the recordType
    so that they will not be written to `dataHash` unless explicitly defined
    in the model schema.

    @param {String} key the attribute being get/set
    @param {Object} value the value to set the key to, if present
    @returns {Object} the value
  */
  unknownProperty: function(key, value) {

    if (value !== undefined) {

      // first check if we should ignore unknown properties for this
      // recordType
      var storeKey = this.get('storeKey'),
        recordType = SC.Store.recordTypeFor(storeKey);

      if(recordType.ignoreUnknownProperties===YES) {
        this[key] = value;
        return value;
      }

      // if we're modifying the PKEY, then `SC.Store` needs to relocate where
      // this record is cached. store the old key, update the value, then let
      // the store do the housekeeping...
      var primaryKey = this.get('primaryKey');
      this.writeAttribute(key,value);

      // update ID if needed
      if (key === primaryKey) {
        SC.Store.replaceIdFor(storeKey, value);
      }

    }
    return this.readAttribute(key);
  },

  /**
    Lets you commit this specific record to the store which will trigger
    the appropriate methods in the data source for you.

    @param {Hash} params optional additional params that will passed down
      to the data source
    @param {boolean} recordOnly optional param if you want to only commit a single
      record if it has a parent.
    @param {Function} callback optional callback that the store will fire once the
    datasource finished committing
    @returns {SC.Record} receiver
  */
  commitRecord: function(params, recordOnly, callback) {
    var store = this.get('store'), rec, ro,
        prKey = store.parentStoreKeyExists();

    // If we only want to commit this record or it doesn't have a parent record
    // we will commit this record
    ro = recordOnly || (SC.none(recordOnly) && SC.none(prKey));
    if (ro){
      store.commitRecord(undefined, undefined, this.get('storeKey'), params, callback);
    } else if (prKey){
      rec = store.materializeRecord(prKey);
      rec.commitRecord(params, recordOnly, callback);
    }
    return this;
  },

  // ..........................................................
  // EMULATE SC.ERROR API
  //

  /**
    Returns `YES` whenever the status is SC.Record.ERROR.  This will allow you
    to put the UI into an error state.

    @type Boolean
    @property
    @dependsOn status
  */
  isError: function() {
    return !!(this.get('status') & SC.Record.ERROR);
  }.property('status').cacheable(),

  /**
    Returns the receiver if the record is in an error state.  Returns null
    otherwise.

    @type SC.Record
    @property
    @dependsOn isError
  */
  errorValue: function() {
    return this.get('isError') ? SC.val(this.get('errorObject')) : null;
  }.property('isError').cacheable(),

  /**
    Returns the current error object only if the record is in an error state.
    If no explicit error object has been set, returns SC.Record.GENERIC_ERROR.

    @type SC.Error
    @property
    @dependsOn isError
  */
  errorObject: function() {
    if (this.get('isError')) {
      var store = this.get('store');
      return store.readError(this.get('storeKey')) || SC.Record.GENERIC_ERROR;
    } else return null;
  }.property('isError').cacheable(),

  // ...............................
  // PRIVATE
  //

  /** @private
    Sets the key equal to value.

    This version will first check to see if the property is an
    `SC.RecordAttribute`, and if so, will ensure that its isEditable property
    is `YES` before attempting to change the value.

    @param key {String} the property to set
    @param value {Object} the value to set or null.
    @returns {SC.Record}
  */
  set: function(key, value) {
    var func = this[key];

    if (func && func.isProperty && func.get && !func.get('isEditable')) {
      return this;
    }
    return arguments.callee.base.apply(this,arguments);
  },

  /**
    Registers a child record with this parent record.

    If the parent already knows about the child record, return the cached
    instance. If not, create the child record instance and add it to the child
    record cache.

    @param {Hash} value The hash of attributes to apply to the child record.
    @param {Integer} key The store key that we are asking for
    @param {String} path The property path of the child record
    @returns {SC.Record} the child record that was registered
   */
  registerNestedRecord: function(value, key, path) {
    var store, psk = this.get('storeKey'), csk, childRecord, recordType;

    // if no path is entered it must be the key
    if (SC.none(path)) path = key;
    // if a record instance is passed, simply use the storeKey.  This allows
    // you to pass a record from a chained store to get the same record in the
    // current store.
    if (value && value.get && value.get('isRecord')) {
      childRecord = value;
    }
    else {
      recordType = this._materializeNestedRecordType(value, key);
      childRecord = this.createNestedRecord(recordType, value, psk, path);
    }
    if (childRecord){
      this.isParentRecord = YES;
      store = this.get('store');
      csk = childRecord.get('storeKey');
      store.registerChildToParent(psk, csk, path);
    }

    return childRecord;
  },

  /**
    Unregisters a child record from its parent record.

    Since accessing a child (nested) record creates a new data hash for the
    child and caches the child record and its relationship to the parent record,
    it's important to clear those caches when the child record is overwritten
    or removed.  This function tells the store to remove the child record from
    the store's various child record caches.

    You should not need to call this function directly.  Simply setting the
    child record property on the parent to a different value will cause the
    previous child record to be unregistered.

    @param {String} path The property path of the child record.
  */
  unregisterNestedRecord: function(path) {
    var childRecord, csk, store;

    store = this.get('store');
    childRecord = this.getPath(path);
    csk = childRecord.get('storeKey');
    store.unregisterChildFromParent(csk);
  },

  /**
    @private

     private method that retrieves the `recordType` from the hash that is
     provided.

     Important for use in polymorphism but you must have the following items
     in the parent record:

     `nestedRecordNamespace` <= this is the object that has the `SC.Records`
     defined

     @param {Hash} value The hash of attributes to apply to the child record.
     @param {String} key the name of the key on the attribute
     @param {SC.Record} the record that was materialized
    */
  _materializeNestedRecordType: function(value, key){
    var childNS, recordType;

    // Get the record type, first checking the "type" property on the hash.
    if (SC.typeOf(value) === SC.T_HASH) {
      // Get the record type.
      childNS = this.get('nestedRecordNamespace');
      if (value.type && !SC.none(childNS)) {
        recordType = childNS[value.type];
      }
    }

    // Maybe it's not a hash or there was no type property.
    if (!recordType && key && this[key]) {
      recordType = this[key].get('typeClass');
    }

    // When all else fails throw and exception.
    if (!recordType || !SC.kindOf(recordType, SC.Record)) {
      throw new Error('SC.Child: Error during transform: Invalid record type.');
    }

    return recordType;
  },

  /**
    Creates a new nested record instance.

    @param {SC.Record} recordType The type of the nested record to create.
    @param {Hash} hash The hash of attributes to apply to the child record.
    (may be null)
    @returns {SC.Record} the nested record created
   */
  createNestedRecord: function(recordType, hash, psk, path) {
    var store = this.get('store'), id, sk, cr = null;

    hash = hash || {}; // init if needed

    if (SC.none(store)) throw new Error('Error: during the creation of a child record: NO STORE ON PARENT!');

    // Check for a primary key in the child record hash and if not found, then
    // check for a custom id generation function and if we still have no id,
    // generate a unique (and re-createable) id based on the parent's
    // storeKey.  Having the generated id be re-createable is important so
    // that we don't keep making new storeKeys for the same child record each
    // time that it is reloaded.
    id = hash[recordType.prototype.primaryKey];
    if (!id) { id = this.generateIdForChild(cr); }
    if (!id) { id = psk + '.' + path; }

    // If there is an id, there may also be a storeKey.  If so, update the
    // hash for the child record in the store and materialize it.  If not,
    // then create the child record.
    sk = store.storeKeyExists(recordType, id);
    if (sk) {
      store.writeDataHash(sk, hash);
      cr = store.materializeRecord(sk);
    } else {
      cr = store.createRecord(recordType, hash, id);
    }

    return cr;
  },

  _nestedRecordKey: 0,

  /**
    Override this function if you want to have a special way of creating
    ids for your child records

    @param {SC.Record} childRecord
    @returns {String} the id generated
   */
  generateIdForChild: function(childRecord){}

});

// Class Methods
SC.Record.mixin( /** @scope SC.Record */ {

  /**
    Whether to ignore unknown properties when they are being set on the record
    object. This is useful if you want to strictly enforce the model schema
    and not allow dynamically expanding it by setting new unknown properties

    @static
    @type Boolean
    @default NO
  */
  ignoreUnknownProperties: NO,

  // ..........................................................
  // CONSTANTS
  //

  /**
    Generic state for records with no local changes.

    Use a logical AND (single `&`) to test record status

    @static
    @constant
    @type Number
    @default 0x0001
  */
  CLEAN:            0x0001, // 1

  /**
    Generic state for records with local changes.

    Use a logical AND (single `&`) to test record status

    @static
    @constant
    @type Number
    @default 0x0002
  */
  DIRTY:            0x0002, // 2

  /**
    State for records that are still loaded.

    A record instance should never be in this state.  You will only run into
    it when working with the low-level data hash API on `SC.Store`. Use a
    logical AND (single `&`) to test record status

    @static
    @constant
    @type Number
    @default 0x0100
  */
  EMPTY:            0x0100, // 256

  /**
    State for records in an error state.

    Use a logical AND (single `&`) to test record status

    @static
    @constant
    @type Number
    @default 0x1000
  */
  ERROR:            0x1000, // 4096

  /**
    Generic state for records that are loaded and ready for use

    Use a logical AND (single `&`) to test record status

    @static
    @constant
    @type Number
    @default 0x0200
  */
  READY:            0x0200, // 512

  /**
    State for records that are loaded and ready for use with no local changes

    Use a logical AND (single `&`) to test record status

    @static
    @constant
    @type Number
    @default 0x0201
  */
  READY_CLEAN:      0x0201, // 513


  /**
    State for records that are loaded and ready for use with local changes

    Use a logical AND (single `&`) to test record status

    @static
    @constant
    @type Number
    @default 0x0202
  */
  READY_DIRTY:      0x0202, // 514


  /**
    State for records that are new - not yet committed to server

    Use a logical AND (single `&`) to test record status

    @static
    @constant
    @type Number
    @default 0x0203
  */
  READY_NEW:        0x0203, // 515


  /**
    Generic state for records that have been destroyed

    Use a logical AND (single `&`) to test record status

    @static
    @constant
    @type Number
    @default 0x0400
  */
  DESTROYED:        0x0400, // 1024


  /**
    State for records that have been destroyed and committed to server

    Use a logical AND (single `&`) to test record status

    @static
    @constant
    @type Number
    @default 0x0401
  */
  DESTROYED_CLEAN:  0x0401, // 1025


  /**
    State for records that have been destroyed but not yet committed to server

    Use a logical AND (single `&`) to test record status

    @static
    @constant
    @type Number
    @default 0x0402
  */
  DESTROYED_DIRTY:  0x0402, // 1026


  /**
    Generic state for records that have been submitted to data source

    Use a logical AND (single `&`) to test record status

    @static
    @constant
    @type Number
    @default 0x0800
  */
  BUSY:             0x0800, // 2048


  /**
    State for records that are still loading data from the server

    Use a logical AND (single `&`) to test record status

    @static
    @constant
    @type Number
    @default 0x0804
  */
  BUSY_LOADING:     0x0804, // 2052


  /**
    State for new records that were created and submitted to the server;
    waiting on response from server

    Use a logical AND (single `&`) to test record status

    @static
    @constant
    @type Number
    @default 0x0808
  */
  BUSY_CREATING:    0x0808, // 2056


  /**
    State for records that have been modified and submitted to server

    Use a logical AND (single `&`) to test record status

    @static
    @constant
    @type Number
    @default 0x0810
  */
  BUSY_COMMITTING:  0x0810, // 2064


  /**
    State for records that have requested a refresh from the server.

    Use a logical AND (single `&`) to test record status.

    @static
    @constant
    @type Number
    @default 0x0820
  */
  BUSY_REFRESH:     0x0820, // 2080


  /**
    State for records that have requested a refresh from the server.

    Use a logical AND (single `&`) to test record status

    @static
    @constant
    @type Number
    @default 0x0821
  */
  BUSY_REFRESH_CLEAN:  0x0821, // 2081

  /**
    State for records that have requested a refresh from the server.

    Use a logical AND (single `&`) to test record status

    @static
    @constant
    @type Number
    @default 0x0822
  */
  BUSY_REFRESH_DIRTY:  0x0822, // 2082

  /**
    State for records that have been destroyed and submitted to server

    Use a logical AND (single `&`) to test record status

    @static
    @constant
    @type Number
    @default 0x0840
  */
  BUSY_DESTROYING:  0x0840, // 2112


  // ..........................................................
  // ERRORS
  //

  /**
    Error for when you try to modify a record while it is in a bad
    state.

    @static
    @constant
    @type SC.Error
  */
  BAD_STATE_ERROR: SC.$error("Internal Inconsistency"),

  /**
    Error for when you try to create a new record that already exists.

    @static
    @constant
    @type SC.Error
  */
  RECORD_EXISTS_ERROR: SC.$error("Record Exists"),

  /**
    Error for when you attempt to locate a record that is not found

    @static
    @constant
    @type SC.Error
  */
  NOT_FOUND_ERROR: SC.$error("Not found "),

  /**
    Error for when you try to modify a record that is currently busy

    @static
    @constant
    @type SC.Error
  */
  BUSY_ERROR: SC.$error("Busy"),

  /**
    Generic unknown record error

    @static
    @constant
    @type SC.Error
  */
  GENERIC_ERROR: SC.$error("Generic Error"),

  /**
    If true, then searches for records of this type will return subclass instances. For example:

        Person = SC.Record.extend();
        Person.isPolymorphic = true;

        Male = Person.extend();
        Female = Person.extend();

    Using SC.Store#find, or a toOne or toMany relationship on Person will then return records of
    type Male and Female. Polymorphic record types must have unique GUIDs across all subclasses.

    @type Boolean
    @default NO
  */
  isPolymorphic: NO,

  /**
    @private
    The next child key to allocate.  A nextChildKey must always be greater than 0.
  */
  _nextChildKey: 0,

  // ..........................................................
  // CLASS METHODS
  //

  /**
    Helper method returns a new `SC.RecordAttribute` instance to map a simple
    value or to-one relationship.  At the very least, you should pass the
    type class you expect the attribute to have.  You may pass any additional
    options as well.

    Use this helper when you define SC.Record subclasses.

        MyApp.Contact = SC.Record.extend({
          firstName: SC.Record.attr(String, { isRequired: YES })
        });

    @param {Class} type the attribute type
    @param {Hash} opts the options for the attribute
    @returns {SC.RecordAttribute} created instance
  */
  attr: function(type, opts) {
    return SC.RecordAttribute.attr(type, opts);
  },

  /**
    Returns an `SC.RecordAttribute` that describes a fetched attribute.  When
    you reference this attribute, it will return an `SC.RecordArray` that uses
    the type as the fetch key and passes the attribute value as a param.

    Use this helper when you define SC.Record subclasses.

        MyApp.Group = SC.Record.extend({
          contacts: SC.Record.fetch('MyApp.Contact')
        });

    @param {SC.Record|String} recordType The type of records to load
    @param {Hash} opts the options for the attribute
    @returns {SC.RecordAttribute} created instance
  */
  fetch: function(recordType, opts) {
    return SC.FetchedAttribute.attr(recordType, opts);
  },

  /**
    Will return one of the following:

     1. `SC.ManyAttribute` that describes a record array backed by an
        array of guids stored in the underlying JSON.
     2. `SC.ChildrenAttribute` that describes a record array backed by a
        array of hashes.

    You can edit the contents of this relationship.

    For `SC.ManyAttribute`, If you set the inverse and `isMaster: NO` key,
    then editing this array will modify the underlying data, but the
    inverse key on the matching record will also be edited and that
    record will be marked as needing a change.

    @param {SC.Record|String} recordType The type of record to create
    @param {Hash} opts the options for the attribute
    @returns {SC.ManyAttribute|SC.ChildrenAttribute} created instance
  */
  toMany: function(recordType, opts) {
    opts = opts || {};
    var isNested = opts.nested || opts.isNested;
    var attr;

    this._throwUnlessRecordTypeDefined(recordType, 'toMany');

    if(isNested){
      

      attr = SC.ChildrenAttribute.attr(recordType, opts);
    }
    else {
      attr = SC.ManyAttribute.attr(recordType, opts);
    }
    return attr;
  },

  /**
    Will return one of the following:

     1. `SC.SingleAttribute` that converts the underlying ID to a single
        record.  If you modify this property, it will rewrite the underlying
        ID. It will also modify the inverse of the relationship, if you set it.
     2. `SC.ChildAttribute` that you can edit the contents
        of this relationship.

    @param {SC.Record|String} recordType the type of the record to create
    @param {Hash} opts additional options
    @returns {SC.SingleAttribute|SC.ChildAttribute} created instance
  */
  toOne: function(recordType, opts) {
    opts = opts || {};
    var isNested = opts.nested || opts.isNested;
    var attr;

    this._throwUnlessRecordTypeDefined(recordType, 'toOne');

    if(isNested){
      

      attr = SC.ChildAttribute.attr(recordType, opts);
    }
    else {
      attr = SC.SingleAttribute.attr(recordType, opts);
    }
    return attr;
  },

  _throwUnlessRecordTypeDefined: function(recordType, relationshipType) {
    if (!recordType) {
      throw new Error("Attempted to create " + relationshipType + " attribute with " +
            "undefined recordType. Did you forget to sc_require a dependency?");
    }
  },

  /**
    Returns all storeKeys mapped by Id for this record type.  This method is used mostly by the
    `SC.Store` and the Record to coordinate.  You will rarely need to call this method yourself.

    Note that for polymorpic record classes, all store keys are kept on the top-most polymorphic
    superclass. This ensures that store key by id requests at any level return only the one unique
    store key.

    @see SC.Record.storeKeysById
  */
  storeKeysById: function() {
    var superclass = this.superclass,
      key = SC.keyFor('storeKey', SC.guidFor(this)),
      ret = this[key];

    if (!ret) {
      if (this.isPolymorphic && superclass.isPolymorphic && superclass !== SC.Record) {
        ret = this[key] = superclass.storeKeysById();
      } else {
        ret = this[key] = {};
      }
    }

    return ret;
  },

  /**
    Given a primaryKey value for the record, returns the associated
    storeKey.  If the primaryKey has not been assigned a storeKey yet, it
    will be added.

    For the inverse of this method see `SC.Store.idFor()` and
    `SC.Store.recordTypeFor()`.

    @param {String} id a record id
    @returns {Number} a storeKey.
  */
  storeKeyFor: function(id) {
    var storeKeys = this.storeKeysById(),
        ret = storeKeys[id];

    if (!ret) {
      ret = SC.Store.generateStoreKey();
      SC.Store.idsByStoreKey[ret] = id;
      SC.Store.recordTypesByStoreKey[ret] = this;
      storeKeys[id] = ret;
    }

    return ret;
  },

  /**
    Given a primaryKey value for the record, returns the associated
    storeKey.  As opposed to `storeKeyFor()` however, this method
    will NOT generate a new storeKey but returned undefined.

    @param {String} id a record id
    @returns {Number} a storeKey.
  */
  storeKeyExists: function(id) {
    var storeKeys = this.storeKeysById(),
        ret = storeKeys[id];

    return ret;
  },

  /**
    Returns a record with the named ID in store.

    @param {SC.Store} store the store
    @param {String} id the record id or a query
    @returns {SC.Record} record instance
  */
  find: function(store, id) {
    return store.find(this, id);
  },

  /** @private - enhance extend to notify SC.Query and ensure polymorphic subclasses are marked as polymorphic as well. */
  extend: function() {
    var ret = SC.Object.extend.apply(this, arguments);

    if (SC.Query) SC.Query._scq_didDefineRecordType(ret);

    // All subclasses of a polymorphic class, must also be polymorphic.
    if (ret.prototype.hasOwnProperty('isPolymorphic')) {
      ret.isPolymorphic = ret.prototype.isPolymorphic;
      delete ret.prototype.isPolymorphic;
    }

    return ret;
  }

});

/* >>>>>>>>>> BEGIN source/data_sources/fixtures.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('data_sources/data_source');
sc_require('models/record');

/** @class

  TODO: Describe Class

  @extends SC.DataSource
  @since SproutCore 1.0
*/
SC.FixturesDataSource = SC.DataSource.extend(
  /** @scope SC.FixturesDataSource.prototype */ {

  /**
    If YES then the data source will asynchronously respond to data requests
    from the server.  If you plan to replace the fixture data source with a
    data source that talks to a real remote server (using Ajax for example),
    you should leave this property set to YES so that Fixtures source will
    more accurately simulate your remote data source.

    If you plan to replace this data source with something that works with
    local storage, for example, then you should set this property to NO to
    accurately simulate the behavior of your actual data source.

    @type Boolean
  */
  simulateRemoteResponse: NO,

  /**
    If you set simulateRemoteResponse to YES, then the fixtures source will
    assume a response latency from your server equal to the msec specified
    here.  You should tune this to simulate latency based on the expected
    performance of your server network.  Here are some good guidelines:

     - 500: Simulates a basic server written in PHP, Ruby, or Python (not twisted) without a CDN in front for caching.
     - 250: (Default) simulates the average latency needed to go back to your origin server from anywhere in the world.  assumes your servers itself will respond to requests < 50 msec
     - 100: simulates the latency to a "nearby" server (i.e. same part of the world).  Suitable for simulating locally hosted servers or servers with multiple data centers around the world.
     - 50: simulates the latency to an edge cache node when using a CDN.  Life is really good if you can afford this kind of setup.

    @type Number
  */
  latency: 50,

  // ..........................................................
  // CANCELLING
  //

  /** @private */
  cancel: function(store, storeKeys) {
    return NO;
  },


  // ..........................................................
  // FETCHING
  //

  /** @private */
  fetch: function(store, query) {

    // can only handle local queries out of the box
    if (query.get('location') !== SC.Query.LOCAL) {
      SC.throw('SC.Fixture data source can only fetch local queries');
    }

    if (!query.get('recordType') && !query.get('recordTypes')) {
      SC.throw('SC.Fixture data source can only fetch queries with one or more record types');
    }

    if (this.get('simulateRemoteResponse')) {
      this.invokeLater(this._fetch, this.get('latency'), store, query);

    } else this._fetch(store, query);
  },

  /** @private
    Actually performs the fetch.
  */
  _fetch: function(store, query) {

    // NOTE: Assumes recordType or recordTypes is defined.  checked in fetch()
    var recordType = query.get('recordType'),
        recordTypes = query.get('recordTypes') || [recordType];

    // load fixtures for each recordType
    recordTypes.forEach(function(recordType) {
      if (SC.typeOf(recordType) === SC.T_STRING) {
        recordType = SC.objectForPropertyPath(recordType);
      }

      if (recordType) this.loadFixturesFor(store, recordType);
    }, this);

    // notify that query has now loaded - puts it into a READY state
    store.dataSourceDidFetchQuery(query);
  },

  // ..........................................................
  // RETRIEVING
  //

  /** @private */
  retrieveRecords: function(store, storeKeys) {
    // first let's see if the fixture data source can handle any of the
    // storeKeys
    var latency = this.get('latency'),
        ret     = this.hasFixturesFor(storeKeys) ;
    if (!ret) return ret ;

    if (this.get('simulateRemoteResponse')) {
      this.invokeLater(this._retrieveRecords, latency, store, storeKeys);
    } else this._retrieveRecords(store, storeKeys);

    return ret ;
  },

  _retrieveRecords: function(store, storeKeys) {

    storeKeys.forEach(function(storeKey) {
      var ret        = [],
          recordType = SC.Store.recordTypeFor(storeKey),
          id         = store.idFor(storeKey),
          hash       = this.fixtureForStoreKey(store, storeKey);
      ret.push(storeKey);
      store.dataSourceDidComplete(storeKey, hash, id);
    }, this);
  },

  // ..........................................................
  // UPDATE
  //

  /** @private */
  updateRecords: function(store, storeKeys, params) {
    // first let's see if the fixture data source can handle any of the
    // storeKeys
    var latency = this.get('latency'),
        ret     = this.hasFixturesFor(storeKeys) ;
    if (!ret) return ret ;

    if (this.get('simulateRemoteResponse')) {
      this.invokeLater(this._updateRecords, latency, store, storeKeys);
    } else this._updateRecords(store, storeKeys);

    return ret ;
  },

  _updateRecords: function(store, storeKeys) {
    storeKeys.forEach(function(storeKey) {
      var hash = store.readDataHash(storeKey);
      this.setFixtureForStoreKey(store, storeKey, hash);
      store.dataSourceDidComplete(storeKey);
    }, this);
  },


  // ..........................................................
  // CREATE RECORDS
  //

  /** @private */
  createRecords: function(store, storeKeys, params) {
    // first let's see if the fixture data source can handle any of the
    // storeKeys
    var latency = this.get('latency');

    if (this.get('simulateRemoteResponse')) {
      this.invokeLater(this._createRecords, latency, store, storeKeys);
    } else this._createRecords(store, storeKeys);

    return YES ;
  },

  _createRecords: function(store, storeKeys) {
    storeKeys.forEach(function(storeKey) {
      var id         = store.idFor(storeKey),
          recordType = store.recordTypeFor(storeKey),
          dataHash   = store.readDataHash(storeKey),
          fixtures   = this.fixturesFor(recordType);

      if (!id) id = this.generateIdFor(recordType, dataHash, store, storeKey);
      this._invalidateCachesFor(recordType, storeKey, id);
      fixtures[id] = dataHash;

      store.dataSourceDidComplete(storeKey, null, id);
    }, this);
  },

  // ..........................................................
  // DESTROY RECORDS
  //

  /** @private */
  destroyRecords: function(store, storeKeys, params) {
    // first let's see if the fixture data source can handle any of the
    // storeKeys
    var latency = this.get('latency'),
        ret     = this.hasFixturesFor(storeKeys) ;
    if (!ret) return ret ;

    if (this.get('simulateRemoteResponse')) {
      this.invokeLater(this._destroyRecords, latency, store, storeKeys);
    } else this._destroyRecords(store, storeKeys);

    return ret ;
  },


  _destroyRecords: function(store, storeKeys) {
    storeKeys.forEach(function(storeKey) {
      var id         = store.idFor(storeKey),
          recordType = store.recordTypeFor(storeKey),
          fixtures   = this.fixturesFor(recordType);

      this._invalidateCachesFor(recordType, storeKey, id);
      if (id) delete fixtures[id];
      store.dataSourceDidDestroy(storeKey);
    }, this);
  },

  // ..........................................................
  // INTERNAL METHODS/PRIMITIVES
  //

  /**
    Load fixtures for a given fetchKey into the store
    and push it to the ret array.

    @param {SC.Store} store the store to load into
    @param {SC.Record} recordType the record type to load
    @param {SC.Array} ret is passed, array to add loaded storeKeys to.
    @returns {SC.FixturesDataSource} receiver
  */
  loadFixturesFor: function(store, recordType, ret) {
    var hashes   = [],
        dataHashes, i, storeKey ;

    dataHashes = this.fixturesFor(recordType);

    for(i in dataHashes){
      storeKey = recordType.storeKeyFor(i);
      if (store.peekStatus(storeKey) === SC.Record.EMPTY) {
        hashes.push(dataHashes[i]);
      }
      if (ret) ret.push(storeKey);
    }

    // only load records that were not already loaded to avoid infinite loops
    if (hashes && hashes.length>0) store.loadRecords(recordType, hashes);

    return this ;
  },


  /**
    Generates an id for the passed record type.  You can override this if
    needed.  The default generates a storekey and formats it as a string.

    @param {Class} recordType Subclass of SC.Record
    @param {Hash} dataHash the data hash for the record
    @param {SC.Store} store the store
    @param {Number} storeKey store key for the item
    @returns {String}
  */
  generateIdFor: function(recordType, dataHash, store, storeKey) {
    return "@id%@".fmt(SC.Store.generateStoreKey());
  },

  /**
    Based on the storeKey it returns the specified fixtures

    @param {SC.Store} store the store
    @param {Number} storeKey the storeKey
    @returns {Hash} data hash or null
  */
  fixtureForStoreKey: function(store, storeKey) {
    var id         = store.idFor(storeKey),
        recordType = store.recordTypeFor(storeKey),
        fixtures   = this.fixturesFor(recordType);
    return fixtures ? fixtures[id] : null;
  },

  /**
    Update the data hash fixture for the named store key.

    @param {SC.Store} store the store
    @param {Number} storeKey the storeKey
    @param {Hash} dataHash
    @returns {SC.FixturesDataSource} receiver
  */
  setFixtureForStoreKey: function(store, storeKey, dataHash) {
    var id         = store.idFor(storeKey),
        recordType = store.recordTypeFor(storeKey),
        fixtures   = this.fixturesFor(recordType);
    this._invalidateCachesFor(recordType, storeKey, id);
    fixtures[id] = dataHash;
    return this ;
  },

  /**
    Get the fixtures for the passed record type and prepare them if needed.
    Return cached value when complete.

    @param {SC.Record} recordType
    @returns {Hash} data hashes
  */
  fixturesFor: function(recordType) {
    // get basic fixtures hash.
    if (!this._fixtures) this._fixtures = {};
    var fixtures = this._fixtures[SC.guidFor(recordType)];
    if (fixtures) return fixtures ;

    // need to load fixtures.
    var dataHashes = recordType ? recordType.FIXTURES : null,
        len        = dataHashes ? dataHashes.length : 0,
        primaryKey = recordType ? recordType.prototype.primaryKey : 'guid',
        idx, dataHash, id ;

    this._fixtures[SC.guidFor(recordType)] = fixtures = {} ;
    for(idx=0;idx<len;idx++) {
      dataHash = dataHashes[idx];
      id = dataHash[primaryKey];
      if (!id) id = this.generateIdFor(recordType, dataHash);
      fixtures[id] = dataHash;
    }
    return fixtures;
  },

  /**
    Returns YES if fixtures for a given recordType have already been loaded

    @param {SC.Record} recordType
    @returns {Boolean} storeKeys
  */
  fixturesLoadedFor: function(recordType) {
    if (!this._fixtures) return NO;
    var ret = [], fixtures = this._fixtures[SC.guidFor(recordType)];
    return fixtures ? YES: NO;
  },

  /**
    Resets the fixtures to their original values.

    @returns {SC.FixturesDataSource} receiver
  */
  reset: function(){
    this._fixtures = null;
    return this;
  },

  /**
    Returns YES or SC.MIXED_STATE if one or more of the storeKeys can be
    handled by the fixture data source.

    @param {Array} storeKeys the store keys
    @returns {Boolean} YES if all handled, MIXED_STATE if some handled
  */
  hasFixturesFor: function(storeKeys) {
    var ret = NO ;
    storeKeys.forEach(function(storeKey) {
      if (ret !== SC.MIXED_STATE) {
        var recordType = SC.Store.recordTypeFor(storeKey),
            fixtures   = recordType ? recordType.FIXTURES : null ;
        if (fixtures && fixtures.length && fixtures.length>0) {
          if (ret === NO) ret = YES ;
        } else if (ret === YES) ret = SC.MIXED_STATE ;
      }
    }, this);

    return ret ;
  },

  /** @private
    Invalidates any internal caches based on the recordType and optional
    other parameters.  Currently this only invalidates the storeKeyCache used
    for fetch, but it could invalidate others later as well.

    @param {SC.Record} recordType the type of record modified
    @param {Number} storeKey optional store key
    @param {String} id optional record id
    @returns {SC.FixturesDataSource} receiver
  */
  _invalidateCachesFor: function(recordType, storeKey, id) {
    var cache = this._storeKeyCache;
    if (cache) delete cache[SC.guidFor(recordType)];
    return this ;
  }

});

/**
  Default fixtures instance for use in applications.

  @property {SC.FixturesDataSource}
*/
SC.Record.fixtures = SC.FixturesDataSource.create();

/* >>>>>>>>>> BEGIN source/mixins/relationship_support.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/** @class
  Provides support for having relationships propagate by
  data provided by the data source.

  This means the following interaction is now valid:

      App = { store: SC.Store.create(SC.RelationshipSupport) };

      App.Person = SC.Record.extend({
        primaryKey: 'name',

        name: SC.Record.attr(String),

        power: SC.Record.toOne('App.Power', {
          isMaster: NO,
          inverse: 'person'
        })
      });

      App.Power = SC.Record.extend({
        person: SC.Record.toOne('App.Person', {
          isMaster: YES,
          inverse: 'power'
        })
      });

      var zan = App.store.createRecord(App.Person, { name: 'Zan' }),
          jayna = App.store.createRecord(App.Person, { name: 'Janya' });

      // Wondertwins activate!
      var glacier = App.store.loadRecords(App.Power, [{
        guid: 'petunia',  // Shape of...
        person: 'Jayna'
      }, {
        guid: 'drizzle',  // Form of...
        person: 'Zan'
      }]);


  Leveraging this mixin requires your records to be unambiguously
  defined. Note that this mixin does not take into account record
  relationship created / destroyed on `dataSourceDidComplete`,
  `writeAttribute`, etc. The only support here is for `pushRetrieve`,
  `pushDestroy`, and `loadRecords` (under the hood, `loadRecord(s)` uses
  `pushRetrieve`).

  This mixin also supports lazily creating records when a related
  record is pushed in from the store (but it doesn't exist).

  This means that the previous example could have been simplified
  to this:

      App.Power = SC.Record.extend({
        person: SC.Record.toOne('App.Person', {
          isMaster: YES,
          lazilyInstantiate: YES,
          inverse: 'power'
        })
      });

      // Wondertwins activate!
      var glacier = App.store.loadRecords(App.Power, [{
        guid: 'petunia',  // Shape of...
        person: 'Jayna'
      }, {
        guid: 'drizzle',  // Form of...
        person: 'Zan'
      }]);


  When the `loadRecords` call is done, there will be four unmaterialized
  records in the store, giving the exact same result as the former
  example.

  As a side note, this mixin was developed primarily for use
  in a real-time backend that provides data to SproutCore
  as soon as it gets it (no transactions). This means streaming
  APIs / protocols like the Twitter streaming API or XMPP (an IM
  protocol) can be codified easier.

  @since SproutCore 1.6
 */
SC.RelationshipSupport = {

  /** @private
    Relinquish many records.

    This happens when a master record (`isMaster` = `YES`) removes a reference
    to related records, either through `pushRetrieve` or `pushDestroy`.
   */
  _srs_inverseDidRelinquishRelationships: function (recordType, ids, attr, inverseId) {
    ids.forEach(function (id) {
      this._srs_inverseDidRelinquishRelationship(recordType, id, attr, inverseId);
    }, this);
  },

  /** @private
    Relinquish the record, removing the reference of the record being
    destroyed on any related records.
   */
  _srs_inverseDidRelinquishRelationship: function (recordType, id, toAttr, relativeID) {
    var storeKey = recordType.storeKeyFor(id),
      dataHash = this.readDataHash(storeKey),
      key = toAttr.inverse,
      proto = recordType.prototype;

    if (!dataHash || !key) return;

    if (SC.instanceOf(proto[key], SC.SingleAttribute)) {
      delete dataHash[key];
    } else if (SC.instanceOf(proto[key], SC.ManyAttribute) &&
        SC.typeOf(dataHash[key]) === SC.T_ARRAY) {

      dataHash[key].removeObject(relativeID);

      // If there is a materialized record with a ManyArray we have to clear the
      // internal cache of the ManyArray. Otherwise calling `objectAt` on the
      // Many Array will retrieve the cached record.
      var record = this.records[storeKey];
      if (record) {
        record.get(key)._records = null;
      }
    }

    this.pushRetrieve(recordType, id, dataHash, undefined, true);
  },

  /** @private
    Add a relationship to many inverse records.

    This happens when a master record (`isMaster` = `YES`) adds a reference
    to another record on a `pushRetrieve`.
   */
  _srs_inverseDidAddRelationships: function (recordType, ids, attr, inverseId) {
    ids.forEach(function (id) {
      this._srs_inverseDidAddRelationship(recordType, id, attr, inverseId);
    }, this);
  },


  /** @private
    Add a relationship to an inverse record.

    If the flag lazilyInstantiate is set to YES, then the inverse record will be
    created lazily.

    @param {SC.Record} recordType The inverse record type.
    @param {String} id The id of the recordType to add.
    @param {SC.RecordAttribute} toAttr The record attribute that represents
      the relationship being created.
    @param {String} relativeID The ID of the model that needs to have it's
      relationship updated.
   */
  _srs_inverseDidAddRelationship: function (recordType, id, toAttr, relativeID) {
    var storeKey = recordType.storeKeyFor(id),
        dataHash = this.readDataHash(storeKey),
        status = this.peekStatus(storeKey),
        proto = recordType.prototype,
        key = toAttr.inverse,
        hashKey = proto[key],
        primaryAttr = proto[proto.primaryKey],
        shouldRecurse = false;

    // in case the SC.RecordAttribute defines a `key` field, we need to use that
    hashKey = (hashKey && hashKey.get && hashKey.get('key') || hashKey.key) || key;

    if ((status === SC.Record.EMPTY) &&
        (SC.typeOf(toAttr.lazilyInstantiate) === SC.T_FUNCTION && toAttr.lazilyInstantiate() ||
         SC.typeOf(toAttr.lazilyInstantiate) !== SC.T_FUNCTION && toAttr.lazilyInstantiate)) {

      if (!SC.none(primaryAttr) && primaryAttr.typeClass &&
          SC.typeOf(primaryAttr.typeClass()) === SC.T_CLASS) {

        // Recurse to create the record that this primaryKey points to iff it
        // also should be created if the record is empty.
        // Identifies chained relationships where the object up the chain
        // doesn't exist yet.

        // TODO: this can lead to an infinite recursion if the relationship
        // graph is cyclic
        shouldRecurse = true;
      }
      dataHash = {};
      dataHash[proto.primaryKey] = id;
    }

    if (!dataHash || !key) return;

    if (SC.instanceOf(proto[key], SC.SingleAttribute)) {
      dataHash[hashKey] = relativeID;
    } else if (SC.instanceOf(proto[key], SC.ManyAttribute)) {
      dataHash[hashKey] = dataHash[hashKey] || [];

      if (dataHash[hashKey].indexOf(relativeID) < 0) {
        dataHash[hashKey].push(relativeID);
      }
    }

    this.pushRetrieve(recordType, id, dataHash, undefined, !shouldRecurse);
  },

  // ..........................................................
  // ASYNCHRONOUS RECORD RELATIONSHIPS
  //

  /** @private
    Iterates over keys on the recordType prototype, looking for RecordAttributes
    that have relationships (toOne or toMany).

    @param {SC.Record} recordType The record type to do introspection on to see
      if it has any RecordAttributes that have relationships to other records.
    @param {String} id The id of the record being pushed in.
    @param {Number} storeKey The storeKey
   */
  _srs_pushIterator: function (recordType, id, storeKey, lambda) {
    var proto = recordType.prototype,
        attr, currentHash, key, inverseType;

    if (typeof storeKey === "undefined") {
      storeKey = recordType.storeKeyFor(id);
    }

    currentHash = this.readDataHash(storeKey) || {};

    for (key in proto) {
      attr = proto[key];
      if (attr && attr.typeClass && attr.inverse && attr.isMaster) {
        inverseType = attr.typeClass();

        if (SC.typeOf(inverseType) !== SC.T_CLASS) continue;

        lambda.apply(this, [inverseType, currentHash, attr,
                            attr.get && attr.get('key') || key]);
      }
    }
  },


  /**
    Disassociate records that are related to the one being destroyed iff this
    record has `isMaster` set to `YES`.
   */
  pushDestroy: function (original, recordType, id, storeKey) {
    var existingIDs;

    this._srs_pushIterator(recordType, id, storeKey,
      function (inverseType, currentHash, toAttr, keyValue) {
        // update old relationships
        existingIDs = [currentHash[keyValue] || null].flatten().compact().uniq();
        this._srs_inverseDidRelinquishRelationships(inverseType, existingIDs, toAttr, id);
      });

    return original(recordType, id, storeKey);
  }.enhance(),

  /**
    Associate records that are added via a pushRetrieve, and update subsequent
    relationships to ensure that the master-slave relationship is kept intact.

    For use cases, see the test for pushRelationships.

    The `ignore` argument is only set to true when adding the inverse
    relationship (to prevent recursion).
   */
  pushRetrieve: function (original, recordType, id, dataHash, storeKey, ignore) {
    // avoid infinite recursions when additional changes are propogated
    // from `_srs_inverseDidAddRelationship`
    if (!ignore) {
      var existingIDs, inverseIDs;

      this._srs_pushIterator(recordType, id, storeKey,
        /** @ignore
          @param {SC.Record} inverseType - in a Master-Slave
          relationship when pushing master, Slave is the inverse type
          @param {Object} currentHash - the hash in the data store (data to be replaced by `dataHash`)
          @param {SC.RecordAttribute} toAttr - key in `recordType.prototype` that names isMaster and has an inverse
          @param {String} keyValue - the property name in the datahash that defines this foreign key relationship
         */
        function (inverseType, currentHash, toAttr, keyValue) {

          // Find the new relations.
          inverseIDs = [dataHash[keyValue] || null].flatten().compact().uniq();

          // Find the old relations.
          existingIDs = [currentHash[keyValue] || null].flatten().compact().uniq();
          existingIDs = existingIDs.filter(
            function (el) {
              return inverseIDs.indexOf(el) === -1;
            });

          // Update the relationships.
          this._srs_inverseDidRelinquishRelationships(inverseType, existingIDs, toAttr, id);
          this._srs_inverseDidAddRelationships(inverseType, inverseIDs, toAttr, id);
        });
    }

    storeKey = storeKey || recordType.storeKeyFor(id);

    return original(recordType, id, dataHash, storeKey);
  }.enhance()
};

/* >>>>>>>>>> BEGIN source/models/record_attribute.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('models/record');

/** @class

  A RecordAttribute describes a single attribute on a record.  It is used to
  generate computed properties on records that can automatically convert data
  types and verify data.

  When defining an attribute on an SC.Record, you can configure it this way:

      title: SC.Record.attr(String, {
        defaultValue: 'Untitled',
        isRequired: YES|NO
      })

  In addition to having predefined transform types, there is also a way to
  set a computed relationship on an attribute. A typical example of this would
  be if you have record with a parentGuid attribute, but are not able to
  determine which record type to map to before looking at the guid (or any
  other attributes). To set up such a computed property, you can attach a
  function in the attribute definition of the SC.Record subclass:

      relatedToComputed: SC.Record.toOne(function() {
        return (this.readAttribute('relatedToComputed').indexOf("foo")==0) ? MyApp.Foo : MyApp.Bar;
      })

  Notice that we are not using .get() to avoid another transform which would
  trigger an infinite loop.

  You usually will not work with RecordAttribute objects directly, though you
  may extend the class in any way that you like to create a custom attribute.

  A number of default RecordAttribute types are defined on the SC.Record.

  @extends SC.Object
  @see SC.Record
  @see SC.ManyAttribute
  @see SC.SingleAttribute
  @since SproutCore 1.0
*/
SC.RecordAttribute = SC.Object.extend(
  /** @scope SC.RecordAttribute.prototype */ {
  /**
    Walk like a duck.

    @type Boolean
    @default YES
  */
  isRecordAttribute: YES,

  /**
    The default value.  If attribute is `null` or `undefined`, this default
    value will be substituted instead.  Note that `defaultValue`s are not
    converted, so the value should be in the output type expected by the
    attribute.

    If you use a `defaultValue` function, the arguments given to it are the
    record instance and the key.

    @type Object|function
    @default null
  */
  defaultValue: null,

  /**
    The attribute type.  Must be either an object class or a property path
    naming a class.  The built in handler allows all native types to pass
    through, converts records to ids and dates to UTF strings.

    If you use the `attr()` helper method to create a RecordAttribute instance,
    it will set this property to the first parameter you pass.

    @type Object|String
    @default String
  */
  type: String,

  /**
    The underlying attribute key name this attribute should manage.  If this
    property is left empty, then the key will be whatever property name this
    attribute assigned to on the record.  If you need to provide some kind
    of alternate mapping, this provides you a way to override it.

    @type String
    @default null
  */
  key: null,

  /**
    If `YES`, then the attribute is required and will fail validation unless
    the property is set to a non-null or undefined value.

    @type Boolean
    @default NO
  */
  isRequired: NO,

  /**
    If `NO` then attempts to edit the attribute will be ignored.

    @type Boolean
    @default YES
  */
  isEditable: YES,

  /**
    If set when using the Date format, expect the ISO8601 date format.
    This is the default.

    @type Boolean
    @default YES
  */
  useIsoDate: YES,

  /**
    Can only be used for toOne or toMany relationship attributes. If YES,
    this flag will ensure that any related objects will also be marked
    dirty when this record dirtied.

    Useful when you might have multiple related objects that you want to
    consider in an 'aggregated' state. For instance, by changing a child
    object (image) you might also want to automatically mark the parent
    (album) dirty as well.

    @type Boolean
    @default NO
  */
  aggregate: NO,


  /**
    Can only be used for toOne or toMany relationship attributes. If YES,
    this flag will lazily create the related record that was pushed in
    from the data source (via pushRetrieve) if the related record does
    not exist yet.

    Useful when you have a record used as a join table. Assumptions then
    can be made that the record exists at all times (even if it doesn't).
    For instance, if you have a contact that is a member of groups,
    a group will be created automatically when a contact pushes a new
    group.

    Note that you will have to take care of destroying the created record
    once all relationships are removed from it.

    @type Boolean
    @default NO
   */
  lazilyInstantiate: NO,

  // ..........................................................
  // HELPER PROPERTIES
  //

  /**
    Returns the type, resolved to a class.  If the type property is a regular
    class, returns the type unchanged.  Otherwise attempts to lookup the
    type as a property path.

    @property
    @type Object
    @default String
  */
  typeClass: function() {
    var ret = this.get('type');
    if (SC.typeOf(ret) === SC.T_STRING) ret = SC.requiredObjectForPropertyPath(ret);
    return ret ;
  }.property('type').cacheable(),

  /**
    Finds the transform handler. Attempts to find a transform that you
    registered using registerTransform for this attribute's type, otherwise
    defaults to using the default transform for String.

    @property
    @type Transform
  */
  transform: function() {
    var klass      = this.get('typeClass') || String,
        transforms = SC.RecordAttribute.transforms,
        ret ;

    // walk up class hierarchy looking for a transform handler
    while(klass && !(ret = transforms[SC.guidFor(klass)])) {
      // check if super has create property to detect SC.Object's
      if(klass.superclass.hasOwnProperty('create')) klass = klass.superclass ;
      // otherwise return the function transform handler
      else klass = SC.T_FUNCTION ;
    }

    return ret ;
  }.property('typeClass').cacheable(),

  // ..........................................................
  // LOW-LEVEL METHODS
  //

  /**
    Converts the passed value into the core attribute value.  This will apply
    any format transforms.  You can install standard transforms by adding to
    the `SC.RecordAttribute.transforms` hash.  See
    SC.RecordAttribute.registerTransform() for more.

    @param {SC.Record} record The record instance
    @param {String} key The key used to access this attribute on the record
    @param {Object} value The property value before being transformed
    @returns {Object} The transformed value
  */
  toType: function(record, key, value) {
    var transform = this.get('transform'),
        type      = this.get('typeClass'),
        children;

    if (transform && transform.to) {
      value = transform.to(value, this, type, record, key) ;

      // if the transform needs to do something when its children change, we need to set up an observer for it
      if(!SC.none(value) && (children = transform.observesChildren)) {
        var i, len = children.length,
        // store the record, transform, and key so the observer knows where it was called from
        context = {
          record: record,
          key: key
        };

        for(i = 0; i < len; i++) value.addObserver(children[i], this, this._SCRA_childObserver, context);
      }
    }

    return value ;
  },

  /**
    @private

    Shared observer used by any attribute whose transform creates a seperate
    object that needs to write back to the datahash when it changes. For
    example, when enumerable content changes on a `SC.Set` attribute, it
    writes back automatically instead of forcing you to call `.set` manually.

    This functionality can be used by setting an array named
    observesChildren on your transform containing the names of keys to
    observe. When one of them triggers it will call childDidChange on your
    transform with the same arguments as to and from.

    @param {Object} obj The transformed value that is being observed
    @param {String} key The key used to access this attribute on the record
    @param {Object} prev Previous value (not used)
    @param {Object} context Hash of extra context information
  */
  _SCRA_childObserver: function(obj, key, prev, context) {
    // write the new value back to the record
    this.call(context.record, context.key, obj);

    // mark the attribute as dirty
    context.record.notifyPropertyChange(context.key);
  },

  /**
    Converts the passed value from the core attribute value.  This will apply
    any format transforms.  You can install standard transforms by adding to
    the `SC.RecordAttribute.transforms` hash.  See
    `SC.RecordAttribute.registerTransform()` for more.

    @param {SC.Record} record The record instance
    @param {String} key The key used to access this attribute on the record
    @param {Object} value The transformed value
    @returns {Object} The value converted back to attribute format
  */
  fromType: function(record, key, value) {
    var transform = this.get('transform'),
        type      = this.get('typeClass');

    if (transform && transform.from) {
      value = transform.from(value, this, type, record, key);
    }
    return value;
  },

  /**
    The core handler. Called when `get()` is called on the
    parent record, since `SC.RecordAttribute` uses `isProperty` to masquerade
    as a computed property. Get expects a property be a function, thus we
    need to implement call.

    @param {SC.Record} record The record instance
    @param {String} key The key used to access this attribute on the record
    @param {Object} value The property value if called as a setter
    @returns {Object} property value
  */
  call: function(record, key, value) {
    var attrKey = this.get('key') || key, nvalue;

    if ((value !== undefined) && this.get('isEditable')) {
      // careful: don't overwrite value here.  we want the return value to
      // cache.
      nvalue = this.fromType(record, key, value) ; // convert to attribute.
      record.writeAttribute(attrKey, nvalue);
    }

    value = record.readAttribute(attrKey);
    if (SC.none(value) && (value = this.get('defaultValue'))) {
       if (typeof value === SC.T_FUNCTION) {
        value = value(record, key, this);
      }
    }

    value = this.toType(record, key, value);

    return value ;
  },

  /**
    Apply needs to implemented for sc_super to work.

    @see SC.RecordAttribute#call
  */
  apply: function(target, args) {
    return this.call.apply(target, args);
  },

  // ..........................................................
  // INTERNAL SUPPORT
  //

  /** @private - Make this look like a property so that `get()` will call it. */
  isProperty: YES,

  /** @private - Make this look cacheable */
  isCacheable: YES,

  /** @private - needed for KVO `property()` support */
  dependentKeys: [],

  /** @private */
  init: function() {
    arguments.callee.base.apply(this,arguments);
    // setup some internal properties needed for KVO - faking 'cacheable'
    this.cacheKey = "__cache__recattr__" + SC.guidFor(this) ;
    this.lastSetValueKey = "__lastValue__recattr__" + SC.guidFor(this) ;
  }
}) ;

// ..........................................................
// CLASS METHODS
//

SC.RecordAttribute.mixin(
  /** @scope SC.RecordAttribute.prototype */{
  /**
    The default method used to create a record attribute instance.  Unlike
    `create()`, takes an `attributeType` as the first parameter which will be
    set on the attribute itself.  You can pass a string naming a class or a
    class itself.

    @static
    @param {Object|String} attributeType the assumed attribute type
    @param {Hash} opts optional additional config options
    @returns {SC.RecordAttribute} new instance
  */
  attr: function(attributeType, opts) {
    if (!opts) opts = {} ;
    if (!opts.type) opts.type = attributeType || String ;
    return this.create(opts);
  },

  /** @private
    Hash of registered transforms by class guid.
  */
  transforms: {},

  /**
    Call to register a transform handler for a specific type of object.  The
    object you pass can be of any type as long as it responds to the following
    methods

     - `to(value, attr, klass, record, key)` converts the passed value
       (which will be of the class expected by the attribute) into the
       underlying attribute value
     - `from(value, attr, klass, record, key)` converts the underlying
       attribute value into a value of the class

    You can also provide an array of keys to observer on the return value.
    When any of these change, your from method will be called to write the
    changed object back to the record. For example:

        {
          to: function(value, attr, type, record, key) {
            if(value) return value.toSet();
            else return SC.Set.create();
          },

          from: function(value, attr, type, record, key) {
            return value.toArray();
          },

          observesChildren: ['[]']
        }

    @static
    @param {Object} klass the type of object you convert
    @param {Object} transform the transform object
    @returns {SC.RecordAttribute} receiver
  */
  registerTransform: function(klass, transform) {
    SC.RecordAttribute.transforms[SC.guidFor(klass)] = transform;
  }
});

// ..........................................................
// STANDARD ATTRIBUTE TRANSFORMS
//

// Object, String, Number just pass through.

/** @private - generic converter for Boolean records */
SC.RecordAttribute.registerTransform(Boolean, {
  /** @private - convert an arbitrary object value to a boolean */
  to: function(obj) {
    return SC.none(obj) ? null : !!obj;
  }
});

/** @private - generic converter for Numbers */
SC.RecordAttribute.registerTransform(Number, {
  /** @private - convert an arbitrary object value to a Number */
  to: function(obj) {
    return SC.none(obj) ? null : Number(obj) ;
  }
});

/** @private - generic converter for Strings */
SC.RecordAttribute.registerTransform(String, {
  /** @private -
    convert an arbitrary object value to a String
    allow null through as that will be checked separately
  */
  to: function(obj) {
    if (!(typeof obj === SC.T_STRING) && !SC.none(obj) && obj.toString) {
      obj = obj.toString();
    }
    return obj;
  }
});

/** @private - generic converter for Array */
SC.RecordAttribute.registerTransform(Array, {
  /** @private - check if obj is an array
  */
  to: function(obj) {
    if (!SC.isArray(obj) && !SC.none(obj)) {
      obj = [];
    }
    return obj;
  },

  observesChildren: ['[]']
});

/** @private - generic converter for Object */
SC.RecordAttribute.registerTransform(Object, {
  /** @private - check if obj is an object */
  to: function(obj) {
    if (!(typeof obj === 'object') && !SC.none(obj)) {
      obj = {};
    }
    return obj;
  }
});

/** @private - generic converter for SC.Record-type records */
SC.RecordAttribute.registerTransform(SC.Record, {

  /** @private - convert a record id to a record instance */
  to: function(id, attr, recordType, parentRecord) {
    var store = parentRecord.get('store');
    if (SC.none(id) || (id==="")) return null;
    else return store.find(recordType, id);
  },

  /** @private - convert a record instance to a record id */
  from: function(record) { return record ? record.get('id') : null; }
});

/** @private - generic converter for transforming computed record attributes */
SC.RecordAttribute.registerTransform(SC.T_FUNCTION, {

  /** @private - convert a record id to a record instance */
  to: function(id, attr, recordType, parentRecord) {
    recordType = recordType.apply(parentRecord);
    var store = parentRecord.get('store');
    return store.find(recordType, id);
  },

  /** @private - convert a record instance to a record id */
  from: function(record) { return record.get('id'); }
});

/** @private - generic converter for Date records */
SC.RecordAttribute.registerTransform(Date, {

  /** @private - convert a string to a Date */
  to: function(str, attr) {

    // If a null or undefined value is passed, don't
    // do any normalization.
    if (SC.none(str)) { return str; }

    var ret ;
    str = str.toString() || '';

    if (attr.get('useIsoDate')) {
      var regexp = "([0-9]{4})(-([0-9]{2})(-([0-9]{2})" +
             "(T([0-9]{2}):([0-9]{2})(:([0-9]{2})(\\.([0-9]+))?)?" +
             "(Z|(([-+])([0-9]{2}):([0-9]{2})))?)?)?)?",
          d      = str.match(new RegExp(regexp)),
          offset = 0,
          date   = new Date(d[1], 0, 1),
          time ;

      if (d[3]) { date.setMonth(d[3] - 1); }
      if (d[5]) { date.setDate(d[5]); }
      if (d[7]) { date.setHours(d[7]); }
      if (d[8]) { date.setMinutes(d[8]); }
      if (d[10]) { date.setSeconds(d[10]); }
      if (d[12]) { date.setMilliseconds(Number("0." + d[12]) * 1000); }
      if (d[14]) {
         offset = (Number(d[16]) * 60) + Number(d[17]);
         offset *= ((d[15] === '-') ? 1 : -1);
      }

      offset -= date.getTimezoneOffset();
      time = (Number(date) + (offset * 60 * 1000));

      ret = new Date();
      ret.setTime(Number(time));
    } else ret = new Date(Date.parse(str));
    return ret ;
  },

  _dates: {},

  /** @private - pad with leading zeroes */
  _zeropad: function(num) {
    return ((num<0) ? '-' : '') + ((num<10) ? '0' : '') + Math.abs(num);
  },

  /** @private - convert a date to a string */
  from: function(date) {

    if (SC.none(date)) { return null; }

    var ret = this._dates[date.getTime()];
    if (ret) return ret ;

    // figure timezone
    var zp = this._zeropad,
        tz = 0-date.getTimezoneOffset()/60;

    tz = (tz === 0) ? 'Z' : '%@:00'.fmt(zp(tz));

    this._dates[date.getTime()] = ret = "%@-%@-%@T%@:%@:%@%@".fmt(
      zp(date.getFullYear()),
      zp(date.getMonth()+1),
      zp(date.getDate()),
      zp(date.getHours()),
      zp(date.getMinutes()),
      zp(date.getSeconds()),
      tz) ;

    return ret ;
  }
});

if (SC.DateTime && !SC.RecordAttribute.transforms[SC.guidFor(SC.DateTime)]) {

  /**
    Registers a transform to allow `SC.DateTime` to be used as a record
    attribute, ie `SC.Record.attr(SC.DateTime);`
  */

  SC.RecordAttribute.registerTransform(SC.DateTime, {

    /** @private
      Convert a String to a DateTime
    */
    to: function(str, attr) {
      if (SC.none(str) || SC.instanceOf(str, SC.DateTime)) return str;
      if(attr.get('useUnixTime')) {
        if(SC.typeOf(str) === SC.T_STRING) { str = parseInt(str); }
        if(isNaN(str) || SC.typeOf(str) !== SC.T_NUMBER) { str = 0; }
        return SC.DateTime.create({ milliseconds: str*1000, timezone: 0 });
      }
      if (SC.instanceOf(str, Date)) return SC.DateTime.create(str.getTime());
      var format = attr.get('format');
      return SC.DateTime.parse(str, format ? format : SC.DateTime.recordFormat);
    },

    /** @private
      Convert a DateTime to a String
    */
    from: function(dt, attr) {
      if (SC.none(dt)) return dt;
      if (attr.get('useUnixTime')) {
        return dt.get('milliseconds')/1000;
      }
      var format = attr.get('format');
      return dt.toFormattedString(format ? format : SC.DateTime.recordFormat);
    }
  });

}

/**
  Parses a coreset represented as an array.
 */
SC.RecordAttribute.registerTransform(SC.Set, {
  to: function(value, attr, type, record, key) {
    return SC.Set.create(value);
  },

  from: function(value, attr, type, record, key) {
    return value.toArray();
  },

  observesChildren: ['[]']
});

/* >>>>>>>>>> BEGIN source/models/child_attribute.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2010 Evin Grano
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('models/record');
sc_require('models/record_attribute');

/** @class

  ChildAttribute is a subclass of `RecordAttribute` and handles to-one
  relationships for child records.

  When setting ( `.set()` ) the value of a toMany attribute, make sure
  to pass in an array of `SC.Record` objects.

  There are many ways you can configure a ManyAttribute:

      contacts: SC.ChildAttribute.attr('SC.Child');

  @extends SC.RecordAttribute
  @since SproutCore 1.0
*/
SC.ChildAttribute = SC.RecordAttribute.extend(
  /** @scope SC.ChildAttribute.prototype */ {

  isNestedRecordTransform: YES,

  // ..........................................................
  // LOW-LEVEL METHODS
  //

  /**  @private - adapted for to one relationship */
  toType: function(record, key, value) {
    var ret   = null, rel,
        recordType  = this.get('typeClass');

    if (!record) {
      throw new Error('SC.Child: Error during transform: Unable to retrieve parent record.');
    }
    if (!SC.none(value)) ret = record.registerNestedRecord(value, key);

    return ret;
  },

  // Default fromType is just returning itself
  fromType: function(record, key, value) {
    var sk, store, ret;

    if (record) {
      // Unregister the old child (nested) record.
      if (record.readAttribute(key)) {
        record.unregisterNestedRecord(key);
      }

      if (SC.none(value)) {
        // Handle null value.
        record.writeAttribute(key, value);
        ret = value;
      } else {
        // Register the nested record with this record (the parent).
        ret = record.registerNestedRecord(value, key);

        if (ret) {
          // Write the data hash of the nested record to the store.
          sk = ret.get('storeKey');
          store = ret.get('store');
          record.writeAttribute(key, store.readDataHash(sk));
        } else if (value) {
          // If registration failed, just write the value.
          record.writeAttribute(key, value);
        }
      }
    }

    return ret;
  },

  /**
    The core handler.  Called from the property.
    @param {SC.Record} record the record instance
    @param {String} key the key used to access this attribute on the record
    @param {Object} value the property value if called as a setter
    @returns {Object} property value
  */
  call: function(record, key, value) {
    var attrKey = this.get('key') || key;
    if (value !== undefined) {
      value = this.fromType(record, key, value) ; // convert to attribute.
    } else {
      value = record.readAttribute(attrKey);
      if (SC.none(value) && (value = this.get('defaultValue'))) {
        if (typeof value === SC.T_FUNCTION) {
          value = this.defaultValue(record, key, this);
          // write default value so it doesn't have to be executed again
          if(record.attributes()) record.writeAttribute(attrKey, value, true);
        }
      } else value = this.toType(record, key, value);
    }

    return value ;
  }
});



/* >>>>>>>>>> BEGIN source/models/child_record.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('models/record');

/**
  @class
  @deprecated SC.ChildRecord is deprecated. Please extend SC.Record instead.
*/
SC.ChildRecord = SC.Record.extend({});

SC.ChildRecord.extend = function() {
  

  return SC.Record.extend.apply(this, arguments);
};

/* >>>>>>>>>> BEGIN source/system/child_array.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2010 Evin Grano
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @class

  A `ChildArray` is used to map an array of `ChildRecord` objects.

  @extends SC.Enumerable
  @extends SC.Array
  @since SproutCore 1.0
*/

SC.ChildArray = SC.Object.extend(SC.Enumerable, SC.Array,
  /** @scope SC.ChildArray.prototype */ {

  


  /**
    If set, it is the default record `recordType`

    @default null
    @type String
  */
  defaultRecordType: null,

  /**
    If set, the parent record will be notified whenever the array changes so that
    it can change its own state

    @default null
    @type {SC.Record}
  */
  record: null,

  /**
    The name of the attribute in the parent record's datahash that represents
    this child array's data.

    @default null
    @type String
  */
  propertyName: null,

  /**
    The store that owns this child array's parent record.

    @type SC.Store
    @readonly
  */
  store: function() {
    return this.getPath('record.store');
  }.property('record').cacheable(),

  /**
    The storeKey for the parent record of this child array.

    @type Number
    @readonly
  */
  storeKey: function() {
    return this.getPath('record.storeKey');
  }.property('record').cacheable(),

  /**
    Returns the original child array of JavaScript Objects.

    Note: Avoid modifying this array directly, because changes will not be
    reflected by this SC.ChildArray.

    @type SC.Array
    @property
  */
  readOnlyChildren: function() {
    return this.get('record').readAttribute(this.get('propertyName'));
  }.property(),

  /**
    Returns an editable child array of JavaScript Objects.

    Any changes to this array will not affect the parent record's datahash.

    @type {SC.Array}
    @property
  */
  editableChildren: function() {
    var store    = this.get('store'),
        storeKey = this.get('storeKey'),
        pname    = this.get('propertyName'),
        ret, hash;

    ret = store.readEditableProperty(storeKey, pname);
    if (!ret) {
      hash = store.readEditableDataHash(storeKey);
      ret = hash[pname] = [];
    }

    return ret ;
  }.property(),

  // ..........................................................
  // ARRAY PRIMITIVES
  //

  /** @private
    Returned length is a pass-through to the storeIds array.

    @type Number
    @property
  */
  length: function() {
    var children = this.get('readOnlyChildren');
    return children ? children.length : 0;
  }.property('readOnlyChildren'),

  /**
    Looks up the store id in the store ids array and materializes a
    records.

    @param {Number} idx index of the object to retrieve.
    @returns {SC.Record} The nested record if found or undefined if not.
  */
  objectAt: function(idx) {
    var recs      = this._records,
        children = this.get('readOnlyChildren'),
      hash, ret,
      pname = this.get('propertyName'),
      parent = this.get('record'),
      len = children ? children.length : 0;

    if (!children) return undefined; // nothing to do
    if (recs && (ret=recs[idx])) return ret ; // cached

    // If not a good index return undefined
    if (idx >= len) return undefined;
    hash = children.objectAt(idx);
    if (!hash) return undefined;

    // not in cache, materialize
    if (!recs) this._records = recs = []; // create cache
    recs[idx] = ret = parent.registerNestedRecord(hash, pname, pname+'.'+idx);

    return ret;
  },

  /**
    Pass through to the underlying array.  The passed in objects should be
    nested SC.Records, which can be converted to JavaScript objects or
    JavaScript objects themselves.

    @param {Number} idx index of the object to replace.
    @param {Number} amt number of objects to replace starting at idx.
    @param {Number} recs array with records to replace. These may be JavaScript objects or nested SC.Record objects.
    @returns {SC.ChildArray}
  */
  replace: function(idx, amt, recs) {
    var children = this.get('editableChildren'),
      recsLen = recs ? (recs.get ? recs.get('length') : recs.length) : 0,
      parent = this.get('record'),
      pname    = this.get('propertyName'),
      store = this.get('store'),
      removeCount, addCount,
      defaultRecordType, storeKeysById,
      newObjects, rec,
      i, len;

    // Create the proxy cache, we will need it.
    if (!this._records) this._records = [];

    // Convert any SC.Record objects into JavaScript objects.
    newObjects = this._processRecordsToHashes(recs);

    // Unregister the records being replaced.
    // for (i = idx, len = children.length; i < len; ++i) {
    //  this.unregisterNestedRecord(i);
    // }

    // Ensure that all removed objects are pre-registered in case any instances are outstanding.
    // These objects will improperly reflect being registered to this parent, but
    // at least they won't conflict with the actual associated records once we
    // disassociate them from the record type.
    defaultRecordType = this.get('defaultRecordType');
    storeKeysById = defaultRecordType.storeKeysById();

    for (i = idx, len = idx + amt; i < len; i++) {
      rec = this._records[i];

      if (!rec) {
        rec = parent.registerNestedRecord(children[i], pname, pname + '.' + i);
      } else {
        // Remove the cached record.
        this._records[i] = null;
      }

      // Now throw away the connection, so that the parent won't retrieve this
      // same instance. This is a work-around due to the fact that nested records
      // are proxied through their parent records.
      storeKeysById[rec.get('id')] = null;
    }

    // All materialized nested records after idx + amt to end need to be removed
    // because the paths will no longer be valid.
    for (i = idx + amt, len = this._records.length; i < len; i++) {
      rec = this._records[i];

      if (rec) {
        store.unregisterChildFromParent(rec.get('storeKey'));

        this._records[i] = null;
      }
    }

    // All objects from idx to the end must be removed to do an insert.
    removeCount = children.length - idx;
    addCount = children.length - idx - amt + recsLen;

    this.arrayContentWillChange(idx, removeCount, addCount);

    // Perform a raw array replace without any KVO checks.
    if (newObjects.length === 0) {
      children.splice(idx, amt);
    } else {
      var args = [idx, amt].concat(newObjects);
      children.splice.apply(children, args);
    }

    // All current SC.Record instances must be updated to their new backing object.
    // For example, when passing an SC.Record object in, that instance should
    // update to reflect its new nested object path.
    for (i = idx, len = children.length; i < len; i++) {
      this._records[i] = parent.registerNestedRecord(children[i], pname, pname + '.' + i);
    }

    // Update the enumerable, [], property (including firstObject and lastObject)
    this.arrayContentDidChange(idx, removeCount, addCount);

    // Update our cache! So when the record property change comes back down we can ignore it.
    this._sc_prevChildren = children;

    // We must indicate to the parent that we have been modified, so they can
    // update their status.
    parent.recordDidChange(pname);

    return this;
  },

  /**
    Unregisters a child record from its parent record.

    Since accessing a child (nested) record creates a new data hash for the
    child and caches the child record and its relationship to the parent record,
    it's important to clear those caches when the child record is overwritten
    or removed.  This function tells the store to remove the child record from
    the store's various child record caches.

    You should not need to call this function directly.  Simply setting the
    child record property on the parent to a different value will cause the
    previous child record to be unregistered.

    @param {Number} idx The index of the child record.
  */
  // unregisterNestedRecord: function(idx) {
  //   var childArray, childRecord, csk, store,
  //       record   = this.get('record'),
  //       pname    = this.get('propertyName');
  //
  //   store = record.get('store');
  //   childArray = record.getPath(pname);
  //   childRecord = childArray.objectAt(idx);
  //   csk = childRecord.get('storeKey');
  //   store.unregisterChildFromParent(csk);
  // },

  /**
    Calls normalize on each object in the array
  */
  normalize: function(){
    this.forEach(function (rec) {
      if (rec.normalize) rec.normalize();
    });
  },

  // ..........................................................
  // INTERNAL SUPPORT
  //

  /** @private Converts any SC.Records in the array into an array of hashes.

    @param {SC.Array} recs records to be converted to hashes.
    @returns {SC.Array} array of hashes.
  */
  _processRecordsToHashes: function (recs) {
    var store, sk,
      ret = [];

    recs.forEach(function (rec, idx) {
      if (rec.isNestedRecord) {
        store = rec.get('store');
        sk = rec.storeKey;
        ret[idx] = store.readDataHash(sk);
      } else {
        ret[idx] = rec;
      }
    });

    return ret;
  },

  /** @private
    This is called by the parent record whenever its properties change. It is
    also called by the ChildrenAttribute transform when the attribute is set
    to a new array.
  */
  recordPropertyDidChange: function (keys) {
    var oldLength = this.get('length'),
      children = this.get('readOnlyChildren'),
      newLength = children ? children.length : 0,
      // store = this.get('store'),
      prevChildren = this._sc_prevChildren;

    // Fast Path! No actual change to our backing array attribute so we should
    // not notify any changes.
    if (prevChildren === children) { return; }

    // TODO: We can not use this, because removed instances will lose their
    // connection to their data hashes in the store. There is an ugly hack in
    // SC.Store#writeDataHash which can't handle this.
    // All materialized nested records need to be removed. They are no longer valid!
    // if (this._records) {
    //   for (var i = 0, len = this._records.length; i < len; i++) {
    //     var rec = this._records[i];

    //     // Unregister the nested record.
    //     if (rec) {
    //       store.unregisterChildFromParent(rec.get('storeKey'));
    //     }
    //   }

    //   // Throw away our cache.
    //   this._records.length = 0;
    // }

    // Throw away our cache.
    this._records = null;

    // this.arrayContentWillChange(0, oldLength, newLength);
    this.arrayContentDidChange(0, oldLength, newLength);

    // Cache our backing array so we can avoid updates when we haven't actually
    // changed. See fast path above.
    this._sc_prevChildren = children;
  }

}) ;

/* >>>>>>>>>> BEGIN source/models/children_attribute.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2010 Evin Grano
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('models/record');
sc_require('models/record_attribute');
sc_require('models/child_attribute');
sc_require('system/child_array');

/** @class

  ChildrenAttribute is a subclass of ChildAttribute and handles to-many
  relationships for child records.

  When setting ( `.set()` ) the value of a toMany attribute, make sure
  to pass in an array of SC.Record objects.

  There are many ways you can configure a ChildrenAttribute:

      contacts: SC.ChildrenAttribute.attr('SC.Child');

  @extends SC.RecordAttribute
  @since SproutCore 1.0
*/
SC.ChildrenAttribute = SC.ChildAttribute.extend(
  /** @scope SC.ChildrenAttribute.prototype */ {

  // ..........................................................
  // LOW-LEVEL METHODS
  //

  /**  @private - adapted for to many relationship */
  toType: function (record, key, value) {
    var attrKey   = this.get('key') || key,
        arrayKey  = SC.keyFor('__kidsArray__', SC.guidFor(this)),
        ret       = record[arrayKey],
        recordType  = this.get('typeClass'),
        rel;

    // lazily create a ChildArray one time.  after that always return the
    // same object.
    if (!ret) {
      ret = SC.ChildArray.create({
        record: record,
        propertyName: attrKey,
        defaultRecordType: recordType
      });

      record[arrayKey] = ret; // cache on record

      // Make sure the child array gets notified of changes to the parent record.
      rel = record.get('relationships');
      if (!rel) record.set('relationships', rel = []);
      rel.push(ret);
    }

    return ret;
  },

  // Default fromType is just returning itself
  fromType: function (record, key, value) {
    var sk, store,
        arrayKey = SC.keyFor('__kidsArray__', SC.guidFor(this)),
        ret = record[arrayKey];

    if (record) {
      record.writeAttribute(key, value);

      // If the SC.ChildArray already exists, indicate that its backing content has changed.
      if (ret) ret = ret.recordPropertyDidChange();
    }

    return ret;
  }

  /** UNUSED. This seems to have no effect on SC.ChildArray usage. Kept here for quick reference.
    The core handler.  Called from the property.
    @param {SC.Record} record the record instance
    @param {String} key the key used to access this attribute on the record
    @param {Object} value the property value if called as a setter
    @returns {Object} property value
  */
  // call: function(record, key, value) {
  //   var attrKey = this.get('key') || key, cRef,
  //       cacheKey = SC.keyFor('__kid__', SC.guidFor(this));
  //   if (value !== undefined) {
  //     value = this.fromType(record, key, value) ; // convert to attribute.
  //   } else {
  //     value = record.readAttribute(attrKey);
  //     if (SC.none(value) && (value = this.get('defaultValue'))) {
  //       if (typeof value === SC.T_FUNCTION) {
  //         value = this.defaultValue(record, key, this);
  //         // write default value so it doesn't have to be executed again
  //         if (record.attributes()) {
  //           // Check for an array
  //           if (value instanceof Array) {
  //             // Instantiate the construct and replace all of the content.
  //             value = this.toType(record, key, value).replace(0, value.length, value);
  //           } else {
  //             record.writeAttribute(attrKey, value, true);
  //           }
  //         }
  //       }
  //     } else value = this.toType(record, key, value);
  //   }

  //   return value ;
  // }

});



/* >>>>>>>>>> BEGIN source/models/fetched_attribute.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('models/record');
sc_require('models/record_attribute');

/** @class

  Describes a single attribute that is fetched dynamically from the server
  when you request it.  Normally getting a property value with this attribute
  applied will cause call the `find()` method on the record store passing
  the attribute record type as the query key along with the property value,
  owner record, and property key name as parameters.

  The DataSource you hook up to your store must know how to load this kind
  of relationship for this fetched property to work properly.

  The return value is usually an `SC.RecordArray` that will populate with the
  record data so that you can display it.

  @extends SC.RecordAttribute
  @since SproutCore 1.0
*/
SC.FetchedAttribute = SC.RecordAttribute.extend(
  /** @scope SC.FetchedAttribute.prototype */ {

  /**
    Define the param key that will be passed to the `find` method on the
    store.  If `null`, the param will not be sent.  Defaults to `'link'`

    @type String
  */
  paramValueKey: 'link',

  /**
    Define the param key used to send the parent record.  If `null`, the param
    will not be sent.  Defaults to '`owner'`.

    @type String
  */
  paramOwnerKey: 'owner',

  /**
    Define the param key used to send the key name used to reference this
    attribute.  If `null`, the param will not be sent.  Defaults to `"rel"`

    @type String
  */
  paramRelKey: 'rel',

  /**
    Optional query key to pass to find.  Otherwise type class will be
    passed.

    @type String
  */
  queryKey: null,

  /**
    Fetched attributes are not editable

    @type Boolean
  */
  isEditable: NO,

  // ..........................................................
  // LOW-LEVEL METHODS
  //

  /**  @private - adapted for fetching. do find */
  toType: function(record, key, value) {
    var store = record.get('store');
    if (!store) return null ; // nothing to do

    var paramValueKey = this.get('paramValueKey'),
        paramOwnerKey = this.get('paramOwnerKey'),
        paramRelKey   = this.get('paramRelKey'),
        queryKey      = this.get('queryKey') || this.get('typeClass'),
        params        = {};

    // setup params for query
    if (paramValueKey) params[paramValueKey] = value ;
    if (paramOwnerKey) params[paramOwnerKey] = record ;
    if (paramRelKey)   params[paramRelKey]   = this.get('key') || key ;

    // make request - should return SC.RecordArray instance
    return store.find(queryKey, params);
  },

  /** @private - fetched attributes are read only. */
  fromType: function(record, key, value) {
    return value;
  }

}) ;


/* >>>>>>>>>> BEGIN source/system/many_array.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/**
  @class

  A `ManyArray` is used to map an array of record ids back to their
  record objects which will be materialized from the owner store on demand.

  Whenever you create a `toMany()` relationship, the value returned from the
  property will be an instance of `ManyArray`.  You can generally customize the
  behavior of ManyArray by passing settings to the `toMany()` helper.

  @extends SC.Enumerable
  @extends SC.Array
  @since SproutCore 1.0
*/

SC.ManyArray = SC.Object.extend(SC.Enumerable, SC.Array,
  /** @scope SC.ManyArray.prototype */ {

  


  /**
    `recordType` will tell what type to transform the record to when
    materializing the record.

    @default null
    @type String
  */
  recordType: null,

  /**
    If set, the record will be notified whenever the array changes so that
    it can change its own state

    @default null
    @type SC.Record
  */
  record: null,

  /**
    If set will be used by the many array to get an editable version of the
    storeIds from the owner.

    @default null
    @type String
  */
  propertyName: null,


  /**
    The `ManyAttribute` that created this array.

    @default null
    @type SC.ManyAttribute
  */
  manyAttribute: null,

  /**
    The store that owns this record array.  All record arrays must have a
    store to function properly.

    @type SC.Store
    @property
  */
  store: function () {
    return this.get('record').get('store');
  }.property('record').cacheable(),

  /**
    The `storeKey` for the parent record of this many array.  Editing this
    array will place the parent record into a `READY_DIRTY` state.

    @type Number
    @property
  */
  storeKey: function () {
    return this.get('record').get('storeKey');
  }.property('record').cacheable(),

  /**
    Determines whether the new record (i.e. unsaved) support should be enabled
    or not.

    Normally, all records in the many array should already have been previously
    committed to a remote data store and have an actual `id`. However, with
    `supportNewRecords` set to true, adding records without an `id `to the many
    array will assign unique temporary ids to the new records.

    *Note:* You must update the many array after the new records are successfully
    committed and have real ids. This is done by calling `updateNewRecordId()`
    on the many array. In the future this should be automatic.

    @type Boolean
    @default false
    @since SproutCore 1.11.0
  */
  supportNewRecords: NO,

  /**
    Returns the `storeId`s in read-only mode.  Avoids modifying the record
    unnecessarily.

    @type SC.Array
    @property
  */
  readOnlyStoreIds: function () {
    return this.get('record').readAttribute(this.get('propertyName'));
  }.property(),


  /**
    Returns an editable array of `storeId`s.  Marks the owner records as
    modified.

    @type {SC.Array}
    @property
  */
  editableStoreIds: function () {
    var store    = this.get('store'),
        storeKey = this.get('storeKey'),
        pname    = this.get('propertyName'),
        ret, hash;

    ret = store.readEditableProperty(storeKey, pname);
    if (!ret) {
      hash = store.readEditableDataHash(storeKey);
      ret = hash[pname] = [];
    }

    // if (ret !== this._sc_prevStoreIds) this.recordPropertyDidChange();
    return ret;
  }.property(),


  // ..........................................................
  // COMPUTED FROM OWNER
  //

  /**
    Computed from owner many attribute

    @type Boolean
    @property
  */
  isEditable: function () {
    // NOTE: can't use get() b/c manyAttribute looks like a computed prop
    var attr = this.manyAttribute;
    return attr ? attr.get('isEditable') : NO;
  }.property('manyAttribute').cacheable(),

  /**
    Computed from owner many attribute

    @type String
    @property
  */
  inverse: function () {
    // NOTE: can't use get() b/c manyAttribute looks like a computed prop
    var attr = this.manyAttribute;
    return attr ? attr.get('inverse') : null;
  }.property('manyAttribute').cacheable(),

  /**
    Computed from owner many attribute

    @type Boolean
    @property
  */
  isMaster: function () {
    // NOTE: can't use get() b/c manyAttribute looks like a computed prop
    var attr = this.manyAttribute;
    return attr ? attr.get('isMaster') : null;
  }.property("manyAttribute").cacheable(),

  /**
    Computed from owner many attribute

    @type Array
    @property
  */
  orderBy: function () {
    // NOTE: can't use get() b/c manyAttribute looks like a computed prop
    var attr = this.manyAttribute;
    return attr ? attr.get('orderBy') : null;
  }.property("manyAttribute").cacheable(),

  // ..........................................................
  // ARRAY PRIMITIVES
  //

  /** @private
    Returned length is a pass-through to the `storeIds` array.

    @type Number
    @property
  */
  length: function () {
    var storeIds = this.get('readOnlyStoreIds');
    return storeIds ? storeIds.get('length') : 0;
  }.property('readOnlyStoreIds'),

  /** @private
    Looks up the store id in the store ids array and materializes a
    records.
  */
  objectAt: function (idx) {
    var recs = this._records,
      storeIds  = this.get('readOnlyStoreIds'),
      store = this.get('store'),
      recordType = this.get('recordType'),
      len = storeIds ? storeIds.length : 0,
      storeKey, ret, storeId;

    if (!storeIds || !store) return undefined; // nothing to do
    if (recs && (ret = recs[idx])) return ret; // cached

    // If not a good index return undefined
    if (idx >= len) return undefined;
    storeId = storeIds.objectAt(idx);
    if (!storeId) return undefined;

    // not in cache, materialize
    if (!recs) this._records = recs = []; // create cache

    // Handle transient records.
    if (typeof storeId === SC.T_STRING && storeId.indexOf('_sc_id_placeholder_') === 0) {
      storeKey = storeId.replace('_sc_id_placeholder_', '');
    } else {
      storeKey = store.storeKeyFor(recordType, storeId);
    }

    // If record is not loaded already, then ask the data source to retrieve it.
    if (store.readStatus(storeKey) === SC.Record.EMPTY) {
      store.retrieveRecord(recordType, null, storeKey);
    }

    recs[idx] = ret = store.materializeRecord(storeKey);

    return ret;
  },

  /** @private
    Pass through to the underlying array.  The passed in objects must be
    records, which can be converted to `storeId`s.
  */
  replace: function (idx, amt, recs) {
    


    var storeIds = this.get('editableStoreIds'),
      recsLen = recs ? (recs.get ? recs.get('length') : recs.length) : 0,
      parent   = this.get('record'),
      pname    = this.get('propertyName'),
      supportNewRecords = this.get('supportNewRecords'),
      ids, toRemove, inverse, attr, inverseRecord,
      i;

    // Create the cache, we will need it.
    if (!this._records) this._records = [];

    // map to store keys
    ids = [];
    for (i = 0; i < recsLen; i++) {
      var rec = recs.objectAt(i),
        id = rec.get('id');

      if (SC.none(id)) {
        // If the record inserted doesn't have an id yet, use a unique placeholder based on the storeKey.
        if (supportNewRecords) {
          ids[i] = '_sc_id_placeholder_' + rec.get('storeKey');
        } else {
          throw new Error("Developer Error: Attempted to add a record without a primary key to a to-many relationship (%@). The record must have a real id or be given a temporary id before it can be used. ".fmt(pname));
        }
      } else {
        ids[i] = id;
      }
    }

    // if we have an inverse - collect the list of records we are about to
    // remove
    inverse = this.get('inverse');
    if (inverse && amt > 0) {
      // Use a shared array to save on processing.
      toRemove = SC.ManyArray._toRemove;
      if (toRemove) SC.ManyArray._toRemove = null; // reuse if possible
      else toRemove = [];

      for (i = 0; i < amt; i++) {
        toRemove[i] = this.objectAt(idx + i);
      }
    }

    // Notify that the content will change.
    this.arrayContentWillChange(idx, amt, recsLen);

    // Perform a raw array replace without any KVO checks.
    // NOTE: the cache must be updated to mirror changes to the storeIds
    if (ids.length === 0) {
      storeIds.splice(idx, amt);
      this._records.splice(idx, amt);
    } else {
      var args = [idx, amt].concat(ids);
      storeIds.splice.apply(storeIds, args);
      args = [idx, amt].concat(new Array(ids.length)); // Insert empty items into the cache
      this._records.splice.apply(this._records, args);
    }

    // ok, notify records that were removed then added; this way reordered
    // objects are added and removed
    if (inverse) {

      // notify removals
      for (i = 0; i < amt; i++) {
        inverseRecord = toRemove[i];
        attr = inverseRecord ? inverseRecord[inverse] : null;
        if (attr && attr.inverseDidRemoveRecord) {
          attr.inverseDidRemoveRecord(inverseRecord, inverse, parent, pname);
        }
      }

      if (toRemove) {
        toRemove.length = 0; // cleanup
        if (!SC.ManyArray._toRemove) SC.ManyArray._toRemove = toRemove;
      }

      // notify additions
      for (i = 0; i < recsLen; i++) {
        inverseRecord = recs.objectAt(i);
        attr = inverseRecord ? inverseRecord[inverse] : null;
        if (attr && attr.inverseDidAddRecord) {
          attr.inverseDidAddRecord(inverseRecord, inverse, parent, pname);
        }
      }

    }

    // Notify that the content did change.
    this.arrayContentDidChange(idx, amt, recsLen);

    // Update our cache! So when the record property change comes back down we can ignore it.
    this._sc_prevStoreIds = storeIds;

    // Only mark record dirty if there is no inverse or we are master.
    if (parent && (!inverse || this.get('isMaster'))) {

      // We must indicate to the parent that we have been modified, so they can
      // update their status.
      parent.recordDidChange(pname);
    }

    return this;
  },

  // ..........................................................
  // INVERSE SUPPORT
  //

  /**
    Called by the `ManyAttribute` whenever a record is removed on the inverse
    of the relationship.

    @param {SC.Record} inverseRecord the record that was removed
    @returns {SC.ManyArray} receiver
  */
  removeInverseRecord: function (inverseRecord) {
    // Fast path!
    if (!inverseRecord) return this; // nothing to do

    var id = inverseRecord.get('id'),
      storeIds = this.get('editableStoreIds'),
      idx = (storeIds && id) ? storeIds.indexOf(id) : -1,
      record;

    if (idx >= 0) {

      // Notify that the content will change.
      this.arrayContentWillChange(idx, 1, 0);

      // Perform a raw array replace without any KVO checks.
      // NOTE: the cache must be updated to mirror changes to the storeIds
      storeIds.splice(idx, 1);
      if (this._records) { this._records.splice(idx, 1); }

      // Notify that the content did change.
      this.arrayContentDidChange(idx, 1, 0);

      // Update our cache! So when the record property change comes back down we can ignore it.
      this._sc_prevStoreIds = storeIds;

      if (this.get('isMaster') && (record = this.get('record'))) {
        record.recordDidChange(this.get('propertyName'));
      }
    }

    return this;
  },

  /**
    Called by the `ManyAttribute` whenever a record is added on the inverse
    of the relationship.

    @param {SC.Record} inverseRecord the record this array is a part of
    @returns {SC.ManyArray} receiver
  */
  addInverseRecord: function (inverseRecord) {
    // Fast path!
    if (!inverseRecord) return this;

    var storeIds = this.get('editableStoreIds'),
      orderBy  = this.get('orderBy'),
      len = storeIds.get('length'),
      idx, record,
      removeCount, addCount;

    // find idx to insert at.
    if (orderBy) {
      idx = this._findInsertionLocation(inverseRecord, 0, len, orderBy);

      // All objects from idx to the end must be removed to do an ordered insert.
      removeCount = storeIds.length - idx;
      addCount = storeIds.length - idx + 1;
    } else {
      idx = len;

      removeCount = 0;
      addCount = 1;
    }

    // Notify that the content will change.
    this.arrayContentWillChange(idx, removeCount, addCount);

    // Perform a raw array replace without any KVO checks.
    // NOTE: the cache must be updated to mirror changes to the storeIds
    storeIds.splice(idx, 0, inverseRecord.get('id'));
    if (this._records) { this._records.splice(idx, 0, null); }

    // Notify that the content did change.
    this.arrayContentDidChange(idx, removeCount, addCount);

    // Update our cache! So when the record property change comes back down we can ignore it.
    this._sc_prevStoreIds = storeIds;

    if (this.get('isMaster') && (record = this.get('record'))) {
      record.recordDidChange(this.get('propertyName'));
    }

    return this;
  },

  /** @private binary search to find insertion location */
  _findInsertionLocation: function (rec, min, max, orderBy) {
    var idx   = min + Math.floor((max - min) / 2),
        cur   = this.objectAt(idx),
        order = this._compare(rec, cur, orderBy);

    if (order < 0) {
      // The location is before the first index.
      if (idx === 0) return idx;

      // The location is in the lower subset.
      else return this._findInsertionLocation(rec, 0, idx - 1, orderBy);
    } else if (order > 0) {
      // The location is after the current index.
      if (idx >= max) return idx + 1;

      // The location is in the upper subset.
      else return this._findInsertionLocation(rec, idx + 1, max, orderBy);
    } else {
      // The location is the current index.
      return idx;
    }
  },

  /** @private function to compare two objects*/
  _compare: function (a, b, orderBy) {
    var t = SC.typeOf(orderBy),
        ret, idx, len;

    if (t === SC.T_FUNCTION) ret = orderBy(a, b);
    else if (t === SC.T_STRING) ret = SC.compare(a, b);
    else {
      len = orderBy.get('length');
      ret = 0;
      for (idx = 0; ret === 0 && idx < len; idx++) ret = SC.compare(a, b);
    }

    return ret;
  },

  /**
    Call this when a new record that was added to the many array previously
    has been committed and now has a proper `id`. This will fix up the temporary
    id that was used to allow the new record to be a part of this many array.

    @return {void}
  */
  updateNewRecordId: function (rec) {
    var storeIds = this.get('editableStoreIds'),
      idx;

    // Update the storeIds array with the new record id.
    idx = storeIds.indexOf('_sc_id_placeholder_' + rec.get('storeKey'));

    // Beware of records that are no longer a part of storeIds.
    if (idx >= 0) {
      storeIds.replace(idx, 1, [rec.get('id')]);
    }
  },

  // ..........................................................
  // INTERNAL SUPPORT
  //

  /** @private */
  unknownProperty: function (key, value) {
    var ret;
    if (SC.typeOf(key) === SC.T_STRING) ret = this.reducedProperty(key, value);
    return ret === undefined ? arguments.callee.base.apply(this,arguments) : ret;
  },

  /** @private */
  init: function () {
    arguments.callee.base.apply(this,arguments);

    // Initialize.
    this.recordPropertyDidChange();
  },

  /** @private
    This is called by the parent record whenever its properties change. It is
    also called by the ChildrenAttribute transform when the attribute is set
    to a new array.
  */
  recordPropertyDidChange: function (keys) {
    if (keys && !keys.contains(this.get('propertyName'))) return this;

    var oldLength = this.get('length'),
      storeIds = this.get('readOnlyStoreIds'),
      newLength = storeIds ? storeIds.length : 0,
      prev = this._sc_prevStoreIds;

    // Fast Path! No actual change to our backing array attribute so we should
    // not notify any changes.
    if (storeIds === prev) { return; }

    // Throw away our cache.
    this._records = null;

    // Notify that the content did change.
    this.arrayContentDidChange(0, oldLength, newLength);

    // Cache our backing array so we can avoid updates when we haven't actually
    // changed. See fast path above.
    this._sc_prevStoreIds = storeIds;
  }

});

/* >>>>>>>>>> BEGIN source/models/many_attribute.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('models/record');
sc_require('models/record_attribute');
sc_require('system/many_array');

/** @class

  ManyAttribute is a subclass of `RecordAttribute` and handles to-many
  relationships.

  Relationships in the client are meant to mirror the relationships that
  the real data has in the remote data store on the server. For example,
  if a `Parent` record on the server has an array of `Child` ids, then it is
  appropriate for the `MyApp.Parent` model in the SproutCore app to have a `toMany`
  relationship to the `MyApp.Child` in the app. In this way, changes to the
  relationship in the client will best match how the data should be committed
  to the server.

  There are many ways you can configure a `ManyAttribute`:

      contacts: SC.Record.toMany('MyApp.Contact', {
        inverse: 'group', // set the key used to represent the inverse
        isMaster: YES|NO, // indicate whether changing this should dirty
        transform: function(), // transforms value <=> storeKey,
        isEditable: YES|NO, make editable or not,
        through: 'taggings' // set a relationship this goes through
      });

  Note: When setting ( `.set()` ) the value of a `toMany` attribute, make sure
  to pass in an array of `SC.Record` objects.

  ## Using new Records in Relationships

  Because relationships are based on `id`, new records created in the client
  (that don't have an `id`) are typically not able to be assigned to a
  relationship until after they have been committed to the server. However,
  because it's unwieldy to manually update relationships after the real `id` is
  known, `SC.ManyAttribute` through `SC.ManyArray`, allows new records to be added
  that don't yet have an `id`.

  As long as the `supportNewRecords` property is true, adding records without an
  `id `to the relationship will assign unique temporary ids to the new records.

  *Note:* You must update the relationship after the new records are successfully
  committed and have real ids. This is done by calling `updateNewRecordId()`
  on the many array. In the future this should be automatic.

  @extends SC.RecordAttribute
  @since SproutCore 1.0
*/
SC.ManyAttribute = SC.RecordAttribute.extend(
  /** @scope SC.ManyAttribute.prototype */ {

  /**
    Set the foreign key on content objects that represent the inversion of
    this relationship. The inverse property should be a `toOne()` or
    `toMany()` relationship as well. Modifying this many array will modify
    the `inverse` property as well.

    @type String
  */
  inverse: null,

  /**
    If `YES` then modifying this relationships will mark the owner record
    dirty. If set to `NO`, then modifying this relationship will not alter
    this record.  You should use this property only if you have an inverse
    property also set. Only one of the inverse relationships should be marked
    as master so you can control which record should be committed.

    @type Boolean
  */
  isMaster: YES,

  /**
    If set and you have an inverse relationship, will be used to determine the
    order of an object when it is added to an array. You can pass a function
    or an array of property keys.

    @property {Function|Array}
  */
  orderBy: null,

  /**
    Determines whether the new record support of `SC.ManyArray` should be
    enabled or not.

    Normally, all records in the relationship should already have been previously
    committed to a remote data store and have an actual `id`. However, with
    `supportNewRecords` set to true, adding records without an `id `to the
    relationship will assign unique temporary ids to the new records.

    *Note:* You must update the relationship after the new records are successfully
    committed and have real ids. This is done by calling `updateNewRecordId()`
    on the many array. In the future this should be automatic.

    If you wish to turn this off, SC.ManyArray will throw an exception if you
    add a record without an id to the relationship. If you use temporary `id`s
    for new record, you will need to manually update the relationship, but
    run the risk of committing inverse records with temporary `id`s in their
    datahashes.

    @type Boolean
    @default true
    @since SproutCore 1.11.0
  */
  supportNewRecords: true,

  // ..........................................................
  // LOW-LEVEL METHODS
  //

  /**  @private - adapted for to many relationship */
  toType: function(record, key, value) {
    var type      = this.get('typeClass'),
        supportNewRecords = this.get('supportNewRecords'),
        attrKey   = this.get('key') || key,
        arrayKey  = SC.keyFor('__manyArray__', SC.guidFor(this)),
        ret       = record[arrayKey],
        rel;

    // lazily create a ManyArray one time.  after that always return the
    // same object.
    if (!ret) {
      ret = SC.ManyArray.create({
        recordType:    type,
        record:        record,
        propertyName:  attrKey,
        manyAttribute: this,
        supportNewRecords: supportNewRecords
      });

      record[arrayKey] = ret ; // save on record
      rel = record.get('relationships');
      if (!rel) record.set('relationships', rel = []);
      rel.push(ret); // make sure we get notified of changes...

    }

    return ret;
  },

  /** @private - adapted for to many relationship */
  fromType: function(record, key, value) {
    var ret = [];

    if(!SC.isArray(value)) throw new Error("Expects toMany attribute to be an array");

    var len = value.get('length');
    for(var i=0;i<len;i++) {
      ret[i] = value.objectAt(i).get('id');
    }

    return ret;
  },

  /**
    Called by an inverse relationship whenever the receiver is no longer part
    of the relationship.  If this matches the inverse setting of the attribute
    then it will update itself accordingly.

    You should never call this directly.

    @param {SC.Record} the record owning this attribute
    @param {String} key the key for this attribute
    @param {SC.Record} inverseRecord record that was removed from inverse
    @param {String} key key on inverse that was modified
    @returns {void}
  */
  inverseDidRemoveRecord: function(record, key, inverseRecord, inverseKey) {
    var manyArray = record.get(key);
    if (manyArray) {
      manyArray.removeInverseRecord(inverseRecord);
    }
  },

  /**
    Called by an inverse relationship whenever the receiver is added to the
    inverse relationship.  This will set the value of this inverse record to
    the new record.

    You should never call this directly.

    @param {SC.Record} the record owning this attribute
    @param {String} key the key for this attribute
    @param {SC.Record} inverseRecord record that was added to inverse
    @param {String} key key on inverse that was modified
    @returns {void}
  */
  inverseDidAddRecord: function(record, key, inverseRecord, inverseKey) {
    var manyArray = record.get(key);
    if (manyArray) {
      manyArray.addInverseRecord(inverseRecord);
    }
  }

});

/* >>>>>>>>>> BEGIN source/models/single_attribute.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('models/record');
sc_require('models/record_attribute');

/** @class

  `SingleAttribute` is a subclass of `RecordAttribute` and handles to-one
  relationships.

  There are many ways you can configure a `SingleAttribute`:

      group: SC.Record.toOne('MyApp.Group', {
        inverse: 'contacts', // set the key used to represent the inverse
        isMaster: YES|NO, // indicate whether changing this should dirty
        transform: function(), // transforms value <=> storeKey,
        isEditable: YES|NO, make editable or not
      });

  @extends SC.RecordAttribute
  @since SproutCore 1.0
*/
SC.SingleAttribute = SC.RecordAttribute.extend(
  /** @scope SC.SingleAttribute.prototype */ {

  /**
    Specifies the property on the member record that represents the inverse
    of the current relationship.  If set, then modifying this relationship
    will also alter the opposite side of the relationship.

    @type String
    @default null
  */
  inverse: null,

  /**
    If set, determines that when an inverse relationship changes whether this
    record should become dirty also or not.

    @type Boolean
    @default YES
  */
  isMaster: YES,


  /**
    @private - implements support for handling inverse relationships.
  */
  call: function(record, key, newRec) {
    var attrKey = this.get('key') || key,
        inverseKey, isMaster, oldRec, attr, ret, nvalue;

    // WRITE
    if (newRec !== undefined && this.get('isEditable')) {

      // can only take other records or null
      


      inverseKey = this.get('inverse');
      if (inverseKey) oldRec = this._scsa_call(record, key);

      // careful: don't overwrite value here.  we want the return value to
      // cache.
      nvalue = this.fromType(record, key, newRec) ; // convert to attribute.
      record.writeAttribute(attrKey, nvalue, !this.get('isMaster'));
      ret = newRec ;

      // ok, now if we have an inverse relationship, get the inverse
      // relationship and notify it of what is happening.  This will allow it
      // to update itself as needed.  The callbacks implemented here are
      // supported by both SingleAttribute and ManyAttribute.
      //
      if (inverseKey && (oldRec !== newRec)) {
        if (oldRec && (attr = oldRec[inverseKey])) {
          attr.inverseDidRemoveRecord(oldRec, inverseKey, record, key);
        }

        if (newRec && (attr = newRec[inverseKey])) {
          attr.inverseDidAddRecord(newRec, inverseKey, record, key);
        }
      }

    // READ
    } else ret = this._scsa_call(record, key, newRec);

    return ret ;
  },

  /** @private - save original call() impl */
  _scsa_call: SC.RecordAttribute.prototype.call,

  /**
    Called by an inverse relationship whenever the receiver is no longer part
    of the relationship.  If this matches the inverse setting of the attribute
    then it will update itself accordingly.

    @param {SC.Record} record the record owning this attribute
    @param {String} key the key for this attribute
    @param {SC.Record} inverseRecord record that was removed from inverse
    @param {String} inverseKey key on inverse that was modified
  */
  inverseDidRemoveRecord: function(record, key, inverseRecord, inverseKey) {

    var myInverseKey  = this.get('inverse'),
        curRec   = this._scsa_call(record, key),
        isMaster = this.get('isMaster'), attr;

    // ok, you removed me, I'll remove you...  if isMaster, notify change.
    record.writeAttribute(this.get('key') || key, null, !isMaster);
    record.notifyPropertyChange(key);

    // if we have another value, notify them as well...
    if ((curRec !== inverseRecord) || (inverseKey !== myInverseKey)) {
      if (curRec && (attr = curRec[myInverseKey])) {
        attr.inverseDidRemoveRecord(curRec, myInverseKey, record, key);
      }
    }
  },

  /**
    Called by an inverse relationship whenever the receiver is added to the
    inverse relationship.  This will set the value of this inverse record to
    the new record.

    @param {SC.Record} record the record owning this attribute
    @param {String} key the key for this attribute
    @param {SC.Record} inverseRecord record that was added to inverse
    @param {String} inverseKey key on inverse that was modified
  */
  inverseDidAddRecord: function(record, key, inverseRecord, inverseKey) {
    var myInverseKey  = this.get('inverse'),
        curRec   = this._scsa_call(record, key),
        isMaster = this.get('isMaster'),
        attr, nvalue;

    // ok, replace myself with the new value...
    nvalue = this.fromType(record, key, inverseRecord); // convert to attr.
    record.writeAttribute(this.get('key') || key, nvalue, !isMaster);
    record.notifyPropertyChange(key);

    // if we have another value, notify them as well...
    if ((curRec !== inverseRecord) || (inverseKey !== myInverseKey)) {
      if (curRec && (attr = curRec[myInverseKey])) {
        attr.inverseDidRemoveRecord(curRec, myInverseKey, record, key);
      }
    }
  }

});

/* >>>>>>>>>> BEGIN source/system/store.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('models/record');

/**
  @class


  The Store is where you can find all of your dataHashes. Stores can be
  chained for editing purposes and committed back one chain level at a time
  all the way back to a persistent data source.

  Every application you create should generally have its own store objects.
  Once you create the store, you will rarely need to work with the store
  directly except to retrieve records and collections.

  Internally, the store will keep track of changes to your json data hashes
  and manage syncing those changes with your data source.  A data source may
  be a server, local storage, or any other persistent code.

  @extends SC.Object
  @since SproutCore 1.0
*/
SC.Store = SC.Object.extend( /** @scope SC.Store.prototype */ {

  /**
    An (optional) name of the store, which can be useful during debugging,
    especially if you have multiple nested stores.

    @type String
  */
  name: null,

  /**
    An array of all the chained stores that current rely on the receiver
    store.

    @type Array
  */
  nestedStores: null,

  /**
    The data source is the persistent storage that will provide data to the
    store and save changes.  You normally will set your data source when you
    first create your store in your application.

    @type SC.DataSource
  */
  dataSource: null,

  /**
    This type of store is not nested.

    @default NO
    @type Boolean
  */
  isNested: NO,

  /**
    This type of store is not nested.

    @default NO
    @type Boolean
  */
  commitRecordsAutomatically: NO,

  // ..........................................................
  // DATA SOURCE SUPPORT
  //

  /**
    Convenience method.  Sets the current data source to the passed property.
    This will also set the store property on the dataSource to the receiver.

    If you are using this from the `core.js` method of your app, you may need to
    just pass a string naming your data source class.  If this is the case,
    then your data source will be instantiated the first time it is requested.

    @param {SC.DataSource|String} dataSource the data source
    @returns {SC.Store} receiver
  */
  from: function(dataSource) {
    this.set('dataSource', dataSource);
    return this ;
  },

  // lazily convert data source to real object
  _getDataSource: function() {
    var ret = this.get('dataSource');
    if (typeof ret === SC.T_STRING) {
      ret = SC.requiredObjectForPropertyPath(ret);
      if (ret.isClass) ret = ret.create();
      this.set('dataSource', ret);
    }
    return ret;
  },

  /**
    Convenience method.  Creates a `CascadeDataSource` with the passed
    data source arguments and sets the `CascadeDataSource` as the data source
    for the receiver.

    @param {SC.DataSource...} dataSource one or more data source arguments
    @returns {SC.Store} receiver
  */
  cascade: function(dataSource) {
    var dataSources;

    // Fast arguments access.
    // Accessing `arguments.length` is just a Number and doesn't materialize the `arguments` object, which is costly.
    dataSources = new Array(arguments.length); //  SC.A(arguments)
    for (var i = 0, len = dataSources.length; i < len; i++) { dataSources[i] = arguments[i]; }

    dataSource = SC.CascadeDataSource.create({
      dataSources: dataSources
    });
    return this.from(dataSource);
  },

  // ..........................................................
  // STORE CHAINING
  //

  /**
    Returns a new nested store instance that can be used to buffer changes
    until you are ready to commit them.  When you are ready to commit your
    changes, call `commitChanges()` or `destroyChanges()` and then `destroy()`
    when you are finished with the chained store altogether.

        store = MyApp.store.chain();
        .. edit edit edit
        store.commitChanges().destroy();

    @param {Hash} attrs optional attributes to set on new store
    @param {Class} newStoreClass optional the class of the newly-created nested store (defaults to SC.NestedStore)
    @returns {SC.NestedStore} new nested store chained to receiver
  */
  chain: function(attrs, newStoreClass) {
    if (!attrs) attrs = {};
    attrs.parentStore = this;

    if (newStoreClass) {
      // Ensure the passed-in class is a type of nested store.
      if (SC.typeOf(newStoreClass) !== 'class') throw new Error("%@ is not a valid class".fmt(newStoreClass));
      if (!SC.kindOf(newStoreClass, SC.NestedStore)) throw new Error("%@ is not a type of SC.NestedStore".fmt(newStoreClass));
    }
    else {
      newStoreClass = SC.NestedStore;
    }

    // Replicate parent records references
    attrs.childRecords = this.childRecords ? SC.clone(this.childRecords) : {};
    attrs.parentRecords = this.parentRecords ? SC.clone(this.parentRecords) : {};

    var ret    = newStoreClass.create(attrs),
        nested = this.nestedStores;

    if (!nested) nested = this.nestedStores = [];
    nested.push(ret);
    return ret ;
  },

  /**
    Creates an autonomous nested store that is connected to the data source.
    Use this kind of nested store to ensure that all records that are committed into main store are first of all committed on the server.

    ns = store.chainAutonomousStore();
    ... perform changes into the nested store
    ns.commitRecords( ...,callback );
    or...
    newRecord.commitRecord( ..., callback );

    into the callback method:
      A. If using a transaction model: "all or nothing" where all rows are handled into a single transaction

         if the transaction is successful, commit the successful changes into the main store and destroy:
           ns.commitSuccessfulChanges();
           ns.destroy();

        if not successful, handle the error, allow corrections if needed, etc.

      B. If using a transaction model: "independent rows" where the edited rows are independent and committed separately into the backend database
         When only some of them have been accepted by the server, the overall transaction is only partially
         successful therefore the nested store will contain rows with different statuses.
         In such case, into the callback method only the accepted rows should be pushed to the main store using commitSuccessfulChanges()

           ns.commitSuccessfulChanges();
           ...
         if some of the rows were not accepted by the backend, allow corrections, attempt another commit, etc.:
           ns.commitRecords( ...,callback );
           ... the callback will be invoked again

         Important note: In the case of such configuration, in order to preserve the consistency of the main store with
         the backend database, it is recommended to systematically call commitSuccessfulChanges() when receiving the answer from the server.

    @param {Hash} attrs optional attributes to set on new store
    @param {Class} newStoreClass optional the class of the newly-created nested store (defaults to SC.NestedStore)
    @returns {SC.NestedStore} new nested store chained to receiver
  */
  chainAutonomousStore: function(attrs, newStoreClass) {
    var newAttrs = attrs ? SC.clone( attrs ) : {};
    var source  = this._getDataSource();

    newAttrs.dataSource = source;
    return this.chain( newAttrs, newStoreClass );
  },

  /** @private

    Called by a nested store just before it is destroyed so that the parent
    can remove the store from its list of nested stores.

    @returns {SC.Store} receiver
  */
  willDestroyNestedStore: function(nestedStore) {
    if (this.nestedStores) {
      this.nestedStores.removeObject(nestedStore);
    }
    return this ;
  },

  /**
    Used to determine if a nested store belongs directly or indirectly to the
    receiver.

    @param {SC.Store} store store instance
    @returns {Boolean} YES if belongs
  */
  hasNestedStore: function(store) {
    while(store && (store !== this)) store = store.get('parentStore');
    return store === this ;
  },

  // ..........................................................
  // SHARED DATA STRUCTURES
  //

  /** @private
    JSON data hashes indexed by store key.

    *IMPORTANT: Property is not observable*

    Shared by a store and its child stores until you make edits to it.

    @type Hash
  */
  dataHashes: null,

  /** @private
    The current status of a data hash indexed by store key.

    *IMPORTANT: Property is not observable*

    Shared by a store and its child stores until you make edits to it.

    @type Hash
  */
  statuses: null,

  /** @private
    This array contains the revisions for the attributes indexed by the
    storeKey.

    *IMPORTANT: Property is not observable*

    Revisions are used to keep track of when an attribute hash has been
    changed. A store shares the revisions data with its parent until it
    starts to make changes to it.

    @type Hash
  */
  revisions: null,

  /**
    Array indicates whether a data hash is possibly in use by an external
    record for editing.  If a data hash is editable then it may be modified
    at any time and therefore chained stores may need to clone the
    attributes before keeping a copy of them.

    Note that this is kept as an array because it will be stored as a dense
    array on some browsers, making it faster.

    @type Array
  */
  editables: null,

  /**
    A set of storeKeys that need to be committed back to the data source. If
    you call `commitRecords()` without passing any other parameters, the keys
    in this set will be committed instead.

    @type SC.Set
  */
  changelog: null,

  /**
    An array of `SC.Error` objects associated with individual records in the
    store (indexed by store keys).

    Errors passed form the data source in the call to dataSourceDidError() are
    stored here.

    @type Array
  */
  recordErrors: null,

  /**
    A hash of `SC.Error` objects associated with queries (indexed by the GUID
    of the query).

    Errors passed from the data source in the call to
    `dataSourceDidErrorQuery()` are stored here.

    @type Hash
  */
  queryErrors: null,

  /**
    A hash of child Records and there immediate parents
  */
  childRecords: null,

  /**
    A hash of parent records with registered children
  */
  parentRecords: null,

  // ..........................................................
  // CORE ATTRIBUTE API
  //
  // The methods in this layer work on data hashes in the store.  They do not
  // perform any changes that can impact records.  Usually you will not need
  // to use these methods.

  /**
    Returns the current edit status of a store key.  May be one of
    `EDITABLE` or `LOCKED`.  Used mostly for unit testing.

    @param {Number} storeKey the store key
    @returns {Number} edit status
  */
  storeKeyEditState: function(storeKey) {
    var editables = this.editables;
    return (editables && editables[storeKey]) ? SC.Store.EDITABLE : SC.Store.LOCKED ;
  },

  /**
    Returns the data hash for the given `storeKey`.  This will also 'lock'
    the hash so that further edits to the parent store will no
    longer be reflected in this store until you reset.

    @param {Number} storeKey key to retrieve
    @returns {Hash} data hash or null
  */
  readDataHash: function(storeKey) {
    return this.dataHashes[storeKey];
  },

  /**
    Returns the data hash for the `storeKey`, cloned so that you can edit
    the contents of the attributes if you like.  This will do the extra work
    to make sure that you only clone the attributes one time.

    If you use this method to modify data hash, be sure to call
    `dataHashDidChange()` when you make edits to record the change.

    @param {Number} storeKey the store key to retrieve
    @returns {Hash} the attributes hash
  */
  readEditableDataHash: function(storeKey) {
    // read the value - if there is no hash just return; nothing to do
    var ret = this.dataHashes[storeKey];
    if (!ret) return ret ; // nothing to do.

    // clone data hash if not editable
    var editables = this.editables;
    if (!editables) editables = this.editables = [];
    if (!editables[storeKey]) {
      editables[storeKey] = 1 ; // use number to store as dense array
      ret = this.dataHashes[storeKey] = SC.clone(ret, YES);
    }
    return ret;
  },

  /**
    Reads a property from the hash - cloning it if needed so you can modify
    it independently of any parent store.  This method is really only well
    tested for use with toMany relationships.  Although it is public you
    generally should not call it directly.

    @param {Number} storeKey storeKey of data hash
    @param {String} propertyName property to read
    @returns {Object} editable property value
  */
  readEditableProperty: function(storeKey, propertyName) {
    var hash      = this.readEditableDataHash(storeKey),
        editables = this.editables[storeKey], // get editable info...
        ret       = hash[propertyName];

    // editables must be made into a hash so that we can keep track of which
    // properties have already been made editable
    if (editables === 1) editables = this.editables[storeKey] = {};

    // clone if needed
    if (!editables[propertyName]) {
      ret = hash[propertyName];
      if (ret && ret.isCopyable) ret = hash[propertyName] = ret.copy(YES);
      editables[propertyName] = YES ;
    }

    return ret ;
  },

  /**
    Replaces the data hash for the `storeKey`.  This will lock the data hash
    and mark them as cloned.  This will also call `dataHashDidChange()` for
    you.

    Note that the hash you set here must be a different object from the
    original data hash.  Once you make a change here, you must also call
    `dataHashDidChange()` to register the changes.

    If the data hash does not yet exist in the store, this method will add it.
    Pass the optional status to edit the status as well.

    @param {Number} storeKey the store key to write
    @param {Hash} hash the new hash
    @param {String} status the new hash status
    @returns {SC.Store} receiver
  */
  writeDataHash: function(storeKey, hash, status) {

    // update dataHashes and optionally status.
    if (hash) this.dataHashes[storeKey] = hash;
    if (status) this.statuses[storeKey] = status ;

    // also note that this hash is now editable
    var editables = this.editables;
    if (!editables) editables = this.editables = [];
    editables[storeKey] = 1 ; // use number for dense array support

    // propagate the data to the child records
    this._updateChildRecordHashes(storeKey, hash, status);

    return this ;
  },

  /** @private

    Called by writeDataHash to update the child record hashes starting from the new (parent) data hash.

    @returns {SC.Store} receiver
  */
  _updateChildRecordHashes: function(storeKey, hash, status) {
    var processedPaths={};
    // Update the child record hashes in place.
    if (!SC.none(this.parentRecords) ) {
      var children = this.parentRecords[storeKey] || {},
        childHash;

      for (var key in children) {
        if (children.hasOwnProperty(key)) {
          if (hash) {
            var childPath = children[key];
            childPath = childPath.split('.');
            if (childPath.length > 1) {
              childHash = hash[childPath[0]][childPath[1]];
            } else {
              childHash = hash[childPath[0]];
            }

            if (!processedPaths[hash[childPath[0]]]){
                // update data hash: required to push changes beyond the first nesting level
                this.writeDataHash(key, childHash, status);
            }

            if (childPath.length > 1 && ! processedPaths[hash[childPath[0]]]) {
              // save it so that we don't processed it over and over
              processedPaths[hash[childPath[0]]]=true;

              // force fetching of all children records by invoking the children_attribute wrapper code
              // and then interating the list in an empty loop
              // Ugly, but there's basically no other way to do it at the moment, other than
              // leaving this broken as it was before
              var that = this;
              this.invokeLast(function() {
                that.records[storeKey].get(childPath[0]).forEach(function (it) {});
              });
            }
          } else {
            this.writeDataHash(key, null, status);
          }
        }
      }
    }
  },

  /**
    Removes the data hash from the store.  This does not imply a deletion of
    the record.  You could be simply unloading the record.  Either way,
    removing the dataHash will be synced back to the parent store but not to
    the server.

    Note that you can optionally pass a new status to go along with this. If
    you do not pass a status, it will change the status to `SC.RECORD_EMPTY`
    (assuming you just unloaded the record).  If you are deleting the record
    you may set it to `SC.Record.DESTROYED_CLEAN`.

    Be sure to also call `dataHashDidChange()` to register this change.

    @param {Number} storeKey
    @param {String} status optional new status
    @returns {SC.Store} receiver
  */
  removeDataHash: function(storeKey, status) {
     // don't use delete -- that will allow parent dataHash to come through
    this.dataHashes[storeKey] = null;
    this.statuses[storeKey] = status || SC.Record.EMPTY;

    // hash is gone and therefore no longer editable
    var editables = this.editables;
    if (editables) editables[storeKey] = 0 ;

    return this ;
  },

  /**
    Reads the current status for a storeKey.  This will also lock the data
    hash.  If no status is found, returns `SC.RECORD_EMPTY`.

    @param {Number} storeKey the store key
    @returns {Number} status
  */
  readStatus: function(storeKey) {
    // use readDataHash to handle optimistic locking.  this could be inlined
    // but for now this minimized copy-and-paste code.
    this.readDataHash(storeKey);
    return this.statuses[storeKey] || SC.Record.EMPTY;
  },

  /**
    Reads the current status for the storeKey without actually locking the
    record.  Usually you won't need to use this method.  It is mostly used
    internally.

    @param {Number} storeKey the store key
    @returns {Number} status
  */
  peekStatus: function(storeKey) {
    return this.statuses[storeKey] || SC.Record.EMPTY;
  },

  /**
    Writes the current status for a storeKey.  If the new status is
    `SC.Record.ERROR`, you may also pass an optional error object.  Otherwise
    this param is ignored.

    @param {Number} storeKey the store key
    @param {String} newStatus the new status
    @param {SC.Error} error optional error object
    @returns {SC.Store} receiver
  */
  writeStatus: function(storeKey, newStatus) {
    var that = this,
        ret;
    // use writeDataHash for now to handle optimistic lock.  maximize code
    // reuse.
    ret = this.writeDataHash(storeKey, null, newStatus);
    this._propagateToChildren(storeKey, function(storeKey) {
      that.writeStatus(storeKey, newStatus);
    });
    return ret;
  },

  /**
    Call this method whenever you modify some editable data hash to register
    with the Store that the attribute values have actually changed.  This will
    do the book-keeping necessary to track the change across stores including
    managing locks.

    @param {Number|Array} storeKeys one or more store keys that changed
    @param {Number} rev optional new revision number. normally leave null
    @param {Boolean} statusOnly (optional) YES if only status changed
    @param {String} key that changed (optional)
    @returns {SC.Store} receiver
  */
  dataHashDidChange: function(storeKeys, rev, statusOnly, key) {
    // update the revision for storeKey.  Use generateStoreKey() because that
    // guarantees a universally (to this store hierarchy anyway) unique
    // key value.
    if (!rev) rev = SC.Store.generateStoreKey();
    var isArray, len, idx, storeKey;

    isArray = SC.typeOf(storeKeys) === SC.T_ARRAY;
    if (isArray) {
      len = storeKeys.length;
    } else {
      len = 1;
      storeKey = storeKeys;
    }

    var that = this;
    for(idx=0;idx<len;idx++) {
      if (isArray) storeKey = storeKeys[idx];
      this.revisions[storeKey] = rev;
      this._notifyRecordPropertyChange(storeKey, statusOnly, key);

      this._propagateToChildren(storeKey, function(storeKey){
        that.dataHashDidChange(storeKey, null, statusOnly, key);
      });
    }

    return this ;
  },

  /** @private
    Will push all changes to a the recordPropertyChanges property
    and execute `flush()` once at the end of the runloop.
  */
  _notifyRecordPropertyChange: function(storeKey, statusOnly, key) {

    var records      = this.records,
        nestedStores = this.get('nestedStores'),
        K            = SC.Store,
        rec, editState, len, idx, store, status, keys;

    // pass along to nested stores
    len = nestedStores ? nestedStores.length : 0 ;
    for(idx=0;idx<len;idx++) {
      store = nestedStores[idx];
      status = store.peekStatus(storeKey); // important: peek avoids read-lock
      editState = store.storeKeyEditState(storeKey);

      // when store needs to propagate out changes in the parent store
      // to nested stores
      if (editState === K.INHERITED) {
        store._notifyRecordPropertyChange(storeKey, statusOnly, key);

      } else if (status & SC.Record.BUSY) {
        // make sure nested store does not have any changes before resetting
        if(store.get('hasChanges')) K.CHAIN_CONFLICT_ERROR.throw();
        store.reset();
      }
    }

    // store info in changes hash and schedule notification if needed.
    var changes = this.recordPropertyChanges;
    if (!changes) {
      changes = this.recordPropertyChanges =
        { storeKeys:      SC.CoreSet.create(),
          records:        SC.CoreSet.create(),
          hasDataChanges: SC.CoreSet.create(),
          propertyForStoreKeys: {} };
    }

    changes.storeKeys.add(storeKey);

    if (records && (rec=records[storeKey])) {
      changes.records.push(storeKey);

      // If there are changes other than just the status we need to record
      // that information so we do the right thing during the next flush.
      // Note that if we're called multiple times before flush and one call
      // has `statusOnly=true` and another has `statusOnly=false`, the flush
      // will (correctly) operate in `statusOnly=false` mode.
      if (!statusOnly) changes.hasDataChanges.push(storeKey);

      // If this is a key specific change, make sure that only those
      // properties/keys are notified.  However, if a previous invocation of
      // `_notifyRecordPropertyChange` specified that all keys have changed, we
      // need to respect that.
      if (key) {
        if (!(keys = changes.propertyForStoreKeys[storeKey])) {
          keys = changes.propertyForStoreKeys[storeKey] = SC.CoreSet.create();
        }

        // If it's '*' instead of a set, then that means there was a previous
        // invocation that said all keys have changed.
        if (keys !== '*') {
          keys.add(key);
        }
      }
      else {
        // Mark that all properties have changed.
        changes.propertyForStoreKeys[storeKey] = '*';
      }
    }

    this.invokeOnce(this.flush);
    return this;
  },

  /**
    Delivers any pending changes to materialized records.  Normally this
    happens once, automatically, at the end of the RunLoop.  If you have
    updated some records and need to update records immediately, however,
    you may call this manually.

    @returns {SC.Store} receiver
  */
  flush: function() {
    if (!this.recordPropertyChanges) return this;

    var changes              = this.recordPropertyChanges,
        storeKeys            = changes.storeKeys,
        hasDataChanges       = changes.hasDataChanges,
        records              = changes.records,
        propertyForStoreKeys = changes.propertyForStoreKeys,
        recordTypes = SC.CoreSet.create(),
        rec, recordType, statusOnly, keys;

    storeKeys.forEach(function(storeKey) {
      if (records.contains(storeKey)) {
        statusOnly = hasDataChanges.contains(storeKey) ? NO : YES;
        rec = this.records[storeKey];
        keys = propertyForStoreKeys ? propertyForStoreKeys[storeKey] : null;

        // Are we invalidating all keys?  If so, don't pass any to
        // storeDidChangeProperties.
        if (keys === '*') keys = null;

        // remove it so we don't trigger this twice
        records.remove(storeKey);

        if (rec) rec.storeDidChangeProperties(statusOnly, keys);
      }

      recordType = SC.Store.recordTypeFor(storeKey);
      recordTypes.add(recordType);

    }, this);

    if (storeKeys.get('length') > 0) this._notifyRecordArrays(storeKeys, recordTypes);

    storeKeys.clear();
    hasDataChanges.clear();
    records.clear();
    // Provide full reference to overwrite
    this.recordPropertyChanges.propertyForStoreKeys = {};

    return this;
  },

  /**
    Resets the store content.  This will clear all internal data for all
    records, resetting them to an EMPTY state.  You generally do not want
    to call this method yourself, though you may override it.

    @returns {SC.Store} receiver
  */
  reset: function() {

    // create a new empty data store
    this.dataHashes = {} ;
    this.revisions  = {} ;
    this.statuses   = {} ;
    this.records = {};
    this.childRecords = {};
    this.parentRecords = {};

    // also reset temporary objects and errors
    this.chainedChanges = this.locks = this.editables = null;
    this.changelog = null ;
    this.recordErrors = null;
    this.queryErrors = null;

    var dataSource = this.get('dataSource');
    if (dataSource && dataSource.reset) { dataSource.reset(); }

    var records = this.records, storeKey;
    if (records) {
      for(storeKey in records) {
        if (!records.hasOwnProperty(storeKey)) continue ;
        this._notifyRecordPropertyChange(parseInt(storeKey, 10), NO);
      }
    }

    // Also reset all pre-created recordArrays.
    var ra, raList = this.get('recordArrays');
    if (raList) {
      while ((ra = raList.pop())) {
        ra.destroy();
      }
      raList.clear();
      this.set('recordArrays', null);
    }

    this.set('hasChanges', NO);
  },

  /** @private
    Called by a nested store on a parent store to commit any changes from the
    store.  This will copy any changed dataHashes as well as any persistent
    change logs.

    If the parentStore detects a conflict with the optimistic locking, it will
    raise an exception before it makes any changes.  If you pass the
    force flag then this detection phase will be skipped and the changes will
    be applied even if another resource has modified the store in the mean
    time.

    @param {SC.Store} nestedStore the child store
    @param {SC.Set} changes the set of changed store keys
    @param {Boolean} force
    @returns {SC.Store} receiver
  */
  commitChangesFromNestedStore: function (nestedStore, changes, force) {
    // first, check for optimistic locking problems
    if (!force && nestedStore.get('conflictedStoreKeys')) {
      SC.Store.CHAIN_CONFLICT_ERROR.throw();
    }

    // OK, no locking issues.  So let's just copy them changes.
    // get local reference to values.
    var len = changes.length, i, storeKey, myDataHashes, myStatuses,
      myEditables, myRevisions, myParentRecords, myChildRecords,
      chDataHashes, chStatuses, chRevisions, chParentRecords, chChildRecords;

    myRevisions     = this.revisions ;
    myDataHashes    = this.dataHashes;
    myStatuses      = this.statuses;
    myEditables     = this.editables ;
    myParentRecords = this.parentRecords ? this.parentRecords : this.parentRecords ={} ;
    myChildRecords  = this.childRecords ? this.childRecords : this.childRecords = {} ;

    // setup some arrays if needed
    if (!myEditables) myEditables = this.editables = [] ;
    chDataHashes    = nestedStore.dataHashes;
    chRevisions     = nestedStore.revisions ;
    chStatuses      = nestedStore.statuses;
    chParentRecords = nestedStore.parentRecords || {};
    chChildRecords  = nestedStore.childRecords || {};

    for(i=0;i<len;i++) {
      storeKey = changes[i];

      // now copy changes
      myDataHashes[storeKey]    = chDataHashes[storeKey];
      myStatuses[storeKey]      = chStatuses[storeKey];
      myRevisions[storeKey]     = chRevisions[storeKey];
      myParentRecords[storeKey] = chParentRecords[storeKey];
      myChildRecords[storeKey]  = chChildRecords[storeKey];

      myEditables[storeKey] = 0 ; // always make dataHash no longer editable

      this._notifyRecordPropertyChange(storeKey, NO);
    }

    // add any records to the changelog for commit handling
    var myChangelog = this.changelog, chChangelog = nestedStore.changelog;
    if (chChangelog) {
      if (!myChangelog) myChangelog = this.changelog = SC.CoreSet.create();
      myChangelog.addEach(chChangelog);
    }
    this.changelog = myChangelog;

    // immediately flush changes to notify records - nested stores will flush
    // later on.
    if (!this.get('parentStore')) this.flush();

    return this ;
  },

  // ..........................................................
  // HIGH-LEVEL RECORD API
  //

  /**
    Finds a single record instance with the specified `recordType` and id or
    an  array of records matching some query conditions.

    Finding a Single Record
    ---

    If you pass a single `recordType` and id, this method will return an
    actual record instance.  If the record has not been loaded into the store
    yet, this method will ask the data source to retrieve it.  If no data
    source indicates that it can retrieve the record, then this method will
    return `null`.

    Note that if the record needs to be retrieved from the server, then the
    record instance returned from this method will not have any data yet.
    Instead it will have a status of `SC.Record.READY_LOADING`.  You can
    monitor the status property to be notified when the record data is
    available for you to use it.

    Find a Collection of Records
    ---

    If you pass only a record type or a query object, you can instead find
    all records matching a specified set of conditions.  When you call
    `find()` in this way, it will create a query if needed and pass it to the
    data source to fetch the results.

    If this is the first time you have fetched the query, then the store will
    automatically ask the data source to fetch any records related to it as
    well.  Otherwise you can refresh the query results at anytime by calling
    `refresh()` on the returned `RecordArray`.

    You can detect whether a RecordArray is fetching from the server by
    checking its status.

    Examples
    ---

    Finding a single record:

        MyApp.store.find(MyApp.Contact, "23"); // returns MyApp.Contact

    Finding all records of a particular type:

        MyApp.store.find(MyApp.Contact); // returns SC.RecordArray of contacts


    Finding all contacts with first name John:

        var query = SC.Query.local(MyApp.Contact, "firstName = %@", "John");
        MyApp.store.find(query); // returns SC.RecordArray of contacts

    Finding all contacts using a remote query:

        var query = SC.Query.remote(MyApp.Contact);
        MyApp.store.find(query); // returns SC.RecordArray filled by server

    @param {SC.Record|String} recordType the expected record type
    @param {String} id the id to load
    @returns {SC.Record} record instance or null
  */
  find: function(recordType, id) {

    // if recordType is passed as string, find object
    if (SC.typeOf(recordType)===SC.T_STRING) {
      recordType = SC.objectForPropertyPath(recordType);
    }

    // handle passing a query...
    if ((arguments.length === 1) && !(recordType && recordType.get && recordType.get('isRecord'))) {
      if (!recordType) throw new Error("SC.Store#find() must pass recordType or query");
      if (!recordType.isQuery) {
        recordType = SC.Query.local(recordType);
      }
      return this._findQuery(recordType, YES, YES);

    // handle finding a single record
    } else {
      return this._findRecord(recordType, id);
    }
  },

  /** @private */
  _findQuery: function(query, createIfNeeded, refreshIfNew) {

    // lookup the local RecordArray for this query.
    var cache = this._scst_recordArraysByQuery,
        key   = SC.guidFor(query),
        ret, ra ;
    if (!cache) cache = this._scst_recordArraysByQuery = {};
    ret = cache[key];

    // if a RecordArray was not found, then create one and also add it to the
    // list of record arrays to update.
    if (!ret && createIfNeeded) {
      cache[key] = ret = SC.RecordArray.create({ store: this, query: query });

      ra = this.get('recordArrays');
      if (!ra) this.set('recordArrays', ra = SC.Set.create());
      ra.add(ret);

      if (refreshIfNew) this.refreshQuery(query);
    }

    this.flush();
    return ret ;
  },

  /** @private */
  _findRecord: function(recordType, id) {

    var storeKey ;

    // if a record instance is passed, simply use the storeKey.  This allows
    // you to pass a record from a chained store to get the same record in the
    // current store.
    if (recordType && recordType.get && recordType.get('isRecord')) {
      storeKey = recordType.get('storeKey');

    // otherwise, lookup the storeKey for the passed id.  look in subclasses
    // as well.
    } else storeKey = id ? recordType.storeKeyFor(id) : null;

    if (storeKey && (this.peekStatus(storeKey) === SC.Record.EMPTY)) {
      storeKey = this.retrieveRecord(recordType, id);
    }

    // now we have the storeKey, materialize the record and return it.
    return storeKey ? this.materializeRecord(storeKey) : null ;
  },

  // ..........................................................
  // RECORD ARRAY OPERATIONS
  //

  /**
    Called by the record array just before it is destroyed.  This will
    de-register it from receiving future notifications.

    You should never call this method yourself.  Instead call `destroy()` on
    the `RecordArray` directly.

    @param {SC.RecordArray} recordArray the record array
    @returns {SC.Store} receiver
  */
  recordArrayWillDestroy: function(recordArray) {
    var cache = this._scst_recordArraysByQuery,
        set   = this.get('recordArrays');

    if (cache) delete cache[SC.guidFor(recordArray.get('query'))];
    if (set) set.remove(recordArray);
    return this ;
  },

  /**
    Called by the record array whenever it needs the data source to refresh
    its contents.  Nested stores will actually just pass this along to the
    parent store.  The parent store will call `fetch()` on the data source.

    You should never call this method yourself.  Instead call `refresh()` on
    the `RecordArray` directly.

    @param {SC.Query} query the record array query to refresh
    @returns {SC.Store} receiver
  */
  refreshQuery: function(query) {
    if (!query) throw new Error("refreshQuery() requires a query");

    var cache    = this._scst_recordArraysByQuery,
        recArray = cache ? cache[SC.guidFor(query)] : null,
        source   = this._getDataSource();

    if (source && source.fetch) {
      if (recArray) recArray.storeWillFetchQuery(query);
      source.fetch.call(source, this, query);
    }

    return this ;
  },

  /** @private
    Will ask all record arrays that have been returned from `find`
    with an `SC.Query` to check their arrays with the new `storeKey`s

    @param {SC.IndexSet} storeKeys set of storeKeys that changed
    @param {SC.Set} recordTypes
    @returns {SC.Store} receiver
  */
  _notifyRecordArrays: function(storeKeys, recordTypes) {
    var recordArrays = this.get('recordArrays');
    if (!recordArrays) return this;

    recordArrays.forEach(function(recArray) {
      if (recArray) recArray.storeDidChangeStoreKeys(storeKeys, recordTypes);
    }, this);

    return this ;
  },


  // ..........................................................
  // LOW-LEVEL HELPERS
  //

  /**
    Array of all records currently in the store with the specified
    type.  This method only reflects the actual records loaded into memory and
    therefore is not usually needed at runtime.  However you will often use
    this method for testing.

    @param {SC.Record} recordType the record type
    @returns {SC.Array} array instance - usually SC.RecordArray
  */
  recordsFor: function(recordType) {
    var storeKeys     = [],
        storeKeysById = recordType.storeKeysById(),
        id, storeKey, ret;

    // collect all non-empty store keys
    for(id in storeKeysById) {
      storeKey = storeKeysById[id]; // get the storeKey
      if (this.readStatus(storeKey) !== SC.RECORD_EMPTY) {
        storeKeys.push(storeKey);
      }
    }

    if (storeKeys.length>0) {
      ret = SC.RecordArray.create({ store: this, storeKeys: storeKeys });
    } else ret = storeKeys; // empty array
    return ret ;
  },

  /** @private */
  _CACHED_REC_ATTRS: {},

  /** @private */
  _CACHED_REC_INIT: function() {},

  /**
    Given a `storeKey`, return a materialized record.  You will not usually
    call this method yourself.  Instead it will used by other methods when
    you find records by id or perform other searches.

    If a `recordType` has been mapped to the storeKey, then a record instance
    will be returned even if the data hash has not been requested yet.

    Each Store instance returns unique record instances for each storeKey.

    @param {Number} storeKey The storeKey for the dataHash.
    @returns {SC.Record} Returns a record instance.
  */
  materializeRecord: function(storeKey) {
    var records = this.records,
      ret, recordType, attrs;

    // look up in cached records
    if (!records) records = this.records = {}; // load cached records
    ret = records[storeKey];
    if (ret) return ret;

    // not found -- OK, create one then.
    recordType = SC.Store.recordTypeFor(storeKey);
    if (!recordType) return null; // not recordType registered, nothing to do

    // Populate the attributes.
    attrs = this._CACHED_REC_ATTRS ;
    attrs.storeKey = storeKey ;
    attrs.store    = this ;

    // We do a little gymnastics here to prevent record initialization before we've
    // received and cached a copy of the object. This is because if initialization
    // triggers downstream effects which call materializeRecord for the same record,
    // we won't have a copy of it cached yet, causing another copy to be created
    // and resulting in a stack overflow at best and a really hard-to-diagnose bug
    // involving two instances of the same record floating around at worst.

    // Override _object_init to prevent premature initialization.
    var _object_init = recordType.prototype._object_init;
    recordType.prototype._object_init = this._CACHED_REC_INIT;
    // Create the record (but don't init it).
    ret = records[storeKey] = recordType.create();
    // Repopulate the _object_init method and run initialization.
    recordType.prototype._object_init = ret._object_init = _object_init;
    ret._object_init([attrs]);

    return ret ;
  },

  // ..........................................................
  // CORE RECORDS API
  //
  // The methods in this section can be used to manipulate records without
  // actually creating record instances.

  /**
    Creates a new record instance with the passed `recordType` and `dataHash`.
    You can also optionally specify an id or else it will be pulled from the
    data hash.

    Example:

      MyApp.Record = SC.Record.extend({
        attrA: SC.Record.attr(String, { defaultValue: 'def' }),
        isAttrB: SC.Record.attr(Boolean, { key: 'attr_b' }),
        primaryKey: 'pKey'
      });

      // If you don't provide a value and have designated a defaultValue, the
      // defaultValue will be used.
      MyApp.store.createRecord(MyApp.Record).get('attributes');
      > { attrA: 'def' }

      // If you use a key on an attribute, you can specify the key name or the
      // attribute name when creating the record, but if you specify both, only
      // the key name will be used.
      MyApp.store.createRecord(MyApp.Record, { isAttrB: YES }).get('attributes');
      > { attr_b: YES }
      MyApp.store.createRecord(MyApp.Record, { attr_b: YES }).get('attributes');
      > { attr_b: YES }
      MyApp.store.createRecord(MyApp.Record, { isAttrB: NO, attr_b: YES }).get('attributes');
      > { attr_b: YES }

    Note that the record will not yet be saved back to the server.  To save
    a record to the server, call `commitChanges()` on the store.

    @param {SC.Record} recordType the record class to use on creation
    @param {Hash} dataHash the JSON attributes to assign to the hash.
    @param {String} id (optional) id to assign to record

    @returns {SC.Record} Returns the created record
  */
  createRecord: function(recordType, dataHash, id) {
    var primaryKey, prototype, storeKey, status, K = SC.Record, changelog, defaultVal, ret;

    //initialize dataHash if necessary
    dataHash = (dataHash ? dataHash : {});

    // First, try to get an id.  If no id is passed, look it up in the
    // dataHash.
    if (!id && (primaryKey = recordType.prototype.primaryKey)) {
      id = dataHash[primaryKey];
      // if still no id, check if there is a defaultValue function for
      // the primaryKey attribute and assign that
      defaultVal = recordType.prototype[primaryKey] ? recordType.prototype[primaryKey].defaultValue : null;
      if(!id && SC.typeOf(defaultVal)===SC.T_FUNCTION) {
        id = dataHash[primaryKey] = defaultVal();
      }
    }

    // Next get the storeKey - base on id if available
    storeKey = id ? recordType.storeKeyFor(id) : SC.Store.generateStoreKey();

    // now, check the state and do the right thing.
    status = this.readStatus(storeKey);

    // check state
    // any busy or ready state or destroyed dirty state is not allowed
    if ((status & K.BUSY)  ||
        (status & K.READY) ||
        (status === K.DESTROYED_DIRTY)) {
      (id ? K.RECORD_EXISTS_ERROR : K.BAD_STATE_ERROR).throw();

    // allow error or destroyed state only with id
    } else if (!id && (status===SC.DESTROYED_CLEAN || status===SC.ERROR)) {
      K.BAD_STATE_ERROR.throw();
    }

    // Store the dataHash and setup initial status.
    this.writeDataHash(storeKey, dataHash, K.READY_NEW);

    // Register the recordType with the store.
    SC.Store.replaceRecordTypeFor(storeKey, recordType);
    this.dataHashDidChange(storeKey);

    // If the attribute wasn't provided in the dataHash, attempt to insert a
    // default value.  We have to do this after materializing the record,
    // because the defaultValue property may be a function that expects
    // the record as an argument.
    ret = this.materializeRecord(storeKey);
    prototype = recordType.prototype;
    for (var prop in prototype) {
      var propPrototype = prototype[ prop ];
      if (propPrototype && propPrototype.isRecordAttribute) {
        // Use the record attribute key if it is defined.
        var attrKey = propPrototype.key || prop;

        if (!dataHash.hasOwnProperty(attrKey)) {
          if (dataHash.hasOwnProperty(prop)) {
            // If the attribute key doesn't exist but the name does, fix it up.
            // (i.e. the developer has a record attribute `endDate` with a key
            // `end_date` on a record and when they created the record they
            // provided `endDate` not `end_date`)
            dataHash[ attrKey ] = dataHash[ prop ];
            delete dataHash[ prop ];
          } else {
            // If the attribute doesn't exist in the hash at all, check for a
            // default value to use instead.
            defaultVal = propPrototype.defaultValue;
            if (defaultVal) {
              if (SC.typeOf(defaultVal)===SC.T_FUNCTION) dataHash[ attrKey ] = SC.copy(defaultVal(ret, attrKey), YES);
              else dataHash[ attrKey ] = SC.copy(defaultVal, YES);
            }
          }
        } else if (attrKey !== prop && dataHash.hasOwnProperty(prop)) {
          // If both attrKey and prop are provided, use attrKey only.
          delete dataHash[ prop ];
        }
      }
    }

    // Record is now in a committable state -- add storeKey to changelog
    changelog = this.changelog;
    if (!changelog) changelog = SC.Set.create();
    changelog.add(storeKey);
    this.changelog = changelog;

    // if commit records is enabled
    if(this.get('commitRecordsAutomatically')){
      this.invokeLast(this.commitRecords);
    }

    // Propagate the status to any aggregate records before returning.
    if (ret) ret.propagateToAggregates();
    return ret;
  },

  /**
    Creates an array of new records.  You must pass an array of `dataHash`es
    plus a `recordType` and, optionally, an array of ids.  This will create an
    array of record instances with the same record type.

    If you need to instead create a bunch of records with different data types
    you can instead pass an array of `recordType`s, one for each data hash.

    @param {SC.Record|Array} recordTypes class or array of classes
    @param {Array} dataHashes array of data hashes
    @param {Array} ids (optional) ids to assign to records
    @returns {Array} array of materialized record instances.
  */
  createRecords: function(recordTypes, dataHashes, ids) {
    var ret = [], recordType, id, isArray, len = dataHashes.length, idx ;
    isArray = SC.typeOf(recordTypes) === SC.T_ARRAY;
    if (!isArray) recordType = recordTypes;
    for(idx=0;idx<len;idx++) {
      if (isArray) recordType = recordTypes[idx] || SC.Record;
      id = ids ? ids[idx] : undefined ;
      ret.push(this.createRecord(recordType, dataHashes[idx], id));
    }
    return ret ;
  },


  /**
    Unloads a record, removing the data hash from the store.  If you try to
    unload a record that is already destroyed then this method will have no effect.
    If you unload a record that does not exist or an error then an exception
    will be raised.

    @param {SC.Record} recordType the recordType
    @param {String} id the record id
    @param {Number} storeKey (optional) if passed, ignores recordType and id
    @returns {SC.Store} receiver
  */
  unloadRecord: function(recordType, id, storeKey, newStatus) {
    if (storeKey === undefined) storeKey = recordType.storeKeyFor(id);
    var status = this.readStatus(storeKey), K = SC.Record;
    newStatus = newStatus || K.EMPTY;
    // handle status - ignore if destroying or destroyed
    if ((status === K.BUSY_DESTROYING) || (status & K.DESTROYED)) {
      return this; // nothing to do

    // error out if empty
    } else if (status & K.BUSY) {
      K.BUSY_ERROR.throw();

    // otherwise, destroy in dirty state
    } else status = newStatus ;

    // remove the data hash, set the new status and remove the cached record.
    this.removeDataHash(storeKey, status);
    this.dataHashDidChange(storeKey);
    delete this.records[storeKey];

    // If this record is a parent record, unregister all of its child records.
    var that = this;
    this._propagateToChildren(storeKey, function (storeKey) {
      that.unregisterChildFromParent(storeKey);
    });

    // If this record is a parent record, its child records have been cleared so also clear the
    // cached reference as well.
    if (this.parentRecords) {
      delete this.parentRecords[storeKey];
    }

    return this ;
  },

  /**
    Unloads a group of records.  If you have a set of record ids, unloading
    them this way can be faster than retrieving each record and unloading
    it individually.

    You can pass either a single `recordType` or an array of `recordType`s. If
    you pass a single `recordType`, then the record type will be used for each
    record.  If you pass an array, then each id must have a matching record
    type in the array.

    You can optionally pass an array of `storeKey`s instead of the `recordType`
    and ids.  In this case the first two parameters will be ignored.  This
    is usually only used by low-level internal methods.  You will not usually
    unload records this way.

    @param {SC.Record|Array} recordTypes class or array of classes
    @param {Array} [ids] ids to unload
    @param {Array} [storeKeys] store keys to unload
    @returns {SC.Store} receiver
  */
  unloadRecords: function(recordTypes, ids, storeKeys, newStatus) {
    var len, isArray, idx, id, recordType, storeKey;

    if (storeKeys === undefined) {
      isArray = SC.typeOf(recordTypes) === SC.T_ARRAY;
      if (!isArray) recordType = recordTypes;
      if (ids === undefined) {
        len = isArray ? recordTypes.length : 1;
        for (idx = 0; idx < len; idx++) {
          if (isArray) recordType = recordTypes[idx];
          storeKeys = this.storeKeysFor(recordType);
          this.unloadRecords(undefined, undefined, storeKeys, newStatus);
        }
      } else {
        len = ids.length;
        for (idx = 0; idx < len; idx++) {
          if (isArray) recordType = recordTypes[idx] || SC.Record;
          id = ids ? ids[idx] : undefined;
          this.unloadRecord(recordType, id, undefined, newStatus);
        }
      }
    } else {
      len = storeKeys.length;
      for (idx = 0; idx < len; idx++) {
        storeKey = storeKeys ? storeKeys[idx] : undefined;
        this.unloadRecord(undefined, undefined, storeKey, newStatus);
      }
    }

    return this;
  },

  /**
    Destroys a record, removing the data hash from the store and adding the
    record to the destroyed changelog.  If you try to destroy a record that is
    already destroyed then this method will have no effect.  If you destroy a
    record that does not exist or an error then an exception will be raised.

    @param {SC.Record} recordType the recordType
    @param {String} id the record id
    @param {Number} storeKey (optional) if passed, ignores recordType and id
    @returns {SC.Store} receiver
  */
  destroyRecord: function(recordType, id, storeKey) {
    if (storeKey === undefined) storeKey = recordType.storeKeyFor(id);
    var status = this.readStatus(storeKey), changelog, K = SC.Record;

    // handle status - ignore if destroying or destroyed
    if ((status === K.BUSY_DESTROYING) || (status & K.DESTROYED)) {
      return this; // nothing to do

    // error out if empty
    } else if (status === K.EMPTY) {
      K.NOT_FOUND_ERROR.throw();

    // error out if busy
    } else if (status & K.BUSY) {
      K.BUSY_ERROR.throw();

    // if new status, destroy in clean state
    } else if (status === K.READY_NEW) {
      status = K.DESTROYED_CLEAN ;
      this.removeDataHash(storeKey, status) ;

    // otherwise, destroy in dirty state
    } else status = K.DESTROYED_DIRTY ;

    // remove the data hash, set new status
    this.writeStatus(storeKey, status);
    this.dataHashDidChange(storeKey);

    // add/remove change log
    changelog = this.changelog;
    if (!changelog) changelog = this.changelog = SC.Set.create();

    if (status & K.DIRTY) { changelog.add(storeKey); }
    else { changelog.remove(storeKey); }
    this.changelog=changelog;

    // if commit records is enabled
    if(this.get('commitRecordsAutomatically')){
      this.invokeLast(this.commitRecords);
    }

    var that = this;
    this._propagateToChildren(storeKey, function(storeKey){
      that.destroyRecord(null, null, storeKey);
    });

    return this ;
  },

  /**
    Destroys a group of records.  If you have a set of record ids, destroying
    them this way can be faster than retrieving each record and destroying
    it individually.

    You can pass either a single `recordType` or an array of `recordType`s. If
    you pass a single `recordType`, then the record type will be used for each
    record.  If you pass an array, then each id must have a matching record
    type in the array.

    You can optionally pass an array of `storeKey`s instead of the `recordType`
    and ids.  In this case the first two parameters will be ignored.  This
    is usually only used by low-level internal methods.  You will not usually
    destroy records this way.

    @param {SC.Record|Array} recordTypes class or array of classes
    @param {Array} ids ids to destroy
    @param {Array} storeKeys (optional) store keys to destroy
    @returns {SC.Store} receiver
  */
  destroyRecords: function(recordTypes, ids, storeKeys) {
    var len, isArray, idx, id, recordType, storeKey;
    if(storeKeys===undefined){
      len = ids.length;
      isArray = SC.typeOf(recordTypes) === SC.T_ARRAY;
      if (!isArray) recordType = recordTypes;
      for(idx=0;idx<len;idx++) {
        if (isArray) recordType = recordTypes[idx] || SC.Record;
        id = ids ? ids[idx] : undefined ;
        this.destroyRecord(recordType, id, undefined);
      }
    }else{
      len = storeKeys.length;
      for(idx=0;idx<len;idx++) {
        storeKey = storeKeys ? storeKeys[idx] : undefined ;
        this.destroyRecord(undefined, undefined, storeKey);
      }
    }
    return this ;
  },

  /**
    register a Child Record to the parent
  */
  registerChildToParent: function(parentStoreKey, childStoreKey, path){
    var parentRecords, childRecords, oldPk, oldChildren, pkRef;

    // Check the child to see if it has a parent
    childRecords = this.childRecords || {};
    parentRecords = this.parentRecords || {};

    // first rid of the old parent
    oldPk = childRecords[childStoreKey];
    if (oldPk){
      oldChildren = parentRecords[oldPk];
      delete oldChildren[childStoreKey];
      // this.recordDidChange(null, null, oldPk, key);
    }
    pkRef = parentRecords[parentStoreKey] || {};
    pkRef[childStoreKey] = path || YES;
    parentRecords[parentStoreKey] = pkRef;
    childRecords[childStoreKey] = parentStoreKey;

    // sync the status of the child
    this.writeStatus(childStoreKey, this.statuses[parentStoreKey]);
    this.childRecords = childRecords;
    this.parentRecords = parentRecords;
  },

  /**
    Unregister the Child Record from its Parent.  This will cause the Child
    Record to be removed from the store.

    @param {Number} childStoreKey storeKey to unregister
  */
  unregisterChildFromParent: function(childStoreKey) {
    var childRecords, oldPk, storeKeys,
        recordType = this.recordTypeFor(childStoreKey),
        id = this.idFor(childStoreKey),
        that = this;

    // Check the child to see if it has a parent
    childRecords = this.childRecords;

    // Remove the child.
    // 1. from the cache of data hashes
    // 2. from the cache of record objects
    // 3. from the cache of child record store keys
    this.removeDataHash(childStoreKey);
    if (this.records) {
      delete this.records[childStoreKey];
    }

    if (childRecords) {
      // Remove the parent's connection to the child.  This doesn't remove the
      // parent store key from the cache of parent store keys if the parent
      // no longer has any other registered children, because the amount of effort
      // to determine that would not be worth the miniscule memory savings.
      oldPk = childRecords[childStoreKey];
      if (oldPk) {
        delete this.parentRecords[oldPk][childStoreKey];
      }

      delete childRecords[childStoreKey];
    }

    // 4. from the cache of ids
    // 5. from the cache of store keys
    delete SC.Store.idsByStoreKey[childStoreKey];
    storeKeys = recordType.storeKeysById();
    delete storeKeys[id];

    this._propagateToChildren(childStoreKey, function(storeKey) {
      that.unregisterChildFromParent(storeKey);
    });
  },

  /**
    materialize the parent when passing in a store key for the child
  */
  materializeParentRecord: function(childStoreKey){
    var pk, crs;
    if (SC.none(childStoreKey)) return null;
    crs = this.childRecords;
    pk = crs ? this.childRecords[childStoreKey] : null ;
    if (SC.none(pk)) return null;

    return this.materializeRecord(pk);
  },

  /**
    function for retrieving a parent record key

    @param {Number} storeKey The store key of the parent
  */
  parentStoreKeyExists: function(storeKey){
    if (SC.none(storeKey)) return ;
    var crs = this.childRecords || {};
    return crs[storeKey];
  },

  /**
    function that propagates a function call to all children
  */
  _propagateToChildren: function(storeKey, func){
    // Handle all the child Records
    if ( SC.none(this.parentRecords) ) return;
    var children = this.parentRecords[storeKey] || {};
    if (SC.none(func)) return;
    for (var key in children) {
      // for .. in makes the key a String, but be sure to pass a Number to the
      // function.
      if (children.hasOwnProperty(key)) func(parseInt(key, 10));
    }
  },

  /**
    Notes that the data for the given record id has changed.  The record will
    be committed to the server the next time you commit the root store.  Only
    call this method on a record in a READY state of some type.

    @param {SC.Record} recordType the recordType
    @param {String} id the record id
    @param {Number} storeKey (optional) if passed, ignores recordType and id
    @param {String} key that changed (optional)
    @param {Boolean} if the change is to statusOnly (optional)
    @returns {SC.Store} receiver
  */
  recordDidChange: function(recordType, id, storeKey, key, statusOnly) {
    if (storeKey === undefined) storeKey = recordType.storeKeyFor(id);
    var status = this.readStatus(storeKey), changelog, K = SC.Record;

    // BUSY_LOADING, BUSY_CREATING, BUSY_COMMITTING, BUSY_REFRESH_CLEAN
    // BUSY_REFRESH_DIRTY, BUSY_DESTROYING
    if (status & K.BUSY) {
      K.BUSY_ERROR.throw();

    // if record is not in ready state, then it is not found.
    // ERROR, EMPTY, DESTROYED_CLEAN, DESTROYED_DIRTY
    } else if (!(status & K.READY)) {
      K.NOT_FOUND_ERROR.throw();

    // otherwise, make new status READY_DIRTY unless new.
    // K.READY_CLEAN, K.READY_DIRTY, ignore K.READY_NEW
    } else {
      if (status !== K.READY_NEW) this.writeStatus(storeKey, K.READY_DIRTY);
    }

    // record data hash change
    this.dataHashDidChange(storeKey, null, statusOnly, key);

    // record in changelog
    changelog = this.changelog ;
    if (!changelog) changelog = this.changelog = SC.Set.create() ;
    changelog.add(storeKey);
    this.changelog = changelog;

    // if commit records is enabled
    if(this.get('commitRecordsAutomatically')){
      this.invokeLast(this.commitRecords);
    }

    return this ;
  },

  /**
    Mark a group of records as dirty.  The records will be committed to the
    server the next time you commit changes on the root store.  If you have a
    set of record ids, marking them dirty this way can be faster than
    retrieving each record and destroying it individually.

    You can pass either a single `recordType` or an array of `recordType`s. If
    you pass a single `recordType`, then the record type will be used for each
    record.  If you pass an array, then each id must have a matching record
    type in the array.

    You can optionally pass an array of `storeKey`s instead of the `recordType`
    and ids.  In this case the first two parameters will be ignored.  This
    is usually only used by low-level internal methods.

    @param {SC.Record|Array} recordTypes class or array of classes
    @param {Array} ids ids to destroy
    @param {Array} storeKeys (optional) store keys to destroy
    @returns {SC.Store} receiver
  */
  recordsDidChange: function(recordTypes, ids, storeKeys) {
     var len, isArray, idx, id, recordType, storeKey;
      if(storeKeys===undefined){
        len = ids.length;
        isArray = SC.typeOf(recordTypes) === SC.T_ARRAY;
        if (!isArray) recordType = recordTypes;
        for(idx=0;idx<len;idx++) {
          if (isArray) recordType = recordTypes[idx] || SC.Record;
          id = ids ? ids[idx] : undefined ;
          storeKey = storeKeys ? storeKeys[idx] : undefined ;
          this.recordDidChange(recordType, id, storeKey);
        }
      }else{
        len = storeKeys.length;
        for(idx=0;idx<len;idx++) {
          storeKey = storeKeys ? storeKeys[idx] : undefined ;
          this.recordDidChange(undefined, undefined, storeKey);
        }
      }
      return this ;
  },

  /**
    Retrieves a set of records from the server.  If the records has
    already been loaded in the store, then this method will simply return.
    Otherwise if your store has a `dataSource`, this will call the
    `dataSource` to retrieve the record.  Generally you will not need to
    call this method yourself. Instead you can just use `find()`.

    This will not actually create a record instance but it will initiate a
    load of the record from the server.  You can subsequently get a record
    instance itself using `materializeRecord()`.

    @param {SC.Record|Array} recordTypes class or array of classes
    @param {Array} ids ids to retrieve
    @param {Array} storeKeys (optional) store keys to retrieve
    @param {Boolean} isRefresh
    @param {Function|Array} callback function or array of functions
    @returns {Array} storeKeys to be retrieved
  */
  retrieveRecords: function(recordTypes, ids, storeKeys, isRefresh, callbacks) {

    var source  = this._getDataSource(),
        isArray = SC.typeOf(recordTypes) === SC.T_ARRAY,
        hasCallbackArray = SC.typeOf(callbacks) === SC.T_ARRAY,
        len     = (!storeKeys) ? ids.length : storeKeys.length,
        ret     = [],
        rev     = SC.Store.generateStoreKey(),
        K       = SC.Record,
        recordType, idx, storeKey, status, ok, callback;

    if (!isArray) recordType = recordTypes;

    // if no storeKeys were passed, map recordTypes + ids
    for(idx=0;idx<len;idx++) {

      // collect store key
      if (storeKeys) {
        storeKey = storeKeys[idx];
      } else {
        if (isArray) recordType = recordTypes[idx];
        storeKey = recordType.storeKeyFor(ids[idx]);
      }
      //collect the callback
      callback = hasCallbackArray ? callbacks[idx] : callbacks;

      // collect status and process
      status = this.readStatus(storeKey);

      // K.EMPTY, K.ERROR, K.DESTROYED_CLEAN - initial retrieval
      if ((status === K.EMPTY) || (status === K.ERROR) || (status === K.DESTROYED_CLEAN)) {
        this.writeStatus(storeKey, K.BUSY_LOADING);
        this.dataHashDidChange(storeKey, rev, YES);
        ret.push(storeKey);
        this._setCallbackForStoreKey(storeKey, callback, hasCallbackArray, storeKeys);
      // otherwise, ignore record unless isRefresh is YES.
      } else if (isRefresh) {
        // K.READY_CLEAN, K.READY_DIRTY, ignore K.READY_NEW
        if (status & K.READY) {
          this.writeStatus(storeKey, K.BUSY_REFRESH | (status & 0x03)) ;
          this.dataHashDidChange(storeKey, rev, YES);
          ret.push(storeKey);
          this._setCallbackForStoreKey(storeKey, callback, hasCallbackArray, storeKeys);
        // K.BUSY_DESTROYING, K.BUSY_COMMITTING, K.BUSY_CREATING
        } else if ((status === K.BUSY_DESTROYING) || (status === K.BUSY_CREATING) || (status === K.BUSY_COMMITTING)) {
          K.BUSY_ERROR.throw();

        // K.DESTROY_DIRTY, bad state...
        } else if (status === K.DESTROYED_DIRTY) {
          K.BAD_STATE_ERROR.throw();

        // ignore K.BUSY_LOADING, K.BUSY_REFRESH_CLEAN, K.BUSY_REFRESH_DIRTY
        }
      }
    }

    // now retrieve storeKeys from dataSource.  if there is no dataSource,
    // then act as if we couldn't retrieve.
    ok = NO;
    if (source) ok = source.retrieveRecords.call(source, this, ret, ids);

    // if the data source could not retrieve or if there is no source, then
    // simulate the data source calling dataSourceDidError on those we are
    // loading for the first time or dataSourceDidComplete on refreshes.
    if (!ok) {
      len = ret.length;
      rev = SC.Store.generateStoreKey();
      for(idx=0;idx<len;idx++) {
        storeKey = ret[idx];
        status   = this.readStatus(storeKey);
        if (status === K.BUSY_LOADING) {
          this.writeStatus(storeKey, K.ERROR);
          this.dataHashDidChange(storeKey, rev, YES);

        } else if (status & K.BUSY_REFRESH) {
          this.writeStatus(storeKey, K.READY | (status & 0x03));
          this.dataHashDidChange(storeKey, rev, YES);
        }
      }
      ret.length = 0 ; // truncate to indicate that none could refresh
    }
    return ret ;
  },

  _TMP_RETRIEVE_ARRAY: [],

  _callback_queue: {},

  /**
    @private
    stores the callbacks for the storeKeys that are inflight
  **/
  _setCallbackForStoreKey: function(storeKey, callback, hasCallbackArray, storeKeys){
    var queue = this._callback_queue;
    if(hasCallbackArray) queue[storeKey] = {callback: callback, otherKeys: storeKeys};
    else queue[storeKey] = callback;
  },

  /**
    @private
    Retrieves and calls callback for `storeKey` if exists, also handles if a single callback is
    needed for one key..
  **/
  _retrieveCallbackForStoreKey: function(storeKey){
    var queue = this._callback_queue,
        callback = queue[storeKey],
        allFinished, keys;
    if(callback){
      if(SC.typeOf(callback) === SC.T_FUNCTION){
        callback.call(); //args?
        delete queue[storeKey]; //cleanup
      }
      else if(SC.typeOf(callback) === SC.T_HASH){
        callback.completed = YES;
        keys = callback.storeKeys;
        keys.forEach(function(key){
          if(!queue[key].completed) allFinished = YES;
        });
        if(allFinished){
          callback.callback.call(); // args?
          //cleanup
          keys.forEach(function(key){
            delete queue[key];
          });
        }

      }
    }
  },

  /*
    @private

  */
  _cancelCallback: function(storeKey){
    var queue = this._callback_queue;
    if(queue[storeKey]){
      delete queue[storeKey];
    }
  },


  /**
    Retrieves a record from the server.  If the record has already been loaded
    in the store, then this method will simply return.  Otherwise if your
    store has a `dataSource`, this will call the `dataSource` to retrieve the
    record.  Generally you will not need to call this method yourself.
    Instead you can just use `find()`.

    This will not actually create a record instance but it will initiate a
    load of the record from the server.  You can subsequently get a record
    instance itself using `materializeRecord()`.

    @param {SC.Record} recordType class
    @param {String} id id to retrieve
    @param {Number} storeKey (optional) store key
    @param {Boolean} isRefresh
    @param {Function} callback (optional)
    @returns {Number} storeKey that was retrieved
  */
  retrieveRecord: function(recordType, id, storeKey, isRefresh, callback) {
    var array = this._TMP_RETRIEVE_ARRAY,
        ret;

    if (storeKey) {
      array[0] = storeKey;
      storeKey = array;
      id = null ;
    } else {
      array[0] = id;
      id = array;
    }

    ret = this.retrieveRecords(recordType, id, storeKey, isRefresh, callback);
    array.length = 0 ;
    return ret[0];
  },

  /**
    Refreshes a record from the server.  If the record has already been loaded
    in the store, then this method will request a refresh from the
    `dataSource`. Otherwise it will attempt to retrieve the record.

    @param {SC.Record} recordType the expected record type
    @param {String} id to id of the record to load
    @param {Number} storeKey (optional) optional store key
    @param {Function} callback (optional) when refresh completes
    @returns {Boolean} YES if the retrieval was a success.
  */
  refreshRecord: function(recordType, id, storeKey, callback) {
    return !!this.retrieveRecord(recordType, id, storeKey, YES, callback);
  },

  /**
    Refreshes a set of records from the server.  If the records has already been loaded
    in the store, then this method will request a refresh from the
    `dataSource`. Otherwise it will attempt to retrieve them.

    @param {SC.Record|Array} recordTypes class or array of classes
    @param {Array} ids ids to destroy
    @param {Array} storeKeys (optional) store keys to destroy
    @param {Function} callback (optional) when refresh completes
    @returns {Boolean} YES if the retrieval was a success.
  */
  refreshRecords: function(recordTypes, ids, storeKeys, callback) {
    var ret = this.retrieveRecords(recordTypes, ids, storeKeys, YES, callback);
    return ret && ret.length>0;
  },

  /**
    Commits the passed store keys or ids. If no `storeKey`s are given,
    it will commit any records in the changelog.

    Based on the current state of the record, this will ask the data
    source to perform the appropriate actions
    on the store keys.

    @param {Array} recordTypes the expected record types (SC.Record)
    @param {Array} ids to commit
    @param {SC.Set} storeKeys to commit
    @param {Hash} params optional additional parameters to pass along to the
      data source
    @param {Function|Array} callback function or array of callbacks

    @returns {Boolean} if the action was succesful.
  */
  commitRecords: function(recordTypes, ids, storeKeys, params, callbacks) {
    var source    = this._getDataSource(),
        isArray   = SC.typeOf(recordTypes) === SC.T_ARRAY,
        hasCallbackArray = SC.typeOf(callbacks) === SC.T_ARRAY,
        retCreate= [], retUpdate= [], retDestroy = [],
        rev       = SC.Store.generateStoreKey(),
        K         = SC.Record,
        recordType, idx, storeKey, status, ret, len, callback;

    // If no params are passed, look up storeKeys in the changelog property.
    // Remove any committed records from changelog property.

    if(!recordTypes && !ids && !storeKeys){
      storeKeys = this.changelog;
    }

    len = storeKeys ? storeKeys.get('length') : (ids ? ids.get('length') : 0);

    for(idx=0;idx<len;idx++) {

      // collect store key
      if (storeKeys) {
        storeKey = storeKeys[idx];
      } else {
        if (isArray) recordType = recordTypes[idx] || SC.Record;
        else recordType = recordTypes;
        storeKey = recordType.storeKeyFor(ids[idx]);
      }

      //collect the callback
      callback = hasCallbackArray ? callbacks[idx] : callbacks;

      // collect status and process
      status = this.readStatus(storeKey);

      if (status === K.ERROR) {
        K.NOT_FOUND_ERROR.throw();
      }
      else {
        if(status === K.READY_NEW) {
          this.writeStatus(storeKey, K.BUSY_CREATING);
          this.dataHashDidChange(storeKey, rev, YES);
          retCreate.push(storeKey);
          this._setCallbackForStoreKey(storeKey, callback, hasCallbackArray, storeKeys);
        } else if (status === K.READY_DIRTY) {
          this.writeStatus(storeKey, K.BUSY_COMMITTING);
          this.dataHashDidChange(storeKey, rev, YES);
          retUpdate.push(storeKey);
          this._setCallbackForStoreKey(storeKey, callback, hasCallbackArray, storeKeys);
        } else if (status === K.DESTROYED_DIRTY) {
          this.writeStatus(storeKey, K.BUSY_DESTROYING);
          this.dataHashDidChange(storeKey, rev, YES);
          retDestroy.push(storeKey);
          this._setCallbackForStoreKey(storeKey, callback, hasCallbackArray, storeKeys);
        } else if (status === K.DESTROYED_CLEAN) {
          this.dataHashDidChange(storeKey, rev, YES);
        }
        // ignore K.EMPTY, K.READY_CLEAN, K.BUSY_LOADING, K.BUSY_CREATING, K.BUSY_COMMITTING,
        // K.BUSY_REFRESH_CLEAN, K_BUSY_REFRESH_DIRTY, KBUSY_DESTROYING
      }
    }

    // now commit storeKeys to dataSource
    if (source && (len>0 || params)) {
      ret = source.commitRecords.call(source, this, retCreate, retUpdate, retDestroy, params);
    }

    //remove all committed changes from changelog
    if (ret && !recordTypes && !ids) {
      if (storeKeys === this.changelog) {
        this.changelog = null;
      }
      else {
        this.changelog.removeEach(storeKeys);
      }
    }
    return ret ;
  },

  /**
    Commits the passed store key or id.  Based on the current state of the
    record, this will ask the data source to perform the appropriate action
    on the store key.

    You have to pass either the id or the storeKey otherwise it will return
    NO.

    @param {SC.Record} recordType the expected record type
    @param {String} id the id of the record to commit
    @param {Number} storeKey the storeKey of the record to commit
    @param {Hash} params optional additional params that will passed down
      to the data source
    @param {Function|Array} callback function or array of functions
    @returns {Boolean} if the action was successful.
  */
  commitRecord: function(recordType, id, storeKey, params, callback) {
    var array = this._TMP_RETRIEVE_ARRAY,
        ret ;
    if (id === undefined && storeKey === undefined ) return NO;
    if (storeKey !== undefined) {
      array[0] = storeKey;
      storeKey = array;
      id = null ;
    } else {
      array[0] = id;
      id = array;
    }

    ret = this.commitRecords(recordType, id, storeKey, params, callback);
    array.length = 0 ;
    return ret;
  },

  /**
    Cancels an inflight request for the passed records.  Depending on the
    server implementation, this could cancel an entire request, causing
    other records to also transition their current state.

    @param {SC.Record|Array} recordTypes class or array of classes
    @param {Array} ids ids to destroy
    @param {Array} storeKeys (optional) store keys to destroy
    @returns {SC.Store} the store.
  */
  cancelRecords: function(recordTypes, ids, storeKeys) {
    var source  = this._getDataSource(),
        isArray = SC.typeOf(recordTypes) === SC.T_ARRAY,
        K       = SC.Record,
        ret     = [],
        status, len, idx, id, recordType, storeKey;

    len = (storeKeys === undefined) ? ids.length : storeKeys.length;
    for(idx=0;idx<len;idx++) {
      if (isArray) recordType = recordTypes[idx] || SC.Record;
      else recordType = recordTypes || SC.Record;

      id = ids ? ids[idx] : undefined ;

      if(storeKeys===undefined){
        storeKey = recordType.storeKeyFor(id);
      }else{
        storeKey = storeKeys ? storeKeys[idx] : undefined ;
      }
      if(storeKey) {
        status = this.readStatus(storeKey);

        if ((status === K.EMPTY) || (status === K.ERROR)) {
          K.NOT_FOUND_ERROR.throw();
        }
        ret.push(storeKey);
        this._cancelCallback(storeKey);
      }
    }

    if (source) source.cancel.call(source, this, ret);

    return this ;
  },

  /**
    Cancels an inflight request for the passed record.  Depending on the
    server implementation, this could cancel an entire request, causing
    other records to also transition their current state.

    @param {SC.Record|Array} recordTypes class or array of classes
    @param {Array} ids ids to destroy
    @param {Array} storeKeys (optional) store keys to destroy
    @returns {SC.Store} the store.
  */
  cancelRecord: function(recordType, id, storeKey) {
    var array = this._TMP_RETRIEVE_ARRAY,
        ret ;

    if (storeKey !== undefined) {
      array[0] = storeKey;
      storeKey = array;
      id = null ;
    } else {
      array[0] = id;
      id = array;
    }

    ret = this.cancelRecords(recordType, id, storeKey);
    array.length = 0 ;
    return this;
  },

  /**
    Convenience method can be called by the store or other parts of your
    application to load a record into the store.  This method will take a
    recordType and a data hashes and either add or update the
    record in the store.

    The loaded records will be in an `SC.Record.READY_CLEAN` state, indicating
    they were loaded from the data source and do not need to be committed
    back before changing.

    This method will check the state of the storeKey and call either
    `pushRetrieve()` or `dataSourceDidComplete()`.  The standard state constraints
    for these methods apply here.

    The return value will be the `storeKey` used for the push.  This is often
    convenient to pass into `loadQuery()`, if you are fetching a remote query.

    If you are upgrading from a pre SproutCore 1.0 application, this method
    is the closest to the old `updateRecord()`.

    @param {SC.Record} recordType the record type
    @param {Array} dataHash to update
    @param {Array} id optional.  if not passed lookup on the hash
    @returns {String} store keys assigned to these id
  */
  loadRecord: function(recordType, dataHash, id) {
    var K       = SC.Record,
        ret, primaryKey, storeKey;

    // save lookup info
    recordType = recordType || SC.Record;
    primaryKey = recordType.prototype.primaryKey;


    // push each record
    id = id || dataHash[primaryKey];
    ret = storeKey = recordType.storeKeyFor(id); // needed to cache

    if (this.readStatus(storeKey) & K.BUSY) {
      this.dataSourceDidComplete(storeKey, dataHash, id);
    } else this.pushRetrieve(recordType, id, dataHash, storeKey);

    // return storeKey
    return ret ;
  },

  /**
    Convenience method can be called by the store or other parts of your
    application to load records into the store.  This method will take a
    recordType and an array of data hashes and either add or update the
    record in the store.

    The loaded records will be in an `SC.Record.READY_CLEAN` state, indicating
    they were loaded from the data source and do not need to be committed
    back before changing.

    This method will check the state of each storeKey and call either
    `pushRetrieve()` or `dataSourceDidComplete()`.  The standard state
    constraints for these methods apply here.

    The return value will be the storeKeys used for each push.  This is often
    convenient to pass into `loadQuery()`, if you are fetching a remote query.

    If you are upgrading from a pre SproutCore 1.0 application, this method
    is the closest to the old `updateRecords()`.

    @param {SC.Record} recordTypes the record type or array of record types
    @param {Array} dataHashes array of data hashes to update
    @param {Array} [ids] array of ids.  if not passed lookup on hashes
    @returns {Array} store keys assigned to these ids
  */
  // TODO: No reason for first argument to be an array. The developer can just call loadRecords multiple times with different record type each time. Would save us the need to check if recordTypes is an Array or not.
  loadRecords: function (recordTypes, dataHashes, ids) {
    var isArray = SC.typeOf(recordTypes) === SC.T_ARRAY,
        len     = dataHashes.get('length'),
        ret     = [],
        recordType,
        id, primaryKey, idx, dataHash;

    // save lookup info
    if (!isArray) {
      recordType = recordTypes || SC.Record;
      primaryKey = recordType.prototype.primaryKey;
    }

    // push each record
    for (idx = 0; idx < len; idx++) {
      dataHash = dataHashes.objectAt(idx);
      if (isArray) {
        recordType = recordTypes.objectAt(idx) || SC.Record;
        primaryKey = recordType.prototype.primaryKey ;
      }

      id = (ids) ? ids.objectAt(idx) : dataHash[primaryKey];

      ret[idx] = this.loadRecord(recordType, dataHash, id);
    }

    // return storeKeys
    return ret;
  },

  /**
    Returns the `SC.Error` object associated with a specific record.

    @param {Number} storeKey The store key of the record.

    @returns {SC.Error} SC.Error or undefined if no error associated with the record.
  */
  readError: function(storeKey) {
    var errors = this.recordErrors ;
    return errors ? errors[storeKey] : undefined ;
  },

  /**
    Returns the `SC.Error` object associated with a specific query.

    @param {SC.Query} query The SC.Query with which the error is associated.

    @returns {SC.Error} SC.Error or undefined if no error associated with the query.
  */
  readQueryError: function(query) {
    var errors = this.queryErrors ;
    return errors ? errors[SC.guidFor(query)] : undefined ;
  },

  // ..........................................................
  // DATA SOURCE CALLBACKS
  //
  // Mathods called by the data source on the store

  /**
    Called by a `dataSource` when it cancels an inflight operation on a
    record.  This will transition the record back to it non-inflight state.

    @param {Number} storeKey record store key to cancel
    @returns {SC.Store} receiver
  */
  dataSourceDidCancel: function(storeKey) {
    var status = this.readStatus(storeKey),
        K      = SC.Record;

    // EMPTY, ERROR, READY_CLEAN, READY_NEW, READY_DIRTY, DESTROYED_CLEAN,
    // DESTROYED_DIRTY
    if (!(status & K.BUSY)) {
      K.BAD_STATE_ERROR.throw(); // should never be called in this state
    }

    // otherwise, determine proper state transition
    switch(status) {
      case K.BUSY_LOADING:
        status = K.EMPTY;
        break ;

      case K.BUSY_CREATING:
        status = K.READY_NEW;
        break;

      case K.BUSY_COMMITTING:
        status = K.READY_DIRTY ;
        break;

      case K.BUSY_REFRESH_CLEAN:
        status = K.READY_CLEAN;
        break;

      case K.BUSY_REFRESH_DIRTY:
        status = K.READY_DIRTY ;
        break ;

      case K.BUSY_DESTROYING:
        status = K.DESTROYED_DIRTY ;
        break;

      default:
        K.BAD_STATE_ERROR.throw() ;
    }
    this.writeStatus(storeKey, status) ;
    this.dataHashDidChange(storeKey, null, YES);
    this._cancelCallback(storeKey);

    return this ;
  },

  /**
    Called by a data source when it creates or commits a record.  Passing an
    optional id will remap the `storeKey` to the new record id.  This is
    required when you commit a record that does not have an id yet.

    @param {Number} storeKey record store key to change to READY_CLEAN state
    @param {Hash} dataHash optional data hash to replace current hash
    @param {Object} newId optional new id to replace the old one
    @returns {SC.Store} receiver
  */
  dataSourceDidComplete: function(storeKey, dataHash, newId) {
    var status = this.readStatus(storeKey), K = SC.Record, statusOnly;

    // EMPTY, ERROR, READY_CLEAN, READY_NEW, READY_DIRTY, DESTROYED_CLEAN,
    // DESTROYED_DIRTY
    if (!(status & K.BUSY)) {
      K.BAD_STATE_ERROR.throw(); // should never be called in this state
    }

    // otherwise, determine proper state transition
    if(status === K.BUSY_DESTROYING) {
      K.BAD_STATE_ERROR.throw();
    } else status = K.READY_CLEAN;

    this.writeStatus(storeKey, status);
    if (dataHash) this.writeDataHash(storeKey, dataHash, status);
    if (newId) { SC.Store.replaceIdFor(storeKey, newId); }

    statusOnly = dataHash || newId ? NO : YES;
    this.dataHashDidChange(storeKey, null, statusOnly);

    // Force record to refresh its cached properties based on store key
    var record = this.materializeRecord(storeKey);
    if (record !== null) {
      // If the record's id property has been computed, ensure that it re-computes.
      if (newId) { record.propertyDidChange('id'); }
      record.notifyPropertyChange('status');
    }
    //update callbacks
    this._retrieveCallbackForStoreKey(storeKey);

    return this ;
  },

  /**
    Called by a data source when it has destroyed a record.  This will
    transition the record to the proper state.

    @param {Number} storeKey record store key to cancel
    @returns {SC.Store} receiver
  */
  dataSourceDidDestroy: function(storeKey) {
    var status = this.readStatus(storeKey), K = SC.Record;

    // EMPTY, ERROR, READY_CLEAN, READY_NEW, READY_DIRTY, DESTROYED_CLEAN,
    // DESTROYED_DIRTY
    if (!(status & K.BUSY)) {
      K.BAD_STATE_ERROR.throw(); // should never be called in this state
    }
    // otherwise, determine proper state transition
    else{
      status = K.DESTROYED_CLEAN ;
    }
    this.removeDataHash(storeKey, status) ;
    this.dataHashDidChange(storeKey);

    // Force record to refresh its cached properties based on store key
    var record = this.materializeRecord(storeKey);
    if (record !== null) {
      record.notifyPropertyChange('status');
    }

    this._retrieveCallbackForStoreKey(storeKey);

    return this ;
  },

  /**
    Converts the passed record into an error object.

    @param {Number} storeKey record store key to error
    @param {SC.Error} error [optional] an SC.Error instance to associate with storeKey
    @returns {SC.Store} receiver
  */
  dataSourceDidError: function(storeKey, error) {
    var status = this.readStatus(storeKey), errors = this.recordErrors, K = SC.Record;

    // EMPTY, ERROR, READY_CLEAN, READY_NEW, READY_DIRTY, DESTROYED_CLEAN,
    // DESTROYED_DIRTY
    if (!(status & K.BUSY)) { K.BAD_STATE_ERROR.throw(); }

    // otherwise, determine proper state transition
    else status = K.ERROR ;

    // Add the error to the array of record errors (for lookup later on if necessary).
    if (error && error.isError) {
      if (!errors) errors = this.recordErrors = [];
      errors[storeKey] = error;
    }

    this.writeStatus(storeKey, status) ;
    this.dataHashDidChange(storeKey, null, YES);

    // Force record to refresh its cached properties based on store key
    var record = this.materializeRecord(storeKey);
    if (record) {
      record.notifyPropertyChange('status');
    }

    this._retrieveCallbackForStoreKey(storeKey);
    return this ;
  },

  // ..........................................................
  // PUSH CHANGES FROM DATA SOURCE
  //

  /**
    Call by the data source whenever you want to push new data out of band
    into the store.

    @param {Class} recordType the SC.Record subclass
    @param {Object} id the record id or null
    @param {Hash} dataHash data hash to load
    @param {Number} storeKey optional store key.
    @returns {Number|Boolean} storeKey if push was allowed, NO if not
  */
  pushRetrieve: function(recordType, id, dataHash, storeKey) {
    var K = SC.Record, status;

    if(storeKey===undefined) storeKey = recordType.storeKeyFor(id);
    status = this.readStatus(storeKey);
    if(status === K.EMPTY || status === K.ERROR || status === K.READY_CLEAN || status === K.DESTROYED_CLEAN) {

      status = K.READY_CLEAN;
      if(dataHash === undefined) this.writeStatus(storeKey, status) ;
      else this.writeDataHash(storeKey, dataHash, status) ;

      if (id && this.idFor(storeKey) !== id) {
        SC.Store.replaceIdFor(storeKey, id);

        // If the record's id property has been computed, ensure that it re-computes.
        var record = this.materializeRecord(storeKey);
        record.propertyDidChange('id');
      }
      this.dataHashDidChange(storeKey);

      return storeKey;
    }
    //conflicted (ready)
    return NO;
  },

  /**
    Call by the data source whenever you want to push a deletion into the
    store.

    @param {Class} recordType the SC.Record subclass
    @param {Object} id the record id or null
    @param {Number} storeKey optional store key.
    @returns {Number|Boolean} storeKey if push was allowed, NO if not
  */
  pushDestroy: function(recordType, id, storeKey) {
    var K = SC.Record, status;

    if(storeKey===undefined){
      storeKey = recordType.storeKeyFor(id);
    }
    status = this.readStatus(storeKey);
    if(status === K.EMPTY || status === K.ERROR || status === K.READY_CLEAN || status === K.DESTROYED_CLEAN){
      status = K.DESTROYED_CLEAN;
      this.removeDataHash(storeKey, status) ;
      this.dataHashDidChange(storeKey);
      return storeKey;
    }
    //conflicted (destroy)
    return NO;
  },

  /**
    Call by the data source whenever you want to push an error into the
    store.

    @param {Class} recordType the SC.Record subclass
    @param {Object} id the record id or null
    @param {SC.Error} error [optional] an SC.Error instance to associate with id or storeKey
    @param {Number} storeKey optional store key.
    @returns {Number|Boolean} storeKey if push was allowed, NO if not
  */
  pushError: function(recordType, id, error, storeKey) {
    var K = SC.Record, status, errors = this.recordErrors;

    if(storeKey===undefined) storeKey = recordType.storeKeyFor(id);
    status = this.readStatus(storeKey);

    if(status === K.EMPTY || status === K.ERROR || status === K.READY_CLEAN || status === K.DESTROYED_CLEAN){
      status = K.ERROR;

      // Add the error to the array of record errors (for lookup later on if necessary).
      if (error && error.isError) {
        if (!errors) errors = this.recordErrors = [];
        errors[storeKey] = error;
      }

      this.writeStatus(storeKey, status) ;
      this.dataHashDidChange(storeKey, null, YES);
      return storeKey;
    }
    //conflicted (error)
    return NO;
  },

  // ..........................................................
  // FETCH CALLBACKS
  //

  // **NOTE**: although these method works on RecordArray instances right now.
  // They could be optimized to actually share query results between nested
  // stores.  This is why these methods are implemented here instead of
  // directly on `Query` or `RecordArray` objects.

  /** @deprecated

    @param {SC.Query} query the query you are loading.  must be remote.
    @param {SC.Array} storeKeys array of store keys
    @returns {SC.Store} receiver
  */
  loadQueryResults: function(query, storeKeys) {
    


    return this.dataSourceDidFetchQuery(query, storeKeys);
  },

  /**
    Called by your data source whenever you finish fetching the results of a
    query.  This will put the record array for the query into a READY_CLEAN
    state if it was previously loading or refreshing.

    # Handling REMOTE queries

    Note that if the query is REMOTE, then you must first load the results
    into the store using `loadRecords()` and pass the ordered array of store
    keys returned by `loadRecords()` into this method.

    For example,

        storeKeys = store.loadRecords(MyApp.SomeType, body.contacts);
        store.dataSourceDidFetchQuery(query, storeKeys);

    # Automatic updates

    When you call this method the record array for the query will notify that
    its contents have changed.  If the query is LOCAL then the contents will
    update automatically to include any new records you added to the store.
    If the query is REMOTE the contents will update to be the ordered records
    for the passed in store keys.

    # Incremental loading for REMOTE queries

    If you want to support incremental loading, then pass an SC.SparseArray
    object to hold the store keys.  This will allow you to load results
    incrementally and provide more store keys as you do.

    See the SC.SparseArray documentation for more information.

    @param {SC.Query} query The query you fetched
    @param {Array} [storeKeys] Ordered array of store keys as returned by a remote query.  NOTE: Required for remote queries.
    @returns {SC.Store} receiver
  */
  dataSourceDidFetchQuery: function (query, storeKeys) {
    var recArray = this._findQuery(query, YES, NO);

    // Set the ordered array of store keys for remote queries.
    if (recArray && query.get('isRemote')) {
      


      recArray.set('storeKeys', storeKeys);
    }

    return this._scstore_dataSourceDidFetchQuery(query);
  },

  /** @private */
  _scstore_dataSourceDidFetchQuery: function (query) {
    var recArray     = this._findQuery(query, NO, NO),
        nestedStores = this.get('nestedStores'),
        loc          = nestedStores ? nestedStores.get('length') : 0;

    // fix query if needed
    if (recArray) recArray.storeDidFetchQuery(query);

    // notify nested stores
    while(--loc >= 0) {
      nestedStores[loc]._scstore_dataSourceDidFetchQuery(query);
    }

    return this ;
  },

  /**
    Called by your data source if it cancels fetching the results of a query.
    This will put any RecordArray's back into its original state (READY or
    EMPTY).

    @param {SC.Query} query the query you cancelled
    @returns {SC.Store} receiver
  */
  dataSourceDidCancelQuery: function(query) {
    return this._scstore_dataSourceDidCancelQuery(query, YES);
  },

  _scstore_dataSourceDidCancelQuery: function(query, createIfNeeded) {
    var recArray     = this._findQuery(query, createIfNeeded, NO),
        nestedStores = this.get('nestedStores'),
        loc          = nestedStores ? nestedStores.get('length') : 0;

    // fix query if needed
    if (recArray) recArray.storeDidCancelQuery(query);

    // notify nested stores
    while(--loc >= 0) {
      nestedStores[loc]._scstore_dataSourceDidCancelQuery(query, NO);
    }

    return this ;
  },

  /**
    Called by your data source if it encountered an error loading the query.
    This will put the query into an error state until you try to refresh it
    again.

    @param {SC.Query} query the query with the error
    @param {SC.Error} error [optional] an SC.Error instance to associate with query
    @returns {SC.Store} receiver
  */
  dataSourceDidErrorQuery: function(query, error) {
    var errors = this.queryErrors;

    // Add the error to the array of query errors (for lookup later on if necessary).
    if (error && error.isError) {
      if (!errors) errors = this.queryErrors = {};
      errors[SC.guidFor(query)] = error;
    }

    return this._scstore_dataSourceDidErrorQuery(query, YES);
  },

  _scstore_dataSourceDidErrorQuery: function(query, createIfNeeded) {
    var recArray     = this._findQuery(query, createIfNeeded, NO),
        nestedStores = this.get('nestedStores'),
        loc          = nestedStores ? nestedStores.get('length') : 0;

    // fix query if needed
    if (recArray) recArray.storeDidErrorQuery(query);

    // notify nested stores
    while(--loc >= 0) {
      nestedStores[loc]._scstore_dataSourceDidErrorQuery(query, NO);
    }

    return this ;
  },

  // ..........................................................
  // INTERNAL SUPPORT
  //

  /** @private */
  init: function() {
    arguments.callee.base.apply(this,arguments);
    this.reset();
  },


  toString: function() {
    // Include the name if the client has specified one.
    var name = this.get('name');
    if (!name) {
      return arguments.callee.base.apply(this,arguments);
    }
    else {
      var ret = arguments.callee.base.apply(this,arguments);
      return "%@ (%@)".fmt(name, ret);
    }
  },


  // ..........................................................
  // PRIMARY KEY CONVENIENCE METHODS
  //

  /**
    Given a `storeKey`, return the `primaryKey`.

    @param {Number} storeKey the store key
    @returns {String} primaryKey value
  */
  idFor: function(storeKey) {
    return SC.Store.idFor(storeKey);
  },

  /**
    Given a storeKey, return the recordType.

    @param {Number} storeKey the store key
    @returns {SC.Record} record instance
  */
  recordTypeFor: function(storeKey) {
    return SC.Store.recordTypeFor(storeKey) ;
  },

  /**
    Given a `recordType` and `primaryKey`, find the `storeKey`. If the
    `primaryKey` has not been assigned a `storeKey` yet, it will be added.

    @param {SC.Record} recordType the record type
    @param {String} primaryKey the primary key
    @returns {Number} storeKey
  */
  storeKeyFor: function(recordType, primaryKey) {
    return recordType.storeKeyFor(primaryKey);
  },

  /**
    Given a `primaryKey` value for the record, returns the associated
    `storeKey`.  As opposed to `storeKeyFor()` however, this method
    will **NOT** generate a new `storeKey` but returned `undefined`.

    @param {SC.Record} recordType the record type
    @param {String} primaryKey the primary key
    @returns {Number} a storeKey.
  */
  storeKeyExists: function(recordType, primaryKey) {
    return recordType.storeKeyExists(primaryKey);
  },

  /**
    Finds all `storeKey`s of a certain record type in this store
    and returns an array.

    @param {SC.Record} recordType
    @returns {Array} set of storeKeys
  */
  storeKeysFor: function(recordType) {
    var ret = [],
        isEnum = recordType && recordType.isEnumerable,
        recType, storeKey, isMatch ;

    if (!this.statuses) return ret;
    for(storeKey in SC.Store.recordTypesByStoreKey) {
      recType = SC.Store.recordTypesByStoreKey[storeKey];

      // if same record type and this store has it
      if (isEnum) isMatch = recordType.contains(recType);
      else isMatch = recType === recordType;

      if(isMatch && this.statuses[storeKey]) ret.push(parseInt(storeKey, 10));
    }

    return ret;
  },

  /**
    Finds all `storeKey`s in this store
    and returns an array.

    @returns {Array} set of storeKeys
  */
  storeKeys: function() {
    var ret = [], storeKey;
    if(!this.statuses) return ret;

    for(storeKey in this.statuses) {
      // if status is not empty
      if(this.statuses[storeKey] !== SC.Record.EMPTY) {
        ret.push(parseInt(storeKey, 10));
      }
    }

    return ret;
  },

  /**
    Returns string representation of a `storeKey`, with status.

    @param {Number} storeKey
    @returns {String}
  */
  statusString: function(storeKey) {
    var rec = this.materializeRecord(storeKey);
    return rec.statusString();
  }

}) ;

SC.Store.mixin(/** @scope SC.Store.prototype */{

  /**
    Standard error raised if you try to commit changes from a nested store
    and there is a conflict.

    @type Error
  */
  CHAIN_CONFLICT_ERROR: SC.$error("Nested Store Conflict"),

  /**
    Standard error if you try to perform an operation on a nested store
    without a parent.

    @type Error
  */
  NO_PARENT_STORE_ERROR: SC.$error("Parent Store Required"),

  /**
    Standard error if you try to perform an operation on a nested store that
    is only supported in root stores.

    @type Error
  */
  NESTED_STORE_UNSUPPORTED_ERROR: SC.$error("Unsupported In Nested Store"),

  /**
    Standard error if you try to retrieve a record in a nested store that is
    dirty.  (This is allowed on the main store, but not in nested stores.)

    @type Error
  */
  NESTED_STORE_RETRIEVE_DIRTY_ERROR: SC.$error("Cannot Retrieve Dirty Record in Nested Store"),

  /**
    Data hash state indicates the data hash is currently editable

    @type String
  */
  EDITABLE:  'editable',

  /**
    Data hash state indicates the hash no longer tracks changes from a
    parent store, but it is not editable.

    @type String
  */
  LOCKED:    'locked',

  /**
    Data hash state indicates the hash is tracking changes from the parent
    store and is not editable.

    @type String
  */
  INHERITED: 'inherited',

  /** @private
    This array maps all storeKeys to primary keys.  You will not normally
    access this method directly.  Instead use the `idFor()` and
    `storeKeyFor()` methods on `SC.Record`.
  */
  idsByStoreKey: [],

  /** @private
    Maps all `storeKey`s to a `recordType`.  Once a `storeKey` is associated
    with a `primaryKey` and `recordType` that remains constant throughout the
    lifetime of the application.
  */
  recordTypesByStoreKey: {},

  /** @private
    Maps some `storeKeys` to query instance.  Once a `storeKey` is associated
    with a query instance, that remains constant through the lifetime of the
    application.  If a `Query` is destroyed, it will remove itself from this
    list.

    Don't access this directly.  Use queryFor().
  */
  queriesByStoreKey: [],

  /** @private
    The next store key to allocate.  A storeKey must always be greater than 0
  */
  nextStoreKey: 1,

  /**
    Generates a new store key for use.

    @type Number
  */
  generateStoreKey: function() { return this.nextStoreKey++; },

  /**
    Given a `storeKey` returns the `primaryKey` associated with the key.
    If no `primaryKey` is associated with the `storeKey`, returns `null`.

    @param {Number} storeKey the store key
    @returns {String} the primary key or null
  */
  idFor: function(storeKey) {
    return this.idsByStoreKey[storeKey] ;
  },

  /**
    Given a `storeKey`, returns the query object associated with the key.  If
    no query is associated with the `storeKey`, returns `null`.

    @param {Number} storeKey the store key
    @returns {SC.Query} query query object
  */
  queryFor: function(storeKey) {
    return this.queriesByStoreKey[storeKey];
  },

  /**
    Given a `storeKey` returns the `SC.Record` class associated with the key.
    If no record type is associated with the store key, returns `null`.

    The SC.Record class will only be found if you have already called
    storeKeyFor() on the record.

    @param {Number} storeKey the store key
    @returns {SC.Record} the record type
  */
  recordTypeFor: function(storeKey) {
    return this.recordTypesByStoreKey[storeKey];
  },

  /**
    Swaps the `primaryKey` mapped to the given storeKey with the new
    `primaryKey`.  If the `storeKey` is not currently associated with a record
    this will raise an exception.

    @param {Number} storeKey the existing store key
    @param {String} newPrimaryKey the new primary key
    @returns {SC.Store} receiver
  */
  replaceIdFor: function(storeKey, newId) {
    var oldId = this.idsByStoreKey[storeKey],
        recordType, storeKeys;

    if (oldId !== newId) { // skip if id isn't changing

      recordType = this.recordTypeFor(storeKey);
       if (!recordType) {
        throw new Error("replaceIdFor: storeKey %@ does not exist".fmt(storeKey));
      }

      // map one direction...
      this.idsByStoreKey[storeKey] = newId;

      // then the other...
      storeKeys = recordType.storeKeysById() ;
      delete storeKeys[oldId];
      storeKeys[newId] = storeKey;
    }

    return this ;
  },

  /**
    Swaps the `recordType` recorded for a given `storeKey`.  Normally you
    should not call this method directly as it can damage the store behavior.
    This method is used by other store methods to set the `recordType` for a
    `storeKey`.

    @param {Integer} storeKey the store key
    @param {SC.Record} recordType a record class
    @returns {SC.Store} receiver
  */
  replaceRecordTypeFor: function(storeKey, recordType) {
    this.recordTypesByStoreKey[storeKey] = recordType;
    return this ;
  }

});

/* >>>>>>>>>> BEGIN source/system/nested_store.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('system/store');

/**
  @class

  A nested store can buffer changes to a parent store and then commit them
  all at once.  You usually will use a `NestedStore` as part of store chaining
  to stage changes to your object graph before sharing them with the rest of
  the application.

  Normally you will not create a nested store directly.  Instead, you can
  retrieve a nested store by using the `chain()` method.  When you are finished
  working with the nested store, `destroy()` will dispose of it.

  @extends SC.Store
  @since SproutCore 1.0
*/
SC.NestedStore = SC.Store.extend(
/** @scope SC.NestedStore.prototype */ {

  /**
    This is set to YES when there are changes that have not been committed
    yet.

    @type Boolean
    @default NO
  */
  hasChanges: NO,

  /**
    The parent store this nested store is chained to.  Nested stores must have
    a parent store in order to function properly.  Normally, you create a
    nested store using the `SC.Store#chain()` method and this property will be
    set for you.

    @type SC.Store
    @default null
  */
  parentStore: null,

  /**
    `YES` if the store is nested. Walk like a duck

    @type Boolean
    @default YES
  */
  isNested: YES,

  /**
    If YES, then the attribute hash state will be locked when you first
    read the data hash or status.  This means that if you retrieve a record
    then change the record in the parent store, the changes will not be
    visible to your nested store until you commit or discard changes.

    If `NO`, then the attribute hash will lock only when you write data.

    Normally you want to lock your attribute hash the first time you read it.
    This will make your nested store behave most consistently.  However, if
    you are using multiple sibling nested stores at one time, you may want
    to turn off this property so that changes from one store will be reflected
    in the other one immediately.  In this case you will be responsible for
    ensuring that the sibling stores do not edit the same part of the object
    graph at the same time.

    @type Boolean
    @default YES
  */
  lockOnRead: YES,

  /** @private
    Array contains the base revision for an attribute hash when it was first
    cloned from the parent store.  If the attribute hash is edited and
    committed, the commit will fail if the parent attributes hash has been
    edited since.

    This is a form of optimistic locking, hence the name.

    Each store gets its own array of locks, which are selectively populated
    as needed.

    Note that this is kept as an array because it will be stored as a dense
    array on some browsers, making it faster.

    @type Array
    @default null
  */
  locks: null,

  /** @private
    An array that includes the store keys that have changed since the store
    was last committed.  This array is used to sync data hash changes between
    chained stores.  For a log changes that may actually be committed back to
    the server see the changelog property.

    @type SC.Set
    @default YES
  */
  chainedChanges: null,

  // ..........................................................
  // STORE CHAINING
  //

  /**
    `find()` cannot accept REMOTE queries in a nested store.  This override will
    verify that condition for you.  See `SC.Store#find()` for info on using this
    method.

    @param {SC.Query} query query object to use.
    @returns {SC.Record|SC.RecordArray}
  */
  find: function(query) {
    if (query && query.isQuery && query.get('location') !== SC.Query.LOCAL) {
      throw new Error("SC.Store#find() can only accept LOCAL queries in nested stores");
    }
    return arguments.callee.base.apply(this,arguments);
  },

  /**
    Propagate this store's changes to its parent.  If the store does not
    have a parent, this has no effect other than to clear the change set.

    @param {Boolean} force if YES, does not check for conflicts first
    @returns {SC.Store} receiver
  */
  commitChanges: function(force) {
    if (this.get('hasChanges')) {
      var pstore = this.get('parentStore');
      pstore.commitChangesFromNestedStore(this, this.get('chainedChanges'), force);
    }

    // clear out custom changes - even if there is nothing to commit.
    this.reset();
    return this;
  },

  /**
    An array of store keys for all conflicting records with the parent store. If there are no
    conflicting records, this property will be null.

    @readonly
    @field
    @type Array
    @default null
  */
  conflictedStoreKeys: function () {
    var ret = null;

    if (this.get('hasChanges')) {
      var pstore = this.get('parentStore'),
          locks = this.locks,
          revisions = pstore.revisions;

      if (locks && revisions) {
        var changes = this.get('chainedChanges');

        for (var i = 0, len = changes.length; i < len; i++) {
          var storeKey = changes[i],
              lock = locks[storeKey] || 1,
              revision = revisions[storeKey] || 1;

          // If the same revision for the item does not match the current revision, then someone has
          // changed the data hash in this store and we have a conflict.
          if (lock < revision) {
            if (!ret) ret = [];
            ret.push(storeKey);
          }
        }
      }
    }

    return ret;
  }.property('chainedChanges').cacheable(),

  /**
    Propagate this store's successful changes to its parent (if exists). At the end, it clears the
    local, private status of the committed records therefore the method can be called several times
    until the full transaction is successful or editing is abandoned

    @param {Boolean} force if YES, does not check for conflicts first
    @returns {SC.Store} receiver
  */
  commitSuccessfulChanges: function(force) {
    var chainedChanges = this.get('chainedChanges');

    if (this.get('hasChanges') && chainedChanges) {
      var dataHashes = this.dataHashes,
          revisions  = this.revisions,
          statuses   = this.statuses,
          editables  = this.editables,
          locks      = this.locks;

      var successfulChanges = chainedChanges.filter( function(storeKey) {
        var state = this.readStatus(storeKey);

        return state === SC.Record.READY_CLEAN || state === SC.Record.DESTROYED_CLEAN;
      }, this );

      var pstore = this.get('parentStore');

      pstore.commitChangesFromNestedStore(this, successfulChanges, force);

      // remove the local status so these records that have been successfully committed on the server
      // are no longer retrieved from this nested store but from the parent
      for (var i = 0, len = successfulChanges.get('length'); i < len; i++) {
        var storeKey = successfulChanges.objectAt(i);

        if (dataHashes && dataHashes.hasOwnProperty(storeKey)) { delete dataHashes[storeKey]; }
        if (revisions && revisions.hasOwnProperty(storeKey)) { delete revisions[storeKey]; }
        if (editables) { delete editables[storeKey]; }
        if (locks) { delete locks[storeKey]; }
        if (statuses && statuses.hasOwnProperty(storeKey)) { delete statuses[storeKey]; }

        chainedChanges.remove(storeKey);
      }

      // Indicate that chainedChanges has changed.
      if (successfulChanges.length > 0) { this.notifyPropertyChange('chainedChanges'); }
    }

    return this;
  },

  /**
    Discard the changes made to this store and reset the store.

    @returns {SC.Store} receiver
  */
  discardChanges: function() {
    // any locked records whose rev or lock rev differs from parent need to
    // be notified.
    var records, locks;
    if ((records = this.records) && (locks = this.locks)) {
      var pstore = this.get('parentStore'), psRevisions = pstore.revisions;
      var revisions = this.revisions, storeKey, lock, rev;
      for (storeKey in records) {
        if (!records.hasOwnProperty(storeKey)) continue ;
        if (!(lock = locks[storeKey])) continue; // not locked.

        rev = psRevisions[storeKey];
        if ((rev !== lock) || (revisions[storeKey] > rev)) {
          this._notifyRecordPropertyChange(parseInt(storeKey, 10));
        }
      }
    }

    this.reset();
    this.flush();
    return this ;
  },

  /**
    When you are finished working with a chained store, call this method to
    tear it down.  This will also discard any pending changes.

    @returns {SC.Store} receiver
  */
  destroy: function() {
    this.discardChanges();

    var parentStore = this.get('parentStore');
    if (parentStore) parentStore.willDestroyNestedStore(this);

    arguments.callee.base.apply(this,arguments);
    return this ;
  },

  /**
    Resets a store's data hash contents to match its parent.
  */
  reset: function() {
    // requires a pstore to reset
    var parentStore = this.get('parentStore');
    if (!parentStore) SC.Store.NO_PARENT_STORE_ERROR.throw();

    // inherit data store from parent store.
    this.dataHashes = SC.beget(parentStore.dataHashes);
    this.revisions  = SC.beget(parentStore.revisions);
    this.statuses   = SC.beget(parentStore.statuses);

    // beget nested records references
    this.childRecords = parentStore.childRecords ? SC.beget(parentStore.childRecords) : {};
    this.parentRecords = parentStore.parentRecords ? SC.beget(parentStore.parentRecords) : {};

    // also, reset private temporary objects
    this.set('hasChanges', false);
    this.chainedChanges = this.locks = this.editables = null;
    this.changelog = null ;

    // TODO: Notify record instances
  },

  /** @private

    Chain to parentstore
  */
  refreshQuery: function(query) {
    var parentStore = this.get('parentStore');
    if (parentStore) parentStore.refreshQuery(query);
    return this ;
  },

  /**
    Returns the `SC.Error` object associated with a specific record.

    Delegates the call to the parent store.

    @param {Number} storeKey The store key of the record.

    @returns {SC.Error} SC.Error or null if no error associated with the record.
  */
  readError: function(storeKey) {
    var parentStore = this.get('parentStore');
    return parentStore ? parentStore.readError(storeKey) : null;
  },

  /**
    Returns the `SC.Error` object associated with a specific query.

    Delegates the call to the parent store.

    @param {SC.Query} query The SC.Query with which the error is associated.

    @returns {SC.Error} SC.Error or null if no error associated with the query.
  */
  readQueryError: function(query) {
    var parentStore = this.get('parentStore');
    return parentStore ? parentStore.readQueryError(query) : null;
  },

  /** @private - adapt for nested store */
  chainAutonomousStore: function(attrs, newStoreClass) {
    SC.Store.NESTED_STORE_UNSUPPORTED_ERROR.throw();
  },

  // ..........................................................
  // CORE ATTRIBUTE API
  //
  // The methods in this layer work on data hashes in the store.  They do not
  // perform any changes that can impact records.  Usually you will not need
  // to use these methods.

  /**
    Returns the current edit status of a storekey.  May be one of `INHERITED`,
    `EDITABLE`, and `LOCKED`.  Used mostly for unit testing.

    @param {Number} storeKey the store key
    @returns {Number} edit status
  */
  storeKeyEditState: function(storeKey) {
    var editables = this.editables, locks = this.locks;
    return (editables && editables[storeKey]) ? SC.Store.EDITABLE : (locks && locks[storeKey]) ? SC.Store.LOCKED : SC.Store.INHERITED ;
  },

  /**  @private
    Locks the data hash so that it iterates independently from the parent
    store.
  */
  _lock: function(storeKey) {
    var locks = this.locks, rev, editables,
        pk, pr, path, tup, obj, key;

    // already locked -- nothing to do
    if (locks && locks[storeKey]) return this;

    // create locks if needed
    if (!locks) locks = this.locks = [];

    // fixup editables
    editables = this.editables;
    if (editables) editables[storeKey] = 0;


    // if the data hash in the parent store is editable, then clone the hash
    // for our own use.  Otherwise, just copy a reference to the data hash
    // in the parent store. -- find first non-inherited state
    var pstore = this.get('parentStore'), editState;
    while(pstore && (editState=pstore.storeKeyEditState(storeKey)) === SC.Store.INHERITED) {
      pstore = pstore.get('parentStore');
    }

    if (pstore && editState === SC.Store.EDITABLE) {

      pk = this.childRecords[storeKey];
      if (pk){
        // Since this is a nested record we have to actually walk up the parent chain
        // to get to the root parent and clone that hash. And then reconstruct the
        // memory space linking.
        this._lock(pk);
        pr = this.parentRecords[pk];
        if (pr) {
          path = pr[storeKey];
          tup = path ? SC.tupleForPropertyPath(path, this.dataHashes[pk]) : null;
          if (tup){ obj = tup[0]; key = tup[1]; }
          this.dataHashes[storeKey] = obj && key ? obj[key] : null;
        }
      }
      else {
        this.dataHashes[storeKey] = SC.clone(pstore.dataHashes[storeKey], YES);
      }
      if (!editables) editables = this.editables = [];
      editables[storeKey] = 1 ; // mark as editable

    } else this.dataHashes[storeKey] = pstore.dataHashes[storeKey];

    // also copy the status + revision
    this.statuses[storeKey] = this.statuses[storeKey];
    rev = this.revisions[storeKey] = this.revisions[storeKey];

    // save a lock and make it not editable
    locks[storeKey] = rev || 1;

    return this ;
  },

  /** @private - adds chaining support */
  readDataHash: function(storeKey) {
    if (this.get('lockOnRead')) this._lock(storeKey);
    return this.dataHashes[storeKey];
  },

  /** @private - adds chaining support */
  readEditableDataHash: function(storeKey) {

    // lock the data hash if needed
    this._lock(storeKey);

    return arguments.callee.base.apply(this,arguments);
  },

  /** @private - adds chaining support -
    Does not call sc_super because the implementation of the method vary too
    much.
  */
  writeDataHash: function(storeKey, hash, status) {
    var locks = this.locks, didLock = NO, rev ;

    // Update our dataHash and/or status, depending on what was passed in.
    // Note that if no new hash was passed in, we'll lock the storeKey to
    // properly fork our dataHash from our parent store.  Similarly, if no
    // status was passed in, we'll save our own copy of the value.
    if (hash) {
      this.dataHashes[storeKey] = hash;
    }
    else {
      this._lock(storeKey);
      didLock = YES;
    }

    if (status) {
      this.statuses[storeKey] = status;
    }
    else {
      if (!didLock) this.statuses[storeKey] = (this.statuses[storeKey] || SC.Record.READY_NEW);
    }

    if (!didLock) {
      rev = this.revisions[storeKey] = this.revisions[storeKey]; // copy ref

      // make sure we lock if needed.
      if (!locks) locks = this.locks = [];
      if (!locks[storeKey]) locks[storeKey] = rev || 1;
    }

    // Also note that this hash is now editable.  (Even if we locked it,
    // above, it may not have been marked as editable.)
    var editables = this.editables;
    if (!editables) editables = this.editables = [];
    editables[storeKey] = 1 ; // use number for dense array support

    // propagate the data to the child records
    this._updateChildRecordHashes(storeKey, hash, status);

    return this ;
  },

  /** @private - adds chaining support */
  removeDataHash: function(storeKey, status) {

    // record optimistic lock revision
    var locks = this.locks;
    if (!locks) locks = this.locks = [];
    if (!locks[storeKey]) locks[storeKey] = this.revisions[storeKey] || 1;

    return arguments.callee.base.apply(this,arguments);
  },

  /** @private - bookkeeping for a single data hash. */
  dataHashDidChange: function(storeKeys, rev, statusOnly, key) {
    // update the revision for storeKey.  Use generateStoreKey() because that
    // guarantees a universally (to this store hierarchy anyway) unique
    // key value.
    if (!rev) rev = SC.Store.generateStoreKey();
    var isArray, len, idx, storeKey;

    isArray = SC.typeOf(storeKeys) === SC.T_ARRAY;
    if (isArray) {
      len = storeKeys.length;
    } else {
      len = 1;
      storeKey = storeKeys;
    }

    var changes = this.get('chainedChanges');
    if (!changes) changes = this.chainedChanges = SC.Set.create();

    var that = this,
        didAddChainedChanges = false;

    for (idx = 0; idx < len; idx++) {
      if (isArray) storeKey = storeKeys[idx];

      this._lock(storeKey);
      this.revisions[storeKey] = rev;

      if (!changes.contains(storeKey)) {
        changes.add(storeKey);
        didAddChainedChanges = true;
      }

      this._notifyRecordPropertyChange(storeKey, statusOnly, key);

      // notify also the child records
      this._propagateToChildren(storeKey, function(storeKey){
        that.dataHashDidChange(storeKey, null, statusOnly, key);
      });
    }

    this.setIfChanged('hasChanges', YES);
    if (didAddChainedChanges) {
      this.notifyPropertyChange('chainedChanges');
    }

    return this ;
  },

  // ..........................................................
  // SYNCING CHANGES
  //

  /** @private - adapt for nested store */
  commitChangesFromNestedStore: function(nestedStore, changes, force) {

    arguments.callee.base.apply(this,arguments);

    // save a lock for each store key if it does not have one already
    // also add each storeKey to my own changes set.
    var pstore = this.get('parentStore'), psRevisions = pstore.revisions, i;
    var myLocks = this.locks,
        myChanges = this.get('chainedChanges'),
        len,
        storeKey;

    if (!myLocks) myLocks = this.locks = [];
    if (!myChanges) myChanges = this.chainedChanges = SC.Set.create();

    len = changes.length ;
    for(i=0;i<len;i++) {
      storeKey = changes[i];
      if (!myLocks[storeKey]) myLocks[storeKey] = psRevisions[storeKey]||1;
      myChanges.add(storeKey);
    }

    // Finally, mark store as dirty if we have changes
    this.setIfChanged('hasChanges', myChanges.get('length') > 0);
    this.notifyPropertyChange('chainedChanges');

    this.flush();

    return this ;
  },

  // ..........................................................
  // HIGH-LEVEL RECORD API
  //


  /** @private - adapt for nested store */
  queryFor: function(recordType, conditions, params) {
    return this.get('parentStore').queryFor(recordType, conditions, params);
  },

  // ..........................................................
  // CORE RECORDS API
  //
  // The methods in this section can be used to manipulate records without
  // actually creating record instances.

  /** @private - adapt for nested store

    Unlike for the main store, for nested stores if isRefresh=YES, we'll throw
    an error if the record is dirty.  We'll otherwise avoid setting our status
    because that can disconnect us from upper and/or lower stores.
  */
  retrieveRecords: function(recordTypes, ids, storeKeys, isRefresh, callbacks) {
    var pstore = this.get('parentStore'), idx, storeKey,
      len = (!storeKeys) ? ids.length : storeKeys.length,
      K = SC.Record, status;

    // Is this a refresh?
    if (isRefresh) {
      for(idx=0;idx<len;idx++) {
        storeKey = !storeKeys ? pstore.storeKeyFor(recordTypes, ids[idx]) : storeKeys[idx];
        status   = this.peekStatus(storeKey);

        // We won't allow calling retrieve on a dirty record in a nested store
        // (although we do allow it in the main store).  This is because doing
        // so would involve writing a unique status, and that would break the
        // status hierarchy, so even though lower stores would complete the
        // retrieval, the upper layers would never inherit the new statuses.
        if (status & K.DIRTY) {
          SC.Store.NESTED_STORE_RETRIEVE_DIRTY_ERROR.throw();
        }
        else {
          // Not dirty?  Then abandon any status we had set (to re-establish
          // any prototype linkage breakage) before asking our parent store to
          // perform the retrieve.
          var dataHashes = this.dataHashes,
              revisions  = this.revisions,
              statuses   = this.statuses,
              editables  = this.editables,
              locks      = this.locks;

          var changed    = NO;
          var statusOnly = NO;

          if (dataHashes  &&  dataHashes.hasOwnProperty(storeKey)) {
            delete dataHashes[storeKey];
            changed = YES;
          }
          if (revisions   &&  revisions.hasOwnProperty(storeKey)) {
            delete revisions[storeKey];
            changed = YES;
          }
          if (editables) delete editables[storeKey];
          if (locks) delete locks[storeKey];

          if (statuses  &&  statuses.hasOwnProperty(storeKey)) {
            delete statuses[storeKey];
            if (!changed) statusOnly = YES;
            changed = YES;
          }

          if (changed) this._notifyRecordPropertyChange(storeKey, statusOnly);
        }
      }
    }

    return pstore.retrieveRecords(recordTypes, ids, storeKeys, isRefresh, callbacks);
  },

  /** @private - adapt for nested store */
  commitRecords: function(recordTypes, ids, storeKeys) {
    if( this.get( "dataSource" ) )
      return arguments.callee.base.apply(this,arguments);
    else
      SC.Store.NESTED_STORE_UNSUPPORTED_ERROR.throw();
  },

  /** @private - adapt for nested store */
  commitRecord: function(recordType, id, storeKey) {
    if( this.get( "dataSource" ) )
      return arguments.callee.base.apply(this,arguments);
    else
      SC.Store.NESTED_STORE_UNSUPPORTED_ERROR.throw();
  },

  /** @private - adapt for nested store */
  cancelRecords: function(recordTypes, ids, storeKeys) {
    if( this.get( "dataSource" ) )
      return arguments.callee.base.apply(this,arguments);
    else
      SC.Store.NESTED_STORE_UNSUPPORTED_ERROR.throw();
  },

  /** @private - adapt for nested store */
  cancelRecord: function(recordType, id, storeKey) {
    if( this.get( "dataSource" ) )
      return arguments.callee.base.apply(this,arguments);
    else
      SC.Store.NESTED_STORE_UNSUPPORTED_ERROR.throw();
  },

  // ..........................................................
  // DATA SOURCE CALLBACKS
  //
  // Methods called by the data source on the store

  /** @private - adapt for nested store */
  dataSourceDidCancel: function(storeKey) {
    if( this.get( "dataSource" ) )
      return arguments.callee.base.apply(this,arguments);
    else
      SC.Store.NESTED_STORE_UNSUPPORTED_ERROR.throw();
  },

  /** @private - adapt for nested store */
  dataSourceDidComplete: function(storeKey, dataHash, newId) {
    if( this.get( "dataSource" ) )
      return arguments.callee.base.apply(this,arguments);
    else
      SC.Store.NESTED_STORE_UNSUPPORTED_ERROR.throw();
  },

  /** @private - adapt for nested store */
  dataSourceDidDestroy: function(storeKey) {
    if( this.get( "dataSource" ) )
      return arguments.callee.base.apply(this,arguments);
    else
      SC.Store.NESTED_STORE_UNSUPPORTED_ERROR.throw();
  },

  /** @private - adapt for nested store */
  dataSourceDidError: function(storeKey, error) {
    if( this.get( "dataSource" ) )
      return arguments.callee.base.apply(this,arguments);
    else
      SC.Store.NESTED_STORE_UNSUPPORTED_ERROR.throw();
  },

  // ..........................................................
  // PUSH CHANGES FROM DATA SOURCE
  //

  /** @private - adapt for nested store */
  pushRetrieve: function(recordType, id, dataHash, storeKey) {
    if( this.get( "dataSource" ) )
      return arguments.callee.base.apply(this,arguments);
    else
      SC.Store.NESTED_STORE_UNSUPPORTED_ERROR.throw();
  },

  /** @private - adapt for nested store */
  pushDestroy: function(recordType, id, storeKey) {
    if( this.get( "dataSource" ) )
      return arguments.callee.base.apply(this,arguments);
    else
      SC.Store.NESTED_STORE_UNSUPPORTED_ERROR.throw();
  },

  /** @private - adapt for nested store */
  pushError: function(recordType, id, error, storeKey) {
    if( this.get( "dataSource" ) )
      return arguments.callee.base.apply(this,arguments);
    else
      SC.Store.NESTED_STORE_UNSUPPORTED_ERROR.throw();
  }

}) ;


/* >>>>>>>>>> BEGIN source/system/record_array.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

sc_require('models/record');

/**
  @class

  A `RecordArray` is a managed list of records (instances of your `SC.Record`
  model classes).

  Using RecordArrays
  ---

  Most often, RecordArrays contain the results of a `SC.Query`. You will generally not
  create or modify record arrays yourselves, instead using the ones returned from calls
  to `SC.Store#find` with either a record type or a query.

  The membership of these query-backed record arrays is managed by the store, which
  searches already-loaded records for local queries, and defers to your data source
  for remote ones (see `SC.Query` documentation for more details). Since membership
  in these record arrays is managed by the store, you will not generally add, remove
  or rearrange them here (see `isEditable` below).

  Query-backed record arrays have a status property which reflects the store's progress
  in fulfilling the query. See notes on `status` below.

  (Note that instances of `SC.Query` are dumb descriptor objects which do not have a
  status or results of their own. References to a query's status or results should be
  understood to refer to those of its record array.)

  Internal Notes
  ---

  This section is about `RecordArray` internals, and is only intended for those
  who need to extend this class to do something special.

  A `RecordArray` wraps an array of store keys, listed on its `storeKeys`
  property. If you request a record from the array, e.g. via `objectAt`,
  the `RecordArray` will convert the requested store key to a record
  suitable for public use.

  The list of store keys is usually managed by the store. If you are using
  your `RecordArray` with a query, you should manage the results via the
  store, and not try to directly manipulate the results via the array. If you
  are managing the array's store keys yourself, then any array-like operation
  will be translated into similar calls on the underlying `storeKeys` array.
  This underlying array can be a real array, or, if you wish to implement
  incremental loading, it may be a `SparseArray`.

  If the record array is created with an `SC.Query` object (as is almost always the
  case), then the record array will also consult the query for various delegate
  operations such as determining if the record array should update automatically
  whenever records in the store changes. It will also ask the query to refresh the
  `storeKeys` list whenever records change in the store.

  @extends SC.Object
  @extends SC.Enumerable
  @extends SC.Array
  @since SproutCore 1.0
*/

SC.RecordArray = SC.Object.extend(SC.Enumerable, SC.Array,
  /** @scope SC.RecordArray.prototype */ {

  


  /**
    The store that owns this record array.  All record arrays must have a
    store to function properly.

    NOTE: You **MUST** set this property on the `RecordArray` when creating
    it or else it will fail.

    @type SC.Store
  */
  store: null,

  /**
    The `SC.Query` object this record array is based upon.  All record arrays
    **MUST** have an associated query in order to function correctly.  You
    cannot change this property once it has been set.

    NOTE: You **MUST** set this property on the `RecordArray` when creating
    it or else it will fail.

    @type SC.Query
  */
  query: null,

  /**
    The array of `storeKeys` as retrieved from the owner store.

    @type SC.Array
  */
  storeKeys: null,

  /** @private The cache of previous store keys so that we can avoid unnecessary updates. */
  _prevStoreKeys: null,

  /**
    Reflects the store's current status in fulfilling the record array's query. Note
    that this status is not directly related to the status of the array's records:

    - The store returns local queries immediately, regardless of any first-time loading
      they may trigger. (Note that by default, local queries are limited to 100ms
      processing time per run loop, so very complex queries may take several run loops
      to return to `READY` status. You can edit `SC.RecordArray.QUERY_MATCHING_THRESHOLD`
      to change this duration.)
    - The store fulfills remote queries by passing them to your data source's `fetch`
      method. While fetching, it sets your array's status to `BUSY_LOADING` or
      `BUSY_REFRESHING`. Once your data source has finished fetching (successfully or
      otherwise), it will call the appropriate store methods (e.g. `dataSourceDidFetchQuery`
      or `dataSourceDidErrorQuery`), which will update the query's array's status.

    Thus, a record array may have a `READY` status while records are still loading (if
    a local query triggers a call to `SC.DataSource#fetch`), and will not reflect the
    `DIRTY` status of any of its records.

    @type Number
  */
  status: SC.Record.EMPTY,

  /**
    The current editable state of the query. If this record array is not backed by a
    query, it is assumed to be editable.

    @property
    @type Boolean
  */
  isEditable: function() {
    var query = this.get('query');
    return query ? query.get('isEditable') : YES;
  }.property('query').cacheable(),

  // ..........................................................
  // ARRAY PRIMITIVES
  //

  /** @private
    Returned length is a pass-through to the `storeKeys` array.
		@property
  */
  length: function() {
    this.flush(); // cleanup pending changes
    var storeKeys = this.get('storeKeys');
    return storeKeys ? storeKeys.get('length') : 0;
  }.property('storeKeys').cacheable(),

  /** @private
    A cache of materialized records. The first time an instance of SC.Record is
    created for a store key at a given index, it will be saved to this array.

    Whenever the `storeKeys` property is reset, this cache is also reset.

    @type Array
  */
  _scra_records: null,

  /** @private
    Looks up the store key in the `storeKeys array and materializes a
    records.

    @param {Number} idx index of the object
    @return {SC.Record} materialized record
  */
  objectAt: function(idx) {

    this.flush(); // cleanup pending if needed

    var recs      = this._scra_records,
        storeKeys = this.get('storeKeys'),
        store     = this.get('store'),
        storeKey, ret ;

    if (!storeKeys || !store) return undefined; // nothing to do
    if (recs && (ret=recs[idx])) return ret ; // cached

    // not in cache, materialize
    if (!recs) this._scra_records = recs = [] ; // create cache
    storeKey = storeKeys.objectAt(idx);

    if (storeKey) {
      // if record is not loaded already, then ask the data source to
      // retrieve it
      if (store.peekStatus(storeKey) === SC.Record.EMPTY) {
        store.retrieveRecord(null, null, storeKey);
      }
      recs[idx] = ret = store.materializeRecord(storeKey);
    }
    return ret ;
  },

  /** @private - optimized forEach loop. */
  forEach: function(callback, target) {
    this.flush();

    var recs      = this._scra_records,
        storeKeys = this.get('storeKeys'),
        store     = this.get('store'),
        len       = storeKeys ? storeKeys.get('length') : 0,
        idx, storeKey, rec;

    if (!storeKeys || !store) return this; // nothing to do
    if (!recs) recs = this._scra_records = [] ;
    if (!target) target = this;

    for(idx=0;idx<len;idx++) {
      rec = recs[idx];
      if (!rec) {
        rec = recs[idx] = store.materializeRecord(storeKeys.objectAt(idx));
      }
      callback.call(target, rec, idx, this);
    }

    return this;
  },

  /** @private
    Replaces a range of records starting at a given index with the replacement
    records provided. The objects to be inserted must be instances of SC.Record
    and must have a store key assigned to them.

    Note that most SC.RecordArrays are *not* editable via `replace()`, since they
    are generated by a rule-based SC.Query. You can check the `isEditable` property
    before attempting to modify a record array.

    @param {Number} idx start index
    @param {Number} amt count of records to remove
    @param {SC.RecordArray} recs the records that should replace the removed records

    @returns {SC.RecordArray} receiver, after mutation has occurred
  */
  replace: function(idx, amt, recs) {

    this.flush(); // cleanup pending if needed

    var storeKeys = this.get('storeKeys'),
        len       = recs ? (recs.get ? recs.get('length') : recs.length) : 0,
        i, keys;

    if (!storeKeys) throw new Error("Unable to edit an SC.RecordArray that does not have its storeKeys property set.");

    if (!this.get('isEditable')) SC.RecordArray.NOT_EDITABLE.throw();

    // map to store keys
    keys = [] ;
    for(i=0;i<len;i++) keys[i] = recs.objectAt(i).get('storeKey');

    // pass along - if allowed, this should trigger the content observer
    storeKeys.replace(idx, amt, keys);
    return this;
  },

  /**
    Returns YES if the passed record can be found in the record array.  This is
    provided for compatibility with SC.Set.

    @param {SC.Record} record
    @returns {Boolean}
  */
  contains: function(record) {
    return this.indexOf(record)>=0;
  },

  /** @private
    Returns the first index where the specified record is found.

    @param {SC.Record} record
    @param {Number} startAt optional starting index
    @returns {Number} index
  */
  indexOf: function(record, startAt) {
    if (!SC.kindOf(record, SC.Record)) {
      

      return -1; // only takes records
    }

    this.flush();

    var storeKey  = record.get('storeKey'),
        storeKeys = this.get('storeKeys');

    return storeKeys ? storeKeys.indexOf(storeKey, startAt) : -1;
  },

  /** @private
    Returns the last index where the specified record is found.

    @param {SC.Record} record
    @param {Number} startAt optional starting index
    @returns {Number} index
  */
  lastIndexOf: function(record, startAt) {
    if (!SC.kindOf(record, SC.Record)) {
      

      return -1; // only takes records
    }

    this.flush();

    var storeKey  = record.get('storeKey'),
        storeKeys = this.get('storeKeys');
    return storeKeys ? storeKeys.lastIndexOf(storeKey, startAt) : -1;
  },

  /**
    Adds the specified record to the record array if it is not already part
    of the array.  Provided for compatibility with `SC.Set`.

    @param {SC.Record} record
    @returns {SC.RecordArray} receiver
  */
  add: function(record) {
    if (!SC.kindOf(record, SC.Record)) return this ;
    if (this.indexOf(record)<0) this.pushObject(record);
    return this ;
  },

  /**
    Removes the specified record from the array if it is not already a part
    of the array.  Provided for compatibility with `SC.Set`.

    @param {SC.Record} record
    @returns {SC.RecordArray} receiver
  */
  remove: function(record) {
    if (!SC.kindOf(record, SC.Record)) return this ;
    this.removeObject(record);
    return this ;
  },

  // ..........................................................
  // HELPER METHODS
  //

  /**
    Extends the standard SC.Enumerable implementation to return results based
    on a Query if you pass it in.

    @param {SC.Query} query a SC.Query object
		@param {Object} target the target object to use

    @returns {SC.RecordArray}
  */
  find: function(original, query, target) {
    if (query && query.isQuery) {
      return this.get('store').find(query.queryWithScope(this));
    } else return original.apply(this, SC.$A(arguments).slice(1));
  }.enhance(),

  /**
    Call whenever you want to refresh the results of this query.  This will
    notify the data source, asking it to refresh the contents.

    @returns {SC.RecordArray} receiver
  */
  refresh: function() {
    this.get('store').refreshQuery(this.get('query'));
    return this;
  },

  /**
    Will recompute the results of the attached `SC.Query`. Useful if your query
    is based on computed properties that might have changed.

    This method is for local use only, operating only on records that have already
    been loaded into your store. If you wish to re-fetch a remote query via your
    data source, use `refresh()` instead.

    @returns {SC.RecordArray} receiver
  */
  reload: function() {
    this.flush(YES);
    return this;
  },

  /**
    Destroys the record array.  Releases any `storeKeys`, and deregisters with
    the owner store.

    @returns {SC.RecordArray} receiver
  */
  destroy: function() {
    if (!this.get('isDestroyed')) {
      this.get('store').recordArrayWillDestroy(this);
    }

    arguments.callee.base.apply(this,arguments);
  },

  // ..........................................................
  // STORE CALLBACKS
  //

  // **NOTE**: `storeWillFetchQuery()`, `storeDidFetchQuery()`,
  // `storeDidCancelQuery()`, and `storeDidErrorQuery()` are tested implicitly
  // through the related methods in `SC.Store`.  We're doing it this way
  // because eventually this particular implementation is likely to change;
  // moving some or all of this code directly into the store. -CAJ

  /** @private
    Called whenever the store initiates a refresh of the query.  Sets the
    status of the record array to the appropriate status.

    @param {SC.Query} query
    @returns {SC.RecordArray} receiver
  */
  storeWillFetchQuery: function(query) {
    var status = this.get('status'),
        K      = SC.Record;
    if ((status === K.EMPTY) || (status === K.ERROR)) status = K.BUSY_LOADING;
    if (status & K.READY) status = K.BUSY_REFRESH;
    this.setIfChanged('status', status);
    return this ;
  },

  /** @private
    Called whenever the store has finished fetching a query.

    @param {SC.Query} query
    @returns {SC.RecordArray} receiver
  */
  storeDidFetchQuery: function(query) {
    this.setIfChanged('status', SC.Record.READY_CLEAN);
    return this ;
  },

  /** @private
    Called whenever the store has cancelled a refresh.  Sets the
    status of the record array to the appropriate status.

    @param {SC.Query} query
    @returns {SC.RecordArray} receiver
  */
  storeDidCancelQuery: function(query) {
    var status = this.get('status'),
        K      = SC.Record;
    if (status === K.BUSY_LOADING) status = K.EMPTY;
    else if (status === K.BUSY_REFRESH) status = K.READY_CLEAN;
    this.setIfChanged('status', status);
    return this ;
  },

  /** @private
    Called whenever the store encounters an error while fetching.  Sets the
    status of the record array to the appropriate status.

    @param {SC.Query} query
    @returns {SC.RecordArray} receiver
  */
  storeDidErrorQuery: function(query) {
    this.setIfChanged('status', SC.Record.ERROR);
    return this ;
  },

  /** @private
    Called by the store whenever it changes the state of certain store keys. If
    the receiver cares about these changes, it will mark itself as dirty and add
    the changed store keys to the _scq_changedStoreKeys index set.

    The next time you try to access the record array, it will call `flush()` and
    add the changed keys to the underlying `storeKeys` array if the new records
    match the conditions of the record array's query.

    @param {SC.Array} storeKeys the effected store keys
    @param {SC.Set} recordTypes the record types for the storeKeys.
    @returns {SC.RecordArray} receiver
  */
  storeDidChangeStoreKeys: function(storeKeys, recordTypes) {
    var query =  this.get('query');
    // fast path exits
    if (query.get('location') !== SC.Query.LOCAL) return this;
    if (!query.containsRecordTypes(recordTypes)) return this;

    // ok - we're interested.  mark as dirty and save storeKeys.
    var changed = this._scq_changedStoreKeys;
    if (!changed) changed = this._scq_changedStoreKeys = SC.IndexSet.create();
    changed.addEach(storeKeys);

    this.set('needsFlush', YES);
    if (this.get('storeKeys')) {
      this.flush();
    }

    return this;
  },

  /**
    Applies the query to any pending changed store keys, updating the record
    array contents as necessary.  This method is called automatically anytime
    you access the RecordArray to make sure it is up to date, but you can
    call it yourself as well if you need to force the record array to fully
    update immediately.

    Currently this method only has an effect if the query location is
    `SC.Query.LOCAL`.  You can call this method on any `RecordArray` however,
    without an error.

    @param {Boolean} _flush to force it - use reload() to trigger it
    @returns {SC.RecordArray} receiver
  */
  flush: function(_flush) {
    // Are we already inside a flush?  If so, then don't do it again, to avoid
    // never-ending recursive flush calls.  Instead, we'll simply mark
    // ourselves as needing a flush again when we're done.
    if (this._insideFlush) {
      this.set('needsFlush', YES);
      return this;
    }

    if (!this.get('needsFlush') && !_flush) return this; // nothing to do
    this.set('needsFlush', NO); // avoid running again.

    // fast exit
    var query = this.get('query'),
        store = this.get('store');
    if (!store || !query || query.get('location') !== SC.Query.LOCAL) {
      return this;
    }

    this._insideFlush = YES;

    // OK, actually generate some results
    var storeKeys = this.get('storeKeys'),
        changed   = this._scq_changedStoreKeys,
        didChange = NO,
        K         = SC.Record,
        storeKeysToPace = [],
        startDate = new Date(),
        rec, status, recordType, sourceKeys, scope, included;

    // if we have storeKeys already, just look at the changed keys
    var oldStoreKeys = storeKeys;
    if (storeKeys && !_flush) {

      if (changed) {
        changed.forEach(function(storeKey) {
          if(storeKeysToPace.length>0 || new Date()-startDate>SC.RecordArray.QUERY_MATCHING_THRESHOLD) {
            storeKeysToPace.push(storeKey);
            return;
          }
          // get record - do not include EMPTY or DESTROYED records
          status = store.peekStatus(storeKey);
          if (!(status & K.EMPTY) && !((status & K.DESTROYED) || (status === K.BUSY_DESTROYING))) {
            rec = store.materializeRecord(storeKey);
            included = !!(rec && query.contains(rec));
          } else included = NO ;

          // if storeKey should be in set but isn't -- add it.
          if (included) {
            if (storeKeys.indexOf(storeKey)<0) {
              if (!didChange) storeKeys = storeKeys.copy();
              storeKeys.pushObject(storeKey);
            }
          // if storeKey should NOT be in set but IS -- remove it
          } else {
            if (storeKeys.indexOf(storeKey)>=0) {
              if (!didChange) storeKeys = storeKeys.copy();
              storeKeys.removeObject(storeKey);
            } // if (storeKeys.indexOf)
          } // if (included)

        }, this);
        // make sure resort happens
        didChange = YES ;

      } // if (changed)

    // if no storeKeys, then we have to go through all of the storeKeys
    // and decide if they belong or not.  ick.
    } else {

      // collect the base set of keys.  if query has a parent scope, use that
      if (scope = query.get('scope')) {
        sourceKeys = scope.flush().get('storeKeys');
      // otherwise, lookup all storeKeys for the named recordType...
      } else if (recordType = query.get('expandedRecordTypes')) {
        sourceKeys = SC.IndexSet.create();
        recordType.forEach(function(cur) {
          sourceKeys.addEach(store.storeKeysFor(cur));
        });
      }

      // loop through storeKeys to determine if it belongs in this query or
      // not.
      storeKeys = [];
      sourceKeys.forEach(function(storeKey) {
        if(storeKeysToPace.length>0 || new Date()-startDate>SC.RecordArray.QUERY_MATCHING_THRESHOLD) {
          storeKeysToPace.push(storeKey);
          return;
        }

        status = store.peekStatus(storeKey);
        if (!(status & K.EMPTY) && !((status & K.DESTROYED) || (status === K.BUSY_DESTROYING))) {
          rec = store.materializeRecord(storeKey);
          if (rec && query.contains(rec)) storeKeys.push(storeKey);
        }
      });

      didChange = YES ;
    }

    // if we reach our threshold of pacing we need to schedule the rest of the
    // storeKeys to also be updated
    if (storeKeysToPace.length > 0) {
      this.invokeNext(function () {
        if (!this || this.get('isDestroyed')) return;
        this.set('needsFlush', YES);
        this._scq_changedStoreKeys = SC.IndexSet.create().addEach(storeKeysToPace);
        this.flush();
      });
    }

    // clear set of changed store keys
    if (changed) changed.clear();

    // Clear the flushing flag.
    // NOTE: Do this now, because any observers of storeKeys could trigger a call
    // to flush (ex. by calling get('length') on the RecordArray).
    this._insideFlush = NO;

    // only resort and update if we did change
    if (didChange) {

      // storeKeys must be a new instance because orderStoreKeys() works on it
      if (storeKeys && (storeKeys===oldStoreKeys)) {
        storeKeys = storeKeys.copy();
      }

      storeKeys = SC.Query.orderStoreKeys(storeKeys, query, store);
      if (SC.compare(oldStoreKeys, storeKeys) !== 0){
        this.set('storeKeys', SC.clone(storeKeys)); // replace content
      }
    }

    return this;
  },

  /**
    Set to `YES` when the query is dirty and needs to update its storeKeys
    before returning any results.  `RecordArray`s always start dirty and become
    clean the first time you try to access their contents.

    @type Boolean
  */
  needsFlush: YES,

  // ..........................................................
  // EMULATE SC.ERROR API
  //

  /**
    Returns `YES` whenever the status is `SC.Record.ERROR`.  This will allow
    you to put the UI into an error state.

		@property
    @type Boolean
  */
  isError: function() {
    return !!(this.get('status') & SC.Record.ERROR);
  }.property('status').cacheable(),

  /**
    Returns the receiver if the record array is in an error state.  Returns
    `null` otherwise.

		@property
    @type SC.Record
  */
  errorValue: function() {
    return this.get('isError') ? SC.val(this.get('errorObject')) : null ;
  }.property('isError').cacheable(),

  /**
    Returns the current error object only if the record array is in an error
    state. If no explicit error object has been set, returns
    `SC.Record.GENERIC_ERROR.`

		@property
    @type SC.Error
  */
  errorObject: function() {
    if (this.get('isError')) {
      var store = this.get('store');
      return store.readQueryError(this.get('query')) || SC.Record.GENERIC_ERROR;
    } else return null ;
  }.property('isError').cacheable(),

  // ..........................................................
  // INTERNAL SUPPORT
  //

  propertyWillChange: function(key) {
    if (key === 'storeKeys') {
      var storeKeys = this.get('storeKeys');
      var len = storeKeys ? storeKeys.get('length') : 0;

      this.arrayContentWillChange(0, len, 0);
    }

    return arguments.callee.base.apply(this,arguments);
  },

  /** @private
    Invoked whenever the `storeKeys` array changes.  Observes changes.
  */
  _storeKeysDidChange: function() {
    var storeKeys = this.get('storeKeys');

    var prev = this._prevStoreKeys, oldLen, newLen;

    if (storeKeys === prev) { return; } // nothing to do

    if (prev) {
      prev.removeArrayObservers({
        target: this,
        willChange: this.arrayContentWillChange,
        didChange: this._storeKeysContentDidChange
      });

      oldLen = prev.get('length');
    } else {
      oldLen = 0;
    }

    this._prevStoreKeys = storeKeys;
    if (storeKeys) {
      storeKeys.addArrayObservers({
        target: this,
        willChange: this.arrayContentWillChange,
        didChange: this._storeKeysContentDidChange
      });

      newLen = storeKeys.get('length');
    } else {
      newLen = 0;
    }

    this._storeKeysContentDidChange(0, oldLen, newLen);

  }.observes('storeKeys'),

  /** @private
    If anyone adds an array observer on to the record array, make sure
    we flush so that the observers don't fire the first time length is
    calculated.
  */
  addArrayObservers: function() {
    this.flush();
    return SC.Array.addArrayObservers.apply(this, arguments);
  },

  /** @private
    Invoked whenever the content of the `storeKeys` array changes.  This will
    dump any cached record lookup and then notify that the enumerable content
    has changed.
  */
  _storeKeysContentDidChange: function(start, removedCount, addedCount) {
    if (this._scra_records) this._scra_records.length=0 ; // clear cache

    this.arrayContentDidChange(start, removedCount, addedCount);
  },

  /** @private */
  init: function() {
    arguments.callee.base.apply(this,arguments);
    this._storeKeysDidChange();
  }

});

SC.RecordArray.mixin(/** @scope SC.RecordArray.prototype */{

  /**
    Standard error throw when you try to modify a record that is not editable

    @type SC.Error
  */
  NOT_EDITABLE: SC.$error("SC.RecordArray is not editable"),

  /**
    Number of milliseconds to allow a query matching to run for. If this number
    is exceeded, the query matching will be paced so as to not lock up the
    browser (by essentially splitting the work with an invokeNext)

    @type Number
  */
  QUERY_MATCHING_THRESHOLD: 100
});


/* >>>>>>>>>> BEGIN javascript.js */
/* >>>>>>>>>> BEGIN source/core.js */
// ==========================================================================
// Project:   SC.Statechart - A Statechart Framework for SproutCore
// Copyright: ©2010, 2011 Michael Cohen, and contributors.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
/* >>>>>>>>>> BEGIN source/ext/function.js */
// ==========================================================================
// Project:   SC.Statechart - A Statechart Framework for SproutCore
// Copyright: ©2010, 2011 Michael Cohen, and contributors.
//            Portions @2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/*globals SC */

/**
  Extends the JS Function object with the handleEvents method that
  will provide more advanced event handling capabilities when constructing
  your statechart's states.

  By default, when you add a method to a state, the state will react to
  events that matches a method's name, like so:

  {{{

    state = SC.State.extend({

      // Will be invoked when a event named "foo" is sent to this state
      foo: function(event, sender, context) { ... }

    })

  }}}

  In some situations, it may be advantageous to use one method that can react to
  multiple events instead of having multiple methods that essentially all do the
  same thing. In order to set a method to handle more than one event you use
  the handleEvents method which can be supplied a list of string and/or regular
  expressions. The following example demonstrates the use of handleEvents:

  {{{

    state = SC.State.extend({

      eventHandlerA: function(event, sender, context) {

      }.handleEvents('foo', 'bar'),

      eventHandlerB: function(event, sender, context) {

      }.handleEvents(/num\d/, 'decimal')

    })

  }}}

  Whenever events 'foo' and 'bar' are sent to the state, the method eventHandlerA
  will be invoked. When there is an event that matches the regular expression
  /num\d/ or the event is 'decimal' then eventHandlerB is invoked. In both
  cases, the name of the event will be supplied to the event handler.

  It should be noted that the use of regular expressions may impact performance
  since that statechart will not be able to fully optimize the event handling logic based
  on its use. Therefore the use of regular expression should be used sparingly.

  @param {(String|RegExp)...} args
*/
Function.prototype.handleEvents = function() {
  this.isEventHandler = YES;
  this.events = arguments;
  return this;
};

/**
  Extends the JS Function object with the stateObserves method that will
  create a state observe handler on a given state object.

  Use a stateObserves() instead of the common observes() method when you want a
  state to observer changes to some property on the state itself or some other
  object.

  Any method on the state that has stateObserves is considered a state observe
  handler and behaves just like when you use observes() on a method, but with an
  important difference. When you apply stateObserves to a method on a state, those
  methods will be active *only* when the state is entered, otherwise those methods
  will be inactive. This removes the need for you having to explicitly call
  addObserver and removeObserver. As an example:

  {{{

    state = SC.State.extend({

      foo: null,

      user: null,

      observeHandlerA: function(target, key) {

      }.stateObserves('MyApp.someController.status'),

      observeHandlerB: function(target, key) {

      }.stateObserves('foo'),

      observeHandlerC: function(target, key) {

      }.stateObserves('.user.name', '.user.salary')

    })

  }}}

  Above, state has three state observe handlers: observeHandlerA, observeHandlerB, and
  observeHandlerC. When state is entered, the state will automatically add itself as
  an observer for all of its registered state observe handlers. Therefore when
  foo changes, observeHandlerB will be invoked, and when MyApp.someController's status
  changes then observeHandlerA will be invoked. The moment that state is exited then
  the state will automatically remove itself as an observer for all of its registered
  state observe handlers. Therefore none of the state observe handlers will be
  invoked until the next time the state is entered.

  @param {String...} args
*/
Function.prototype.stateObserves = function() {
  this.isStateObserveHandler = YES;

  // Fast arguments access.
  // Accessing `arguments.length` is just a Number and doesn't materialize the `arguments` object, which is costly.
  this.args = new Array(arguments.length); // SC.A(arguments)
  for (var i = 0, len = this.args.length; i < len; i++) { this.args[i] = arguments[i]; }

  return this;
};

/* >>>>>>>>>> BEGIN source/mixins/statechart_delegate.js */
// ==========================================================================
// Project:   SC.Statechart - A Statechart Framework for SproutCore
// Copyright: ©2010, 2011 Michael Cohen, and contributors.
//            Portions @2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/*globals SC */

/**
  @class
  
  Apply to objects that are to represent a delegate for a SC.Statechart object.
  When assigned to a statechart, the statechart and its associated states will
  use the delegate in order to make various decisions.
  
  @see SC.Statechart#delegate 

  @author Michael Cohen
*/

SC.StatechartDelegate = /** @scope SC.StatechartDelegate.prototype */ {
  
  // Walk like a duck
  isStatechartDelegate: YES,
  
  // Route Handling Management
  
  /**
    Called to update the application's current location. 
    
    The location provided is dependent upon the application's underlying
    routing mechanism.
    
    @param {SC.StatechartManager} statechart the statechart
    @param {String|Hash} location the new location 
    @param {SC.State} state the state requesting the location update
  */
  statechartUpdateLocationForState: function(statechart, location, state) {
    SC.routes.set('location', location);
  },
  
  /**
    Called to acquire the application's current location.
    
    @param {SC.StatechartManager} statechart the statechart
    @param {SC.State} state the state requesting the location
    @returns {String} the location 
  */
  statechartAcquireLocationForState: function(statechart, state) {
    return SC.routes.get('location');
  },
  
  /**
    Used to bind a state's handler to a route. When the application's location
    matches the given route, the state's handler is to be invoked. 
    
    The statechart and states remain completely independent of how the underlying 
    routing mechanism works thereby providing a looser coupling and more flexibility 
    in how routing is to work. Given this flexiblity, it is important that a route
    assigned (using the {@link SC.State#representRoute} property) to a state strictly 
    conforms to the underlying routing mechanism's criteria in order for the given 
    handler to be properly invoked.
    
    By default the {@link SC.routes} mechanism is used to bind the state's handler with
    the given route.
    
    @param {SC.StatechartManager} statechart the statechart
    @param {SC.State} state the state to bind the route to
    @param {String|Hash} route the route that is to be bound to the state
    @param {Function|String} handler the method on the state to be invoked when the route
      gets triggered.
      
    @see SC.State#representRoute
  */
  statechartBindStateToRoute: function(statechart, state, route, handler) {
    SC.routes.add(route, state, handler);
  },
  
  /**
    Invoked by a state that has been notified to handle a triggered route. The state
    asks if it should go ahead an actually handle the triggered route. If no then
    the state's handler will no longer continue and finish by calling this delegate's
    `statechartStateCancelledHandlingTriggeredRoute` method. If yes then the state will 
    continue with handling the triggered route.
    
    By default `YES` is returned.
    
    @param {SC.StatechartManager} statechart the statechart
    @param {SC.State} state the state making the request
    @param {SC.StateRouteHandlerContext} routeContext contextual information about the handling 
      of a route
    
    @see #statechartStateCancelledHandlingTriggeredRoute
  */
  statechartShouldStateHandleTriggeredRoute: function(statechart, state, context) {
    return YES;
  },
  
  /**
    Invoked by a state that has been informed by the delegate to not handle a triggered route.
    Used this for any additional clean up or processing that you may wish to perform.
    
    @param {SC.StatechartManager} statechart the statechart
    @param {SC.State} state the state making the request
    @param {SC.StateRouteHandlerContext} routeContext contextual information about the handling 
      of a route
    
    @see #statechartShouldStateHandleTriggeredRoute
  */
  statechartStateCancelledHandlingTriggeredRoute: function(statechart, state, context) { }
  
};
/* >>>>>>>>>> BEGIN source/private/state_path_matcher.js */
// ==========================================================================
// Project:   SC.Statechart - A Statechart Framework for SproutCore
// Copyright: ©2010, 2011 Michael Cohen, and contributors.
//            Portions @2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/*globals SC */

/** @class

  The `SC.StatePathMatcher` is used to match a given state path match expression 
  against state paths. A state path is a basic dot-notion consisting of
  one or more state names joined using '.'. Ex: 'foo', 'foo.bar'. 
  
  The state path match expression language provides a way of expressing a state path.
  The expression is matched against a state path from the end of the state path
  to the beginning of the state path. A match is true if the expression has been
  satisfied by the given path. 
  
  Syntax:
  
    expression -> <this> <subpath> | <path>
    
    path -> <part> <subpath>
    
    subpath -> '.' <part> <subpath> | empty
  
    this -> 'this'
    
    part -> <name> | <expansion>
    
    expansion -> <name> '~' <name>
    
    name -> [a-z_][\w]*
    
  Expression examples:
  
    foo
    
    foo.bar
    
    foo.bar.mah
    
    foo~mah
    
    this.foo
    
    this.foo.bar
    
    this.foo~mah
    
    foo.bar~mah
    
    foo~bar.mah

  @extends SC.Object
  @author Michael Cohen
*/
SC.StatePathMatcher = SC.Object.extend(
  /** @scope SC.StatePathMatcher.prototype */{
    
  /**
    The state that is used to represent 'this' for the
    matcher's given expression.
    
    @field {SC.State}
    @see #expression
  */
  state: null,
    
  /**
    The expression used by this matcher to match against
    given state paths
    
    @field {String}
  */
  expression: null,
  
  /**
    A parsed set of tokens from the matcher's given expression
    
    @field {Array}
    @see #expression
  */
  tokens: null,
  
  init: function() {
    arguments.callee.base.apply(this,arguments);
    this._parseExpression();
  },
  
  /** @private 
  
    Will parse the matcher's given expession by creating tokens and chaining them
    together.
    
    Note: Because the DSL for state path expressions is tiny, a simple hand-crafted 
    parser is being used. However, if the DSL becomes any more complex, then it will 
    probably be necessary to refactor the logic in order follow a more conventional 
    type of parser.
    
    @see #expression
  */
  _parseExpression: function() {
    var parts = this.expression ? this.expression.split('.') : [],
        len = parts.length, i = 0, part,
        chain = null, token, tokens = [];
      
    for (; i < len; i += 1) {
      part = parts[i];      
      
      if (part.indexOf('~') >= 0) {
        part = part.split('~');
        if (part.length > 2) {
          throw new Error("Invalid use of '~' at part %@".fmt(i));
        }
        token = SC.StatePathMatcher._ExpandToken.create({
          start: part[0], end: part[1]
        });
      } 
      
      else if (part === 'this') {
        if (tokens.length > 0) {
          throw new Error("Invalid use of 'this' at part %@".fmt(i));
        }
        token = SC.StatePathMatcher._ThisToken.create();
      }
      
      else {
        token = SC.StatePathMatcher._BasicToken.create({
          value: part
        });
      }
      
      token.owner = this;
      tokens.push(token);
    }

    this.set('tokens', tokens);

    var stack = SC.clone(tokens);
    this._chain = chain = stack.pop();
    while (token = stack.pop()) {
      chain.nextToken = token;
      chain = token;
    }
  },
  
  /**
    Returns the last part of the expression. So if the
    expression is 'foo.bar' or 'foo~bar' then 'bar' is returned
    in both cases. If the expression is 'this' then 'this is
    returned. 
  */
  lastPart: function() {
    var tokens = this.get('tokens'),
        len = tokens ? tokens.length : 0,
        token = len > 0 ? tokens[len -1] : null;
    return token.get('lastPart');
  }.property('tokens').cacheable(),
    
  /**
    Will make a state path against this matcher's expression. 
    
    The path provided must follow a basic dot-notation path containing
    one or dots '.'. Ex: 'foo', 'foo.bar'
    
    @param path {String} a dot-notation path
    @return {Boolean} true if there is a match, otherwise false
  */
  match: function(path) {
    this._stack = path.split('.');
    if (SC.empty(path) || SC.typeOf(path) !== SC.T_STRING) return NO;
    return this._chain.match();
  },
  
  /** @private */
  _pop: function() {
    this._lastPopped = this._stack.pop();
    return this._lastPopped;
  }

});

/** @private @class

  Base class used to represent a token the expression
*/
SC.StatePathMatcher._Token = SC.Object.extend({
  
  /** The type of this token */
  type: null,
  
  /** The state path matcher that owns this token */
  owner: null,
  
  /** The next token in the matching chain */
  nextToken: null,
  
  /** 
    The last part the token represents, which is either a valid state
    name or representation of a state
  */
  lastPart: null,
  
  /** 
    Used to match against what is currently on the owner's
    current path stack
  */
  match: function() { return NO; }
  
});

/** @private @class

  Represents a basic name of a state in the expression. Ex 'foo'. 
  
  A match is true if the matcher's current path stack is popped and the
  result matches this token's value.
*/
SC.StatePathMatcher._BasicToken = SC.StatePathMatcher._Token.extend({
    
  type: 'basic',
    
  value: null,
   
  lastPart: function() {
    return this.value; 
  }.property('value').cacheable(),
    
  match: function() {
    var part = this.owner._pop(),
        token = this.nextToken;
    if (this.value !== part) return NO;
    return token ? token.match() : YES;
  }
    
});
  
/** @private @class

  Represents an expanding path based on the use of the '<start>~<end>' syntax.
  <start> represents the start and <end> represents the end. 
  
  A match is true if the matcher's current path stack is first popped to match 
  <end> and eventually is popped to match <start>. If neither <end> nor <start>
  are satified then false is retuend.
*/
SC.StatePathMatcher._ExpandToken = SC.StatePathMatcher._Token.extend({
    
  type: 'expand',
    
  start: null,
    
  end: null,
  
  lastPart: function() {
    return this.end; 
  }.property('end').cacheable(),

  match: function() {
    var start = this.start,
        end = this.end, part,
        token = this.nextToken;
          
    part = this.owner._pop();
    if (part !== end) return NO;
      
    while (part = this.owner._pop()) {
      if (part === start) {
        return token ? token.match() : YES;
      }
    }
      
    return NO;
  }
    
});

/** @private @class
  
  Represents a this token, which is used to represent the owner's
  `state` property.
  
  A match is true if the last path part popped from the owner's
  current path stack is an immediate substate of the state this
  token represents.
*/
SC.StatePathMatcher._ThisToken = SC.StatePathMatcher._Token.extend({
    
  type: 'this',
  
  lastPart: 'this',
  
  match: function() {
    var state = this.owner.state,
        substates = state.get('substates'),
        len = substates.length, i = 0, part;
        
    part = this.owner._lastPopped;

    if (!part || this.owner._stack.length !== 0) return NO;
    
    for (; i < len; i += 1) {
      if (substates[i].get('name') === part) return YES;
    }
    
    return NO;
  }
  
});
/* >>>>>>>>>> BEGIN source/system/async.js */
// ==========================================================================
// Project:   SC.Statechart - A Statechart Framework for SproutCore
// Copyright: ©2010, 2011 Michael Cohen, and contributors.
//            Portions @2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/*globals SC */

/**
  @class

  Represents a call that is intended to be asynchronous. This is
  used during a state transition process when either entering or
  exiting a state.

  @extends SC.Object
  @author Michael Cohen
*/
SC.Async = SC.Object.extend(
  /** @scope SC.Async.prototype */{

  func: null,

  arg1: null,

  arg2: null,

  /** @private
    Called by the statechart
  */
  tryToPerform: function(state) {
    var func = this.get('func'),
        arg1 = this.get('arg1'),
        arg2 = this.get('arg2'),
        funcType = SC.typeOf(func);

    if (funcType === SC.T_STRING) {
      state.tryToPerform(func, arg1, arg2);
    }
    else if (funcType === SC.T_FUNCTION) {
      func.apply(state, [arg1, arg2]);
    }
  }

});

/**
  Singleton
*/
SC.Async.mixin(/** @scope SC.Async */{

  /**
    Call in either a state's enterState or exitState method when you
    want a state to perform an asynchronous action, such as an animation.

    Examples:

      SC.State.extend({

        enterState: function() {
          return SC.Async.perform('foo');
        },

        exitState: function() {
          return SC.Async.perform('bar', 100);
        }

        foo: function() { ... },

        bar: function(arg) { ... }

      });

    @param func {String|Function} the function to be invoked on a state
    @param arg1 Optional. An argument to pass to the given function
    @param arg2 Optional. An argument to pass to the given function
    @return {SC.Async} a new instance of a SC.Async
  */
  perform: function(func, arg1, arg2) {
    return SC.Async.create({ func: func, arg1: arg1, arg2: arg2 });
  }

});

/* >>>>>>>>>> BEGIN source/system/state.js */
// ==========================================================================
// Project:   SC.Statechart - A Statechart Framework for SproutCore
// Copyright: ©2010, 2011 Michael Cohen, and contributors.
//            Portions @2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/*globals SC */




/**
  @class

  Represents a state within a statechart.

  The statechart actively manages all states belonging to it. When a state is created,
  it immediately registers itself with it parent states.

  You do not create an instance of a state itself. The statechart manager will go through its
  state heirarchy and create the states itself.

  For more information on using statecharts, see SC.StatechartManager.

  @author Michael Cohen
  @extends SC.Object
*/
SC.State = SC.Object.extend(
  /** @lends SC.State.prototype */ {

  


  /**
    The name of the state

    @type String
  */
  name: null,

  /**
    This state's parent state. Managed by the statechart

    @type State
  */
  parentState: null,

  /**
    This state's history state. Can be null. Managed by the statechart.

    @type State
  */
  historyState: null,

  /**
    Used to indicate the initial substate of this state to enter into.

    You assign the value with the name of the state. Upon creation of
    the state, the statechart will automatically change the property
    to be a corresponding state object

    The substate is only to be this state's immediate substates. If
    no initial substate is assigned then this states initial substate
    will be an instance of an empty state (SC.EmptyState).

    Note that a statechart's root state must always have an explicity
    initial substate value assigned else an error will be thrown.

    @property {String|State}
  */
  initialSubstate: null,

  /**
    Used to indicates if this state's immediate substates are to be
    concurrent (orthogonal) to each other.

    @type Boolean
  */
  substatesAreConcurrent: NO,

  /**
    The immediate substates of this state. Managed by the statechart.

    @type Array
  */
  substates: null,

  /**
    The statechart that this state belongs to. Assigned by the owning
    statechart.

    @type Statechart
  */
  statechart: null,

  /**
    Indicates if this state has been initialized by the statechart

    @propety {Boolean}
  */
  stateIsInitialized: NO,

  /**
    An array of this state's current substates. Managed by the statechart

    @propety {Array}
  */
  currentSubstates: null,

  /**
    An array of this state's substates that are currently entered. Managed by
    the statechart.

    @type Array
  */
  enteredSubstates: null,

  /**
    Can optionally assign what route this state is to represent.

    If assigned then this state will be notified to handle the route when triggered
    any time the app's location changes and matches this state's assigned route.
    The handler invoked is this state's {@link #routeTriggered} method.

    The value assigned to this property is dependent on the underlying routing
    mechanism used by the application. The default routing mechanism is to use
    SC.routes.

    @property {String|Hash}

    @see #routeTriggered
    @see #location
    @see SC.StatechartDelegate
  */
  representRoute: null,

  /**
    Indicates who the owner is of this state. If not set on the statechart
    then the owner is the statechart, otherwise it is the assigned
    object. Managed by the statechart.

    @see SC.StatechartManager#owner

    @type SC.Object
  */
  owner: function() {
    var sc = this.get('statechart'),
        key = sc ? sc.get('statechartOwnerKey') : null,
        owner = sc ? sc.get(key) : null;
    return owner ? owner : sc;
  }.property().cacheable(),

  /**
    Returns the statechart's assigned delegate. A statechart delegate is one
    that adheres to the {@link SC.StatechartDelegate} mixin.

    @type SC.Object

    @see SC.StatechartDelegate
  */
  statechartDelegate: function() {
    return this.getPath('statechart.statechartDelegate');
  }.property().cacheable(),

  /**
    A volatile property used to get and set the app's current location.

    This computed property defers to the the statechart's delegate to
    actually update and acquire the app's location.

    Note: Binding for this particular case is discouraged since in most
    cases we need the location value immediately. If we were to use
    bindings then the location value wouldn't be updated until at least
    the end of one run loop. It is also advised that the delegate not
    have its `statechartUpdateLocationForState` and
    `statechartAcquireLocationForState` methods implemented where bindings
    are used since they will inadvertenly stall the location value from
    propogating immediately.

    @type String

    @see SC.StatechartDelegate#statechartUpdateLocationForState
    @see SC.StatechartDelegate#statechartAcquireLocationForState
  */
  location: function(key, value) {
    var sc = this.get('statechart'),
        del = this.get('statechartDelegate');

    if (value !== undefined) {
      del.statechartUpdateLocationForState(sc, value, this);
    }

    return del.statechartAcquireLocationForState(sc, this);
  }.property().idempotent(),

  init: function() {
    arguments.callee.base.apply(this,arguments);

    this._registeredEventHandlers = {};
    this._registeredStringEventHandlers = {};
    this._registeredRegExpEventHandlers = [];
    this._registeredStateObserveHandlers = {};
    this._registeredSubstatePaths = {};
    this._registeredSubstates = [];
    this._isEnteringState = NO;
    this._isExitingState = NO;

    // Setting up observes this way is faster then using .observes,
    // which adds a noticable increase in initialization time.

    var sc = this.get('statechart'),
        ownerKey = sc ? sc.get('statechartOwnerKey') : null;

    if (sc) {
      sc.addObserver(ownerKey, this, '_statechartOwnerDidChange');

      

    }
  },

  destroy: function() {
    var sc = this.get('statechart'),
        ownerKey = sc ? sc.get('statechartOwnerKey') : null;

    if (sc) {
      sc.removeObserver(ownerKey, this, '_statechartOwnerDidChange');

      

    }

    var substates = this.get('substates');
    if (substates) {
      substates.forEach(function(state) {
        state.destroy();
      });
    }

    this._teardownAllStateObserveHandlers();

    this.set('substates', null);
    this.set('currentSubstates', null);
    this.set('enteredSubstates', null);
    this.set('parentState', null);
    this.set('historyState', null);
    this.set('initialSubstate', null);
    this.set('statechart', null);

    


    this.notifyPropertyChange('owner');

    this._registeredEventHandlers = null;
    this._registeredStringEventHandlers = null;
    this._registeredRegExpEventHandlers = null;
    this._registeredStateObserveHandlers = null;
    this._registeredSubstatePaths = null;
    this._registeredSubstates = null;

    arguments.callee.base.apply(this,arguments);
  },

  /**
    Used to initialize this state. To only be called by the owning statechart.
  */
  initState: function() {
    if (this.get('stateIsInitialized')) return;

    this._registerWithParentStates();
    this._setupRouteHandling();

    var key = null,
        value = null,
        state = null,
        substates = [],
        matchedInitialSubstate = NO,
        initialSubstate = this.get('initialSubstate'),
        substatesAreConcurrent = this.get('substatesAreConcurrent'),
        valueIsFunc = NO,
        historyState = null;

    this.set('substates', substates);

    if (SC.kindOf(initialSubstate, SC.HistoryState) && initialSubstate.isClass) {
      historyState = this.createSubstate(initialSubstate);
      this.set('initialSubstate', historyState);

      if (SC.none(historyState.get('defaultState'))) {
        this.stateLogError("Initial substate is invalid. History state requires the name of a default state to be set");
        this.set('initialSubstate', null);
        historyState = null;
      }
    }

    // Iterate through all this state's substates, if any, create them, and then initialize
    // them. This causes a recursive process.
    for (key in this) {
      value = this[key];
      valueIsFunc = SC.typeOf(value) === SC.T_FUNCTION;

      if (valueIsFunc && value.isEventHandler) {
        this._registerEventHandler(key, value);
        continue;
      }

      if (valueIsFunc && value.isStateObserveHandler) {
        this._registerStateObserveHandler(key, value);
        continue;
      }

      if (valueIsFunc && value.statePlugin) {
        value = value.apply(this);
      }

      if (SC.kindOf(value, SC.State) && value.isClass && this[key] !== this.constructor) {
        state = this._addSubstate(key, value);
        if (key === initialSubstate) {
          this.set('initialSubstate', state);
          matchedInitialSubstate = YES;
        } else if (historyState && historyState.get('defaultState') === key) {
          historyState.set('defaultState', state);
          matchedInitialSubstate = YES;
        }
      }
    }

    if (!SC.none(initialSubstate) && !matchedInitialSubstate) {
      this.stateLogError("Unable to set initial substate %@ since it did not match any of state's %@ substates".fmt(initialSubstate, this));
    }

    if (substates.length === 0) {
      if (!SC.none(initialSubstate)) {
        this.stateLogWarning("Unable to make %@ an initial substate since state %@ has no substates".fmt(initialSubstate, this));
      }
    }
    else if (substates.length > 0) {
      state = this._addEmptyInitialSubstateIfNeeded();
      if (!state && initialSubstate && substatesAreConcurrent) {
        this.set('initialSubstate', null);
        this.stateLogWarning("Can not use %@ as initial substate since substates are all concurrent for state %@".fmt(initialSubstate, this));
      }
    }

    this.notifyPropertyChange('substates');
    this.set('currentSubstates', []);
    this.set('enteredSubstates', []);
    this.set('stateIsInitialized', YES);
  },

  /** @private

    Used to bind this state with a route this state is to represent if a route has been assigned.

    When invoked, the method will delegate the actual binding strategy to the statechart delegate
    via the delegate's {@link SC.StatechartDelegate#statechartBindStateToRoute} method.

    Note that a state cannot be bound to a route if this state is a concurrent state.

    @see #representRoute
    @see SC.StatechartDelegate#statechartBindStateToRoute
  */
  _setupRouteHandling: function() {
    var route = this.get('representRoute'),
        sc = this.get('statechart'),
        del = this.get('statechartDelegate');

    if (SC.none(route)) return;

    if (this.get('isConcurrentState')) {
      this.stateLogError("State %@ cannot handle route '%@' since state is concurrent".fmt(this, route));
      return;
    }

    del.statechartBindStateToRoute(sc, this, route, this.routeTriggered);
  },

  /**
    Main handler that gets triggered whenever the app's location matches this state's assigned
    route.

    When invoked the handler will first refer to the statechart delegate to determine if it
    should actually handle the route via the delegate's
    {@see SC.StatechartDelegate#statechartShouldStateHandleTriggeredRoute} method. If the
    delegate allows the handling of the route then the state will continue on with handling
    the triggered route by calling the state's {@link #handleTriggeredRoute} method, otherwise
    the state will cancel the handling and inform the delegate through the delegate's
    {@see SC.StatechartDelegate#statechartStateCancelledHandlingRoute} method.

    The handler will create a state route context ({@link SC.StateRouteContext}) object
    that packages information about what is being currently handled. This context object gets
    passed along to the delegate's invoked methods as well as the state transition process.

    Note that this method is not intended to be directly called or overridden.

    @see #representRoute
    @see SC.StatechartDelegate#statechartShouldStateHandleRoute
    @see SC.StatechartDelegate#statechartStateCancelledHandlingRoute
    @see #createStateRouteHandlerContext
    @see #handleTriggeredRoute
  */
  routeTriggered: function(params) {
    if (this._isEnteringState) return;

    var sc = this.get('statechart'),
        del = this.get('statechartDelegate'),
        loc = this.get('location');

    var attr = {
      state: this,
      location: loc,
      params: params,
      handler: this.routeTriggered
    };

    var context = this.createStateRouteHandlerContext(attr);

    if (del.statechartShouldStateHandleTriggeredRoute(sc, this, context)) {
      

      this.handleTriggeredRoute(context);
    } else {
      del.statechartStateCancelledHandlingTriggeredRoute(sc, this, context);
    }
  },

  /**
    Constructs a new instance of a state routing context object.

    @param {Hash} attr attributes to apply to the constructed object
    @return {SC.StateRouteContext}

    @see #handleRoute
  */
  createStateRouteHandlerContext: function(attr) {
    return SC.StateRouteHandlerContext.create(attr);
  },

  /**
    Invoked by this state's {@link #routeTriggered} method if the state is
    actually allowed to handle the triggered route.

    By default the method invokes a state transition to this state.
  */
  handleTriggeredRoute: function(context) {
    this.gotoState(this, context);
  },

  /** @private */
  _addEmptyInitialSubstateIfNeeded: function() {
    var initialSubstate = this.get('initialSubstate'),
        substatesAreConcurrent = this.get('substatesAreConcurrent');

    if (initialSubstate || substatesAreConcurrent) return null;

    var state = this.createSubstate(SC.EmptyState);
    this.set('initialSubstate', state);
    this.get('substates').push(state);
    this[state.get('name')] = state;
    state.initState();
    this.stateLogWarning("state %@ has no initial substate defined. Will default to using an empty state as initial substate".fmt(this));
    return state;
  },

  /** @private */
  _addSubstate: function(name, state, attr) {
    var substates = this.get('substates');

    attr = SC.clone(attr) || {};
    attr.name = name;
    state = this.createSubstate(state, attr);
    substates.push(state);
    this[name] = state;
    state.initState();
    return state;
  },

  /**
    Used to dynamically add a substate to this state. Once added successfully you
    are then able to go to it from any other state within the owning statechart.

    A couple of notes when adding a substate:

    - If this state does not have any substates, then in addition to the
      substate being added, an empty state will also be added and set as the
      initial substate. To make the added substate the initial substate, set
      this object's initialSubstate property.

    - If this state is a current state, the added substate will not be entered.

    - If this state is entered and its substates are concurrent, the added
      substate will not be entered.

    If this state is either entered or current and you'd like the added substate
    to take affect, you will need to explicitly reenter this state by calling
    its `reenter` method.

    Be aware that the name of the state you are adding must not conflict with
    the name of a property on this state or else you will get an error.
    In addition, this state must be initialized to add substates.

    @param {String} name a unique name for the given substate.
    @param {SC.State} state a class that derives from `SC.State`
    @param {Object} [attr] literal to be applied to the substate
    @returns {SC.State} an instance of the given state class
  */
  addSubstate: function(name, state, attr) {
    if (SC.empty(name)) {
      this.stateLogError("Can not add substate. name required");
      return null;
    }

    if (this[name] !== undefined) {
      this.stateLogError("Can not add substate '%@'. Already a defined property".fmt(name));
      return null;
    }

    if (!this.get('stateIsInitialized')) {
      this.stateLogError("Can not add substate '%@'. this state is not yet initialized".fmt(name));
      return null;
    }

    var len = arguments.length;

    if (len === 1) {
      state = SC.State;
    } else if (len === 2 && SC.typeOf(state) === SC.T_HASH) {
      attr = state;
      state = SC.State;
    }

    var stateIsValid = SC.kindOf(state, SC.State) && state.isClass;

    if (!stateIsValid) {
      this.stateLogError("Can not add substate '%@'. must provide a state class".fmt(name));
      return null;
    }

    state = this._addSubstate(name, state, attr);
    this._addEmptyInitialSubstateIfNeeded();
    this.notifyPropertyChange('substates');

    return state;
  },

  /**
    creates a substate for this state
  */
  createSubstate: function(state, attr) {
    attr = attr || {};
    return state.create({
      parentState: this,
      statechart: this.get('statechart')
    }, attr);
  },

  /** @private

    Registers event handlers with this state. Event handlers are special
    functions on the state that are intended to handle more than one event. This
    compared to basic functions that only respond to a single event that reflects
    the name of the method.
  */
  _registerEventHandler: function(name, handler) {
    var events = handler.events,
        event = null,
        len = events.length,
        i = 0;

    this._registeredEventHandlers[name] = handler;

    for (; i < len; i += 1) {
      event = events[i];

      if (SC.typeOf(event) === SC.T_STRING) {
        this._registeredStringEventHandlers[event] = {
          name: name,
          handler: handler
        };
        continue;
      }

      if (event instanceof RegExp) {
        this._registeredRegExpEventHandlers.push({
          name: name,
          handler: handler,
          regexp: event
        });
        continue;
      }

      this.stateLogError("Invalid event %@ for event handler %@ in state %@".fmt(event, name, this));
    }
  },

  /** @private

    Registers state observe handlers with this state. State observe handlers behave just like
    when you apply observes() on a method but will only be active when the state is currently
    entered, otherwise the handlers are inactive until the next time the state is entered
  */
  _registerStateObserveHandler: function(name, handler) {
    var i = 0,
        args = handler.args,
        len = args.length,
        arg, validHandlers = YES;

    for (; i < len; i += 1) {
      arg = args[i];
      if (SC.typeOf(arg) !== SC.T_STRING || SC.empty(arg)) {
        this.stateLogError("Invalid argument %@ for state observe handler %@ in state %@".fmt(arg, name, this));
        validHandlers = NO;
      }
    }

    if (!validHandlers) return;

    this._registeredStateObserveHandlers[name] = handler.args;
  },

  /** @private
    Will traverse up through this state's parent states to register
    this state with them.
  */
  _registerWithParentStates: function() {
    var parent = this.get('parentState');
    while (!SC.none(parent)) {
      parent._registerSubstate(this);
      parent = parent.get('parentState');
    }
  },

  /** @private
    Will register a given state as a substate of this state
  */
  _registerSubstate: function(state) {
    var path = state.pathRelativeTo(this);
    if (SC.none(path)) return;

    this._registeredSubstates.push(state);

    // Keep track of states based on their relative path
    // to this state.
    var regPaths = this._registeredSubstatePaths;
    if (regPaths[state.get('name')] === undefined) {
      regPaths[state.get('name')] = { };
    }

    var paths = regPaths[state.get('name')];
    paths[path] = state;
  },

  /**
    Will generate path for a given state that is relative to this state. It is
    required that the given state is a substate of this state.

    If the heirarchy of the given state to this state is the following:
    A > B > C, where A is this state and C is the given state, then the
    relative path generated will be "B.C"
  */
  pathRelativeTo: function(state) {
    var path = this.get('name'),
        parent = this.get('parentState');

    while (!SC.none(parent) && parent !== state) {
      path = "%@.%@".fmt(parent.get('name'), path);
      parent = parent.get('parentState');
    }

    if (parent !== state && state !== this) {
      this.stateLogError('Can not generate relative path from %@ since it not a parent state of %@'.fmt(state, this));
      return null;
    }

    return path;
  },

  /**
    Used to get a substate of this state that matches a given value.

    If the value is a state object, then the value will be returned if it is indeed
    a substate of this state, otherwise null is returned.

    If the given value is a string, then the string is assumed to be a path expression
    to a substate. The value is then parsed to find the closest match. For path expression
    syntax, refer to the {@link SC.StatePathMatcher} class.

    If there is no match then null is returned. If there is more than one match then null
    is return and an error is generated indicating ambiguity of the given value.

    An optional callback can be provided to handle the scenario when either no
    substate is found or there is more than one match. The callback is then given
    the opportunity to further handle the outcome and return a result which the
    getSubstate method will then return. The callback should have the following
    signature:

      function(state, value, paths)

    - state: The state getState was invoked on
    - value: The value supplied to getState
    - paths: An array of substate paths that matched the given value

    If there were no matches then `paths` is not provided to the callback.

    You can also optionally provide a target that the callback is invoked on. If no
    target is provided then this state is used as the target.

    @param value {State|String} used to identify a substate of this state
    @param [callback] {Function} the callback
    @param [target] {Object} the target
  */
  getSubstate: function(value, callback, target) {
    if (!value) return null;

    var valueType = SC.typeOf(value);

    // If the value is an object then just check if the value is
    // a registered substate of this state, and if so return it.
    if (valueType === SC.T_OBJECT) {
      return this._registeredSubstates.indexOf(value) > -1 ? value : null;
    }

    if (valueType !== SC.T_STRING) {
      this.stateLogError("Can not find matching subtype. value must be an object or string: %@".fmt(value));
      return null;
    }

    var matcher = SC.StatePathMatcher.create({ state: this, expression: value }),
        matches = [], key;

    if (matcher.get('tokens').length === 0) return null;

    var paths = this._registeredSubstatePaths[matcher.get('lastPart')];
    if (!paths) return this._notifySubstateNotFound(callback, target, value);

    for (key in paths) {
      if (matcher.match(key)) {
        matches.push(paths[key]);
      }
    }

    if (matches.length === 1) return matches[0];

    if (matches.length > 1) {
      var keys = [];
      for (key in paths) { keys.push(key); }

      if (callback) return this._notifySubstateNotFound(callback, target, value, keys);

      var msg = "Can not find substate matching '%@' in state %@. Ambiguous with the following: %@";
      this.stateLogError(msg.fmt(value, this.get('fullPath'), keys.join(', ')));
    }

    return this._notifySubstateNotFound(callback, target, value);
  },

  /** @private */
  _notifySubstateNotFound: function(callback, target, value, keys) {
    return callback ? callback.call(target || this, this, value, keys) : null;
  },

  /**
    Will attempt to get a state relative to this state.

    A state is returned based on the following:

    1. First check this state's substates for a match; and
    2. If no matching substate then attempt to get the state from
       this state's parent state.

    Therefore states are recursively traversed up to the root state
    to identify a match, and if found is ultimately returned, otherwise
    null is returned. In the case that the value supplied is ambiguous
    an error message is returned.

    The value provided can either be a state object or a state path expression.
    For path expression syntax, refer to the {@link SC.StatePathMatcher} class.
  */
  getState: function(value) {
    if (value === this.get('name')) return this;
    if (SC.kindOf(value, SC.State)) return value;
    return this.getSubstate(value, this._handleSubstateNotFound);
  },

  /** @private */
  _handleSubstateNotFound: function(state, value, keys) {
    var parentState = this.get('parentState');

    if (parentState) return parentState.getState(value);

    if (keys) {
      var msg = "Can not find state matching '%@'. Ambiguous with the following: %@";
      this.stateLogError(msg.fmt(value, keys.join(', ')));
    }

    return null;
  },

  /**
    Used to go to a state in the statechart either directly from this state if it is a current state,
    or from the first relative current state from this state.

    If the value given is a string then it is considered a state path expression. The path is then
    used to find a state relative to this state based on rules of the {@link #getState} method.

    @param value {SC.State|String} the state to go to
    @param [context] {Hash|Object} context object that will be supplied to all states that are
           exited and entered during the state transition process. Context can not be an instance of
           SC.State.
  */
  gotoState: function(value, context) {
    var state = this.getState(value);

    if (!state) {
      var msg = "can not go to state %@ from state %@. Invalid value.";
      this.stateLogError(msg.fmt(value, this));
      return;
    }

    var from = this.findFirstRelativeCurrentState(state);
    this.get('statechart').gotoState(state, from, false, context);
  },

  /**
    Used to go to a given state's history state in the statechart either directly from this state if it
    is a current state or from one of this state's current substates.

    If the value given is a string then it is considered a state path expression. The path is then
    used to find a state relative to this state based on rules of the {@link #getState} method.

    Method can be called in the following ways:

        // With one argument
        gotoHistoryState(<value>)

        // With two arguments
        gotoHistoryState(<value>, <boolean | hash>)

        // With three arguments
        gotoHistoryState(<value>, <boolean>, <hash>)

    Where <value> is either a string or a SC.State object and <hash> is a regular JS hash object.

    @param value {SC.State|String} the state whose history state to go to
    @param [recusive] {Boolean} indicates whether to follow history states recusively starting
           from the given state
    @param [context] {Hash|Object} context object that will be supplied to all states that are exited
           entered during the state transition process. Context can not be an instance of SC.State.
  */
  gotoHistoryState: function(value, recursive, context) {
    var state = this.getState(value);

    if (!state) {
      var msg = "can not go to history state %@ from state %@. Invalid value.";
      this.stateLogError(msg.fmt(value, this));
      return;
    }

    var from = this.findFirstRelativeCurrentState(state);
    this.get('statechart').gotoHistoryState(state, from, recursive, context);
  },

  /**
    Resumes an active goto state transition process that has been suspended.
  */
  resumeGotoState: function() {
    this.get('statechart').resumeGotoState();
  },

  /**
    Used to check if a given state is a current substate of this state. Mainly used in cases
    when this state is a concurrent state.

    @param state {State|String} either a state object or the name of a state
    @returns {Boolean} true is the given state is a current substate, otherwise false is returned
  */
  stateIsCurrentSubstate: function(state) {
    if (SC.typeOf(state) === SC.T_STRING) state = this.get('statechart').getState(state);
    var current = this.get('currentSubstates');
    return !!current && current.indexOf(state) >= 0;
  },

  /**
    Used to check if a given state is a substate of this state that is currently entered.

    @param state {State|String} either a state object of the name of a state
    @returns {Boolean} true if the given state is a entered substate, otherwise false is returned
  */
  stateIsEnteredSubstate: function(state) {
    if (SC.typeOf(state) === SC.T_STRING) state = this.get('statechart').getState(state);
    var entered = this.get('enteredSubstates');
    return !!entered && entered.indexOf(state) >= 0;
  },

  /**
    Indicates if this state is the root state of the statechart.

    @type Boolean
  */
  isRootState: function() {
    return this.getPath('statechart.rootState') === this;
  }.property(),

  /**
    Indicates if this state is a current state of the statechart.

    @type Boolean
  */
  isCurrentState: function() {
    return this.stateIsCurrentSubstate(this);
  }.property('currentSubstates').cacheable(),

  /**
    Indicates if this state is a concurrent state

    @type Boolean
  */
  isConcurrentState: function() {
    return this.getPath('parentState.substatesAreConcurrent');
  }.property(),

  /**
    Indicates if this state is a currently entered state.

    A state is currently entered if during a state transition process the
    state's enterState method was invoked, but only after its exitState method
    was called, if at all.
  */
  isEnteredState: function() {
    return this.stateIsEnteredSubstate(this);
  }.property('enteredSubstates').cacheable(),

  /**
    Indicate if this state has any substates

    @propety {Boolean}
  */
  hasSubstates: function() {
    return this.getPath('substates.length') > 0;
  }.property('substates'),

  /**
    Indicates if this state has any current substates
  */
  hasCurrentSubstates: function() {
    var current = this.get('currentSubstates');
    return !!current && current.get('length') > 0;
  }.property('currentSubstates').cacheable(),

  /**
    Indicates if this state has any currently entered substates
  */
  hasEnteredSubstates: function() {
    var entered = this.get('enteredSubstates');
    return !!entered  && entered.get('length') > 0;
  }.property('enteredSubstates').cacheable(),

  /**
    Will attempt to find a current state in the statechart that is relative to
    this state.

    Ordered set of rules to find a relative current state:

      1. If this state is a current state then it will be returned

      2. If this state has no current states and this state has a parent state then
        return parent state's first relative current state, otherwise return null

      3. If this state has more than one current state then use the given anchor state
         to get a corresponding substate that can be used to find a current state relative
         to the substate, if a substate was found.

      4. If (3) did not find a relative current state then default to returning
         this state's first current substate.

    @param anchor {State|String} Optional. a substate of this state used to help direct
      finding a current state
    @return {SC.State} a current state
  */
  findFirstRelativeCurrentState: function(anchor) {
    if (this.get('isCurrentState')) return this;

    var currentSubstates = this.get('currentSubstates') || [],
        numCurrent = currentSubstates.get('length'),
        parent = this.get('parentState');

    if (numCurrent === 0) {
      return parent ? parent.findFirstRelativeCurrentState() : null;
    }

    if (numCurrent > 1) {
      anchor = this.getSubstate(anchor);
      if (anchor) return anchor.findFirstRelativeCurrentState();
    }

    return currentSubstates[0];
  },

  /**
    Used to re-enter this state. Call this only when the state a current state of
    the statechart.
  */
  reenter: function() {
    if (this.get('isEnteredState')) {
      this.gotoState(this);
    } else {
       SC.Logger.error('Can not re-enter state %@ since it is not an entered state in the statechart'.fmt(this));
    }
  },

  /**
    Called by the statechart to allow a state to try and handle the given event. If the
    event is handled by the state then YES is returned, otherwise NO.

    There is a particular order in how an event is handled by a state:

     1. Basic function whose name matches the event
     2. Registered event handler that is associated with an event represented as a string
     3. Registered event handler that is associated with events matching a regular expression
     4. The unknownEvent function

    Use of event handlers that are associated with events matching a regular expression may
    incur a performance hit, so they should be used sparingly.

    The unknownEvent function is only invoked if the state has it, otherwise it is skipped. Note that
    you should be careful when using unknownEvent since it can be either abused or cause unexpected
    behavior.

    Example of a state using all four event handling techniques:

        SC.State.extend({

          // Basic function handling event 'foo'
          foo: function(arg1, arg2) { ... },

          // event handler that handles 'frozen' and 'canuck'
          eventHandlerA: function(event, arg1, arg2) {
            ...
          }.handleEvent('frozen', 'canuck'),

          // event handler that handles events matching the regular expression /num\d/
          //   ex. num1, num2
          eventHandlerB: function(event, arg1, arg2) {
            ...
          }.handleEvent(/num\d/),

          // Handle any event that was not handled by some other
          // method on the state
          unknownEvent: function(event, arg1, arg2) {

          }

        });
  */
  tryToHandleEvent: function(event, arg1, arg2) {
    


    var sc = this.get('statechart'),
        ret;

    // First check if the name of the event is the same as a registered event handler. If so,
    // then do not handle the event.
    if (this._registeredEventHandlers[event]) {
      this.stateLogWarning("state %@ can not handle event '%@' since it is a registered event handler".fmt(this, event));
      return NO;
    }

    if (this._registeredStateObserveHandlers[event]) {
      this.stateLogWarning("state %@ can not handle event '%@' since it is a registered state observe handler".fmt(this, event));
      return NO;
    }

    // Now begin by trying a basic method on the state to respond to the event
    if (SC.typeOf(this[event]) === SC.T_FUNCTION) {
      

      sc.stateWillTryToHandleEvent(this, event, event);
      ret = (this[event](arg1, arg2) !== NO);
      sc.stateDidTryToHandleEvent(this, event, event, ret);
      return ret;
    }

    // Try an event handler that is associated with an event represented as a string
    var handler = this._registeredStringEventHandlers[event];
    if (handler) {
      

      sc.stateWillTryToHandleEvent(this, event, handler.name);
      ret = (handler.handler.call(this, event, arg1, arg2) !== NO);
      sc.stateDidTryToHandleEvent(this, event, handler.name, ret);
      return ret;
    }

    // Try an event handler that is associated with events matching a regular expression

    var len = this._registeredRegExpEventHandlers.length,
        i = 0;

    for (; i < len; i += 1) {
      handler = this._registeredRegExpEventHandlers[i];
      if (event.match(handler.regexp)) {
        

        sc.stateWillTryToHandleEvent(this, event, handler.name);
        ret = (handler.handler.call(this, event, arg1, arg2) !== NO);
        sc.stateDidTryToHandleEvent(this, event, handler.name, ret);
        return ret;
      }
    }

    // Final attempt. If the state has an unknownEvent function then invoke it to
    // handle the event
    if (SC.typeOf(this['unknownEvent']) === SC.T_FUNCTION) {
      

      sc.stateWillTryToHandleEvent(this, event, 'unknownEvent');
      ret = (this.unknownEvent(event, arg1, arg2) !== NO);
      sc.stateDidTryToHandleEvent(this, event, 'unknownEvent', ret);
      return ret;
    }

    // Nothing was able to handle the given event for this state
    return NO;
  },

  /**
    Called whenever this state is to be entered during a state transition process. This
    is useful when you want the state to perform some initial set up procedures.

    If when entering the state you want to perform some kind of asynchronous action, such
    as an animation or fetching remote data, then you need to return an asynchronous
    action, which is done like so:

        enterState: function() {
          return this.performAsync('foo');
        }

    After returning an action to be performed asynchronously, the statechart will suspend
    the active state transition process. In order to resume the process, you must call
    this state's resumeGotoState method or the statechart's resumeGotoState. If no asynchronous
    action is to be perform, then nothing needs to be returned.

    When the enterState method is called, an optional context value may be supplied if
    one was provided to the gotoState method.

    In the case that the context being supplied is a state context object
    ({@link SC.StateRouteHandlerContext}), an optional `enterStateByRoute` method can be invoked
    on this state if the state has implemented the method. If `enterStateByRoute` is
    not part of this state then the `enterState` method will be invoked by default. The
    `enterStateByRoute` is simply a convenience method that helps removes checks to
    determine if the context provide is a state route context object.

    @param {Hash} [context] value if one was supplied to gotoState when invoked

    @see #representRoute
  */
  enterState: function(context) { },

  /**
    Notification called just before enterState is invoked.

    Note: This is intended to be used by the owning statechart but it can be overridden if
    you need to do something special.

    @param {Hash} [context] value if one was supplied to gotoState when invoked
    @see #enterState
  */
  stateWillBecomeEntered: function(context) {
    this._isEnteringState = YES;
  },

  /**
    Notification called just after enterState is invoked.

    Note: This is intended to be used by the owning statechart but it can be overridden if
    you need to do something special.

    @param context {Hash} Optional value if one was supplied to gotoState when invoked
    @see #enterState
  */
  stateDidBecomeEntered: function(context) {
    this._setupAllStateObserveHandlers();
    this._isEnteringState = NO;
  },

  /**
    Called whenever this state is to be exited during a state transition process. This is
    useful when you want the state to peform some clean up procedures.

    If when exiting the state you want to perform some kind of asynchronous action, such
    as an animation or fetching remote data, then you need to return an asynchronous
    action, which is done like so:

        exitState: function() {
          return this.performAsync('foo');
        }

    After returning an action to be performed asynchronously, the statechart will suspend
    the active state transition process. In order to resume the process, you must call
    this state's resumeGotoState method or the statechart's resumeGotoState. If no asynchronous
    action is to be perform, then nothing needs to be returned.

    When the exitState method is called, an optional context value may be supplied if
    one was provided to the gotoState method.

    @param context {Hash} Optional value if one was supplied to gotoState when invoked
  */
  exitState: function(context) { },

  /**
    Notification called just before exitState is invoked.

    Note: This is intended to be used by the owning statechart but it can be overridden
    if you need to do something special.

    @param context {Hash} Optional value if one was supplied to gotoState when invoked
    @see #exitState
  */
  stateWillBecomeExited: function(context) {
    this._isExitingState = YES;
    this._teardownAllStateObserveHandlers();
  },

  /**
    Notification called just after exitState is invoked.

    Note: This is intended to be used by the owning statechart but it can be overridden
    if you need to do something special.

    @param context {Hash} Optional value if one was supplied to gotoState when invoked
    @see #exitState
  */
  stateDidBecomeExited: function(context) {
    this._isExitingState = NO;
  },

  /** @private

    Used to setup all the state observer handlers. Should be done when
    the state has been entered.
  */
  _setupAllStateObserveHandlers: function() {
    this._configureAllStateObserveHandlers('addObserver');
  },

  /** @private

    Used to teardown all the state observer handlers. Should be done when
    the state is being exited.
  */
  _teardownAllStateObserveHandlers: function() {
    this._configureAllStateObserveHandlers('removeObserver');
  },

  /** @private

    Primary method used to either add or remove this state as an observer
    based on all the state observe handlers that have been registered with
    this state.

    Note: The code to add and remove the state as an observer has been
    taken from the observerable mixin and made slightly more generic. However,
    having this code in two different places is not ideal, but for now this
    will have to do. In the future the code should be refactored so that
    there is one common function that both the observerable mixin and the
    statechart framework use.
  */
  _configureAllStateObserveHandlers: function(action) {
    var key, values, dotIndex, path, observer, i, root;

    for (key in this._registeredStateObserveHandlers) {
      values = this._registeredStateObserveHandlers[key];
      for (i = 0; i < values.length; i += 1) {
        path = values[i]; observer = key;

        // Use the dot index in the path to determine how the state
        // should add itself as an observer.

        dotIndex = path.indexOf('.');

        if (dotIndex < 0) {
          this[action](path, this, observer);
        } else if (path.indexOf('*') === 0) {
          this[action](path.slice(1), this, observer);
        } else {
          root = null;

          if (dotIndex === 0) {
            root = this; path = path.slice(1);
          } else if (dotIndex === 4 && path.slice(0, 5) === 'this.') {
            root = this; path = path.slice(5);
          } else if (dotIndex < 0 && path.length === 4 && path === 'this') {
            root = this; path = '';
          }

          SC.Observers[action](path, this, observer, root);
        }
      }
    }
  },

  /**
    Call when an asynchronous action need to be performed when either entering or exiting
    a state.

    @see enterState
    @see exitState
  */
  performAsync: function(func, arg1, arg2) {
    return SC.Async.perform(func, arg1, arg2);
  },

  /** @override

    Returns YES if this state can respond to the given event, otherwise
    NO is returned

    @param event {String} the value to check
    @returns {Boolean}
  */
  respondsToEvent: function(event) {
    if (this._registeredEventHandlers[event]) return false;
    if (SC.typeOf(this[event]) === SC.T_FUNCTION) return true;
    if (this._registeredStringEventHandlers[event]) return true;
    if (this._registeredStateObserveHandlers[event]) return false;

    var len = this._registeredRegExpEventHandlers.length,
        i = 0,
        handler;

    for (; i < len; i += 1) {
      handler = this._registeredRegExpEventHandlers[i];
      if (event.match(handler.regexp)) return true;
    }

    return SC.typeOf(this['unknownEvent']) === SC.T_FUNCTION;
  },

  /**
    Returns the path for this state relative to the statechart's
    root state.

    The path is a dot-notation string representing the path from
    this state to the statechart's root state, but without including
    the root state in the path. For instance, if the name of this
    state if "foo" and the parent state's name is "bar" where bar's
    parent state is the root state, then the full path is "bar.foo"

    @type String
  */
  fullPath: function() {
    var root = this.getPath('statechart.rootState');
    if (!root) return this.get('name');
    return this.pathRelativeTo(root);
  }.property('name', 'parentState').cacheable(),

  toString: function() {
    return this.get('fullPath');
  },

  /** @private */
  _statechartOwnerDidChange: function() {
    this.notifyPropertyChange('owner');
  },

  /**
    Used to log a state warning message
  */
  stateLogWarning: function(msg) {
    var sc = this.get('statechart');
    sc.statechartLogWarning(msg);
  },

  /**
    Used to log a state error message
  */
  stateLogError: function(msg) {
    var sc = this.get('statechart');
    sc.statechartLogError(msg);
  }

});

/**
  Use this when you want to plug-in a state into a statechart. This is beneficial
  in cases where you split your statechart's states up into multiple files and
  don't want to fuss with the sc_require construct.

  Example:

      MyApp.statechart = SC.Statechart.create({
        rootState: SC.State.design({
          initialSubstate: 'a',
          a: SC.State.plugin('path.to.a.state.class'),
          b: SC.State.plugin('path.to.another.state.class')
        })
      });

  You can also supply hashes the plugin feature in order to enhance a state or
  implement required functionality:

      SomeMixin = { ... };

      stateA: SC.State.plugin('path.to.state', SomeMixin, { ... })

  @param value {String} property path to a state class
  @param args {Hash,...} Optional. Hash objects to be added to the created state
*/
SC.State.plugin = function(value) {
  var args;

  // Fast arguments access.
  // Accessing `arguments.length` is just a Number and doesn't materialize the `arguments` object, which is costly.
  args = new Array(arguments.length - 1); // SC.A(arguments).shift()
  for (var i = 0, len = args.length; i < len; i++) { args[i] = arguments[i + 1]; }

  var func = function() {
    var klass = SC.objectForPropertyPath(value);
    if (!klass) {
      console.error('SC.State.plugin: Unable to determine path %@'.fmt(value));
      return undefined;
    }
    if (!klass.isClass || !klass.kindOf(SC.State)) {
      console.error('SC.State.plugin: Unable to extend. %@ must be a class extending from SC.State'.fmt(value));
      return undefined;
    }
    return klass.extend.apply(klass, args);
  };
  func.statePlugin = YES;
  return func;
};

SC.State.design = SC.State.extend;

/* >>>>>>>>>> BEGIN source/system/empty_state.js */
// ==========================================================================
// Project:   SC.Statechart - A Statechart Framework for SproutCore
// Copyright: ©2010, 2011 Michael Cohen, and contributors.
//            Portions @2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/*globals SC */

sc_require('system/state');

/** 
  The default name given to an empty state
*/
SC.EMPTY_STATE_NAME = "__EMPTY_STATE__";

/**
  @class
  
  Represents an empty state that gets assigned as a state's initial substate 
  if the state does not have an initial substate defined.

  @extends SC.State
*/
SC.EmptyState = SC.State.extend(/** @scope SC.EmptyState.prototype */{
  
  name: SC.EMPTY_STATE_NAME,
  
  enterState: function() {
    var msg = "No initial substate was defined for state %@. Entering default empty state";
    this.stateLogWarning(msg.fmt(this.get('parentState')));
  }
  
});

/* >>>>>>>>>> BEGIN source/system/history_state.js */
// ==========================================================================
// Project:   SC.Statechart - A Statechart Framework for SproutCore
// Copyright: ©2010, 2011 Michael Cohen, and contributors.
//            Portions @2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/*globals SC */

sc_require('system/state');

/**
  @class

  Represents a history state that can be assigned to a SC.State object's
  initialSubstate property.

  If a SC.HistoryState object is assigned to a state's initial substate,
  then after a state is entered the statechart will refer to the history
  state object to determine the next course of action. If the state has
  its historyState property assigned then the that state will be entered,
  otherwise the default state assigned to history state object will be entered.

  An example of how to use:

    stateA: SC.State.design({

      initialSubstate: SC.HistoryState({
        defaultState: 'stateB'
      }),

      stateB: SC.State.design({ ... }),

      stateC: SC.State.design({ ... })

    })

  @author Michael Cohen
  @extends SC.Object
*/
SC.HistoryState = SC.Object.extend(
  /** @scope SC.HistoryState.prototype */{

  /**
    Used to indicate if the statechart should recurse the
    history states after entering the this object's parent state

    @type Boolean
  */
  isRecursive: NO,

  /**
    The default state to enter if the parent state does not
    yet have its historyState property assigned to something
    other than null.

    The value assigned to this property must be the name of an
    immediate substate that belongs to the parent state. The
    statechart will manage the property upon initialization.

    @type String
  */
  defaultState: null,

  /** @private
    Managed by the statechart

    The statechart that owns this object.
  */
  statechart: null,

  /** @private
    Managed by the statechart

    The state that owns this object
  */
  parentState: null,

  /**
    Used by the statechart during a state transition process.

    Returns a state to enter based on whether the parent state has
    its historyState property assigned. If not then this object's
    assigned default state is returned.
  */
  state: function() {
    var defaultState = this.get('defaultState'),
        historyState = this.getPath('parentState.historyState');
    return !!historyState ? historyState : defaultState;
  }.property().cacheable(),

  /** @private */
  parentHistoryStateDidChange: function() {
    this.notifyPropertyChange('state');
  }.observes('*parentState.historyState')

});

/* >>>>>>>>>> BEGIN source/system/state_route_handler_context.js */
// ==========================================================================
// Project:   SC.Statechart - A Statechart Framework for SproutCore
// Copyright: ©2010, 2011 Michael Cohen, and contributors.
//            Portions @2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/*globals SC */

/**
  @class

  Represents contextual information for whenever a state handles a triggered
  route. In additional to retaining contextual information, you can also
  use the object to retry trigging the state's route handler. Useful in cases
  where you need to defer the handling of the route for a later time.

  @see SC.State

  @extends SC.Object
  @author Michael Cohen
*/
SC.StateRouteHandlerContext = SC.Object.extend(
  /** @scope SC.StateRouteContext.prototype */{

  /**
    The state that constructed this context object.

    @property {SC.State}
  */
  state: null,

  /**
    The location that caused the state's route to be
    triggered.

    @type String
  */
  location: null,

  /**
    The parameters that were supplied to the state's
    handler when the state's route was triggered.

    @type Hash
  */
  params: null,

  /**
    The handler that got invoked when the state's
    route was triggered. This can either be a reference
    to the actual method or a name of the method.

    @property {Function|String}
  */
  handler: null,

  /**
    Used to retry invoking the state's handler for when
    the state's route gets triggered. When called this will
    essentially perform the same call as when the handler
    was originally triggered on state.
  */
  retry: function() {
    var state = this.get('state'),
        params = this.get('params'),
        handler = this.get('handler');

    if (SC.typeOf(handler) === SC.T_STRING) {
      handler = state[handler];
    }

    if (SC.typeOf(handler) === SC.T_FUNCTION) {
      handler.apply(state, [params]);
    }
  }

});

/* >>>>>>>>>> BEGIN source/system/statechart.js */
// ==========================================================================
// Project:   SC.Statechart - A Statechart Framework for SproutCore
// Copyright: ©2010, 2011 Michael Cohen, and contributors.
//            Portions @2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/*global SC */

sc_require('system/state');
sc_require('mixins/statechart_delegate');

/**
  @class

  The startchart manager mixin allows an object to be a statechart. By becoming a statechart, the
  object can then be manage a set of its own states.

  This implementation of the statechart manager closely follows the concepts stated in D. Harel's
  original paper "Statecharts: A Visual Formalism For Complex Systems"
  (www.wisdom.weizmann.ac.il/~harel/papers/Statecharts.pdf).

  The statechart allows for complex state heircharies by nesting states within states, and
  allows for state orthogonality based on the use of concurrent states.

  At minimum, a statechart must have one state: The root state. All other states in the statechart
  are a decendents (substates) of the root state.

  The following example shows how states are nested within a statechart:

      MyApp.Statechart = SC.Object.extend(SC.StatechartManager, {
        rootState: SC.State.design({
          initialSubstate: 'stateA',

          stateA: SC.State.design({
            // ... can continue to nest further states
          }),

          stateB: SC.State.design({
            // ... can continue to nest further states
          })
        })
      });

  Note how in the example above, the root state as an explicit initial substate to enter into. If no
  initial substate is provided, then the statechart will default to the the state's first substate.

  You can also defined states without explicitly defining the root state. To do so, simply create properties
  on your object that represents states. Upon initialization, a root state will be constructed automatically
  by the mixin and make the states on the object substates of the root state. As an example:

      MyApp.Statechart = SC.Object.extend(SC.StatechartManager, {
        initialState: 'stateA',

        stateA: SC.State.design({
          // ... can continue to nest further states
        }),

        stateB: SC.State.design({
          // ... can continue to nest further states
        })
      });

  If you liked to specify a class that should be used as the root state but using the above method to defined
  states, you can set the rootStateExample property with a class that extends from SC.State. If the
  rootStateExample property is not explicitly assigned the then default class used will be SC.State.

  To provide your statechart with orthogonality, you use concurrent states. If you use concurrent states,
  then your statechart will have multiple current states. That is because each concurrent state represents an
  independent state structure from other concurrent states. The following example shows how to provide your
  statechart with concurrent states:

      MyApp.Statechart = SC.Object.extend(SC.StatechartManager, {
        rootState: SC.State.design({
          substatesAreConcurrent: YES,

          stateA: SC.State.design({
            // ... can continue to nest further states
          }),

          stateB: SC.State.design({
            // ... can continue to nest further states
          })
        })
      });

  Above, to indicate that a state's substates are concurrent, you just have to set the substatesAreConcurrent to
  YES. Once done, then stateA and stateB will be independent of each other and each will manage their
  own current substates. The root state will then have more then one current substate.

  To define concurrent states directly on the object without explicitly defining a root, you can do the
  following:

      MyApp.Statechart = SC.Object.extend(SC.StatechartManager, {
        statesAreConcurrent: YES,

        stateA: SC.State.design({
          // ... can continue to nest further states
        }),

        stateB: SC.State.design({
          // ... can continue to nest further states
        })
      });

  Remember that a startchart can have a mixture of nested and concurrent states in order for you to
  create as complex of statecharts that suite your needs. Here is an example of a mixed state structure:

      MyApp.Statechart = SC.Object.extend(SC.StatechartManager, {
        rootState: SC.State.design({
          initialSubstate: 'stateA',

          stateA: SC.State.design({
            substatesAreConcurrent: YES,

            stateM: SC.State.design({ ... })
            stateN: SC.State.design({ ... })
            stateO: SC.State.design({ ... })
          }),

          stateB: SC.State.design({
            initialSubstate: 'stateX',

            stateX: SC.State.design({ ... })
            stateY: SC.State.design({ ... })
          })
        })
      });

  Depending on your needs, a statechart can have lots of states, which can become hard to manage all within
  one file. To modularize your states and make them easier to manage and maintain, you can plug-in states
  into other states. Let's say we are using the statechart in the last example above, and all the code is
  within one file. We could update the code and split the logic across two or more files like so:

      // state_a.js

      MyApp.StateA = SC.State.extend({
        substatesAreConcurrent: YES,

        stateM: SC.State.design({ ... })
        stateN: SC.State.design({ ... })
        stateO: SC.State.design({ ... })
      });

      // state_b.js

      MyApp.StateB = SC.State.extend({
        substatesAreConcurrent: YES,

        stateM: SC.State.design({ ... })
        stateN: SC.State.design({ ... })
        stateO: SC.State.design({ ... })
      });

      // statechart.js

      MyApp.Statechart = SC.Object.extend(SC.StatechartManager, {
        rootState: SC.State.design({
          initialSubstate: 'stateA',
          stateA: SC.State.plugin('MyApp.StateA'),
          stateB: SC.State.plugin('MyApp.StateB')
        })
      });

  Using state plug-in functionality is optional. If you use the plug-in feature you can break up your statechart
  into as many files as you see fit.

  @author Michael Cohen
*/

SC.StatechartManager = /** @scope SC.StatechartManager.prototype */{

  


  // Walk like a duck
  isResponderContext: YES,

  // Walk like a duck
  isStatechart: YES,

  /**
    Indicates if this statechart has been initialized

    @type Boolean
  */
  statechartIsInitialized: NO,

  /**
    Optional name you can provide the statechart with. If set this will be included
    in tracing and error output as well as detail output. Useful for
    debugging/diagnostic purposes
  */
  name: null,

  /**
    The root state of this statechart. All statecharts must have a root state.

    If this property is left unassigned then when the statechart is initialized
    it will used the rootStateExample, initialState, and statesAreConcurrent
    properties to construct a root state.

    @see #rootStateExample
    @see #initialState
    @see #statesAreConcurrent

    @property {SC.State}
  */
  rootState: null,

  /**
    Represents the class used to construct a class that will be the root state for
    this statechart. The class assigned must derive from SC.State.

    This property will only be used if the rootState property is not assigned.

    @see #rootState

    @property {SC.State}
  */
  rootStateExample: SC.State,

  /**
    Indicates what state should be the initial state of this statechart. The value
    assigned must be the name of a property on this object that represents a state.
    As well, the statesAreConcurrent must be set to NO.

    This property will only be used if the rootState property is not assigned.

    @see #rootState

    @type String
  */
  initialState: null,

  /**
    Indicates if properties on this object representing states are concurrent to each other.
    If YES then they are concurrent, otherwise they are not. If the YES, then the
    initialState property must not be assigned.

    This property will only be used if the rootState property is not assigned.

    @see #rootState

    @type Boolean
  */
  statesAreConcurrent: NO,

  /**
    Used to specify what property (key) on the statechart should be used as the owner property. By
    default the property is 'owner'.

    @type String
  */
  statechartOwnerKey: 'owner',

  /**
    Sets who the owner is of this statechart. If null then the owner is this object otherwise
    the owner is the assigned object.

    @see #statechartOwnerKey

    @type SC.Object
  */
  owner: null,

  /**
    Indicates if the statechart should be automatically initialized by this
    object after it has been created. If YES then initStatechart will be
    called automatically, otherwise it will not.

    @type Boolean
  */
  autoInitStatechart: YES,

  /**
    If yes, any warning messages produced by the statechart or any of its states will
    not be logged, otherwise all warning messages will be logged.

    While designing and debugging your statechart, it's best to keep this value false.
    In production you can then suppress the warning messages.

    @type Boolean
  */
  suppressStatechartWarnings: NO,

  /**
    A statechart delegate used by the statechart and the states that the statechart
    manages. The value assigned must adhere to the {@link SC.StatechartDelegate} mixin.

    @type SC.Object

    @see SC.StatechartDelegate
  */
  delegate: null,

  /**
    Computed property that returns an objects that adheres to the
    {@link SC.StatechartDelegate} mixin. If the {@link #delegate} is not
    assigned then this object is the default value returned.

    @see SC.StatechartDelegate
    @see #delegate
  */
  statechartDelegate: function () {
    var del = this.get('delegate');
    return this.delegateFor('isStatechartDelegate', del);
  }.property('delegate'),

  initMixin: function () {
    if (this.get('autoInitStatechart')) {
      this.initStatechart();
    }
  },

  destroyMixin: function () {
    var root = this.get('rootState');

    


    root.destroy();
    this.set('rootState', null);
    this.notifyPropertyChange('currentStates');
  },

  /**
    Initializes the statechart. By initializing the statechart, it will create all the states and register
    them with the statechart. Once complete, the statechart can be used to go to states and send events to.
  */
  initStatechart: function () {
    if (this.get('statechartIsInitialized')) return;

    this._gotoStateLocked = NO;
    this._sendEventLocked = NO;
    this._pendingStateTransitions = [];
    this._pendingSentEvents = [];

    this.sendAction = this.sendEvent;

    


    var rootState = this.get('rootState'),
        msg;

    // If no root state was explicitly defined then try to construct
    // a root state class
    if (!rootState) {
      rootState = this._constructRootStateClass();
    }
    else if (SC.typeOf(rootState) === SC.T_FUNCTION && rootState.statePlugin) {
      rootState = rootState.apply(this);
    }

    if (!(SC.kindOf(rootState, SC.State) && rootState.isClass)) {
      msg = "Unable to initialize statechart. Root state must be a state class";
      this.statechartLogError(msg);
      SC.throw(msg);
    }

    rootState = this.createRootState(rootState, {
      statechart: this,
      name: SC.ROOT_STATE_NAME
    });

    this.set('rootState', rootState);
    rootState.initState();

    if (SC.kindOf(rootState.get('initialSubstate'), SC.EmptyState)) {
      msg = "Unable to initialize statechart. Root state must have an initial substate explicitly defined";
      this.statechartLogError(msg);
      SC.throw(msg);
    }

    if (!SC.empty(this.get('initialState'))) {
      var key = 'initialState';
      this.set(key, rootState.get(this.get(key)));
    }

    this.set('statechartIsInitialized', YES);
    this.gotoState(rootState);

    

  },

  /**
    Will create a root state for the statechart
  */
  createRootState: function (state, attrs) {
    if (!attrs) attrs = {};
    state = state.create(attrs);
    return state;
  },

  /**
    Returns an array of all the current states for this statechart

    @returns {Array} the current states
  */
  currentStates: function () {
    return this.getPath('rootState.currentSubstates');
  }.property().cacheable(),

  /**
    Returns the first current state for this statechart.

    @return {SC.State}
  */
  firstCurrentState: function () {
    var cs = this.get('currentStates');
    return cs ? cs.objectAt(0) : null;
  }.property('currentStates').cacheable(),

  /**
    Returns the count of the current states for this statechart

    @returns {Number} the count
  */
  currentStateCount: function () {
    return this.getPath('currentStates.length');
  }.property('currentStates').cacheable(),

  /**
    Checks if a given state is a current state of this statechart.

    @param state {State|String} the state to check
    @returns {Boolean} true if the state is a current state, otherwise fals is returned
  */
  stateIsCurrentState: function (state) {
    return this.get('rootState').stateIsCurrentSubstate(state);
  },

  /**
    Returns an array of all the states that are currently entered for
    this statechart.

    @returns {Array} the currently entered states
  */
  enteredStates: function () {
    return this.getPath('rootState.enteredSubstates');
  }.property().cacheable(),

  /**
    Checks if a given state is a currently entered state of this statechart.

    @param state {State|String} the state to check
    @returns {Boolean} true if the state is a currently entered state, otherwise false is returned
  */
  stateIsEntered: function (state) {
    return this.get('rootState').stateIsEnteredSubstate(state);
  },

  /**
    Checks if the given value represents a state is this statechart

    @param value {State|String} either a state object or the name of a state
    @returns {Boolean} true if the state does belong ot the statechart, otherwise false is returned
  */
  doesContainState: function (value) {
    return !SC.none(this.getState(value));
  },

  /**
    Gets a state from the statechart that matches the given value

    @param value {State|String} either a state object of the name of a state
    @returns {State} if a match then the matching state is returned, otherwise null is returned
  */
  getState: function (state) {
    var root = this.get('rootState');
    return root === state ? root : root.getSubstate(state);
  },

  /**
    When called, the statechart will proceed with making state transitions in the statechart starting from
    a current state that meet the statechart conditions. When complete, some or all of the statechart's
    current states will be changed, and all states that were part of the transition process will either
    be exited or entered in a specific order.

    The state that is given to go to will not necessarily be a current state when the state transition process
    is complete. The final state or states are dependent on factors such an initial substates, concurrent
    states, and history states.

    Because the statechart can have one or more current states, it may be necessary to indicate what current state
    to start from. If no current state to start from is provided, then the statechart will default to using
    the first current state that it has; depending of the make up of the statechart (no concurrent state vs.
    with concurrent states), the outcome may be unexpected. For a statechart with concurrent states, it is best
    to provide a current state in which to start from.

    When using history states, the statechart will first make transitions to the given state and then use that
    state's history state and recursively follow each history state's history state until there are no
    more history states to follow. If the given state does not have a history state, then the statechart
    will continue following state transition procedures.

    Method can be called in the following ways:

        // With one argument.
        gotoState(<state>)

        // With two argument.
        gotoState(<state>, <state | boolean | hash>)

        // With three argument.
        gotoState(<state>, <state>, <boolean | hash>)
        gotoState(<state>, <boolean>, <hash>)

        // With four argument.
        gotoState(<state>, <state>, <boolean>, <hash>)

    where <state> is either a SC.State object or a string and <hash> is a regular JS hash object.

    @param state {SC.State|String} the state to go to (may not be the final state in the transition process)
    @param fromCurrentState {SC.State|String} Optional. The current state to start the transition process from.
    @param useHistory {Boolean} Optional. Indicates whether to include using history states in the transition process
    @param context {Hash} Optional. A context object that will be passed to all exited and entered states
  */
  gotoState: function (state, fromCurrentState, useHistory, context) {
    if (!this.get('statechartIsInitialized')) {
      this.statechartLogError("can not go to state %@. statechart has not yet been initialized".fmt(state));
      return;
    }

    if (this.get('isDestroyed')) {
      this.statechartLogError("can not go to state %@. statechart is destroyed".fmt(this));
      return;
    }

    // Fast arguments access.
    // Accessing `arguments.length` is just a Number and doesn't materialize the `arguments` object, which is costly.
    var args = new Array(arguments.length); //  SC.$A(arguments)
    for (var i = 0, len = args.length; i < len; i++) { args[i] = arguments[i]; }

    args = this._processGotoStateArgs(args);

    state = args.state;
    fromCurrentState = args.fromCurrentState;
    useHistory = args.useHistory;
    context = args.context;

    var pivotState = null,
        exitStates = [],
        enterStates = [],
        paramState = state,
        paramFromCurrentState = fromCurrentState,
        msg;

    state = this.getState(state);

    if (SC.none(state)) {
      this.statechartLogError("Can not to goto state %@. Not a recognized state in statechart".fmt(paramState));
      return;
    }

    if (this._gotoStateLocked) {
      // There is a state transition currently happening. Add this requested state
      // transition to the queue of pending state transitions. The request will
      // be invoked after the current state transition is finished.
      this._pendingStateTransitions.push({
        state: state,
        fromCurrentState: fromCurrentState,
        useHistory: useHistory,
        context: context
      });

      return;
    }

    // Lock the current state transition so that no other requested state transition
    // interferes.
    this._gotoStateLocked = YES;

    if (fromCurrentState) {
      // Check to make sure the current state given is actually a current state of this statechart
      fromCurrentState = this.getState(fromCurrentState);
      if (SC.none(fromCurrentState) || !fromCurrentState.get('isCurrentState')) {
        msg = "Can not to goto state %@. %@ is not a recognized current state in statechart";
        this.statechartLogError(msg.fmt(paramState, paramFromCurrentState));
        this._gotoStateLocked = NO;
        return;
      }
    }
    else {
      // No explicit current state to start from; therefore, need to find a current state
      // to transition from.
      fromCurrentState = state.findFirstRelativeCurrentState();
      if (!fromCurrentState) fromCurrentState = this.get('firstCurrentState');
    }

    


    // If there is a current state to start the transition process from, then determine what
    // states are to be exited
    if (!SC.none(fromCurrentState)) {
      exitStates = this._createStateChain(fromCurrentState);
    }

    // Now determine the initial states to be entered
    enterStates = this._createStateChain(state);

    // Get the pivot state to indicate when to go from exiting states to entering states
    pivotState = this._findPivotState(exitStates, enterStates);

    if (pivotState) {
      

      if (pivotState.get('substatesAreConcurrent') && pivotState !== state) {
        this.statechartLogError("Can not go to state %@ from %@. Pivot state %@ has concurrent substates.".fmt(state, fromCurrentState, pivotState));
        this._gotoStateLocked = NO;
        return;
      }
    }

    // Collect what actions to perform for the state transition process
    var gotoStateActions = [];


    // Go ahead and find states that are to be exited
    this._traverseStatesToExit(exitStates.shift(), exitStates, pivotState, gotoStateActions);

    // Now go find states that are to be entered
    if (pivotState !== state) {
      this._traverseStatesToEnter(enterStates.pop(), enterStates, pivotState, useHistory, gotoStateActions);
    } else {
      this._traverseStatesToExit(pivotState, [], null, gotoStateActions);
      this._traverseStatesToEnter(pivotState, null, null, useHistory, gotoStateActions);
    }

    // Collected all the state transition actions to be performed. Now execute them.
    this._gotoStateActions = gotoStateActions;
    this._executeGotoStateActions(state, gotoStateActions, null, context);
  },

  /**
    Indicates if the statechart is in an active goto state process
  */
  gotoStateActive: function () {
    return this._gotoStateLocked;
  }.property(),

  /**
    Indicates if the statechart is in an active goto state process
    that has been suspended
  */
  gotoStateSuspended: function () {
    return this._gotoStateLocked && !!this._gotoStateSuspendedPoint;
  }.property(),

  /**
    Resumes an active goto state transition process that has been suspended.
  */
  resumeGotoState: function () {
    if (!this.get('gotoStateSuspended')) {
      this.statechartLogError("Can not resume goto state since it has not been suspended");
      return;
    }

    var point = this._gotoStateSuspendedPoint;
    this._executeGotoStateActions(point.gotoState, point.actions, point.marker, point.context);
  },

  /** @private */
  _executeGotoStateActions: function (gotoState, actions, marker, context) {
    var action = null,
        len = actions.length,
        actionResult = null;

    marker = SC.none(marker) ? 0 : marker;

    for (; marker < len; marker += 1) {
      this._currentGotoStateAction = action = actions[marker];
      switch (action.action) {
      case SC.EXIT_STATE:
        actionResult = this._exitState(action.state, context);
        break;

      case SC.ENTER_STATE:
        actionResult = this._enterState(action.state, action.currentState, context);
        break;
      }

      //
      // Check if the state wants to perform an asynchronous action during
      // the state transition process. If so, then we need to first
      // suspend the state transition process and then invoke the
      // asynchronous action. Once called, it is then up to the state or something
      // else to resume this statechart's state transition process by calling the
      // statechart's resumeGotoState method.
      //
      if (SC.kindOf(actionResult, SC.Async)) {
        this._gotoStateSuspendedPoint = {
          gotoState: gotoState,
          actions: actions,
          marker: marker + 1,
          context: context
        };

        actionResult.tryToPerform(action.state);
        return;
      }
    }

    this.beginPropertyChanges();
    this.notifyPropertyChange('currentStates');
    this.notifyPropertyChange('enteredStates');
    this.endPropertyChanges();

    


    this._cleanupStateTransition();
  },

  /** @private */
  _cleanupStateTransition: function () {
    this._currentGotoStateAction = null;
    this._gotoStateSuspendedPoint = null;
    this._gotoStateActions = null;
    this._gotoStateLocked = NO;
    this._flushPendingStateTransition();
    // Check the flags so we only flush if the events will actually get sent.
    if (!this._sendEventLocked && !this._gotoStateLocked) { this._flushPendingSentEvents(); }
  },

  /** @private */
  _exitState: function (state, context) {
    var parentState;

    if (state.get('currentSubstates').indexOf(state) >= 0) {
      parentState = state.get('parentState');
      while (parentState) {
        parentState.get('currentSubstates').removeObject(state);
        parentState.notifyPropertyChange('currentSubstates');
        parentState = parentState.get('parentState');
      }
    }

    parentState = state;
    while (parentState) {
      parentState.get('enteredSubstates').removeObject(state);
      parentState.notifyPropertyChange('enteredSubstates');
      parentState = parentState.get('parentState');
    }

    


    state.set('currentSubstates', []);
    state.notifyPropertyChange('currentSubstates');

    state.stateWillBecomeExited(context);
    var result = this.exitState(state, context);
    state.stateDidBecomeExited(context);

    


    state._traverseStatesToExit_skipState = NO;

    return result;
  },

  /**
    What will actually invoke a state's exitState method.

    Called during the state transition process whenever the gotoState method is
    invoked.

    @param state {SC.State} the state whose enterState method is to be invoked
    @param context {Hash} a context hash object to provide the enterState method
  */
  exitState: function (state, context) {
    return state.exitState(context);
  },

  /** @private */
  _enterState: function (state, current, context) {
    var parentState = state.get('parentState');
    if (parentState && !state.get('isConcurrentState')) parentState.set('historyState', state);

    if (current) {
      parentState = state;
      while (parentState) {
        parentState.get('currentSubstates').pushObject(state);
        parentState.notifyPropertyChange('currentSubstates');
        parentState = parentState.get('parentState');
      }
    }

    parentState = state;
    while (parentState) {
      parentState.get('enteredSubstates').pushObject(state);
      parentState.notifyPropertyChange('enteredSubstates');
      parentState = parentState.get('parentState');
    }

    


    state.stateWillBecomeEntered(context);
    var result = this.enterState(state, context);
    state.stateDidBecomeEntered(context);

    


    return result;
  },

  /**
    What will actually invoke a state's enterState method.

    Called during the state transition process whenever the gotoState method is
    invoked.

    If the context provided is a state route context object
    ({@link SC.StateRouteContext}), then if the given state has a enterStateByRoute
    method, that method will be invoked, otherwise the state's enterState method
    will be invoked by default. The state route context object will be supplied to
    both enter methods in either case.

    @param state {SC.State} the state whose enterState method is to be invoked
    @param context {Hash} a context hash object to provide the enterState method
  */
  enterState: function (state, context) {
    if (state.enterStateByRoute && SC.kindOf(context, SC.StateRouteHandlerContext)) {
      return state.enterStateByRoute(context);
    } else {
      return state.enterState(context);
    }
  },

  /**
    When called, the statechart will proceed to make transitions to the given state then follow that
    state's history state.

    You can either go to a given state's history recursively or non-recursively. To go to a state's history
    recursively means to following each history state's history state until no more history states can be
    followed. Non-recursively means to just to the given state's history state but do not recusively follow
    history states. If the given state does not have a history state, then the statechart will just follow
    normal procedures when making state transitions.

    Because a statechart can have one or more current states, depending on if the statechart has any concurrent
    states, it is optional to provided current state in which to start the state transition process from. If no
    current state is provided, then the statechart will default to the first current state that it has; which,
    depending on the make up of that statechart, can lead to unexpected outcomes. For a statechart with concurrent
    states, it is best to explicitly supply a current state.

    Method can be called in the following ways:

        // With one arguments.
        gotoHistoryState(<state>)

        // With two arguments.
        gotoHistoryState(<state>, <state | boolean | hash>)

        // With three arguments.
        gotoHistoryState(<state>, <state>, <boolean | hash>)
        gotoHistoryState(<state>, <boolean>, <hash>)

        // With four argumetns
        gotoHistoryState(<state>, <state>, <boolean>, <hash>)

    where <state> is either a SC.State object or a string and <hash> is a regular JS hash object.

    @param state {SC.State|String} the state to go to and follow it's history state
    @param fromCurrentState {SC.State|String} Optional. the current state to start the state transition process from
    @param recursive {Boolean} Optional. whether to follow history states recursively.
  */
  gotoHistoryState: function (state, fromCurrentState, recursive, context) {
    if (!this.get('statechartIsInitialized')) {
      this.statechartLogError("can not go to state %@'s history state. Statechart has not yet been initialized".fmt(state));
      return;
    }

    // Fast arguments access.
    // Accessing `arguments.length` is just a Number and doesn't materialize the `arguments` object, which is costly.
    var args = new Array(arguments.length); //  SC.$A(arguments)
    for (var i = 0, len = args.length; i < len; i++) { args[i] = arguments[i]; }

    args = this._processGotoStateArgs(args);

    state = args.state;
    fromCurrentState = args.fromCurrentState;
    recursive = args.useHistory;
    context = args.context;

    state = this.getState(state);

    if (!state) {
      this.statechartLogError("Can not to goto state %@'s history state. Not a recognized state in statechart".fmt(state));
      return;
    }

    var historyState = state.get('historyState');

    if (!recursive) {
      if (historyState) {
        this.gotoState(historyState, fromCurrentState, context);
      } else {
        this.gotoState(state, fromCurrentState, context);
      }
    } else {
      this.gotoState(state, fromCurrentState, YES, context);
    }
  },

  /**
    Sends a given event to all the statechart's current states.

    If a current state does can not respond to the sent event, then the current state's parent state
    will be tried. This process is recursively done until no more parent state can be tried.

    Note that a state will only be checked once if it can respond to an event. Therefore, if
    there is a state S that handles event foo and S has concurrent substates, then foo will
    only be invoked once; not as many times as there are substates.

    @param event {String} name of the event
    @param arg1 {Object} optional argument
    @param arg2 {Object} optional argument
    @returns {SC.Responder} the responder that handled it or null

    @see #stateWillTryToHandleEvent
    @see #stateDidTryToHandleEvent
  */
  sendEvent: function (event, arg1, arg2) {

    if (this.get('isDestroyed')) {
      this.statechartLogError("can not send event %@. statechart is destroyed".fmt(event));
      return;
    }

    var statechartHandledEvent = NO,
        result = this,
        eventHandled = NO,
        currentStates = this.get('currentStates').slice(),
        checkedStates = {},
        len = 0,
        i = 0,
        state = null;

    if (this._sendEventLocked || this._gotoStateLocked) {
      // Want to prevent any actions from being processed by the states until
      // they have had a chance to handle the most immediate action or completed
      // a state transition
      this._pendingSentEvents.push({
        event: event,
        arg1: arg1,
        arg2: arg2
      });

      return;
    }

    this._sendEventLocked = YES;

    


    len = currentStates.get('length');
    for (; i < len; i += 1) {
      eventHandled = NO;
      state = currentStates[i];
      if (!state.get('isCurrentState')) continue;
      while (!eventHandled && state) {
        if (!checkedStates[state.get('fullPath')]) {
          eventHandled = state.tryToHandleEvent(event, arg1, arg2);
          checkedStates[state.get('fullPath')] = YES;
        }
        if (!eventHandled) state = state.get('parentState');
        else statechartHandledEvent = YES;
      }
    }

    // Now that all the states have had a chance to process the
    // first event, we can go ahead and flush any pending sent events.
    this._sendEventLocked = NO;

    


    // Check if the flags are unlocked. These means any pending events
    // will successfully send, so go ahead and flush. Otherwise, events
    // would become out of order since the first event would get shifted,
    // then pushed.
    if (!this._sendEventLocked && !this._gotoStateLocked) {
      result = this._flushPendingSentEvents();
    }

    return statechartHandledEvent ? this : (result ? this : null);
  },

  /**
    Used to notify the statechart that a state will try to handle event that has been passed
    to it.

    @param {SC.State} state the state that will try to handle the event
    @param {String} event the event the state will try to handle
    @param {String} handler the name of the method on the state that will try to handle the event
  */
  stateWillTryToHandleEvent: function (state, event, handler) {
    this._stateHandleEventInfo = {
      state: state,
      event: event,
      handler: handler
    };
  },

  /**
    Used to notify the statechart that a state did try to handle event that has been passed
    to it.

    @param {SC.State} state the state that did try to handle the event
    @param {String} event the event the state did try to handle
    @param {String} handler the name of the method on the state that did try to handle the event
    @param {Boolean} handled indicates if the handler was able to handle the event
  */
  stateDidTryToHandleEvent: function (state, event, handler, handled) {
    this._stateHandleEventInfo = null;
  },

  /** @private

    Creates a chain of states from the given state to the greatest ancestor state (the root state). Used
    when perform state transitions.
  */
  _createStateChain: function (state) {
    var chain = [];

    while (state) {
      chain.push(state);
      state = state.get('parentState');
    }

    return chain;
  },

  /** @private

    Finds a pivot state from two given state chains. The pivot state is the state indicating when states
    go from being exited to states being entered during the state transition process. The value
    returned is the fist matching state between the two given state chains.
  */
  _findPivotState: function (stateChain1, stateChain2) {
    if (stateChain1.length === 0 || stateChain2.length === 0) return null;

    var pivot = stateChain1.find(function (state, index) {
      if (stateChain2.indexOf(state) >= 0) return YES;
    });

    return pivot;
  },

  /** @private

    Recursively follow states that are to be exited during a state transition process. The exit
    process is to start from the given state and work its way up to when either all exit
    states have been reached based on a given exit path or when a stop state has been reached.

    @param state {State} the state to be exited
    @param exitStatePath {Array} an array representing a path of states that are to be exited
    @param stopState {State} an explicit state in which to stop the exiting process
  */
  _traverseStatesToExit: function (state, exitStatePath, stopState, gotoStateActions) {
    if (!state || state === stopState) return;

    // This state has concurrent substates. Therefore we have to make sure we
    // exit them up to this state before we can go any further up the exit chain.
    if (state.get('substatesAreConcurrent')) {
      var i = 0,
          currentSubstates = state.get('currentSubstates'),
          len = currentSubstates.length,
          currentState = null;

      for (; i < len; i += 1) {
        currentState = currentSubstates[i];
        if (currentState._traverseStatesToExit_skipState === YES) continue;
        var chain = this._createStateChain(currentState);
        this._traverseStatesToExit(chain.shift(), chain, state, gotoStateActions);
      }
    }

    gotoStateActions.push({ action: SC.EXIT_STATE, state: state });
    if (state.get('isCurrentState')) state._traverseStatesToExit_skipState = YES;
    this._traverseStatesToExit(exitStatePath.shift(), exitStatePath, stopState, gotoStateActions);
  },

  /** @private

    Recursively follow states that are to be entered during the state transition process. The
    enter process is to start from the given state and work its way down a given enter path. When
    the end of enter path has been reached, then continue entering states based on whether
    an initial substate is defined, there are concurrent substates or history states are to be
    followed; when none of those condition are met then the enter process is done.

    @param state {State} the sate to be entered
    @param enterStatePath {Array} an array representing an initial path of states that are to be entered
    @param pivotState {State} The state pivoting when to go from exiting states to entering states
    @param useHistory {Boolean} indicates whether to recursively follow history states
  */
  _traverseStatesToEnter: function (state, enterStatePath, pivotState, useHistory, gotoStateActions) {
    if (!state) return;

    // We do not want to enter states in the enter path until the pivot state has been reached. After
    // the pivot state has been reached, then we can go ahead and actually enter states.
    if (pivotState) {
      if (state !== pivotState) {
        this._traverseStatesToEnter(enterStatePath.pop(), enterStatePath, pivotState, useHistory, gotoStateActions);
      } else {
        this._traverseStatesToEnter(enterStatePath.pop(), enterStatePath, null, useHistory, gotoStateActions);
      }
    }

    // If no more explicit enter path instructions, then default to enter states based on
    // other criteria
    else if (!enterStatePath || enterStatePath.length === 0) {
      var gotoStateAction = { action: SC.ENTER_STATE, state: state, currentState: NO };
      gotoStateActions.push(gotoStateAction);

      var initialSubstate = state.get('initialSubstate'),
          historyState = state.get('historyState');

      // State has concurrent substates. Need to enter all of the substates
      if (state.get('substatesAreConcurrent')) {
        this._traverseConcurrentStatesToEnter(state.get('substates'), null, useHistory, gotoStateActions);
      }

      // State has substates and we are instructed to recursively follow the state's
      // history state if it has one.
      else if (state.get('hasSubstates') && historyState && useHistory) {
        this._traverseStatesToEnter(historyState, null, null, useHistory, gotoStateActions);
      }

      // State has an initial substate to enter
      else if (initialSubstate) {
        if (SC.kindOf(initialSubstate, SC.HistoryState)) {
          if (!useHistory) useHistory = initialSubstate.get('isRecursive');
          initialSubstate = initialSubstate.get('state');
        }
        this._traverseStatesToEnter(initialSubstate, null, null, useHistory, gotoStateActions);
      }

      // Looks like we hit the end of the road. Therefore the state has now become
      // a current state of the statechart.
      else {
        gotoStateAction.currentState = YES;
      }
    }

    // Still have an explicit enter path to follow, so keep moving through the path.
    else if (enterStatePath.length > 0) {
      gotoStateActions.push({ action: SC.ENTER_STATE, state: state });
      var nextState = enterStatePath.pop();
      this._traverseStatesToEnter(nextState, enterStatePath, null, useHistory, gotoStateActions);

      // We hit a state that has concurrent substates. Must go through each of the substates
      // and enter them
      if (state.get('substatesAreConcurrent')) {
        this._traverseConcurrentStatesToEnter(state.get('substates'), nextState, useHistory, gotoStateActions);
      }
    }
  },

  /** @override

    Returns YES if the named value translates into an executable function on
    any of the statechart's current states or the statechart itself.

    @param event {String} the property name to check
    @returns {Boolean}
  */
  respondsTo: function (event) {
    // Fast path!
    if (this.get('isDestroyed')) {
      this.statechartLogError("can not respond to event %@. statechart is destroyed".fmt(event));
      return false;
    }

    var currentStates = this.get('currentStates'),
        len = currentStates.get('length'),
        i = 0, state = null;

    for (; i < len; i += 1) {
      state = currentStates.objectAt(i);
      while (state) {
        if (state.respondsToEvent(event)) return true;
        state = state.get('parentState');
      }
    }

    // None of the current states can respond. Now check the statechart itself
    return SC.typeOf(this[event]) === SC.T_FUNCTION;
  },

  /** @override

    Attempts to handle a given event against any of the statechart's current states and the
    statechart itself. If any current state can handle the event or the statechart itself can
    handle the event then YES is returned, otherwise NO is returned.

    @param event {String} what to perform
    @param arg1 {Object} Optional
    @param arg2 {Object} Optional
    @returns {Boolean} YES if handled, NO if not handled
  */
  tryToPerform: function (event, arg1, arg2) {
    if (!this.respondsTo(event)) return NO;

    if (SC.typeOf(this[event]) === SC.T_FUNCTION) {
      var result = this[event](arg1, arg2);
      if (result !== NO) return YES;
    }

    return !!this.sendEvent(event, arg1, arg2);
  },

  /**
    Used to invoke a method on current states. If the method can not be executed
    on a current state, then the state's parent states will be tried in order
    of closest ancestry.

    A few notes:

     1. Calling this is not the same as calling sendEvent or sendAction.
        Rather, this should be seen as calling normal methods on a state that
        will *not* call gotoState or gotoHistoryState.
     2. A state will only ever be invoked once per call. So if there are two
        or more current states that have the same parent state, then that parent
        state will only be invoked once if none of the current states are able
        to invoke the given method.

    When calling this method, you are able to supply zero ore more arguments
    that can be pass onto the method called on the states. As an example

        invokeStateMethod('render', context, firstTime);

    The above call will invoke the render method on the current states
    and supply the context and firstTime arguments to the method.

    Because a statechart can have more than one current state and the method
    invoked may return a value, the addition of a callback function may be provided
    in order to handle the returned value for each state. As an example, let's say
    we want to call a calculate method on the current states where the method
    will return a value when invoked. We can handle the returned values like so:

        invokeStateMethod('calculate', value, function (state, result) {
          // .. handle the result returned from calculate that was invoked
          //    on the given state
        })

    If the method invoked does not return a value and a callback function is
    supplied, then result value will simply be undefined. In all cases, if
    a callback function is given, it must be the last value supplied to this
    method.

    invokeStateMethod will return a value if only one state was able to have
    the given method invoked on it, otherwise no value is returned.

    @param methodName {String} methodName a method name
    @param args {Object...} Optional. any additional arguments
    @param func {Function} Optional. a callback function. Must be the last
           value supplied if provided.

    @returns a value if the number of current states is one, otherwise undefined
             is returned. The value is the result of the method that got invoked
             on a state.
  */
  invokeStateMethod: function (methodName, args, func) {
    if (methodName === 'unknownEvent') {
      this.statechartLogError("can not invoke method unkownEvent");
      return;
    }

    args = SC.A(arguments);
    args.shift();

    var len = args.length,
        arg = len > 0 ? args[len - 1] : null,
        callback = SC.typeOf(arg) === SC.T_FUNCTION ? args.pop() : null,
        currentStates = this.get('currentStates'),
        i = 0, state = null,
        checkedStates = {},
        method, result,
        calledStates = 0;

    len = currentStates.get('length');

    for (; i < len; i += 1) {
      state = currentStates.objectAt(i);
      while (state) {
        if (checkedStates[state.get('fullPath')]) break;
        checkedStates[state.get('fullPath')] = YES;
        method = state[methodName];
        if (SC.typeOf(method) === SC.T_FUNCTION && !method.isEventHandler) {
          result = method.apply(state, args);
          if (callback) callback.call(this, state, result);
          calledStates += 1;
          break;
        }
        state = state.get('parentState');
      }
    }

    return calledStates === 1 ? result : undefined;
  },

  /** @private

    Iterate over all the given concurrent states and enter them
  */
  _traverseConcurrentStatesToEnter: function (states, exclude, useHistory, gotoStateActions) {
    var i = 0,
        len = states.length,
        state = null;

    for (; i < len; i += 1) {
      state = states[i];
      if (state !== exclude) this._traverseStatesToEnter(state, null, null, useHistory, gotoStateActions);
    }
  },

  /** @private

    Called by gotoState to flush a pending state transition at the front of the
    pending queue.
  */
  _flushPendingStateTransition: function () {
    if (!this._pendingStateTransitions) {
      this.statechartLogError("Unable to flush pending state transition. _pendingStateTransitions is invalid");
      return;
    }
    var pending = this._pendingStateTransitions.shift();
    if (!pending) return;
    this.gotoState(pending.state, pending.fromCurrentState, pending.useHistory, pending.context);
  },

  /** @private

     Called by sendEvent to flush a pending actions at the front of the pending
     queue
   */
  _flushPendingSentEvents: function () {
    var pending = this._pendingSentEvents.shift();
    if (!pending) return null;
    return this.sendEvent(pending.event, pending.arg1, pending.arg2);
  },

  /** @private */
  


  /** @private
    Will process the arguments supplied to the gotoState method.

    TODO: Come back to this and refactor the code. It works, but it
          could certainly be improved
  */
  _processGotoStateArgs: function (args) {
    var processedArgs = {
        state: null,
        fromCurrentState: null,
        useHistory: false,
        context: null
      },
      len = null,
      value = null;

    args = args.filter(function (item) {
      return item !== undefined;
    });
    len = args.length;

    if (len < 1) return processedArgs;

    processedArgs.state = args[0];

    if (len === 2) {
      value = args[1];
      switch (SC.typeOf(value)) {
      case SC.T_BOOL:
        processedArgs.useHistory = value;
        break;
      case SC.T_HASH:
      case SC.T_OBJECT:
        if (!SC.kindOf(value, SC.State)) {
          processedArgs.context = value;
        }
        break;
      default:
        processedArgs.fromCurrentState = value;
      }
    }
    else if (len === 3) {
      value = args[1];
      if (SC.typeOf(value) === SC.T_BOOL) {
        processedArgs.useHistory = value;
        processedArgs.context = args[2];
      } else {
        processedArgs.fromCurrentState = value;
        value = args[2];
        if (SC.typeOf(value) === SC.T_BOOL) {
          processedArgs.useHistory = value;
        } else {
          processedArgs.context = value;
        }
      }
    }
    else {
      processedArgs.fromCurrentState = args[1];
      processedArgs.useHistory = args[2];
      processedArgs.context = args[3];
    }

    return processedArgs;
  },

  /** @private

    Will return a newly constructed root state class. The root state will have substates added to
    it based on properties found on this state that derive from a SC.State class. For the
    root state to be successfully built, the following much be met:

     - The rootStateExample property must be defined with a class that derives from SC.State
     - Either the initialState or statesAreConcurrent property must be set, but not both
     - There must be one or more states that can be added to the root state

  */
  _constructRootStateClass: function () {
    var rsExampleKey = 'rootStateExample',
        rsExample = this.get(rsExampleKey),
        initialState = this.get('initialState'),
        statesAreConcurrent = this.get('statesAreConcurrent'),
        stateCount = 0,
        key, value, valueIsFunc, attrs = {};

    if (SC.typeOf(rsExample) === SC.T_FUNCTION && rsExample.statePlugin) {
      rsExample = rsExample.apply(this);
    }

    if (!(SC.kindOf(rsExample, SC.State) && rsExample.isClass)) {
      this._logStatechartCreationError("Invalid root state example");
      return null;
    }

    if (statesAreConcurrent && !SC.empty(initialState)) {
      this._logStatechartCreationError("Can not assign an initial state when states are concurrent");
    } else if (statesAreConcurrent) {
      attrs.substatesAreConcurrent = YES;
    } else if (SC.typeOf(initialState) === SC.T_STRING) {
      attrs.initialSubstate = initialState;
    } else {
      this._logStatechartCreationError("Must either define initial state or assign states as concurrent");
      return null;
    }

    for (key in this) {
      if (key === rsExampleKey) continue;

      value = this[key];
      valueIsFunc = SC.typeOf(value) === SC.T_FUNCTION;

      if (valueIsFunc && value.statePlugin) {
        value = value.apply(this);
      }

      if (SC.kindOf(value, SC.State) && value.isClass && this[key] !== this.constructor) {
        attrs[key] = value;
        stateCount += 1;
      }
    }

    if (stateCount === 0) {
      this._logStatechartCreationError("Must define one or more states");
      return null;
    }

    return rsExample.extend(attrs);
  },

  /** @private */
  _logStatechartCreationError: function (msg) {
    SC.Logger.error("Unable to create statechart for %@: %@.".fmt(this, msg));
  },

  /**
    Used to log a statechart error message
  */
  statechartLogError: function (msg) {
    SC.Logger.error("ERROR %@: %@".fmt(this.get('statechartLogPrefix'), msg));
  },

  /**
    Used to log a statechart warning message
  */
  statechartLogWarning: function (msg) {
    if (this.get('suppressStatechartWarnings')) return;
    SC.Logger.warn("WARN %@: %@".fmt(this.get('statechartLogPrefix'), msg));
  },

  /** @property */
  statechartLogPrefix: function () {
    var className = SC._object_className(this.constructor),
        name = this.get('name'), prefix;

    if (SC.empty(name)) prefix = "%@<%@>".fmt(className, SC.guidFor(this));
    else prefix = "%@<%@, %@>".fmt(className, name, SC.guidFor(this));

    return prefix;
  }.property().cacheable()

};

SC.mixin(SC.StatechartManager, SC.StatechartDelegate, SC.DelegateSupport);

/**
  The default name given to a statechart's root state
*/
SC.ROOT_STATE_NAME = "__ROOT_STATE__";

/**
  Constants used during the state transition process
*/
SC.EXIT_STATE = 0;
SC.ENTER_STATE = 1;

/**
  A Statechart class.
*/
SC.Statechart = SC.Object.extend(SC.StatechartManager, {
  autoInitStatechart: NO
});

SC.Statechart.design = SC.Statechart.extend;


/* >>>>>>>>>> BEGIN javascript.js */
/* >>>>>>>>>> BEGIN source/license.js */
/*!
 * ==========================================================================
 * SproutCore -- JavaScript Application Framework
 * Copyright ©2008-2011 Apple Inc. All rights reserved.
 * Copyright 2006-2011, Strobe Inc. and contributors.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a 
 * copy of this software and associated documentation files (the "Software"), 
 * to deal in the Software without restriction, including without limitation 
 * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the 
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in 
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 * DEALINGS IN THE SOFTWARE.
 * 
 * SproutCore and the SproutCore logo are trademarks of Strobe Inc.
 * 
 * For more information about SproutCore, visit http://www.sproutcore.com
 * 
 * ==========================================================================
 */


/* >>>>>>>>>> BEGIN javascript.js */
/* >>>>>>>>>> BEGIN source/theme.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

/** @class
  @extends SC.Theme
  @since SproutCore 1.1
*/
SC.EmptyTheme = SC.BaseTheme.create({
  name: 'sc-empty-theme'
});

SC.Theme.addTheme(SC.EmptyTheme);


/* >>>>>>>>>> BEGIN javascript.js */
/* >>>>>>>>>> BEGIN source/theme.js */

/**
 * @class
 * SproutCore's Ace theme.
 */
SC.AceTheme = SC.BaseTheme.create({
  name: "ace",
  description: "A SproutCore built-in theme by Alex Iskander and contributors. Only supports browsers that implement CSS3."
});

// register the theme with SproutCore
SC.Theme.addTheme(SC.AceTheme);

// SC.ButtonView variants
SC.AceTheme.PointLeft = SC.AceTheme.subtheme("point-left", "point-left");
SC.AceTheme.PointRight = SC.AceTheme.subtheme("point-right", "point-right");
SC.AceTheme.Capsule = SC.AceTheme.subtheme("capsule", "capsule");

// Dark Variant
/**
 * @class SC.AceTheme.Dark
 * SproutCore's Ace theme's Dark Side. Used in popovers or wherever you
 * choose (use it by making the view or one of its parents have a
 * themeName of 'dark').
 */
SC.AceTheme.Dark = SC.AceTheme.subtheme("dark");

// for backwards-compatibility with apps that do not set their
// own default theme:
SC.defaultTheme = 'ace';

/* >>>>>>>>>> BEGIN source/resources/button/dark/button.js */
sc_require("theme");

SC.AceTheme.Dark.PointLeft = SC.AceTheme.Dark.subtheme("point-left", "point-left");
SC.AceTheme.Dark.PointRight = SC.AceTheme.Dark.subtheme("point-right", "point-right");
SC.AceTheme.Dark.PointRight = SC.AceTheme.Dark.subtheme("capsule", "capsule");

/* >>>>>>>>>> BEGIN source/resources/collection/source-list/source-list.js */
SC.AceTheme.SourceList = SC.AceTheme.subtheme('source-list');

// later we may define/override some constants here
/* >>>>>>>>>> BEGIN source/resources/picker/popover/popover.js */
sc_require("theme");

// it is derived from dark, but will be available both under Ace and not.
SC.AceTheme.Popover = SC.AceTheme.Dark.subtheme("popover");
SC.AceTheme.addTheme(SC.AceTheme.Popover);

// there is a solid variety
SC.AceTheme.SolidPopover = SC.AceTheme.Popover.subtheme('solid');

// and a shortcut to the solid variety.
SC.AceTheme.addTheme(SC.AceTheme.SolidPopover.create({ name: 'solid-popover' }));


/* >>>>>>>>>> BEGIN source/resources/picker/popover/picker.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================
sc_require("resources/picker/popover/popover");

SC.AceTheme.Popover.pickerRenderDelegate = SC.RenderDelegate.create({
  className: 'picker',
  
  render: function(dataSource, context) {
    var preferType = dataSource.get('preferType');
    var pointerPosition = dataSource.get('pointerPos');
    var pointerPositionY = dataSource.get('pointerPosY');

    if (preferType == SC.PICKER_POINTER || preferType == SC.PICKER_MENU_POINTER) {
      context.addClass(pointerPosition);
    }
  },
  
  update: function(dataSource, $) {
    var preferType = dataSource.get('preferType');
    var pointerPosition = dataSource.get('pointerPos');
    var pointerPositionY = dataSource.get('pointerPosY');
    
    if (preferType == SC.PICKER_POINTER || preferType == SC.PICKER_MENU_POINTER) {
      $.addClass(pointerPosition);
    }
    
  }
});
/* >>>>>>>>>> BEGIN source/resources/picker/popover/workspace.js */
// ==========================================================================
// Project:   SproutCore - JavaScript Application Framework
// Copyright: ©2006-2011 Strobe Inc. and contributors.
//            Portions ©2008-2011 Apple Inc. All rights reserved.
// License:   Licensed under MIT license (see license.js)
// ==========================================================================

SC.AceTheme.Popover.workspaceRenderDelegate = SC.RenderDelegate.create({
  className: 'workspace',
  render: function(dataSource, context) {
    context.setClass({
      'top-toolbar': dataSource.get('hasTopToolbar'),
      'bottom-toolbar': dataSource.get('hasBottomToolbar')
    });
    
    context = context.begin('div').addClass('popover-background');
    this.includeSlices(dataSource, context, SC.NINE_SLICE);
    context.push("<div class = 'sc-pointer'></div>");
    context = context.end();
  },

  update: function(dataSource, jquery) {
    jquery.setClass({
      'top-toolbar': dataSource.get('hasTopToolbar'),
      'bottom-toolbar': dataSource.get('hasBottomToolbar')
    });
  }
});

/* >>>>>>>>>> BEGIN javascript.js */
/* >>>>>>>>>> BEGIN source/lproj/strings.js */
SC.stringsFor("de", {
              "DG.fileMenu.menuItem.newDocument": "Neu",
              "DG.fileMenu.menuItem.openDocument": "Öffnen...",
              "DG.fileMenu.menuItem.closeDocument": "Schließen",
              "DG.fileMenu.menuItem.importFile": "Importieren ...",
              "DG.fileMenu.menuItem.revertTo": "Zurückkehren...",
              "DG.fileMenu.menuItem.revertToOpened": "Kürzlich geöffnete Fassung",
              "DG.fileMenu.menuItem.revertToShared": "Geteilte Ansicht",
              "DG.fileMenu.menuItem.saveDocument": "Speichern ...",
              "DG.fileMenu.menuItem.copyDocument": "Kopie erstellen",
              "DG.fileMenu.menuItem.share": "Teilen ...",
              "DG.fileMenu.menuItem.shareGetLink": "Link erhalten für geteilte Ansicht",
              "DG.fileMenu.menuItem.shareUpdate": "Geteilte Ansicht aktualisieren",
              "DG.fileMenu.menuItem.renameDocument": "Umbennen",
              "DG.main.userEntryView.title": "Was soll getan werden?",
              "DG.main.userEntryView.openDocument": "Dokument öffnen oder Beispiele ansehen",
              "DG.main.userEntryView.newDocument": "Neues Dokument erstellen",
              "DG.mainPage.mainPane.undoButton.title": "Rückgängig",
              "DG.mainPage.mainPane.undoButton.toolTip": "Die letzte Aktion rückgängig machen",
              "DG.mainPage.mainPane.redoButton.title": "Wiederholen",
              "DG.mainPage.mainPane.redoButton.toolTip": "Letzte Aktion wiederholen",
              "DG.mainPage.mainPane.versionString": "Version %@ (%@)",
              "DG.mainPage.mainPane.messageView.value": "Leider wird CODAP aktuell nicht vom verwendeten Browser unterstützt. CODAP wird unterstützt von Firefox 46+, Chrome 50+, Windows Edge 14+ und Safari 10+. CODAP wird zur Zeit nicht von anderen Browsern unterstützt.",
              "DG.mainPage.titleBar.saved": "Dokument gespeichert!",
              "DG.mainPage.mainPane.versionString.IS_BUILD": "Version %@ (%@ IS)",
              "DG.mainPage.mainPane.versionString.SRRI_BUILD": "Version %@ (%@.srri10)",
              "DG.AppController.resetData.title": "Daten löschen...",
              "DG.AppController.resetData.toolTip": "Alle Daten des aktuellen Dokuments löschen",
              "DG.AppController.resetData.warnMessage": "Sollen wirklich alle Daten in diesem Dokument gelöscht werden?",
              "DG.AppController.resetData.warnDescription": "Diese Aktion kann nicht rückgängig gemacht werden.",
              "DG.AppController.resetData.okButtonTitle": "Ja, Daten löschen",
              "DG.AppController.resetData.cancelButtonTitle": "Nein, Daten behalten",
              "DG.AppController.closeDocument.warnMessage": "Ohne Speichern schließen?",
              "DG.AppController.closeDocument.warnDescription": "Diese Aktion kann nicht rückgängig gemacht werden.",
              "DG.AppController.closeDocument.okButtonTitle": "Schließen",
              "DG.AppController.closeDocument.cancelButtonTitle": "Abbrechen",
              "DG.AppController.beforeUnload.confirmationMessage": "Das Dokument enthält ungespeicherte Änderungen.",
              "DG.AppController.optionMenuItems.reportProblem": "Feedback senden...",
              "DG.AppController.optionMenuItems.viewWebPage": "Webseite anzeigen...",
              "DG.AppController.optionMenuItems.configureGuide": "Anleitung konfigurieren",
              "DG.AppController.optionMenuItems.about": "Über CODAP...",
              "DG.AppController.optionMenuItems.releaseNotes": "Neuigkeiten",
              "DG.AppController.optionMenuItems.help": "Hilfe...",
              "DG.AppController.optionMenuItems.toWebSite": "CODAP Webseite",
              "DG.AppController.exportDocument.prompt": "Dateiname:",
              "DG.AppController.exportCaseData.prompt": "Daten exportieren",
              "DG.AppController.exportDocument.exportTitle": "Exportieren",
              "DG.AppController.exportDocument.exportTooltip": "Daten exportieren in eine Datei",
              "DG.AppController.exportDocument.cancelTitle": "Abbrechen",
              "DG.AppController.exportDocument.cancelTooltip": "Exportvorgang abbrechen",
              "DG.AppController.feedbackDialog.dialogTitle": "Rückmeldung geben",
              "DG.AppController.feedbackDialog.subHeaderText": "Deine Rückmeldung ist wichtig für uns!",
              "DG.AppController.feedbackDialog.messageText": "Bitte hilf uns, unser Produkt weiter zu verbessern. Fragen, Fehlerberichte und Feature-Wünsche sind willkommen. Danke!",
              "DG.AppController.feedbackDialog.subjectHint": "Wozu gibst Du eine Rückmeldung",
              "DG.AppController.feedbackDialog.feedbackHint": "Details",
              "DG.AppController.feedbackDialog.submitFeedbackButton": "Einreichen",
              "DG.AppController.feedbackDialog.cancelFeedbackButton": "Abbrechen",
              "DG.AppController.showWebSiteTitle": "Über CODAP",
              "DG.AppController.showHelpTitle": "Hilfe zu CODAP",
              "DG.AppController.showAboutTitle": "Über CODAP",
              "DG.AppController.showReleaseNotesTitle": "CODAP Versionshinweise",
              "DG.AppController.dropFile.error": "Fehler: %@1",
              "DG.AppController.dropFile.unknownFileType": "Dieser Dateityp kann nicht importiert werden",
              "DG.AppController.validateDocument.missingRequiredProperty": "Notwendige Eigenschaft nicht gefunden: %@1",
              "DG.AppController.validateDocument.unexpectedProperty": "Unerwartete Top-Level Eigenschaft: %@1",
              "DG.AppController.validateDocument.unresolvedID": "Ungeklärte Id: %@1",
              "DG.AppController.validateDocument.parseError": "Analysefehler im Dokument: %@1",
              "DG.AppController.validateDocument.invalidDocument": "Ungültiges JSON Dokument: %@1",
              "DG.AppController.openDocument.error.general": "Das Dokument konnte nicht geöffnet werden.",
              "DG.AppController.openDocument.error.invalid_format": "Dieser Dokumenttyp kann von CODAP nicht gelesen werden",
              "DG.AppController.createDataSet.initialAttribute": "Merkmal",
              "DG.AppController.createDataSet.name": "Neuer Datensatz",
              "DG.AppController.createDataSet.collectionName": "Fälle",
              "DG.AppController.caseTableMenu.newDataSet": "-- neu --",
              "DG.SingleTextDialog.okButton.title": "OK",
              "DG.SingleTextDialog.cancelButton.title": "Abbrechen",
              "DG.SingleTextDialog.cancelButton.toolTip": "Ohne Änderungen verlassen",
              "DG.DocumentController.calculatorTitle": "Taschenrechner",
              "DG.DocumentController.caseTableTitle": "Falltabelle",
              "DG.DocumentController.graphTitle": "Graph",
              "DG.DocumentController.sliderTitle": "Regler",
              "DG.DocumentController.textTitle": "Textfeld",
              "DG.DocumentController.mapTitle": "Karte",
              "DG.DocumentController.enterURLPrompt": "URL eingeben, um eine Website anzuzeigen",
              "DG.DocumentController.enterViewWebPageOKTip": "Die Website der URL anzeigen",
              "DG.Document.defaultDocumentName": "Unbenanntes Dokument",
              "DG.Document.documentName.toolTip": "Klicken, um den Name des Dokuments zu ändern",
              "DG.SliderView.thumbView.toolTip": "Ziehen, um den Wert des Reglers zu ändern",
              "DG.SliderView.startButton.toolTip": "Animation starten/anhalten",
              "DG.ToolButtonData.tableButton.title": "Tabellen",
              "DG.ToolButtonData.tableButton.toolTip": "Öffne eine Falltabelle für jeden Datensatz (Strg+alt+t)",
              "DG.ToolButtonData.graphButton.title": "Graph",
              "DG.ToolButtonData.graphButton.toolTip": "Erstelle einen Graph (Strg+alt+g)",
              "DG.ToolButtonData.sliderButton.title": "Regler",
              "DG.ToolButtonData.sliderButton.toolTip": "Erstelle einen Regler (Strg+alt+s)",
              "DG.ToolButtonData.calcButton.title": "Rechner",
              "DG.ToolButtonData.calcButton.toolTip": "Öffne/Schließe den Taschenrechner (Strg+alt+c)",
              "DG.ToolButtonData.textButton.title": "Text",
              "DG.ToolButtonData.textButton.toolTip": "Erstelle ein Textfeld (Strg+alt+shift+t)",
              "DG.ToolButtonData.mapButton.title": "Karte",
              "DG.ToolButtonData.mapButton.toolTip": "Eine Karte erstellen",
              "DG.ToolButtonData.optionMenu.title": "Einstellungen",
              "DG.ToolButtonData.optionMenu.toolTip": "Website anzeigen, Anleitung konfigurieren",
              "DG.ToolButtonData.tileListMenu.title": "Objekte",
              "DG.ToolButtonData.tileListMenu.toolTip": "Liste der Objekte anzeigen",
              "DG.ToolButtonData.guideMenu.title": "Anleitung",
              "DG.ToolButtonData.guideMenu.toolTip": "Anleitung dieser Aktivität anzeigen und verwenden",
              "DG.ToolButtonData.guideMenu.showGuide": "Anleitung zeigen",
              "DG.ToolButtonData.help.title": "Hilfe",
              "DG.ToolButtonData.help.toolTip": "Hilfe zu CODAP, das Projekt kennenlernen",
              "DG.Slider.multiples": "Begrenzen auf Vielfache von:",
              "DG.Slider.maxPerSecond": "Maximum Animation Frames/sec",
              "DG.Slider.direction": "Richtung der Animation",
              "DG.Slider.backAndForth": "Vor und Zurück",
              "DG.Slider.lowToHigh": "Niedrig zu Hoch",
              "DG.Slider.highToLow": "Hoch zu Niedrig",
              "DG.Slider.mode": "Wiederholung der Animation",
              "DG.Slider.nonStop": "pausenlos",
              "DG.Slider.onceOnly": "Nur einmal",
              "DG.Undo.exceptionOccurred": "Ein Fehler trat auf beim Rückgängig Machen.",
              "DG.Redo.exceptionOccurred": "Ein Fehler trat auf beim Wiederholen.",
              "DG.Undo.componentMove": "Rückgängig: Das Objekt verschieben",
              "DG.Redo.componentMove": "Wiederholen: Das Objekt verschieben",
              "DG.Undo.componentResize": "Rückgängig: Größenänderung des Objekts",
              "DG.Redo.componentResize": "Wiederholen: Größenänderung des Objekts",
              "DG.Undo.axisDilate": "Rückgängig: Die Achse verändern",
              "DG.Redo.axisDilate": "Wiederholen: Die Achse verändern",
              "DG.Undo.axisRescaleFromData": "Rückgängig: Die Achse verändern",
              "DG.Redo.axisRescaleFromData": "Wiederholen: Die Achse verändern",
              "DG.Undo.axisDrag": "Rückgängig: Verschieben der Achse",
              "DG.Redo.axisDrag": "Wiederholen: Verschieben der Achse",
              "DG.Undo.axisAttributeChange": "Rückgängig: Das Merkmal der Achse verändern",
              "DG.Redo.axisAttributeChange": "Wiederholen: Das Merkmal der Achse verändern",
              "DG.Undo.axisAttributeAdded": "Rückgängig: Der Achse ein Merkmal hinzufügen",
              "DG.Redo.axisAttributeAdded": "Wiederholen: Der Achse ein Merkmal hinzufügen",
              "DG.Undo.toggleComponent.add.calcView": "Rückgängig: Den Taschenrechner einblenden",
              "DG.Redo.toggleComponent.add.calcView": "Wiederholen: Den Taschenrechner einblenden",
              "DG.Undo.toggleComponent.delete.calcView": "Rückgängig: Den Taschenrechner verbergen",
              "DG.Redo.toggleComponent.delete.calcView": "Wiederholen: Den Taschenrechner verbergen",
              "DG.Undo.caseTable.open": "Rückgängig: Die Tabelle einblenden",
              "DG.Redo.caseTable.open": "Wiederholen: Die Tabelle einblenden",
              "DG.Undo.caseTable.editAttribute": "Rückgängig: Eigenschaften der Tabelle",
              "DG.Redo.caseTable.editAttribute": "Wiederholen: Eigenschaften der Tabelle",
              "DG.Undo.caseTable.createAttribute": "Rückgängig: Eigenschaften der Tabelle erstellen",
              "DG.Redo.caseTable.createAttribute": "Wiederholen: Eigenschaften der Tabelle erstellen",
              "DG.Undo.caseTable.editAttributeFormula": "Rückgängig: Formel der Tabelle bearbeiten",
              "DG.Redo.caseTable.editAttributeFormula": "Wiederholen: Formel der Tabelle bearbeiten",
              "DG.Undo.caseTable.editCellValue": "Rückgängig: Zellwert der Tabelle bearbeiten",
              "DG.Redo.caseTable.editCellValue": "Wiederholen: Zellwert der Tabelle bearbeiten",
              "DG.Undo.caseTable.sortCases": "Rückgängig: Fälle sortieren",
              "DG.Redo.caseTable.sortCases": "Wiederholen: Fälle sortieren",
              "DG.Undo.caseTable.deleteAttribute": "Rückgängig: Eigenschaft der Tabelle löschen",
              "DG.Redo.caseTable.deleteAttribute": "Wiederholen: Eigenschaft der Tabelle löschen",
              "DG.Undo.caseTable.createCollection": "Rückgängig: Neue Kollektion erstellen",
              "DG.Redo.caseTable.createCollection": "Wiederholen: Neue Kollektion erstellen",
              "DG.Undo.caseTable.collectionNameChange": "Rückgängig: Kollektion umbenennen",
              "DG.Redo.caseTable.collectionNameChange": "Wiederholen: Kollektion umbenennen",
              "DG.Undo.caseTable.createNewCase": "Rückgängig: Neuen Fall erstellen",
              "DG.Redo.caseTable.createNewCase": "Wiederholen: Neuen Fall erstellen",
              "DG.Undo.caseTable.insertCases": "Rückgängig: Fälle einfügen",
              "DG.Redo.caseTable.insertCases": "Wiederholen: Fälle einfügen",
              "DG.Undo.caseTable.groupToggleExpandCollapseAll": "Rückgängig: Ein-/Ausblenden",
              "DG.Redo.caseTable.groupToggleExpandCollapseAll": "Wiederholen: Ein-/Ausblenden",
              "DG.Undo.caseTable.expandCollapseOneCase": "Rückgängig: Gruppe vergrößern oder verkleinern",
              "DG.Redo.caseTable.expandCollapseOneCase": "Wiederholen: Gruppe vergrößern oder verkleinern",
              "DG.Undo.caseTable.resizeColumns": "Rückgängig: Automatische Größenanpassung aller Spalten",
              "DG.Redo.caseTable.resizeColumns": "Wiederholen: Automatische Größenanpassung aller Spalten",
              "DG.Undo.document.share": "Rückgängig: Dokument teilen",
              "DG.Redo.document.share": "Wiederholen: Dokument teilen",
              "DG.Undo.document.unshare": "Rückgängig: Dokument teilen beenden",
              "DG.Redo.document.unshare": "Wiederholen: Dokument teilen beenden",
              "DG.Undo.game.add": "Rückgängig: Ein Spiel hinzufügen",
              "DG.Redo.game.add": "Wiederholen: Ein Spiel hinzufügen",
              "DG.Undo.graph.showCount": "Rückgängig: Anzahl zeigen",
              "DG.Redo.graph.showCount": "Wiederholen: Anzahl zeigen",
              "DG.Undo.graph.hideCount": "Rückgängig: Anzahl verbergen",
              "DG.Redo.graph.hideCount": "Wiederholen: Anzahl verbergen",
              "DG.Undo.graph.showPercent": "Rückgängig: Prozent zeigen",
              "DG.Redo.graph.showPercent": "Wiederholen: Prozent zeigen",
              "DG.Undo.graph.hidePercent": "Rückgängig: Prozent verbergen",
              "DG.Redo.graph.hidePercent": "Wiederholen: Prozent verbergen",
              "DG.Undo.graph.showMovableLine": "Rückgängig: Bewegliche Linie zeigen",
              "DG.Redo.graph.showMovableLine": "Wiederholen: Bewegliche Linie zeigen",
              "DG.Undo.graph.hideMovableLine": "Rückgängig: Bewegliche Linie verbergen",
              "DG.Redo.graph.hideMovableLine": "Wiederholen: Bewegliche Linie verbergen",
              "DG.Undo.graph.lockIntercept": "Rückgängig: Abschnitt sperren",
              "DG.Redo.graph.lockIntercept": "Wiederholen: Abschnitt sperren",
              "DG.Undo.graph.unlockIntercept": "Rückgängig: Abschnitt freigeben",
              "DG.Redo.graph.unlockIntercept": "Wiederholen: Abschnitt freigeben",
              "DG.Undo.graph.showPlotFunction": "Rückgängig: Funktion anzeigen",
              "DG.Redo.graph.showPlotFunction": "Wiederholen: Funktion anzeigen",
              "DG.Undo.graph.hidePlotFunction": "Rückgängig: Funktion verbergen",
              "DG.Redo.graph.hidePlotFunction": "Wiederholen: Funktion verbergen",
              "DG.Undo.graph.changePlotFunction": "Rückgängig: Funktion ändern",
              "DG.Redo.graph.changePlotFunction": "Wiederholen: Funktion ändern",
              "DG.Undo.graph.showPlotValue": "Rückgängig: Werte anzeigen",
              "DG.Redo.graph.showPlotValue": "Wiederholen: Werte anzeigen",
              "DG.Undo.graph.hidePlotValue": "Rückgängig: Werte verbergen",
              "DG.Redo.graph.hidePlotValue": "Wiederholen: Werte verbergen",
              "DG.Undo.graph.changePlotValue": "Rückgängig: Werte ändern",
              "DG.Redo.graph.changePlotValue": "Wiederholen :Werte ändern",
              "DG.Undo.graph.showConnectingLine": "Rückgängig: Verbundene Linien zeigen",
              "DG.Redo.graph.showConnectingLine": "Wiederholen: Verbundene Linien zeigen",
              "DG.Undo.graph.hideConnectingLine": "Rückgängig: Verbundene Linien verbergen",
              "DG.Redo.graph.hideConnectingLine": "Wiederholen: Verbundene Linien verbergen",
              "DG.Undo.graph.showLSRL": "Rückgängig: Ausgleichsgerade",
              "DG.Redo.graph.showLSRL": "Wiederholen: Ausgleichsgerade",
              "DG.Undo.graph.hideLSRL": "Rückgängig: Ausgleichsgerade",
              "DG.Redo.graph.hideLSRL": "Wiederholen: Ausgleichsgerade",
              "DG.Undo.graph.showSquares": "Rückgängig: Quadrate anzeigen",
              "DG.Redo.graph.showSquares": "Wiederholen: Quadrate anzeigen",
              "DG.Undo.graph.hideSquares": "Rückgängig: Quadrate verbergen",
              "DG.Redo.graph.hideSquares": "Wiederholen: Quadrate verbergen",
              "DG.Undo.graph.showPlottedMean": "Rückgängig: Arithmetisches Mittel anzeigen",
              "DG.Redo.graph.showPlottedMean": "Wiederholen: Arithmetisches Mittel anzeigen",
              "DG.Undo.graph.hidePlottedMean": "Rückgängig: Arithmetisches Mittel verbergen",
              "DG.Redo.graph.hidePlottedMean": "Wiederholen: Arithmetisches Mittel verbergen",
              "DG.Undo.graph.showPlottedMedian": "Rückgängig: Median anzeigen",
              "DG.Redo.graph.showPlottedMedian": "Wiederholen: Median anzeigen",
              "DG.Undo.graph.hidePlottedMedian": "Rückgängig: Median verbergen",
              "DG.Redo.graph.hidePlottedMedian": "Wiederholen: Median verbergen",
              "DG.Undo.graph.showPlottedStDev": "Rückgängig: Standardabweichung anzeigen",
              "DG.Redo.graph.showPlottedStDev": "Wiederholen: Standardabweichung anzeigen",
              "DG.Undo.graph.hidePlottedStDev": "Rückgängig: Standardabweichung verbergen",
              "DG.Redo.graph.hidePlottedStDev": "Wiederholen: Standardabweichung verbergen",
              "DG.Undo.graph.showPlottedIQR": "Rückgängig: Interquartilsabstand anzeigen",
              "DG.Redo.graph.hidePlottedIQR": "Wiederholen: Interquartilsabstand anzeigen",
              "DG.Undo.graph.hidePlottedIQR": "Rückgängig: Interquartilsabstand verbergen",
              "DG.Redo.graph.showPlottedIQR": "Wiederholen: Interquartilsabstand verbergen",
              "DG.Undo.graph.addMovableValue": "Rückgängig: Beweglichen Wert hinzufügen",
              "DG.Redo.graph.addMovableValue": "Wiederholen: Beweglichen Wert hinzufügen",
              "DG.Undo.graph.removeMovableValue": "Rückgängig: Beweglichen Wert entfernen",
              "DG.Redo.graph.removeMovableValue": "Wiederholen: Beweglichen Wert entfernen",
              "DG.Undo.graph.moveMovableValue": "Rückgängig: Beweglichen Wert bewegen",
              "DG.Redo.graph.moveMovableValue": "Wiederholen: Beweglichen Wert bewegen",
              "DG.Undo.graph.changePointColor": "Rückgängig: Datenfarbe ändern",
              "DG.Redo.graph.changePointColor": "Wiederholen: Datenfarbe ändern",
              "DG.Undo.graph.changeStrokeColor": "Rückgängig: Umrandungsfarbe ändern",
              "DG.Redo.graph.changeStrokeColor": "Wiederholen: Umrandungsfarbe ändern",
              "DG.Undo.graph.changePointSize": "Rückgängig: Punktgröße ändern",
              "DG.Redo.graph.changePointSize": "Wiederholen: Punktgröße ändern",
              "DG.Undo.graph.changeAttributeColor": "Rückgängig: Merkmalsfarbe ändern",
              "DG.Redo.graph.changeAttributeColor": "Wiederholen: Merkmalsfarbe ändern",
              "DG.Undo.graph.changeBackgroundColor": "Rückgängig: Hintergrundfarbe des Graphen ändern",
              "DG.Redo.graph.changeBackgroundColor": "Wiederholen: Hintergrundfarbe des Graphen ändern",
              "DG.Undo.graph.toggleTransparent": "Rückgängig: Transparenz ändern",
              "DG.Redo.graph.toggleTransparent": "Wiederholen: Transparenz ändern",
              "DG.Undo.guide.show": "Rückgängig: Einführung anzeigen",
              "DG.Redo.guide.show": "Wiederholen: Einführung anzeigen",
              "DG.Undo.guide.navigate": "Rückgängig: Einführungsseite ändern",
              "DG.Redo.guide.navigate": "Wiederholen: Einführungsseite ändern",
              "DG.Undo.hideSelectedCases": "Rückgängig: Ausgewählte Fälle verbergen",
              "DG.Redo.hideSelectedCases": "Wiederholen: Ausgewählte Fälle verbergen",
              "DG.Undo.hideUnselectedCases": "Rückgängig: Nichtausgewählte Fälle verbergen",
              "DG.Redo.hideUnselectedCases": "Wiederholen: Nichtausgewählte Fälle verbergen",
              "DG.Undo.enableNumberToggle": "Rückgängig: übergeordnete Sichtbarkeit aktivieren",
              "DG.Redo.enableNumberToggle": "Wiederholen: übergeordnete Sichtbarkeit aktivieren",
              "DG.Undo.disableNumberToggle": "Rückgängig: übergeordnete Sichtbarkeit verbergen",
              "DG.Redo.disableNumberToggle": "Wiederholen: übergeordnete Sichtbarkeit verbergen",
              "DG.Undo.interactiveUndoableAction": "Rückgängig: Aktivität",
              "DG.Redo.interactiveUndoableAction": "Wiederholen: Aktivität",
              "DG.Undo.showAllCases": "Rückgängig: Alle Fälle anzeigen",
              "DG.Redo.showAllCases": "Wiederholen: Alle Fälle anzeigen",
              "DG.Undo.map.create": "Rückgängig: Karte hinzufügen",
              "DG.Redo.map.create": "Wiederholen: Karte hinzufügen",
              "DG.Undo.map.fitBounds": "Rückgängig: Kartengröße ändern",
              "DG.Redo.map.fitBounds": "Wiederholen: Kartengröße ändern",
              "DG.Undo.map.pan": "Rückgängig: Karte verschieben",
              "DG.Redo.map.pan": "Wiederholen: Karte verschieben",
              "DG.Undo.map.zoom": "Rückgängig: Zoomen",
              "DG.Redo.map.zoom": "Wiederholen: Zoomen",
              "DG.Undo.map.showGrid": "Rückgängig: Raster in Karte zeigen",
              "DG.Redo.map.showGrid": "Wiederholen: Raster in Karte zeigen",
              "DG.Undo.map.hideGrid": "Rückgängig: Raster in Karte verbergen",
              "DG.Redo.map.hideGrid": "Wiederholen: Raster in Karte verbergen",
              "DG.Undo.map.changeGridSize": "Rückgängig: Rastergröße der Karte ändern",
              "DG.Redo.map.changeGridSize": "Wiederholen: Rastergröße der Karte ändern",
              "DG.Undo.map.showPoints": "Rückgängig: Punkte auf Karte zeigen",
              "DG.Redo.map.showPoints": "Wiederholen: Punkte auf Karte zeigen",
              "DG.Undo.map.hidePoints": "Rückgängig: Punkte auf Karte verbergen",
              "DG.Redo.map.hidePoints": "Wiederholen: Punkte auf Karte verbergen",
              "DG.Undo.map.showLines": "Rückgängig: Linien auf Karte zeigen",
              "DG.Redo.map.showLines": "Wiederholen: Linien auf Karte zeigen",
              "DG.Undo.map.hideLines": "Rückgängig: Linien auf Karte verbergen",
              "DG.Redo.map.hideLines": "Wiederholen: Linien auf Karte verbergen",
              "DG.Undo.map.changeBaseMap": "Rückgängig: Hintergrund der Karte ändern",
              "DG.Redo.map.changeBaseMap": "Wiederholen: Hintergrund der Karte ändern",
              "DG.Undo.textComponent.create": "Rückgängig: Textobjekt hinzufügen",
              "DG.Redo.textComponent.create": "Wiederholen: Textobjekt hinzufügen",
              "DG.Undo.textComponent.edit": "Rückgängig: Text editieren",
              "DG.Redo.textComponent.edit": "Wiederholen: Text editieren",
              "DG.Undo.sliderComponent.create": "Rückgängig: Regler hinzufügen",
              "DG.Redo.sliderComponent.create": "Wiederholen: Regler hinzufügen",
              "DG.Undo.slider.change": "Rückgängig: Wert des Reglers ändern",
              "DG.Redo.slider.change": "Wiederholen: Wert des Reglers ändern",
              "DG.Undo.slider.changeMultiples": "Rückgängig: Einschränkung",
              "DG.Redo.slider.changeMultiples": "Wiederholen: Einschränkung",
              "DG.Undo.slider.changeSpeed": "Rückgängig: Reglergeschwindigkeit",
              "DG.Redo.slider.changeSpeed": "Wiederholen: Reglergeschwindigkeit",
              "DG.Undo.slider.changeDirection": "Rückgängig: Regleranimation",
              "DG.Redo.slider.changeDirection": "Wiederholen: Regleranimation",
              "DG.Undo.slider.changeRepetition": "Rückgängig: Regler",
              "DG.Redo.slider.changeRepetition": "Wiederholen: Regler",
              "DG.Undo.graphComponent.create": "Rückgängig: Graph hinzufügen",
              "DG.Redo.graphComponent.create": "Wiederholen: Graph hinzufügen",
              "DG.Undo.dataContext.create": "Rückgängig: Datensatz erstellen",
              "DG.Redo.dataContext.create": "Wiederholen: Datensatz erstellen",
              "DG.Undo.data.deleteCases": "Rückgängig: Fälle löschen",
              "DG.Redo.data.deleteCases": "Wiederholen: Fälle löschen",
              "DG.Undo.component.close": "Rückgängig: Schließen",
              "DG.Redo.component.close": "Wiederholen: Schließen",
              "DG.Undo.component.minimize": "Rückgängig: Verkleinern",
              "DG.Redo.component.minimize": "Wiederholen: Verkleinern",
              "DG.Undo.dataContext.moveAttribute": "Rückgängig: Merkmal der Tabelle verschieben",
              "DG.Redo.dataContext.moveAttribute": "Wiederholen: Merkmal der Tabelle verschieben",
              "DG.DataContext.singleCaseName": "Fall",
              "DG.DataContext.pluralCaseName": "Fälle",
              "DG.DataContext.caseCountString": "%@1 %@2",
              "DG.DataContext.setOfCasesLabel": "Eine Kollektion",
              "DG.DataContext.collapsedRowString": "%@1 of %@2",
              "DG.DataContext.noData": "Keine Daten",
              "DG.DataContext.baseName": "Datensatz_%@1",
              "DG.CollectionClient.cantEditFormulaErrorMsg": "Die Formel des Merkmals \"%@\" kann nicht geändert werden.",
              "DG.CollectionClient.cantEditFormulaErrorDesc": "Ein neues Merkmal erstellen, um eine Formel zu verwenden",
              "DG.Formula.FuncCategoryArithmetic": "Arithmetik Funktionen",
              "DG.Formula.FuncCategoryConversion": "Andere Funktionen",
              "DG.Formula.FuncCategoryDateTime": "Datum/Zeit Funktionen",
              "DG.Formula.FuncCategoryLookup": "Such-Funktionen",
              "DG.Formula.FuncCategoryOther": "Andere Funktionen",
              "DG.Formula.FuncCategoryRandom": "Andere Funktionen",
              "DG.Formula.FuncCategoryStatistical": "Statistische Funktionen",
              "DG.Formula.FuncCategoryString": "Text Funktionen",
              "DG.Formula.FuncCategoryTrigonometric": "Trigonometrische Funktionen",
              "DG.Formula.DateLongMonthJanuary": "Januar",
              "DG.Formula.DateLongMonthFebruary": "Februar",
              "DG.Formula.DateLongMonthMarch": "März",
              "DG.Formula.DateLongMonthApril": "April",
              "DG.Formula.DateLongMonthMay": "Mai",
              "DG.Formula.DateLongMonthJune": "Juni",
              "DG.Formula.DateLongMonthJuly": "Juli",
              "DG.Formula.DateLongMonthAugust": "August",
              "DG.Formula.DateLongMonthSeptember": "September",
              "DG.Formula.DateLongMonthOctober": "Oktober",
              "DG.Formula.DateLongMonthNovember": "November",
              "DG.Formula.DateLongMonthDecember": "Dezember",
              "DG.Formula.DateShortMonthJanuary": "Jan",
              "DG.Formula.DateShortMonthFebruary": "Feb",
              "DG.Formula.DateShortMonthMarch": "Mär",
              "DG.Formula.DateShortMonthApril": "Apr",
              "DG.Formula.DateShortMonthMay": "Mai",
              "DG.Formula.DateShortMonthJune": "Jun",
              "DG.Formula.DateShortMonthJuly": "Jul",
              "DG.Formula.DateShortMonthAugust": "Aug",
              "DG.Formula.DateShortMonthSeptember": "Sep",
              "DG.Formula.DateShortMonthOctober": "Okt",
              "DG.Formula.DateShortMonthNovember": "Nov",
              "DG.Formula.DateShortMonthDecember": "Dez",
              "DG.Formula.DateLongDaySunday": "Sonntag",
              "DG.Formula.DateLongDayMonday": "Montag",
              "DG.Formula.DateLongDayTuesday": "Dienstag",
              "DG.Formula.DateLongDayWednesday": "Mittwoch",
              "DG.Formula.DateLongDayThursday": "Donnerstag",
              "DG.Formula.DateLongDayFriday": "Freitag",
              "DG.Formula.DateLongDaySaturday": "Samstag",
              "DG.Utilities.date.localDatePattern": "(?:(?:[0-3]?\\d-(?:jan|feb|mär|apr|mai|jun|jul|aug|sep|okt|nov|dez)-\\d{2}(?:\\d{2})?)|(?:[01]?\\d/[0-3]?\\d/\\d{2}(?:\\d{2})?))",
              "DG.Utilities.date.timePattern": "(?:[0-2]?\\d:[0-5]?\\d(?::[0-5]\\d(?:\\.\\d{3})?)? ?(?:[ap]m)?)",
              "DG.Utilities.date.iso8601Pattern": "^\\d{4}-[01]\\d-[0-3]\\d(?:[T ][0-2]\\d:[0-5]\\d(?::[0-5]\\d(?:\\.\\d{3,6})?)?(?:Z|(?:[-+]?[01]\\d:[0-5]\\d)|(?: ?[-+][0-2]\\d{3}))?)?$",
              "DG.Utilities.colorPattern": "4\n(?:rgb\\((?:\\d{1,3},){2}\\d{1,3}\\))|(?:rgba\\((?:\\d{1,3},){3}[\\d\\.]*\\))|(?:#[\\da-f]{6})",
              "DG.Formula.SyntaxErrorMiddle": "Syntaxfehler: '%@'",
              "DG.Formula.SyntaxErrorEnd": "Unvollständiger Ausdruck",
              "DG.Formula.SyntaxErrorInvalidOperator": "Ungültiger Operator '%@'",
              "DG.Formula.TypeError.name": "❌",
              "DG.Formula.TypeError.message": "ungültige Typen '%@'",
              "DG.Formula.TypeError.description": "ungültige Typen '%@'",
              "DG.Formula.VarReferenceError.name": "❌",
              "DG.Formula.VarReferenceError.message": "'%@' wurde nicht erkannt",
              "DG.Formula.VarReferenceError.description": "Die Variable '%@' wurde nicht erkannt.",
              "DG.Formula.HierReferenceError.name": "❌",
              "DG.Formula.HierReferenceError.message": "ungültiger Bezug '%@'",
              "DG.Formula.HierReferenceError.description": "'%@' ist ein untergeordnetes Merkmal und kann nur aggregiert werden",
              "DG.Formula.FuncReferenceError.name": "❌",
              "DG.Formula.FuncReferenceError.message": "'%@()' wurde nicht erkannt",
              "DG.Formula.FuncReferenceError.description": "Die Funktion '%@()' wurde nicht erkannt",
              "DG.Formula.FuncArgsError.name": "❌",
              "DG.Formula.FuncArgsErrorSingle.message": "'%@()' erwartet 1 Argument",
              "DG.Formula.FuncArgsErrorSingle.description": "Die Funktion '%@()' erwartet 1 Argument",
              "DG.Formula.FuncArgsErrorPlural.message": "'%@()' erwartet %@ Argumente",
              "DG.Formula.FuncArgsErrorPlural.description": "Die Funktion '%@()' erwartet %@ Argumente",
              "DG.Formula.FuncArgsErrorRange.message": "'%@()' erwartet %@-%@ Argumente",
              "DG.Formula.FuncArgsErrorRange.description": "Die Funktion '%@()' erwartet %@-%@ Argumente",
              "DG.Formula.PendingRequest.name": "⌛",
              "DG.Formula.PendingRequest.message": "Ausstehende Anfrage...",
              "DG.Formula.PendingRequest.description": "Ausstehende Anfrage...",
              "DG.Formula.FailedRequest.name": "❌",
              "DG.Formula.FailedRequest.message": "Anfrage fehlgeschlagen  (%@)",
              "DG.Formula.FailedRequest.description": "Anfrage fehlgeschlagen (%@)",
              "DG.Formula.PendingBoundaries.name": "⌛",
              "DG.Formula.PendingBoundaries.message": "offene Grenzen...",
              "DG.Formula.PendingBoundaries.description": "offene Grenzen...",
              "DG.Formula.FailedBoundaries.name": "❌",
              "DG.Formula.FailedBoundaries.message": "Grenzen gescheitert (%@)",
              "DG.Formula.FailedBoundaries.description": "Grenzen gescheitert (%@)",
              "DG.Formula.LookupDataSetError.message": "'%@': nicht erkannter Datensatz",
              "DG.Formula.LookupDataSetError.description": "Der Datensatz '%@' wurde nicht erkannt",
              "DG.Formula.LookupAttrError.message": "'%@' wurde im Datensatz '%@' nicht gefunden",
              "DG.Formula.LookupAttrError.description": "Merkmal '%@' im Datensatz '%@' nicht gefunden",
              "DG.TableController.headerMenuItems.editAttribute": "Eigenschaften des Merkmals bearbeiten...",
              "DG.TableController.headerMenuItems.editFormula": "Formel bearbeiten...",
              "DG.TableController.headerMenuItems.randomizeAttribute": "Rerandomisieren",
              "DG.TableController.headerMenuItems.sortAscending": "Aufsteigend sortieren (A→Z, 0→9)",
              "DG.TableController.headerMenuItems.sortDescending": "Absteigend sortieren (Z→A, 9→0)",
              "DG.TableController.headerMenuItems.deleteAttribute": "Merkmal löschen",
              "DG.TableController.newAttrDlg.defaultAttrName": "neues_Merkm",
              "DG.TableController.newAttrDlg.attrNameHint": "Einen Namen eingeben für das neue Merkmal",
              "DG.TableController.newAttrDlg.formulaHint": "Eine Formel benutzen, um Werte dieses Merkmals zu berechnen, falls gewünscht",
              "DG.TableController.newAttrDlg.applyTooltip": "Das neue Merkmal definieren mit einem Namen und einer (optionalen) Formel",
              "DG.TableController.newAttrDlg.mustEnterAttrNameMsg": "Bitte einen Namen eingeben für das neue Merkmal",
              "DG.TableController.newAttrDialog.AttributesCategory": "Merkmale",
              "DG.TableController.newAttrDialog.SpecialCategory": "Spezial",
              "DG.TableController.newAttrDialog.GlobalsCategory": "Allgemeines",
              "DG.TableController.newAttrDialog.ConstantsCategory": "Konstanten",
              "DG.TableController.newAttrDialog.FunctionsCategory": "Funktionen",
              "DG.TableController.renameAttributeInvalidMsg": "Merkmalsnamen dürfen nicht leer sein",
              "DG.TableController.renameAttributeInvalidDesc": "Bitte einen gültigen Merkmalsnamen eingeben",
              "DG.TableController.renameAttributeDuplicateMsg": "Dieser Merkmalsname ist bereits vergeben",
              "DG.TableController.renameAttributeDuplicateDesc": "Bitte einen eindeutigen Merkmalsnamen eingeben",
              "DG.TableController.deleteAttribute.confirmMessage": "Das Merkmal '%@' löschen?",
              "DG.TableController.deleteAttribute.confirmDescription": "Diese Aktion kann nicht rückgängig gemacht werden.",
              "DG.TableController.deleteAttribute.okButtonTitle": "Merkmal löschen",
              "DG.TableController.deleteAttribute.cancelButtonTitle": "Abbrechen",
              "DG.TableController.deleteDataSet.confirmMessage": "Diesen Datensatz unwiederbringlich löschen: '%@'?",
              "DG.TableController.deleteDataSet.confirmDescription": "Diese Aktion kann nicht rückgängig gemacht werden.",
              "DG.TableController.deleteDataSet.okButtonTitle": "Datensatz löschen",
              "DG.TableController.deleteDataSet.cancelButtonTitle": "Abbrechen",
              "DG.TableController.attrEditor.unitHint": "Einheit der Messung, falls angebbar",
              "DG.TableController.attrEditor.descriptionHint": "Das Merkmal beschreiben",
              "DG.TableController.setScoreDlg.applyTooltip": "Eine Formel für das Merkmal '%@' eingeben",
              "DG.TableController.setScoreDlg.formulaHint": "Eine Formel eingeben, um Werte dieses Merkmals zu berechnen",
              "DG.TableController.newAttributeTooltip": "Der Tabelle ein neues Merkmal hinzufügen",
              "DG.TableController.attributeEditor.title": "Eigenschaften des Merkmals",
              "DG.CaseTableDropTarget.dropMessage": "Merkmal fallen lassen, um eine neue Kollektion zu erzeugen",
              "DG.CaseTable.defaultAttrName": "neuesMerkm",
              "DG.CaseTable.indexColumnName": "Index",
              "DG.CaseTable.indexColumnTooltip": "Zeilennummer (FallIndex) der Kollektion",
              "DG.CaseTable.indexMenu.insertCase": "Fall hinzufügen",
              "DG.CaseTable.indexMenu.insertCases": "Fälle hinzufügen",
              "DG.CaseTable.indexMenu.deleteCase": "Fall löschen",
              "DG.CaseTable.indexMenu.deleteCases": "Fälle löschen",
              "DG.CaseTable.attribute.type.none": "\u200b",
              "DG.CaseTable.attribute.type.nominal": "kategorial",
              "DG.CaseTable.attribute.type.categorical": "kategorial",
              "DG.CaseTable.attribute.type.numeric": "numerisch",
              "DG.CaseTable.attribute.type.date": "Datum",
              "DG.CaseTable.attribute.type.qualitative": "qualitativ",
              "DG.CaseTable.attribute.type.boundary": "Grenzen",
              "DG.CaseTable.attributeEditor.name": "Name",
              "DG.CaseTable.attributeEditor.description": "Beschreibung",
              "DG.CaseTable.attributeEditor.type": "Typ",
              "DG.CaseTable.attributeEditor.unit": "Einheit",
              "DG.CaseTable.attributeEditor.precision": "Genauigkeit",
              "DG.CaseTable.attributeEditor.editable": "editierbar",
              "DG.CaseTable.insertCasesDialog.title": "Fälle hinzufügen",
              "DG.CaseTable.insertCasesDialog.numCasesPrompt": "# Fälle, die eingefügt werden sollen",
              "DG.CaseTable.insertCasesDialog.beforeAfter.prompt": "Position:",
              "DG.CaseTable.insertCasesDialog.beforeAfter.before": "vor",
              "DG.CaseTable.insertCasesDialog.beforeAfter.after": "nach",
              "DG.CaseTable.insertCasesDialog.applyBtnTitle": "Fälle einfügen",
              "DG.CaseTable.insertCasesDialog.applyBtnTooltip": "Festgelegte Anzahl Fälle einfügen",
              "DG.CaseTableController.allTables": "Alle Tabellen",
              "DG.AttrFormView.attrNamePrompt": "Name des Merkmals:",
              "DG.AttrFormView.formulaPrompt": "Formel:",
              "DG.AttrFormView.operandMenuTitle": "--- Wert einfügen ---",
              "DG.AttrFormView.functionMenuTitle": "--- Funktion einfügen ---",
              "DG.AttrFormView.applyBtnTitle": "Bestätigen",
              "DG.AttrFormView.cancelBtnTitle": "Abbrechen",
              "DG.AttrFormView.cancelBtnTooltip": "Den Dialog ohne Änderungen verlassen",
              "DG.GuideConfigView.titlePrompt": "Einführungstitel",
              "DG.GuideConfigView.titleHint": "Name der Aktivität",
              "DG.GuideConfigView.itemTitleHint": "Abschnittsname",
              "DG.GuideConfigView.itemURLHint": "URL des Abschnitts",
              "DG.GuideConfigView.okBtnTitle": "OK",
              "DG.GuideConfigView.okBtnToolTip": "Einführungspunkte akzeptieren",
              "DG.GuideConfigView.cancelBtnTitle": "Abbrechen",
              "DG.GuideConfigView.cancelBtnTooltip": "Den Dialog verlassen ohne Änderung",
              "DG.GuideConfigView.httpWarning": "Die Adresse muss entweder mit http:// oder mit https:// starten",
              "DG.DataDisplayModel.rescaleToData": "Daten skalieren",
              "DG.DataDisplayModel.ShowConnectingLine": "Verbindungslinien zeigen",
              "DG.DataDisplayModel.HideConnectingLine": "Verbindungslinien verbergen",
              "DG.AxisView.emptyGraphCue": "Hier klicken oder ein Merkmal hierher ziehen",
              "DG.CellLinearAxisView.midPanelTooltip": "Ziehen, um die Achsenskala anzupassen",
              "DG.CellLinearAxisView.lowerPanelTooltip": "Ziehen, um die untere Grenze der Achse zu ändern",
              "DG.CellLinearAxisView.upperPanelTooltip": "Ziehen, um die obere Grenze der Achse zu ändern",
              "DG.PlotModel.mixup": "Graph mischen",
              "DG.PlotModel.showCount": "Anzahl zeigen",
              "DG.PlotModel.hideCount": "Anzahl verbergen",
              "DG.ScatterPlotModel.sumSquares": ",\nSumme der Quadrate = %@",
              "DG.ScatterPlotModel.slopeOnly": "Steigung = %@ %@",
              "DG.ScatterPlotModel.yearsLabel": "pro Jahr",
              "DG.ScatterPlotModel.daysLabel": "pro Tag",
              "DG.ScatterPlotModel.hoursLabel": "pro Stunde",
              "DG.ScatterPlotModel.minutesLabel": "pro Minute",
              "DG.ScatterPlotModel.secondsLabel": "pro Sekunde",
              "DG.LegendView.attributeTooltip": "Klicken, um das Legendenmerkmal zuändern",
              "DG.NumberToggleView.showAll": "Alle anzeigen –",
              "DG.NumberToggleView.hideAll": "Alle verbergen –",
              "DG.NumberToggleView.lastDash": "–",
              "DG.NumberToggleView.lastUnchecked": "☐",
              "DG.NumberToggleView.lastChecked": "☒",
              "DG.NumberToggleView.lastLabel": "Letzte",
              "DG.NumberToggleView.showAllTooltip": "Klicken, um alle Fälle anzuzeigen\nÜbergeordnete Etiketten anklicken, um Sichtbarkeit zu ändern",
              "DG.NumberToggleView.hideAllTooltip": "Klicken, um alle Fälle zu verbergen\nÜbergeordnete Etikellten anklicken, um Sichtbarkeit zu ändern",
              "DG.NumberToggleView.enableLastModeTooltip": "Übergeordneten Fall anzeigen",
              "DG.NumberToggleView.disableLastModeTooltip": "Übergeordneten Fall verlassen",
              "DG.NumberToggleView.indexTooltip": "Sichtbarkeit umschalten",
              "DG.PlottedAverageAdornment.meanValueTitle": "aMittel=%@",
              "DG.PlottedAverageAdornment.medianValueTitle": "Median=%@",
              "DG.PlottedAverageAdornment.stDevValueTitle": "±1 SD, %@",
              "DG.PlottedAverageAdornment.iqrValueTitle": "IQR=%@",
              "DG.PlottedAverageAdornment.boxPlotTitle": "untere=%@\nQ1=%@\nMedian=%@\nQ3=%@\nobere=%@\nIQR=%@",
              "DG.PlottedCountAdornment.title": "%@ %@, %@%",
              "DG.DataDisplayMenu.attribute_x": "X: %@",
              "DG.DataDisplayMenu.attribute_y": "Y: %@",
              "DG.DataDisplayMenu.attribute_y2": "Y: %@",
              "DG.DataDisplayMenu.attribute_legend": "Legende: %@",
              "DG.DataDisplayMenu.remove": "Merkmal entfernen",
              "DG.DataDisplayMenu.removeAttribute_x": "Entferne X: %@",
              "DG.DataDisplayMenu.removeAttribute_y": "Entferne Y: %@",
              "DG.DataDisplayMenu.removeAttribute_y2": "Entferne Y: %@",
              "DG.DataDisplayMenu.removeAttribute_legend": "Entferne Legende: %@",
              "DG.DataDisplayMenu.treatAsCategorical": "Als kategorial behandeln",
              "DG.DataDisplayMenu.treatAsNumeric": "Als numerisch behandeln",
              "DG.DataDisplayMenu.hide": "Verbergen und Zeigen",
              "DG.DataDisplayMenu.hideSelectedPlural": "Ausgewählte Fälle verbergen",
              "DG.DataDisplayMenu.hideUnselectedPlural": "Nicht ausgewählte Fälle verbergen",
              "DG.DataDisplayMenu.hideSelectedSing": "Ausgewählte Fälle verbergen",
              "DG.DataDisplayMenu.hideUnselectedSing": "Nicht ausgewählte Fälle verbergen",
              "DG.DataDisplayMenu.enableNumberToggle": "Übergeordnete Sichtbarkeit anzeigen",
              "DG.DataDisplayMenu.disableNumberToggle": "Übergeordnete Sichtbarkeit verbergen",
              "DG.DataDisplayMenu.showAll": "Alle Fälle anzeigen",
              "DG.DataDisplayMenu.snapshot": "Screenshot",
              "DG.GraphView.replaceAttribute": "Ersetze %@ durch %@",
              "DG.GraphView.addAttribute": "Merkmal %@ hinzufügen",
              "DG.GraphView.addToEmptyPlace": "Achse erstellen aus %@",
              "DG.GraphView.addToEmptyX": "X-Achse erstellen aus %@",
              "DG.GraphView.dropInPlot": "Punkte einfärben nach Werten von %@",
              "DG.GraphView.zoomTip": "Doppelklick zum Vergrößern\nUmschalt+Doppelklick zu Verkleinern",
              "DG.GraphView.rescale": "An Daten skalieren",
              "DG.AxisView.labelTooltip": "—Klicken, um %@ Achsenmerkmal zu ändern",
              "DG.AxisView.vertical": "senkrecht",
              "DG.AxisView.horizontal": "waagrecht",
              "DG.DataTip.connectingLine": "%@: %@\nmit %@ %@",
              "DG.MovableMonthYear": "%@, %@",
              "DG.MovableMonthDayHour": "%@ %@ %@:00",
              "DG.PlottedFormula.defaultNamePrompt": "Formel",
              "DG.PlottedValue.namePrompt": "Wert",
              "DG.PlottedValue.formulaPrompt": "Wert =",
              "DG.PlottedValue.formulaHint": "\u200b",
              "DG.PlottedFunction.namePrompt": "Funktion",
              "DG.PlottedFunction.formulaPrompt": "f() =",
              "DG.PlottedFunction.formulaHint": "Einen Ausdruck angeben, z. B. x*x/30 - 50",
              "DG.MapView.showGrid": "Gitter zeigen",
              "DG.MapView.hideGrid": "Gitter verbergen",
              "DG.MapView.showPoints": "Punkte zeigen",
              "DG.MapView.hidePoints": "Punkte verbergen",
              "DG.MapView.marqueeHint": "Markierungswerkzeug",
              "DG.MapView.gridControlHint": "Gittergröße ändern",
              "DG.Inspector.values": "Messung",
              "DG.Inspector.styles": "Format",
              "DG.Inspector.pointSize": "Punktgröße:",
              "DG.Inspector.transparency": "Transparenz:",
              "DG.Inspector.color": "Farbe:",
              "DG.Inspector.legendColor": "Legendenfarbe:",
              "DG.Inspector.backgroundColor": "Hintergrundfarbe:",
              "DG.Inspector.stroke": "Umrandung:",
              "DG.Inspector.rescale.toolTip": "Anzeige anpassen um alle Daten zu zeigen",
              "DG.Inspector.mixUp.toolTip": "Alle Punkte mischen",
              "DG.Inspector.hideShow.toolTip": "Alle Fälle zeigen oder ausgewählte/nicht ausgewählte Fälle verbergen",
              "DG.Inspector.delete.toolTip": "Ausgewählte oder nicht ausgewählte Fälle löschen",
              "DG.Inspector.sliderValues.toolTip": "Animation des Reglers",
              "DG.Inspector.webViewEditURL.toolTip": "URL editieren",
              "DG.Inspector.selection.selectAll": "Alle Fälle auswählen",
              "DG.Inspector.selection.deleteSelectedCases": "Ausgewählte Fälle löschen",
              "DG.Inspector.selection.deleteUnselectedCases": "Nicht ausgewählte Fälle löschen",
              "DG.Inspector.deleteAll": "Alle Fälle löschen",
              "DG.Inspector.deleteDataSet": "Datensatz löschen und zerstören",
              "DG.Inspector.displayValues.toolTip": "Ändern, was mit den Punkten angezeigt wird",
              "DG.Inspector.displayStyles.toolTip": "Erscheinungsbild der Anzeige ändern",
              "DG.Inspector.makeImage.toolTip": "Bild als png Datei speichern",
              "DG.Inspector.displayShow": "Zeigen...",
              "DG.Inspector.colorPicker.more": "mehr",
              "DG.Inspector.colorPicker.less": "weniger",
              "DG.Inspector.graphTransparency": "transparent",
              "DG.Inspector.graphCount": "Anzahl",
              "DG.Inspector.graphPercent": "Prozent",
              "DG.Inspector.graphRow": "Zeile",
              "DG.Inspector.graphColumn": "Spalte",
              "DG.Inspector.graphCell": "Zelle",
              "DG.Inspector.graphConnectingLine": "Linien verbinden",
              "DG.Inspector.graphMovableLine": "Bewegliche Linie",
              "DG.Inspector.graphInterceptLocked": "Abschnitt gesperrt",
              "DG.Inspector.graphPlottedFunction": "Funktion",
              "DG.Inspector.graphSquares": "Residuenquadrate",
              "DG.Inspector.graphLSRL": "Ausgleichsgerade",
              "DG.Inspector.graphMovableValue": "Beweglicher Wert",
              "DG.Inspector.graphAdd": "Hinzufügen",
              "DG.Inspector.graphRemove": "Entfernen",
              "DG.Inspector.graphPlottedMean": "arithmetisches Mittel",
              "DG.Inspector.graphPlottedMedian": "Median",
              "DG.Inspector.graphPlottedStDev": "Standardabweichung",
              "DG.Inspector.graphPlottedIQR": "Interquartilsabstand",
              "DG.Inspector.graphPlottedBoxPlot": "Boxplot",
              "DG.Inspector.graphPlottedValue": "Wert",
              "DG.Inspector.attributes.toolTip": "Neues Merkmal erstellen. Falldaten exportieren",
              "DG.Inspector.resize.toolTip": "Spaltengröße an Daten anpassen",
              "DG.Inspector.newAttribute": "Neues Merkmal als %@...",
              "DG.Inspector.randomizeAllAttributes": "Alle rerandomisieren",
              "DG.Inspector.exportCaseData": "Falldaten exportieren...",
              "DG.Inspector.mapGrid": "Gitter",
              "DG.Inspector.mapPoints": "Punkte",
              "DG.Inspector.mapLines": "Linien verbinden",
              "DG.GameController.continuityError": "Entschuldigung, nachdem die Spalten der Tabelle neu angeordnet wurden können keine neuen Daten akzeptiert werden.",
              "DG.GameView.loading": "Lädt",
              "DG.GameView.loadError": "Wenn dieser Text zu sehen ist, dann ist das Laden der URL möglicherweise fehlgeschlagen. Der Link kann in einem anderen Browser überprüft werden. Oder der Fehler kann hier berichtet werden: http://codap.concord.org/help.",
              "DG.Component.closeComponent.confirmCloseMessage": "Sicher?",
              "DG.Component.closeComponent.confirmCloseDescription": "\u200b",
              "DG.Component.closeComponent.okButtonTitle": "Ja, schließen",
              "DG.Component.closeComponent.cancelButtonTitle": "Abbrechen",
              "DG.GameController.confirmCloseDescription": "Wenn dies geschlossen wird, können möglicherweise keine weiteren Daten hinzugefügt werden.",
              "DG.WebView.defaultTitle": "Website",
              "DG.mainPage.exceptionMessage": "Ein Fehler ist aufgetreten. Seite neu laden (Fehler: %@)",
              "DG.fileMenu.provider.examples.displayName": "Beispieldokumente",
              "DG.ToolButtonData.pluginMenu.title": "Plugins",
              "DG.ToolButtonData.pluginMenu.toolTip": "Plugin öffnen",
              "DG.Undo.graph.showMovablePoint": "Rückgängig: Beweglichen Punkt zeigen",
              "DG.Redo.graph.showMovablePoint": "Wiederholen: Beweglichen Punkt zeigen",
              "DG.Undo.graph.hideMovablePoint": "Rückgängig: Beweglichen Punkt verbergen",
              "DG.Redo.graph.hideMovablePoint": "Wiederholen: Beweglichen Punkt verbergen",
              "DG.Undo.graph.moveMovablePoint": "Rückgängig: Beweglichen Punkt bewegen",
              "DG.Redo.graph.moveMovablePoint": "Wiederholen: Beweglichen Punkt bewegen",
              "DG.DataDisplayMenu.copyAsImage": "Im Zeichenwerkzeug öffnen",
              "DG.DataDisplayMenu.exportImage": "Bild exportieren...",
              "DG.DataDisplayMenu.imageOfTitle": "Bild %@",
              "DG.Inspector.graphMovablePoint": "Beweglicher Punkt",
              "DG.AppController.caseTableMenu.openCaseTableToolTip": "Falltabelle zu diesem Datensatz öffnen",
              "DG.AppController.caseTableMenu.newDataSetToolTip": "Neuen Datensatz erstellen",
              "DG.AppController.caseTableMenu.deleteDataSetToolTip": "Diesen Datensatz löschen und zerstören",
              "DG.Undo.graph.showAsBarChart": "Rückgängig: Punkte verschmelzen",
              "DG.Redo.graph.showAsBarChart": "Wiederholen: Punkte verschmelzen",
              "DG.Undo.graph.showAsDotChart": "Rückgängig: Säulen in Punkte verwandeln",
              "DG.Redo.graph.showAsDotChart": "Wiederholen: Säulen in Punkte verwandeln",
              "DG.CountAxisView.countLabel": "Anzahl",
              "DG.CountAxisView.countLabelDescription": "Anzahl Fälle der Säule dieser Achse",
              "DG.CountAxisView.percentLabel": "Prozent",
              "DG.CountAxisView.percentLabelDescription": "Prozent der Fälle in der Säule dieser Achse",
              "DG.BarChartModel.cellTipPlural": "%@ von %@ %@ (%@%) sind %@",
              "DG.BarChartModel.cellTipSingular": "%@ von %@ %@ (%@%) ist %@",
              "DG.Inspector.configuration": "Einstellung",
              "DG.Inspector.displayConfiguration.toolTip": "Einstellung zur Anzeige",
              "DG.Inspector.displayScale": "Skalieren...",
              "DG.Inspector.graphBarChart": "Punkte rechteckig verschmelzen",
              "DG.Locale.name.de": "Deutsch",
              "DG.Locale.name.en": "Englisch",
              "DG.Locale.name.es": "Spanisch",
              "DG.Locale.name.he": "Hebräisch",
              "DG.Locale.name.tr": "Türkisch",
              "DG.Locale.name.zh": "Chinesisch",
              "DG.Undo.graph.swapCategories": "Rückgängig: Kategorien anordnen",
              "DG.Redo.graph.swapCategories": "Wiederholen: Kategorien anordnen",
              "DG.TableController.collectionTitleText": "%@1 (%@2 Fälle)",
              "DG.TableController.collectionTitleTextWithSetAside": "%@1 (%@2 Fälle, %@3 ablegen)",
              "DG.Inspector.setaside.setAsideSelectedCases": "Ausgewählte Fälle ablegen",
              "DG.Inspector.setaside.setAsideUnselectedCases": "Nicht ausgewählte Fälle ablegen",
              "DG.Inspector.setaside.restoreSetAsideCases": "Abglegte Fälle %@ wiederherstellen",
              "DG.DocumentController.caseCardTitle": "Datenkarte",
              "DG.DocumentController.toggleToCaseCard": "Zur Datenkartenansicht wechseln",
              "DG.DocumentController.toggleToCaseTable": "Zur Tabellenansicht wechseln",
              "DG.CaseCard.indexString": "1 von %@ %@",
              "DG.CaseCard.namePlusCaseCount": "%@ %@",
              "DG.CaseCard.namePlusSelectionCount": "%@ von %@ %@ ausgewählt",
              "DG.CaseCard.summaryValues": "%@ Werte",
              "DG.CaseCard.summaryRange": "%@–%@ %@",
              "DG.CaseCard.navNextCase": "Auswählen und nächsten Fall anzeigen",
              "DG.CaseCard.navPrevCase": "Auswählen und vorherigen Fall anzeigen",
              "DG.CaseCard.navFirstCase": "Auswählen und ersten Fall anzeigen",
              "DG.CaseCard.navLastCase": "Auswählen und letzten Fall anzeigen",
              "DG.Undo.component.toggleTableToCard": "Rückgängig: Datenkartenansicht",
              "DG.Redo.component.toggleTableToCard": "Wiederholen: Datenkartenansicht",
              "DG.Undo.component.toggleCardToTable": "Rückgängig: Tabellenansicht",
              "DG.Redo.component.toggleCardToTable": "Wiederholen: Tabellenansicht",
              "DG.Undo.graph.addBackgroundImage": "Rückgängig: Hintergrundbild hinzufügen",
              "DG.Redo.graph.addBackgroundImage": "Wiederholen: Hintergrundbild hinzufügen",
              "DG.Undo.graph.removeBackgroundImage": "Rückgängig: Hintergrundbild entfernen",
              "DG.Redo.graph.removeBackgroundImage": "Wiederholen: Hintergrundbild entfernen",
              "DG.Undo.graph.lockBackgroundImage": "Rückgängig: Hintergrundbild an Achse",
              "DG.Redo.graph.lockBackgroundImage": "Wiederholen: Hintergrundbild an Achse",
              "DG.Undo.graph.unlockBackgroundImage": "Rückgängig: Hintergrundbild von Achse entfernen",
              "DG.Redo.graph.unlockBackgroundImage": "Wiederholen: Hintergrundbild von Achse entfernen",
              "DG.Undo.enableMeasuresForSelection": "Rückgängig: Messung für Auswahl anzeigen",
              "DG.Redo.enableMeasuresForSelection": "Wiederholen: Messung für Auswahl anzeigen",
              "DG.Undo.disableMeasuresForSelection": "Rückgängig: Messung für Auswahl verbergen",
              "DG.Redo.disableMeasuresForSelection": "Wiederholen: Messung für Auswahl verbergen",
              "DG.DataDisplayMenu.enableMeasuresForSelection": "Messung für Auswahl anzeigen",
              "DG.DataDisplayMenu.disableMeasuresForSelection": "Messung für Auswahl verbergen",
              "DG.DataDisplayMenu.addBackgroundImage": "Hintergrundbild hinzufügen",
              "DG.DataDisplayMenu.lockImageToAxes": "Hintergrundbild an Achsen ausrichten",
              "DG.DataDisplayMenu.unlockImageFromAxes": "Hintergrundbild von Achse entfernen",
              "DG.DataDisplayMenu.removeBackgroundImage": "Hintergrundbild entfernen",
              "DG.main.page.title": "%@1 - %@2",
              "DG.TableController.headerMenuItems.deleteFormula": "Formel löschen (Werte behalten)",
              "DG.TableController.headerMenuItems.recoverFormula": "Formel wiederherstellen",
              "DG.Inspector.displayLayers.toolTip": "Aussehen der Kartenebenen ändern",
              "DG.Inspector.layers": "Ebenen",
              "DG.Undo.graph.repositionEquation": "Rückgängig: Gleichung verschieben",
              "DG.Redo.graph.repositionEquation": "Wiederholen: Gleichung verschieben",
              "DG.TableController.attrEditor.precisionNumericHint": "Anzahl der Nachkommastellen",
              "DG.TableController.attrEditor.precisionDateHint": "Legt fest, wieviele der Datenpunkte angezeigt werden",
              "DG.TableController.attrEditor.typeHint": "Merkmalstyp festlegen",
              "DG.TableController.attrEditor.nameHint": "Der Merkmalsname erscheint in der Tabelle, case card und auf den Graph-Achsen",
              "DG.TableController.attrEditor.editableHint": "Wenn das Merkmal nicht editierbar ist, können seine Werte und/oder Formeln nicht geändert werden",
              "DG.CaseTable.attributeEditor.datePrecisionOptions": "Jahr Monat Tag Stunde Minute Sekunde Millisekunde",
              "DG.AttributeFormat.DatePrecision.year": "YYYY",
              "DG.AttributeFormat.DatePrecision.month": "MMM YYYY",
              "DG.AttributeFormat.DatePrecision.day": "D, MMM YYYY",
              "DG.AttributeFormat.DatePrecision.hour": "D, MMM YYYY HH:00",
              "DG.AttributeFormat.DatePrecision.minute": "D, MMM YYYY HH:mm",
              "DG.AttributeFormat.DatePrecision.second": "D, MMM YYYY HH:mm:ss",
              "DG.CaseCard.attrHintPlain": "%@",
              "DG.CaseCard.attrHintUnitsOnly": "%@ in %@",
              "DG.CaseCard.attrHintDescription": "%@: %@",
              "DG.CaseCard.attrHintFormula": "%@\n%@",
              "DG.AppController.optionMenuItems.help-forum": "Hilfeforum...",
              "DG.AppController.showHelpForumTitle": "Hilfeforum",
              "DG.Locale.name.el": "Griechisch",
              "DG.BarChartModel.cellTipNoLegendSingular": "%@ of %@ (%@%) ist %@",
              "DG.BarChartModel.cellTipNoLegendPlural": "%@ von %@ (%@%) sind %@",
              "DG.DataDisplayMenu.removeAttribute_top": "Entfernen: Side-by-side Layout durch %@\n",
              "DG.DataDisplayMenu.removeAttribute_right": "Entfernen: Vertikales Layout durch %@",
              "DG.GraphView.layoutPlotsSideBySide": "Side-by-side Layout durch %@",
              "DG.GraphView.layoutPlotsVertically": "Vertikales Layout durch %@",
              "DG.Undo.graph.makeStrokeSameAsFill": "Rückgängig: Umrandung und Füllung gleich",
              "DG.Redo.graph.makeStrokeSameAsFill": "Wiederholen: Umrandung und Füllung gleich",
              "DG.Undo.graph.makeStrokeIndependent": "Rückgängig: Umrandung anders als Füllung",
              "DG.Redo.graph.makeStrokeIndependent": "Wiederholen: Umrandung anders als Füllung",
              "DG.Inspector.strokeSameAsFill": "Umrandung und Füllung gleich",
              "DG.Formula.DateShortDaySunday": "Son",
              "DG.Formula.DateShortDayMonday": "Mon",
              "DG.Formula.DateShortDayTuesday": "Die",
              "DG.Formula.DateShortDayWednesday": "Mit",
              "DG.Formula.DateShortDayThursday": "Don",
              "DG.Formula.DateShortDayFriday": "Fre",
              "DG.Formula.DateShortDaySaturday": "Sam",
              "DG.AttributeFormat.DatePrecision.millisecond": "D, MMM YYYY HH:mm:ss.SSS\n",
              "DG.CellAxis.other": "ANDERE",
              "DG.PlottedAverageAdornment.madValueTitle": "±1 MAD, %@",
              "DG.Inspector.graphPlottedMeanAbsDev": "Abweichung (absolut)",
              "DG.Undo.graph.showPlottedBoxPlot": "Boxplot wieder entfernen",
              "DG.Redo.graph.hidePlottedBoxPlot": "Boxplot erneut verbergen",
              "DG.Undo.graph.hidePlottedBoxPlot": "Rückgängig: Boxplot verbergen",
              "DG.Redo.graph.showPlottedBoxPlot": "Wiederholen: Boxplot anzeigen",
              "DG.Undo.graph.showOutliers": "Rückgängig: Ausreißer anzeigen",
              "DG.Redo.graph.hideOutliers": "Wiederholen: Ausreißer verbergen",
              "DG.Undo.graph.hideOutliers": "Rückgängig: Ausreißer verbergen",
              "DG.Redo.graph.showOutliers": "Wiederholen: Ausreißer anzeigen",
              "DG.Inspector.graphBoxPlotShowOutliers": "Ausreißer anzeigen",
              "DG.Locale.name.nb": "Bokmål",
              "DG.Locale.name.nn": "Nynorsk",
              "DG.CaseCard.newCaseToolTip": "Dieser Sammlung einen leeren Fall hinzufügen",
              "DG.TableController.headerMenuItems.renameAttribute": "Umbenennen",
              "DG.Undo.graph.fuseDotsToRectangles": "Rückgängig: Punkte rechteckig verschmelzen",
              "DG.Redo.graph.fuseDotsToRectangles": "Wiederholen: Punkte rechteckig verschmelzen",
              "DG.Undo.graph.dissolveRectanglesToDots": "Rückgängig: Rechtecke auflösen in Punkte",
              "DG.Redo.graph.dissolveRectanglesToDots": "Wiederholen: Rechtecke auflösen in Punkte",
              "DG.Undo.graph.changeBreakdownType": "Rückgängig: Art der Skalierung ändern",
              "DG.Redo.graph.changeBreakdownType": "Wiederholen: Art der Skalierung ändern",
              "DG.Undo.graph.showAsBinnedPlot": "Rückgängig: Klasseneinteilung",
              "DG.Redo.graph.showAsBinnedPlot": "Wiederholen: Klasseneinteilung",
              "DG.Undo.graph.showAsDotPlot": "Rückgängig: Klasseneinteilung auflösen",
              "DG.Redo.graph.showAsDotPlot": "Wiederholen: Klasseneinteilung auflösen",
              "DG.Undo.graph.dragBinBoundary": "Rückgängig: Klassenbreite ziehen",
              "DG.Redo.graph.dragBinBoundary": "Wiederholen: Klassenbreite ziehen",
              "DG.Undo.graph.changeBinWidth": "Rückgängig: Klassenbreite ändern",
              "DG.Redo.graph.changeBinWidth": "Wiederholen: Klassenbreite ändern",
              "DG.Undo.graph.changeBinAlignment": "Rückgängig: Anpassen der Klassen",
              "DG.Redo.graph.changeBinAlignment": "Wiederholen: Anpassen der Klassen",
              "DG.BinnedPlotModel.dragBinTip": "Ziehen, um die Klassenbreite zu ändern",
              "DG.HistogramView.barTipPlural": "%@ von %@ %@ (%@%) sind ≥ %@ und < %@",
              "DG.HistogramView.barTipSingular": "%@ von %@ %@ (%@%) ist ≥ %@ und < %@",
              "DG.HistogramView.barTipNoLegendSingular": "%@ von %@ (%@%) ist ≥ %@ und < %@",
              "DG.HistogramView.barTipNoLegendPlural": "%@ von %@ (%@%) sind ≥ %@ und < %@\n",
              "DG.Inspector.graphGroupIntoBins": "In Klassen einteilen",
              "DG.Inspector.graphBinWidth": "Klassenbreite",
              "DG.Inspector.graphAlignment": "Anpassen",
              "DG.CaseTable.dividerView.expandAllTooltip": "Alle Gruppen aufklappen",
              "DG.CaseTable.dividerView.expandGroupTooltip": "Gruppe aufklappen",
              "DG.CaseTable.dividerView.collapseAllTooltip": "Alle Gruppen einklappen",
              "DG.CaseTable.dividerView.collapseGroupTooltip": "Gruppe einklappen",
              "DG.BinnedPlotModel.binLabelTip": "In dieser Klasse befinden sich Werte ≥ %@ und < %@",
              "DG.Component.closeComponent.toolTip": "Schließen",
              "DG.Component.minimizeComponent.toolTip": "Minimieren oder Maximieren",
              "DG.Locale.name.ja": "Japanisch",
              "DG.CaseCard.attrHintDescriptionAndFormula": "%@1: %@2\n%@1 = %@3",
              "DG.Locale.name.zh-Hans": "Vereinfachtes Chinesisch",
              "DG.PlottedCount.withoutSelection": "%@",
              "DG.PlottedCount.withSelection": "%@ sind ausgewählt",
              "DG.PlottedPercent.withoutSelection": "%@%",
              "DG.PlottedPercent.withSelection": "%@ sind ausgewählt",
              "DG.PlottedCountPercent.withoutSelection": "%@ (%@%)",
              "DG.PlottedCountPercent.withSelection": "%@ von %@ (%@%) sind ausgewählt",
              "DG.Undo.caseTable.resizeColumn": "Rückgängig: Breite anpassen",
              "DG.Redo.caseTable.resizeColumn": "Wiederholen: Breite anpassen",
              "DG.TableController.headerMenuItems.resizeColumn": "Breite anpassen",
              "DG.SelectedInfoView.infoPlural": "Messgrößen für %@ ausgewählte Fälle anzeigen",
              "DG.SelectedInfoView.infoSing": "Messgrößen für %@ ausgewählte Fälle anzeigen",
              "DG.Inspector.copyCaseDataToClipboard": "In die Zwischenablage kopieren...",
              "DG.Inspector.caseTable.exportCaseDialog.copyFrom": "Falldaten kopieren von:",
              "DG.Inspector.caseTable.exportCaseDialog.copy": "Kopieren",
              "DG.Inspector.caseTable.exportCaseDialog.copyTooltip": "Daten in die Zwischenablage kopieren",
              "DG.Inspector.caseTable.exportCaseDialog.copiedData": "%@ in die Zwischenablage kopiert\n",
              "DG.Undo.caseTable.hideAttribute": "Rückgängig: Merkmal verbergen",
              "DG.Redo.caseTable.hideAttribute": "Wiederholen: Merkmal verbergen",
              "DG.Undo.caseTable.showAllHiddenAttributes": "Rückgängig: Alle verborgenen Merkmale zeigen",
              "DG.Redo.caseTable.showAllHiddenAttributes": "Wiederholen: Alle verborgenenen Merkmale zeigen",
              "DG.TableController.headerMenuItems.hideAttribute": "Merkmal verbergen",
              "DG.Inspector.attributes.showAllHiddenAttributesSing": "%@ verborgene Merkmale zeigen",
              "DG.Inspector.attributes.showAllHiddenAttributesPlural": "%@ versteckte Merkmale zeigen",
              "DG.Inspector.attributes.showAllHiddenAttributesDisabled": "Versteckte Merkmale zeigen",
              "DG.Inspector.getCaseDataFromClipboard": "Daten aus der Zwischenablage importieren",
              "DG.CaseCard.addCaseButton": "Fall hinzufügen",
              "DG.Undo.DataContext.join": "Rückgängig: %@ mit %@ vereinen",
              "DG.Redo.DataContext.join": "Wiederholen: %@ mit %@ vereinen",
              "DG.Collection.joinTip": "%@ mit %@ vereinen zu %@ in %@ durch Zusammenführen von %@ mit %@",
              "DG.Inspector.graphPlotPoints": "Punkte",
              "DG.Inspector.graphBarForEachPoint": "Wertebalken",
              "DG.Undo.graph.changeBarChartFunction": "Rückgängig: Formel ändern",
              "DG.Redo.graph.changeBarChartFunction": "Wiederholen: Formel ändern",
              "DG.Undo.graph.showAsLinePlot": "Rückgängig: Wertebalken",
              "DG.Redo.graph.showAsLinePlot": "Wiederholen: Wertebalken",
              "DG.Undo.graph.showAsStandardBarChart": "Rückgängig: Anzahl oder Prozent nutzen",
              "DG.Redo.graph.showAsStandardBarChart": "Wiederholen: Anzahl oder Prozent nutzen",
              "DG.Undo.graph.showAsComputedBarChart": "Rückgängig: Balkenlänge berechnen",
              "DG.Redo.graph.showAsComputedBarChart": "Wiederholen: Balkenlänge berechnen",
              "DG.FormulaAxisView.labelDescription": "Dieser Ausdruck bestimmt die Länge der Balken. Zum Editieren anklicken",
              "DG.ComputedBarChartModel.cellTip": "Für die Gruppe %@ ist der Wert %@",
              "DG.BarChartFunction.namePrompt": "Balkendiagramm",
              "DG.BarChartFunction.formulaPrompt": "Balkenlänge =",
              "DG.BarChartFunction.formulaHint": "Formel eingeben um eine Balkenlänge zu berechnen",
              "DG.BarChartFunction.emptyExpressionAxisPrompt": "Hier klicken um eine Formel zu erstellen",
              "DG.Inspector.graphFormula": "Formel",
              "DG.Undo.displayOnlySelected": "Rückgängig: Nur ausgewählte Fälle anzeigen",
              "DG.Redo.displayOnlySelected": "Wiederholen: Nur ausgewählte Fälle anzeigen",
              "DG.Undo.webView.show": "Rückgängig: Webseite hinzufügen",
              "DG.Redo.webView.show": "Wiederholen: Webseite hinzufügen",
              "DG.Undo.imageComponent.show": "Rückgängig: Bildkomponente hinzufügen",
              "DG.Redo.imageComponent.show": "Wiederholen: Bildkomponente hinzufügen",
              "DG.DataDisplayMenu.displayOnlySelected": "Nur ausgewählte Fälle anzeigen",
              "DG.DataDisplayMenu.displayingOnlySelected": "Nur ausgewählte Fälle werden angezeigt",
              "DG.PlotBackgroundView.msg0": "Dieser Graph wird angezeigt",
              "DG.PlotBackgroundView.msg1": "nur ausgewählte Fälle",
              "DG.PlotBackgroundView.msg2": "Es sind keine Fälle ausgewählt",
              "DG.PlotBackgroundView.msg3": "Es wird nichts angezeigt.",
              "DG.PlotBackgroundView.msg4": "Fälle können ausgewählt werden entweder in",
              "DG.PlotBackgroundView.msg5": "einer Tabelle oder in einem anderen Graphen",
              "DG.ImageComponent.defaultTitle": "Bild",
              "DG.TableController.datasetMetadata.title": "Informationen zum Datensatz",
              "DG.CaseTable.datasetMetadata.url": "Quelle",
              "DG.CaseTable.datasetMetadata.creationDate": "Datum importieren",
              "DG.TableController.datasetMetadata.descriptionHint": "Den Datensatz beschreiben",
              "DG.Inspector.datasetInfo.toolTip": "Informationen zum Datensatz anzeigen",
              "DG.CaseTable.indexMenu.moveEntryRow": "Spalte hierher bewegen",
              "DG.CaseCard.deselect": "Alle Fälle abwählen",
              "DG.CaseCard.noDeselect": "Es sind keine Fälle ausgewählt",
              "DG.CaseTable.indexProto.tooltip": "Ziehen, um die Dateneingabezeile in dieser Tabelle zu platzieren",
              "DG.AttributeFormat.DatePrecisionShort.year": "YYYY",
              "DG.AttributeFormat.DatePrecisionShort.month": "M/YY",
              "DG.AttributeFormat.DatePrecisionShort.day": "D/M/YY",
              "DG.AttributeFormat.DatePrecisionShort.hour": "D/M/YY HH:00",
              "DG.AttributeFormat.DatePrecisionShort.minute": "D/M/YY HH:mm",
              "DG.AttributeFormat.DatePrecisionShort.second": "D/M/YY HH:mm:ss",
              "DG.AttributeFormat.DatePrecisionShort.millisecond": "D/M/YY HH:mm:ss:SSS",
              "DG.Formula.FuncCategoryLogic": "Logik Funktionen",
              "DG.Undo.graph.showMeasureLabels": "Rückgängig: Werte anzeigen",
              "DG.Redo.graph.showMeasureLabels": "Wiederholen: Werte anzeigen",
              "DG.Undo.graph.hideMeasureLabels": "Rückgängig: Werte ausblenden",
              "DG.Redo.graph.hideMeasureLabels": "Wiederholen: Werte ausblenden",
              "DG.Inspector.showLabels": "Werte anzeigen",
              "DG.Undo.caseTable.resizeOneColumn": "Rückgängig: Spaltengröße ändern",
              "DG.Redo.caseTable.resizeOneColumn": "Wiederholen: Spaltengröße ändern",
              "DG.CaseTable.attribute.type.checkbox": "Kontrollkästchen",
              "DG.AppController.caseTableMenu.clipboardDataset": "-- Neu aus der Zwischenablage --",
              "DG.AppController.caseTableMenu.clipboardDatasetToolTip": "Datensatz aus der Zwischenablage einfügen",
              "DG.AppController.optionMenuItems.toPrivacyPage": "Zum Datenschutz...",
              "DG.plugin.Importer.title": "CSV importieren",
              "DG.plugin.Importer.enter-url": "URL eingeben: ",
              "DG.plugin.Importer.or": "oder",
              "DG.plugin.Importer.downsample-section": "Einstellungen zu Stichprobe verkleinern",
              "DG.plugin.Importer.downsample-random-p1": "Zufällig auswählen",
              "DG.plugin.Importer.downsample-random-p2": "Zeilen",
              "DG.plugin.Importer.downsample-every-nth-p1": "Jede auswählen",
              "DG.plugin.Importer.downsample-every-nth-p2": "te Zeile",
              "DG.plugin.Importer.downsample-import-all": "Alle Zeilen importieren",
              "DG.plugin.Importer.target-options-title": "Zieleinstellungen",
              "DG.plugin.Importer.target-options-replace": "Den vorhandenen Datensatz mit diesem ersetzen",
              "DG.plugin.Importer.target-options-append": "Diesen Datensatz zu dem vorhandenen hinzufügen",
              "DG.plugin.Importer.target-options-create-new": "Einen neuen Datensatz erstellen",
              "DG.plugin.Importer.button-cancel": "Abbrechen",
              "DG.plugin.Importer.button-submit": "Ok",
              "DG.plugin.Importer.button-dismiss": "Verwerfen",
              "DG.plugin.Importer.load-error": "Fehler beim Laden: \"%@\" Grund: \"%@\"",
              "DG.plugin.Importer.no-table-error": "Es konnten keine tabellarischen Daten gefunden werden, die in CODAP importiert weren können",
              "DG.plugin.Importer.duplicate-dataset-msg": "Es existiert bereits ein Datensatz wie dieser. Er heißt \"%@\".",
              "DG.plugin.Importer.upload-time-msg": "%@ wurde hochgeladen",
              "DG.plugin.Importer.large-file-msg": "Die importierte Datei \"%@\" hat %@ Zeilen. Bei mehr als %@ Zeilen wird CODAP stark verlangsamt. Eine Stichprobe des Datensatzes kann besser funktionieren, später kann der gesamte Datensatz genutzt werden.",
              "DG.plugin.Importer.error-codap-connection": "Fehler beim Senden der Daten an CODAP",
              "DG.plugin.Importer.error-upload": "Die Datei %@ konnte nicht importiert werden",
              "DG.plugin.Importer.import-message": "Den Import von %@ Zeilen nach \"%@\" von einer Tabelle mit %@ Merkmalen vorbereiten: %@%@\n",
              "DG.Undo.component.componentTitleChange": "Rückgängig: Überschrift der Komponente ändern",
              "DG.Redo.component.componentTitleChange": "Wiederholen: Überschrift der Komponente ändern",
              "DG.TableController.collectionTitleText-nonempty": "%@1 (%@2 nonempty cases)",
              "DG.TableController.collectionTitleTextWithSetAside-nonempty": "%@1 (%@2 nonempty cases, %@3 set aside)",
              "DG.CaseTable.closedGroup.summary": "%@1 %@2",
              "DG.CaseTable.closedGroup.summary-nonempty": "%@1 nonempty %@2",
              "DG.DataDisplayMenu.exportPngImage": "Export PNG Image...",
              "DG.DataDisplayMenu.exportSvgImage": "Export SVG Image...",
              "DG.plugin.StoryBuilder.pluginName": "Story Builder",
              "DG.plugin.StoryBuilder.description": "Create a narrative of your investigation.",
              "DG.plugin.StoryBuilder.controlArea.discardAlt": "Discard changes",
              "DG.plugin.StoryBuilder.controlArea.discardTooltip": "Discard changes to this moment",
              "DG.plugin.StoryBuilder.controlArea.saveAlt": "Save",
              "DG.plugin.StoryBuilder.controlArea.saveTooltip": "Save this moment",
              "DG.plugin.StoryBuilder.controlArea.newAlt": "Make a new moment",
              "DG.plugin.StoryBuilder.controlArea.newTooltip": "Add a new moment to the right",
              "DG.plugin.StoryBuilder.dialog.optOutCheckbox": "Don't ask me again (always save)",
              "DG.plugin.StoryBuilder.emptyMoment.createAlt": "make new moment",
              "DG.plugin.StoryBuilder.emptyMoment.createTitle": "Click to make a new moment",
              "DG.plugin.StoryBuilder.buttons.helpAlt": "get help",
              "DG.plugin.StoryBuilder.buttons.helpTitle": "Get some help about how to use Story Builder",
              "DG.plugin.StoryBuilder.buttons.autoSaveTitleAuto": "Currently will automatically save changes to moments. Click to be asked whether to save or discard.",
              "DG.plugin.StoryBuilder.buttons.autoSaveTitleManual": "Currently will ask to save or discard changes to moments. Click to automatically save changes without asking.",
              "DG.plugin.StoryBuilder.momentComponent.deleteAlt": "Delete this moment",
              "DG.plugin.StoryBuilder.momentComponent.deleteTitle": "Delete this moment",
              "DG.plugin.StoryBuilder.momentTextboxContent": "What did you do? Why did you do it?",
              "DG.plugin.StoryBuilder.momentTextboxFirstContent": "This is the beginning of your data story.",
              "DG.plugin.StoryBuilder.momentManager.firstTitle": "start ...",
              "DG.plugin.StoryBuilder.momentManager.nextTitle": "moment title",
              "DG.plugin.StoryBuilder.storyArea.dialog.cancel": "Cancel",
              "DG.plugin.StoryBuilder.storyArea.dialog.discard": "Discard",
              "DG.plugin.StoryBuilder.storyArea.dialog.save": "Save",
              "DG.plugin.StoryBuilder.storyArea.qClickAnotherMomentPrompt": "Save or discard changes?",
              "DG.plugin.StoryBuilder.storyArea.qClickAnotherMomentExplanation": "You have made changes to Moment %@. Would you like to save or discard these changes?",
              "DG.plugin.StoryBuilder.storyArea.qDupNotLastMomentPrompt": "Save changes before creating Moment %@?",
              "DG.plugin.StoryBuilder.storyArea.qDupNotLastMomentExplanation": "You have made changes to Moment %@. Would you like to save those changes to both Moments %@ and %@ or only to the new Moment %@?",
              "DG.plugin.StoryBuilder.storyArea.qDupNotLastMomentTwoMoments": "Moments %@ and %@",
              "DG.plugin.StoryBuilder.storyArea.qDupNotLastMomentOneMoment": "Only Moment %@",
              "DG.plugin.StoryBuilder.storyArea.qRevertPrompt": "Discard changes?",
              "DG.plugin.StoryBuilder.storyArea.qRevertExplanation": "Would you like to discard the changes you made to Moment %@ (and revert to the state it was in before you made changes)?",
              "DG.plugin.StoryBuilder.storyArea.qClickLockPrompt": "Save or discard changes?",
              "DG.plugin.StoryBuilder.storyArea.qClickLockExplanation": "You have made changes to Moment %@. Would you like to save or discard these changes?",
              "DG.plugin.Scrambler.name": "Mischmaschine",
              "DG.plugin.Scrambler.description": "Test hypotheses by randomly varying an attribute.",
              "DG.plugin.Scrambler.language": "Deutsch",
              "DG.plugin.Scrambler.static.scramblerTitle": "Mischmaschine",
              "DG.plugin.Scrambler.static.cantScrambleStripe": "Dies ändern, um weiter zu machen.",
              "DG.plugin.Scrambler.static.howManyLabel": "Wie häufig?",
              "DG.plugin.Scrambler.static.scrambledDataButtonName": "Mischungen anzeigen",
              "DG.plugin.Scrambler.sScramble": "Mischen",
              "DG.plugin.Scrambler.sNoAttribute": "ein Merkmal fehlt 😕",
              "DG.plugin.Scrambler.sIterationAttName": "Durchgang",
              "DG.plugin.Scrambler.sIterationAttDescription": "Anzahl der \"Durchgänge.\" Erhöht sich jedes Mal, wenn gemischt wird.",
              "DG.plugin.Scrambler.sScrambledAttName": "Gemischtes Merkmal",
              "DG.plugin.Scrambler.sScrambledAttDescription": "Merkmal, welches gemischt wurde.",
              "DG.plugin.Scrambler.sNoDataset": "Wählen Sie einen Datensatz und ziehen Sie das Merkmal hierher, welches gemischt werden soll!",
              "DG.plugin.Scrambler.sNoScrambleAttribute": "Welches Merkmal soll gemischt werden? Hierher ziehen!",
              "DG.plugin.Scrambler.shShowScrambledButtonHelpText": "einen vermischten Datensatz anzeigen",
              "DG.plugin.Scrambler.sfScrambledAttribute": "<span><code>%@1</code> mischen</span>",
              "DG.plugin.Scrambler.sfOKtoScramble": "<span><code>%@1</code> im Datensatz <code>%@2</code> kann gemischt werden</span>",
              "DG.plugin.Scrambler.sfNoMeasure": "<span>Zuerst muss im Datensatz <code>%@1</code> etwas geändert werden. Wahrscheinlich benötigen Sie zuerst ein Merkmal mit einer Formel. Ziehen Sie ein Merkmal nach links, um etwas zum Sammeln zu haben.</span>",
              "DG.plugin.Scrambler.sfFormulaProblem": "<span>Das Mischen von <code>%@1</code> wird nicht funktionieren, weil es eine Formel beinhaltet. Ziehen Sie ein anderes Merkmal aus der unteren Tabellenebene (<code>%@2</code>) hier hinein, z.B. <code>%@3</code>.</span>",
              "DG.plugin.Scrambler.sfNotALeafProblem": "<span>Das Mischen von <code>%@1</code> wird nicht funktionieren, weil es sich nicht in der unteren Tabellenebene (<code>%@2</code>) befindet. Ziehen Sie ein Merkmal aus <code>%@2</code> hierher, wie <code>%@3</code>.</span> ",
              "DG.plugin.Scrambler.sOr": "oder",
              "DG.plugin.Scrambler.sScrambledDatasetPrefix": "scrambled_",
              "DG.plugin.Scrambler.sMeasureDatasetPrefix": "measures_from_",
              "DG.plugin.Sampler.title": "Sampler",
              "DG.plugin.Sampler.description": "Create random datasets from scratch or existing datasets.",
              "DG.plugin.Sampler.tab.sampler": "Sampler",
              "DG.plugin.Sampler.tab.options": "Options",
              "DG.plugin.Sampler.tab.about": "About",
              "DG.plugin.Sampler.top-bar.run": "START",
              "DG.plugin.Sampler.top-bar.stop": "STOP",
              "DG.plugin.Sampler.top-bar.pause": "PAUSE",
              "DG.plugin.Sampler.top-bar.medium-speed": "Medium",
              "DG.plugin.Sampler.draw-settings.select-items-p1": "Select",
              "DG.plugin.Sampler.draw-settings.select-items-p2": "items",
              "DG.plugin.Sampler.draw-settings.collect-samples-p1": "Collect",
              "DG.plugin.Sampler.draw-settings.collect-samples-p2": "samples",
              "DG.plugin.Sampler.model-controls.add-variable-title": "Add the next item to the mixer",
              "DG.plugin.Sampler.model-controls.remove-variable-title": "Remove the last item from the mixer",
              "DG.plugin.Sampler.model-controls.add-series-title": "Specify a series of labels for items",
              "DG.plugin.Sampler.model-controls.select-collection-loading": "Loading collections...",
              "DG.plugin.Sampler.reset-title": "Delete all data and extra item-level attributes",
              "DG.plugin.Sampler.reset-text": "CLEAR DATA",
              "DG.plugin.Sampler.device-selection.mixer": "Mixer",
              "DG.plugin.Sampler.device-selection.spinner": "Spinner",
              "DG.plugin.Sampler.device-selection.collector": "Collector",
              "DG.plugin.Sampler.spinner-cover-alt": "transparent cover",
              "DG.plugin.sampler.speed.slow": "Slow",
              "DG.plugin.sampler.speed.medium": "Medium",
              "DG.plugin.sampler.speed.fast": "Fast",
              "DG.plugin.sampler.speed.Fastest": "Fastest",
              "DG.plugin.sampler.collector.noDatasets": "No data sets",
              "DG.plugin.Sampler.selection-options.select-cases": "Select cases",
              "DG.plugin.Sampler.selection-options.with-replacement": "with replacement",
              "DG.plugin.Sampler.selection-options.without-replacement": "without replacement",
              "DG.plugin.Sampler.hide-options.hide": "Hide model",
              "DG.plugin.Sampler.password-options.lock-title": "Lock settings with password:",
              "DG.plugin.Sampler.password-options.lock": "Lock",
              "DG.plugin.Sampler.password-options.unlock-title": "Unlock settings with password:",
              "DG.plugin.Sampler.password-options.unlock": "Unlock",
              "DG.plugin.Sampler.password-options.password-failed": "Password is incorrect.",
              "DG.plugin.Sampler.options.reload": "Reload default settings",
              "DG.plugin.Sampler.about.paragraph1": "The CODAP Sampler plugin can randomly choose items placed in a mixer, choose items based on sector sizes of a spinner, or choose cases from a collection of data.",
              "DG.plugin.Sampler.about.item1": "<b>Select &lt;n&gt; items</b> determines the sample size,",
              "DG.plugin.Sampler.about.item2": "<b>Collect &lt;n&gt; samples</b> controls how many samples to repeat in a given experiment.",
              "DG.plugin.Sampler.about.paragraph2.1": "The speed of sampling can be controlled, as well as whether to sample with or without replacement (in Options tab). The data generated from the Sampler will appear in a hierarchical table. The top level represents the experiment (one complete run of a simulation) and allows you to compute statistics about an entire experiment. The next level contains information about each sample and allows one to compute statistics about each sample. The items level shows each individual value drawn from the Sampler. This ",
              "DG.plugin.Sampler.about.paragraph2.2": " explains Sampler basics.",
              "DG.plugin.Sampler.about.tutorial-link-text": "video tutorial",
              "DG.plugin.Sampler.about.paragraph3.1": "The Sampler in CODAP was inspired by the Sampler in",
              "DG.plugin.Sampler.about.paragraph3.2": ". It was developed by ",
              "DG.plugin.Sampler.about.paragraph3.3": " a part of the ",
              "DG.plugin.Sampler.about.paragraph3.4": "with support by the National Science Foundation under Grant No. DUE <span style=\"color:red;\">1625713</span> awarded to North Carolina State University.",
              "DG.plugin.Sampler.about.paragraph3.6": " Any opinions, findings, and conclusions or recommendations in this material are those of the principal investigators and do not necessarily reflect the views of the National Science Foundation.",
              "DG.plugin.Sampler.about.tinkerPlots-link-text": "TinkerPlots",
              "DG.plugin.Sampler.about.concord-link-text": "Concord Consortium",
              "DG.plugin.Sampler.about.esteem-link-text": "ESTEEM project",
              "DG.plugin.Sampler.about.esteem-logo-text": "Esteem logo",
              "DG.plugin.Sampler.sample-list.parse-error": "Sorry. Unable to parse that. Here are some valid list and range expressions: 'a,b,b,b', 'cat,cat,dog', '1-50', '-5 to 5', '1.0 to 5.0', or 'A-Z'",
              "DG.plugin.Sampler.sample-list.prompt": "Enter a list (e.g. 'cat, cat, dog') or a range (e.g. '1-50', '-5 %@1 5', '1.0 %@1 5.0', 'A-Z')",
              "DG.plugin.Sampler.sample-list.initial-value": "a %@1 c",
              "DG.plugin.Sampler.range-word": "to",
              "DG.plugin.Sampler.dataset.name": "Sampler",
              "DG.plugin.Sampler.dataset.experiment-collection-name": "experiments",
              "DG.plugin.Sampler.dataset.sample-collection-name": "samples",
              "DG.plugin.Sampler.dataset.item-collection-name": "items",
              "DG.plugin.Sampler.dataset.attr-experiment": "experiment",
              "DG.plugin.Sampler.dataset.attr-description": "description",
              "DG.plugin.Sampler.dataset.attr-sample_size": "sample_size",
              "DG.plugin.Sampler.dataset.attr-sample": "sample",
              "DG.plugin.Sampler.dataset.attr-value": "value",
              "DG.plugin.Sampler.dataset.col-experiments": "experiments",
              "DG.plugin.Sampler.dataset.col-samples": "samples",
              "DG.plugin.Sampler.dataset.col-items": "items",
              "DG.plugin.sampler.experiment.description": "%@1 containing %@2 %@3%@4(%@5)",
              "DG.plugin.sampler.experiment.no-description": "hidden!",
              "DG.plugin.sampler.experiment.description-mixer-item-kind": "items",
              "DG.plugin.sampler.experiment.description-spinner-item-kind": "sections",
              "DG.plugin.sampler.experiment.description-collector-item-kind": "cases",
              "DG.plugin.sampler.experiment.description-collector-phrase": " from %@1 ",
              "DG.plugin.sampler.experiment.description-replacement-phrase": "with replacement",
              "DG.plugin.sampler.experiment.description-no-replacement-phrase": "without replacement",
              "DG.plugin.DrawTool.title": "Draw Tool",
              "DG.plugin.DrawTool.description": "Annotate an image.",
              "DG.plugin.MicrodataPortal.title": "Microdata Portal",
              "DG.plugin.MicrodataPortal.description": "Investigate populations from the US census at the individual level.",
              "DG.plugin.NOAA-weather.title": "NOAA Weather",
              "DG.plugin.NOAA-weather.description": "Investigate historical weather patterns.",
              "DG.plugin.Choosy.title": "Choosy",
              "DG.plugin.Choosy.description": "Organize and simplify datasets with many attributes.",
              "DG.plugin.Transformers.title": "Transformers",
              "DG.plugin.Transformers.description": "Transform datasets with a collection of powerful tools.",
              "DG.Locale.name.ko": "Korean",
              "DG.Locale.name.pl": "Polski",
              "DG.Undo.graph.showICI": "Undo showing informal confidence interval",
              "DG.Redo.graph.hideICI": "Redo hiding informal confidence interval",
              "DG.Undo.graph.hideICI": "Undo hiding informal confidence interval",
              "DG.Redo.graph.showICI": "Redo showing informal confidence interval",
              "DG.Undo.graph.showPlottedStErr": "Undo showing standard error",
              "DG.Redo.graph.showPlottedStErr": "Redo showing standard error",
              "DG.Undo.graph.hidePlottedStErr": "Undo hiding standard error",
              "DG.Redo.graph.hidePlottedStErr": "Redo hiding standard error",
              "DG.Undo.graph.setNumStErrs": "Undo setting the number of standard errors",
              "DG.Redo.graph.setNumStErrs": "Redo setting the number of standard errors",
              "DG.Undo.graph.showPlottedNormal": "Undo showing normal curve",
              "DG.Redo.graph.hidePlottedNormal": "Redo hiding normal curve",
              "DG.Undo.graph.hidePlottedNormal": "Undo hiding normal curve",
              "DG.Redo.graph.showPlottedNormal": "Redo showing normal curve",
              "DG.ScatterPlotModel.LSRLCIBandInfo": "Shaded regions shows the range\n in which the true regression line\n lies at 95% confidence level.",
              "DG.PlottedAverageAdornment.stErrValueTitle": "%@ SE%@mean%@=%@",
              "DG.Inspector.graphLSRLSlopeCI": "Show Fit Uncertainty",
              "DG.Inspector.graphSpreadOptions": "Measures of Spread",
              "DG.Inspector.graphPlottedStErr": "Standard Error",
              "DG.Inspector.graphPlottedNormal": "Normal Curve",
              "DG.Inspector.graphPlottedGaussianFit": "Gaussian Fit",
              "DG.Undo.legend.lockQuantiles": "Undo locking legend color bins",
              "DG.Redo.legend.lockQuantiles": "Redo locking legend color bins",
              "DG.Undo.legend.unlockQuantiles": "Undo unlocking legend color bins",
              "DG.Redo.legend.unlockQuantiles": "Redo unlocking legend color bins",
              "DG.Inspector.lockLegendQuantiles": "Lock legend color bins",
              "DG.Inspector.lockLegendQuantilesTooltip": "When checked, the color bins will not change when the values change.",
              "DG.Inspector.graphBoxPlotShowICI": "Show Informal CI",
              "DG.plugin.Sampler.tab.devices": "Model",
              "DG.plugin.Sampler.tab.measures": "Measures",
              "DG.Inspector.graphCenterOptions": "Measures of Center",
              "DG.Inspector.graphBoxPlotNormalCurveOptions": "Box Plot and Normal Curve",
              "DG.Inspector.graphBoxPlotGaussianFitOptions": "Box Plot and Gaussian Fit",
              "DG.Inspector.graphOtherValuesOptions": "Plotted and Movable Values",
              "DG.plugin.Sampler.measures.instructions": "Compute common measures for each sample using the template below.",
              "DG.plugin.Sampler.measures.select-measure": "Select a measure: ",
              "DG.plugin.Sampler.measures.add-measure": "Add Measure",
              "DG.plugin.Sampler.measures.mean": "Mean",
              "DG.plugin.Sampler.measures.mean-formula": "mean",
              "DG.plugin.Sampler.measures.conditional_mean": "Conditional mean",
              "DG.plugin.Sampler.measures.conditional_mean-formula": "mean",
              "DG.plugin.Sampler.measures.difference_of_means": "Difference of means",
              "DG.plugin.Sampler.measures.difference_of_means-formula-pt-1": "mean",
              "DG.plugin.Sampler.measures.difference_of_means-formula-pt-2": "– mean",
              "DG.plugin.Sampler.measures.sum": "Sum",
              "DG.plugin.Sampler.measures.sum-formula": "sum",
              "DG.plugin.Sampler.measures.median": "Median",
              "DG.plugin.Sampler.measures.median-formula": "median",
              "DG.plugin.Sampler.measures.conditional_median": "Conditional median",
              "DG.plugin.Sampler.measures.conditional_median-formula": "median",
              "DG.plugin.Sampler.measures.difference_of_medians": "Difference of medians",
              "DG.plugin.Sampler.measures.difference_of_medians-formula-pt-1": "median",
              "DG.plugin.Sampler.measures.difference_of_medians-formula-pt-2": " - median",
              "DG.plugin.Sampler.measures.conditional_sum": "Conditional sum",
              "DG.plugin.Sampler.measures.conditional_sum-formula": "sum",
              "DG.plugin.Sampler.measures.select-formula": "Select a formula: ",
              "DG.plugin.Sampler.measures.count": "Count",
              "DG.plugin.Sampler.measures.count-formula": "count",
              "DG.plugin.Sampler.measures.percent": "Percent",
              "DG.plugin.Sampler.measures.percent-formula-pt-1": "100 * count",
              "DG.plugin.Sampler.measures.percent-formula-pt-2": " / count( )",
              "DG.plugin.Sampler.measures.name-label": "Name the measure: "
});
/* >>>>>>>>>> BEGIN source/core.js */
// ==========================================================================
//                                DG
//
//  DG is the namespace for all of the CODAP(formerly Data Games) JavaScript code.
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
/*global DG:true */ // eslint-disable-line no-redeclare

/*  According to Erich Ocean, apps should always ignore unknown properties on records.
 Here's the meaning of this from the code:

 Whether to ignore unknown properties when they are being set on the record
 object. This is useful if you want to strictly enforce the model schema
 and not allow dynamically expanding it by setting new unknown properties
 */
SC.Record.ignoreUnknownProperties = true;

/*  The QUERY_MATCHING_THRESHOLD is used to by SC.RecordArray.flush() to break up
 large updates into smaller packets of work. Unfortunately, when this occurs
 our notifications do not go out as expected and we end up only processing
 some of the data. This was seen as not all of the cases showing up when
 opening up a large document on the iPad, for instance. As a short-term
 quick-fix, we simply up the threshold from 100msec to 10sec. Eventually,
 a proper fix should be found which allows us to detect when this has
 occurred and to process the cases as they become available. Here's the
 description of the QUERY_MATCHING_THRESHOLD in the SproutCore code:

 Number of milliseconds to allow a query matching to run for. If this number
 is exceeded, the query matching will be paced so as to not lock up the
 browser (by essentially splitting the work with a setTimeout)
 */
SC.RecordArray.QUERY_MATCHING_THRESHOLD = 10000;

/** @namespace

 A web app prototype for the DataGames project.

 @extends SC.Object
 */
DG = SC.Application.create((function () // closure
/** @scope DG.prototype */ {

  var theStore = null;

  // Utility function for extracting URL parameters
  var getUrlParameter = function (iParam, iDefault) {
    iParam = iParam.replace(/[\[]/, "\\[").replace(/[\]]/, "\\]");
    iDefault = iDefault || '';
    var regexS = "[\\?&]" + iParam + "(&|$|=([^&]*))";
    var regex = new RegExp(regexS);
    var results = regex.exec(window.location.search);
    var encoded;
    if (SC.none(results)) {
      return iDefault;
    } else if (!results[2]) {
      // follow query-string convention of returning null for url parameters without values
      // cf. https://github.com/sindresorhus/query-string#falsy-values
      return null;
    } else {
      encoded = results[2].replace(/[+]/g, '%20');
      return decodeURIComponent(encoded);
    }
  };

  var isDGBuild = function () {
    var appParam = getUrlParameter('app');
    return !SC.empty(appParam) ? appParam === 'dg'
      : window.location.href.indexOf('/dg') >= 0;
  };

  var isInquirySpaceBuild = function () {
    var appParam = getUrlParameter('app');
    return !SC.empty(appParam) ? appParam === 'is'
      : window.location.href.indexOf('/is') >= 0;
  };

  var isSrriBuild = function () {
    var appParam = getUrlParameter('app');
    return !SC.empty(appParam) ? appParam === 'srri'
      : window.location.href.indexOf('srri') >= 0;
  };

  var isDevBuild = function () {
    return (window.location.href.indexOf('-dev.codap.concord.org') >= 0) ||
      (window.location.href.indexOf('localhost:4020') >= 0);
  };

  var noDataTipPref = function () {
    var noDtParam = getUrlParameter('no_dt');
    return !SC.empty(noDtParam) && noDtParam === 'true';
  };

  var useStandaloneMode = function () {
    var standaloneParam = getUrlParameter('standalone');
    return !SC.empty(standaloneParam) && standaloneParam !== 'false';
  };

  var keepInBoundsPref = function () {
    var keepInBoundsParam = getUrlParameter('inbounds');
    return !SC.empty(keepInBoundsParam) && keepInBoundsParam === 'true';
  };

  return Object.assign({ // return from closure

    NAMESPACE: 'DG',
    APPNAME: 'DG',
    USER_APPNAME: 'CODAP',

    /*
     * Semantic version number
     */
    VERSION: '2.0',
    CODAP_SERVER: SC.buildMode==='debug'?'/extn':'../../../../extn',

    /*
     * Build number
     */
    BUILD_NUM: '0713',

    IS_DG_BUILD: isDGBuild.property(),

    IS_INQUIRY_SPACE_BUILD: isInquirySpaceBuild.property(),

    IS_SRRI_BUILD: isSrriBuild.property(),

    exampleListBaseURL: function () {

      return getUrlParameter('exampleURL') || this.get('CODAP_SERVER') + '/example-documents';
    }.property(),

    exampleListURL: function () {
      return '%@1/index.json.%@2'.loc(this.get('exampleListBaseURL'), SC.Locale.currentLanguage);
    }.property(),

    showHelpURL: 'https://codap.concord.org/help',
    showHelpURL_ja: 'https://codap.concord.org/resources/latest/help-documents/CODAP解説書.pdf',

    showHelpForumURL: 'https://codap.concord.org/forums/forum/test/',

    showWebSiteURL: 'https://codap.concord.org',
    showPrivacyURL: 'https://codap.concord.org/privacy',

    splashURL: '../../../../static/dg/de/cert/source/resources/images/codap-splash-screen.png',

    /* This is the developer client id. Provides access to an unverified
     * version of the app. Should be overridden for end users */
    googleDriveClientID: '891260722961-81f8ic8tddobbh66p1j7nenr42hb93u1.apps.googleusercontent.com',
    googleDriveAPIKey: 'AIzaSyDici8Bs9pd6-dSxheNPTpnJlcR4YuGGQQ',
    googleDriveAppId: '891260722961',

    /**
     * URL for a plugin data store.
     */
    pluginURL: function () {
      return getUrlParameter('pluginURL') ||
          this.get('CODAP_SERVER') + '/plugins';
    }.property(),

    /**
     * URL for metadata describing the contents of the plugin data store.
     * This is a JSON document consisting of an array of plugin descriptions
     * like the following:
     *      * [
     *  {
     *    "title": "Sampler",
     *    "description": "Has a mixer, a spinner, and a collector for sampling simulation. Modeled on TinkerPlots Sampler and created for the <a target=\"_blank\" href=\"http://hirise.fi.ncsu.edu/projects/esteem/\">ESTEEM</a> project at NCSU.",
     *    "width": 450,
     *    "height": 200,
     *    "path": "/TP-Sampler/index.html",
     *    "visible": true,
     *    "categories": [
     *      "Partners",
     *      "Utilities"
     *    ]
     *  }
     * ]
     */
    pluginMetadataURL: function () {
      return this.get('pluginURL') + '/published-plugins.json';
    }.property(),

    /**
     * plugin metadata: information about published plugins.
    */
    pluginMetadata: null,

    drawToolPluginURL: function() {
      return this.get('pluginURL') + '/DrawTool/index.html';
    }.property(),

    /*
     * Logging is enabled when origin server within this domain.
     */
    logFromServer: 'concord.org',

    defaultLogServerLoginURLSecure: 'https://logger.concord.org/logs',

    getQueryParam: function(iParam, iDefault) {
      return getUrlParameter(iParam, iDefault);
    },

    removeQueryParams: function(iParams) {
      var queryParams = window.location.search,
          paramsToRemove = Array.isArray(iParams) ? iParams : [iParams];
      paramsToRemove.forEach(function(iParam) {
        iParam = iParam.replace(/[\[]/, "\\[").replace(/[\]]/, "\\]");
        // match the leading delimiter along with the query parameter
        var regexS = "[\\?&]" + iParam + "=([^&]*)",
            regex = new RegExp(regexS),
            result = regex.exec(queryParams),
            match = result && result[0],
            matchIndex = result && result.index,
            matchLength = match && match.length,
            isFirstParam = matchIndex === 0,
            isLastParam = matchIndex + matchLength >= queryParams.length;

        // leave the initial question mark if there are more parameters
        if (isFirstParam && !isLastParam)
          match = match.substr(1) + '&';
        if (match)
          queryParams = queryParams.replace(match, '');
      });
      if ((queryParams !== window.location.search) && window.history.replaceState) {
        var newUrl = window.location.protocol + '//' + window.location.host +
                      window.location.pathname + queryParams + window.location.hash;
        window.history.replaceState(null, null, newUrl);
      }
    },

    /**
     * Modify the given string key (usually in strings.js), and return the associated variant of the
     * key if this is an SRRI build (also expected to be in in strings.js).
     * @param iKey
     * @return {String}
     */
    getVariantString: function (iKey) {
      var key = iKey;
      if (DG.get('IS_INQUIRY_SPACE_BUILD')) {
        key += '.IS_BUILD';
      }
      else if (DG.get('IS_SRRI_BUILD')) {
        key += '.SRRI_BUILD';
      }
      return key;
    },

    IS_DEV_BUILD: isDevBuild(),

    NO_DATA_TIP_PREF: noDataTipPref(),

    KEEP_IN_BOUNDS_PREF: keepInBoundsPref(),

    STANDALONE_MODE: useStandaloneMode(),
    STANDALONE_PLUGIN: getUrlParameter('standalone'),
    isStandaloneComponent: function (iComponentName, iComponentType) {
      var standalonePlugin = (DG.STANDALONE_PLUGIN || '').toLowerCase();
      var componentName = (iComponentName || '').toLowerCase();
      return (DG.STANDALONE_MODE
          && (iComponentType === 'DG.GameView')
          && (DG.STANDALONE_PLUGIN === 'true' || (componentName === standalonePlugin))
      );
    },

    // This is your application store.  You will use this store to access all
    // of your model data.  You can also set a data source on this store to
    // connect to a backend server.
    appStore: theStore,

    // The current document store. Clients that refer to DG.store are implicitly
    // referring to the store that corresponds to the current document.
    store: null,

    urlParamGames: getUrlParameter('moreGames'),

    startingDocUrl: getUrlParameter('url'),

    /**
     * startingDataInteractive can be passed as a Url parameter named 'di'
     * Expects the URL of an executable page. For now, it will only have
     * an effect if the 'doc' query parameter is _not_ set, and must be singular
     * if present.
     */
    _startingDataInteractive: getUrlParameter('di'),

    startingDataInteractive: function() {
      var parsedGames, hash;

      if (this._startingDataInteractive) {
        hash = window.location.hash;
        return this._startingDataInteractive + (hash.length > 1 ? hash : '');
      } else if (this.urlParamGames) {
        try {
          parsedGames = JSON.parse(this.urlParamGames);
          if (parsedGames && parsedGames[0]) {
            return parsedGames[0].url;
          }
        } catch (ex) {
          DG.logWarn(ex);
        }
      }
    }.property('urlParamGames, _startingDataInteractive'),

    /**
     * enables 'di' URL param to override stored URL that matches
     */
    _dataInteractiveOverride: getUrlParameter('di-override'),
    _diOverrideURL: getUrlParameter('di-override-url') || getUrlParameter('di'),


  /**
     * overrides the specified URL with one specified via 'di' URL parameter if
     * and only if the 'di-override' string is found within the specified URL.
     */
    finalGameUrl: function(iGameUrl) {
      if (!iGameUrl || !DG._diOverrideURL || !DG._dataInteractiveOverride)
        return iGameUrl;
      var hashIndex = iGameUrl.indexOf('#'),
          gameUrlNoHash = hashIndex >= 0 ? iGameUrl.substring(0, hashIndex) : iGameUrl,
          gameUrlHash = hashIndex >= 0 ? iGameUrl.substring(hashIndex) : '',
          matchIndex = gameUrlNoHash.indexOf(DG._dataInteractiveOverride);
      return matchIndex >= 0
              ? DG._diOverrideURL + gameUrlHash
              : iGameUrl;
    },

    /**
     * runKey can be passed as a Url parameter named runKey. It is a key which will be passed to the document server to enable
     * anonymous read-write access to documents. It can be any string.
     * ex: 'e342d47a-d3e5-48b8-9675-8622e40bb2c8'
     */
    runKey: getUrlParameter('runKey') || '',

    /**
     * componentMode can be passed as a Url parameter named tools with values 'yes' or 'no'.
     *  With the value 'yes' DG will not display the tool shelf, nor will it display scroll bars.
     *  The default is 'no'.
     */
    componentMode: function () {
      return getUrlParameter('componentMode', 'no');
    }.property(),

    hideCFMMenu: function () {
      var interactiveApi = getUrlParameter('interactiveApi'),
          // handle presence of the parameter without a value
          hasInteractiveApiParam = !!interactiveApi || (interactiveApi === null);
      return hasInteractiveApiParam || !!getUrlParameter('launchFromLara') || !!getUrlParameter('lara');
    }.property(),

    cfmBaseUrl: getUrlParameter('cfmBaseUrl'),

    /**
     * This URL specifies the location of a JSON file that describes the boundaries (country, state,
     * county, congressional district, PUMA) that CODAP supports.
     */
    boundarySpecsUrl: function() {
      return getUrlParameter('boundarySpec')
          || this.get('CODAP_SERVER') + '/boundaries/default_boundary_specs.json';
    }.property(),

    /**
     * embeddedMode can be passed as a Url parameter named tools with values 'yes' or 'no'.
     *  With the value 'yes' DG will not display the tool shelf, nor will it display scroll bars or the background image and
     *  a iframePhone server will be setup to enable communication with the outside page.
     *  The default is 'no'.
     */
    embeddedMode: function () {
      return getUrlParameter('embeddedMode', 'no');
    }.property(),

    /**
     * hideSplashScreen can be passed as a Url parameter named tools with values 'yes' or 'no'.
     *  With the value 'yes' DG will not display the CODAP splash screen.
     *  The default is 'no'.
     */
    hideSplashScreen: function () {
      return getUrlParameter('hideSplashScreen', 'no');
    }.property(),

    /**
     * hideWebViewLoading can be passed as a Url parameter named tools with values 'yes' or 'no'.
     *  With the value 'yes' DG will not display the loading view when loading webviews.
     *  The default is 'no'.
     */
    hideWebViewLoading: function () {
      return getUrlParameter('hideWebViewLoading', 'no');
    }.property(),

    /**
     * hideUndoRedoInComponent can be passed as a url parameter with values 'yes' or 'no'.
     *  With the value 'yes' DG will not display the undo/redo buttons in the component
     *  when embeddedMore or componentMode is enabled.
     */
    hideUndoRedoInComponent: function () {
      return getUrlParameter('hideUndoRedoInComponent', 'no');
    }.property(),

    /**
     * If set, amends the options object sent to the CFM at initialization.
     * See the main.js:cfmInit().
     * @param {Object}
     */
    cfmConfigurationOverride: null,

    /**
     * embeddedServer can be passed as a Url parameter named tools with values 'yes' or 'no'.
     *  With the value 'yes' the embedded iframePhone server is setup to enable communication with the outside page.
     *  The default is 'no' and this option is ignored if embeddedMode is 'yes'
     */
    embeddedServer: function () {
      return getUrlParameter('embeddedServer', 'no');
    }.property(),

    /**
     * informalConfidenceIntervalEnabled, when present indicates that the boxplot portion of the ruler menu
     * should include a checkbox for enabling/disabling the display of the informal confidence interval.
     * This is used by users in New Zealand in particular to support their stats curriculum.
     */
    informalConfidenceIntervalEnabled: function () {
      return getUrlParameter('ICI', undefined);
    }.property(),

    /**
     * publicConfigurationProperties is a list of properties that can be set by a plugin using the configuration API.
     *
     * For V3 we can have a single public configuration object whose keys are the names of the properties and values
     * are the default values.
     */
    publicConfigurationProperties: ['gaussianFitEnabled'],

    _gaussianFitEnabled: undefined,
    /**
     * gaussianFitEnabled, when present indicates that a "Gaussian Fit" option should be included in the
     * ruler menu for histograms. This option is for use by the PhET Simulations and Noise project. It can
     * be set either through a url parameter or by a plugin using the configuration API.
     * value {string}
     * @property {string | undefined}
     */
    gaussianFitEnabled: function (key, value) {
      if (value !== undefined) {
        this._gaussianFitEnabled = value;
      }
      return this._gaussianFitEnabled || getUrlParameter('gaussianFit', undefined);
    }.property(),

    /**
     * Returns the index of a guide page, if set as a query parameter. This is
     * taken to designate the guid page that should be present when CODAP opens
     * the document. This value should override whichever guide page is current
     * in the document and if the parameter is present and the guide is closed
     * in the document, the guide should be opened.
     */
    _guideIndex: getUrlParameter('guideIndex', undefined),
    initialGuideIndex: function (key, value) {
      if (value !== undefined) {
        this._guideIndex = value;
      }
      return this._guideIndex;
    }.property(),

    toolButtons: [ // These appear on the left side of the tool shelf
      'tableButton',
      'graphButton',
      'mapButton',
      'sliderButton',
      'calcButton',
      'textButton',
      'pluginButton'
    ],

    rightButtons: [ // These appear on the right side of the tool shelf
      'undoButton',
      'redoButton',
      'tileListButton',
      'optionButton',
      'helpButton',
      'guideButton'
    ],

    logServerUrl: function () {
      return DG.defaultLogServerLoginURLSecure;
    }.property(),

    /**
     More useful alternative to JavaScript built-in typeof operator.
     From http://javascriptweblog.wordpress.com/2011/08/08/fixing-the-javascript-typeof-operator/
     */
    toType: function (obj) {
      return ({}).toString.call(obj).match(/\s([a-zA-Z]+)/)[1].toLowerCase();
    },

    /**
     Creates a shallow copy of its argument.
     The argument can be a primitive type, a JS object, an array, an SC object, etc.
     @param    {Object}  iObject The object to be copied.
     @returns  {Object}  A shallow copy of its argument.
     */
    copy: function (iObject) {
      return SC.copy(iObject, NO);
    },

    /**
     Creates a deep copy of its argument.
     The argument can be a primitive type, a JS object, an array, an SC object, etc.
     @param    {Object}  iObject The object to be cloned.
     @returns  {Object}  A deep copy of its argument.
     */
    clone: function (iObject) {
      return SC.clone(iObject, YES);
    },

    /**
     * Determines whether attribute/slider names will be automatically canonicalized
     */
    canonicalizeNames: false,

    // CFM functions, null until connected
    exportFile: null,

    enableUndoHistory: true, //getUrlParameter('undo') === 'true'

    langOverride: function () {
      return DG.getQueryParam('lang-override');
    }.property(),

    /**
     * The current language in effect for this instance of CODAP.
     */
    currentLanguage: function () {
      return this.get('langOverride') || SC.Locale.currentLanguage;
    }.property(),

    locales: [
      {
        langName: 'Deutsch',
        langDigraph: 'de',
        countryDigraph: 'DE',
        icon: 'flag flag-de'
      },
      {
        langName: 'English',
        langDigraph: 'en',
        countryDigraph: 'US',
        icon: 'flag flag-us'
      },
      {
        langName: 'Español',
        langDigraph: 'es',
        countryDigraph: 'ES',
        icon: 'flag flag-es'
      },
      {
        langName: 'فارسی',
        langDigraph: 'fa',
        countryDigraph: 'IR',
        icon: 'flag flag-ir'
      },
      {
        langName: 'Ελληνικά',
        langDigraph: 'el',
        countryDigraph: 'GR',
        icon: 'flag flag-gr'
      },
      {
        langName: 'עברית',
        langDigraph: 'he',
        countryDigraph: 'IL',
        icon: 'flag flag-il'
      },
      {
        langName: '日本語',
        langDigraph: 'ja',
        countryDigraph: 'JP',
        icon: 'flag flag-jp'
      },
      {
        langName: '한국어',
        langDigraph: 'ko',
        countryDigraph: 'KO',
        icon: 'flag flag-kr'
      },
      {
        langName: 'Bokmål',
        langDigraph: 'nb',
        countryDigraph: 'NO',
        icon: 'flag flag-no'
      },
      {
        langName: 'Nynorsk',
        langDigraph: 'nn',
        countryDigraph: 'NO',
        icon: 'flag flag-no'
      },
      {
        langName: 'Polski',
        langDigraph: 'pl',
        countryDigraph: 'PL',
        icon: 'flag flag-pl'
      },
      {
        langName: 'Português do Brasil',
        langDigraph: 'pt-BR',
        countryDigraph: 'BR',
        icon: 'flag flag-br'
      },
      {
        langName: 'ไทย',
        langDigraph: 'th',
        countryDigraph: 'TH',
        icon: 'flag flag-th'
      },
      {
        langName: 'Türkçe',
        langDigraph: 'tr',
        countryDigraph: 'TR',
        icon: 'flag flag-tr'
      },
      {
        langName: '繁体中文',
        langDigraph: 'zh-TW',
        countryDigraph: 'TW',
        icon: 'flag flag-tw'
      },
      {
        langName: '简体中文',
        langDigraph: 'zh-Hans',
        countryDigraph: 'Hans',
        icon: 'flag flag-cn'
      }
    ]

  }, window.DG); // end return from closure

}()));

/* >>>>>>>>>> BEGIN source/alpha/archive_utils.js */
// ==========================================================================
//                        DG.ArchiveUtils
//
//  A collection of utilities to facilitate archiving/restoring documents data.
//
//  Author: Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

  Utility functions for managing the _links_ property used for database
  record ID conversion on save/restore.

  @extends SC.Object
*/
DG.ArchiveUtils = {

  /**
    Primitive function for adding a link object to the '_links_' property
    of another object. If multiple link specs are added for a single key,
    they will be appended to an array and getLinkCount() can be used to
    determine the number of links specs attached to a particular key and
    the 'index' form of getLinkID() can be used to extract each link spec.
    @param    {Object}    iStorage -- the object with the '_links_' property
    @param    {String}    iLinkKey -- the string key for the new link
    @param    {Object}    iLinkSpec -- { type: %className%, id: %ID% }
   */
  _addLinkSpec: function( iStorage, iLinkKey, iLinkSpec) {
    if( iStorage && !SC.empty( iLinkKey) && iLinkSpec) {
      // Make sure we have a _links_ property
      if( !iStorage._links_) iStorage._links_ = {};
      var links = iStorage._links_;
      // If we already have an entry for iKey, then update it
      if( links[ iLinkKey]) {
        if( !SC.isArray( links[ iLinkKey])) {
          // Convert simple property to array if necessary
          links[ iLinkKey] = [ links[ iLinkKey] ];
        }
        // Add the new entry to the array
        links[ iLinkKey].push( iLinkSpec);
      }
      else {
        // Just add the simple property
        links[ iLinkKey] = iLinkSpec;
      }
    }
  },

  /**
    Utility function for adding entries to the _links_ property of a
    storage object. Will create the _links_ property if necessary.
    Accepts link specification in form of class name and ID.
    Will store multiple links added for a single key in an array.
    @param    {Object}    iStorage -- the object with the '_links_' property
    @param    {String}    iLinkKey -- the string key for the new link
    @param    {String}    iClassName -- the name of the class being stored (e.g. 'DG.Case')
    @param    {Number}    iLinkID -- the ID of the record being stored
   */
  addLinkID: function( iStorage, iLinkKey, iClassName, iLinkID) {
    var linkSpec = { type: iClassName, id: iLinkID };
    DG.ArchiveUtils._addLinkSpec( iStorage, iLinkKey, linkSpec);
  },

  /**
    Utility function for adding entries to the _links_ property of a
    componentStorage object. Will create the _links_ property if necessary.
    Will store multiple links added for a single key in an array.
    @param    {Object}  iStorage -- The componentStorage object with the _links_ property
    @param    {String}  iLinkKey -- The string key of the link in the _links_ property
    @param    {Object}  iObject -- The object being linked; must have a toLink() method
                                   which returns a link spec { type: %className%, id: %ID% }
   */
  addLink: function( iStorage, iLinkKey, iObject) {
    var linkSpec = iObject && iObject.toLink && iObject.toLink();
    DG.ArchiveUtils._addLinkSpec( iStorage, iLinkKey, linkSpec);
  },
  
  /**
    Returns the total number of link entries or the number of link entries for a given key.
    @param    {Object}  iStorage -- The componentStorage object with the _links_ property
    @param    {String}  iLinkKey -- The string key of the link in the _links_ property
    @returns  {Number}              The number of link entries (if iLinkKey is not specified)
                                    or the number of links for iLinkKey (if it is specified)
   */
  getLinkCount: function( iStorage, iLinkKey) {
    var links = iStorage && iStorage._links_;
    if( !links)
      return 0;
    // If no link key, return number of entries
    if( SC.empty( iLinkKey))
      return DG.ObjectMap.length( links);
    var entry = links[ iLinkKey];
    return SC.isArray(entry)  ? entry.length
                              : (SC.empty(entry) ? 0 : 1);
  },
  
  /**
    Utility function for extracting link IDs from the _links_ property
    of a componentStorage object.
    @param    {Object}  iStorage -- The componentStorage object with the _links_ property
    @param    {String}  iLinkKey -- The string key of the link in the _links_ property
    @param    {Number}  iIndex   -- [Optional] The index of the ID to retrieve (default: 0)
    @returns  {Number}              The ID from the link object with the specified key [and index]
   */
  getLinkID: function( iStorage, iLinkKey, iIndex) {
    var links = iStorage && iStorage._links_,
        entry = links && links[ iLinkKey],
        link = SC.isArray( entry) ? entry[ iIndex || 0] : entry;
    return link && link.id;
  }
  
};

/* >>>>>>>>>> BEGIN source/alpha/browser.js */
// ==========================================================================
//                              DG.Browser
// 
//   A collection of utilities for browser specific fixes / workarounds.
//  
//   Author:    Matt Litwin
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

DG.Browser = {

  /**
    Initial browser sniffing.
    Will inject various workarounds, so call after loading SC.
   */   
  init: function() {
    // SproutCore changes the 'overflow' setting of the document at various times
    // to avoid presenting scroll bars when they would not be desirable.
    // Firefox has had a long-running bug (supposedly fixed in Firefox 13) which
    // would cause embedded Flash objects to reload unnecessarily when the 'overflow'
    // setting of the document (or various other settings) were changed.
    // Our attempts to prevent the change to the 'overflow' setting in Firefox
    // when there were embedded plugin objects led to other problems, e.g. crashes
    // when attempting to determine whether to apply the fix or not.
    // For 0138 (2012-10-05) we only try to change the SproutCore behavior for
    // Firefox versions before Firefox 13; and when we do change the SproutCore
    // behavior we use a simpler test that applies the change more universally:
    // If there are any <embed>, <object>, or <iframe> tags, we disable SproutCore's
    // 'overflow' changes.
    // See http://dgbugs.kcptech.com/show_bug.cgi?id=111 and comments below for
    // more details.
    if( (SC.browser.name === SC.BROWSER.firefox) && (SC.browser.compare( SC.browser.version, '46') < 0)) {
      // The menu pane base class picker.js plays with
      // the SC.$(document.body) css overflow attribute,
      // toggling between 'hidden' and 'visible' in its private
      // _hideOverflow and _showOverflow functions.
      
      // Code comment to _hideOverflow says.
      // (https://github.com/sproutcore/sproutcore/blob/master/frameworks/desktop/panes/picker.js)
      /*
        Internal method to hide the overflow on the body to make sure we don't
        show scrollbars when the picker has shadows, as it's really anoying.
      */
      
      // But this runs into a Firefox bug which reloads flash in many situtations where it should not
      // https://bugzilla.mozilla.org/show_bug.cgi?id=90268 (Start with comment #80)
      // According to the Bugzilla bug, a fix landed in Firefox 13.
      
      // We'll check for embed and object tags, which show the bug.
      var hasActivePlugin; // Declare function var before referencing it in definition (JSLint warning)     
      hasActivePlugin = function(rootNode) {
        var hasPlugins = false;

        try {
          // Are there any embed/object tags in the main document?
          if((SC.$('embed', rootNode).length > 0) || (SC.$('object', rootNode).length > 0))
              hasPlugins = true;

          // Are there any iframes which could have embedded plugins?
          // Note: We used to try to recursively search through the contents of the
          // iframe looking for <embed>/<object> tags. These tests failed on some
          // versions of Firefox, so we simplify the test to say if there are any
          // iframes, we assume that there could be plugins.
          if( SC.$('iframe', rootNode) > 0)
            hasPlugins = true;
        }
        catch(e) {
          hasPlugins = true;
        }
         
         return hasPlugins;
      };
      
      // Keep track of the SC version of the function.
      var original_hideOverflow = SC.PickerPane.prototype._hideOverflow;
      
      // Override _hideOverflow
      SC.PickerPane.prototype._hideOverflow = function() {
        // Skip the call to SproutCore's _hideOverflow() if we have plug-ins.
        // In the absence of plug-ins, preserve the original behavior.
        if( !hasActivePlugin(SC.$(document)))
          original_hideOverflow.call(this,arguments);
      };
            
      // SC.PickerPane.prototype._showOverflow is bullet proof against a no-op _hideOverflow,
      // so no action is needed here. Saves us the trouble of tracking if we have called 
      // original_hideOverflow() or not.
    }
  },
  
  /**
    Returns true if the current browser is supported (or not explicitly unsupported),
    false otherwise.
   */
  isCompatibleBrowser: function() {

    // Returns true if iCurrentVersion >= iRequiredVersion
    function isSupportedVersion( iRequiredVersion, iCurrentVersion) {
      var requiredParts = iRequiredVersion.split('.'),
          requiredPartCount = requiredParts.length,
          currentParts = iCurrentVersion.split('.');
      for( var i = 0; i < requiredPartCount; ++i) {
        var currentVersion = Number( currentParts[ i]) || 0,
            requiredVersion = Number( requiredParts[ i]);
        if( currentVersion > requiredVersion)
          return true;
        if( currentVersion < requiredVersion)
          return false;
      }
      // If we get here, we have exactly the required version
      return true;
    }
  
    //DG.log('Browser: %@, Version: %@', SC.browser.name, SC.browser.version);
    
    // DEV builds are used for browser compatibility testing
    if( DG.IS_DEV_BUILD)
      return true;
      
    switch( SC.browser.name) {
    case SC.BROWSER.ie: //Win Edge is still recognized as ie in Sproutcore
        //return isSupportedVersion('11',SC.browser.version) ;
        return false; //Not supporting IE11 as of 8/30/2017
    case SC.BROWSER.firefox:
      // Version number corresponds to Gecko version number for Firefox 3.6.
      // See http://en.wikipedia.org/wiki/Firefox_history for details.
      return isSupportedVersion('46', SC.browser.version) ||
              isSupportedVersion('46', SC.browser.engineVersion); //after Gecko 2.0, Firefox and Gecko version number are the same.
    case SC.BROWSER.chrome:
      return isSupportedVersion('50', SC.browser.version);
    case SC.BROWSER.safari:
      // Version number corresponds to WebKit version number for Safari 4.
      // See http://en.wikipedia.org/wiki/Safari_version_history for details.
      return isSupportedVersion('10', SC.browser.version) ||
              isSupportedVersion('603.1.30', SC.browser.engineVersion);
    }
    // Give other (largely untested) browsers the benefit of the doubt
    return true;
  },

  /**
    Encapsulate browser-specific differences in cursor-specification.
    See http://www.useragentman.com/blog/2011/12/21/cross-browser-css-cursor-images-in-depth/
    for more information about custom cursor browser compatibility.
    IE uses the the hotspot information in .cur files, but can't handle
    hot spot information provided in code.
    Chrome ignores the hotspot information in .cur files and so requires
    hot spot information provided in code.
    Most other browsers respect hot spot information in .cur files and
    in code, leading to an interesting question about what happens when
    they conflict. The code below generates different cursor specification
    strings depending on the browser.
    @param    {String}    iUrl -- The URL path for the cursor file
    @param    {Number}    iXHotSpot -- The X coordinate of the cursor hot spot
    @param    {Number}    iYHotSpot -- The Y coordinate of the cursor hot spot
    @param    {String}    iDefault -- [Optional] Defaults to 'auto'
    @returns  {String}    The cursor specification string for the browser
   */
  customCursorStr: function( iUrl, iXHotSpot, iYHotSpot, iDefault) {
    iDefault = iDefault || 'auto';
    return ( SC.browser.engine === SC.ENGINE.trident
                 ? 'url(' + iUrl + '), ' + iDefault
                 : 'url(' + iUrl + ') ' + iXHotSpot + ' ' + iYHotSpot + ', ' + iDefault);
  }
};

/* >>>>>>>>>> BEGIN source/alpha/core_utils.js */
// ==========================================================================
//                              DG.Core
// 
//  This is intended to be a gathering place for widely useful "core" utility
//  functions.
//  
//  Author:   Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

DG.Core = {

  /**
   * This pseudo global flag is set during onMouseDownCapture function in React components to signal to
   * an SC.View that contains them can tell that they should not attempt to handle a given event.
   */
  gClickWillBeHandledInReactComponent: false,
  setClickHandlingForReact: function() {
    DG.Core.gClickWillBeHandledInReactComponent = true;
    setTimeout(function() {
      DG.Core.gClickWillBeHandledInReactComponent = false;
    }, 200);
  },

  /**
    Returns the "class" object which corresponds to the specified string.
    @param    {String}  iClassName -- The name of the class object to be returned
    @returns  {Object}  The class object corresponding to the specified name
   */
  classFromClassName: function( iClassName) {
    var parts = iClassName ? iClassName.split('.') : [],
        i, partCount = parts.length,
        obj = window;
    for( i = 0; i < partCount; ++i) {
      obj = obj && obj[ parts[i]];
    }
    return obj || null;
  },
  
  /**
    Returns true if the specified event indicates that a modifier key
    that extends selection was down at the time of the event. This
    method doesn't currently differentiate between item selection
    (e.g. cmd/ctrl click) and range selection (shift click).
    @param    {SC.Event}    iEvent -- The SproutCore event passed to an event handler
    @returns  {Boolean}     True if the event indicates extension, false otherwise
   */
  isExtendingFromEvent: function( iEvent) {
        // ctrlKey masquerades as meta key in SC.Event
    var osUsesMetaKey = (SC.browser.os === SC.OS.mac) || (SC.browser.os === SC.OS.ios),
        isMetaKeyExtension = osUsesMetaKey && iEvent.metaKey && !iEvent.ctrlKey,
        isCtrlKeyExtension = !osUsesMetaKey && iEvent.ctrlKey;
    return iEvent.shiftKey || isMetaKeyExtension || isCtrlKeyExtension;
  }

};

/* >>>>>>>>>> BEGIN source/utilities/analytics.js */
/* global ga */
(function () {

DG.Analytics = {};

DG.Analytics.Category = {
  GENERAL:  "General",  // catch-all for events that we haven't categorized yet
  DATA:     "Data",     // Interactions with generated data
  DOCUMENT: "Document", // Document interactions
  GAME:     "Game",     // Game interactions
  MODEL:    "Model",    // Model interactions
  PLOT:     "Plot",     // Plot interactions
  SESSION:  "Session",  // Session events (log in/out)
};

var _timeStart = {};

// These were hand-pulled from existing log data, so inevitably there were some missed.
// Really, we should be more explicit about event types, categories, and whatnot
// at the point that we initiate the logging, rather than trying to map them like this.
DG.Analytics.categoryForEvent = function(event) {
  switch (event) {
    case "Show all cases":
    case "Show all":
    case "openCase":
    case "Hide all":
    case "deselectAll":
    case "createCases":
    case "createCase":
    case "closeCase":
    case "attributeRemoved":
    case "attributeCreate":
      return DG.Analytics.Category.DATA;
    case "openDocument":
    case "closeDocument":
    case "componentCreated":
    case "closeComponent":
    case "autoSaveDocument":
    case "saveDocument":
      return DG.Analytics.Category.DOCUMENT;
    case "initGame":
    case "backToGame":
      return DG.Analytics.Category.GAME;
    case "LoadedModel":
    case "StartedModel":
      return DG.Analytics.Category.MODEL;
    case "togglePlottedMean":
    case "togglePlotFunction":
    case "rescaleScatterplot":
    case "rescaleDotPlot":
    case "plotFunction":
    case "plotAxisAttributeChangeType":
    case "plotAxisAttributeChange":
    case "legendAttributeChange":
    case "hoverOverGraphLine":
    case "ExportedModel":
    case "addAxisAttribute":
      return DG.Analytics.Category.PLOT;
    case "Logout":
    case "Login":
      return DG.Analytics.Category.SESSION;
    default:
      if (event && event.search(/Hide .* selected cases/) !== -1) {
        return DG.Analytics.Category.DATA;
      }
      return DG.Analytics.Category.GENERAL;
  }
};

DG.Analytics._analyticsEnabled = function() {
  return typeof(ga) !== "undefined" && ga !== null;
};

DG.Analytics.trackEvent = function(category, action, label, value) {
  if (!this._analyticsEnabled()) return;

  var evt = ['send', 'event', category, action];
  if (label) {
    evt.push(label);
    if (value) {
      evt.push(value);
    }
  }
  ga.apply(window, evt);
};

DG.Analytics.trackTimingStart = function(category) {
  if (!this._analyticsEnabled()) return;

  _timeStart[category] = new Date().getTime();
};

DG.Analytics.trackTimingEnd = function(category) {
  if (!this._analyticsEnabled() || !_timeStart[category]) return;

  var timeSpent = new Date().getTime() - _timeStart[category];
  _timeStart[category] = null;

  // sanity-check: time spend should be positive, and less than two hours
  if (timeSpent > 0 && timeSpent < (1000 * 60 * 120)) {
    var evt = ['send', 'timing', category, 'Time spent', timeSpent];
    ga.apply(window, evt);
  }
};

}());

/* >>>>>>>>>> BEGIN source/alpha/debug.js */
// ==========================================================================
//                              DG.Debug
//
//  Debugging utilities for use in the DG application.
//
//  Author:   Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
sc_require('utilities/analytics');
/**
  Constant used to indicate logging of user actions.
  Analogous to SC.LOGGER_LEVEL_INFO, which as also the SC.Logger level
  at which it is such user log events are processed by SC.Logger.
*/
DG.LOGGER_LEVEL_USER = 'user';

/**
  Global function used to reload the current page.
  Called by the assert code when user presses the Reload button.
*/
DG.debugForceReload = function() {
  window.location.reload();
};

/**
  Global function used to drop into the JavaScript debugger, if one is running.
*/
DG.debugLaunchDebugger = function() {
  /* eslint no-eval: "off" */
  /* jslint evil:true */
  eval('debugger');
};


/** @class

  DG.Debug provides debugging utilities for use during development.
  These debugging utilities are synchronized with the SproutCore facilities.

  (1) Expanded logging support (enhances SC.Logger)
      -- Log messages can be logged to the DG server via DG.logToServer().
      -- Addition of the DG.LOGGER_LEVEL_USER for logging of user actions

      Clients control the level of server logging via the 'logServerLevel'
      property of DG.Debug. Clients should use the global convenience
      functions for their logging needs:
        DG.log(), DG.logRaw(), DG.logGroupBegin(), DG.logGroupEnd()
        DG.logInfo(), DG.logInfoRaw(), DG.logUser(), DG.logUserRaw(),
        DG.logWarn(), DG.logWarnRaw(), DG.logError(), DG.logErrorRaw()

      Note that the "standard" functions support printf-style formatting
      to simplify formatting of log strings. See SC.Logger for details.
      The "raw" functions skip the printf-style formatting for clients
      that would prefer to do the formatting themselves.

  (2) Assert functions

      Assert functions test a condition and put up an alert if it fails.
      As currently configured, the alert provides "Reload" and "Ignore"
      buttons and for developer builds (i.e. when running from sc-server
      during development), a "Debugger" button which drops into the debugger.

      In addition, for developer builds (i.e. when running from sc-server),
      the assert functions will drop into the debugger at a point at which
      the stack is meaningful, as it will contain the function which called
      the assert function.

      The following functions are defined at this point:

      DG.assert( iCondition, iMessage, iDescription)
      DG.check( iObject, iMessage, iDescription)
        -- Equivalent to assert( !SC.none( iObject))

      The assert functions as they exist now are designed to return the
      condition being tested. Thus, it is possible to handle the failure
      as well as being notified about it, e.g.

        if( DG.check( iObject))
          iObject.doSomething();

      Thus, even if the alert and dropping into the debugger features
      of the assert functions are eliminated in a production build, clients
      may still use the assertion functions to bypass code that would
      otherwise fail

      Note that currently the assert function will bring up the assertion
      failure dialog in production builds as well as during development.
      If we decide at some point that this is not what we want, at least
      there will be a single place in which to make the change.

  (3) Unhandled exception handling

      The SproutCore White Screen of Death (WSOD) is the built-in SproutCore
      handler of last resort for otherwise unhandled exceptions. We intercept
      this mechanism to log it (using DG.logError()) and to stop in the debugger
      in developer builds (i.e. when running from sc-server) to allow the
      developer to look around and perhaps set a breakpoint before calling the
      SproutCore White Screen of Death handler.

  @author Kirk Swenson
  @extends SC.Object
*/

SC.Logger.logOutputLevel = SC.LOGGER_LEVEL_WARN;



DG.Debug = SC.Object.create( (function() {
/** @scope DG.GlobalsController.prototype */

  // interval within which CODAP will suppress duplicate alerts
  var kAssertInterval = 1000;
  // the last Assert Message displayed
  var lastAssertMessage = null;
  // the time of the last assert message
  var lastAssertTime = 0;

  return {

    /**
      Controls the logging level to the DG server.
      Analogous to SC.Logger.logOutputLevel and SC.Logger.logRecordingLevel.

      @property: {Constant}
     */
    logServerLevel: SC.LOGGER_LEVEL_INFO,

    /**
      Controls the logging level to Google Analytics.
      Analogous to SC.Logger.logOutputLevel and SC.Logger.logRecordingLevel.

      @property: {Constant}
     */
    googleAnalyticsLevel: SC.LOGGER_LEVEL_INFO,

    /**
      Previous message logging function
      Called from our intervening message log handler.
    */
    _prevHandleLogMessage: null,

    /**
      Previous exception handler
      Called from our intervening exception handler.
    */
    _prevExceptionHandler: null,

    /** the time in milliseconds when init() or logDebugTimer(true) was last called. */
    _debugStartTime: 0,

    /**
      Install our overrides/interventions.
    */
    init: function() {

      this._debugStartTime = Date.now(); // record current time in milliseconds "since the epoch"

      // Install our message-logging intervention
      this._prevHandleLogMessage = SC.Logger._handleMessage;
      SC.Logger._handleMessage = this._prevHandleLogMessage;

      // Install our exception-handling intervention
      // this._prevExceptionHandler = SC.ExceptionHandler.handleException;
      SC.ExceptionHandler.handleException = this._handleException;

      SC.ExceptionHandler.enabled = YES;

    },

    /**
      Issue a log warning if the specified value is not finite (NaN, infinite, etc.)
     */
    logIfNotFinite: function(iValue, iOptString) {
      if( !isFinite( iValue))
        this.logWarn("DG.Debug.logIfNotFinite: String: %@, Value: %@", iOptString, iValue);
    },

    /**
      DG.Debug logging methods.
      Clients will generally use the global convenience functions defined later.
    */
    logDebug: function( iMessage, iOptFormatArgs) {
      DG.Debug._handleLogMessage(SC.LOGGER_LEVEL_DEBUG, YES, iMessage, arguments);
    },

    logDebugRaw: function( iRawArgs) {
      DG.Debug._handleLogMessage(SC.LOGGER_LEVEL_DEBUG, NO, null, arguments);
    },

    /** DG.Debug logging method with '[TIME=0.1234]' timing message (in seconds). */
    logDebugTimer: function( iResetTimer, iMessage, iOptFormatArgs ) {
      var tTimeMS = Date.now(); // time in milliseconds
      if( iResetTimer ) {    // reset the timer to zero
        DG.Debug._debugStartTime = tTimeMS;
        tTimeMS = 0;
      } else {                  // else relative to last start
        tTimeMS -= DG.Debug._debugStartTime;
      }
      // log with '[TIME=seconds.milliseconds] {message}'
      DG.Debug._handleLogMessage(SC.LOGGER_LEVEL_DEBUG, YES, "[TIME="+(tTimeMS/1000)+"] "+iMessage, arguments);
    },

    logDebugGroupBegin: function( iMessage, iOptFormatArgs) {
      SC.Logger._handleGroup(SC.LOGGER_LEVEL_DEBUG, iMessage, arguments);
    },

    logDebugGroupEnd: function() {
      SC.Logger._handleGroupEnd(SC.LOGGER_LEVEL_DEBUG);
    },

    logInfo: function( iMessage, iOptFormatArgs) {
      DG.Debug._handleLogMessage(SC.LOGGER_LEVEL_INFO, YES, iMessage, arguments);
    },

    logInfoRaw: function( iRawArgs) {
      DG.Debug._handleLogMessage(SC.LOGGER_LEVEL_INFO, NO, null, arguments);
    },

    /**
     * Log user actions. Has the priority of an Info level log message but may
     * also be logged to the log server and other places.
     * @param iMessage {string} A string, potentially with format strings as in
     * SC.String.fmt.
     * @param iOptFormatArgs {string} ... A variable number of substitution
     * parameters according to the format fields in IMessage.
     */
    logUser: function( iMessage, iOptFormatArgs) {
      var values = {
        formatStr: iMessage,
        replaceArgs: [].slice.call(arguments, 1)
      };
      var notificationManager = DG.currDocumentController().notificationManager;
      if (notificationManager) {
        notificationManager.notifyLogMessageSubscribers(values);
      }

      DG.Debug._handleLogMessage(DG.LOGGER_LEVEL_USER, YES, iMessage, arguments);
    },

    /**
     * This is a special purpose logger to support log messages coming from
     * the DI API. These may have an additional "topic" argument which we
     * need to handle specially. We need to convey them forward to the NotificationManager.
     * @param iTopic {string}
     * @param iMessage {string} A string, potentially with format strings as in
     * SC.String.fmt.
     * @param iOptFormatArgs {string} ... A variable number of substitution
     * parameters according to the format fields in IMessage.
     */
    logUserWithTopic: function( iTopic, iMessage, iOptFormatArgs) {
      var values = {
        topic: iTopic,
        formatStr: iMessage,
        replaceArgs: [].slice.call(arguments, 2)
      };

      var notificationManager = DG.currDocumentController().notificationManager;

      // Notification manager will not exist before there is a document.
      // Neither, of course, will any entities to notify.
      if (notificationManager) {
        notificationManager.notifyLogMessageSubscribers(values);
      }

      var args = [].slice.call(arguments, 1);

      DG.Debug._handleLogMessage(DG.LOGGER_LEVEL_USER, YES, iMessage, args);
    },

    logUserRaw: function( iRawArgs) {
      DG.Debug._handleLogMessage(DG.LOGGER_LEVEL_USER, NO, null, arguments);
    },

    logWarn: function( iMessage, iOptFormatArgs) {
      DG.Debug._handleLogMessage(SC.LOGGER_LEVEL_WARN, YES, iMessage, arguments);
    },

    logWarnRaw: function( iRawArgs) {
      DG.Debug._handleLogMessage(SC.LOGGER_LEVEL_WARN, NO, null, arguments);
    },

    logError: function( iMessage, iOptFormatArgs) {
      DG.Debug._handleLogMessage(SC.LOGGER_LEVEL_ERROR, YES, iMessage, arguments);
    },

    logErrorRaw: function( iRawArgs) {
      DG.Debug._handleLogMessage(SC.LOGGER_LEVEL_ERROR, NO, null, arguments);
    },

    /**
      Asserts that its condition is true.
      Puts up an alert message when its condition is not true, and
      automatically drops into the debugger in debug builds.
      Alert dialog has options for "Reload" and "Ignore" (and "Debug"
      for developer builds).

      @param {Boolean}  iCondition    The condition to test
      @param {String}   iMessage      A primary message
      @param {String}   iDescription  A secondary message
      @returns {Boolean}              The condition that was tested
    */
    assert: function( iCondition, iMessage, iDescription) {
      if( !iCondition) {

        var showAlert = ((lastAssertMessage !== iMessage) &&
                ((Date.now() - lastAssertTime) > kAssertInterval)),
            stopInDebugger = true;

        // Log assertion failures automatically
        DG.Debug.logErrorRaw( "Assertion Failed: " + iMessage + ": " + iDescription);

        // Stop in debugger in debug builds
        if( stopInDebugger ) {
          

        }

        // Show the assertion failure alert
        if( showAlert ) {
          SC.AlertPane.error({
            message: iMessage || "",
            description: iDescription || "",
            buttons: [
              { title: "Reload", action: DG.debugForceReload },
              

              { title: "Ignore" }
            ]
          });
          lastAssertMessage = iMessage;
          lastAssertTime = Date.now();
        }
      }
      // Give clients a chance to handle the failure, e.g.
      // if( !DG.assert(myObj))
      //   myObj.doSomething();
      return iCondition;
    },

    /**
      Asserts that the specified object is defined and non-null.
      Equivalent to DG.assert( !SC.none( iObject, iMessage, iDescription))

      @param {Object}   iObject       The object to test
      @param {String}   iMessage      A primary message
      @param {String}   iDescription  A secondary message
      @returns {Boolean}              The condition that was tested
    */
    check: function( iObject, iMessage, iDescription) {
      return this.assert( !SC.none( iObject), iMessage, iDescription);
    },

    /** @private
      Private function used to decide when to log to the DG server.
      Analogous to SC.Logger._shouldOutputType and SC.Logger._shouldRecordType.

      @param {String}  iType  The name of the type in question from among
                                standard Sproutcore log types.
      @returns {Boolean}
    */
    _shouldLogTypeToServer: function( iType) {
      var logLevelMapping = SC.Logger._LOG_LEVEL_MAPPING,
          level           = logLevelMapping[iType]                      || 0,
          currentLevel    = logLevelMapping[this.get('logServerLevel')] || 0;

      return (level <= currentLevel);
    },

    /** @private
      Outputs to the console and/or records the specified message and/or
      logs it to the DG server if the respective current log levels allows for it.
      Assuming 'automaticallyFormat' is specified, then String.fmt() will be called
      automatically on the message, but only if at least one of the log levels
      is such that the result will be used.

      @param {String}  iType         Expected to be SC.LOGGER_LEVEL_DEBUG, etc.
      @param {Boolean} iAutoFormat   Whether or not to treat 'message' as a format string if there are additional arguments
      @param {String}  iMessage      Expected to a string format (for String.fmt()) if there are other arguments
      @param {Object}  iOriginalArgs (optional) All arguments passed into debug(), etc. (which includes 'message'; for efficiency, we don’t copy it)
    */
    _handleLogMessage: function( iType, iAutoFormat, iMessage, iOriginalArgs) {

      // Map DG-specific types to standard SC.Logger types
      //var scType = (iType === DG.LOGGER_LEVEL_USER ? SC.LOGGER_LEVEL_INFO : iType);
      var scType = iType;
      if (iType === DG.LOGGER_LEVEL_USER) { scType = SC.LOGGER_LEVEL_INFO; }
      else if (iType === DG.LOGGER_LEVEL_INFO) { scType = SC.LOGGER_LEVEL_DEBUG; }

      // Let SC.Logger log the message normally
      this._prevHandleLogMessage.call( SC.Logger, scType, iAutoFormat, iMessage, iOriginalArgs);

      var shouldLogToServer = DG.Debug._shouldLogTypeToServer( scType),
          shouldLogToGA = DG.Debug._shouldLogTypeToGoogleAnalytics(scType);
      if (shouldLogToServer || shouldLogToGA) {
        // Pass along any properties that were passed in the last argument as
        // metaArgs
        var lastArg = (iOriginalArgs && (iOriginalArgs.length > 0))
                ? iOriginalArgs[ iOriginalArgs.length - 1]
                : undefined,
            metaArgs = typeof lastArg === 'object' ? lastArg : {},
            messageParts = DG.Debug._currentMessage? DG.Debug._currentMessage.split(":"): [],
            activityName = DG.getPath('currDocumentController.documentName'),
            messageType = messageParts.shift(),
            messageArgs = messageParts.join(':').trim();

        // Warnings and errors have a messageType of their level. We pass the original message.
        if (scType === SC.LOGGER_LEVEL_ERROR || scType === SC.LOGGER_LEVEL_WARN) {
          messageType = scType;
          messageArgs = '{"message": "' +  DG.Debug._currentMessage + '"}';
        }

        // Log the message to the server as well, if appropriate
        if ( shouldLogToServer ) {
          try {
            DG.logToServer( messageType, {
                  type: iType,
                  args: messageArgs,
                  activity: activityName,
                  application: 'CODAP'
                }, metaArgs);
          } catch(ex) {
            if (console && console.log) {
              console.log('Log to server failed: ' + ex);
            }
          }
        }

        if ( shouldLogToGA ) {
          DG.Analytics.trackEvent(DG.Analytics.categoryForEvent(messageType), messageType, messageArgs);
        }
      }

    },

    /** @private
      Private function used to decide when to log to Google Analytics.
      Analogous to SC.Logger._shouldOutputType and SC.Logger._shouldRecordType.

      @param {String}  iType  The name of the type in question from among
                                standard Sproutcore log types.
      @returns {Boolean}
    */
    _shouldLogTypeToGoogleAnalytics: function( iType) {
      var logLevelMapping = SC.Logger._LOG_LEVEL_MAPPING,
          level           = logLevelMapping[iType]                      || 0,
          currentLevel    = logLevelMapping[this.get('googleAnalyticsLevel')] || 0;

      return DG.GOOGLE_ANALYTICS_ID && (level <= currentLevel);
    },

    /** @private
      Our exception handler override which logs the exception and stops in the debugger
      before calling the SproutCore exception handler.
    */
    _handleException: function( iException) {
      var shouldCallSystemHandler = !SC.none( DG.Debug._prevExceptionHandler);

      DG.Debug.logError( "Exception: " + iException);
      if (console && console.log) {
        DG.log(iException.stack);
      }


      

      window.alert('DG.mainPage.exceptionMessage'.loc(iException.message));  /* eslint no-alert: "off" */

      if( shouldCallSystemHandler)
        DG.Debug._prevExceptionHandler.call( this, iException);

      return true;
    }

  }; // return from function closure
}())); // function closure

/** @private
  Replace SC.Logger._shouldOutputType function with our own implementation which always
  returns true, thus guaranteeing that we have a chance to capture the formatted message.
  Stash the original SC.Logger._shouldOutputType function so we can call it later.
 */
DG.Debug._prevShouldOutputType = SC.Logger._shouldOutputType;
SC.Logger._shouldOutputType = function(type) {
  return true;
};

/** @private
  Replace SC.Logger._outputMessage function with our own implementation which captures the
  formatted message. We then call the original SC.Logger._shouldOutputType method to determine
  whether or not to call the original SC.Logger._outputMessage method.
 */
DG.Debug._prevOutputMessage = SC.Logger._outputMessage;
SC.Logger._outputMessage = function(type, timestampStr, indentation, message, originalArguments) {
  // be careful to place a string in _currentMessage. Otherwise we can fail badly
  // trying to report a minor error.
  if (typeof message === 'string') {
    DG.Debug._currentMessage = message;
  } else if (message && message.toString) {
    DG.Debug._currentMessage = message.toString();
  } else {
    DG.Debug._currentMessage = '';
  }
  if( DG.Debug._prevShouldOutputType.call( SC.Logger, type))
    DG.Debug._prevOutputMessage.call( SC.Logger, type, timestampStr, indentation, message, originalArguments);
};

/**
  Returns the unique SproutCore-generated ID for a SproutCore object.
  Returns "{none}" if there is not SproutCore ID associated with the object.
  This can be useful when logging to help identify objects.
 */
DG.Debug.scObjectID = function( iObject) {
  var scIDValue = "";
  DG.ObjectMap.findKey( iObject, function( iKey, iValue) {
    if( iKey.substr(0,10) === 'SproutCore') {
      scIDValue = iValue;
      return true;
    }
    return false;
  });
  return !SC.empty(scIDValue) ? scIDValue : "{none}";
};

/**
  Convenience functions for DG.Debug functions.
*/
DG.log = DG.Debug.logDebug;
DG.logRaw = DG.Debug.logDebugRaw;
DG.logTimer = DG.Debug.logDebugTimer;
DG.logGroupBegin = DG.Debug.logDebugGroupBegin;
DG.logGroupEnd = DG.Debug.logDebugGroupEnd;

DG.logInfo = DG.Debug.logInfo;
DG.logInfoRaw = DG.Debug.logInfoRaw;
DG.logUser = DG.Debug.logUser;
DG.logUserRaw = DG.Debug.logUserRaw;
DG.logWarn = DG.Debug.logWarn;
DG.logWarnRaw = DG.Debug.logWarnRaw;
DG.logError = DG.Debug.logError;
DG.logErrorRaw = DG.Debug.logErrorRaw;

DG.assert = DG.Debug.assert;
DG.check = DG.Debug.check;


/* >>>>>>>>>> BEGIN source/alpha/destroyable.js */
// ==========================================================================
//                              DG.Destroyable
// 
//  A mixin designed to work with derived classes of SproutCore's SC.Object
//  to simplify the process of destroying properties that need destroying.
//  In particular, the 'autoDestroyProperties' property allows derived
//  classes to specify a set of properties that should be automatically
//  destroyed on destruction of the owning object.
//  
//  Author:   Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

DG.Destroyable = {

  concatenatedProperties: ['autoDestroyProperties'],

  /**
    Automatically destroys properties listed in the 'autoDestroyProperties' property.
    Called automatically from SC.Object.destroy().
   */
  destroyMixin: function() {
    var props = this.get('autoDestroyProperties');
    if( props) {
      props.forEach( function( iPropertyName) {
                        this.destroyProperty( iPropertyName);
                      }.bind( this));
    }
  },
  
  /**
    Destroy the property of this object with the specified name.
    The property is assumed to contain an object reference to an
    object which is derived from SC.Object.
    Performs the following actions for the given property:
      -- Calls the willDestroy() method if it exists
      -- Calls the destroy() method
      -- Sets the property to null to allow it to be garbage collected
          Note: If the name of the property begins with an underscore,
                it is assumed to be a private property and is nulled
                out with an explicit assignment. Otherwise, it is nulled
                out with this.set( iPropertyName, null).
    @param    {String}  iPropertyName - The name of the property to destroy
                          If it begins with an underscore, null will be assigned to it.
                          Otherwise, it will be .set() to null
   */
  destroyProperty: function destroyProperty( iPropertyName) {
    var propertyValue = this.get( iPropertyName);

    // We only deal with Object properties
    if( DG.Destroyable.destroyObject( propertyValue)) {
    
      // Set the property to null.
      // Private properties (indicated by leading underscore in name)
      // set the property directly, while public properties use set().
      if( iPropertyName.charAt( 0) === '_')
        this[ iPropertyName] = null;
      else
        this.set( iPropertyName, null);
    }
  }
  
};

/**
  Destroys the specified object, calling willDestroy() (if available) first.
  @param    {Object}    iObject -- The object to destroy
  @returns  {Boolean}   True if iObject was a destroyable object, false otherwise.
 */
DG.Destroyable.destroyObject = function( iObject) {

  // We only deal with objects
  if( iObject && (iObject instanceof SC.Object)) {
  
    // If the object has a willDestroy() method, we call it
    if( iObject.willDestroy) iObject.willDestroy();
    
    // Call the destroy method explicitly
    iObject.destroy();
    
    // Returning true indicates that iObject was a destroyable object
    return true;
  }
  
  // Returning false indicates that iObject was not a destroyable object
  return false;
};



/* >>>>>>>>>> BEGIN source/utilities/formatter.js */
/**
 * Taken from Mike Bostock's Protovis project <http://mbostock.github.io/protovis/>. Thank you!
 *
 * Abstract; see an implementing class.
 *
 * @class Represents an abstract text formatter and parser. A <i>format</i> is a
 * function that converts an object of a given type, such as a <tt>Date</tt>, to
 * a human-readable string representation. The format may also have a
 * {@link #parse} method for converting a string representation back to the
 * given object type.
 *
 * <p>Because formats are themselves functions, they can be used directly as
 * mark properties. For example, if the data associated with a label are dates,
 * a date format can be used as label text:
 *
 * <pre>    .text(DG.Format.date("%m/%d/%y"))</pre>
 *
 * And as with scales, if the format is used in multiple places, it can be
 * convenient to declare it as a global variable and then reference it from the
 * appropriate property functions. For example, if the data has a <tt>date</tt>
 * attribute, and <tt>format</tt> references a given date format:
 *
 * <pre>    .text(function(d) format(d.date))</pre>
 *
 * Similarly, to parse a string into a date:
 *
 * <pre>var date = format.parse("4/30/2010");</pre>
 *
 * Not all format implementations support parsing. See the implementing class
 * for details.
 *
 * @see DG.Format.date
 * @see DG.Format.number
 * @see DG.Format.time
 */
DG.Format = {};

/**
 * Formats the specified object, returning the string representation.
 *
 * @function
 * @name DG.Format.prototype.format
 * @param {object} x the object to format.
 * @returns {string} the formatted string.
 */

/**
 * Parses the specified string, returning the object representation.
 *
 * @function
 * @name DG.Format.prototype.parse
 * @param {string} x the string to parse.
 * @returns {object} the parsed object.
 */

/**
 * @private Given a string that may be used as part of a regular expression,
 * this methods returns an appropriately quoted version of the specified string,
 * with any special characters escaped.
 *
 * @param {string} s a string to quote.
 * @returns {string} the quoted string.
 */
DG.Format.re = function(s) {
  return s.replace(/[\\\^\$\*\+\?\[\]\(\)\.\{\}]/g, "\\$&");
};

/**
 * @private Optionally pads the specified string <i>s</i> so that it is at least
 * <i>n</i> characters long, using the padding character <i>c</i>.
 *
 * @param {string} c the padding character.
 * @param {number} n the minimum string length.
 * @param {string} s the string to pad.
 * @returns {string} the padded string.
 */
DG.Format.pad = function(c, n, s) {
  var m = n - String(s).length;
  return (m < 1) ? s : new Array(m + 1).join(c) + s;
};
/**
 * Constructs a new date format with the specified string pattern.
 *
 * @class The format string is in the same format expected by the
 * <tt>strftime</tt> function in C. The following conversion specifications are
 * supported:<ul>
 *
 * <li>%a - abbreviated weekday name.</li>
 * <li>%A - full weekday name.</li>
 * <li>%b - abbreviated month names.</li>
 * <li>%B - full month names.</li>
 * <li>%c - locale's appropriate date and time.</li>
 * <li>%C - century number.</li>
 * <li>%d - day of month [01,31] (zero padded).</li>
 * <li>%D - same as %m/%d/%y.</li>
 * <li>%e - day of month [ 1,31] (space padded).</li>
 * <li>%h - same as %b.</li>
 * <li>%H - hour (24-hour clock) [00,23] (zero padded).</li>
 * <li>%I - hour (12-hour clock) [01,12] (zero padded).</li>
 * <li>%m - month number [01,12] (zero padded).</li>
 * <li>%M - minute [0,59] (zero padded).</li>
 * <li>%n - newline character.</li>
 * <li>%p - locale's equivalent of a.m. or p.m.</li>
 * <li>%r - same as %I:%M:%S %p.</li>
 * <li>%R - same as %H:%M.</li>
 * <li>%S - second [00,61] (zero padded).</li>
 * <li>%t - tab character.</li>
 * <li>%T - same as %H:%M:%S.</li>
 * <li>%x - same as %m/%d/%y.</li>
 * <li>%X - same as %I:%M:%S %p.</li>
 * <li>%y - year with century [00,99] (zero padded).</li>
 * <li>%Y - year including century.</li>
 * <li>%% - %.</li>
 *
 * </ul>The following conversion specifications are currently <i>unsupported</i>
 * for formatting:<ul>
 *
 * <li>%j - day number [1,366].</li>
 * <li>%u - weekday number [1,7].</li>
 * <li>%U - week number [00,53].</li>
 * <li>%V - week number [01,53].</li>
 * <li>%w - weekday number [0,6].</li>
 * <li>%W - week number [00,53].</li>
 * <li>%Z - timezone name or abbreviation.</li>
 *
 * </ul>In addition, the following conversion specifications are currently
 * <i>unsupported</i> for parsing:<ul>
 *
 * <li>%a - day of week, either abbreviated or full name.</li>
 * <li>%A - same as %a.</li>
 * <li>%c - locale's appropriate date and time.</li>
 * <li>%C - century number.</li>
 * <li>%D - same as %m/%d/%y.</li>
 * <li>%I - hour (12-hour clock) [1,12].</li>
 * <li>%n - any white space.</li>
 * <li>%p - locale's equivalent of a.m. or p.m.</li>
 * <li>%r - same as %I:%M:%S %p.</li>
 * <li>%R - same as %H:%M.</li>
 * <li>%t - same as %n.</li>
 * <li>%T - same as %H:%M:%S.</li>
 * <li>%x - locale's equivalent to %m/%d/%y.</li>
 * <li>%X - locale's equivalent to %I:%M:%S %p.</li>
 *
 * </ul>
 *
 * @see <a
 * href="http://www.opengroup.org/onlinepubs/007908799/xsh/strftime.html">strftime</a>
 * documentation.
 * @see <a
 * href="http://www.opengroup.org/onlinepubs/007908799/xsh/strptime.html">strptime</a>
 * documentation.
 * @extends DG.Format
 * @param {string} pattern the format pattern.
 */
DG.Format.date = function(pattern) {
  var pad = DG.Format.pad;

  /** @private */
  function format(d) {
    return pattern.replace(/%[a-zA-Z0-9]/g, function(s) {
      var h, w;
      switch (s) {
        case '%a': return [
          "Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"
        ][d.getDay()];
        case '%A': return [
          "Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday",
          "Saturday"
        ][d.getDay()];
        case '%h':
        case '%b': return [
          "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep",
          "Oct", "Nov", "Dec"
        ][d.getMonth()];
        case '%B': return [
          "January", "February", "March", "April", "May", "June", "July",
          "August", "September", "October", "November", "December"
        ][d.getMonth()];
        case '%c': return d.toLocaleString();
        case '%C': return pad("0", 2, Math.floor(d.getFullYear() / 100) % 100);
        case '%d': return pad("0", 2, d.getDate());
        case '%x':
        case '%D': return pad("0", 2, d.getMonth() + 1)
            + "/" + pad("0", 2, d.getDate())
            + "/" + pad("0", 2, d.getFullYear() % 100);
        case '%e': return pad(" ", 2, d.getDate());
        case '%H': return pad("0", 2, d.getHours());
        case '%I': {
          h = d.getHours() % 12;
          return h ? pad("0", 2, h) : 12;
        }
        // TODO %j: day of year as a decimal number [001,366]
        case '%m': return pad("0", 2, d.getMonth() + 1);
        case '%M': return pad("0", 2, d.getMinutes());
        case '%n': return "\n";
        case '%p': return d.getHours() < 12 ? "AM" : "PM";
        case '%T':
        case '%X':
        case '%r': {
          h = d.getHours() % 12;
          return (h ? pad("0", 2, h) : 12)
              + ":" + pad("0", 2, d.getMinutes())
              + ":" + pad("0", 2, d.getSeconds())
              + " " + (d.getHours() < 12 ? "AM" : "PM");
        }
        case '%R': return pad("0", 2, d.getHours()) + ":" + pad("0", 2, d.getMinutes());
        case '%S': return pad("0", 2, d.getSeconds());
        case '%Q': return pad("0", 3, d.getMilliseconds());
        case '%t': return "\t";
        case '%u': {
          w = d.getDay();
          return w ? w : 1;
        }
        // TODO %U: week number (sunday first day) [00,53]
        // TODO %V: week number (monday first day) [01,53] ... with weirdness
        case '%w': return d.getDay();
        // TODO %W: week number (monday first day) [00,53] ... with weirdness
        case '%y': return pad("0", 2, d.getFullYear() % 100);
        case '%Y': return d.getFullYear();
        // TODO %Z: timezone name or abbreviation
        case '%%': return "%";
      }
      return s;
    });
  }

  /**
   * Converts a date to a string using the associated formatting pattern.
   *
   * @function
   * @name DG.Format.date.prototype.format
   * @param {Date} date a date to format.
   * @returns {string} the formatted date as a string.
   */
  format.format = format;

  /**
   * Parses a date from a string using the associated formatting pattern.
   *
   * @function
   * @name DG.Format.date.prototype.parse
   * @param {string} s the string to parse as a date.
   * @returns {Date} the parsed date.
   */
  format.parse = function(s) {
    var year = 1970, month = 0, date = 1, hour = 0, minute = 0, second = 0;
    var fields = [function() {}];

    /* Register callbacks for each field in the format pattern. */
    var re = DG.Format.re(pattern).replace(/%[a-zA-Z0-9]/g, function(s) {
      switch (s) {
        // TODO %a: day of week, either abbreviated or full name
        // TODO %A: same as %a
        case '%b': {
          fields.push(function(x) { month = {
            Jan: 0, Feb: 1, Mar: 2, Apr: 3, May: 4, Jun: 5, Jul: 6, Aug: 7,
            Sep: 8, Oct: 9, Nov: 10, Dec: 11
          }[x]; });
          return "([A-Za-z]+)";
        }
        case '%h':
        case '%B': {
          fields.push(function(x) { month = {
            January: 0, February: 1, March: 2, April: 3, May: 4, June: 5,
            July: 6, August: 7, September: 8, October: 9, November: 10,
            December: 11
          }[x]; });
          return "([A-Za-z]+)";
        }
        // TODO %c: locale's appropriate date and time
        // TODO %C: century number[0,99]
        case '%e':
        case '%d': {
          fields.push(function(x) { date = x; });
          return "([0-9]+)";
        }
        // TODO %D: same as %m/%d/%y
        case '%I':
        case '%H': {
          fields.push(function(x) { hour = x; });
          return "([0-9]+)";
        }
        // TODO %j: day number [1,366]
        case '%m': {
          fields.push(function(x) { month = x - 1; });
          return "([0-9]+)";
        }
        case '%M': {
          fields.push(function(x) { minute = x; });
          return "([0-9]+)";
        }
        // TODO %n: any white space
        // TODO %p: locale's equivalent of a.m. or p.m.
        case '%p': { // TODO this is a hack
          fields.push(function(x) {
            if (hour === 12) {
              if (x === "am") hour = 0;
            } else if (x === "pm") {
              hour = Number(hour) + 12;
            }
          });
          return "(am|pm)";
        }
        // TODO %r: %I:%M:%S %p
        // TODO %R: %H:%M
        case '%S': {
          fields.push(function(x) { second = x; });
          return "([0-9]+)";
        }
        // TODO %t: any white space
        // TODO %T: %H:%M:%S
        // TODO %U: week number [00,53]
        // TODO %w: weekday [0,6]
        // TODO %W: week number [00, 53]
        // TODO %x: locale date (%m/%d/%y)
        // TODO %X: locale time (%I:%M:%S %p)
        case '%y': {
          fields.push(function(x) {
            x = Number(x);
            year = x + (((0 <= x) && (x < 69)) ? 2000
                : (((x >= 69) && (x < 100) ? 1900 : 0)));
          });
          return "([0-9]+)";
        }
        case '%Y': {
          fields.push(function(x) { year = x; });
          return "([0-9]+)";
        }
        case '%%': {
          fields.push(function() {});
          return "%";
        }
      }
      return s;
    });

    var match = s.match(re);
    if (match) match.forEach(function(m, i) { fields[i](m); });
    return new Date(year, month, date, hour, minute, second);
  };

  return format;
};
/**
 * Returns a time format of the given type, either "short" or "long".
 *
 * @class Represents a time format, converting between a <tt>number</tt>
 * representing a duration in milliseconds, and a <tt>string</tt>. Two types of
 * time formats are supported: "short" and "long". The <i>short</i> format type
 * returns a string such as "3.3 days" or "12.1 minutes", while the <i>long</i>
 * format returns "13:04:12" or similar.
 *
 * @extends DG.Format
 * @param {string} type the type; "short" or "long".
 */
DG.Format.time = function(type) {
  var pad = DG.Format.pad;

  /*
   * MILLISECONDS = 1
   * SECONDS = 1e3
   * MINUTES = 6e4
   * HOURS = 36e5
   * DAYS = 864e5
   * WEEKS = 6048e5
   * MONTHS = 2592e6
   * YEARS = 31536e6
   */

  /** @private */
  function format(t) {
    function toInt(fl) {
      /* eslint no-bitwise: "off" */
      /* jshint ignore: start */
      return fl >> 0; // bit-shift zero places: converts to 32 bit int
      /* jshint ignore: end */
    }
    t = Number(t); // force conversion from Date
    switch (type) {
      case "short": {
        if (t >= 31536e6) {
          return (t / 31536e6).toFixed(1) + " years";
        } else if (t >= 6048e5) {
          return (t / 6048e5).toFixed(1) + " weeks";
        } else if (t >= 864e5) {
          return (t / 864e5).toFixed(1) + " days";
        } else if (t >= 36e5) {
          return (t / 36e5).toFixed(1) + " hours";
        } else if (t >= 6e4) {
          return (t / 6e4).toFixed(1) + " minutes";
        }
        return (t / 1e3).toFixed(1) + " seconds";
      }
      case "long": {
        var a = [],
            s = toInt((t % 6e4) / 1e3),
            m = toInt((t % 36e5) / 6e4);
        a.push(pad("0", 2, s));
        if (t >= 36e5) {
          var h = toInt((t % 864e5) / 36e5);
          a.push(pad("0", 2, m));
          if (t >= 864e5) {
            a.push(pad("0", 2, h));
            a.push(Math.floor(t / 864e5).toFixed());
          } else {
            a.push(h.toFixed());
          }
        } else {
          a.push(m.toFixed());
        }
        return a.reverse().join(":");
      }
    }
  }

  /**
   * Formats the specified time, returning the string representation.
   *
   * @function
   * @name DG.Format.time.prototype.format
   * @param {number} t the duration in milliseconds. May also be a <tt>Date</tt>.
   * @returns {string} the formatted string.
   */
  format.format = format;

  /**
   * Parses the specified string, returning the time in milliseconds.
   *
   * @function
   * @name DG.Format.time.prototype.parse
   * @param {string} s a formatted string.
   * @returns {number} the parsed duration in milliseconds.
   */
  format.parse = function(s) {
    var re, a, t, f, u;
    switch (type) {
      case "short": {
        re = /([0-9,.]+)\s*([a-z]+)/g;
        t = 0;
        a = re.exec(s);
        while (a) {
          f = parseFloat(a[0].replace(",", ""));
          u = 0;
          switch (a[2].toLowerCase()) {
            case "year": case "years": u = 31536e6; break;
            case "week": case "weeks": u = 6048e5; break;
            case "day": case "days": u = 864e5; break;
            case "hour": case "hours": u = 36e5; break;
            case "minute": case "minutes": u = 6e4; break;
            case "second": case "seconds": u = 1e3; break;
          }
          t += f * u;
          a = re.exec(s);
        }
        return t;
      }
      case "long": {
        a = s.replace(",", "").split(":").reverse();
        t = 0;
        if (a.length) t += parseFloat(a[0]) * 1e3;
        if (a.length > 1) t += parseFloat(a[1]) * 6e4;
        if (a.length > 2) t += parseFloat(a[2]) * 36e5;
        if (a.length > 3) t += parseFloat(a[3]) * 864e5;
        return t;
      }
    }
  };

  return format;
};
/**
 * Returns a default number format.
 *
 * @class Represents a number format, converting between a <tt>number</tt> and a
 * <tt>string</tt>. This class allows numbers to be formatted with variable
 * precision (both for the integral and fractional part of the number), optional
 * thousands grouping, and optional padding. The thousands (",") and decimal
 * (".") separator can be customized.
 *
 * @returns {DG.Format.number} a number format.
 */
DG.Format.number = function() {
  var mini = 0, // default minimum integer digits
      maxi = Infinity, // default maximum integer digits
      mins = 0, // mini, including group separators
      minf = 0, // default minimum fraction digits
      maxf = 0, // default maximum fraction digits
      maxk = 1, // 10^maxf
      padi = "0", // default integer pad
      padf = "0", // default fraction pad
      padg = true, // whether group separator affects integer padding
      decimal = ".", // default decimal separator
      group = ",", // default group separator
      np = "\u2212", // default negative prefix
      ns = ""; // default negative suffix

  /** @private */
  function format(x) {
    /* Round the fractional part, and split on decimal separator. */
    if (Infinity > maxf) x = Math.round(x * maxk) / maxk;
    var s = String(Math.abs(x)).split(".");

    /* Pad, truncate and group the integral part. */
    var i = s[0];
    if (i.length > maxi) i = i.substring(i.length - maxi);
    if (padg && (i.length < mini)) i = new Array(mini - i.length + 1).join(padi) + i;
    if (i.length > 3) i = i.replace(/\B(?=(?:\d{3})+(?!\d))/g, group);
    if (!padg && (i.length < mins)) i = new Array(mins - i.length + 1).join(padi) + i;
    s[0] = x < 0 ? np + i + ns : i;

    /* Pad the fractional part. */
    var f = s[1] || "";
    if (f.length < minf) s[1] = f + new Array(minf - f.length + 1).join(padf);

    return s.join(decimal);
  }

  /**
   * @function
   * @name DG.Format.number.prototype.format
   * @param {number} x
   * @returns {string}
   */
  format.format = format;

  /**
   * Parses the specified string as a number. Before parsing, leading and
   * trailing padding is removed. Group separators are also removed, and the
   * decimal separator is replaced with the standard point ("."). The integer
   * part is truncated per the maximum integer digits, and the fraction part is
   * rounded per the maximum fraction digits.
   *
   * @function
   * @name DG.Format.number.prototype.parse
   * @param {string} x the string to parse.
   * @returns {number} the parsed number.
   */
  format.parse = function(x) {
    var re = DG.Format.re;

    /* Remove leading and trailing padding. Split on the decimal separator. */
    var s = String(x)
        .replace(new RegExp("^(" + re(padi) + ")*"), "")
        .replace(new RegExp("(" + re(padf) + ")*$"), "")
        .split(decimal);

    /* Remove grouping and truncate the integral part. */
    var i = s[0].replace(new RegExp(re(group), "g"), "");
    if (i.length > maxi) i = i.substring(i.length - maxi);

    /* Round the fractional part. */
    var f = s[1] ? Number("0." + s[1]) : 0;
    if (Infinity > maxf) f = Math.round(f * maxk) / maxk;

    return Math.round(i) + f;
  };

  /**
   * Sets or gets the minimum and maximum number of integer digits. This
   * controls the number of decimal digits to display before the decimal
   * separator for the integral part of the number. If the number of digits is
   * smaller than the minimum, the digits are padded; if the number of digits is
   * larger, the digits are truncated, showing only the lower-order digits. The
   * default range is [0, Infinity].
   *
   * <p>If only one argument is specified to this method, this value is used as
   * both the minimum and maximum number. If no arguments are specified, a
   * two-element array is returned containing the minimum and the maximum.
   *
   * @function
   * @name DG.Format.number.prototype.integerDigits
   * @param {number} [min] the minimum integer digits.
   * @param {number} [max] the maximum integer digits.
   * @returns {DG.Format.number} <tt>this</tt>, or the current integer digits.
   */
  format.integerDigits = function(min, max) {
    if (arguments.length) {
      mini = Number(min);
      maxi = (arguments.length > 1) ? Number(max) : mini;
      mins = mini + Math.floor(mini / 3) * group.length;
      return this;
    }
    return [mini, maxi];
  };

  /**
   * Sets or gets the minimum and maximum number of fraction digits. The
   * controls the number of decimal digits to display after the decimal
   * separator for the fractional part of the number. If the number of digits is
   * smaller than the minimum, the digits are padded; if the number of digits is
   * larger, the fractional part is rounded, showing only the higher-order
   * digits. The default range is [0, 0].
   *
   * <p>If only one argument is specified to this method, this value is used as
   * both the minimum and maximum number. If no arguments are specified, a
   * two-element array is returned containing the minimum and the maximum.
   *
   * @function
   * @name DG.Format.number.prototype.fractionDigits
   * @param {number} [min] the minimum fraction digits.
   * @param {number} [max] the maximum fraction digits.
   * @returns {DG.Format.number} <tt>this</tt>, or the current fraction digits.
   */
  format.fractionDigits = function(min, max) {
    if (arguments.length) {
      minf = Number(min);
      maxf = (arguments.length > 1) ? Number(max) : minf;
      maxk = Math.pow(10, maxf);
      return this;
    }
    return [minf, maxf];
  };

  /**
   * Sets or gets the character used to pad the integer part. The integer pad is
   * used when the number of integer digits is smaller than the minimum. The
   * default pad character is "0" (zero).
   *
   * @param {string} [x] the new pad character.
   * @returns {DG.Format.number} <tt>this</tt> or the current pad character.
   */
  format.integerPad = function(x) {
    if (arguments.length) {
      padi = String(x);
      padg = /\d/.test(padi);
      return this;
    }
    return padi;
  };

  /**
   * Sets or gets the character used to pad the fration part. The fraction pad
   * is used when the number of fraction digits is smaller than the minimum. The
   * default pad character is "0" (zero).
   *
   * @param {string} [x] the new pad character.
   * @returns {DG.Format.number} <tt>this</tt> or the current pad character.
   */
  format.fractionPad = function(x) {
    if (arguments.length) {
      padf = String(x);
      return this;
    }
    return padf;
  };

  /**
   * Sets or gets the character used as the decimal point, separating the
   * integer and fraction parts of the number. The default decimal point is ".".
   *
   * @param {string} [x] the new decimal separator.
   * @returns {DG.Format.number} <tt>this</tt> or the current decimal separator.
   */
  format.decimal = function(x) {
    if (arguments.length) {
      decimal = String(x);
      return this;
    }
    return decimal;
  };

  /**
   * Sets or gets the character used as the group separator, grouping integer
   * digits by thousands. The default decimal point is ",". Grouping can be
   * disabled by using "" for the separator.
   *
   * @param {string} [x] the new group separator.
   * @returns {DG.Format.number} <tt>this</tt> or the current group separator.
   */
  format.group = function(x) {
    if (arguments.length) {
      group = x ? String(x) : "";
      mins = mini + Math.floor(mini / 3) * group.length;
      return this;
    }
    return group;
  };

  /**
   * Sets or gets the negative prefix and suffix. The default negative prefix is
   * "&minus;", and the default negative suffix is the empty string.
   *
   * @param {string} [x] the negative prefix.
   * @param {string} [y] the negative suffix.
   * @returns {DG.Format.number} <tt>this</tt> or the current negative format.
   */
  format.negativeAffix = function(x, y) {
    if (arguments.length) {
      np = String(x || "");
      ns = String(y || "");
      return this;
    }
    return [np, ns];
  };

  return format;
};

/* >>>>>>>>>> BEGIN source/components/calculator/calculator.js */
// ==========================================================================
//                            DG.Calculator
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('utilities/formatter');

/** @class

  This is a self-contained view that provides calculator functionality. It has
 a fixed height and width, awaiting only a top and left for its specification.

 @extends SC.View
 */
DG.Calculator = SC.View.extend( (function() // closure
/** @scope DG.Calculator.prototype */ {

  // Private closure variables
  var kButtonWidth = 30,
    kButtonHeight = 24,

    kMargin = 5,
    kTopMargin = 5,
    kGap = 2,

    kDoubleButtonWidth = 2 * kButtonWidth + kGap,

    kColumnWidth = kButtonWidth + kGap,
    kRowHeight = kButtonHeight + kGap,

    kColumnCount = 4,
    kRowCount = 5;

  return {  // return from closure

    classNames: ['dg-calculator'],
    backgroundColor: '#333333',

    _justEvaled: NO,  // If the expressions has just been evaluated, pressing
    // number key should wipe it out while arithmetic operation should insert.

    // The view format is the default number format, which after some earlier
    // modification of the Protovis code uses the Unicode minus sign for negative numbers.
    viewFormat: DG.Format.number().fractionDigits( 0, 9).group(""),

    // The export format uses the ASCII minus sign for negative numbers,
    // for use in log statements, etc.
    exportFormat: DG.Format.number().fractionDigits( 0, 9).group("").negativeAffix("-",""),
    
    /**
      Formats values for use by the Calculator view.
      Uses the Unicode minus sign for negative numbers.
     */
    formatForView: function( iValue) {
      if( typeof iValue !== 'number') return String( iValue);
      // DG.Format has been modified separately to use the Unicode minus sign,
      // so this will format negative numbers with the Unicode minus sign.
      return this.viewFormat( iValue);
    },

    /**
      Formats values for export (e.g. for logging).
      Uses the ASCII minus sign for negative numbers.
     */
    formatForExport: function( iValue) {
      if( typeof iValue !== 'number') return iValue;
      // The export format uses the ASCII minus sign for negative numbers.
      return this.exportFormat( iValue);
    },

    clearValue: function() {
      var calculator = this,
          currentValue = this.editView.get('value');
      // Calculator is a singleton view, so it's ok to access the view directly from the Command
      DG.UndoHistory.execute(DG.Command.create({
        name: 'calculator.calculate',
        undoString: 'DG.Undo.calculator.calculate',
        redoString: 'DG.Redo.calculator.calculate',
        log: "Calculator value cleared",
        _redoValue: null,
        executeNotification: {
          action: 'notify',
          resource: 'component',
          values: {
            operation: 'calculate',
            type: 'DG.Calculator'
          }
        },
        execute: function() {
          calculator.editView.set('value', this._redoValue || '');
          calculator._justEvaled = NO;
        },
        undo: function() {
          this._redoValue = calculator.editView.get('value');
          calculator.editView.set('value', currentValue);
          calculator._justEvaled = NO;
        }
      }));
    },
    insert: function( iToInsert ) {
      if( this._justEvaled && !isNaN( parseInt( iToInsert, 10 ) ) )
        this.clearValue();
      this.editView.replaceSelectionWithString( iToInsert );
      if( !this.editView.get('isFirstResponder'))
        this.editView.becomeFirstResponder();
      this._justEvaled = NO;
    },
    insertSymbol: function( aSymbol ) {
      // Typically parentheses or decimal point
      if( this._justEvaled )
        this.clearValue();
      this.insert( aSymbol );
    },
    calculate: function() {
      var tCurrent = this.editView.get( 'formulaExpression' ),
          tFormula = DG.Formula.create({ source: tCurrent }),
          tValue = '';
      
      // Don't try to evaluate error messages
      if( !SC.empty( tCurrent) && (tCurrent.charAt( 0) === '#'))
        return;
      
      try {
        tValue = tFormula.evaluateDirect();
      }
      catch( err ) {
        tValue = !SC.empty( err.message) ? err.message : String( err);

        // Put a '#' in front of errors so that they stand out and also so that
        // if the user presses return, we can detect that we shouldn't evaluate.
        tValue = '#' + tValue;
      }

      var newValue = this.formatForView( tValue),
          currentValue = this.editView.get('value'),
          calculator = this;
      // Calculator is a singleton view, so it's ok to access the view directly from the Command
      DG.UndoHistory.execute(DG.Command.create({
        name: 'calculator.calculate',
        undoString: 'DG.Undo.calculator.calculate',
        redoString: 'DG.Redo.calculator.calculate',
        log: "Calculation done: %@ = %@".fmt(tCurrent, this.formatForExport( tValue)),
        executeNotification: {
          action: 'notify',
          resource: 'component',
          values: {
            operation: 'calculate',
            type: 'DG.Calculator'
          }
        },
        execute: function() {
          calculator.editView.set('value', newValue);
          calculator._justEvaled = YES;
        },
        undo: function() {
          calculator.editView.set('value', currentValue);
          calculator._justEvaled = NO;
        }
      }));
    },

    init: function() {
      arguments.callee.base.apply(this,arguments);

      this.setupSubViews();
    },

    /**
     * All buttons and the edit view are setup here.
     */
    setupSubViews: function() {
      var this_ = this;

      // The two views that require special treatment are the editView (because it's not a button)
      // and the equals button (because it is bigger than the others).
      this.editView = DG.FormulaTextEditView.create( {
        layout: { top: 5, left: 5, right: 5, height: 20 },
        value: '',
        continuouslyUpdatesValue: false,
        borderStyle: SC.BORDER_BEZEL,
        keyDown: function( evt) {
          if( this_.handleKeyDown( evt))
            return arguments.callee.base.apply(this,arguments);
          else
            return true;  // prevent further handling
        }
      } );
      this.appendChild( this.editView );

      this.set('defaultFirstResponder', this.editView);

      this.equals = SC.ButtonView.create( {
        layout: { bottom: kMargin, left: kMargin + 2 * kColumnWidth,
                  width: kDoubleButtonWidth, height: kButtonHeight },
        title: '=',
        titleMinWidth: 0
      } );
      this.appendChild( this.equals );

      // We assign equal view its action here because then we don't require reference to globals
      this.equals.action = function() {
        this_.calculate();
      };

      // Fix our width and height in terms of the number of rows and columns and the
      // size of the buttons.
      var kTop = kTopMargin + kMargin + this.editView.layout.height;
      this.set( 'layout', { top: 3, left: 5,
          width: 1.5 * kGap + kColumnCount * kColumnWidth,
          height: kTop + kRowCount * kRowHeight + kMargin*3 }
      );

      // All but two child views we can lay out automatically. We only need to provide
      // a title and an action.
      // Note that we are using a "deprecated" form of installing actions in button views.
      // But it is clearly better for our purposes than separate action/target recommended
      // by SproutCore.
      var tParams = [
        [ 'C', function() {
          this_.clearValue();
        } ],
        [ '(', function() {
          this_.insertSymbol( '(' );
        } ],
        [ ')', function() {
          this_.insertSymbol( ')' );
        } ],
        [ '/', function() {
          this_.insert( ' / ' );
        } ],
        [ '7', function() {
          this_.insert( '7' );
        } ],
        [ '8', function() {
          this_.insert( '8' );
        } ],
        [ '9', function() {
          this_.insert( '9' );
        } ],
        [ 'X', function() {
          this_.insert( ' * ' );
        } ],
        [ '4', function() {
          this_.insert( '4' );
        } ],
        [ '5', function() {
          this_.insert( '5' );
        } ],
        [ '6', function() {
          this_.insert( '6' );
        } ],
        [ DG.UNICODE.MINUS_SIGN, function() {
          this_.insert(' ' + DG.UNICODE.MINUS_SIGN + ' ');
        } ],
        [ '1', function() {
          this_.insert( '1' );
        } ],
        [ '2', function() {
          this_.insert( '2' );
        } ],
        [ '3', function() {
          this_.insert( '3' );
        } ],
        [ '+', function() {
          this_.insert( ' + ' );
        } ],
        [ '0', function() {
          this_.insert( '0' );
        } ],
        [ '.', function() {
          this_.insertSymbol( '.' );
        } ]
      ];
      var tCounter = 0,
        kNumRows = 5;
      tParams.forEach( function( aParam ) {
        var tRow = Math.floor( tCounter / kColumnCount );
        var tColumn = tCounter % kColumnCount;
        var tButton = SC.ButtonView.create( {
          layout: { bottom: kMargin + (kNumRows - tRow - 1) * kRowHeight,
            left: kMargin + tColumn * kColumnWidth,
            width: kButtonWidth, height: kButtonHeight
          },
          title: aParam[0],
          action: aParam[1],
          titleMinWidth: 0
        } );
        this_.appendChild( tButton );
        tCounter++;
      } );
    },
    
    handleKeyDown: function( evt ) {
      // Weird bug: It is possible to get here after closing the calculator and then switching
      // to another component with the world not looking the way we expect. If so, just bail.
      if( !this ) return NO;
      if( (evt.which === SC.Event.KEY_RETURN) && !evt.isIMEInput) {
        // Some browsers send both keydown & keypress for the RETURN key, and SproutCore
        // forwards both to this handler, so we have to make sure we only handle one.
        // Since other browsers only send keydown and not keypress, we only respond to keydown.
        if( evt.type === 'keydown')
          this.calculate();
      }
      else if( evt.which === SC.Event.KEY_ESC) // <esc>
        this.clearValue();
      else {
        var tChar = String.fromCharCode( evt.which );
        if( this._justEvaled && ("/*-+\t".indexOf( tChar ) === -1) ) {
          this.clearValue();
        }
        else if( tChar === '=' ) {
          this.calculate();
          // We calculated, so we don't want sc_super to do its thing
          return false;
        }
        else
          this._justEvaled = NO;
      }
      return true;
    },

    /**
     * We've animated to our initial position and along the way lost editing focus.
     */
    didReachInitialPosition: function() {
      this.editView.beginEditing();
    }

  };  // end return from closure
}()) );  // end closure

/* >>>>>>>>>> BEGIN source/react/dg-react.js */
/* global createReactClass, createReactFactory, ReactDOM, SlateEditor */

// this would be defined once in CODAP
DG.React = {
  createClass: function (def, highOrderComponentList) {
    var finalClass = createReactClass(def);
    if (highOrderComponentList) {
      highOrderComponentList.forEach(function (highOrderComponent) {
        finalClass = highOrderComponent(finalClass);
      });
    }
    return finalClass;
  },

  createComponent: function (def, highOrderComponentList) {
    return createReactFactory(DG.React.createClass(def, highOrderComponentList));
  },

  // toggles the component to render in the container node
  toggleRender: function (containerNode, component) {
    if (containerNode.children.length > 0) {
      ReactDOM.unmountComponentAtNode(containerNode);
    }
    else if (component) {
      ReactDOM.render(component, containerNode);
    }
  },

  // wait for React to become available when the CFM loads
  ready: function (callback) {
    if (window.React && window.ReactDOM) {
      callback();
    }
    else {
      setTimeout(function () { DG.React.ready(callback); }, 250);
    }
  }
};

DG.React.SlateContainer = createReactFactory(SlateEditor.SlateContainer);
DG.React.SlateEditor = createReactFactory(SlateEditor.SlateEditor);
DG.React.SlateToolbar = createReactFactory(SlateEditor.SlateToolbar);

// these augment custom components with common behaviors
DG.React.HighOrderComponents = {
  _render: function (componentInstance, childComponentClass, highOrderProps) {
    var props = Object.assign({}, componentInstance.props, componentInstance.state, (highOrderProps || {}));
    return createReactFactory(childComponentClass)(props);
  },

  UnmountOnOutsideClick: function (childComponentClass) {
    return createReactClass({
      componentDidMount: function () {
        window.addEventListener('mousedown', this.checkForToggle, true);
        window.addEventListener('touchstart', this.checkForToggle, true);
      },

      componentWillUnmount: function () {
        window.removeEventListener('mousedown', this.checkForToggle, true);
        window.removeEventListener('touchstart', this.checkForToggle, true);
      },

      checkForToggle: function (e) {
        // eslint-disable-next-line react/no-find-dom-node
        var containerNode = ReactDOM.findDOMNode(this).parentNode,
            clickedNode = e.target;

        // check if clicked node is within the rendered child container
        while (clickedNode && (clickedNode !== containerNode)) {
          clickedNode = clickedNode.parentNode;
        }

        // the clicked node was outside the child container so unmount it
        if (!clickedNode) {
          this.unmount();
          e.preventDefault();
          e.stopPropagation();
        }
      },

      unmount: function () {
        // eslint-disable-next-line react/no-find-dom-node
        DG.React.toggleRender(ReactDOM.findDOMNode(this).parentNode);
      },

      render: function () {
        return DG.React.HighOrderComponents._render(this, childComponentClass, {unmount: this.unmount});
      }
    });
  },

  UnmountOnEscapeKey: function (childComponentClass) {
    return createReactClass({
      componentDidMount: function () {
        window.addEventListener('keydown', this.checkForEscape, true);
      },

      componentWillUnmount: function () {
        window.removeEventListener('keydown', this.checkForEscape, true);
      },

      checkForEscape: function (e) {
        if (e.keyCode === 27) {
          this.unmount();
          e.preventDefault();
          e.stopPropagation();
        }
      },

      unmount: function () {
        // eslint-disable-next-line react/no-find-dom-node
        DG.React.toggleRender(ReactDOM.findDOMNode(this).parentNode);
      },

      render: function () {
        return DG.React.HighOrderComponents._render(this, childComponentClass, {unmount: this.unmount});
      }
    });
  }
};

DG.React.Components = {};
/* >>>>>>>>>> BEGIN source/components/case_card/attribute_name_cell.js */
// sc_require('react/dg-react');
/* global ReactDOMFactories */

DG.React.ready(function () {
  var
      img = ReactDOMFactories.img,
      div = ReactDOMFactories.div,
      td = ReactDOMFactories.td;

  DG.React.AttributeNameCell = DG.React.createComponent(
      (function () {

        return {
          cellRef: null,
          cellWidth: null,
          moveDirection: '',

          componentDidMount: function () {
            this.componentDidRender();
          },

          componentDidUpdate: function () {
            this.componentDidRender();
          },

          componentDidRender: function () {
            if (this.cellRef && this.props.onColumnWidthChanged) {
              var bounds = this.cellRef.getBoundingClientRect();
              if (bounds.width !== this.cellWidth) {
                this.cellWidth = bounds.width;
                this.props.onColumnWidthChanged(this.cellWidth);
              }
            }
          },

          showDragTip: function (iShow) {
            if (iShow && !this.tipIsShowing) {
              var tRect = this.cellRef.getBoundingClientRect(),
                  tData = this.props.dragStatus.dragObject.data,
                  tSourceKeyAttributeName = tData.attribute.get('name'),
                  tSourceCollectionName = tData.collection.get('name'),
                  tSourceContextName = tData.context.get('name'),
                  tDestKeyAttribute = this.props.attribute,
                  tDestCollectionName = tDestKeyAttribute.getPath('collection.name'),
                  tDestContextName = tDestKeyAttribute.getPath('collection.dataSet.dataContextRecord.name'),
                  tDestKeyAttributeName = tDestKeyAttribute.get('name'),
                  tTip = "DG.Collection.joinTip".loc(tSourceCollectionName,
                      tSourceContextName, tDestCollectionName, tDestContextName,
                      tSourceKeyAttributeName, tDestKeyAttributeName);
              var tTipView = DG.mainPage.getPath('mainPane.tipView');
              tTipView.invokeLater(function () {
                tTipView.show(
                    {x: tRect.left, y: tRect.top + tRect.height}, tTip);
              }, 10);
              this.tipIsShowing = true;
            } else if (!iShow && this.tipIsShowing) {
              DG.mainPage.getPath('mainPane.tipView').hide();
              this.tipIsShowing = false;
            }
          },

          render: function () {
            var this_ = this;

            function assignCellRef(iElement) {
              this_.cellRef = iElement;
            }

            function dragLocation() {
              var tResult = '';
              this_.moveDirection = '';
              if (this_.props.dragStatus && this_.props.dragStatus.event && this_.cellRef) {
                var tEvent = this_.props.dragStatus.event,
                    tX = tEvent.clientX,
                    tY = tEvent.clientY,
                    tRect = this_.cellRef.getBoundingClientRect(),
                    tDragType = this_.props.dragStatus.dragType;
                if (tX > tRect.x && tX < tRect.x + tRect.width && tY > tRect.y &&
                    tY < tRect.y + tRect.height) {
                  switch (tDragType) {
                    case 'ownContext':
                      if (tY < tRect.y + tRect.height / 2) {
                        this_.moveDirection = 'up';
                        tResult = 'attr-cell-upper';
                      } else if (tY < tRect.y + tRect.height) {
                        this_.moveDirection = 'down';
                        tResult = 'attr-cell-lower';
                      }
                      break;
                    case 'foreignContext':
                      this_.moveDirection = 'join';
                      tResult = 'attr-cell-all';
                  }
                }
              }
              return tResult;
            }

            function handleDropIfAny() {
              if (this_.props.dragStatus &&
                  this_.props.dragStatus.op === SC.DRAG_LINK &&
                  this_.props.dropCallback &&
                  this_.moveDirection !== '') {
                this_.props.dropCallback(this_.moveDirection);
              }
            }

            function clickHandler(iCallback) {
              SC.run(function () {
                this_.dropdown.hide();
                iCallback();
              });
            }

            function renameAttributeClickHandler() {
              clickHandler(this_.props.onBeginRenameAttribute);
            }

            function editAttributeClickHandler() {
              clickHandler(this_.props.editAttributeCallback);
            }

            function editFormulaClickHandler() {
              clickHandler(this_.props.editFormulaCallback);
            }

            function hideAttributeClickHandler() {
              clickHandler(this_.props.hideAttributeCallback);
            }

            function deleteAttributeFormulaClickHandler() {
              clickHandler(this_.props.deleteAttributeFormulaCallback);
            }

            function recoverAttributeFormulaClickHandler() {
              clickHandler(this_.props.recoverAttributeFormulaCallback);
            }

            function deleteAttributeClickHandler() {
              clickHandler(this_.props.deleteAttributeCallback);
            }

            function rerandomizeClickHandler() {
              clickHandler(this_.props.rerandomizeCallback);
            }

            function newAttributeClickHandler() {
              if (this_.props.newAttributeCallback)
                this_.props.newAttributeCallback();
            }

            var renderStaticContents = function () {
              var hasFormula = this.props.attribute.get('formula') !== '',
                  hasDeletedFormula = this.props.attribute.hasDeletedFormula(),
                  tDeleteFormulaLabel = hasDeletedFormula ? 'DG.TableController.headerMenuItems.recoverFormula'.loc() :
                      'DG.TableController.headerMenuItems.deleteFormula'.loc(),
                  tMenuItems = [
                    {
                      label: 'DG.TableController.headerMenuItems.renameAttribute'.loc(),
                      clickHandler: renameAttributeClickHandler
                    },
                    {
                      label: 'DG.TableController.headerMenuItems.editAttribute'.loc(),
                      clickHandler: editAttributeClickHandler
                    },
                    {
                      label: 'DG.TableController.headerMenuItems.editFormula'.loc(),
                      disabled: !this.props.attributeIsEditableCallback(),
                      clickHandler: editFormulaClickHandler
                    },
                    {
                      label: tDeleteFormulaLabel,
                      disabled: !this.props.attributeIsEditableCallback() || (!hasFormula && !hasDeletedFormula),
                      clickHandler: hasDeletedFormula ? recoverAttributeFormulaClickHandler :
                          deleteAttributeFormulaClickHandler
                    },
                    {
                      label: 'DG.TableController.headerMenuItems.randomizeAttribute'.loc(),
                      disabled: !this.props.attributeCanBeRandomizedCallback(),
                      clickHandler: rerandomizeClickHandler
                    },
                    {
                      label: 'DG.TableController.headerMenuItems.hideAttribute'.loc(),
                      disabled: !this.props.attributeCanBeHiddenCallback(),
                      clickHandler: hideAttributeClickHandler
                    },
                    {
                      label: 'DG.TableController.headerMenuItems.deleteAttribute'.loc(),
                      disabled: false,
                      clickHandler: deleteAttributeClickHandler
                    }
                  ].map(function (iItem, iIndex) {
                    return DG.React.Components.DropdownItem({
                          disabled: iItem.disabled,
                          key: 'item-' + iIndex,
                          clickHandler: iItem.clickHandler
                        },
                        iItem.label);
                  }),
                  tNameDiv = div({
                    className: 'react-name-cell'
                  }, this.props.content);
              return DG.React.Components.Dropdown({
                trigger: tNameDiv,
                menuItems: tMenuItems,
                ref: function (iDropdown) {
                  this.dropdown = iDropdown;
                }.bind(this),
                onRefCallback: assignCellRef
              });
            }.bind(this);

            handleDropIfAny();

            var tClassName = 'attr-cell ' + dragLocation(),
                tNewAttrDisabledClass = this.props.newAttributeCallback ? '' : ' disabled',
                tNewAttrButton = this.props.showNewAttrButton &&
                    img({
                      src: '../../../../static/dg/de/cert/source/resources/images/add_circle_grey_72x72.png',
                      className: 'dg-floating-plus dg-wants-touch' + tNewAttrDisabledClass,
                      title: 'DG.TableController.newAttributeTooltip'.loc(),
                      onClick: newAttributeClickHandler
                    }),
                tColumnWidth = this.props.columnWidthPct != null
                    ? (Math.round(this.props.columnWidthPct * 1000) / 10) + '%'
                    : undefined,
                tContents = this.props.isEditing
                    ? DG.React.SimpleEdit({
                      className: 'react-data-card-attr-name-input',
                      value: this.props.attribute.get('name'),
                      onCompleteEdit: this.props.onEndRenameAttribute
                    })
                    : renderStaticContents();
            this.showDragTip(this.moveDirection === 'join');
            return td({
              className: tClassName,
              ref: assignCellRef,
              style: {width: tColumnWidth}
            }, tNewAttrButton, tContents);
          }
        };
      }()), []);

});

/* >>>>>>>>>> BEGIN source/components/case_card/attribute_summary.js */
/* global ReactDOMFactories */
// sc_require('react/dg-react');

DG.React.ready(function () {
  var
      span = ReactDOMFactories.span;

  DG.React.Components.AttributeSummary = DG.React.createComponent(
      (function () {

        /**
         * Props are
         *    cases: {[DG.Case]}  The cases for which we'll provide a summary
         *    attrID: {Number}    This is the attribute whose values we'll summarize
         *    unit: {String}
         */

        return {

          render: function () {
            var tAttribute = this.props.attr,
                tAttrID = tAttribute.get('id'),
                tType = tAttribute.get('type'),
                tIsNumericType = tType === 'numeric',
                tAllNumeric = true,
                tMin = Number.MAX_VALUE,
                tMax = -Number.MAX_VALUE,
                tUniqueValues = {},
                tNumUniqueValues,
                tSummary;
            this.props.cases.forEach(function (iCase) {
              var tValue = tIsNumericType ? iCase.getForcedNumericValue(tAttrID) : iCase.getValue(tAttrID);
              if( !SC.empty(tValue)) {
                if (!tUniqueValues[tValue])
                  tUniqueValues[tValue] = 0;
                tUniqueValues[tValue]++;
                if (tValue !== '' && isFinite(tValue)) {
                  tMin = Math.min(tMin, tValue);
                  tMax = Math.max(tMax, tValue);
                } else if (tValue !== '') {
                  tAllNumeric = false;
                }
              }
            });
            if( tAllNumeric) {
              tMin = DG.MathUtilities.formatNumber(tMin, 2);
              tMax = DG.MathUtilities.formatNumber(tMax, 2);
            }
            tNumUniqueValues = Object.keys(tUniqueValues).length;
            if( tNumUniqueValues > 2 || tAllNumeric) {
              tSummary = (tMin === "Infinity") ? '' :
                  tAllNumeric ?
                  (tMin === tMax ? (tMin + this.props.unit) :
                      'DG.CaseCard.summaryRange'.loc(tMin, tMax, this.props.unit)) :
                  'DG.CaseCard.summaryValues'.loc(tNumUniqueValues);
              return span({className: 'react-data-card-attribute-summary'}, tSummary);
            }
            else {
              var tUniqueValue = Object.keys( tUniqueValues).filter( function(iKey) {
                return iKey !== 'undefined';
              }).join(', ');
              if(tUniqueValue==='undefined')
                tUniqueValue = '';
              return span({
                className: 'react-data-card-attribute-summary'
              }, tUniqueValue);
            }
          }
        };
      }()), []);

});

/* >>>>>>>>>> BEGIN source/models/model_store.js */
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
/**
 * ModelStore is a bare bones storage service. It is intended to
 * replace SC.Store in CODAP. It provides a mechanism for constructing
 * object identifiers and supporting access to CODAP model objects
 * by id.
 *
 * Created by jsandoe on 10/17/14.
 */
DG.ModelStore = SC.Object.extend(
/** @scope DG.ModelStore.prototype */ {
    _idCount: 0,
    /*
     * Right now, CODAP can manage one document per instance and all managed
     * objects are owned by the document. Therefore there is one store per
     * document. It may be that there is more than one document per instance.
     * In that circumstance, we may have multiple documents managed within the
     * same store and this class will need to change.
     */
    _store: null,
    init: function() {
      arguments.callee.base.apply(this,arguments);
      this._store = [];
    },
    /**
     * register: registers the object in the global store.
     *
     * If there is an id or guid property, and tries to use this as the identifier.
     * If not, gets the next identifier for the type.
     */
    register: function (iRecordType, iObj) {
      var tNewID= this.getIDForNewRecord(iObj);
      iObj.id = tNewID;
      DG.assert(!SC.none(tNewID),
        'Check if found or created valid new ID for record of type %@'
          .fmt(iRecordType));
      DG.assert(SC.none(this._store[tNewID]),
        'Check if store contains new object ID of type %@'.fmt(iRecordType));
      this._store[tNewID] = iObj;
      return tNewID;
    },

    /**
     * unregister: removes the object from the global store.
     * @param {number} id
     */
    deregister: function (id) {
      delete this._store[id];
    },

    /**
     * find: locates an object in the global store.
     * @param {string or object} type: for compatibility with older usage. Optional.
     * @param {number} id
     * @returns {object}
     */
    find: function (type, id) {
      // handle omission of type.
      if (typeof type === 'number' && typeof id === 'undefined') {
        id = type;
      }
      return this._store[id];
    },

    /**
     * Computes a record id.
     *
     * If there is an id or guid property, and tries to use this as the identifier.
     * Verifies that id's do not correspond with any registered records.
     * If not, gets the next identifier in sequence.
     */
    getIDForNewRecord: function (tObj) {
      var tNewID;
      if (!SC.empty(tObj.guid)) {
        tNewID = tObj.guid;
      } else if (!SC.empty(tObj.id)) {
        tNewID = tObj.id;
      }
      if (!SC.empty(tNewID) && !SC.empty(this._store[tNewID])) {
        DG.logWarn('Store may be corrupt: found id, ' + tNewID + ', in new object and store.');
        DG.logWarn("Creating new object, but bad references may be present.");
      }
      if (SC.empty(tNewID)) {
        while (SC.empty(tNewID) || this._store[tNewID]) {
          tNewID = ++this._idCount;
        }
      }
      return tNewID;
    },
    _getDataSource: function () { return this;},
    /**
     Utility function for converting from a class name (record type string),
     e.g. "DG.Document", to a record type (e.g. DG.Document).

     @param {String} iRecordTypeStr  String representing the name of the record class (e.g. "DG.Document")
     @returns {Class}                Object representing the record class (e.g. DG.Document)
     */
    recordTypeFromString: function (iRecordTypeStr) {
      var dotIndex = iRecordTypeStr.indexOf('.'),
        classNameStartPos = dotIndex >= 0 ? dotIndex + 1 : 0,
        className = iRecordTypeStr.substr(classNameStartPos);
      return DG[className];
    },
    destroyAllRecordsOfType: function (type, exceptionKeys) {
      var removedKeys = [];
      if (SC.empty(exceptionKeys)) {
        exceptionKeys = [];
      }
      this._store.forEach(function (obj) {
        var id = obj.id;
        if (obj.get('recordType') === type && !exceptionKeys.contains(id)) {
          removedKeys.push(id);
          obj.destroy();
          if (this._store[id]) {
            this.deregister(id);
          }
        }
      }.bind(this));
      return removedKeys;
    },
    /*
     * If x is an ID look it up. If it is an object, return it as is.
     */
    resolve: function(x) {
      var obj;
      if (typeof x === 'object') {
        return x;
      }
      if (typeof x === 'number') {
        obj = this.find(null, x);
        if (SC.empty(obj)) {
          DG.logError('Could not resolve reference: ' + x);
          return x;
        }
        return obj;
      }
    },
    commitRecords: function () { /* No-op */},
    flush: function () { /* No-op */}
});


/* >>>>>>>>>> BEGIN source/models/base_model.js */
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
/**
 * Created by jsandoe on 10/29/14.
 */
/** @class
 *
 * The base class for "managed objects".
 * Here, "managed objects" means they are model layer objects that are registered
 * with the ModelStore and are a constituent part of CODAP document. Their state
 * is captured entirely by a document save operation and they can be restored
 * entirely by a document restore operation.
 *
 * @extends SC.Object
 */
DG.BaseModel = SC.Object.extend(
  /** @scope DG.BaseModel.prototype */ {
    recordType: function() {
      // Record type should be the constructor function
      return this.constructor;
    }.property().cacheable(),

    recordTypeString: function() {
      return this.toString().replace(/:.*/, '');
    }.property().cacheable(),

    init: function () {
      arguments.callee.base.apply(this,arguments);
      // DG.store can be missing in test scenario
      if (!SC.empty(DG.store)) {
        DG.store.register(this.recordType(), this);
      }
      this.verify();
    },

    destroy: function () {
      DG.store.deregister(this.id);
      arguments.callee.base.apply(this,arguments);
    },

    /*
       Provide an abstract reference to this object.
     */
    toLink: function() {
      var recordTypeString = this.get('recordTypeString');
      return { type: recordTypeString, id: this.get('id') };
    },
    /**
     Update any properties that need to be updated pre-archive, e.g. layout.

     In general when overriding, call arguments.callee.base.apply(this,arguments), and then do your own thing.

     @function
     */
    willSaveRecord: function() {
    },

    /**
     Restore any properties that need to be updated post-archive, e.g. layout.

     */
    didLoadRecord: function() {
    },

    /*
     * Allows for verification of the initial construction of an object.
     * Verifiers should log to the console, in the case of missing mandatory
     * properties or inconsistencies.
     */
    verify: function () { }
  });

/* >>>>>>>>>> BEGIN source/models/attribute_model.js */
// ==========================================================================
//                            DG.Attribute
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('models/model_store');
sc_require('models/base_model');

/* global Set:true */


/** @class
 *
 * Describes the named constituent data values of a case. An attribute may be
 * 'nominal' or 'numeric', meaning the data value will either be interpreted as
 * string valued or numeric. An attribute may be a formula, meaning that the
 * attribute's corresponding data value would be computed.
 * An attribute may be editable or not. Some properties of attributes affect
 * how the corresponding values are displayed. For example, 'precision' affects
 * the formatting of numeric attributes, and 'categoryMap' affects the color's used
 * when the attribute is displayed in a graph legend.
 *
 * @extends SC.BaseModel
 */
DG.Attribute = DG.BaseModel.extend(
    /** @scope DG.Attribute.prototype */ {

      /**
       * The name of the attribute
       * @property {String}
       */
      name: '',

      /**
       * The displayable name of the attribute
       */
      _title: null,
      title: function (k, v) {
        if (!SC.none(v)) {
          this._title = v;
        }
        return this._title || this.get('name');
      }.property(),

      /**
       * The formula for the attribute
       * @property {String}
       */
      formula: '',

      /**
       * Recently formula preserved for later recovery
       * @property {String}
       */
      deletedFormula: '',

      /**
       * The map of attribute and category color values, for the attribute.
       * For special color keys and values, see:
       *   DG.ColorUtilities.getAttributeColorFromColorMap(),
       *   DG.ColorUtilities.getStrokeColorFromColorMap(),
       *   DG.ColorUtilities.getCategoryColorFromColorMap(),
       *   DG.ColorUtilities.simpleColorNames()
       * Maintains an array that specifies the order of iteration through the categories
       * @property {Object}
       */
      _categoryMap: null,
      categoryMap: function(iKey, iValue) {
        if( !SC.none( iValue)) {
          this._categoryMap = iValue;
        }
        if(SC.none( this._categoryMap) || !SC.isArray( this._categoryMap.__order) ||
              this._categoryMap.__order.length === 0 ){
          this.updateCategoryMap();
          // Default order is alphameric
          this._categoryMap.__order.sort( function( a, b) {
            if( DG.isNumeric(a) && DG.isNumeric(b))
              return a - b;
            else return a > b;
          });
        }
        return this._categoryMap;
      }.property(),

      /**
       * If false, empty categories will be displayed in categorical plots and legends
       * @property{Boolean}
       */
      blockDisplayOfEmptyCategories: true,

      /**
       * A description of/comment for the attribute
       * @property {String}
       */
      description: '',

      /**
       * Type of the attribute: 'numeric' or 'nominal'
       */
      type: null,

      /**
       * Globally unique id supporting collaboration.
       * @property {String}
       */
      cid: null,

      /**
       * A relational link back to the parent collection.
       * @property {DG.CollectionRecord}
       */
      collection: null,

      /**
       * Number of decimal places to use for display.
       * Applicable only to numeric values.
       * @property {Number}
       */
      precision: 2,

      /**
       * Currently the only significance of this string property is that it
       * shows in parentheses next to attribute names in case table column
       * headers and graph axis labels.
       * @property{String}
       */
      unit: null,

      /**
       * True if the attribute is user-editable, false otherwise.
       * By default user-created attributes are editable as well as
       * any game-created attributes marked as such.
       * @property {Boolean}
       */
      editable: true,

      /**
       * True if the attribute is hidden from the user, false otherwise.
       * By default attributes are visible.
       * @property {Boolean}
       */
      hidden: false,

      /**
       * True if the attribute is renameable, false otherwise.
       * @property {Boolean}
       */
      renameable: true,

      /**
       * True if the attribute is user-deletable, false otherwise.
       *
       * @property {Boolean}
       */
      deleteable: true,

      /**
       @private
       The DG.Formula for evaluation.
       @property   {DG.Formula}
       */
      _dgFormula: null,

      /**
       @private
       Cached values and validFlags.
       @property   {Object.<string, {isValid: boolean, value: any}>}
       */
      _cachedValues: null,

      /**
       Initialization function.
       */
      init: function () {
        arguments.callee.base.apply(this,arguments);

        // Handle formula passed in as property at creation
        var formulaSource = this.get('formula');
        if (!SC.empty(formulaSource) && !this._dgFormula) {
          this.createDGFormula();
          this._dgFormula.set('source', formulaSource);
        }
        if (typeof this.collection === 'number') {
          this.collection = DG.store.find(DG.Attribute, this.collection);
        }

        this._cachedValues = {};
      },

      verify: function () {
        if (SC.empty(this.collection)) {
          DG.logWarn('Unattached attribute: ' + this.id);
        }
        if (typeof this.collection === 'number') {
          DG.logWarn('Unresolved reference to collection id, ' + this.collection +
              ', in attribute: ' + this.id);
        }
        if (!(this.collection.recordType
                && this.collection.recordType() === DG.Collection)) {
          DG.logWarn('Unexpected collection RecordType: '
              + this.collection.recordTypeString());
        }
      },

      /**
       Destruction function.
       */
      destroy: function () {
        var attrID = this.get('id');

        if (!SC.none(attrID)) {
          delete DG.Attribute.idMap[attrID];
        }

        if (this.collection) {
          this.collection.attrs.removeObject(this);
          // remove from data set
          this.collection.dataSet.deleteAttribute(this);
        }

        if (this._dgFormula)
          this.destroyDGFormula();
        arguments.callee.base.apply(this,arguments);
      },

      /**
       * Return object with copies of all properties that could be transferred to another attribute
       * @return {{}}
       */
      getTransferableProperties: function() {
        return {
          name: this.get('name'),
          title: this.get('title'),
          formula: this.get('formula'),
          deletedFormula: this.get('deletedFormula'),
          categoryMap: JSON.parse(JSON.stringify( this.get('categoryMap'))),
          blockDisplayOfEmptyCategories: this.get('blockDisplayOfEmptyCategories'),
          description: this.get('description'),
          type: this.get('type'),
          precision: this.get('precision'),
          unit: this.get('unit')
          // The rest of the properties shouldn't be transferred, at least in the join situation
          // editable: this.get('editable'),
          // hidden: this.get('hidden'),
          // renameable: this.get('renameable'),
          // deleteable: this.get('deleteable'),
        };
      },

      /**
       * Iterate through the categories in the order maintained in the categoryMap
       *
       * @param iFunc has signature String, Color, Integer
       */
      forEachCategory: function( iFunc) {
        var tCategories = this.get('categoryMap');
        DG.assert(!SC.none( tCategories) && SC.isArray( tCategories.__order));
        tCategories.__order.forEach( function( iCategory, iIndex) {
          var tColor = tCategories[iCategory];
          tColor = tColor && tColor.colorString ? tColor.colorString : tColor;
          iFunc( iCategory, tColor, iIndex);
        });
      },

      /**
       Utility function for creating the DG.Formula when necessary
       and hooking up the necessary observers.
       */
      createDGFormula: function () {
        var context = DG.CollectionFormulaContext.create({
          ownerSpec: {
            type: DG.DEP_TYPE_ATTRIBUTE,
            id: this.get('id'),
            name: this.get('name')
          },
          collection: this.get('collection')
        });
        this._dgFormula = DG.Formula.create({context: context});

        this._dgFormula.addObserver('namespaceChange', this, 'namespaceDidChange');
        this._dgFormula.addObserver('dependentChange', this, 'dependentDidChange');
      },

      /**
       Update the formula context when the collection changes
       */
      collectionDidChange: function () {
        if (this.hasFormula()) {
          this._cachedValues = {};
          this.setPath('_dgFormula.context.collection', this.get('collection'));
          this._dgFormula.invalidate();
        }
      }.observes('collection'),

      /**
       Utility function for destroying the DG.Formula when necessary
       and cleanup up the necessary observers.
       */
      destroyDGFormula: function () {
        this._dgFormula.removeObserver('dependentChange', this, 'dependentDidChange');
        this._dgFormula.removeObserver('namespaceChange', this, 'namespaceDidChange');
        this._dgFormula.destroy();
        this._dgFormula = null;
      },

      /**
       * {Computed} True if the attribute has a non-empty formula.
       * @property {Boolean}
       */
      hasFormula: function () {
        return !SC.empty(this.get('formula'));
      }.property('formula').cacheable(),

      /**
       * {Computed} True if the attribute has a recently-deleted formula.
       * @property {Boolean}
       */
      hasDeletedFormula: function () {
        return !SC.empty(this.get('deletedFormula'));
      }.property('deletedFormula').cacheable(),

      /**
       * Evaluates the attribute's formula in the context of the specified namespace object.
       * @param iCase {Object}    Namespace object with property:value pairs for evaluation context
       * @return {Number | ?} Result of evaluation
       */
      evalFormula: function (iCase) {
        var tFormula = this._dgFormula,
            tReturnValue = NaN,
            tCaseID = iCase && iCase.get('id'),
            cacheEntry = this._cachedValues[tCaseID];

        // if we have a valid cache entry, use it
        if (cacheEntry && cacheEntry.isValid)
          return cacheEntry.value;

        try {
          // Client is responsible for passing _case_ and _id_
          tReturnValue = tFormula.evaluate({
            _case_: iCase,
            _id_: iCase && iCase.get('id'),
            _collectionID_: this.getPath('collection.id')
          });
          if (cacheEntry) {
            // update the existing cache entry
            cacheEntry.isValid = true;
            cacheEntry.value = tReturnValue;
          }
          else {
            // cache a new entry
            this._cachedValues[tCaseID] = {isValid: true, value: tReturnValue};
          }
        }
        catch (e) {
          // Return error objects as attribute values.
          tReturnValue = e;
        }

        return tReturnValue;
      },

      /*
       Invalidate the cached values for the specified cases, or for all cases
       if no specific cases are identified. Invalidates the attribute value
       cache along with the specified aggregate function caches as well.
       @param {DG.Case[]}   iCases - array of cases to invalidate
                                      if no cases specified, invalidate all cases
       @param {number[]}    iAggFnIndices - array of aggregate function indices
       */
      invalidateCases: function (iCases, iAggFnIndices) {
        var caseCount = iCases && iCases.length;
        if (caseCount > 0) {
          // invalidate specified cases
          iCases.forEach(function (iCase) {
            var caseID = iCase && iCase.get('id'),
                cachedValue = this._cachedValues[caseID];
            if (cachedValue)
              cachedValue.isValid = false;
          }.bind(this));
        }
        else {
          // invalidate all cases
          DG.ObjectMap.forEach(this._cachedValues, function (iCaseID, iCachedValue) {
            iCachedValue.isValid = false;
          });
        }

        // invalidate specified aggregate function caches
        if (iAggFnIndices && iAggFnIndices.length) {
          

          var formulaContext = this.getPath('_dgFormula.context');
          if (formulaContext)
            formulaContext.invalidateFunctions(iAggFnIndices);
        }
      },

      /**
       Observer function called when the formula changes.
       This function creates, updates, or destroys the corresponding
       DG.Formula as needed and sets up/tears down the necessary
       observers whenever the formula changes.
       */
      formulaDidChange: function () {
        var tSource = this.get('formula');

        // Non-empty formula string -- we need a DG.Formula
        if (!SC.empty(tSource)) {
          // Create the DG.Formula if we don't have one yet
          if (!this._dgFormula)
            this.createDGFormula();
          // Update the DG.Formula with the new source
          this._dgFormula.set('source', tSource);

          // mark all cached values as invalid
          DG.ObjectMap.forEach(this._cachedValues,
              function (id, iCachedValue) {
                iCachedValue.isValid = false;
              });
        }

        // empty formula string -- no need for a DG.Formula
        else {
          if (this._dgFormula)
            this.destroyDGFormula();
          this._cachedValues = {};
        }

        // Discard old deleted formula waiting for recovery.
        this.set('deletedFormula', '');
      }.observes('formula'),

      namespaceDidChange: function () {
        // mark all cached values as invalid
        DG.ObjectMap.forEach(this._cachedValues,
            function (id, iCachedValue) {
              iCachedValue.isValid = false;
            });
      },

      /**
       Observer function called when an attribute formula notifies
       that one of its dependents has changed.
       */
      dependentDidChange: function (iNotifier, iKey) {
        this.notifyPropertyChange(iKey);
      },

      hasValues: function() {
        var hasValues = false;
        var tCollection = this.get('collection');
        if( tCollection) {
          var tAttrID = this.get('id'),
              tCases = tCollection.get('cases');
          tCases && tCases.forEach( function( iCase) {
            var tValue = iCase.getValue(tAttrID);
            if ((tValue == null) || (tValue === "")) return;
            if ((typeof tValue === "number") && !isFinite(tValue)) return;
            hasValues = true;
          }.bind( this));
        }
        return hasValues;
      }.property(),

      /**
       * Gets called when attribute is used categorically in a graph and something has changed.
       * When we find categories that are no longer used we push them to the end rather than delete them.
       * That way swapping categories by dragging on a legend will still work.
       */
      updateCategoryMap: function() {
        var ignorable = ['__order', 'stroke-color', 'stroke-transparency'];

        function validateAndFixCategoryMap(iCategoryMap, iColorIndex) {
          // A plugin can produce a category map without colors assigned. This messes up assignment to __order.
          // Also, it can happen that the __order array contains extra elements and/or is missing an element
          var tLeftOver = iCategoryMap.__order.slice();
          DG.ObjectMap.forEach( iCategoryMap, function( iCategory, iValue) {
            if( !ignorable.includes(iCategory)) {
              if (SC.none(iValue)) {
                iCategoryMap[iCategory] = DG.ColorUtilities.kKellyColors[iColorIndex];
                iColorIndex = (iColorIndex + 1) % DG.ColorUtilities.kKellyColors.length;
              }
              if( tLeftOver.includes(iCategory))
                tLeftOver.splice(tLeftOver.indexOf(iCategory), 1);
              else
                iCategoryMap.__order.push( iCategory);
            }
          });
          tLeftOver.forEach( function( iElement) {
            iCategoryMap.__order.splice(iCategoryMap.__order.indexOf(iElement), 1);
          });
        }

        var tCollection = this.get('collection');
        if( tCollection) {
          var tAttrID = this.get('id'),
              tCases = tCollection.get('cases'),
              tCategoryMap = this._categoryMap || { __order: []},
              tColorIndex = tCategoryMap.__order.length % DG.ColorUtilities.kKellyColors.length,
              tFoundCategoriesSet = new Set();
          validateAndFixCategoryMap(tCategoryMap, tColorIndex);
          tCases && tCases.forEach( function( iCase) {
            var tValue = iCase.getStrValue( tAttrID);
            if( SC.none( tCategoryMap[ String( tValue)])) {
              if( !SC.empty(tValue)) {
                tCategoryMap[tValue] = DG.ColorUtilities.kKellyColors[tColorIndex];
                tColorIndex = (tColorIndex + 1) % DG.ColorUtilities.kKellyColors.length;
                tCategoryMap.__order.push(tValue);
              }
            }
            tFoundCategoriesSet.add( tValue);
          }.bind( this));
          // Note that we are not deleting categories that may no longer be present. This is so we don't lose
          // color assignments for categories whose cases are deleted but then reappear. (Think sampler.)
          if( !this._categoryMap) {
            tCategoryMap.__order.sort( function( item1, item2) {
              if( typeof item1 === 'number' && typeof item2 === 'number')
                return item1 - item2;
              else if( item1 < item2)
                return -1;
              else if( item1 > item2)
                return 1;
              else return 0;
            });  // Default is alphabetical
          }
          // We push categories that are present but not found in cases to the end
          DG.ObjectMap.forEach( tCategoryMap, function (iCategory) {
            if(!ignorable.includes(iCategory) && !tFoundCategoriesSet.has(iCategory)) {
              var tIndex = tCategoryMap.__order.indexOf(iCategory);
              tCategoryMap.__order.splice( tIndex, 1);
              tCategoryMap.__order.push( iCategory);
            }
          });
          this.set('categoryMap', tCategoryMap);
        }
      },

      /**
       Override to update our attribute map to include attributes loaded
       from documents.
       */
      didLoadRecord: function () {
        var id = this.get('id');
        DG.Attribute.idMap[id] = this;
      },
      toArchive: function () {
        return {
          name: this.get('name'),
          type: this.type,
          title: this.get('title'),
          cid: this.get('cid'),
          defaultMin: this.defaultMin,
          defaultMax: this.defaultMax,
          description: this.get('description'),
          _categoryMap: this._categoryMap ? this.get('categoryMap') : undefined,
          blockDisplayOfEmptyCategories: this.blockDisplayOfEmptyCategories || undefined,
          editable: this.editable,
          hidden: this.hidden,
          renameable: this.renameable,
          deleteable: this.deleteable,
          formula: this.hasFormula() ? this.formula : undefined,
          deletedFormula: this.hasDeletedFormula() ? this.deletedFormula : undefined,
          guid: this.id,
          id: this.id,
          precision: this.precision,
          unit: this.unit
        };
      }
    });

/**
 Global map from attribute ID to attribute.
 More efficient than calling DG.store.find(DG.Attribute, attrID);
 */
DG.Attribute.idMap = {};

/**
 Retrieves an attribute by its ID using our internal map.
 @param  {Number}  iAttrID -- the ID of the attribute to be retrieved
 */
DG.Attribute.getAttributeByID = function (iAttrID) {
  return DG.Attribute.idMap[iAttrID];
};

/**
 * Creates a new attribute with the specified properties.
 * @param {Object}  iProperties List of properties to apply to the newly-created DG.Attribute.
 * @return {DG.Attribute}   The newly-created DG.Attribute
 */
DG.Attribute.createAttribute = function (iProperties) {
  var collection = DG.store.resolve(iProperties.collection),
      newAttribute, tNewColormap;

  // As part of the transition from colormap to _colormap and colormap to categoryMap,
  // we have to convert the old property that comes in from previously saved documents and plugins
  if( iProperties.colormap) {
    iProperties.categoryMap = iProperties.colormap;
    delete iProperties.colormap;
  }
  if( iProperties._colormap) {
    iProperties._categoryMap = iProperties._colormap;
    delete iProperties._colormap;
  }
  if( iProperties.categoryMap) {
    if(DG.ObjectMap.length(iProperties.categoryMap) > 0)
      iProperties._categoryMap = iProperties.categoryMap;
    delete iProperties.categoryMap;
  }

  // create collaborative id,  if not already there.
  if (!iProperties.cid) {
    iProperties.cid = DG.DataUtilities.createUniqueID();
  }

  iProperties.collection = collection;
  newAttribute = DG.Attribute.create(iProperties || {});
  if (iProperties._categoryMap) {
    tNewColormap = SC.clone(iProperties._categoryMap);
    if (iProperties._categoryMap.__order) {
      tNewColormap.__order = SC.clone(iProperties._categoryMap.__order);
    }
    else {
      tNewColormap.__order = [];
      DG.ObjectMap.forEach(tNewColormap, function (iKey) {
        if (iKey !== '__order' && !SC.empty( iKey))
          tNewColormap.__order.push(String(iKey));
      });
    }
    newAttribute.set('categoryMap', tNewColormap);
  }
  if (iProperties.type && iProperties.type === DG.Attribute.TYPE_NOMINAL) {
    iProperties.type = DG.Attribute.TYPE_CATEGORICAL;
  }

  DG.store.commitRecords();
  DG.Attribute.idMap[newAttribute.get('id')] = newAttribute;
  return newAttribute;
};

/**
 * Returns unit part of a name string.
 * By convention, a parenthesized substring at the end of a name string is
 * interpreted as a unit by CODAP.
 *
 * @param iName
 * @return unit string, if present. otherwise null.
 */
DG.Attribute.extractUnitFromNameString = function (iName) {
  if (!iName) {
    return null;
  }

  var match = /\(([^)]*)\)$/.exec(iName.trim());
  if (match) {
    return match[1];
  } else {
    return null;
  }
};

/**
 * Convert a string to a "legal" attribute name.
 */
DG.Attribute.canonicalizeName = function (iName, iCanonicalize) {
  var tName = String(SC.none(iName) ? '' : iName),
      tReg = /\([^)]*\)$/;  // Identifies parenthesized substring at end

  tName = tName.trim(); // Get rid of trailing white space
  if (iCanonicalize || ((iCanonicalize == null) && DG.canonicalizeNames)) {
    tName = tName.replace(tReg, '');  // Get rid of parenthesized units
    tName = tName.replace(/\W/g, '_');  // Replace non-word characters with underscore
  }
  // if after all this we have an empty string replace with a default name.
  if (tName.length === 0) {
    tName = 'attr';
  }
  return tName;
};
/**
 * Destroys the specified DG.Attribute.
 * @param iAttribute {DG.Attribute}  The DG.Attribute to destroy
 */
DG.Attribute.destroyAttribute = function (iAttribute) {
  iAttribute.destroy();
};

/**
 * Valid Attribute types
 *
 * Empty string names an untyped attribute.
 *
 * @type {string[]}
 */
DG.Attribute.TYPE_UNSPECIFIED = 'none';
DG.Attribute.TYPE_NOMINAL = 'nominal'; // no longer used
DG.Attribute.TYPE_CATEGORICAL = 'categorical';
DG.Attribute.TYPE_NUMERIC = 'numeric';
DG.Attribute.TYPE_DATE = 'date';
DG.Attribute.TYPE_QUALITATIVE = 'qualitative';
DG.Attribute.TYPE_BOUNDARY = 'boundary';
DG.Attribute.TYPE_CHECKBOX = 'checkbox';

DG.Attribute.attributeTypes = [
  DG.Attribute.TYPE_UNSPECIFIED,
  DG.Attribute.TYPE_CATEGORICAL,
  DG.Attribute.TYPE_NUMERIC,
  DG.Attribute.TYPE_DATE,
  DG.Attribute.TYPE_QUALITATIVE,
  DG.Attribute.TYPE_BOUNDARY,
  DG.Attribute.TYPE_CHECKBOX
];

/**
 * Date precision options
 *
 * @type {string[]}
 */
DG.Attribute.DATE_PRECISION_NONE = '';
DG.Attribute.DATE_PRECISION_YEAR = 'year';
DG.Attribute.DATE_PRECISION_MONTH = 'month';
DG.Attribute.DATE_PRECISION_DAY = 'day';
DG.Attribute.DATE_PRECISION_HOUR = 'hour';
DG.Attribute.DATE_PRECISION_MINUTE = 'minute';
DG.Attribute.DATE_PRECISION_SECOND = 'second';
DG.Attribute.DATE_PRECISION_MILLISECOND = 'millisecond';

DG.Attribute.datePrecisionOptions = [
  DG.Attribute.DATE_PRECISION_NONE,
  DG.Attribute.DATE_PRECISION_YEAR,
  DG.Attribute.DATE_PRECISION_MONTH,
  DG.Attribute.DATE_PRECISION_DAY,
  DG.Attribute.DATE_PRECISION_HOUR,
  DG.Attribute.DATE_PRECISION_MINUTE,
  DG.Attribute.DATE_PRECISION_SECOND,
  DG.Attribute.DATE_PRECISION_MILLISECOND
];

/* >>>>>>>>>> BEGIN source/models/case_model.js */
// ==========================================================================
//                                DG.Case
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('models/model_store');
sc_require('models/base_model');

/** @class
 *
 * Represents an individual case in the collection. For the base collection (the
 * rightmost collection, the one with no child collection) there is one case
 * for each item in the data set. For all upper level collections a case is a unique
 * combination of attribute values among the data items with the same parentage.
 * Each collection manages an attribute group. An individual case is the set of
 * DataItems in the DataSet for which the attributes in the attribute group all
 * have the same values.
 *
 * @extends SC.Object
 */
DG.Case = DG.BaseModel.extend((function() {
  /** @scope DG.Case.prototype */

  /**
    Utility function to convert dates to strings while leaving
    all other values alone.
   */
  function convertValue(x, iAttr) {
    if (iAttr && (iAttr.type === 'date' && (DG.isDate(x)))) {
      return DG.formatDate(x, iAttr.precision);
    }
    else {
      return (DG.isDate(x)) ? DG.formatDate(x) : x;
    }
  }

  return {

    /**
     * Revision counter for the case.
     *  Incrementing the revision property causes change notifications to be sent.
     *  Calling beginCaseValueChanges()/endCaseValueChanges() will automatically
     *  increment the revision counter when endCaseValueChanges() is called.
     * @property {Number}
     */
    revision: 0,

    /**
     * A relational link back to the parent collection.
     * @property {DG.Collection}
     */
    collection: null,

    /**
     * A relational link back to the parent case (if any).
     * @property {DG.Case}
     */
    parent: null,

    /**
     * A relational link to the child cases of this case.
     * @property {[DG.Case]}
     */
    children: null,

      /**
       * Every case gets its attribute values from an item.
       * @type {DG.DataItem}
       */
    item: null,

    _cachedDate: null,

    /**
     * Associative array of {AttrID:value} pairs for quicker lookups.
     */
    _valuesMap: function () {
      return this.get('item').values;
    }.property(),

    /**
     * Initialization function for the case.
     */
    init: function() {
      arguments.callee.base.apply(this,arguments);

      this._cachedDate = {};
      DG.Case._addCaseToItemMap(this);

      this.children = [];
      if (this.parent) {
        this.parent.children.pushObject(this);
      }
    },

    verify: function () {
      if (SC.empty(this.collection)) {
        DG.logWarn('Unattached case: ' + this.id);
      }
      if (typeof this.collection === 'number') {
        DG.logWarn('Unresolved reference to collection id, ' + this.collection +
          ', in case: ' + this.id);
      }
      if (typeof this.get('parent') === 'number') {
        DG.logWarn('Unresolved reference to parent, ' + this.get('parent') +
          ', in case: ' + this.id);
      }
    },

    /**
     * Destruction function for the case.
     */
    destroy: function() {

      DG.Case._removeCaseFromItemMap(this);

      arguments.callee.base.apply(this,arguments);
    },

    beginCaseValueChanges: function() {
      this.beginPropertyChanges();
    },

    /**
     * Ends a set of property changes and increments the revision property.
     */
    endCaseValueChanges: function() {
      this.incrementProperty('revision');
      this.endPropertyChanges();
    },

    /**
     * Returns the raw value of the specified attribute for this case.
     * Dates are returned as Dates rather than converted to strings.
     * @param {Number} iAttrID ID of the attribute for which the value should be returned.
     * @returns {Number | String | null}
     */
    getRawValue: function( iAttrID) {

      if( !SC.none( iAttrID)) {

        // If we have an attribute formula, we must evaluate it.
        var tAttr = DG.Attribute.getAttributeByID( iAttrID);
        var valuesMap = this.get('_valuesMap');
        if (tAttr && tAttr.get('hasFormula') &&
          // we only do the evaluation if it's one of this case's attributes
          (this.getPath('collection.id') === tAttr.getPath('collection.id'))) {
          return tAttr.evalFormula( this);
        }

        // If we have a cached value, simply return it
        if( tAttr && valuesMap && (!SC.none(valuesMap[iAttrID])) &&
            // we only do the evaluation if it's one of this case's attributes. This is important!
            (this.getPath('collection.id') === tAttr.getPath('collection.id'))) {
          return valuesMap[iAttrID];
        }

        // one last chance if we've got a parent and it has 'getValue'
        // Need for this seems to have been brought about by a particular import of boundary file data. Can't hurt.
        var tParent = this.get('parent');
        if( tParent )
          return tParent.getRawValue( iAttrID);
      }
      // if we get here, return value is undefined
    },

    /**
     * Returns the value of the specified attribute for this case.
     * Dates are converted to strings.
     * @param {Number} iAttrID ID of the attribute for which the value should be returned.
     * @returns {Number | String | null}
     */
    getValue: function( iAttrID) {
      var rawValue = this.getRawValue(iAttrID);
      var attr = DG.Attribute.getAttributeByID( iAttrID);
      return rawValue != null ? convertValue(rawValue, attr) : rawValue;
    },

    /**
     * Returns the numeric value of the specified attribute for this case.
     * Note that the built-in isFinite() can be used with the result (rather than
     * DG.isFinite()) because nulls/undefineds/etc. have already been filtered out.
     * @param {Number} iAttrID -- ID of the attribute for which the value should be returned.
     * @param {Object} oOptInfo -- Additional information about the value can be returned to
     *                              the client via this object.
     *                  .type -- The type of the value, e.g. "string", "number", etc.
     *                  .isNominal -- True if the value is non-numeric and can be
     *                                converted to a non-empty string.
     * @returns {Number}
     */
    getNumValue: function( iAttrID, oOptInfo) {
      var value = this.getRawValue( iAttrID),
          valType = typeof value,
          tAttr = DG.Attribute.getAttributeByID( iAttrID),
          attrType = tAttr && tAttr.type;
      if (DG.isDate(value)) {
        // treat dates numerically
        value = Number(value);
        valType = "number";
      } else if (attrType === 'date') {
        if (!this._cachedDate[iAttrID]) {
          this._cachedDate[iAttrID] = DG.parseDate(value, true);
        }
        value = Number(this._cachedDate[iAttrID]);
        valType = "number";
      } else if (DG.isDateString(value)) {
        this._cachedDate[iAttrID] = DG.parseDate(value);
        value = Number(this._cachedDate[iAttrID]);
        valType = "number";
      }
      else if (attrType === 'numeric') {
        value = DG.MathUtilities.extractNumeric(value);
        valType = "number";
      }
      if( oOptInfo) {
        oOptInfo.type = valType;
        // Note: we don't consider non-primitive types (e.g. objects, arrays, etc.)
        oOptInfo.isNominal = (valType === "boolean") ||
          ((valType === "string") && !SC.empty(String(value)));
      }
      switch( valType) {
        case "number":
          return value;
        case "string":
          return (value !== "" ? Number(value) : NaN);
      }
      return NaN;
    },

   /**
     * Returns a numeric value of the specified attribute for this case where the raw value has been stripped
    *   of non-numeric characters and the first valid number.
     * @param {Number} iAttrID -- ID of the attribute for which the value should be returned.
   */
    getForcedNumericValue: function( iAttrID) {
      var tInfo = {},
          tValue = this.getNumValue( iAttrID, tInfo);
      if( tInfo.type === 'number')
        return tValue;
      else
        return DG.MathUtilities.extractNumeric( this.getRawValue( iAttrID));
    },

    /**
     * Returns the string value of the specified attribute for this case.
     * @param {Number} iAttrID ID of the attribute for which the value should be returned.
     * @param {Object} oOptInfo -- Additional information about the value can be returned to
     *                              the client via this object.
     *                  .type -- The type of the value, e.g. "string", "number", etc.
     * @returns {String}
     */
    getStrValue: function( iAttrID, oOptInfo) {
      var value = this.getValue( iAttrID),
          valType = typeof value;
      if( oOptInfo) {
        oOptInfo.type = valType;
      }
      return DG.DataUtilities.toString(value);
    },

    /**
     * Return the value that fits the attribute's type
     * @param iAttrID {Number}
     * @return {number|string|null}
     */
    getTypedValue: function( iAttrID) {
      var tAttribute = DG.Attribute.getAttributeByID( iAttrID);
      if( tAttribute) {
        switch (DG.Attribute.getAttributeByID(iAttrID).get('type')) {
          case 'numeric':
            return this.getForcedNumericValue(iAttrID);
          case 'date':
            return this.getValue(iAttrID);
          case 'nominal':
            return this.getStrValue(iAttrID);
          default:
            return this.getRawValue(iAttrID);
        }
      }
      else
        return this.getRawValue( iAttrID);
    },

    /**
     * Is there a value of the specified attribute for this case.
     * Note that a formula can return a null value, so some cases will be thought
     * to have a value for the given attribute ID, when actually they don't.
     * @param {Number} iAttrID ID of the attribute for which the value should be returned.
     * @returns {Boolean}
     */
    hasValue: function( iAttrID) {
      if (!SC.none( iAttrID)) {
        var tAttr = this.get('collection').getAttributeByID( iAttrID);
        if(tAttr && tAttr.get('hasFormula'))
          return !SC.empty( this.getValue( iAttrID));

        if( tAttr)
          return this.get('_valuesMap') && !SC.empty( this.get('_valuesMap')[iAttrID]);

        var tParent = this.get('parent');
        return tParent && tParent.hasValue( iAttrID);
      }
    },

    /**
     * Sets the value of the specified attribute for this case.
     * @param {Number} iAttrID ID of the attribute for which the value should be set.
     * @param {String} iValue Value of the newly created case value.
     */
    setValue: function(iAttrID, iValue) {
      var children = this.get('children');
      if( !this.get('_valuesMap')) return; // Looks like case has been destroyed

      this._cachedDate[iAttrID] = null;
      if (children.length === 0) {
        this.item.setValue(iAttrID, iValue);
      } else {
        children.forEach(function (child) { child.setValue(iAttrID, iValue); });
      }
    },

    /**
     Returns a copy of the case's values.
     */
    copyValues: function() {
      var valuesMap = this.get('_valuesMap'),
          attrs = this.collection.attrs,
          values = {};
      attrs.forEach(function (attr) {
        values[attr.name] = valuesMap[attr.id];
      });
      return values;
    },

    /**
     Override to handle 'values' specially.
     During runtime, the _valuesMap, which maps from attrID to value,
     is the definitive contents of the case. In this method, we copy the
     contents of the _valuesMap to the 'archivableValues' property, which
     maps from attrName to value and converts values for archival purposes.
     */
    archivableValues: function() {
      var values = {};
      var valuesMap = this.get('_valuesMap');
      var attrs = this.collection.attrs;
      attrs.forEach(function (attr, ix) {
        values[attr.name] = convertValue(valuesMap[attr.id]);
      });
      return values;
    }.property(),


    debugLog: function(iPrompt) {
      DG.log('Case ' + this.get('id'));
    },

    toArchive: function () {
      var result;
      result = {
        parent: (this.get('parent') && this.get('parent').id)  || undefined,
        guid: this.id,
        id: this.id,
        itemID: this.item.id,
        values: this.get('archivableValues')
      };
      return result;
    },

    /**
     * A case is considered empty iff
     *   1. it is in the rightmost collection,
     *   2. all attribute values are empty
     */
    isEmpty: function () {
      var collection = this.get('collection');
      var attrs = collection.get('attrs');
      // rightmost
      var empty = collection.get('children') == null ||
          collection.get('children').length === 0;
      empty = empty && attrs && !attrs.find(function (attr) {
        // has value and not from a formula
        return this.hasValue(attr.id);
      }.bind(this));
      return empty;
    }.property()
  };
})());

/*
  Map from { collectionID: { itemID: DG.Case }}
  Used for looking up cases from items.
 */
DG.Case._itemCaseMaps = {};

/*
  Adds a (new) case to the item case map.
 */
DG.Case._addCaseToItemMap = function(iCase) {
  var collectionID = iCase.getPath('collection.id'),
      itemID = iCase.getPath('item.id'),
      itemCaseMap = collectionID && DG.Case._itemCaseMaps[collectionID];
  if (!SC.none(itemID) && collectionID) {
    if (!itemCaseMap)
      DG.Case._itemCaseMaps[collectionID] = itemCaseMap = {};
    itemCaseMap[itemID] = iCase;
  }
};

/*
  Removes a case from the item case map.
 */
DG.Case._removeCaseFromItemMap = function(iCase) {
  var collectionID = iCase.getPath('collection.id'),
      itemID = iCase.getPath('item.id'),
      itemCaseMap = collectionID && DG.Case._itemCaseMaps[collectionID];
  if (!SC.none(itemID) && itemCaseMap) {
    delete itemCaseMap[itemID];
  }
};

/*
  Find a case (if any) that corresponds to the specified item.
 */
DG.Case.findCase = function(iCollectionID, iItemID) {
  var itemCaseMap = iCollectionID && DG.Case._itemCaseMaps[iCollectionID];
  return itemCaseMap && !SC.none(iItemID) && itemCaseMap[String(iItemID)];
};

/**
 * Creates a new case with the specified properties.
 * @param iProperties
 *    {{collection:DG.Collection|id, parent:DG.Case|id, extentStart: number}}
 *    Properties to apply to the newly-created DG.Case
 *
 * @return {DG.Case}  The newly-created DG.Case
 */
DG.Case.createCase = function( iProperties) {
  var collection = iProperties.collection,
    parent = iProperties.parent,
    newCase;
  iProperties.collection = DG.store.resolve(collection);
  if (!SC.empty(parent)) {
    iProperties.parent = DG.store.resolve(parent);
  }
  newCase = DG.Case.create(iProperties || {});
  return newCase;
};

/**
 * Destroys the specified DG.Case.
 * @param {DG.Case} iCase The case to destroy
 */
DG.Case.destroyCase = function( iCase) {
  iCase.destroy();
};

/* >>>>>>>>>> BEGIN source/components/case_card/attribute_value_cell.js */
sc_require('models/attribute_model');
sc_require('models/case_model');
sc_require('react/dg-react');
/* global React, createReactFC, PropTypes, ReactDOMFactories, tinycolor */

DG.React.ready(function () {
  var img = ReactDOMFactories.img,
      span = ReactDOMFactories.span,
      input = ReactDOMFactories.input,
      td = ReactDOMFactories.td;

  /**
   * AttributeValueCell
   *    displays the contents of the attribute value cell in the case card
   */
  var config = {
    displayName: "AttributeValueCell",
    propTypes: {
      // {DG.Attribute} the attribute to display
      attribute: PropTypes.instanceOf(DG.Attribute).isRequired,
      dataContext: PropTypes.instanceOf(DG.DataContext).isRequired,
      // {DG.Case} the case to display; undefined to summarize
      displayCase: PropTypes.instanceOf(DG.Case),
      // {DG.Case} the case to whose values to edit; undefined to summarize
      editableCase: PropTypes.instanceOf(DG.Case),
      // {[DG.Case]} - the cases to summarize; undefined for single case
      summaryCases: PropTypes.arrayOf(PropTypes.instanceOf(DG.Case)),
      deselectCallback: PropTypes.func.isRequired,
      forceUpdateCallback: PropTypes.func.isRequired,
      editProps: PropTypes.exact({
        isEditing: PropTypes.bool.isRequired,
        // function(attribute) - toggle into/out of editing mode
        onToggleEditing: PropTypes.func.isRequired,
        // function(attribute) - escape out of editing mode
        onEscapeEditing: PropTypes.func.isRequired,
        // function(attribute) - callback to inform caller of TextInput
        onEditModeCallback: PropTypes.func.isRequired
      }).isRequired
    }
  };

  function AttributeValueCell(props) {

    function isBoolean(v) {
      if (typeof v === 'string') {
        v = v.toLowerCase();
      }
      return ['', 'false', 'true', false, true, null].includes(v) || v === undefined;
    }

    var CheckboxFormatter = function (cellValue) {

      function handleChange(iEvent) {
        var newValue = iEvent.target.checked,
            newState = newValue ? 'checked' : 'unchecked';
        var tChange = {
          operation: 'updateCases',
          cases: [props.displayCase],
          caseIDs: [props.displayCase.get('id')],
          attributeIDs: [tAttr.get('id')],
          values: [[newValue]]
        };
        props.dataContext.applyChange(tChange);
        setTriState(newState);
      }

      React.useEffect(function () {
        var newState,
            newCellValue = (typeof cellValue === 'string') ? cellValue.toLowerCase() : cellValue;
        if (newCellValue && newCellValue !== 'false') {
          newState = 'checked';
          checkRef.current.checked = true;
          checkRef.current.indeterminate = false;
        } else if (newCellValue === false) {
          newState = 'unchecked';
          checkRef.current.checked = false;
          checkRef.current.indeterminate = false;
        } else {
          newState = 'indeterminate';
          checkRef.current.checked = false;
          checkRef.current.indeterminate = true;
        }
        setTriState(newState);
      }, [cellValue, setTriState]);

      var readOnly = (tAttr && (tAttr.formula || !tAttr.editable)),
          checkRef = React.useRef();

      var triStateState = React.useState('indeterminate'),
          setTriState = triStateState[1];


      return span({
            className: 'dg-checkbox-cell dg-wants-mouse dg-wants-touch',
          },
          input({
            type: 'checkbox', disabled: readOnly,
            onChange: handleChange, ref: checkRef
          }));
    };

    var tAttr = props.attribute,
        tAttrID = tAttr.get('id'),
        tUnit = tAttr.get('unit') || '',
        tHasFormula = tAttr.get('hasFormula'),
        tValue = props.displayCase && props.displayCase.getValue(tAttrID),
        tType = tValue && tValue.jsonBoundaryObject
            ? 'boundary'
            : tAttr.get('type'),
        tColorValueField,
        tQualitativeValueField,
        tBoundaryValueField,
        tCheckboxField,
        tColor,
        spanStyle,
        tBoundaryInternalImage,
        tQualitativeInternalSpan,
        tValueClassName = '';
    if (tType === 'numeric' && !DG.isNumeric(tValue)) {
      tValue = props.displayCase && props.displayCase.getForcedNumericValue(tAttrID);
    }
    if (tValue instanceof Error) {
      tValue = tValue.name + tValue.message;
    } else if (DG.isColorSpecString(tValue)) {
      tColor = tinycolor(tValue.toLowerCase().replace(/\s/gi, ''));
      spanStyle = {
        backgroundColor: tColor.toString('rgb')
      };
      tColorValueField = span({
        className: 'react-data-card-color-table-cell',
        style: spanStyle
      });
    } else if (tType === 'qualitative') {
      if (SC.empty(tValue)) {
        tValue = "";
      } else {
        tColor = DG.PlotUtilities.kDefaultPointColor;
        spanStyle = {
          backgroundColor: tColor,
          width: tValue + '%',
        };
        tQualitativeInternalSpan = span({
          className: 'react-data-card-qualitative-bar',
          style: spanStyle
        });
        tQualitativeValueField = span({
          className: 'react-data-card-qualitative-backing'
        }, tQualitativeInternalSpan);
      }
    } else if (tType === DG.Attribute.TYPE_CHECKBOX
        && isBoolean(tValue) && !props.summaryCases) {
      tCheckboxField = CheckboxFormatter(tValue, this); // jshint ignore:line
    } else if (tType === 'boundary') {
      var tResult = 'a boundary',
          tBoundaryObject = DG.GeojsonUtils.boundaryObjectFromBoundaryValue(tValue),
          tThumb = tBoundaryObject && tBoundaryObject.jsonBoundaryObject &&
              tBoundaryObject.jsonBoundaryObject.properties &&
              tBoundaryObject.jsonBoundaryObject.properties.THUMB;
      if (tThumb !== null && tThumb !== undefined) {
        tBoundaryInternalImage = img({
          className: 'react-data-card-thumbnail',
          src: tThumb
        });
        tBoundaryValueField = span({}, tBoundaryInternalImage);
      } else if (tBoundaryObject && (tBoundaryObject.jsonBoundaryObject instanceof Error)) {
        tValue = tBoundaryObject.jsonBoundaryObject.name + tBoundaryObject.jsonBoundaryObject.message;
      }
      tValue = tResult;
    } else if (DG.isNumeric(tValue) && typeof tValue !== 'boolean') {
      var tPrecision = tAttr.get('precision');
      tPrecision = SC.none(tPrecision) ? 2 : tPrecision;
      tValue = DG.MathUtilities.formatNumber(tValue, tPrecision);
      tValueClassName += ' react-data-card-numeric ';
    } else if (tType === 'date' && !props.summaryCases) {
      tValueClassName += ' react-data-card-date ';
    } else if (SC.none(tValue) || (typeof tValue === 'object')) {
      tValue = '';
    }
    var tValueField = props.summaryCases
        ? DG.React.Components.AttributeSummary({
          cases: props.summaryCases,
          attr: tAttr,
          unit: tUnit
        })
        : DG.React.Components.TextInput({
          attr: tAttr,
          'case': props.editableCase,
          value: tValue,
          unit: tUnit,
          isEditable: tAttr.get('editable') && !tAttr.get('hasFormula'),
          createInEditMode: props.editProps.isEditing,
          onToggleEditing: props.editProps.onToggleEditing,
          onEscapeEditing: props.editProps.onEscapeEditing,
          onEditModeCallback: props.editProps.onEditModeCallback
        });
    tValueClassName += tHasFormula ? 'react-data-card-formula' : '';
    if (tColorValueField) {
      tValueField = tColorValueField;
    } else if (tCheckboxField) {
      tValueField = tCheckboxField;
    } else if (tBoundaryValueField) {
      tValueField = tBoundaryValueField;
    } else if (tQualitativeValueField) {
      tValueField = tQualitativeValueField;
    }
    return (
        td({
          className: 'dg-wants-touch ' + tValueClassName
        }, tValueField)
    );
  }

  // two-stage definition required for React-specific eslint rules
  DG.React.AttributeValueCell = createReactFC(config, AttributeValueCell);
});

/* >>>>>>>>>> BEGIN source/components/case_card/column_resize_handle.js */
/* global createReactFC, PropTypes, React, ReactDOMFactories */

DG.React.ready(function () {
  var div = ReactDOMFactories.div;

  function stop(e) {
    e.preventDefault();
    e.stopPropagation();
  }

  /**
   * DragHandle
   */
  var dhConfig = {
    displayName: "DragHandle",
    propTypes: {
      className: PropTypes.string,
      touchId: PropTypes.string,
      onUpdateDrag: PropTypes.func.isRequired,
      onEndDrag: PropTypes.func.isRequired
    }
  };
  function DragHandle(props) {
    var useDragOnDemand = DG.React.useDragOnDemand;

    useDragOnDemand(props.touchId, props.onUpdateDrag, props.onEndDrag);

    return div({ className: props.className });
  }
  // two-stage definition required for React-specific eslint rules
  DG.React.DragHandle = createReactFC(dhConfig, DragHandle);

  /**
   * ColumnResizeHandle
   */
  var crConfig = {
    displayName: "ColumnResizeHandle",
    propTypes: {
      containerWidth: PropTypes.number,
      columnWidth: PropTypes.number,
      minWidth: PropTypes.number.isRequired,
      onResize: PropTypes.func
    }
  };
  function ColumnResizeHandle(props) {
    var isResizingState = React.useState(false),
        isResizing = isResizingState[0],
        setIsResizing = isResizingState[1],
        resizeWidthState = DG.React.useRefState(null),
        resizeWidth = resizeWidthState[0],
        resizeWidthRef = resizeWidthState[1],
        setResizeWidth = resizeWidthState[2],
        touchId = React.useRef(),
        deltaStartRef = React.useRef();

    React.useLayoutEffect(function() {
      setResizeWidth(props.columnWidth);
    }, [props.columnWidth, setResizeWidth]);

    function beginResize(e) {
      deltaStartRef.current = e.pageX - resizeWidthRef.current;
      setIsResizing(true);
    }

    function continueResize(e) {
      var newWidth = e.pageX - deltaStartRef.current,
          minWidth = props.minWidth || 20,
          maxWidth = props.containerWidth - minWidth;
      newWidth = Math.max(newWidth, minWidth);
      newWidth = Math.min(newWidth, maxWidth);
      deltaStartRef.current = e.pageX - newWidth;
      if (newWidth !== resizeWidthRef.current) {
        props.onResize && props.onResize(newWidth);
        setResizeWidth(newWidth);
      }
    }

    function endResize() {
      if (props.onResize) {
        props.onResize(resizeWidthRef.current, true);
      }
      setIsResizing(false);
    }

    function handleMouseDown(e) {
      if (!props.enabled || isResizing || (e.button !== 0)) return;
      beginResize(e);
      stop(e);
    }

    function handleInitialTouch(e) {
      if (!props.enabled || isResizing) return;

      var touch = e.changedTouches[0];
      touchId.current = touch.identifier;
      beginResize(touch);

      stop(e);
    }

    var style = resizeWidth != null
                  ? { left: resizeWidth }
                  : null;
    return (
      (props.enabled || isResizing) &&
        div({
          className: props.className + ' column-resize-handle dg-wants-mouse dg-wants-touch',
          onMouseDown: handleMouseDown,
          onTouchStart: handleInitialTouch,
          style: style
        },
        isResizing && DG.React.DragHandle({
          className: "column-resize-handle-render is-resizing",
          touchId: touchId.current,
          onUpdateDrag: continueResize,
          onEndDrag: endResize
        }))
    );
  }
  // two-stage definition required for React-specific eslint rules
  DG.React.ColumnResizeHandle = createReactFC(crConfig, ColumnResizeHandle);
});

/* >>>>>>>>>> BEGIN source/components/case_card/text_input.js */
/* global ReactDOMFactories */
// sc_require('react/dg-react');

DG.React.ready(function () {
  var
      span = ReactDOMFactories.span,
      input = ReactDOMFactories.input;

  DG.React.Components.TextInput = DG.React.createComponent(
      (function () {

        /**
         * props are
         *    value: {string | number}
         *    unit: {string}
         *    onToggleEditing: {function}
         */

        return {
          inputElement: null,

          getInitialState: function () {
            return {
              editing: false,
              value: this.props.value,
              unit: this.props.unit
            };
          },

          componentDidMount: function () {
            window.addEventListener("touchstart", this._onWindowClick, true);
            window.addEventListener("mousedown", this._onWindowClick, true);
          },
          componentWillUnmount: function () {
            window.removeEventListener("touchstart", this._onWindowClick, true);
            window.removeEventListener("mousedown", this._onWindowClick, true);
          },

          UNSAFE_componentWillReceiveProps: function (iNewProps) {
            if (iNewProps.value !== this.state.value)
              this.setState({value: iNewProps.value});
            if (iNewProps.unit !== this.state.unit)
              this.setState({unit: iNewProps.unit});
            if(iNewProps.createInEditMode && iNewProps.onEditModeCallback)
              iNewProps.onEditModeCallback( this);
          },

          componentDidUpdate: function( iPrevProps) {
            if( this.props.createInEditMode !== iPrevProps.createInEditMode) {
              this.setState( { editing: this.props.createInEditMode });
            }
          },

          _onWindowClick: function (event) {
            if (this.inputElement && this.state.editing &&
                (event.target !== this.inputElement) && !this.inputElement.contains(event.target)) {
              this.props.onToggleEditing(this);
            }
          },

          handleChange: function (iEvent) {
            this.setState({value: iEvent.target.value});
          },

          render: function () {
            var
                this_ = this,
                tUnits = SC.empty(this.state.value) ? '' : ' ' + (this.state.unit || ''),
                tValueClassName = this.props.isEditable ? 'react-data-card-value ' : '',
                tValue = SC.empty( this.state.value) ? '____' : this.state.value,
                kCompletionCodes = [13, 9],
                tResult = this.state.editing ?
                    input({
                      className: 'react-data-card-value-input dg-wants-mouse dg-wants-touch',
                      type: 'text',
                      // ref is called on creation of the input element
                      ref: function( input) {
                        this_.inputElement = input;
                        input && input.focus();
                      },
                      value: this.state.value,
                      onChange: this.handleChange,
                      onKeyDown: function (iEvent) {
                        if (kCompletionCodes.indexOf( iEvent.keyCode) >= 0) {
                          this.props.onToggleEditing(this, iEvent.shiftKey ? 'up' : 'down' );
                          iEvent.preventDefault();
                        }
                        else if( iEvent.keyCode === 27) {
                          this.props.onEscapeEditing( this);
                        }
                      }.bind(this),
                      onFocus: function(iEvent) {
                        iEvent.target.select();
                      }
                    }) :
                    span({
                      className: tValueClassName + (this.props.className || ''),
                      title: tValue,
                      onClick: function ( iEvent) {
                        if (!this.state.editing && this.props.onToggleEditing && this.props.isEditable) {
                          this.props.onToggleEditing(this);
                        }
                      }.bind(this)
                    }, tValue + tUnits);
            return tResult;
          }
        };
      }()), []);

});

/* >>>>>>>>>> BEGIN source/controllers/data_context.js */
// ==========================================================================
//                          DG.DataContext
//
//  The DataContext corresponds to a hierarchical data set comprised of
//  multiple collections in a linear parent/child relationship. Currently,
//  the data are limited to two levels (i.e. parent and child), but future
//  extension to support arbitrary number of levels is an eventual goal.
//
//  Author:   Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
/*global pluralize:true*/
/** @class

    Coordinating controller which manages a set of collections that form the
 hierarchical data model.

 @extends SC.Object
 */
DG.DataContext = SC.Object.extend((function () // closure
    /** @scope DG.DataContext.prototype */ {
  /**
   * Returns an integer constrained within the specified limits including the max.
   * If undefined, returns the max value.
   * @param {number|undefined} num
   * @param {number} min // assumed an integer
   * @param {number} max // assumed an integer
   * @return {number}
   */
  function constrainInt(num, min, max) {
    var n = isNaN(num) ? Number.MAX_SAFE_INTEGER : Math.round(num);
    // clipToIntegerRange is exclusive of the max value
    return DG.MathUtilities.clipToIntegerRange(n, min, max + 1);
  }

  return {  // return from closure

    /**
     *  The type of DataContext, for use when archiving/restoring.
     *  @property {String}
     */
    type: 'DG.DataContext',

    /**
     *  The id of the DG.GameController | DG.ComponentController that manages this context.
     *  @property {string}
     */
    _managingControllerID: null,

    /**
     *  The DG.DataContextRecord for which this is the controller.
     *  @property {DG.DataContextRecord}
     */
    model: null,

    name: function (k, v) {
      if (!SC.none(v)) {
        this.setPath('model.name', v);
      }
      return this.getPath('model.name');
    }.property(),

    title: function (k, v) {
      if (!SC.none(v)) {
        this.setPath('model.title', v);
      }
      return this.getPath('model.title');
    }.property(),

    description: function (k, v) {
      if (!SC.none(v)) {
        this.setPath('model.description', v);
      }
      return this.getPath('model.description');
    }.property(),

    preventReorg: function (k, v) {
      if (!SC.none(v)) {
        this.setPath('model.preventReorg', v);
      }
      return this.getPath('model.preventReorg');
    }.property(),


    /**
     The Dependency Manager object for this context
     @property {DG.DependencyMgr}
     */
    dependencyMgr: function () {
      return this.getPath('model.dependencyMgr');
    }.property(),

    /**
     The number of change requests that have been applied.
     Clients can use this like a seed value to determine when they're out of date
     and by how many changes they're behind. Clients that observe this property
     will be notified whenever a change is applied.
     @property   {Number}
     */
    changeCount: 0,

    /**
     The number of selection change requests that have been applied.
     Clients can use this like a seed value to determine when they're out of date
     and by how many selection changes they're behind. Clients that observe this property
     will be notified whenever a selection change is applied.
     @property   {Number}
     */
    selectionChangeCount: 0,

    /**
     * The number of metadata changes that have occurred.
     * Clients can observe this to be notified of metadata changes.
     * Initially triggered only by the 'managingController' property.
     * @property  {Number}
     */
    metadataChangeCount: 0,

    /**
     Array of change objects that have been applied to/by this data context.
     Newly-applied changes are appended to the array, so the most recent changes
     are at the end.
     @property   {[Object]} Array of change objects
     */
    changes: null,

    /**
     * Flag to indicate that the user has moved attributes within a collection
     * or between grids in a way that invalidates the Data Interactive
     * specification. If this happens we will block new createCase(s), openCase,
     * or updateCase requests from the data interactives to avoid corrupting
     * the data.
     */
    flexibleGroupingChangeFlag: function (key, value) {
      if (!SC.none(value)) {
        this.setPath('model.flexibleGroupingChangeFlag', value);
      }
      return this.getPath('model.flexibleGroupingChangeFlag');
    }.property(),

    // The following code should be uncommented if changes to the above property
    // are to be observed. SC does not support chained properties, and so the
    // observer pattern below is recommended and required for v1.10 and above.
    //flexibleGroupingChangeFlagDidChange: function () {
    //  this.notifyPropertyChange('flexibleGroupingChangeFlag',
    //      this.get('flexibleGroupingChangeFlag'));
    //}.observes('*model.flexibleGroupingChangeFlag'),

    canonicalizeName: function (iName) {
      return DG.Attribute.canonicalizeName(iName);
    },

    /**
     *  The id of our DG.DataContextRecord.
     *  Bound to the 'id' property of the model.
     *  @property {Number}
     */
    id: function () {
      return this.getPath('model.id');
    }.property('model'),

    collections: null,

    /**
     * Return the total number of cases, obtained by summing the case count over all collections
     * @property{ Number }
     */
    totalCaseCount: function () {
      var tTotalCount = 0;
      this.forEachCollection(function (iCollection) {
        tTotalCount += iCollection.getPath('collection.cases').length;
      });
      return tTotalCount;
    }.property('collectionCount'),

    /**
     * Returns a single array containing all cases of all collections
     * @property {[DG.Case]}
     */
    allCases: function () {
      var tResult = [];
      this.forEachCollection(function (iCollection) {
        tResult = tResult.concat(iCollection.getPath('collection.cases'));
      });
      return tResult;
    }.property('collectionCount'),

    itemCount: function () {
      var dataSet = this.get('dataSet');
      return dataSet && dataSet.getDataItemCount();
    }.property(),

    dataSet: function () {
      return this.getPath('model.dataSet');
    }.property(),

    setAsideCount: function () {
      return this.get('dataSet').getSetAsideCount();
    }.property(),

    /**
     *  The collections for which this controller is responsible.
     *  Clients expect the order of this array to be parent --> child.
     *  This function is responsible for guaranteeing the order.
     *  In particular, games using the old API often create their
     *  collections in child --> parent order, and need to be reversed
     *  in this function.
     *
     *  @property {[DG.Collection]}
     */
    collectionsDidChange: function () {
      var srcCollections = this.getPath('model.collections'),
          srcCollectionArray = DG.ObjectMap.values(srcCollections),
          i, c,
          collectionCount = srcCollectionArray.length;

      // Reset and restock the cached array
      this.collections = [];

      // find the ur-parent, then follow it to all its children.
      c = srcCollectionArray[0];
      i = 0;
      if (c) {
        while (!SC.none(c.get('parent')) && i <= collectionCount) {
          c = c.get('parent');
          i++;
        }
        if (i > collectionCount) {
          DG.logError('Circular parental links among collections in context: ' + this.name);
        }
        i = 0;
        while (!SC.none(c) && i <= collectionCount) {
          this.collections.pushObject(c);
          c = c.get('children')[0];
          i++;
        }
        if (i > collectionCount) {
          DG.logError('Circular child links among collections in context: ' + this.name);
        }
      }

      // Return the cached array in the proper order
      return this.collections;
    }.observes('model.collectionsChangeCount'),

    /**
     *  Map of DG.CollectionClients, corresponding one-to-one to the DG.Collections.
     *  @property {Object} Map from collectionID to DG.CollectionClients
     */
    _collectionClients: null,

    /**
     * Whether there are Data Interactives which are affiliated with this
     * data context.
     * @type {boolean}
     */
    hasDataInteractive: function () {
      return !SC.none(this.get('owningDataInteractive'));
    }.property(),

    /**
     * Returns the Data Interactives for which are affiliated with this
     * data context.
     * @type {DG.GameController}
     */
    owningDataInteractive: function () {
      var dataInteractives = DG.currDocumentController().get('dataInteractives');
      var myID = this.get('id');
      var found = dataInteractives && DG.ObjectMap.values(dataInteractives).find(function (dataInteractive) {
        var id = (dataInteractive.getPath('context.id'));
        return (!SC.none(id) && (id === myID));
      }.bind(this));
      DG.assert(SC.none(found) || found.constructor === DG.GameController, "Found Game Controller");
      return found;
    }.property(),

    /**
     * Returns the Data Interactive which manages this data context.
     * May be generalized to support affiliation with other components at some point.
     * @type {DG.GameController}
     */
    managingController: function (key, value) {
      if (value != null) {
        this._managingControllerID = value;
        this.incrementProperty('metadataChangeCount');
      }

      // if no manager specified, default to owner
      if (this._managingControllerID == null)
        return this.get('owningDataInteractive');

      // search for manager
      var dataInteractives = DG.currDocumentController().get('dataInteractives');
      return dataInteractives &&
          DG.ObjectMap.values(dataInteractives)
              .find(function (dataInteractive) {
                var id = (dataInteractive.getPath('model.id'));
                return ((id != null) && (id === this._managingControllerID));
              }.bind(this));
    }.property(),

    /**
     * Whether there are Data Interactives for which are affiliated with this
     * data context.
     * @type {boolean}
     */
    hasGameInteractive: function () {
      var owningDataInteractive = this.get('owningDataInteractive');
      var activeChannel = owningDataInteractive && owningDataInteractive.activeChannel();
      // Its possible that the owning interactive has not contacted codap, so has not
      // established a channel. We assume this is a Game Interactive.
      if (owningDataInteractive) {
        return SC.none(activeChannel) || (activeChannel.constructor === DG.GamePhoneHandler);
      } else {
        return false;
      }
    }.property(),

    /**
     Initialization method.
     */
    init: function () {
      arguments.callee.base.apply(this,arguments);
      this._collectionClients = {};
      this.changes = [];
      this.collectionsDidChange();

      DG.globalsController.addObserver('globalNameChanges', this, 'globalNamesDidChange');
      DG.globalsController.addObserver('globalValueChanges', this, 'globalValuesDidChange');
    },

    /**
     Destruction method.
     */
    destroy: function () {
      DG.globalsController.removeObserver('globalNameChanges', this, 'globalNamesDidChange');
      DG.globalsController.removeObserver('globalValueChanges', this, 'globalValuesDidChange');

      var i, collectionCount = this.get('collectionCount');
      for (i = 0; i < collectionCount; ++i) {
        var collection = this.getCollectionAtIndex(i);
        if (collection) this.willRemoveCollection(collection);
      }
      this.model.destroy();
      arguments.callee.base.apply(this,arguments);
    },

    /**
     Returns an array of DG.Case objects corresponding to the selected cases.
     Optionally returns another array of DG.Case objects for the unselected cases.
     Note that the cases may come from multiple collections within the data context.
     @returns    {[DG.Case]}    The currently selected cases
     or
     {
                  selected: {Array of DG.Case}    The currently selected cases,
                  unselected: {Array of DG.Case}  The currently unselected cases
                }
     */
    getSelectedCases: function (iReturnUnselectedAlso) {
      var i, collectionCount = this.get('collectionCount'),
          selectedIds = {},
          selectedCases = [],
          unselectedCases = [];

      // utility function for adding individual cases to the selection object to return
      function addSelectedCase(iCase) {
        selectedCases.push(iCase);
        // parents of selected cases are considered selected when determining unselected
        for (; iCase; iCase = iCase.get('parent')) {
          selectedIds[iCase.get('id')] = true;
        }
      }

      function addCaseIfUnselected(selection, iCase) {
        if (!selection.contains(iCase) && !selectedIds[iCase.get('id')]) {
          unselectedCases.push(iCase);
        }
      }

      // add each selected case from all collections to the selection object to return
      for (i = collectionCount - 1; i >= 0; --i) {
        var collection = this.getCollectionAtIndex(i),
            collCases = iReturnUnselectedAlso && collection && collection.get('casesController'),
            collSelection = collection && collection.getPath('casesController.selection');
        if (collSelection)
          collSelection.forEach(addSelectedCase);
        if (collCases)
          collCases.forEach(addCaseIfUnselected.bind(null, collSelection));
      }
      return iReturnUnselectedAlso
          ? {selected: selectedCases, unselected: unselectedCases}
          : selectedCases;
    },

    /**
     * Accesses a case from its ID.
     *
     * Centralized method for Component layer objects.
     * @param iCaseID
     * @returns {*}
     */
    getCaseByID: function (iCaseID) {
      var iCase = DG.store.find(DG.Case, iCaseID);
      if (iCase && iCase instanceof DG.Case) return iCase;
    },


    /**
     Private properties used internally to synchronize changes with notifications.
     */
    _changeCount: 0,
    _prevChangeCount: 0,

    /**
     Returns the most-recently applied change object. Clients that observe the 'changeCount'
     property can call this function to determine what change triggered the notification.
     @property   {Object}    [computed] The most-recently applied change object
     */
    lastChange: function () {
      var count = this.changes.length;
      return count > 0 ? this.changes[count - 1] : null;
    }.property(),

    /**
     Returns an array of change objects which correspond to the changes that have
     occurred since the last change notification.
     @property   {[Object]}
     */
    newChanges: function () {
      var changesLength = this.changes && this.changes.length,
          newCount = this._changeCount - this._prevChangeCount;
      DG.assert(this._changeCount <= changesLength);
      DG.assert(this._prevChangeCount <= this._changeCount);
      return this.changes.slice(changesLength - newCount);
    }.property(),

    /**
     Apply the specified change object to this data context.
     @param    {Object}    iChange -- An object specifying the change(s) to apply
     {String}    iChange.operation -- The name of the change to apply
     Other change properties are operation-specific
     */
    applyChange: function (iChange) {
      var this_ = this,
          result = this.performChange(iChange);
      iChange.result = DG.ObjectMap.join((iChange.result || {}), result);
      // TODO: Figure out how/when to prune the changes array so it doesn't grow unbounded.
      this.changes.push(iChange);
      ++this._changeCount;

      // We may not be in a runloop if we got here through an event
      SC.run(function () {
        // Delay the notification until the end of the runloop, so that SproutCore has a
        // chance to flush its caches, update bindings, etc.
        this_.invokeLast(function () {
          this_.set('changeCount', this_._changeCount);
          this_._prevChangeCount = this_._changeCount;
        });
      });
      return iChange.result;
    },

    /**
     Performs the specified change(s) to this data context.
     Called by the applyChange() method.
     @param    {Object}    iChange -- An object specifying the change(s) to apply
     {String}    iChange.operation -- The name of the change to apply
     Other change properties are operation-specific
     */
    performChange: function (iChange) {
      // If the client indicates that the action has already
      // been taken, simply return with success.
      if (iChange.isComplete) return {success: true};


      var result = {success: false},
          shouldDirtyDoc = true,
          shouldRetainUndo = false;
      switch (iChange.operation) {
        case 'createCollection':
          result = this.doCreateCollection(iChange);
          break;
        case 'updateCollection':
          result = this.doUpdateCollection(iChange);
          break;
        case 'deleteCollection':
          result = this.doDeleteCollection(iChange);
          break;
        case 'createCase':
          // doCreateCases() takes an array of values arrays
          iChange.values = [iChange.values || []];
          result = this.doCreateCases(iChange);
          if (result.caseIDs && result.caseIDs.length)
            result.caseID = result.caseIDs[0];
          shouldRetainUndo = true;
          break;
        case 'createCases':
          result = this.doCreateCases(iChange);
          shouldRetainUndo = true;
          break;
        case 'updateCases':
          result = this.doUpdateCases(iChange);
          break;
        case 'moveCases':
          result = this.doMoveCases(iChange);
          break;
        case 'deleteCases':
          result = this.doDeleteCases(iChange);
          shouldDirtyDoc = false;
          break;
        case 'selectCases':
          result = this.doSelectCases(iChange);
          shouldDirtyDoc = false;
          break;
        case 'createItems':
          result = this.doCreateItems(iChange);
          shouldDirtyDoc = false;
          break;
        case 'updateItems':
          result = this.doUpdateItem(iChange);
          shouldDirtyDoc = false;
          break;
        case 'moveItems':
          result = this.doMoveItems(iChange);
          shouldDirtyDoc = false;
          break;
        case 'deleteItems':
          result = this.doDeleteItems(iChange);
          shouldDirtyDoc = false;
          break;
        case 'createAttributes':
          result = this.doCreateAttributes(iChange);
          break;
        case 'updateAttributes':
          result = this.doUpdateAttributes(iChange);
          break;
        case 'unhideAttributes':
        case 'hideAttributes':
          result = this.doChangeAttributesVisibility(iChange);
          break;
        case 'deleteAttributes':
          result = this.doDeleteAttributes(iChange);
          break;
        case 'moveAttribute':
          result = this.doMoveAttribute(iChange);
          shouldDirtyDoc = false;
          break;
        case 'resetCollections':
          result = this.doResetCollections(iChange);
          break;
        case 'deleteDataContext':
          result = this.destroy();
          break;
        case 'updateDataContext':
          result = this.doUpdateDataContext(iChange);
          break;
        default:
          DG.logWarn('DataContext.performChange: unknown operation: '
              + iChange.operation);
      }
      if (shouldDirtyDoc && (iChange.dirtyDocument !== false))
        DG.dirtyCurrentDocument(this.get('model'), shouldRetainUndo);
      return result;
    },

    /**
     Creates a collection according to the arguments specified.
     @param  {Object}                iChange
     {String}              iChange.operation -- 'createCollection'
     {Object}              iChange.properties -- properties of the new collection
     {Array of Object}     iChange.attributes -- array of attribute specifications
     @returns  {Object}              a result object
     {Boolean}           result.success -- true on success, false on failure
     {DG.CollectionClient} result.collection -- the newly created collection
     */
    doCreateCollection: function (iChange) {
      var tCollection = this.guaranteeCollection(iChange.properties);
      var results;
      if (tCollection) {
        iChange.attributes && iChange.attributes.forEach(function (iAttrSpec) {
          if (!SC.none(iAttrSpec.id) && !SC.none(iAttrSpec.collection)) {
            this.moveAttribute(iAttrSpec, tCollection);
          } else {
            tCollection.guaranteeAttribute(iAttrSpec);
          }
        }.bind(this));
        // if this is a recreation of the collection make sure the ordering corresponds
        // to DI expectations.
        iChange.attributes && tCollection.reorderAttributes(iChange.attributes.getEach('name'));
        results = this.regenerateCollectionCases();
        if (results) {
          return {success: true, collection: tCollection};
        }
      }
      return {success: false};
    },


    /**
     * Updates the properties of a collection.
     * @param {object} iChange
     *    {String}              iChange.operation -- 'updateCollection'
     *    {String|DG.CollectionClient} iChange.collection -- the affected collection
     *    {Object}              iChange.properties -- properties of the new collection
     * @returns {{success: boolean}}
     */
    doUpdateCollection: function (iChange) {
      var success = true;
      var updatedProperties = {};
      var kMetaProperties = ['name', 'title'];
      var collection = (SC.typeOf(iChange.collection) === SC.T_STRING)
          ? this.getCollectionByName(iChange.collection)
          : iChange.collection;
      DG.ObjectMap.forEach(iChange.properties, function (key, value) {
        if (kMetaProperties.contains(key)) {
          updatedProperties[key] = value;
          collection.set(key, value);
        } else {
          DG.logWarn('Attempt to update "%@" of collection %@[%@] not permitted.',
              key, collection.get('name'), collection.get('id'));
          delete iChange.properties.key;
        }
      }.bind(this));
      return {
        success: success,
        properties: updatedProperties
      };
    },
    /**
     * Updates the properties of a dataContext. That is: title, description, preventReorg...
     * @param {object} iChange
     *    {String}              iChange.operation -- 'updateDataContext'
     *    {Object}              iChange.properties -- new property values
     * @returns {{success: boolean}}
     */
    doUpdateDataContext: function (iChange) {
      var success = true;
      var updatedProperties = {};
      var kMetaProperties = ['name', 'title', 'preventReorg'];
      DG.ObjectMap.forEach(iChange.properties, function (key, value) {
        // name is not mutable
        if (kMetaProperties.contains(key)) {
          this.set(key, value);
          updatedProperties[key] = value;
        } else {
          DG.logWarn('Attempt to update "%@" of data context %@[%@] not permitted.',
              key, this.get('name'), this.get('id'));
          delete iChange.properties.key;
        }
      }.bind(this));
      return {
        success: success,
        properties: updatedProperties
      };

    },
    /**
     Creates one or more cases according to the arguments specified.
     @param  {Object}                iChange
     {String}                iChange.operation -- 'createCase'|'createCases'
     {DG.CollectionClient}   iChange.collection (optional) -- collection containing cases
     If not present, the case will be created in the child collection.
     {Array of               iChange.values -- The array of values to use for the case values.
             Arrays of Values}
     The order of the values should match the order of the attributes
     in the collection specification (e.g. 'initGame').
     @returns  {Object}              An object is returned
     {Boolean}             result.success -- true on success, false on failure
     {Number}              result.caseID -- the case ID of the first newly created case
     {[Number]}            result.caseIDs -- an array ids of all cases created
     {Number}              result.itemID -- the item ID of the first newly created item
     {[Number]}            result.itemIDs -- an array ids of all items created

     */
    doCreateCases: function (iChange) {
      function createOneCase(iValues) {
        var properties = {};
        var newCase;
        if (iChange.properties) {
          DG.ObjectMap.copy(properties, iChange.properties);
        }
        if (Array.isArray(iValues)) {
          newCase = collection.createCase(properties);
          if (newCase) {
            collection.setCaseValuesFromArray(newCase, iValues);
          }
        } else {
          properties.values = iValues;
          newCase = collection.createCase(properties);
        }
        if (newCase) {
          result.success = true;
          result.caseIDs.push(newCase.get('id'));
          result.itemIDs.push(newCase.item.id);
        }
      }

      /**
       * returns true if either the collection is a child collection or the parentKey
       * resolves to an existing parent.
       * @param parentKey {number}
       */
      var validateParent = function (collection, parentKey) {
        var rslt = true;
        var parentCollectionID = collection.getParentCollectionID();
        if (parentCollectionID) {
          rslt = !SC.none(this.getCaseByID(parentKey));
          if (!rslt) {
            DG.logWarn('Cannot create case with invalid or deleted parent: ' + parentKey);
          }
        }
        return rslt;
      }.bind(this);

      var collection,
          valuesArrays,
          parentIsValid = true,
          result = {success: false, caseIDs: [], itemIDs: []};

      if (!iChange.collection) {
        iChange.collection = this.get('childCollection');
      }
      if( !iChange.collection.casesController)
        iChange.collection = iChange.collection.get('name');

      if (typeof iChange.collection === "string") {
        collection = this.getCollectionByName( iChange.collection);
        iChange.collection = collection;  // Because we'll need it as an object later
      } else {
        collection = iChange.collection;
      }

      // we hold off on observers because of performance issues adding many
      // cases when some cases are selected
      collection.casesController.beginPropertyChanges();
      try {
        if (!iChange.properties) {
          iChange.properties = {};
        }

        if (typeof iChange.properties.parent !== 'object') {
          parentIsValid = validateParent(collection, iChange.properties.parent);
        }
        if (collection && parentIsValid) {
          valuesArrays = iChange.values || [[]];
          valuesArrays.forEach(createOneCase);
          if (result.caseIDs && (result.caseIDs.length > 0)) {
            result.caseID = result.caseIDs[0];
          }
          if (result.itemIDs && (result.itemIDs.length > 0)) {
            result.itemID = result.itemIDs[0];
          }
        }
      } finally {
        collection.casesController.endPropertyChanges();
      }

      // invalidate dependents; aggregate functions may need to recalculate
      this.invalidateAttrsOfCollections([collection], iChange);

      return result;
    },

    /**
     Adds new items to context.

     @param  {Object}                iChange
     {String}                iChange.operation -- 'createItems'
     {Array of DG.Case}      iChange.items (optional)-- DG.Item objects to be added
     {number}                iChange.requester -- ID of requesting object
     */
    doCreateItems: function (iChange) {

      var IDs = this.addItems(iChange.items);
      if (!IDs) {
        return {success: false};
      }
      var caseIDs = IDs.caseIDs;
      var itemIDs = IDs.itemIDs;

      return {success: true, caseIDs: caseIDs, itemIDs: itemIDs};
    },
    /**
     Updates values in one or more items

     @param  {Object}                iChange
     {String}                iChange.operation -- 'createItems'
     {Array of DG.Case}      iChange.items (optional)-- DG.Item objects to be added
     {number}                iChange.requester -- ID of requesting object
     */
    doUpdateItem: function (iChange) {
      function findCaseForItem(item, collection) {
        return collection.get('casesController').find(function (myCase) {
          return myCase.item.id === item.id;
        });
      }

      var itemsUpdate = iChange.items;
      if (itemsUpdate && !Array.isArray(itemsUpdate)) {
        itemsUpdate = [itemsUpdate];
      }
      var items = itemsUpdate.map(function (itemUpdate) {
        return this.updateItem(itemUpdate.id, itemUpdate.values);
      }.bind(this));
      var regenResults = this.regenerateCollectionCases();
      var deletedCases = regenResults && regenResults.deletedCases;
      var createdCases = regenResults && regenResults.createdCases;
      var deletedCaseIDs;
      var collectionIDCaseMap;
      var collections = [];

      var myCases = items.map(function (item) {
        var myCase = findCaseForItem(item, this.getLastCollection());
        return myCase && myCase.id;
      }.bind(this));
      var result = {
        success: true,
        changedCases: myCases,
        deletedCases: deletedCases,
        createCases: createdCases
      };
      if (myCases && myCases.length) {
        this.applyChange({
          operation: 'updateCases',
          collection: regenResults.collection,
          isComplete: true,
          requester: iChange.requester,
          result: result
        });
        return result;
      }
      if (deletedCases && deletedCases.length) {
        deletedCaseIDs = regenResults.deletedCases.map(function (iCase) {
          return iCase.id;
        });
        this.applyChange({
          operation: 'deleteCases',
          isComplete: true,
          requester: iChange.requester,
          result: {
            caseIDs: deletedCaseIDs
          }
        });
      }
      if (createdCases && createdCases.length) {
        createdCases.forEach(function (iCase) {
          var collectionID = iCase.collection.get('id');
          var collectionCases = collectionIDCaseMap[collectionID];
          if (!collectionCases) {
            collections.push(iCase.collection);
            collectionCases = collectionIDCaseMap[collectionID] = [];
          }
          collectionCases.push(iCase.get('id'));
        });

        DG.dirtyCurrentDocument(this.get('model'), false);

        collections.forEach(function (collection) {
          var cases = collectionIDCaseMap[collection.get('id')];
          var change = {
            operation: 'createCases',
            collection: this.getCollectionByID(collection.get('id')),
            isComplete: true,
            properties: {index: true},
            result: {
              caseIDs: cases,
              caseID: cases[0]
            }
          };
          this.applyChange(change);
        }.bind(this));
      }
    },

    doMoveItems: function (iChange) {
      var dataSet = this.get('dataSet');
      if (dataSet && iChange.items && (iChange.itemOrder != null)) {
        var oldIndexMap = dataSet.getClientIndexMapCopy();
        iChange.items.forEach(function (item, index) {
          var itemOrder = Array.isArray(iChange.itemOrder)
              ? iChange.itemOrder[index]
              : iChange.itemOrder;
          if (item.id) {
            dataSet.moveDataItemByID(item.id, itemOrder);
          }
        });
        var newIndexMap = dataSet.getClientIndexMapCopy();
        var isChanged = !newIndexMap
            .every(function (itemIndex, arrayIndex) {
              return oldIndexMap[arrayIndex] === itemIndex;
            });
        if (isChanged) {
          this.regenerateCollectionCases(null, 'moveCases');
        }
      }
    },

    /**
     Deletes items in this context.

     @param  {Object}                iChange
     {String}                iChange.operation -- 'createItems'
     {Array of DG.Case}      iChange.items (optional)-- DG.Item objects to be added
     {number}                iChange.requester -- ID of requesting object
     */
    doDeleteItems: function (iChange) {
      var deletedCaseIDs;
      var deletedItems = this.deleteItems(iChange.items);
      var regenResults = this.regenerateCollectionCases();
      if (regenResults) {
        deletedCaseIDs = regenResults.deletedCases.map(function (iCase) {
          return iCase.id;
        });
        this.applyChange({
          operation: 'deleteCases',
          isComplete: true,
          requester: iChange.requester,
          result: {
            caseIDs: deletedCaseIDs
          }
        });
        return {
          deletedCaseIDs: deletedCaseIDs,
          deletedItemIDs: deletedItems && deletedItems.map(function (item) {
            return item.id;
          })
        };
      } else {
        return {success: false};
      }

    },
    /**
     Selects/deselects the specified cases.

     @param  {Object}                iChange
     {String}                iChange.operation -- 'selectCases'
     {DG.CollectionClient}   iChange.collection (optional) -- collection containing cases
     If not present, collection will be looked up from cases,
     which is less efficient but more flexible.
     {Array of DG.Case}      iChange.cases (optional)-- DG.Case objects to be changed
     If not present, all cases in collection will be changed.
     {Boolean}               iChange.select -- true for selection, false for deselection
     {Boolean}               iChange.extend -- true to extend the current selection
     */
    doSelectCases: function (iChange) {
      var tCollection = iChange.collection || this.get('childCollection'),
          tController = tCollection && tCollection.get('casesController'),
          tExtend = iChange.extend || false,
          tCollectionExtendMap = {},
          tCollectionSelectionMap = {},
          isSelectionChanged = false,
          this_ = this;

      // First selection change for each collection should respect iChange.extend.
      // Subsequent changes for each collection should always extend, otherwise
      // they wipe out any selection done previously.
      function extendForCollection(iCollection) {
        var collectionID = iCollection.get('id').toString();
        if (tCollectionExtendMap[collectionID] === undefined) {
          tCollectionExtendMap[collectionID] = true;
          return tExtend;
        }
        // After the first one, always return true
        return true;
      }

      function addSelectionToCollectionMap(iCollection, iCase) {
        var collectionID = iCollection.get('id').toString();
        if (tCollectionSelectionMap[collectionID] === undefined) {
          tCollectionSelectionMap[collectionID] = {collection: iCollection, cases: []};
        }
        tCollectionSelectionMap[collectionID].cases.push(iCase);
      }

      function doSelectByCollection() {
        DG.ObjectMap.forEach(tCollectionSelectionMap, function (iCollectionID, iCaseMap) {
          var tCollection = iCaseMap.collection,
              tCases = iCaseMap.cases,
              tController = tCollection.get('casesController');
          tController.selectObjects(tCases, extendForCollection(tCollection));
        });
      }

      function doDeselectByCollection() {
        DG.ObjectMap.forEach(tCollectionSelectionMap, function (iCollectionID, iCaseMap) {
          var tCollection = iCaseMap.collection,
              tCases = iCaseMap.cases,
              tController = tCollection.get('casesController');
          tController.deselectObjects(tCases);
        });
      }

      // utility function for recursively selecting a case and its children
      function selectCaseAndChildren(iCase) {
        var tChildren = iCase.get('children'),
            tCollection = this_.getCollectionForCase(iCase),
            tController = tCollection && tCollection.get('casesController');
        if (tController) {
          var tSelection = tController.get('selection');
          if (tSelection && (!tSelection.contains(iCase) || (tSelection.length() > 1)))
            isSelectionChanged = true;
          //tController.selectObject( iCase, extendForCollection( tCollection));
          addSelectionToCollectionMap(tCollection, iCase);
          tChildren.forEach(selectCaseAndChildren);
        }
      }

      // utility function for recursively deselecting a case and its children
      function deselectCaseAndChildren(iCase) {
        var tChildren = iCase.get('children'),
            tCollection = this_.getCollectionForCase(iCase),
            tController = tCollection && tCollection.get('casesController');
        if (tController) {
          var tSelection = tController.get('selection');
          if (tSelection && tSelection.contains(iCase))
            isSelectionChanged = true;
          //tController.deselectObject( iCase);
          addSelectionToCollectionMap(tCollection, iCase);
          tChildren.forEach(deselectCaseAndChildren);
        }
      }

      // If cases aren't specified, assume select/deselect all
      var tCases = iChange.cases || tController,
          // Use the appropriate utility function for the job
          tFunction = iChange.select ? selectCaseAndChildren : deselectCaseAndChildren;
      // DG.log('selectCases: %@ %@ cases'.loc(iChange.select?'select':'deselect', tCases? tCases.get('length'): 0));

      if (iChange.select && !iChange.extend && tCases.length === 0) {
        this.forEachCollection(function (iCollectionClient) {
          var tController = iCollectionClient.get('casesController');
          tController.selectObject(); // deselect all
        });
        this.incrementProperty('selectionChangeCount');
        return {success: true};
      } else {
        // Apply the appropriate function to the specified cases
        if (tCases && tFunction) {
          tCases.forEach(tFunction);
          if (iChange.select) {
            doSelectByCollection();
          } else {
            doDeselectByCollection();
          }
        }

      }

      // If we are only selecting cases in child collection(s), we should
      // deselect any parent level cases when we're not extending.
      // Note that the current behavior is to always deselect all cases in
      // a parent collection after changing the selection in a child collection.
      // This is less ambitious than full synchronization, whereby individually
      // selecting all of the child cases of a single parent collection could
      // auto-select the parent collection as well (or vice-versa).
      if (isSelectionChanged) {
        this.forEachCollection(function (iCollectionClient) {
          var collectionID = iCollectionClient.get('id'),
              tController = iCollectionClient.get('casesController');
          if (collectionID && tController &&
              !extendForCollection(iCollectionClient)) {
            tController.selectObject(); // deselect all
          }
        });
        this.incrementProperty('selectionChangeCount');
      }

      return {success: true};
    },

    /**
     Changes the specified values of the specified cases, providing an array of values.

     @param  {Object}                iChange
     {String}                iChange.operation -- 'updateCases'
     {DG.CollectionClient}   iChange.collection (optional) -- collection containing cases
     If not present, collection will be looked up from case,
     which is less efficient but more flexible.
     {Array of Number}       iChange.attributeIDs (optional) -- attributes whose values
     are to be changed for each case.
     If not specified, all attributes are changed.
     {Array of DG.Case}      iChange.cases -- DG.Case objects to be changed
     {Array of Array of      If attributeIDs are specified, then the values are stored in
             values}       attribute-major fashion, i.e. there is an array of values for
     each attribute with a value for each case in each of the arrays.
     If attributeIDs are not specified, then the values are stored in
     case-major fashion, with an array of values for each case.
     The latter is used primarily for case creation using the Game API.
     */
    doUpdateCasesFromArrayOfValues: function (iChange) {
      var caseCount = iChange.cases.get('length'),
          attrCount = iChange.attributeIDs ? iChange.attributeIDs.get('length') : 0,
          valueArrayCount = iChange.values.get('length'),
          attrSpecs = [],
          caseIDs,
          a, c;

      // If no attributes were specified, set them all using setCaseValuesFromArray().
      // This is primarily used by the Game API to set all values of a case.
      if ((caseCount > 0) && (attrCount === 0) && (valueArrayCount > 0)) {
        iChange.cases.forEach(function (iCase, iIndex) {
          if (iCase && !iCase.get('isDestroyed'))
            this.setCaseValuesFromArray(iCase, iChange.values[iIndex], iChange.collection);
        }.bind(this));
        caseIDs = iChange.cases.map(function (iCase) {
          return iCase.id;
        });
        return {success: true, caseIDs: caseIDs};
      }

      // If attributes are specified, set the values individually.
      iChange.caseIDs = [];
      // Look up the attributes
      for (a = 0; a < attrCount; ++a) {
        var attrID = iChange.attributeIDs.objectAt(a),
            attrSpec = this.getAttrRefByID(attrID);
        attrSpec.attributeID = attrID;
        attrSpecs.push(attrSpec);
      }

      // Loop through the cases
      for (c = 0; c < caseCount; ++c) {
        var tCase = iChange.cases.objectAt(c);
        iChange.caseIDs.push(tCase.get('id'));
        // Change the case values
        tCase.beginCaseValueChanges();
        // Loop through the attributes setting each value
        for (a = 0; a < attrCount; ++a) {
          tCase.setValue(attrSpecs[a].attributeID, iChange.values[a][c]);
        }
        tCase.endCaseValueChanges();
      }

      // invalidate dependents
      var hasGroupingAttr = false,
          attrNodes = attrSpecs.map(function (iSpec) {
            var attr = DG.Attribute.getAttributeByID(iSpec.attributeID);
            if (!hasGroupingAttr && attr.getPath('collection.children'))
              hasGroupingAttr = true;
            return {
              type: DG.DEP_TYPE_ATTRIBUTE, id: iSpec.attributeID,
              name: attr.get('name')
            };
          });
      if (hasGroupingAttr) this.regenerateCollectionCases(null, 'updateCases');
      this.invalidateDependentsAndNotify(attrNodes, iChange);

      return {success: true, caseIDs: iChange.caseIDs};
    },
    /**
     * Changes the specified values of the specified cases providing a hash keyed by attribute name.
     *
     * @param  {Object}                iChange
     *         {String}                iChange.operation -- 'updateCases'
     *         {DG.CollectionClient}   iChange.collection (optional) -- collection containing cases
     *                                 If not present, collection will be looked up from case,
     *                                 which is less efficient but more flexible.
     *         {[DG.Case]}             iChange.cases -- DG.Case objects to be changed
     *         {[Object]}              iChange.values -- Array of hashes keyed by attribute names.
     */
    doUpdateCasesFromHashOfNameValues: function (iChange) {
      var cases = iChange.cases;
      var success = true;
      var attrs = {};
      var caseIDs = [];
      cases.forEach(function (iCase, iCaseIx) {
        var values = iChange.values[iCaseIx];
        caseIDs.push(iCase.id);
        if (values) {
          iCase.beginCaseValueChanges();
          DG.ObjectMap.forEach(values, function (key, value) {
            var attr = this.getAttributeByName(key)
                || this.getAttributeByName(this.canonicalizeName(key));
            if (attr) {
              attrs[attr.id] = attr;
              iCase.setValue(attr.id, value);
            } else {
              DG.logWarn('DataContext.doUpdateCasesFromHashOfNameValues: Cannot resolve attribute: ' + key);
              success = false;
            }
          }.bind(this));
          iCase.endCaseValueChanges();
        }
      }.bind(this));

      var attrNodes = [],
          hasGroupingAttr = false;
      DG.ObjectMap.forEach(attrs, function (id, attr) {
        if (!hasGroupingAttr && attr.getPath('collection.children'))
          hasGroupingAttr = true;
        attrNodes.push({type: DG.DEP_TYPE_ATTRIBUTE, id: attr.id, name: attr.get('name')});
      });
      if (hasGroupingAttr) this.regenerateCollectionCases(null, 'updateCases');
      this.invalidateDependentsAndNotify(attrNodes, iChange);

      return {success: success, caseIDs: caseIDs};
    },

    /*
   * Update case values.
   *
   * Supports updating from an array of values or a hash of attribute name/values.
   * See methods above.
   */
    doUpdateCases: function (iChange) {
      if (iChange.values && iChange.values[0] && Array.isArray(iChange.values[0])) {
        return this.doUpdateCasesFromArrayOfValues(iChange);
      } else {
        return this.doUpdateCasesFromHashOfNameValues(iChange);
      }
    },

    /*
   * Change the order of cases within the collection.
   */
    doMoveCases: function (iChange) {
      var cases = iChange.cases;
      var changeCount = cases.length;
      var success = true;
      var caseIDs = [];
      cases.forEach(function (iCase, iIndex) {
        var collection = iCase.get('collection');
        var caseOrder = Array.isArray(iChange.caseOrder)
            ? iChange.caseOrder[iIndex]
            : iChange.caseOrder;
        // only update the ID map after the last case
        var skipIDMapUpdate = iIndex < changeCount - 1;
        if (caseOrder === 'first') {
          collection.moveCase(iCase, 0, skipIDMapUpdate);
        } else if (caseOrder === 'last') {
          var caseCount = collection.getPath('cases.length');
          collection.moveCase(iCase, caseCount - 1, skipIDMapUpdate);
        } else {
          collection.moveCase(iCase, caseOrder, skipIDMapUpdate);
        }
        // Note that when a sort occurs, all of the caseIDs are listed.
        // In this case, we could list all of the cases affected, i.e. all of
        // the cases whose indices were changed, or simply list all of the
        // cases as is true when sorting. In point of fact, however, there
        // don't appear to be any clients that use this information, so
        // simply listing the IDs of the cases that were actually moved
        // seems sufficient.
        caseIDs.push(iCase.id);
      });
      return {success: success, caseIDs: caseIDs};
    },

    /**
     Deletes the specified cases along with any child cases.
     @param  {Object}                iChange
     {String}                iChange.operation -- 'deleteCases'
     {Array of DG.Case}      iChange.cases -- DG.Case objects to be deleted
     {Array of Number}       iChange.ids -- on output, the IDs of the deleted cases
     */
    deleteCasesAndChildren: function (iChange) {
      var tSetAside = iChange.setAside;
      var tNewChange;
      var items = {};

      function assembleItems(iCase) {
        var children = iCase.get('children');
        var item = iCase.get('item');
        items[item.id] = item;
        if (children) {
          children.forEach(assembleItems);
        }
      }

      if (iChange.cases) {
        iChange.cases.forEach(assembleItems);
        this.deleteItems(Object.values(items), tSetAside);
        tNewChange = this.regenerateCollectionCases(null, 'deleteCases');
      }
      return tNewChange.deletedCases;
    },

    /**
     Deletes the specified cases along with any child cases.
     @param  {Object}                iChange
     {String}                iChange.operation -- 'deleteCases'
     {Array of DG.Case}      iChange.cases -- DG.Case objects to be deleted
     {Array of Number}       iChange.ids -- on output, the IDs of the deleted cases
     */
    doDeleteCases: function (iChange) {
      var deletedCases = [],
          this_ = this,
          allCollections = this.collections;

      DG.UndoHistory.execute(DG.Command.create({
        name: "data.deleteCases",
        undoString: 'DG.Undo.data.deleteCases',
        redoString: 'DG.Redo.data.deleteCases',
        _beforeStorage: {
          context: this
        },
        execute: function () {
          // Delete each case
          deletedCases = this_.deleteCasesAndChildren(iChange);

          // invalidate dependents; aggregate functions may need to recalculate
          this_.invalidateAttrsOfCollections(this_.collections, iChange);

          // Store the set of deleted cases, along with their values
          this._beforeStorage.deletedCases = deletedCases;
          this.log = "Deleted %@ case%@"
              .fmt(deletedCases.length, deletedCases.length === 1 ? "" : "s");
        },
        undo: function () {
          var createdCases;

          // add cases back in collection order
          allCollections.forEach(function (iCollection) {
            this._beforeStorage.deletedCases.forEach(function (iCase, ix) {
              var item = iCase.item;
              var myCollection = iCase.collection;
              if (myCollection && myCollection === iCollection) {
                item.set('deleted', false);
                item.set('setAside', false);
                // Note that we don't call addCase because the case in hand
                // has been destroyed. We allow regenerateCollectionCases to
                // actually bring about the addition of the case.
                // myCollection.addCase(iCase);
              }
            });
          }.bind(this));
          createdCases = this._beforeStorage.context.regenerateCollectionCases().createdCases;
          var tCollectionMap = {};
          createdCases.forEach(function (iCase) {
            var tCollID = iCase.getPath('collection.id');
            if (!tCollectionMap[tCollID]) {
              tCollectionMap[tCollID] = [];
            }
            tCollectionMap[tCollID].push(iCase.get('id'));
          });
          // emit change notifications for created cases.
          DG.ObjectMap.forEach(tCollectionMap, function (collectionID, caseIDs) {
            var undoChange = {
              operation: 'createCases',
              isComplete: true,
              properties: {index: true},
              collections: [this_.getCollectionByID(collectionID)],
              result: {
                caseIDs: caseIDs,
                caseID: caseIDs[0]
              }
            };
            this_.applyChange(undoChange);
          });

          this._afterStorage = {
            cases: createdCases
          };

          // invalidate dependents; aggregate functions may need to recalculate
          this_.invalidateAttrsOfCollections(this_.collections, iChange);
        },
        redo: function () {
          this.execute();
        }
      }));

      return {success: true};
    },

    /**
     * This is really a misleadingly named method. Should be guaranteeAttributes.
     * It is used to create attributes if the attributes don't exist or update
     * their properties, if they do.
     *
     * It may be used in an undo. Undo of formula create expects different
     * behavior from from normal formula delete. Normal formula delete overwrites
     * underlying data. Undo should not.
     *
     * @param iChange
     *
     * @return {{attrIDs: *[], success: boolean, attrs: *[]}}
     */
    doCreateAttributes: function (iChange) {
      var collectionClient = typeof iChange.collection === "string"
          ? this.getCollectionByName(iChange.collection)
          : iChange.collection,
          attrNames = [],
          didCreateAttribute = false,
          result = {success: false, attrs: [], attrIDs: []},
          _this = this;

      // Create/update the specified attribute
      function createAttribute(iAttrProps) {
        if (!iAttrProps) {
          return;
        }
        var hadAttribute = collectionClient.hasAttribute(iAttrProps.name),
            attrProps = DG.copy(iAttrProps),
            attribute;
        // User-created attributes default to editable
        if (!hadAttribute)
          attrProps.editable = true;

        attribute = collectionClient.guaranteeAttribute(attrProps, iChange.isUndo);
        if (!SC.none(iChange.position)) {
          _this.moveAttribute(attribute, collectionClient, iChange.position);
        }
        if (attribute) {
          if (!hadAttribute)
            didCreateAttribute = true;
          attrNames.push(attribute.get('name'));
          // For now, return success if any attribute is created successfully
          result.success = true;
          result.attrs.push(attribute);
          result.attrIDs.push(attribute.get('id'));
        }
      }

      // Create/update each specified attribute
      if (collectionClient && iChange.attrPropsArray)
        iChange.attrPropsArray.forEach(createAttribute);
      this.invalidateNamesAndNotify(attrNames);
      // For now we assume success
      if (!didCreateAttribute)
        iChange.operation = 'updateAttributes';
      return result;
    },

    /**
     * fixes formulas affected by an attribute name change
     * @param iAttr
     * @param iNewName
     * @private
     */
    _handleAttrNameChange: function (iAttr, iNewName, iChange) {
      var response = [];
      if (iNewName == null || iAttr.name === iNewName) {
        return;
      }
      var node = this.get('dependencyMgr').findNode({type:DG.DEP_TYPE_ATTRIBUTE, id: iAttr.id});
      if (node) {
        var dependents = node.dependents;
        dependents.forEach(function (dep) {
          if (dep.type === 'attribute') {
            var attrSpec = this.getAttrRefByID(dep.id);
            var attr = attrSpec && attrSpec.attribute;
            var formula = attr && attr._dgFormula;
            var parseObj = formula && formula.get('parsed');
            var newFormula = parseObj && DG.Formula.toString(DG.Formula.renameVariable(parseObj, iAttr.name, iNewName));
            if (newFormula) {
              response.push({
                operation: 'updateAttributes',
                collection: attr.collection,
                attrPropsArray: [{id: attr.id, formula: newFormula}]
              });
            }
          }
        }.bind(this));
      }
      return response;
    },

    /**
     Updates the specified properties of the specified attributes.
     @param  {Object}    iChange - The change request object
     {String}  .operation - "updateAttributes"
     {DG.CollectionClient} .collection - Collection whose attributes(s) are changed
     {Array of Object} .attrPropsArray - Array of attribute properties
     @returns  {Object}
     {Boolean}               .success
     {Array of DG.Attribute} .attrs
     {Array of Number}       .attrIDs
     */
    doUpdateAttributes: function (iChange) {
      var collection = typeof iChange.collection === "string"
          ? this.getCollectionByName(iChange.collection)
          : iChange.collection,
          names = [],
          result = {success: false, attrs: [], attrIDs: []};

      // Function to update each individual attribute
      function updateAttribute(iAttrProps) {
        // Look up the attribute by ID if one is specified
        var attribute = collection && !SC.none(iAttrProps.id)
            ? collection.getAttributeByID(iAttrProps.id)
            : null;

        // Look up the attribute by name if not found by ID
        if (!attribute && collection && iAttrProps.name) {
          attribute = collection.getAttributeByName(iAttrProps.name);
        }
        if (attribute) {
          attribute.beginPropertyChanges();
          DG.ObjectMap.forEach(iAttrProps,
              function (iKey, iValue) {
                var actions;
                var oldName;
                if (iKey === 'name') {
                  actions = _this._handleAttrNameChange(attribute, iAttrProps.name, iChange);
                  oldName = attribute.get('name');
                  if (names.indexOf(oldName) < 0)
                    names.push(oldName);
                  iValue = DG.Attribute.canonicalizeName(iValue);
                  if (names.indexOf(iValue) < 0)
                    names.push(iValue);
                }
                if (iKey !== "id") {
                  attribute.set(iKey, iValue);
                }
                if (actions) {
                  actions.forEach(function (action) {
                    _this.applyChange(action);
                  });
                }
              });
          attribute.endPropertyChanges();
          result.success = true;
          result.attrs.push(attribute);
          result.attrIDs.push(attribute.get('id'));
        }
      }

      var _this = this;
      // Create/update each specified attribute
      if (collection && iChange.attrPropsArray)
        iChange.attrPropsArray.forEach(updateAttribute);

      // invalidate affected formulas
      this.invalidateNamesAndNotify(names);

      return result;
    },

    doRerandomizeAll: function() {
      var dependencyMgr = this.get('dependencyMgr'),
         randomNode = dependencyMgr &&
                      dependencyMgr.findNode({ type: DG.DEP_TYPE_SPECIAL,
                        id: 'random' });
      this.invalidateDependentsAndNotify([randomNode]);
    },

    /**
     * Regenerates the case lists for all the collections in the context using the
     * dataSet as a reference.
     *
     * May create or delete cases as necessary. Tries to avoid unnecessary creation
     * or destruction.
     *
     * @param affectedCollections {[CollectionClient]}
     * @param [notifyOperation] {string} Optional operation name for use in response
     * @return {object} Change object. If notifyOperation is not set returns an
     *    object with the following properties: collections {[CollectionClient]},
     *    createdCases {[Case]}, deletedCases {[Case]}. If notifyOperation is set, returns an
     *    object with the following properties: operation {string}, isComplete {true},
     *    result {{cases: {[Case]}}}, collections {[CollectionClient]},
     *    createdCases {[Case]}, deletedCases {[Case]}.
     */
    regenerateCollectionCases: function (affectedCollections, notifyOperation) {
      var topCollection = this.getCollectionAtIndex(0),
          collections = {},   // map from id to collection
          createdCases,       // array of created cases
          deletedCases = [];  // array of deleted cases

      function addTrackedCollection(collection) {
        var collectionID = collection && collection.get('id');
        if (collectionID && !collections[collectionID])
          collections[collectionID] = collection;
        // child collections are affected as well
        var children = collection && collection.get('children');
        if (children) {
          children.forEach(function (child) {
            addTrackedCollection(child);
          });
        }
      }

      if (affectedCollections && affectedCollections.length) {
        affectedCollections.forEach(function (collection) {
          addTrackedCollection(collection);
        });
      }

      // drop all cases
      this.forEachCollection(function (collection) {
        collection.markCasesForDeletion();
      });

      // starting with top collection, recreate cases
      // we pause property observers on the collection cases controllers to
      // avoid performance issues with selected cases.
      this.forEachCollection(function (collectionClient) {
        collectionClient.casesController.beginPropertyChanges();
      });
      try {
        createdCases = topCollection.get('collection').recreateCases();
      } finally {
        this.forEachCollection(function (collectionClient) {
          collectionClient.casesController.endPropertyChanges();
        });
      }

      // track affected collections
      if (createdCases) {
        createdCases.forEach(function (iCase) {
          addTrackedCollection(iCase.get('collection'));
        });
      }

      // delete cases that remain marked for deletion
      this.beginPropertyChanges();
      try {
        this.forEachCollection(function (collection) {
          var collectionDeletedCases = collection.deleteMarkedCases();
          deletedCases = deletedCases.concat(collectionDeletedCases);
          if (deletedCases && deletedCases.length)
            addTrackedCollection(collection);
        }.bind(this));
      } finally {
        this.endPropertyChanges();
      }

      // sort collections
      topCollection.get('collection').reorderCases(0, []);
      this.forEachCollection(function (collection) {
        collection.didDeleteCases();
      });
      var change = {
        collections: DG.ObjectMap.values(collections),
        createdCases: createdCases, deletedCases: deletedCases
      };
      if (notifyOperation) {
        change.operation = notifyOperation;
        change.isComplete = true;
        change.result = {
          caseIDs: createdCases.map(function (iCase) {
            return iCase.id;
          })
        };
        this.applyChange(change);
      }
      return change;
    },

    /**
     * Adds items to a data set and updates collections to regenerate cases.
     * Accepts an array of items or a single item. The item can be specified as
     * a DG.DataItem or as an object mapping attribute names to values. Adds
     * an "createCases" item to the change list and returns a list of new case IDs.
     * The new cases may be cases of any collection in the data set.
     *
     * @param iItems {[Object] || [DG.DataItem] || Object || DG.DataItem}
     * @param iBeforeItemID {number|string}
     * @return an array of cases created as a consequence of item creation
     */
    addItems: function (iItems, iBeforeItemID) {
      var dataSet = this.getPath('model.dataSet');
      var items = Array.isArray(iItems) ? iItems : (iItems ? [iItems] : []);
      var attrs = this.getAttributes();
      var results;
      var collections = [];
      var collectionIDCaseMap = {};
      var change;
      items.forEach(function (item, index) {
        var canonicalItem = item instanceof DG.DataItem
            ? item
            : DG.DataUtilities.canonicalizeAttributeValues(attrs, item);
        dataSet.addDataItem(canonicalItem, iBeforeItemID);
      });
      results = this.regenerateCollectionCases();

      // We should never be deleting cases while creating items.
      DG.assert(results && (!results.deletedCases || results.deletedCases.length === 0), 'Unexpected deleted cases');
      results.createdCases.forEach(function (iCase) {
        var collectionID = iCase.collection.get('id');
        var collectionCases = collectionIDCaseMap[collectionID];
        if (!collectionCases) {
          collections.push(iCase.collection);
          collectionCases = collectionIDCaseMap[collectionID] = [];
        }
        collectionCases.push(iCase.get('id'));
      });

      DG.dirtyCurrentDocument(this.get('model'), false);

      if (results && results.createdCases.length > 0) {
        collections.forEach(function (collection) {
          var cases = collectionIDCaseMap[collection.get('id')];
          change = {
            operation: 'createCases',
            collection: this.getCollectionByID(collection.get('id')),
            isComplete: true,
            properties: {index: true},
            result: {
              caseIDs: cases,
              caseID: cases[0]
            }
          };
          this.applyChange(change);
        }.bind(this));
      }

      this.invalidateAttrsOfCollections(collections, change);

      // generate object containing case and item ids
      function createIdObject() {
        var caseIDs = [];
        var itemIDs = [];
        results.createdCases.forEach(function (iCase) {
          caseIDs.push(iCase.id);
          itemIDs.push(iCase.item.id);
        });
        return {caseIDs: caseIDs, itemIDs: itemIDs};
      }

      return results && createIdObject();
    },

    /**
     * Updates an item.
     * @param iItemID {number}
     * @param iValues {object} changed value array
     * @return {DG.Item}
     */
    updateItem: function (iItemID, iValues) {
      var dataSet = this.getPath('model.dataSet');
      return dataSet.updateItem(iItemID, iValues);
    },

    /*
   * Marks items in a dataset for deletion. Accepts an array of items or an
   * individual item. Issues a deleteCases change notice listing the deleted
   * cases. Returns the list of deleted cases.
   * @param iItems {DG.Item|[DG.Item]}
   * @return {[DG.ITEM]} Array of items.
   */
    deleteItems: function (iItems, iSetAside) {
      var dataSet = this.getPath('model.dataSet');
      if (!Array.isArray(iItems)) {
        iItems = [iItems];
      }
      iItems.forEach(function (item) {
        if (!SC.none(item)) {
          dataSet.deleteDataItem(item, iSetAside);
        } else {
          DG.logWarn('Attempt to delete non-Item.');
        }
      });
      return iItems;
    },

    _moveAttributeWithinCollection: function (attr, collectionClient, position) {
      var dataContext = this;
      var name = attr.name;
      var attributeNames = collectionClient.getAttributeNames();
      var ix = attributeNames.indexOf(name);
      var newPosition = constrainInt(position, 0, attributeNames.get('length'));
      var changeFlag = this.get('flexibleGroupingChangeFlag');
      var beforeAttributeNames = attributeNames.slice();
      var adjustedNew = (ix >= newPosition) ? newPosition : newPosition - 1;
      attributeNames.removeAt(ix);
      attributeNames.insertAt(adjustedNew, name);
      var afterAttributeNames = attributeNames.slice();

      if (ix !== -1) {
        DG.UndoHistory.execute(DG.Command.create({
          name: 'dataContext.moveAttribute',
          undoString: 'DG.Undo.dataContext.moveAttribute',
          redoString: 'DG.Redo.dataContext.moveAttribute',
          log: 'move attribute {attribute: "%@", position: %@}'
              .loc(attr.name, position),
          execute: function () {
            DG.log('Moving Attribute from: ' + ix + ' to: ' + adjustedNew + ' (' + newPosition + ')');
            collectionClient.reorderAttributes(afterAttributeNames);
            dataContext.set('flexibleGroupingChangeFlag', true);
          },
          undo: function () {
            DG.log('Undo move of Attribute from: ' + ix + ' to: ' + adjustedNew + ' (' + newPosition + ')');
            collectionClient.reorderAttributes(beforeAttributeNames);
            dataContext.set('flexibleGroupingChangeFlag', changeFlag);

            // notify about this change, but mark as complete, so
            // it is not re-executed
            var tChange = {
              isComplete: true,
              operation: 'moveAttribute',
              attr: attr,
              toCollection: collectionClient,
              position: ix
            };
            dataContext.applyChange(tChange);
          },
          redo: function () {
            DG.log('Redo move of Attribute from: ' + ix + ' to: ' + adjustedNew + ' (' + newPosition + ')');
            collectionClient.reorderAttributes(afterAttributeNames);
            dataContext.set('flexibleGroupingChangeFlag', true);
            // notify
            var tChange = {
              isComplete: true,
              operation: 'moveAttribute',
              attr: attr,
              toCollection: collectionClient,
              position: position
            };
            dataContext.applyChange(tChange);
          }
        }));
      } else {
        DG.logWarn('Reordering attribute, "' + name +
            '", not in collection, "' + collectionClient.get('name') + '"');
      }
    },

    _moveAttributeBetweenCollections: function (iAttr, fromCollection, toCollectionClient, position) {
      var dataContext = this;
      var allCollections = this.collections;
      var fromCollectionProperties = {
        parent: fromCollection.parent,
        id: fromCollection.get('id'),
        name: fromCollection.get('name'),
        title: fromCollection.get('title'),
        context: fromCollection.get('context'),
        children: [fromCollection.children && fromCollection.children[0]]
      };
      var attrID = iAttr.get('id');
      var toCollection = toCollectionClient.get('collection');
      DG.log('Moving attribute, ' + iAttr.get('name') + ', from "' +
          fromCollection.get('name') + '" to "' + toCollectionClient.get('name') + '"');
      var originalPosition = fromCollection.get('attrs').findIndex(function (attr) {
        return attr === iAttr;
      });
      var attrCount = toCollectionClient.getAttributeCount();
      var newPosition = constrainInt(position, 0, attrCount);
      DG.assert(originalPosition !== -1, 'Moving attribute is found in original collection');
      var casesAffected;

      // remove attribute from old collection
      DG.UndoHistory.execute(DG.Command.create({
        name: 'dataContext.moveAttribute',
        undoString: 'DG.Undo.dataContext.moveAttribute',
        redoString: 'DG.Redo.dataContext.moveAttribute',
        log: 'move attribute {attribute: "%@", position: %@}'
            .loc(iAttr.name, position),
        execute: function () {
          iAttr.beginPropertyChanges();
          var collection = iAttr.collection;
          iAttr = collection.removeAttribute(iAttr);

          if (collection.get('attrs').length === 0) {
            dataContext.destroyCollection(collection);
            dataContext.applyChange({
              operation: 'deleteCollection',
              collection: fromCollection,
              isComplete: true
            });
          }

          // add attribute to new collection
          toCollection.addAttribute(iAttr, newPosition);

          casesAffected = dataContext.regenerateCollectionCases([collection, toCollection]);
          dataContext.invalidateAttrsOfCollections(casesAffected.collections);
          dataContext.invalidateNamesAndNotify([iAttr.name]);
          iAttr.endPropertyChanges();
        },
        undo: function () {
          var tAttr = DG.Attribute.getAttributeByID(attrID);
          var toCollection = tAttr.collection;
          var newCollection;
          toCollection.removeAttribute(tAttr);
          if (toCollection.get('attrs').length === 0) {
            dataContext.destroyCollection(toCollection);
            dataContext.applyChange({
              operation: 'deleteCollection',
              collection: toCollection,
              isComplete: true
            });
          }
          // add cases back in collection order
          allCollections.forEach(function (iCollection) {
            casesAffected.deletedCases.forEach(function (iCase, ix) {
              var item = iCase.item;
              var myCollection = iCase.collection;
              if (myCollection && myCollection === iCollection) {
                item.set('deleted', false);
                myCollection.addCase(iCase);
                DG.log('Adding case: ' + iCase.id);
              }
            });
          });

          newCollection = dataContext.guaranteeCollection(fromCollectionProperties);
          dataContext.applyChange({
            operation: 'createCollection',
            collection: fromCollection,
            isComplete: true
          });
          newCollection.get('collection').addAttribute(tAttr, originalPosition);
          var casesAffectedByUndo = dataContext.regenerateCollectionCases([fromCollection, toCollection]);
          dataContext.invalidateAttrsOfCollections(casesAffectedByUndo.collections);
          dataContext.applyChange({
            operation: 'resetCollections',
            isComplete: true
          });
        }.bind(this),
        redo: function () {
          this.execute();
          // notify
          var tChange = {
            isComplete: true,
            operation: 'moveAttribute',
            attr: iAttr,
            toCollection: toCollectionClient,
            position: position
          };
          dataContext.applyChange(tChange);
          dataContext.invalidateAttrsOfCollections(casesAffected.collections);
        }
      }));
    },

    /**
     * Move an attribute from its current collection to a new collection.
     *
     * If moving an attribute leaves its original collection vacant, delete this
     * collection.
     *
     * @param attr {DG.Attribute} The attribute to move.
     * @param toCollectionClient {DG.CollectionClient} The new collection.
     * @param {number|undefined} position The position in the order of attributes in the
     *      new collection. If undefined, appends to the end of the attribute list.
     */
    moveAttribute: function (attr, toCollectionClient, position) {
      var fromCollection = attr.get('collection');

      if (fromCollection === toCollectionClient.get('collection')) {
        // if intra-collection move, we simply delegate to the collection
        this._moveAttributeWithinCollection(attr, toCollectionClient, position);
      } else {
        // inter-collection moves are more complex: we need to reconstruct the
        // cases in the collection
        this._moveAttributeBetweenCollections(attr, fromCollection, toCollectionClient,
            position);
      }
    },
    /**
     * Moves an attribute either within a collection or between collections.
     *
     * @param iChange {Object} Describes the change
     *    {string} .operation            -- "moveAttribute"
     *    {DG.Attribute} .attr           -- the attribute to move.
     *    {DG.CollectionClient} .toCollection -- the collection to
     *                                     move the attribute to. Defaults
     *                                     to the existing collection.
     *    {integer} .position           -- the position to be occupied by
     *                                     the attribute indexed from the
     *                                     left. 0 means leftmost. If not
     *                                     specified, placed rightmost.
     * @return {Object}
     *    {Boolean}               .success
     */
    doMoveAttribute: function (iChange) {
      try {
        var attr = iChange.attr;
        var fromCollection = attr.get('collection');
        var toCollection = iChange.toCollection || fromCollection;
        var position = iChange.position;
        var toCollectionClient = (toCollection.instanceOf(DG.CollectionClient))
            ? toCollection : this.getCollectionByID(toCollection.id);

        this.moveAttribute(attr, toCollectionClient, position);
        return {success: true};
      } catch (ex) {
        DG.logWarn(ex);
        return {success: false};
      }
    },

    /**
     Hides the specified attributes.
     @param  {Object}    iChange - The change request object
     {String}  .operation - "hideAttributes" | "unhideAttributes"
     {Array of Object} .attrs - Array of attributes to hide
     @returns  {Object}
     {Boolean}               .success
     {Array of Number}       .attrIDs
     */
    doChangeAttributesVisibility: function (iChange) {
      var result = {success: true, attrIDs: []};

      // Function to hide or show each individual attribute
      function setVisibility(iAttr, iHidden) {
        // Look up the attribute by ID if one is specified
        var attribute = iAttr.attribute;
        if (attribute) {
          attribute.set('hidden', iHidden);
          result.attrIDs.push(iAttr.id);
        }
      }

      // Change visibility of each specified attribute
      iChange.attrs.forEach(function (iAttr) {
        setVisibility(iAttr, iChange.operation === 'hideAttributes');
      });

      return result;
    },

    /**
     Deletes the specified attributes.
     @param  {Object}    iChange - The change request object
     {String}  .operation - "deleteAttributes"
     {DG.CollectionClient} .collection - Collection whose attributes(s) are changed
     {Array of Object} .attrs - Array of attributes to delete
     @returns  {Object}
     {Boolean}               .success
     {Array of DG.Attribute} .attrs
     {Array of Number}       .attrIDs
     */
    doDeleteAttributes: function (iChange) {
      var collection = typeof iChange.collection === "string"
          ? this.getCollectionByName(iChange.collection)
          : iChange.collection,
          deletedNodes = [],
          result = {success: true, attrIDs: []};

      // Function to delete each individual attribute
      function deleteAttribute(iAttr) {
        // Look up the attribute by ID if one is specified
        var attribute = collection && !SC.none(iAttr.id)
            ? collection.getAttributeByID(iAttr.id)
            : null;
        if (attribute) {
          deletedNodes.push({type: DG.DEP_TYPE_ATTRIBUTE, id: iAttr.id});
          DG.Attribute.destroyAttribute(attribute);
          result.attrIDs.push(iAttr.id);
        }
      }

      function shouldRegenerateCases() {
        // Shouldn't regenerate if the attributes are in the right-most
        // collection and the collection survives the attribute removal.
        var didDeleteAttributes = deletedNodes.length;
        var children = collection && collection.getPath('collection.children');
        var isLastChild = !children || !children.get('length');
        var attrCount = collection.getAttributeCount();
        return collection && didDeleteAttributes && (!isLastChild || !attrCount);
      }

      if (collection && iChange.attrs) {
        // Delete each specified attribute
        iChange.attrs.forEach(deleteAttribute);
        // regenerate collections in case they've changed
        if (shouldRegenerateCases()) {
          this.regenerateCollectionCases();
        }
        // notify dependents for formula evaluation
        this.invalidateDependentsAndNotify(deletedNodes);
        DG.store.commitRecords();
      }
      return result;
    },

    expungeCasesForChildCollection: function () {
      // works only when there are multiple collections
      var childCollection = this.childCollection();
      var parentCollectionID = childCollection && childCollection.getParentCollectionID();
      var parentCollection = parentCollectionID && this.getCollectionByID(parentCollectionID);
      var parentCases = parentCollection.get('casesController');
      var parentItemIDs = parentCases.map(function (myCase) {return myCase.item.id;});
      var items = this.get('dataSet').getDataItems();
      var orphanedItems = items.filter(function (item) { return !parentItemIDs.contains(item.id);});
      return this.deleteItems(orphanedItems);
    },
    /**
     * Handle change request to delete a collection. If the collection is the
     * last remaining collection, do nothing.
     * @param iChange
     * @return {{success: boolean}}
     */
    doDeleteCollection: function (iChange) {
      var collection = iChange.collection;
      var response;
      var collectionCount = this.get('collections').length;
      var deletedItems;
      if (collectionCount === 1) {
        return ({success: false, values: {error: 'cannot delete last collection'}});
      }
      // if collection is the rightmost collection, then we delete data items not
      // directly associated with the parent collection cases.
      if (!collection.getPath('collection.children').length) {
        deletedItems = this.expungeCasesForChildCollection();
      }
      this.destroyCollection(collection);
      response = this.regenerateCollectionCases([collection]) || {};
      response.deletedItems = deletedItems;
      response.success = true;
      return response;
    },

    doResetCollections: function (iChange) {
      DG.store.destroyAllRecordsOfType(DG.Case);
      DG.store.destroyAllRecordsOfType(DG.Attribute);
      DG.store.destroyAllRecordsOfType(DG.CollectionRecord);
    },

    /**
     Handler for global value (e.g. slider) name changes.
     Invalidates all dependent nodes and sends out an appropriate
     'namespaceChange' notification, indicating that all cases of
     the dependent attributes are affected.
     @param  {object}  iNotifier - generally the DG.globalsController
     @param  {string}  iKey - generally 'globalValuesChanged'
     */
    globalNamesDidChange: function (iNotifier, iKey) {
      var changes = iNotifier && iNotifier.get(iKey),
          names = [];
      changes.forEach(function (iChange) {
        if (iChange.oldName && (names.indexOf(iChange.oldName) < 0))
          names.push(iChange.oldName);
        if (iChange.newName && (names.indexOf(iChange.newName) < 0))
          names.push(iChange.newName);
      });
      this.invalidateNamesAndNotify(names);
    },

    /**
     Handler for global value (e.g. slider) changes.
     Invalidates all dependent nodes and sends out an appropriate
     'dependentCases' notification, indicating that all cases of
     the dependent attributes are affected.
     @param  {object}  iNotifier - generally the DG.globalsController
     @param  {string}  iKey - generally 'globalValuesChanged'
     */
    globalValuesDidChange: function (iNotifier, iKey) {
      var names = iNotifier.get(iKey);
      if (names && names.length) {
        var nodes = [];
        names.forEach(function (iName) {
          var globalValue = DG.globalsController.getGlobalValueByName(iName),
              globalID = globalValue && globalValue.get('id');
          if (globalValue) {
            nodes.push({type: DG.DEP_TYPE_GLOBAL, id: globalID, name: iName});
          }
        });

        this.invalidateDependentsAndNotify(nodes);
      }
    },

    /**
     Invalidate all attributes of the specified collections.
     @param {[DG.Collection|DG.CollectionClient]} collections - array of collections affected
     @param {object} iChange - [optional] the change that triggered the invalidation
     */
    invalidateAttrsOfCollections: function (collections, iChange) {
      var attrNodes = [];
      if (!collections || !collections.length) return;
      collections.forEach(function (collection) {
        var collectionModel = collection instanceof DG.Collection
            ? collection
            : collection.get('collection'),
            collectionAttrs = collectionModel && collectionModel.get('attrs');
        if (collectionAttrs) {
          collectionAttrs.forEach(function (attr) {
            attrNodes.push({type: DG.DEP_TYPE_ATTRIBUTE, id: attr.get('id'), name: attr.get('name')});
          });
        }
      });
      this.invalidateDependentsAndNotify(attrNodes, iChange);
    },

    /*
    Notifies clients of namespace changes that affect formulas.
    Invalidates the specified nodes in the DependencyMgr, which invalidates
    all dependent nodes and then returns the sets of nodes that are affected.
    Calls invalidateDependentsAndNotify(), so see description of that
    function for the notifications that can be triggered.
   */
    invalidateNamesAndNotify: function (iNames) {
      var dependencyMgr = this.get('dependencyMgr'),
          namedNodes = dependencyMgr.findNodesWithNames(iNames),
          dependentNodes = dependencyMgr.findDependentsOfNodes(namedNodes);
      dependentNodes.forEach(function (iNode) {
        var dependency = iNode.dependencies && iNode.dependencies[0],
            formulaContext = dependency && dependency.dependentContext;
        if (formulaContext)
          formulaContext.invalidateNamespace();
      });
      // invalidate dependents of the named nodes
      this.invalidateDependentsAndNotify(namedNodes);
    },

    /**
     Invalidates all dependents of the specified nodes and sends out
     appropriate dependentCases notifications. See notifyInvalidationResult
     for details of the notifications.
     @param  {object[]}  iNodes - array of nodes whose dependents are to be invalidated
     @param  {object}    [iChange] - optional change object
     {string}    .operation (e.g. 'createCases'|'updateCases'|'deleteCases')
     */
    invalidateDependentsAndNotify: function (iNodes, iChange) {
      var result = this.get('dependencyMgr').invalidateDependentsOf(iNodes);
      this.notifyInvalidationResult(result, iChange);
    },

    /**
     Invalidates a particular dependent of the specified node and sends out
     appropriate dependentCases notifications. See notifyInvalidationResult
     for details of the notifications.
     @param  {object}  iDependentSpec - specifier for the dependent node
     @param  {object}  iIndependentSpec - specifier for the independent node
     @param  {boolean} iForceAggregate - true if the dependence should be treated as aggregate
     */
    invalidateDependencyAndNotify: function (iDependentSpec, iIndependentSpec, iForceAggregate) {
      var result = this.get('dependencyMgr')
          .invalidateDependency(iDependentSpec, iIndependentSpec, iForceAggregate);
      this.notifyInvalidationResult(result);
    },

    /**
     Notifies clients of dependent changes to cases.
     Invalidates the specified nodes in the DependencyMgr, which invalidates
     all dependent nodes and then returns the sets of nodes that are affected
     in a simple (non-aggregate) or an aggregate manner respectively.
     This information is then used to send out up to two 'dependentCases'
     notifications, indicating the set of attributes in each affected collection
     which require recalculation in a simple (non-aggregate) sense and then in
     a separate notification that set of attributes in each affected collection
     which require recalculation in an aggregate sense (i.e. all cases affected).
     The format of the 'depdentCases' notifications is described below.
     @param  {object[]}  iNodes
     {string}    .type (e.g. DG.DEP_TYPE_ATTRIBUTE|DG.DEP_TYPE_GLOBAL)
     {string}    .id
     {string}    .name (primarily used for debugging)
     @param  {object}    iChange
     {string}    .operation (e.g. 'createCases'|'updateCases'|'deleteCases')

     The iChange object is the same change object used by applyChange(),
     performChange(), etc. The format varies depending on the nature of the
     change, but often follow a pattern such as that below for 'updateCases'.
     See the handler for each change for details.

     {DG.CollectionClient}   iChange.collection (optional) -- collection containing cases
     {Array of Number}       iChange.attributeIDs (optional) -- affected attributes
     {Array of DG.Case}      iChange.cases -- DG.Case objects to be changed

     The 'dependentCases' information is packaged into the form of a change request
     and then applyChange() is called to notify downstream clients.

     @param  {Object}                iChange
     {String}                iChange.operation -- 'dependentCases'
     {Array of Object}       iChange.changes
     {DG.CollectionClient} iChange.changes.collection -- collection containing cases
     {Array of Number}     iChange.changes.attributeIDs -- attributes whose values
     are to be changed for each case.
     {Array of DG.Case}    iChange.changes.cases -- DG.Case objects to be changed
     */
    notifyInvalidationResult: function (iResult, iChange) {
      var changeCollection = iChange && iChange.collection,
          changeCollectionID = changeCollection && changeCollection.get('id'),
          changeCases = (iChange && iChange.cases) || [],
          simpleNotification, aggregateNotification,
          externalDataContexts = [];

      var convertDependenciesToNotification = function (iDependencies, iChange) {
        var notification = {operation: 'dependentCases', changes: [], isComplete: true},
            changeCases = (iChange && iChange.cases) || [],
            collectionChanges = {};

        iDependencies.forEach(function (iDep) {
          var type = iDep.type,
              attr = type === DG.DEP_TYPE_ATTRIBUTE
                  ? DG.Attribute.getAttributeByID(iDep.id) : null,
              dataContextRecord, dataContextID, dataContext,
              collectionRecord = attr && attr.get('collection'),
              collectionID = collectionRecord && collectionRecord.get('id'),
              collectionClient = collectionID && this.getCollectionByID(collectionID),
              affectedCases,
              change = collectionChanges[collectionID];
          if (!collectionClient) {
            // we may have an external data context reference
            dataContextRecord = collectionRecord && collectionRecord.get('context');
            dataContextID = dataContextRecord && dataContextRecord.get('id');
            dataContext = DG.currDocumentController().getContextByID(dataContextID);
            collectionClient = dataContext && collectionID &&
                dataContext.getCollectionByID(collectionID);
            if (externalDataContexts.indexOf(dataContext) < 0)
              externalDataContexts.push(dataContext);
          }
          if (!change) {
            // For simple dependencies within the same collection as the original
            // change, only the cases originally changed can be affected.
            // For aggregate dependencies or dependencies across collections,
            // we simplify by reporting that all cases are affected. This is
            // less than optimally efficient in the case of non-aggregate references
            // from a child collection attribute formula to a parent collection
            // attribute, but for now we make this simplifying assumption.
            affectedCases = collectionID === changeCollectionID ? changeCases : [];
            change = collectionChanges[collectionID] = {
              dataContext: dataContext || this,
              collection: collectionClient,
              attributeIDs: [iDep.id],
              cases: affectedCases
            };
          } else {
            change.attributeIDs.push(iDep.id);
          }
        }.bind(this));

        DG.ObjectMap.forEach(collectionChanges, function (iID, iCollectionChange) {
          notification.changes.push(iCollectionChange);
        });

        return notification;
      }.bind(this);

      if (!iResult.simpleDependencies.length && !iResult.aggregateDependencies.length) {
        //DG.log("DG.DataContext.invalidateDependentsAndNotify: No dependents");
      } else {
        if (!iChange && iResult.simpleDependencies.length) {
          // global value changes affect all cases, like aggregate functions
          iResult.aggregateDependencies = iResult.aggregateDependencies.concat(
              iResult.simpleDependencies);
          iResult.simpleDependencies = [];
        }

        // check if all changed cases are from the same collection
        if (!changeCollection) {
          var commonCollection, commonCollectionID;
          changeCases.forEach(function (iCase) {
            var caseCollection = iCase.get('collection'),
                caseCollectionID = caseCollection && caseCollection.get('id');
            if (!commonCollectionID) {
              commonCollection = caseCollection;
              commonCollectionID = caseCollectionID;
            } else if (caseCollectionID !== commonCollectionID)
              commonCollectionID = -1;
          });
          if (commonCollectionID && (commonCollectionID !== -1)) {
            changeCollection = commonCollection;
            changeCollectionID = commonCollectionID;
          }
        }

        // handle simple dependencies, but only for updateCases
        if (iResult.simpleDependencies.length &&
            iChange && (iChange.operation === 'updateCases')) {
          // DG.log("DG.DataContext.notifyInvalidationResult: simpleDependents: [%@]",
          //         iResult.simpleDependencies.map(function(iDep) {
          //                                     return "'" + iDep.name + "'";
          //                                   })
          //                                   .join(", "));
          simpleNotification = convertDependenciesToNotification(iResult.simpleDependencies, iChange);
        }

        // handle aggregate dependencies
        if (iResult.aggregateDependencies.length) {
          // DG.log("DG.DataContext.notifyInvalidationResult: aggregateDependents: [%@]",
          //         iResult.aggregateDependencies.map(function(iDep) {
          //                                         return "'" + iDep.name + "'";
          //                                       })
          //                                       .join(", "));
          aggregateNotification = convertDependenciesToNotification(iResult.aggregateDependencies);
        }

        if (simpleNotification)
          this.applyChange(simpleNotification);
        if (aggregateNotification) {
          this.applyChange(aggregateNotification);
          // signal any dependent contexts to update as well
          externalDataContexts.forEach(function (iDataContext) {
            iDataContext.applyChange(aggregateNotification);
          });
        }
      }
    },

    /**
     * A utility to find the last collection in the context.
     *
     * @return {DG.CollectionClient}
     */
    getLastCollection: function () {
      var collections = this.get('collections');
      var lastCollection = collections && collections[collections.length - 1];
      // we have a Collection. We want a CollectionClient.
      return lastCollection && this.getCollectionByID(lastCollection.get('id'));
    },
    /**
     * Export the case data for all attributes and cases of the given collection,
     * suitable for pasting into TinkerPlots/Fathom.
     * If no collection name given, returns an list of collection names.
     * @param iWhichCollection {String} collection name of the desired collection.
     * @return {String} Case data in tab-delimited string format
     */
    exportCaseData: function (iWhichCollection) {
      /* Replace newlines w/ space, quote commas */
      function encodeString(str) {
        return (typeof str === 'string')? str.replace(/\n/g, '&NewLine;').replace(/,/g, '&comma;'): str;
      }
      // Encode str as per RFC 4180.
      // If str contains double quotes, convert to two double quotes
      // If str contains commas or double quotes, wrap in double quotes.
      function escape(str) {
        var newStr = '' + (SC.none(str) ? '' : str);
        if (/.*[",].*/.test(str)) {
          newStr = '"' + newStr.replace(/"/g, '""') + '"';
        }
        return newStr;
      }

      var columnDelimiter = ',',
          rowDelimiter = '\r\n',
          collection,
          attributes,
          attribIDs,
          rows = [],
          metadata = this.getPath('model.metadata');

      if (SC.empty(iWhichCollection)) {
        return '';
      }

      if (iWhichCollection === 'DG.CaseTableController.allTables'.loc()) {
        collection = this.getLastCollection();
        attributes = this.getAttributes();
      } else {
        collection = this.getCollectionByName(iWhichCollection);
        attributes = collection.attrsController;
      }

      // remove hidden attributes
      attributes = attributes.filter(function (attr) {
        return !attr.hidden;
      });
      attribIDs = attributes.map(function(attr) {return attr.id; });

      rows.push('# name: ' + encodeString(this.get('name')));
      // Create comment annotations documenting metadata and attribute properties
      if (metadata) {
        Object.entries(metadata).forEach(function(entry) {
          var key = entry[0];
          var value = entry[1];
          rows.push('# ' + key + ': ' + encodeString(value));
        });
      }

      // Create attribute annotations
      attributes.forEach(function (attr) {
        var defaults = {
          type: 'none',
          precision: 2
        };
        var props = [
          'name',
          'description',
          'type',
          'unit',
          'precision',
          'editable',
          'formula'
        ].map(function (property) {
          var value = attr.get(property);
          if (value != null && value !== '' && (defaults[property] !== value)) {
            return property + ': ' + encodeString(value);
          } else {
            return '';
          }
        }).filter(function (e) { return (e !== '');});
        rows.push('# attribute -- ' + props.join(', '));
      });

      // add a row of attribute names
      rows.push(attributes.map(function (attr) {
        return escape(attr.name);
      }).join(columnDelimiter));

      // add each row of case values
      collection.forEachCase(function (iCase, iIndex) {
        var row = [];
        attribIDs.forEach(function (iAttrID) {
          var caseValue = iCase.getValue(iAttrID);
          // export boundary data as GeoJSON
          if (caseValue && typeof caseValue === "object") {
            if (typeof caseValue.jsonBoundaryObject === "object") {
              caseValue = caseValue.jsonBoundaryObject;
            }
            caseValue = JSON.stringify(caseValue);
          }
          row.push(escape(caseValue));
        });
        rows.push(row.join(columnDelimiter)); // append each line of data to the output
      });

      return rows.join(rowDelimiter);
    },

    /**
     *  The number of collections controlled by this controller.
     *  @property {Number}
     */
    collectionCount: function () {
      return this.getPath('collections.length') || 0;
    }.property(),

    /**
     *  Returns the DG.CollectionClient for the child or leaf collection.
     *  @returns  {DG.CollectionClient | null}
     */
    childCollection: function () {
      var collectionCount = this.get('collectionCount');
      return (collectionCount ? this.getCollectionAtIndex(collectionCount - 1) : null);
    }.property('_collectionClients'),

    /**
     *  Returns the DG.CollectionClient for parent collection of the child or leaf collection.
     *  @returns  {DG.CollectionClient | null}
     */
    parentCollection: function () {
      var collectionCount = this.get('collectionCount');
      return (collectionCount ? this.getCollectionAtIndex(collectionCount - 2) : null);
    }.property('_collectionClients'),

    /**
     *  Returns the DG.CollectionClient at the specified index.
     *  Since collections are stored in parent --> child order,
     *  index 0 corresponds to the oldest ancestor, while the last index
     *  corresponds to the child/leaf collection.
     *  @returns  {DG.CollectionClient | undefined}
     */
    getCollectionAtIndex: function (iIndex) {
      var collections = this.get('collections'),
          collectionCount = this.get('collectionCount'),
          collection = (collections && (collectionCount > iIndex) &&
              collections.objectAt(iIndex)) || null;
      return collection && this._collectionClients[collection.get('id')];
    },

    /**
     *  Returns the DG.CollectionClient with the specified name.
     *  Searches its collections from child => parent => grandparent order.
     *  @returns  {DG.CollectionClient | null}
     */
    getCollectionByName: function (iName) {
      var collectionCount = this.get('collectionCount'),
          collections = this.get('collections'),
          collection;
      for (var i = 0; i < collectionCount; ++i) {
        collection = collections.objectAt(i);
        if (collection && (collection.get('name') === iName)) {
          return this._collectionClients[collection.get('id')];
        }
      }
      return null;
    },

    /**
     *  Returns the DG.CollectionClient with the specified ID.
     *  @param    {Number}  iCollectionID -- The ID of the DG.collection
     *  @returns  {DG.CollectionClient | null}
     */
    getCollectionByID: function (iCollectionID) {
      return this._collectionClients[iCollectionID] || null;
    },

    /**
     Returns the collection (DG.CollectionClient) which contains the specified case (DG.Case).
     @param    {DG.Case}               iCase -- The case whose collection is to be returned
     @returns  {DG.CollectionClient}   The collection which contains the specified case
     */
    getCollectionForCase: function (iCase) {
      return this.getCollectionByID(iCase.getPath('collection.id'));
    },

    /**
     Returns the collection (DG.CollectionClient) which contains
     the specified attribute (DG.Attribute).
     @param    {DG.Attribute}          iAttribute -- The attribute whose collection is to be returned
     @returns  {DG.CollectionClient}   The collection which contains the specified case
     */
    getCollectionForAttribute: function (iAttribute) {
      return this.getCollectionByID(iAttribute.getPath('collection.id'));
    },

    /**
     Returns the parent collection, if any, for the specified collection.
     Returns null if the specified collection has no parent collection.
     @param    {DG.CollectionClient}   iCollection -- The (child) collection whose parent is sought
     @returns  {DG.CollectionClient}   The parent collection (if one exists) or null
     */
    getParentCollection: function (iCollection) {
      var childCollectionID = iCollection && iCollection.get('id'),
          collectionCount = this.get('collectionCount'),
          collections = this.get('collections'),
          collection, collectionID,
          prevCollectionID = null;
      for (var i = 0; i < collectionCount; ++i) {
        collection = collections.objectAt(i);
        collectionID = collection.get('id');
        if (collection && (collectionID === childCollectionID))
          return this.getCollectionByID(prevCollectionID);
        prevCollectionID = collectionID;
      }
      return null;
    },

    /**
     Returns the child collection, if any, for the specified collection.
     Returns null if the specified collection has no child collection.
     @param    {DG.CollectionClient}   iCollection -- The (parent) collection whose parent is sought
     @returns  {DG.CollectionClient}   The child collection (if one exists) or null
     */
    getChildCollection: function (iCollection) {
      var childCollectionID = iCollection && iCollection.get('id'),
          collectionCount = this.get('collectionCount'),
          collections = this.get('collections'),
          collection, collectionID,
          prevCollectionID = null;
      for (var i = collectionCount - 1; i >= 0; --i) {
        collection = collections.objectAt(i);
        collectionID = collection.get('id');
        if (collection && (collectionID === childCollectionID))
          return this.getCollectionByID(prevCollectionID);
        prevCollectionID = collectionID;
      }
      return null;
    },

    /**
     Creates a collection with the specified initial properties.
     @param    {Object}              iProperties -- The initial properties for the newly-created object
     @returns  {DG.CollectionClient} The newly-created collection
     */
    createCollection: function (iProperties) {
      var //newCollection = this.get('model').createCollection( iProperties || {}),
          tProperties = iProperties || {},
          newCollectionClient;

      tProperties.context = this.get('model');
      newCollectionClient = this.addCollection(DG.Collection.createCollection(tProperties));
      this.didCreateCollection(newCollectionClient);
      return newCollectionClient;
    },

    destroyCollection: function (collectionClient) {
      var id = collectionClient.get('id');
      this.willRemoveCollection(collectionClient);
      this._collectionClients[id].destroy();
      delete this._collectionClients[id];
    },

    /**
     Called from createCollection to give derived classes a chance to do something.
     @param  {DG.CollectionClient} iNewCollection -- The collection that was just created
     */
    didCreateCollection: function (iNewCollection) {
      // derived classes may override
    },

    /**
     Returns a collection matching the specified properties, creating it if necessary.
     @param    {Object}    iCollectionProperties -- Properties to match or to use as initial
     values if the collection must be created.
     @returns  {DG.CollectionClient}   That matched or newly-created collection
     */
    guaranteeCollection: function (iCollectionProperties) {
      var aCollectionClient = this.getCollectionByName(iCollectionProperties.name);
      if (!aCollectionClient)
        aCollectionClient = this.createCollection(iCollectionProperties);
      return aCollectionClient;
    },

    /**
     Creates and connects a DG.Collection model and DG.CollectionClient controller for the
     specified DG.Collection.
     @param    {DG.Collection || DG.Collection}   iCollection -- The collection record to create the
     model and controller for.
     @returns  {DG.CollectionClient}   The newly-created collection client
     */
    addCollection: function (iCollection) {
      function getCollection(iCollectionRecord) {
        DG.logWarn('Instantiating collection from collectionRecord');
        return DG.Collection.create({collectionRecord: iCollectionRecord});
      }

      var theID = iCollection && iCollection.get('id'),
          theCollection = (theID && (iCollection.type === 'DG.CollectionRecord'))
              ? getCollection(iCollection)
              : iCollection,
          theCollectionClient = theCollection && DG.CollectionClient.create({});
      if (theCollectionClient && theCollection && theID) {
        theCollectionClient.setTargetCollection(theCollection);
        this._collectionClients[theID] = theCollectionClient;
        this.didAddCollection(theCollectionClient);
      }
      return theCollectionClient;
    },

    /**
     Utility function for adding observers for formula change notifications
     from individual collections.
     @param    {DG.CollectionClient}   iCollection -- The collection that was added
     */
    didAddCollection: function (iCollection) {
      iCollection.addObserver('caseIndices', this, 'caseIndicesDidChange');
      iCollection.addObserver('attrFormulaChanges', this, 'attrFormulaDidChange');
    },

    /**
     Utility function for removing observers for formula change notifications
     from individual collections.
     @param    {DG.CollectionClient}   iCollection -- The collection that will be removed
     */
    willRemoveCollection: function (iCollection) {
      iCollection.removeObserver('caseIndices', this, 'caseIndicesDidChange');
      iCollection.removeObserver('attrFormulaChanges', this, 'attrFormulaDidChange');
    },

    /*
    Observer function which invalidates formulas that depend on 'caseIndex'
    when case indices change. Case index change happens when cases are added
    or removed, so all references to attributes are invalidated.
   */
    caseIndicesDidChange: function () {
      var nodes = this.get('dependencyMgr').findNodesWithNames(['caseIndex']);
      this.invalidateDependentsAndNotify(nodes);
    },

    /**
     * The observer/handler for attribute formula change notifications from collections.
     * Notifies clients with an 'updateCases' notification. Note that we don't currently
     * include attribute-specific information in the notification, so clients can't make
     * attribute-specific responses. To support those, the collection would have to include
     * attribute-specific information in its notification, which this method would then
     * propagate to its observers in some fashion.
     *
     * @param iNotifier {DG.Collection}
     */
    attrFormulaDidChange: function (iNotifier, iKey) {
      var attrID = iNotifier.get(iKey),
          change = {
            operation: 'updateCases',
            collection: iNotifier,
            attributeID: attrID,
            isComplete: true
          };
      this.applyChange(change);

      var attr = DG.Attribute.getAttributeByID(attrID),
          attrNodes = [{type: DG.DEP_TYPE_ATTRIBUTE, id: attrID, name: attr.get('name')}];
      this.invalidateDependentsAndNotify(attrNodes);
    },

    /**
     Applies the specified function to each collection managed by this data context.
     @param    iFunction {Function}        The function to apply to each collection
     @returns  {DG.DataContext}  this, for use in method chaining
     */
    forEachCollection: function (iFunction) {
      var this_ = this,
          collections = this.get('collections');
      collections.forEach(function (iCollection) {
        var collectionID = iCollection.get('id'),
            collectionClient = this_.getCollectionByID(collectionID);
        if (collectionClient)
          iFunction(collectionClient);
      });
      return this;
    },

    /**
     Returns the string that best represents the noun form of the specified number of cases,
     e.g. "case"|"cases", "person"|"people", "deer"|"deer", "goose"|"geese", etc.
     @param    {DG.CollectionClient} iCollectionClient -- The collection whose labels are returned
     @param    {Number}              iCount -- The number of cases to represent
     @returns  {String}              The string to represent the specified number of cases
     */
    getCaseNameForCount: function (iCollectionClient, iCount) {
      var tCollection = iCollectionClient.get('collection'),
          tLabels = tCollection && tCollection.get('labels'),
          tSingName = tLabels ? tLabels.singleCase : tCollection.get('caseName'),
          tPluralName = tLabels ? tLabels.pluralCase : tCollection.get('title');
      tSingName = tSingName || (tPluralName && pluralize.singular(tPluralName));
      tSingName = tSingName || 'DG.DataContext.singleCaseName'.loc();
      tPluralName = tPluralName || 'DG.DataContext.pluralCaseName'.loc();
      return (iCount === 1) ? tSingName : tPluralName;
    },

    /**
     Returns a case count string indicating the number of cases using the appropriate
     case name, e.g. "1 case"|"2 cases", "1 person"|"2 people", etc.
     @param    {DG.CollectionClient} iCollection -- The collection whose labels are returned
     @param    {Number}              iCount -- The number of cases to represent
     @returns  {String}              The string to represent the specified number of cases
     */
    getCaseCountString: function (iCollection, iCount) {
      var caseName = this.getCaseNameForCount(iCollection, iCount);
      return 'DG.DataContext.caseCountString'.loc(iCount, caseName);
    },

    /**
     Returns the string that represents a coherent set of cases, e.g. a set of Lunar Lander
     events is often called "a flight record", while in other games it might be "a round".
     @param    {DG.CollectionClient} iCollection -- The collection whose labels are returned
     @returns  {String}              The string label to represent a set of cases
     */
    getLabelForSetOfCases: function (iCollection) {
      return iCollection.getPath('collection.collection.parent.caseName') ||
          'DG.DataContext.setOfCasesLabel'.loc();
    },

    /**
     *  Returns a specification for the DG.Attribute with the specified ID.
     *  Searches its collections from child => parent => grandparent order.
     *  @param    {Number}        iAttributeID -- the ID of the attribute to be returned
     *  @returns  {Object | null} Object.collection:  {DG.CollectionClient}
     *                            Object.attribute:   {DG.Attribute}
     *                            Object.position:    {number}
     */
    getAttrRefByID: function (iAttributeID) {
      var collectionCount = this.get('collectionCount'),
          collections = this.get('collections');
      for (var i = collectionCount - 1; i >= 0; --i) {
        var collection = collections.objectAt(i),
            collectionClient = collection && this._collectionClients[collection.get('id')],
            foundAttr = collectionClient && collectionClient.getAttributeByID(iAttributeID),
            position = foundAttr && collectionClient.getAttributeIndexByName(foundAttr.get('name'));
        if (foundAttr)
          return {
            collection: collectionClient,
            attribute: foundAttr,
            position: position
          };
      }
      return null;
    },

    /**
     *  Returns a specification for the DG.Attribute with the specified name.
     *  Searches its collections from child => parent => grandparent order.
     *  @param    {String}        iName -- the name of the attribute to be returned
     *  @returns  {Object | null} Object.collection:  {DG.CollectionClient}
     *                            Object.attribute:   {DG.Attribute}
     *                            Object.position:    {number}
     */
    getAttrRefByName: function (iName) {
      var collectionCount = this.get('collectionCount'),
          collections = this.get('collections');
      for (var i = collectionCount - 1; i >= 0; --i) {
        var collection = collections.objectAt(i),
            collectionClient = collection && this._collectionClients[collection.get('id')],
            foundAttr = collectionClient && collectionClient.getAttributeByName(iName),
            position = collectionClient && collectionClient.getAttributeIndexByName(iName);
        if (foundAttr)
          return {
            collection: collectionClient,
            attribute: foundAttr,
            position: position
          };
      }
      return null;
    },

    /**
     * Returns a comprehensive list of attributes in this data context.
     * @return {[DG.Attribute]}
     */
    getAttributes: function () {
      var attrs = [];
      var ix;
      var collection;
      var collectionAttrs;
      for (ix = 0; ix < this.get('collectionCount'); ix += 1) {
        collection = this.getCollectionAtIndex(ix);
        collectionAttrs = collection.get('attrsController');
        collectionAttrs && collectionAttrs.forEach(function (attr) {
          attrs.push(attr);
        });
      }

      return attrs;
    },

    getNewAttributeName: function () {
      var attrName = 'DG.CaseTable.defaultAttrName'.loc();
      return this.getUniqueAttributeName(attrName);
    },

    getUniqueAttributeName: function (baseName, allowNames) {
      var attrNames = this.getAttributes().map(function (attr) {
            return attr.get('name');
          }),
          newName = this.canonicalizeName(baseName),
          suffix = 1;
      while ((attrNames.indexOf(newName) >= 0) &&
      // eslint-disable-next-line no-unmodified-loop-condition
      (!allowNames || (allowNames.indexOf(newName) < 0))) {
        newName = baseName + (++suffix);
      }
      return newName;
    },

    /**
     *  Returns the DG.Attribute with the specified name.
     *  Searches its collections from child => parent => grandparent order.
     *  @returns  {DG.Attribute | null}
     */
    getAttributeByName: function (iName) {
      var attrRef = this.getAttrRefByName(iName);
      return attrRef ? attrRef.attribute : null;
    },

    /**
     * @return [{DG.Attribute}]
     */
    getHiddenAttributes: function () {
      var tResult = [];
      this.getAttributes().forEach( function( iAttr) {
        if( iAttr.get('hidden'))
          tResult.push( iAttr);
      });
      return tResult;
    },

    /**
     Sets the values of the specified case from the specified array of values.
     @param    iCase {DG.Case}   The case whose values are to be set
     @param    iValues{[string|number|boolean|null]} The values to use in setting the case values
     @param    iCollection {DG.CollectionClient} (optional) -- The collection which owns the case.
     Will be looked up if it isn't provided, but more efficient if the client provides it.
     */
    setCaseValuesFromArray: function (iCase, iValues, iCollection) {
      var collection = iCollection || this.getCollectionForCase(iCase);
      if (collection)
        collection.setCaseValuesFromArray(iCase, iValues);
    },

    /**
     Returns an object which specifies the default collections for this data context along
     with some of the default properties of that collection, e.g. default attributes to plot.
     @returns    {Object}    An object specifying the defaults
     {DG.CollectionClient}   object.collectionClient -- child collection
     {DG.CollectionClient}   object.parentCollectionClient -- parent collection
     {String}                object.plotXAttr -- default X attribute on graphs
     {String}                object.plotYAttr -- default Y attribute on graphs
     */
    collectionDefaults: function () {

      return {
        collectionClient: this.get('childCollection'),
        parentCollectionClient: this.get('parentCollection'),
        plotXAttr: null,
        plotXAttrIsNumeric: true,
        plotYAttr: null,
        plotYAttrIsNumeric: true
      };
    },

    /**
     Called by the framework as part of the document writing process, to give
     DG.DataContext derived classes a chance to write out context-specific information.
     Clients should implement/override the createStorage() method rather than
     overriding this function.
     */
    willSaveContext: function () {
      var model = this.get('model');
      if (model) {
        var contextStorage = this.createStorage() || {};
        model.set('contextStorage', contextStorage);
      }
    },

    /**
     Returns a link object of the form { type: 'DG.DataContextRecord', id: contextID }.
     @returns  {Object}  linkObject -- contains the type and id of the referenced record
     {String}  linkObject.type -- the type of record ('DG.DataContextRecord' in this case).
     {Number}  linkObject.id -- the id of the data context record
     */
    toLink: function () {
      var model = this.get('model');
      return model && model.toLink();
    },

    /**
     *  Returns the object to be JSON-ified for storage.
     *  @returns  {Object}
     */
    createStorage: function () {
      var selectedCases = this.getSelectedCases(false);
      var storage = {_links_: {}};

      storage._links_.selectedCases = selectedCases.map(function (iCase) {
        return iCase.toLink();
      });

      return storage;
    },

    /**
     *  Copies the contents of iComponentStorage to the model.
     *  @param {Object} iContextStorage -- Properties restored from document.
     */
    restoreFromStorage: function (iContextStorage) {
      var collections = this.get('collections');
      var links = iContextStorage._links_;
      var selectedCaseLinks = links && links.selectedCases;
      var selectedCases = [];
      if (!SC.none(collections)) {
        collections.forEach(function (collection) {
          this.addCollection(collection);
        }.bind(this));
      }
      if (selectedCaseLinks) {
        selectedCases = selectedCaseLinks.map(function (iLink) {
          return this.getCaseByID(iLink.id);
        }.bind(this));
      }
      // allow for a render cycle
      this.invokeOnceLater(function () {
        this.applyChange({
          operation: 'selectCases',
          select: true,
          cases: selectedCases
        });
      }, 200);
    },

    restoreSetAsideCases: function () {
      var items = this.get('dataSet').restoreSetAsideItems();
      var count = items.length;
      var results = this.regenerateCollectionCases(null, 'createCases');
      this.invalidateAttrsOfCollections(this.collections, {operation: 'createCases', cases: results.createdCases});
      DG.log("Restored " + count + " items in context \"" + this.get('name') + "\"");
      DG.log("Restored %@ cases".loc(results.createdCases && results.createdCases.length));
      var tChange = {
        operation: 'selectCases',
        cases: results.createdCases,
        select: true,
        extend: false
      };
      this.applyChange(tChange);
    }

  }; // end return from closure

}())); // end closure

/**
 *  A registry of creation functions for use by the DG.DataContext.factory() function.
 *  Derived classes should add their own factory function entries.
 *  Clients call DG.DataContext.factory() to create a new polymorphically-typed
 *  DataContext object.
 */
DG.DataContext.registry = {};
DG.DataContext.registry['DG.DataContext'] = function (iProperties) {
  return DG.DataContext.create(iProperties);
};

/**
 Returns an array of keys to known data contexts.
 @param  {String}  iDocumentID -- Currently unused since DG is currently single-document

 TODO: Deprecate this method and remove references: We should be getting context
 TODO: information via the DocumentController.
 */
DG.DataContext.contextIDs = function (iDocumentID) {
  var contexts = DG.currDocumentController().contexts;
  return contexts && contexts.map(function (context) {
    return context.get('id');
  });
};

/**
 Returns the context that contains the specified collection.
 Currently, this is implemented simply by following the 'context' property
 of the DG.Collection back to its DG.DataContextRecord and then looking
 up the DG.DataContext by ID. The current implementation (like most other
 functions here) ignores the document ID. Note that there is a bit of a code
 smell surrounding the use of this function. Clients that have access to a
 collection should really have access to the context as well.
 @param    {DG.CollectionClient} iCollectionClient -- The collection whose context is to be found
 @returns  {DG.DataContext}      The collection's DG.DataContext or null

 TODO: Deprecate this method and remove references: We should be getting context
 TODO: information via the DocumentController.
 */
DG.DataContext.getContextFromCollection = function (iCollectionClient) {
  var collection = iCollectionClient &&
      iCollectionClient.get('collection'),
      contextID = collection && collection.getPath('context.id');
  return contextID && DG.currDocumentController().getContextByID(contextID);
};
/**
 Returns an object which specifies the default collections for this data context along
 with some of the default properties of that collection, e.g. default attributes to plot.
 @returns    {Object}    An object specifying the defaults
 {DG.CollectionClient}   object.collectionClient -- child collection
 {DG.CollectionClient}   object.parentCollectionClient -- parent collection
 {String}                object.plotXAttr -- default X attribute on graphs
 {String}                object.plotYAttr -- default Y attribute on graphs
 */
DG.DataContext.collectionDefaults = function () {
  return {
    collectionClient: null, //this.get('childCollection'),
    parentCollectionClient: null, //this.get('parentCollection'),
    plotXAttr: null,
    plotXAttrIsNumeric: true,
    plotYAttr: null,
    plotYAttrIsNumeric: true
  };
};

/**
 *  A factory function for creating an appropriate DG.DataContext object, i.e.
 *  either a DG.DataContext or an appropriate derived class. Derived classes should
 *  add their own factory function entries to the DG.DataContext.registry, so that
 *  when this function is called the factory function will be available when appropriate.

 *  @param iProperties {Object}  properties object passed to the DataContext on construction.
 *  @returns  {DG.DataContext}  a DG.DataContext object or an instance of a derived class
 */
DG.DataContext.factory = function (iProperties) {
  var type = iProperties && iProperties.type,
      func = type && DG.DataContext.registry[type];
  return func ? func(iProperties) : DG.DataContext.create(iProperties);
};

/* >>>>>>>>>> BEGIN source/components/case_card/case_card.js */
sc_require('components/case_card/column_resize_handle');
sc_require('components/case_card/text_input');
sc_require('controllers/data_context');
sc_require('react/dg-react');
/* global createReactClass, createReactFactory, PropTypes, ReactDOMFactories, ReactSizeMe */

DG.React.ready(function () {
  var div = ReactDOMFactories.div,
      table = ReactDOMFactories.table,
      tbody = ReactDOMFactories.tbody,
      tr = ReactDOMFactories.tr;

  var CaseCard = createReactClass(
      (function () {

        var kSelectDelay = 200,  // ms
            kSelectInterval = 100,  // ms
            gWaitingForSelect = false,
            gTimeOfLastSelectCall,  // time
            gSelectTimer, // SC.Timer
            gMoveArrowClickInProgress = false,
            // leave some room for collection name (left) and navigation buttons (right)
            kMinColumnWidth = 82;

        var kThresholdDistance2 = 0, // pixels^2
            tTouchID,
            tTouchTimer,
            tPointerIsDown = false,
            tStartCoordinates,
            tDragInProgress = false,
            tDragHandler;

        var ChangeListener = SC.Object.extend({
          dependent: null,
          _context: null,
          context: function( iKey, iValue) {
            if( iValue && iValue !== this._context) {
              if( this._context) {
                this._context.removeObserver('changeCount', this, this.contextDataDidChange);
              }
              this.guaranteeDataContextObserver(iValue);
              this._context = iValue;
            }
            return this._context;
          }.property(),

          init: function () {
            arguments.callee.base.apply(this,arguments);
          },

          destroy: function () {
            this.removeDataContextObserver(this.get('context'));
            this.dependent = null;

            arguments.callee.base.apply(this,arguments);
          },

          guaranteeDataContextObserver: function (iDataContext) {
            if (!iDataContext.hasObserverFor('changeCount', this, this.contextDataDidChange)) {
              iDataContext.addObserver('changeCount', this, this.contextDataDidChange);
            }
          },

          removeDataContextObserver: function (iDataContext) {
            if( iDataContext)
              iDataContext.removeObserver('changeCount', this, this.contextDataDidChange);
          },

          contextDataDidChange: function (iDataContext) {
            var this_ = this;

            function doIncrement() {
              if( this_.dependent)
                this_.dependent.incrementStateCount();
            }

            function checkTime() {
              var tNow = Date.now();
              if( tNow - gTimeOfLastSelectCall > kSelectDelay) {
                doIncrement();
                gWaitingForSelect = false;
                gSelectTimer.invalidate();
                gSelectTimer = null;
              }
              else {
                gSelectTimer = SC.Timer.schedule({target: this, action: checkTime, interval: kSelectInterval});
              }
            }

            function respondToSelectCases() {
              if( gMoveArrowClickInProgress) {
                gMoveArrowClickInProgress = false;
                doIncrement();
              }
              else {
                gTimeOfLastSelectCall = Date.now();
                if (!gWaitingForSelect) {
                  gWaitingForSelect = true;
                  gSelectTimer = SC.Timer.schedule({target: this, action: checkTime, interval: kSelectInterval});
                }
              }
            }

            function selectNewCases(iCaseIDs) {
              var tCases = iCaseIDs.map( function( iID) {
                return iDataContext.getCaseByID( iID);
              });
              iDataContext.doSelectCases( {
                operation: 'selectCases',
                cases: tCases,
                select: true
              });
            }

            iDataContext.get('newChanges').forEach(function (iChange) {
              switch (iChange.operation) {
                  case 'selectCases':
                    respondToSelectCases();
                    break;
                  case 'createCases':
                    selectNewCases(iChange.result.caseIDs);
                    doIncrement();
                    break;
                default:
                  doIncrement();
              }
            }.bind(this));
          }

        });

        return {
          changeListener: null,
          currEditField: null,

          getInitialState: function () {
            return {
              count: 0,
              attrIdOfNameToEdit: null,
              attrIdOfValueToEdit: null,
              // map: collection => measured widths of attribute columns
              columnWidths: {},
              // map: collection => virtual position of resize handle during active resizing
              resizeWidths: {}
            };
          },

          componentDidMount: function () {
            this.changeListener = ChangeListener.create({
              dependent: this
            });
            this.changeListener.set('context', this.props.context);
          },

          componentDidUpdate: function() {
            this.changeListener.set('context', this.props.context);
          },

          componentWillUnmount: function () {
            this.changeListener.destroy();
            this.changeListener = null;
          },

          handleColumnWidthChange: function (collection, width) {
            this.setState(function(state) {
              if (width)
                state.columnWidths[collection] = width;
              else
                delete state.columnWidths[collection];
              return state;
            });
          },

          handleUserResizeColumn: function (collectionName, iWidth, isComplete) {
            // attempt to maintain minimum column width
            var width = iWidth,
                containerWidth = this.props.size && this.props.size.width;
            if (containerWidth) {
              if ((width < kMinColumnWidth) && (containerWidth >= 2 * kMinColumnWidth)) {
                width = kMinColumnWidth;
              }
              if ((containerWidth - width < kMinColumnWidth) &&
                  (containerWidth > kMinColumnWidth + 20)) {
                width = containerWidth - kMinColumnWidth;
              }
            }
            this.setState(function(state) {
              var newState;
              if (!isComplete) {
                // store current width; presence indicates resize-in-progress
                if (width !== state.resizeWidths[collectionName]) {
                  state.resizeWidths[collectionName] = width;
                  newState = state;
                }
              }
              else {
                // remove width/resize-in-progress indicator once complete
                if (state.resizeWidths[collectionName] !== undefined) {
                  delete state.resizeWidths[collectionName];
                  newState = state;
                }

                // only notify parent once resize is complete
                var widthPct = width / containerWidth;
                this.props.onResizeColumn &&
                  this.props.onResizeColumn(collectionName, widthPct);
              }
              return newState;
            });
          },

          incrementStateCount: function () {
            this.setState({count: this.state.count + 1});
          },

          stashEditValueInCaseAttributeValue: function() {
            if (this.currEditField) {
              DG.DataContextUtilities.stashAttributeValue( this.props.context, this.currEditField.props['case'],
                  this.currEditField.props.attr, this.currEditField.state.value);
              this.currEditField = null;
              this.setState({ attrIdOfValueToEdit: null });
            }
          },

          /**
           *  ------------------Below here are rendering functions---------------
           */

          renderCollectionHeader: function (iIndex, iCollClient, iCaseID) {

            var handleDropInCollectionHeader = function (iAttribute) {
              var tCollection = iCollClient.get('collection'),
                  tParentCollection = tCollection.get('parent'),
                  tCmd = DG.DataContextUtilities.createCollectionCommand(
                      iAttribute, tCollection, this.props.context, tParentCollection);
              DG.UndoHistory.execute(tCmd);
            }.bind(this);

            return DG.React.Components.CollectionHeader({
              index: iIndex,
              collClient: iCollClient,
              caseID: iCaseID,
              onCollectionNameChange: function(iOldName, iNewName) {
                SC.run(function() {
                  DG.CaseDisplayUtils
                    .setCollectionNameWithCommand(this.props.context, iOldName, iNewName);
                }.bind(this));
              }.bind(this),
              onNext: this.moveToNextCase,
              onPrevious: this.moveToPreviousCase,
              onDeselect: this.deselect,
              onNewCase: this.newCase,
              dragStatus: this.props.dragStatus,
              dropCallback: handleDropInCollectionHeader
            });
          },

          renderAttribute: function (iContext, iCollection, iCases,
                                     iAttr, iAttrIndex, iShouldSummarize, iChildmostSelected) {
            /**
             * -------------------------Dragging this attribute----------------
             */
            function stop(iEvent) {
              iEvent.preventDefault();
              iEvent.stopPropagation();
            }

            function cancelTouchTooltip(hide) {
              if (tTouchTimer) {
                clearTimeout(tTouchTimer);
                tTouchTimer = null;
              }
              hide && DG.TouchTooltips.hideAllTouchTooltips();
            }

            function handlePointerDown(iEvent) {
              tPointerIsDown = true;
              tStartCoordinates = {x: iEvent.clientX, y: iEvent.clientY};
              tDragInProgress = false;
            }

            function handlePointerMove(iEvent) {
              if (!tStartCoordinates)
                return;
              if (!tDragInProgress) {
                handleDragStart(iEvent);
              }
              else {
                tDragHandler.handleDoDrag(iEvent.clientX - tStartCoordinates.x,
                    iEvent.clientY - tStartCoordinates.y,
                    iEvent.clientX, iEvent.clientY, iEvent);
              }
            }

            function handlePointerUp() {
              tTouchID = null;
              tTouchTimer = null;
              tPointerIsDown = false;
              tStartCoordinates = null;
              tDragInProgress = false;
              tDragHandler = null;
            }

            function handleMouseDown(iEvent) {
              cancelTouchTooltip(true);
              if (iEvent.button !== 0) return;
              handlePointerDown(iEvent);
            }

            function handleTouchStart(iEvent) {
              cancelTouchTooltip(true);
              var elt = iEvent.target,
                  touch = iEvent.changedTouches[0];
              tTouchID = touch.identifier;
              if (elt) {
                tTouchTimer = setTimeout(function() {
                                DG.TouchTooltips.showTouchTooltip(touch, elt, elt.title);
                                // prevent drag
                                handlePointerUp();
                              }, 500);
              }
              handlePointerDown(iEvent.changedTouches[0]);
            }

            function handleMouseMove(iEvent) {
              handlePointerMove(iEvent);
              tDragInProgress && stop(iEvent);
            }

            function handleTouchEvent(iEvent) {
              cancelTouchTooltip();
              for (var i = 0; i < iEvent.touches.length; ++i) {
                if (iEvent.touches[i].identifier === tTouchID) {
                  // initial touch is still active
                  handlePointerMove(iEvent.touches[i]);
                  tDragInProgress && stop(iEvent);
                  return;
                }
              }
              // initial touch is no longer active
              handlePointerUp();
            }

            function handleMouseUp() {
              handlePointerUp();
            }

            function handleMouseLeave(iEvent) {
              if (tPointerIsDown) {
                if (!tDragInProgress) {
                  doDragStart(iEvent);
                }
                if (tDragHandler) {
                  tDragHandler.handleDoDrag(iEvent.clientX - tStartCoordinates.x,
                    iEvent.clientY - tStartCoordinates.y,
                    iEvent.clientX, iEvent.clientY, iEvent);
                }
              }
            }

            function doDragStart(iEvent) {
              if (!tDragInProgress) {
                tDragHandler = DG.DragCaseCardItemHandler.create({
                  viewToAddTo: DG.mainPage.docView,
                  dataContext: iContext,
                  attribute: iAttr
                });
                tDragHandler.handleStartDrag(iEvent);
                tDragInProgress = true;
              }
            }

            function handleCellLeave(iEvent) {
              if (tDragInProgress)
                handleMouseMove(iEvent);
            }

            function handleDragStart(iEvent) {
              if (!tStartCoordinates)
                return;
              var tCurrent = {x: iEvent.clientX, y: iEvent.clientY},
                  tDistance = (tCurrent.x - tStartCoordinates.x) * (tCurrent.x - tStartCoordinates.x) +
                      (tCurrent.y - tStartCoordinates.y) * (tCurrent.y - tStartCoordinates.y);
              if (tPointerIsDown && tDistance > kThresholdDistance2) {
                doDragStart();
              }
            }

            /**
             * --------------------------Another attribute is dropped---------------
             */
            var moveWithinOwnContext = function(iMoveDirection) {
              var tDroppedAttr = this.props.dragStatus.dragObject.data.attribute,
                  tPosition = iAttrIndex + (iMoveDirection === 'up' ? 0 : 1),
                  tFromCollection = tDroppedAttr.get('collection');
              // If we're not actually moving the attribute, bail now
              if (iCollection === tFromCollection &&
                  tPosition === tFromCollection.get('attrs').indexOf(tDroppedAttr))
                return;

              var tChange = {
                operation: 'moveAttribute',
                attr: tDroppedAttr,
                toCollection: iCollection,
                fromCollection: tFromCollection,
                position: tPosition
              };
              // Apply the change, but not as part of the current render
              iContext.invokeLater(function () {
                iContext.applyChange(tChange);
              });
            }.bind(this);

            var joinForeignContext = function() {
              var tKeyAttribute = this.props.dragStatus.dragObject.data.attribute,
                  tCollClient = iContext.getCollectionByID(iCollection.get('id'));
              if( tKeyAttribute && iContext && tCollClient && iAttr) {
                iContext.invokeLater( function() {
                  DG.DataContextUtilities.joinSourceToDestCollection( tKeyAttribute, iContext,
                      tCollClient, iAttr);
                });
              }
            }.bind( this);

            var handleDrop = function (iMoveDirection) {
              if( this.props.dragStatus.dragType === 'ownContext')
                moveWithinOwnContext( iMoveDirection);
              else if( this.props.dragStatus.dragType === 'foreignContext')
                joinForeignContext();
            }.bind(this);

            /**
             * --------------------------Handling editing the value-----------------
             */
            var toggleEditing = function (iValueField, iMoveDirection ) {
              var tAttrs = iCollection.get('attrs'),
                  tEditFieldOnEntry = this.currEditField;

              function isEditableIndex(index) {
                var attr;
                return (index >= 0) && (index < tAttrs.length) &&
                        (attr = tAttrs[index]) && attr.get('editable') && !attr.hasFormula();
              }

              this.stashEditValueInCaseAttributeValue();
              if (tEditFieldOnEntry !== iValueField) {
                this.currEditField = iValueField;
                this.setState({ attrIdOfValueToEdit: iAttr.get('id') });
              }
              else if( iMoveDirection) {  // Turn off editing
                var tIncrement,
                    tIndexToMount = iAttrIndex;

                switch (iMoveDirection) {
                  case 'up':
                    tIncrement = -1;
                    break;
                  case 'down':
                    tIncrement = 1;
                    break;
                }
                tIndexToMount += tIncrement;
                while ((tIndexToMount >= 0) && (tIndexToMount < tAttrs.length) && !isEditableIndex(tIndexToMount)) {
                  tIndexToMount += tIncrement;
                }
                if (isEditableIndex(tIndexToMount))
                  this.setState({ attrIdOfValueToEdit: tAttrs[tIndexToMount].get('id') });
              }
            }.bind(this);

            var escapeEditing = function (iValueField) {
              this.currEditField = null;
              this.setState({ attrIdOfValueToEdit: null });
            }.bind(this);

            var editModeCallback = function( iValueField) {
              this.currEditField = iValueField;
            }.bind(this);

            /**
             * ---------------------------Handlers for dropdown menu------------
             */

            var updateAttribute = function(iChangedAttrProps) {
                  DG.DataContextUtilities.updateAttribute(iContext, iCollection, iAttr, iChangedAttrProps);
                },
                renameAttribute = function(iNewName) {
                  var currName = iAttr.get('name'),
                      newName = iContext.getUniqueAttributeName(iNewName, [currName]);
                  if (newName !== currName) {
                    updateAttribute({ name: newName });
                  }
                }.bind(this),
                editAttribute = function () {
                  this.updateAttribute = function(iAttrRef, iChangedAttrProps) {
                    updateAttribute(iChangedAttrProps);
                  };
                  var attributePane = DG.AttributeEditorView.create({attrRef: {attribute: iAttr}, attrUpdater: this});
                  attributePane.append();
                }.bind(this),

                editFormula = function () {
                  iContext.invokeLater( function () {
                    DG.DataContextUtilities.editAttributeFormula(iContext, iCollection,
                        iAttr.get('name'), iAttr.get('formula'));
                  }, 30);
                }.bind(this),

                hideAttribute = function () {
                  DG.DataContextUtilities.hideAttribute(iContext, iAttr.get('id'));
                }.bind(this),

                attributeCanBeHidden = function () {
                  return iAttr.get('collection').numberOfVisibleAttributes() > 1;
                }.bind(this),

                deleteAttribute = function () {
                  DG.DataContextUtilities.deleteAttribute(iContext, iAttr.get('id'));
                }.bind(this),

                deleteAttributeFormula = function () {
                  DG.DataContextUtilities.deleteAttributeFormula(iContext, iAttr.get('id'));
                }.bind(this),

                recoverAttributeFormula = function () {
                  DG.DataContextUtilities.recoverAttributeFormula(iContext, iAttr.get('id'));
                }.bind(this),

                formulaIsEditable = function () {
                  return iAttr.get('editable');
                },

                attributeCanBeRandomized = function () {
                  return DG.DataContextUtilities.attributeCanBeRandomized(iContext, iAttr.get('id'));
                },

                rerandomizeAttribute = function () {
                  DG.DataContextUtilities.randomizeAttribute(iContext, iAttr.get('id'));
                },

                isNewAttributeEnabled = function () {
                  var isTopLevel = !iCollection.get('parent');
                  return !(isTopLevel && DG.DataContextUtilities.isTopLevelReorgPrevented(iContext));
                },

                makeNewAttribute = function() {
                  var collection = iContext.getCollectionByID(iCollection.get('id')),
                      position = 1, // Just after the first attribute
                      onComplete = function(attrName) {
                                    var attrRef = iContext.getAttrRefByName(attrName),
                                        attrID = attrRef && attrRef.attribute.get('id');
                                    attrID && this.setState({ attrIdOfNameToEdit: attrID });
                                  }.bind(this);
                  DG.DataContextUtilities.newAttribute(iContext, collection, position, onComplete);
                }.bind(this);

            /**
             * --------------------------Body of renderAttribute-----------------
             */
            var getColumnWidthPct = function(collectionName, attrIndex) {
              // only apply column width to first row of table
              if (attrIndex !== 0) return;
              // if we're actively resizing, size is determined by current resizeWidth
              var resizeWidth = this.state.resizeWidths[collectionName],
                  containerWidth = this.props.size && this.props.size.width;
              if (resizeWidth && containerWidth)
                return resizeWidth / containerWidth;
              // otherwise, size is determined by columnWidthMap
              return this.props.columnWidthMap && this.props.columnWidthMap[collectionName];
            }.bind(this);

            var tCollectionName = iCollection.get('name'),
                tAttrID = iAttr.get('id'),
                tCase = iShouldSummarize ? null : (iChildmostSelected && iChildmostSelected[0]) || iCases[0],
                tDiv = div({
                  className: 'react-data-card-attribute',
                  title: DG.CaseDisplayUtils.getTooltipForAttribute(iAttr),
                  onMouseDown: handleMouseDown,
                  onMouseUp: handleMouseUp,
                  onMouseLeave: handleMouseLeave,
                  onMouseMove: handleMouseMove,
                  onTouchStart: handleTouchStart,
                  onTouchMove: handleTouchEvent,
                  onTouchEnd: handleTouchEvent,
                  onTouchCancel: handleTouchEvent
                }, iAttr.get('name')),
                tNameCell = DG.React.AttributeNameCell({
                  content: tDiv,
                  attribute: iAttr,
                  showNewAttrButton: (iAttrIndex === 0) && (tAttrID !== this.state.attrIdOfNameToEdit),
                  isEditing: tAttrID === this.state.attrIdOfNameToEdit,
                  dragStatus: this.props.dragStatus,
                  dropCallback: handleDrop,
                  onBeginRenameAttribute: function() {
                    this.setState({ attrIdOfNameToEdit: tAttrID });
                  }.bind(this),
                  onEndRenameAttribute: function(iNewName) {
                    iNewName && renameAttribute(iNewName);
                    this.setState({ attrIdOfNameToEdit: null });
                  }.bind(this),
                  columnWidthPct: getColumnWidthPct(tCollectionName, iAttrIndex),
                  onColumnWidthChanged: (iAttrIndex === 0) &&
                                        function(width) {
                                          this.handleColumnWidthChange(tCollectionName, width);
                                        }.bind(this),
                  editAttributeCallback: editAttribute,
                  editFormulaCallback: editFormula,
                  attributeCanBeHiddenCallback: attributeCanBeHidden,
                  hideAttributeCallback: hideAttribute,
                  deleteAttributeCallback: deleteAttribute,
                  deleteAttributeFormulaCallback: deleteAttributeFormula,
                  recoverAttributeFormulaCallback: recoverAttributeFormula,
                  attributeIsEditableCallback: formulaIsEditable,
                  attributeCanBeRandomizedCallback: attributeCanBeRandomized,
                  rerandomizeCallback: rerandomizeAttribute,
                  newAttributeCallback: isNewAttributeEnabled() ? makeNewAttribute : null,
                  cellLeaveCallback: handleCellLeave
                }),
                tValueCell = DG.React.AttributeValueCell({
                  attribute: iAttr,
                  dataContext: this.props.context,
                  displayCase: tCase,
                  editableCase: iShouldSummarize ? null : iCases[0],
                  summaryCases: iShouldSummarize ? iCases : null,
                  deselectCallback: function() {
                    SC.run(function () {
                      if( this.props.isSelectedCallback())
                        this.props.context.applyChange({ operation: 'selectCases', select: false });
                    }.bind(this));
                  }.bind(this),
                  forceUpdateCallback: this.incrementStateCount,
                  editProps: {
                    isEditing: tAttrID === this.state.attrIdOfValueToEdit,
                    onToggleEditing: toggleEditing,
                    onEscapeEditing: escapeEditing,
                    onEditModeCallback: editModeCallback
                  }
                });

            return (
              tr({ key: 'attr-' + iAttrIndex, className: 'react-data-card-row' },
                tNameCell,
                tValueCell
              )
            );
          },

          /**
           *
           * @param iCollectionClient {DG.CollectionClient}
           * @param iCaseIndex { Number} zero-based
           */
          moveToCase: function (iCollectionClient, iCaseIndex) {
            gMoveArrowClickInProgress = true; // So we won't delay reflecting move
            var tCase = iCollectionClient.getCaseAt(iCaseIndex),
                tChange = {
                  operation: 'selectCases',
                  collection: iCollectionClient,
                  cases: [tCase],
                  select: true,
                  extend: false
                };
            SC.run(function () {
              this.props.context.applyChange(tChange);
            }.bind(this));
          },

          /**
           * -------------------Get first child case of selected case-----------------
           */
          getSelectedCaseFirstChildCaseID: function (iCollection) {
              var tSelectedCaseFirstChildCaseID,
                  tContext = this.props.context;
              var tSelectedCases = tContext.getCollectionByID(iCollection.get('id')).getPath('casesController.selection').toArray();
              if (tSelectedCases.length) {
                tSelectedCaseFirstChildCaseID = tSelectedCases[0].get('children')[0].id;
              }
              return tSelectedCaseFirstChildCaseID;
          },

          getSelectedCaseIndices: function (iCollectionClient) {
            var tSelectedCases = iCollectionClient.getPath('casesController.selection').toArray(),
                tSortedSelection = tSelectedCases.map(function(iCase) {
                  return {
                    id: iCase.id,
                    index: iCollectionClient.getCaseIndexByID(iCase.id)
                  };
                });
            tSortedSelection.sort(function(a, b) {
              return a.index - b.index;
            });
            return tSortedSelection.map(function(iEntry) {
              return iEntry.index;
            });
          },

          /**
           *
           * @param iCollectionClient
           * @param iCaseIndex  {
           */
          moveToPreviousCase: function (iCollectionClient, iCaseIndex) {
            this.stashEditValueInCaseAttributeValue();

            var tPrevIndex = null;
            var tParentCollection = iCollectionClient.getPath('collection.parent');
            var tNumCases = iCollectionClient.getPath('collection.cases').length;
            if (SC.none(iCaseIndex)) {
              if (tParentCollection) {
                var tSelectedParentFirstCaseID = this.getSelectedCaseFirstChildCaseID(tParentCollection);
                if (tSelectedParentFirstCaseID) {
                  tPrevIndex = iCollectionClient.getCaseIndexByID(tSelectedParentFirstCaseID) - 1;
                  if (tPrevIndex < 0) {
                    tPrevIndex = tNumCases - 1;
                  }
                }
              }
              else {
                // get index of last selected case
                var tSelectedIndices = this.getSelectedCaseIndices(iCollectionClient);
                if (tSelectedIndices.length)
                  tPrevIndex = tSelectedIndices[tSelectedIndices.length - 1];
              }
            }
            if (SC.none(iCaseIndex) || iCaseIndex > 1) {
              if (SC.none(tPrevIndex)) {
                tPrevIndex = SC.none(iCaseIndex) ? tNumCases - 1 : iCaseIndex - 2; // because we need zero-based
              }
              this.moveToCase(iCollectionClient, tPrevIndex);
            }
          },

          moveToNextCase: function (iCollectionClient, iCaseIndex) {
            this.stashEditValueInCaseAttributeValue();

            var tParentCollection = iCollectionClient.getPath('collection.parent');
            if (SC.none(iCaseIndex)) {
              if (tParentCollection) {
                var tSelectedParentFirstCaseID = this.getSelectedCaseFirstChildCaseID(tParentCollection);
                if (tSelectedParentFirstCaseID) {
                  iCaseIndex = iCollectionClient.getCaseIndexByID(tSelectedParentFirstCaseID);
                }
              }
              else {
                // get index of first selected case
                var tSelectedIndices = this.getSelectedCaseIndices(iCollectionClient);
                if (tSelectedIndices.length)
                  iCaseIndex = tSelectedIndices[0];
              }
            }
            var tNumCases = iCollectionClient.getPath('collection.cases').length;
            if (SC.none(iCaseIndex) || iCaseIndex < tNumCases) {
              var tNext = SC.none(iCaseIndex) ? 0 : iCaseIndex; // because in zero-based this is the index of the next case
              this.moveToCase(iCollectionClient, tNext);
            }
          },

          deselect: function() {
            SC.run(function() {
              this.props.context.applyChange({ operation: 'selectCases', select: false });
            }.bind(this));
          },

          newCase: function( iCollectionClient) {
            var tCollection = iCollectionClient.get('collection'),
                tContext = this.props.context,
                tAttrIDs = tCollection && tCollection.getAttributeIDs(),
                tParentCollectionClient = this.props.context.getCollectionByID( tCollection.getPath('parent.id')),
                tSelectedParentCases = tParentCollectionClient ?
                    tParentCollectionClient.getPath('casesController.selection').toArray() :
                    null,
                tNumSelected = tSelectedParentCases ? tSelectedParentCases.length : null,
                tParentCase = tNumSelected === 1 ? tSelectedParentCases[0] : null;
            SC.run(function () {
              DG.DataContextUtilities.createCaseUndoable(tContext,
                  {
                    collection: iCollectionClient,
                    parent: tParentCase,
                    attrIDs: tAttrIDs,
                    values: []
                  });
            });
          },

          render: function () {

            function getChildmostSelection(iContext) {
              var tChildmostSel,
                  tCollections = iContext.get('collections'),
                  tCurrColl = tCollections[0],
                  tCurrIndex = 0;
              while (tCurrColl) {
                var tSelectedCases = iContext.getCollectionByID(tCurrColl.get('id')).getPath('casesController.selection').toArray(),
                    tNumSelected = tSelectedCases.length;
                if (tNumSelected > 0) {
                  tChildmostSel = tSelectedCases;
                  tCurrColl = tCollections[++tCurrIndex];
                }
                else if (tNumSelected === 0) {
                  tCurrColl = tCollections[++tCurrIndex];
                }
              }
              return tChildmostSel;
            }

            var tCollEntries = [],
                tContext = this.props.context,
                tChildmostSelection = getChildmostSelection(tContext);
            // collection loop
            tContext.get('collections').forEach(function (iCollection, iCollIndex) {

                  function getDescendantsOfCaseInCollection(iCase, iTargetColl) {
                    var tChildren = iCase.get('children');
                    if (tChildren && tChildren.length > 0) {
                      if (tChildren[0].get('collection') === iTargetColl) {
                        return tChildren;
                      } else {
                        var tResult = [];
                        tChildren.forEach(function (iChild) {
                          tResult = tResult.concat(getDescendantsOfCaseInCollection(iChild, iTargetColl));
                        });
                        return tResult;
                      }
                    }
                    return [];
                  }

                  function getParentsOfChildmostSelection() {
                    var tParents = [],
                        tCollOfChildMostSelection = tChildmostSelection && tChildmostSelection[0].get('collection');
                    if (tChildmostSelection &&
                        tChildmostSelection[0].get('collection').isDescendantOf(iCollection)) {
                      iCollection.get('cases').forEach(function (iCase) {
                        // Which of my cases have descendants in tChildmostSelection?
                        var tCandidates = getDescendantsOfCaseInCollection(iCase, tCollOfChildMostSelection);
                        if (tCandidates.some(function (iCandidate) {
                          return tChildmostSelection.indexOf(iCandidate) >= 0;
                        })) {
                          tParents.push(iCase);
                        }
                      });
                    }
                    return tParents;
                  }

                  var tCollClient = tContext.getCollectionByID(iCollection.get('id')),
                      tCollectionName = tCollClient.get('name'),
                      tSelectedCases = tCollClient ? tCollClient.getPath('casesController.selection').toArray() : null,
                      tSelLength = tSelectedCases ? tSelectedCases.length : 0,
                      tCases = tSelLength > 0 ? tSelectedCases :
                          (tChildmostSelection ? getParentsOfChildmostSelection() : iCollection.get('cases')),
                      tCasesLength = tCases ? tCases.length : 0,
                      tCase = tSelLength === 1 ? tSelectedCases[0] :
                          (tCasesLength === 1 ? tCases[0] : null),
                      tShouldSummarize = SC.none( tCase),
                      tCollectionHeader = this.renderCollectionHeader(iCollIndex, tCollClient, tCase && tCase.get('id')),
                      tColumnWidth = this.state.resizeWidths[tCollectionName] || this.state.columnWidths[tCollectionName],
                      tContainerWidth = this.props.size && this.props.size.width,
                      tAttrEntries = [],
                      tResizeHandle;

                  iCollection.get('attrs').forEach(function (iAttr, iAttrIndex) {
                    if (!iAttr.get('hidden')) {
                      tAttrEntries.push(
                          this.renderAttribute(tContext, iCollection, tCases,
                              iAttr, iAttrIndex, tShouldSummarize,
                              tChildmostSelection));
                    }
                  }.bind(this));

                  if (tContainerWidth && tColumnWidth) {
                    var kResizeHandleClass = "case-card-column-resize-handle";
                    tResizeHandle = DG.React.ColumnResizeHandle({
                                      className: kResizeHandleClass,
                                      key: kResizeHandleClass + iCollIndex + '-' + tCollectionName,
                                      enabled: true,
                                      containerWidth: tContainerWidth,
                                      columnWidth: tColumnWidth,
                                      minWidth: kMinColumnWidth,
                                      onResize: function(width, isComplete) {
                                        this.handleUserResizeColumn(tCollectionName, width, isComplete);
                                      }.bind(this)
                                    });
                  }

                  tCollEntries.push(
                    div({ className: 'case-card-collection',
                          key: 'collection-' + iCollIndex + '-' + tCollectionName },
                      table({},
                        tbody({},
                          tCollectionHeader, tAttrEntries)
                      ),
                      tResizeHandle
                    )
                  );
                }.bind(this)
            );

            return div({
              className: 'react-data-card dg-wants-wheel',
              onMouseDownCapture: DG.Core.setClickHandlingForReact,
            }, tCollEntries);
          }
        };
      }()), []);
  CaseCard.displayName = "CaseCard";
  CaseCard.propTypes = {
    size: PropTypes.shape({ width: PropTypes.number }),
    // the data context
    context: PropTypes.instanceOf(DG.DataContext).isRequired,
    // drag/drop support
    dragStatus: PropTypes.object,
    // map from collection name => column width percentage (0-1)
    columnWidthMap: PropTypes.objectOf(PropTypes.number).isRequired,
    // Is the component in which I'm contained the selected component in the document?
    isSelectedCallback: PropTypes.func.isRequired,
    // function(collectionName, columnWidth) - update column width in model
    onResizeColumn: PropTypes.func.isRequired,
  };

  // use ReactSizeMe to inject size prop into CaseCard
  DG.React.CaseCard = createReactFactory(ReactSizeMe.withSize()(CaseCard));
});

/* >>>>>>>>>> BEGIN source/controllers/component_controller.js */
// ==========================================================================
//                      DG.ComponentController
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

    Coordinates responses to events in a CODAP Component.

 @extends SC.Object
 */
DG.ComponentController = SC.Object.extend((function () // closure
/** @scope DG.ComponentController.prototype */ {

  return {  // return from closure

    /**
     * @type {DG.Component}
     */
    model: null,

    /**
     * @type {DG.ComponentView}
     */
    view: null,

    _oldLayout: null,

    /**
     * Lazy initialization is responsibility of subclass
     * @property {Array of DG.InspectorButtonView}
     */
    _inspectorButtons: null,
    inspectorButtons: function() {
      if( !this._inspectorButtons) {
        this._inspectorButtons = this.createInspectorButtons();
      }
      return this._inspectorButtons;
    }.property('_inspectorButtons'),

    /**
     * Subclasses will call sc_super and push onto array.
     * @returns {Array}
     */
    createInspectorButtons: function() {
      return [];
    },

    destroyInspectorButtons: function() {
      this._inspectorButtons.forEach( function( iButton) {
        iButton.destroy();
      });
      this.set('_inspectorButtons', null);
    },

    /**
     * The component view will add these to its titlebar
     * @property {[SC.View]}
     */
    specialTitleBarButtons: null,

    /**
     * Whether the user interface should should confirm the close of this
     * component.
     *
     * @type {boolean}
     */
    shouldConfirmClose: NO,

    shouldDestroyOnComponentDestroy: true,

    init: function() {
      arguments.callee.base.apply(this,arguments);

      this.set('specialTitleBarButtons', []);
    },

    /**
     Give derived classes a chance to clean up after themselves.
     */
    willDestroy: function () {
    },

    destroy: function () {
      this.view = null; // break the loop!
      arguments.callee.base.apply(this,arguments);
    },

    /**
     Utility method for adding entries to the _links_ property of a
     componentStorage object. Will create the _links_ property if necessary.
     @param    {Object}  iStorage -- The componentStorage object with the _links_ property
     @param    {String}  iLinkKey -- The string key of the link in the _links_ property
     @param    {Object}  iObject -- The object being linked; must have a toLink() method
     */
    addLink: function (iStorage, iLinkKey, iObject) {
      DG.ArchiveUtils.addLink(iStorage, iLinkKey, iObject);
    },

    /**
     Utility method for extracting link IDs from the _links_ property
     of a componentStorage object.
     @param    {Object}  iStorage -- The componentStorage object with the _links_ property
     @param    {String}  iLinkKey -- The string key of the link in the _links_ property
     @returns  {Number}              The ID from the link object with the specified key
     */
    getLinkID: function (iStorage, iLinkKey) {
      return DG.ArchiveUtils.getLinkID(iStorage, iLinkKey);
    },

    /**
     Called to create/return an object whose properties should be written out
     to external storage, e.g. by JSONification.
     Derived classes should override to return component-specific storage.
     @returns  {Object}  An object whose properties should be archived.
     */
    createComponentStorage: function () {
      // Derived classes should override to return component-specific storage.
      return {title: this.getPath('model.title')};
    },

    /**
     Called by the framework to give derived classes an opportunity to
     restore the contents of their archived component storage object.
     Derived classes should override to restore their contents appropriately.
     @param  iComponentStorage {Object}  An object whose properties should be restored.
     */
    restoreComponentStorage: function (iComponentStorage, iDocumentID) {
      var tComponentModel = this.get('model'),
          tRestoredTitle = iComponentStorage.title,
          tRestoredName = iComponentStorage.name;
      tComponentModel.set('title', tRestoredTitle || tRestoredName);
      if( tRestoredName)
        tComponentModel.set('name', tRestoredName);
    },

    /**
     Update any properties that need to be updated pre-archive, e.g. layout.
     Called by the framework as part of the document writing process.
     */
    willSaveComponent: function () {

      if (this.model) {
        var componentStorage = this.createComponentStorage();
        if (componentStorage)
          this.model.set('componentStorage', componentStorage);

        this.updateModelLayout();
      }
    },

    /**
     Restore any properties that need to be updated post-archive, e.g. component storage.
     */
    didRestoreComponent: function (iDocumentID) {
      var componentStorage = this.getPath('model.componentStorage');
      if (componentStorage)
        this.restoreComponentStorage(componentStorage, iDocumentID);
      // We don't restore the layout here - the layout is retrieved and used at view construction time.
    },

    updateModelLayout: function() {
      // If our content knows about a frame object, we'll get that frames layout and store it.
      var layout = this.getPath('view.layout'),
          modelLayout = this.model.get('layout');
      layout.isVisible = this.getPath('view.isVisible');  // For views (like Guide) that need to restore visibility
      if( layout && (modelLayout && JSON.stringify(layout) !== JSON.stringify(modelLayout))) {
        this.model.set('layout', layout);
        return modelLayout;
      }
      else if( !modelLayout) {
        this.setPath('model.layout', layout);
      }
      return null;
    },

    revertModelLayout: function(newLayout) {
      var prevLayout = this.model.get('layout');

      this.model.set('layout', newLayout);
      this.model.set('oldLayout', prevLayout);
      this.setPath('view.layout', newLayout);
      return prevLayout;
    },

    /* Notification that the user has clicked the close button on a component. This is an opportunity to finalize things,
       however, the component will be closed as soon as this function returns, so only synchronous code is allowed. It is
       executated outside of an Undo, so it may register a separate undo command, if desired.
     */
    willCloseComponent: function() { }

  }; // end return from closure

}())); // end closure

/* >>>>>>>>>> BEGIN source/utilities/clipboard_utilities.js */
// ==========================================================================
//  
//  Author:   jsandoe
//
//  Copyright (c) 2021 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
sc_require('core');

DG.ClipboardUtilities = {
 foo: 'bar'
};

DG.ClipboardUtilities.canCopy = function () {
  return !!(window.navigator.clipboard);
};

DG.ClipboardUtilities.canPaste = function () {
  return !!(window.navigator.clipboard && window.navigator.clipboard.readText);
};

/* >>>>>>>>>> BEGIN source/components/case_display_common/case_display_controller.js */
// ==========================================================================
//  
//  Author:   jsandoe
//
//  Copyright (c) 2019 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
sc_require('controllers/component_controller');
sc_require('utilities/clipboard_utilities');
DG.CaseDisplayController = DG.ComponentController.extend(
  /** @scope DG.CaseDisplayController.prototype */
  (function() {
    return {
      /**
       The table will reflect the contents of this data context.
       @property   {DG.DataContext} or derived class
       */
      dataContext: null,

      /**
       Initialization function.
       */
      init: function () {
        arguments.callee.base.apply(this,arguments);
      },

      /**
       * Destruction function.
       */
      destroy: function () {
        arguments.callee.base.apply(this,arguments);
      },

      willDestroy: function () {
        arguments.callee.base.apply(this,arguments);
      },

      /**
       * Responds to a notification that this component's data context was deleted.
       * We need to remove ourself, too.
       */
      dataContextWasDeleted: function () {
        var tComponentView = this.get('view'),
            tContainerView = tComponentView.get('parentView');
        this.willCloseComponent();
        this.willSaveComponent();
        tContainerView.removeComponentView( tComponentView);
      },

      /**
       * Hides or shows component.
       */
      toggleViewVisibility: function() {
        // to be overridden in subclass
      },

      /**
       * Creates a serializable object sufficient to restore state of component
       *
       * @return {Object}
       */
      createComponentStorage: function () {
        // to be overridden in subclass
      },

      /**
       * Restores the state of the component from the serializable object
       * created in createComponentStorage.
       *
       * @param iComponentStorage {Object}
       * @param iDocumentID {String}
       */
      restoreComponentStorage: function (iComponentStorage, iDocumentID) {
        // subclasses override
      },

      /**
       * Creates the items in the inspector menu.
       * This is a vertical menu.
       * When active it can be found on the side of a selected Component.
       *
       * @returns {[DG.Button]}
       */
      createInspectorButtons: function() {
        var buttons = arguments.callee.base.apply(this,arguments);
        return buttons;
      },

      createTrashButton: function () {
        return DG.IconButton.create({
              layout: {width: 32},
              classNames: 'dg-table-trash'.w(),
              iconClass: 'moonicon-icon-trash',
              showBlip: true,
              target: this,
              action: 'showDeletePopup',
              toolTip: 'DG.Inspector.delete.toolTip',
              localize: true
            });
      },

      createInfoButton: function () {
        return DG.IconButton.create({
          layout: {width: 32},
          classNames: 'dg-display-dataset-info'.w(),
          iconClass: 'moonicon-icon-info',
          showBlip: true,
          target: this,
          action: 'showInfoPopup',
          toolTip: 'DG.Inspector.datasetInfo.toolTip',  // "Show information about dataset"
          localize: true
        });
      },

      createHideShowButton: function () {
        return DG.IconButton.create({
          layout: {width: 32},
          classNames: 'dg-display-hideshow'.w(),
          iconClass: 'moonicon-icon-hideShow',
          showBlip: true,
          target: this,
          action: 'showHideShowPopup',
          toolTip: 'DG.Inspector.hideShow.toolTip',  // "Show all cases or hide selected/unselected cases"
          localize: true
        });
      },

      createRulerButton: function () {
        // ruler
        return DG.IconButton.create({
              layout: {width: 32},
              classNames: 'dg-table-attributes'.w(),
              iconClass: 'moonicon-icon-values',
              showBlip: true,
              target: this,
              action: 'showAttributesPopup',
              toolTip: 'DG.Inspector.attributes.toolTip',
              localize: true
            });
      },

      createExportCaseButton: function () {
        return {
          title: 'DG.Inspector.exportCaseData', // "Export Case Data..."
          localize: true,
          target: this,
          dgAction: 'exportCaseData'
        };
      },

      createCopyToClipboardButton: function () {
        return {
          title: 'DG.Inspector.copyCaseDataToClipboard', // "Copy Case Data..."
          localize: true,
          isEnabled: DG.ClipboardUtilities.canCopy(),
          target: this,
          dgAction: 'exportCaseDataToClipboard'
        };
      },

      createGetFromClipboardButton: function () {
        return {
          title: 'DG.Inspector.getCaseDataFromClipboard', // "Import Case Data..."
          localize: true,
          isEnabled: DG.ClipboardUtilities.canPaste(),
          target: this,
          dgAction: 'importCaseDataFromClipboard'
        };
      },

      createRandomizeButton: function () {
        var tDataContext = this.get('dataContext');
        return {
          title: 'DG.Inspector.randomizeAllAttributes', // "Randomize Attributes"
          localize: true,
          target: this,
          dgAction: 'randomizeAllAttributes',
          isEnabled: !!(function() {
            var depMgr = tDataContext && tDataContext.get('dependencyMgr'),
                randomNode = depMgr && depMgr.findNode({ type: DG.DEP_TYPE_SPECIAL,
                  id: 'random' }),
                dependents = randomNode && depMgr.findDependentsOfNodes([randomNode]);
            // enabled if any attributes are dependents
            return dependents && dependents.some(function(iDependent) {
              return iDependent.type === DG.DEP_TYPE_ATTRIBUTE;
            });
          }.bind(this))()
        };
      },

      showAttributesPopup: function () {
        // implemented in subclasses
      },

      /**
       * Creates and renders a menu of delete-related actions.
       * Menu is common to the CaseTable and CaseCard components.
       * The menu is instantiated from the Inspector.
       */
      showDeletePopup: function() {
        function deletableCounts(dataContext, cases) {
          var count = cases ? cases.length : 0,
              deletable = cases && cases.map(function(aCase) {
                return DG.DataContextUtilities.isCaseEditable(dataContext, aCase);
              }),
              deletableCount = deletable
                                ? deletable.reduce(function(total, isDeletable) {
                                    return isDeletable ? ++total : total;
                                  }, 0)
                                : 0;
          return { count: count, deletable: deletableCount };
        }
        var tDataContext = this.get('dataContext'),
            tCases = tDataContext && tDataContext.getSelectedCases(true),
            tSelectedCounts = deletableCounts(tDataContext, tCases.selected),
            tUnselectedCounts = deletableCounts(tDataContext, tCases.unselected),
            tItems = [
              {
                title: 'DG.Inspector.selection.selectAll',
                localize: true,
                target: this,
                action: 'selectAll'
              },
              {
                title: 'DG.Inspector.selection.deleteSelectedCases',
                localize: true,
                target: this,
                action: 'deleteSelectedCases',
                isEnabled: tSelectedCounts.deletable > 0
              },
              {
                title: 'DG.Inspector.selection.deleteUnselectedCases',
                localize: true,
                target: this,
                action: 'deleteUnselectedCases',
                isEnabled: tUnselectedCounts.deletable > 0
              },
              {
                title: 'DG.Inspector.deleteAll',
                localize: true,
                target: this,
                action: 'deleteAllCases',
                isEnabled: tSelectedCounts.deletable + tUnselectedCounts.deletable > 0
              }
            ],
            tMenu = DG.MenuPane.create({
              classNames: 'dg-delete-popup'.w(),
              layout: {width: 200, height: 150},
              items: tItems
            });
        tMenu.popup(this.get('inspectorButtons')[0]);
      },

      showInfoPopup: function () {
        var attributePane = DG.DatasetMetadataView.create({dataContext: this.dataContext});
        attributePane.append();
      },

      /**
       * Creates and renders a menu of hide/show-related actions.
       * Menu is common to the CaseTable and CaseCard components.
       * The menu is instantiated from the Inspector.
       */
      showHideShowPopup: function () {
        var tDataContext = this.get('dataContext'),
            tSelection = tDataContext && tDataContext.getSelectedCases(),
            tSelectedIsEnabled = tSelection && tSelection.get('length') > 0,
            tCaseCount = tDataContext.get('totalCaseCount'),
            tSetAsideCount = tDataContext.get('setAsideCount'),
            tUnselectedIsEnabled = (tCaseCount > 0) &&
                (!tSelection || tSelection.get('length') < tCaseCount),
            tHiddenAttributeCount = tDataContext.getHiddenAttributes().length,
            tHiddenAttributePrompt = tHiddenAttributeCount === 0 ?
              'DG.Inspector.attributes.showAllHiddenAttributesDisabled' :
                (tHiddenAttributeCount === 1 ? 'DG.Inspector.attributes.showAllHiddenAttributesSing' :
                     'DG.Inspector.attributes.showAllHiddenAttributesPlural'),
            tItems = [
              {
                title: 'DG.Inspector.setaside.setAsideSelectedCases',
                localize: true,
                target: this,
                action: 'setAsideSelectedCases',
                isEnabled: tSelectedIsEnabled
              },
              {
                title: 'DG.Inspector.setaside.setAsideUnselectedCases',
                localize: true,
                target: this,
                action: 'setAsideUnselectedCases',
                isEnabled: tUnselectedIsEnabled
              },
              {
                title: 'DG.Inspector.setaside.restoreSetAsideCases'.loc(tSetAsideCount),
                localize: false,
                target: this,
                action: 'restoreSetAsideCases',
                isEnabled: (tSetAsideCount > 0)
              },
              {
                title: tHiddenAttributePrompt.loc(tHiddenAttributeCount),
                localize: false,
                target: this,
                action: 'showAllHiddenAttributes',
                isEnabled: (tHiddenAttributeCount > 0)
              }
            ],
            tMenu = DG.MenuPane.create({
              classNames: 'dg-hideshow-popup'.w(),
              layout: {width: 200, height: 150},
              items: tItems
            });
        tMenu.popup(this.get('inspectorButtons')[0]);
      },

      /**
       * Selects all cases in this object's dataset.
       */
      selectAll: function () {
        var tContext = this.get('dataContext'),
            tCollection = tContext && tContext.getCollectionAtIndex(0),
            tChange;
        if (tCollection) {
          tChange = {
            operation: 'selectCases',
            collection: tCollection,
            cases: null,// null selects all
            select: true
          };
        }
        tContext.applyChange( tChange);
      },

      /**
       * Deletes the currently selected cases from their collections.
       */
      deleteSelectedCases: function () {
        this._deleteOrSetAsideSelectedCases(false);
      },

      /**
       * Sets aside the currently selected cases from their collections.
       */
      setAsideSelectedCases: function () {
        this._deleteOrSetAsideSelectedCases(true);
      },

      _deleteOrSetAsideSelectedCases: function(iSetAside) {
        var tContext = this.get('dataContext'),
            tCases = tContext.getSelectedCases(),
            tDeletable = tCases.filter(function(aCase) {
                          return DG.DataContextUtilities.isCaseEditable(tContext, aCase);
                        }),
            tChange;
        if (tContext && tDeletable.length) {
          // We deselect the cases before deleting them for performance
          // reasons. Deleting selected cases is much less efficient because
          // of list reconstruction.
          tChange = {
            operation: 'selectCases',
            select: false,
            cases: tDeletable
          };
          tContext.applyChange( tChange);
          tChange = {
            operation: 'deleteCases',
            setAside: iSetAside,
            cases: tDeletable
          };
          tContext.applyChange( tChange);
        }
      },

      /**
       * Deletes the currently unselected cases.
       */
      deleteUnselectedCases: function () {
        this._deleteOrSetAsideUnselectedCases(false);
      },

      /**
       * Sets aside the currently unselected cases.
       */
      setAsideUnselectedCases: function () {
        this._deleteOrSetAsideUnselectedCases(true);
      },

      _deleteOrSetAsideUnselectedCases: function(iSetAside) {
        var tContext = this.get('dataContext'),
            tCases = tContext.getSelectedCases(true),
            tDeletable = tCases.unselected
                          .filter(function(aCase) {
                            return DG.DataContextUtilities.isCaseEditable(tContext, aCase);
                          });
        if (tCases.unselected.length) {
          tContext.applyChange({
            operation: 'deleteCases',
            setAside: iSetAside,
            cases: tDeletable
          });
        }
      },

      /**
       * Delete all cases represented by the case table.
       * Passes the request on to the data context to do the heavy lifting.
       */
      deleteAllCases: function(){
        var tContext = this.get('dataContext'),
            tAllCases = tContext.get('allCases'),
            tDeletable = tAllCases.filter(function(aCase) {
                          return DG.DataContextUtilities.isCaseEditable(tContext, aCase);
                        });
        if (tDeletable.length) {
          var tChange = {
            operation: 'deleteCases',
            cases: tDeletable
          };
          tContext.applyChange( tChange);
        }
      },

      restoreSetAsideCases: function () {
        var tContext = this.get('dataContext');
        tContext.restoreSetAsideCases();
      },

      showAllHiddenAttributes: function () {
        DG.DataContextUtilities.showAllHiddenAttributes( this.get('dataContext'));
      },

      /**
       * Randomize all attributes
       */
      randomizeAllAttributes: function() {
        var dataContext = this.get('dataContext');
        if (dataContext)
          dataContext.doRerandomizeAll();
      },

      /**
       Handler for the Export Case Data... menu command.
       Displays a dialog, so user can select and copy the case data from the current document.
       */
      _exportCaseData: function (dataContext, prompt, doIt, tooltip, callback) {
        function getCollectionMenuItems(dataContext) {
          var names = [];
          dataContext.forEachCollection(function (collection) {
            var name = collection.get('name');
            names.push(name);
          });
          names.push('DG.CaseTableController.allTables'.loc());
          return names;
        }

        // callback to get export string from one of the menu item titles

        // get array of exportable collection names for menu titles
        var tMenuItems = getCollectionMenuItems(dataContext),
            tStartingMenuItem = tMenuItems[0];

        // If we have only one collection then we will have two items in this
        // array. If we only have one collection, then we can bypass the dialog.
        if (tMenuItems.length > 2) {
          DG.CreateExportCaseDataDialog({
            prompt: prompt,
            collectionMenuTitle: tStartingMenuItem,
            collectionMenuItems: tMenuItems,
            collectionMenuItemAction: callback,
            exportTitle: doIt,
            exportTooltip: tooltip,
            cancelTitle: 'DG.AppController.exportDocument.cancelTitle',
            cancelTooltip: 'DG.AppController.exportDocument.cancelTooltip'
          });
        } else {
          callback(tMenuItems[1]);
        }
      },

      exportCaseData: function () {
        var tDataContext = this.get('dataContext');
        var exportCollection = function (whichCollection) {
          var caseDataString = tDataContext.exportCaseData(whichCollection);
          DG.exportFile(caseDataString, "csv", "text/plain");
        };
        this._exportCaseData(tDataContext,
            'DG.AppController.exportCaseData.prompt',
            'DG.AppController.exportDocument.exportTitle',
            'DG.AppController.exportDocument.exportTooltip',
            exportCollection);
      },

      /**
       * Export case data to clipboard.
       * Puts up dialog to select a collection to export, then copies to
       * clipboard both as text/plain and text/csv. The later is important for
       * reimport.
       *
       * As of 8/2020 browser support varies. Firefox does not support
       * the ClipboardItem API. Chrome does not support setting the ClipboardItem
       * to mime types other than text/plain and image/png. Weirdly, Safari
       * implements everything correctly. So, we attempt to use the API correctly,
       * and if there is a failure we back down to an alternate method that uses
       * the deprecated document command, 'copy'.
       */
      exportCaseDataToClipboard: function () {
        var tDataContext = this.get('dataContext');
        var exportCollection = function (whichCollection) {
          /*
           * This is the fallback copy method. We create a copy event handler which
           * modifies the copy data, perform the copy, then remove the handler.
           */
          function clipboardCopyAlt(data) {
            document.oncopy = function (e) {
              e.preventDefault(); // we handle it
              var dT = e.clipboardData;
              dT.setData( 'text/plain', data ); // as plain text
              dT.setData( 'text/csv', data ); // as csv
            };
            document.execCommand( 'copy' );
            SC.run(function(){
              DG.AlertPane.info({
                localization: true,
                message: copyMessage
              });
            });
            document.oncopy = null;
          }

          function makeCopyMessage(dataContext, collectionName) {
            var isAllTables = (collectionName === 'DG.CaseTableController.allTables'.loc());
            // var groupName = isAllTables? dataContext.get('name') : collectionName;
            var collection = isAllTables? dataContext.get('childCollection'): dataContext.getCollectionByName(collectionName);
            var caseCount = collection.getCaseCount();
            var caseCountString = dataContext.getCaseCountString(collection, caseCount);
            return "DG.Inspector.caseTable.exportCaseDialog.copiedData".loc(caseCountString);
          }

          var caseDataString = tDataContext.exportCaseData(whichCollection);
          var copyMessage = makeCopyMessage(tDataContext, whichCollection);
          if (window.ClipboardItem) {
            var blob = new Blob([caseDataString], {type: 'text/plain'});
            window.navigator.clipboard.write([new window.ClipboardItem({
              'text/csv': blob, 'text/plain': blob
            })]).then(function (data) {
              SC.run(function () {
                DG.AlertPane.info({
                  localization: true,
                  message: copyMessage
                });
              });
            }, function (err) {
              clipboardCopyAlt(caseDataString);
            });
          } else {
            clipboardCopyAlt(caseDataString);
          }
        };
        this._exportCaseData(tDataContext,
            "DG.Inspector.caseTable.exportCaseDialog.copyFrom",
            "DG.Inspector.caseTable.exportCaseDialog.copy",
            "DG.Inspector.caseTable.exportCaseDialog.copyTooltip",
            exportCollection);
      },
      importCaseDataFromClipboard: function() {
        var dataContext = this.get('dataContext');
        var contextName = dataContext && dataContext.get('name');

        window.focus();
        if (document.activeElement) {
          document.activeElement.blur();
        }

        window.navigator.clipboard.readText().then(
          function(data) {

            SC.run(function () {
              DG.appController.openCSVImporter({
                contentType: 'text/csv',
                text: data,
                targetDatasetName: contextName,
                name: 'clipboard',
                showCaseTable: false
              });
            });
          },
          function (err) {
            // maybe user didn't grant access to read from clipboard
            console.log('Error importing from clipboard: ', err);
          }
        );
      }
    };
  }()) // function closure
);

/* >>>>>>>>>> BEGIN source/components/case_card/case_card_controller.js */
// ==========================================================================
//                        DG.CaseCardController
//
//  Copyright (c) 2017 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/case_display_common/case_display_controller');

/** @class

    Coordinating controller for data card singleton.

 @extends DG.CaseDisplayController
 */
DG.CaseCardController = DG.CaseDisplayController.extend(
    /** @scope DG.CaseCardController.prototype */ {

      reactDiv: null,

      init: function() {
        arguments.callee.base.apply(this,arguments);
        this.get('specialTitleBarButtons').push(
            DG.CaseTableToggleButton.create()
        );
      },

      /**
       Destruction function.
       */
      destroy: function() {
        var dataContext = this.get('dataContext');
        if( dataContext && dataContext.removeObserver)
          dataContext.removeObserver('changeCount', this, 'handleDataContextChanges');
        arguments.callee.base.apply(this,arguments);
      },

      /**
       Configure the table for the new data context.
       */
      dataContextDidChange: function() {
        var dataContext = this.get('dataContext');

        if( dataContext !== this._prevDataContext) {
          if( this._prevDataContext)
            this._prevDataContext.removeObserver('changeCount', this, 'handleDataContextChanges');
          if( dataContext)
            dataContext.addObserver('changeCount', this, 'handleDataContextChanges');
          this._prevDataContext = dataContext;
          // In case the previous dataContext was destroyed, we are removed from the registry, so reregister
          DG.currDocumentController().tableCardRegistry.registerView(dataContext, this.get('view'));
        }
      }.observes('dataContext', 'view'),

      /**
       Observer function called when the data context notifies that it has changed.
       */
      handleDataContextChanges: function() {
        var changes = this.getPath('dataContext.newChanges');

        /**
         Process each change that has occurred since the last notification.
         */
        var handleOneChange = function( iChange) {
          var operation = iChange && iChange.operation;
          switch( operation) {
            case 'deleteDataContext':
              this.dataContextWasDeleted();
              break;
            default:
          }
        }.bind( this);

        // Process all changes that have occurred since the last notification.
        if( changes) {
          changes.forEach( function( iChange) {
            handleOneChange( iChange);
          });
        }
      },

      toggleViewVisibility: function() {
        var tCaseCardView = this.get('view'),
            tOperation = tCaseCardView.get('isVisible') ? 'delete' : 'add',
            tViewName = 'caseCardView';
        DG.UndoHistory.execute(DG.Command.create({
          name: 'component.toggle.delete',
          undoString: 'DG.Undo.toggleComponent.' + tOperation + '.' + tViewName,
          redoString: 'DG.Redo.toggleComponent.' + tOperation + '.' + tViewName,
          log: 'Toggle component: %@'.fmt('caseCard'),
          execute: function () {
            var layout = tCaseCardView.get('layout');
            tCaseCardView.set('savedLayout', layout);
            var isVisible = tCaseCardView.toggleProperty('isVisible');
            if( !isVisible && tCaseCardView.parentView && tCaseCardView.parentView.select)
              tCaseCardView.parentView.select(null);

          },
          undo: function () {
            this.execute();
          },
          redo: function () {
            this.execute();
          }
        }));
      },

      /**
       * @returns {[DG.IconButton]}
       */
      createInspectorButtons:  function () {
        var tButtons = arguments.callee.base.apply(this,arguments);

        tButtons.push(this.createInfoButton());
        tButtons.push(this.createTrashButton());
        tButtons.push(this.createHideShowButton());
        tButtons.push(this.createRulerButton());

        return tButtons;
      },

      showAttributesPopup: function() {
        var tItems = [];

        tItems.push(this.createRandomizeButton());
        tItems.push(this.createExportCaseButton());
        tItems.push(this.createCopyToClipboardButton());
        tItems.push(this.createGetFromClipboardButton());

        DG.MenuPane.create({
          classNames: 'dg-attributes-popup'.w(),
          layout: {width: 200, height: 150},
          items: tItems
        }).popup(this.get('inspectorButtons')[1]);
      },

      createComponentStorage: function() {
        var caseCardModel = this.getPath('model.content'),
            dataContext = caseCardModel.get('context'),
            isActive = caseCardModel.get('isActive'),
            columnWidthMap = caseCardModel.get('columnWidthMap'),
            storage = {
              isActive: isActive
            };
        if( dataContext) {
          this.addLink(storage, 'context', dataContext);
        }
        if (columnWidthMap) {
          var columnWidthMapArchive = {};
          DG.ObjectMap.forEach(columnWidthMap, function(key, value) {
            // round to four decimal places for saving
            columnWidthMapArchive[key] = DG.MathUtilities.roundToDecimalPlaces(value, 4);
          });
          storage.columnWidthMap = columnWidthMapArchive;
        }
        return storage;
      },

      restoreComponentStorage: function( iStorage, iDocumentID) {
        arguments.callee.base.apply(this,arguments);
        var caseCardModel = this.getPath('model.content');
        if (caseCardModel) {
          var contextID = this.getLinkID( iStorage, 'context'),
              dataContext = contextID
                  && DG.currDocumentController().getContextByID(contextID);
          if( dataContext) {
            caseCardModel.set('context', dataContext);
            this.set('dataContext', dataContext);
          }
          caseCardModel.set('isActive', iStorage.isActive);
          if (iStorage.columnWidthMap)
            caseCardModel.set('columnWidthMap', SC.clone(iStorage.columnWidthMap));
        }
      }

    });


/* >>>>>>>>>> BEGIN source/components/case_table/data_context_base_model.js */
// ==========================================================================
//  
//  Author:   kswenson
//
//  Copyright (c) 2020 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
/** @class  DG.DataContextBaseModel - The base model for a case table or case card component.

 @extends SC.Object
 */
DG.DataContextBaseModel = SC.Object.extend(/** @scope DG.DataContextBaseModel.prototype */ {
  /**
   @property { DG.DataContext }
   */
  context: null,

  id: null,
  idBinding: '*context.id',

  /**
   * Name of the component, always the data context name.
   * @property {string}
   */
  name: function (k, v) {
    if (!SC.none(v)) {
      this.context.applyChange({
        operation: 'updateDataContext',
        properties: {name: v}
      });
    }
    return this.getPath('context.name');
  }.property(),

  /**
   * Title of the component: always the data context title.
   * @property {string}
   */
  title: function(k, v) {
    if (!SC.none(v)) {
      this.context.applyChange({
        operation: 'updateDataContext',
        properties: {title: v}
      });
    }
    return this.getPath('context.title');
  }.property(),

  titleDidChange: function () {
    return this.notifyPropertyChange('title');
  }.observes('*context.title'),

  defaultTitle: function() {
    return this.getPath('context.defaultTitle');
  }.property(),

  defaultTitleDidChange: function () {
    return this.notifyPropertyChange('defaultTitle');
  }.observes('*context.defaultTitle')

});

/* >>>>>>>>>> BEGIN source/components/case_card/case_card_model.js */
// ==========================================================================
//                        DG.CaseCardModel
//
//  Copyright (c) 2017 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/case_table/data_context_base_model');

/** @class

    A for a case card.

 @extends DG.DataContextBaseModel
 */

DG.CaseCardModel = DG.DataContextBaseModel.extend({
    /**
     * Percentage width of attribute name column
     * 
     * @property {number}
     */
    columnWidthPct: null
});

/* >>>>>>>>>> BEGIN source/components/case_card/case_card_view.js */
// ==========================================================================
//                            DG.CaseCardView
//
//  Author:   William Finzer
//
//  Copyright (c) 2018 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/* global ReactDOM */
/** @class  DG.CaseCardView - The top level view for a case card

 @extends DG.View
 */
DG.CaseCardView = SC.View.extend(
    /** @scope DG.CaseCardView.prototype */
    (function () {

      return {

        isDropTarget: true, // So we'll participate in SC drag-drop

        /**
         The model on which this view is based.
         @property { DG.CaseCardModel }
         */
        model: null,

        /**
         * @property { DG.DataContext }
         */
        context: function() {
          return this.getPath('model.context');
        }.property('model'),

        contextDidChange: function() {
          this.renderCard();
        }.observes('model.context'),
        /**
         * @property {function}
         */
        isSelectedCallback: null,

        /**
         * @property {Element}
         */
        reactDiv: null,

        dragInProgress: false,

        classNames: 'react-data-card-view'.w(),

        classNameBindings: ['dragInProgress'],

        _mouseYInDrag: 0,

        _mouseHandlersInstalled: false,

        /*
        @property {SC.Timer}
         */
        _scrollTimer: null,

        didAppendToDocument: function () {
          this.reactDiv = document.createElement('div');
          this.get('layer').appendChild(this.reactDiv);
          this.renderCard();
        },

        destroy: function () {
          DG.React.toggleRender(this.reactDiv);

          arguments.callee.base.apply(this,arguments);
        },

        viewDidResize: function () {
          // failing to call arguments.callee.base.apply(this,arguments) here breaks attr drop-target highlighting
          arguments.callee.base.apply(this,arguments);
          // update layout, e.g. column resize handle
          this.reactDiv && this.renderCard();
        },

        columnWidthDidChange: function() {
          this.renderCard();
        }.observes('*model.columnWidthMap'),

        resizeColumn: function (iCollectionName, iColumnWidthPct) {
          var columnWidthMap = this.getPath('model.columnWidthMap') || {},
              orgColumnWidthPct = columnWidthMap[iCollectionName];

          if (iColumnWidthPct === columnWidthMap[iCollectionName]) return;

          var setColumnWidth = function(name, width) {
            var columnWidthMap = SC.clone(this.getPath('model.columnWidthMap') || {});
            if (width) {
              columnWidthMap[name] = width;
            }
            else {
              delete columnWidthMap[name];
            }
            this.setPath('model.columnWidthMap', columnWidthMap);
          }.bind(this);

          DG.UndoHistory.execute(DG.Command.create({
            name: 'caseCard.columnWidthChange',
            undoString: 'DG.Undo.caseCard.columnWidthChange',
            redoString: 'DG.Redo.caseCard.columnWidthChange',
            executeNotification: {
              action: 'notify',
              resource: 'component',
              values: {
                operation: 'change column width',
                type: 'DG.CaseCard'
              }
            },
            execute: function () {
              setColumnWidth(iCollectionName, iColumnWidthPct);
              this.log = "Change case card column width for collection '%@' to '%@'%"
                  .fmt(iCollectionName, DG.MathUtilities.roundToDecimalPlaces(100 * iColumnWidthPct, 2));
            },
            undo: function () {
              setColumnWidth(iCollectionName, orgColumnWidthPct);
            },
            redo: function() {
              setColumnWidth(iCollectionName, iColumnWidthPct);
            }
          }));
        },

        renderCard: function (iExtraProps) {
          var this_ = this;

          function installMouseHandlers() {
            if( this_._mouseHandlersInstalled)
              return;
            var tLayer = this_.get('layer'),
                tOKToDeselectOnClick = false;
            tLayer.addEventListener('mousedown', function(e) {
                tOKToDeselectOnClick = this_.isSelectedCallback();
            });
            tLayer.addEventListener('click', function(e) {
              if(tOKToDeselectOnClick && !DG.Core.gClickWillBeHandledInReactComponent) {
                SC.run(function() {
                  this_.get('context').applyChange({operation: 'selectCases', select: false});
                });
              }
              tOKToDeselectOnClick = false;
            });
            this_._mouseHandlersInstalled = true;
          }

          function isChangedWidth(oldWidth, newWidth) {
            var oldWidthRounded = oldWidth && DG.MathUtilities.roundToDecimalPlaces(oldWidth, 4),
                newWidthRounded = newWidth && DG.MathUtilities.roundToDecimalPlaces(newWidth, 4);
            return oldWidthRounded !== newWidthRounded;
          }
          var props = Object.assign({
                        context: this.get('context'),
                        columnWidthMap: this.getPath('model.columnWidthMap') || {},
                        isSelectedCallback: this.isSelectedCallback,
                        onResizeColumn: function(collection, widthPct, isComplete) {
                          SC.run(function() {
                            var columnWidthMap = this.getPath('model.columnWidthMap') || {},
                                columnWidth = columnWidthMap[collection];
                            if (this.get('isVisible') && !this.get('isAnimating') &&
                                (widthPct > 0) && (isComplete || isChangedWidth(columnWidth, widthPct))) {
                              this.resizeColumn(collection, widthPct, isComplete);
                            }
                          }.bind(this));
                        }.bind(this)
                      }, iExtraProps || {});
          ReactDOM.render( DG.React.CaseCard(props), this.reactDiv);

          installMouseHandlers();
        },

        touchStart: function (evt) {
          evt.allowDefault();
          return YES;
        },

        touchEnd: function (evt) {
          evt.allowDefault();
          return YES;
        },

        /**
         * Commit current edit
         * @param evt
         */
        mouseDown: function (evt) {
          DG.globalEditorLock.commitCurrentEdit();
        },

        mouseWheel: function (evt) {
          // don't propagate to document
          return YES;
        },

        /**
         *
         * @param iDrag
         * @return {string | false}
         */
        isValidAttribute: function (iDrag) {
          var tResult = false,
              tDragAttr = iDrag.data.attribute,
              tDragContext = iDrag.data.context;
          if( tDragAttr && tDragContext && tDragContext === this.get('context'))
            tResult = 'ownContext';
          else if( tDragContext && tDragAttr)
            tResult = 'foreignContext';
          return tResult;
        },

        canAcceptDrop: function (iDrag) {
          var canAcceptDrop = false,
              tContext = this.get('context'),
              ownedByGame = tContext.get('hasGameInteractive'),
              preventReorgFlag = tContext.get('preventReorg');
          if (!preventReorgFlag && !ownedByGame) {
            canAcceptDrop = true;
          }
          return canAcceptDrop;
        },

        computeDragOperations: function (iDrag) {
          var tResult;
          if (this.isValidAttribute(iDrag) && this.canAcceptDrop(iDrag))
            tResult = SC.DRAG_LINK;
          else
            tResult = SC.DRAG_NONE;
          return tResult;
        },

        dragEntered: function (iDragObject, iEvent) {
          this.renderCard({ dragStatus: { dragObject: iDragObject, event: iEvent,
              dragType: this.get('dragType')}});
        },

        dragUpdated: function (iDragObject, iEvent) {

          function scrollUp() {
            if( this_._mouseYInDrag < 5 && tLayer.scrollTop > 0) {
              tLayer.scrollTop -= 10;
            }
            else if(this_._scrollTimer && this_._scrollTimer.isValid){
              this_._scrollTimer.invalidate();
            }
          }

          function scrollDown() {
            if( this_._mouseYInDrag > tFrameHeight - 10) {
              tLayer.scrollTop += 10;
            }
            else if(this_._scrollTimer && this_._scrollTimer.isValid){
              this_._scrollTimer.invalidate();
            }
          }

          function setupScrollTimer( iAction) {
            if( !this_._scrollTimer || !this_._scrollTimer.isValid) {
              this_._scrollTimer = SC.Timer.schedule({
                target: this_,
                action: iAction,
                interval: 100,
                repeats: YES
              });
            }
          }

          var this_ = this,
              tViewPoint = DG.ViewUtilities.windowToViewCoordinates({x: iEvent.clientX, y: iEvent.clientY}, this),
              tLayer = this.get('layer'),
              tScrollTop = tLayer.scrollTop,
              tFrameHeight = this.get('frame').height;
          this._mouseYInDrag = tViewPoint.y;
          if( tViewPoint.y < 5 && tScrollTop > 0) {
            setupScrollTimer( scrollUp);
          }
          else if( tViewPoint.y > tFrameHeight - 10) {
            setupScrollTimer( scrollDown);
          }

          this.renderCard({ dragStatus: { dragObject: iDragObject, event: iEvent,
              dragType: this.get('dragType')}});
        },

        dragExited: function (iDragObject, iEvent) {
          this.renderCard({ dragStatus: null});
        },

        acceptDragOperation: function () {
          return YES;
        },

        dragStarted: function (iDrag) {
          var tValidityCheck = this.isValidAttribute(iDrag);
          if (tValidityCheck &&  this.canAcceptDrop(iDrag)) {
            this.set('dragInProgress', true);
            this.set('dragType', tValidityCheck);
          }
        },

        dragEnded: function () {
          if( this._scrollTimer && this._scrollTimer.isValid)
            this._scrollTimer.invalidate();
          this.set('dragInProgress', false);
          this.dragExited();
        },

        performDragOperation: function( iDragObject, iOp) {
          this.renderCard({ dragStatus: { dragObject: iDragObject, op: iOp,
              dragType: this.get('dragType') } });
        }

        // todo: handle data drags

      };
    }()));


/* >>>>>>>>>> BEGIN source/components/case_card/collection_header.js */
/* global ReactDOMFactories */
// sc_require('react/dg-react');

DG.React.ready(function () {
  var
      tr = ReactDOMFactories.tr,
      th = ReactDOMFactories.th,
      div = ReactDOMFactories.div;

  DG.React.Components.CollectionHeader = DG.React.createComponent(
      (function () {

        /**
         * Props are
         *    index {Number}
         *    collClient {DG.CollectionClient}
         *    caseID {Number}
         *    columnWidthPct {Number} - percentage width of attribute column
         *    onCollectionNameChange(newName: string) {function} - called when name is edited
         *    onHeaderWidthChange(width: number) {function} - called with pixel width of column
         *    dragStatus {Object}
         */

        return {

          domRow: null,

          getInitialState: function () {
            return {
              isEditingLabel: false
            };
          },

          render: function () {
            var this_ = this;

            function dragIsInMe() {
              var tResult;
              if (this_.props.dragStatus && this_.props.dragStatus.dragType === 'ownContext'
                  && this_.props.dragStatus.event && this_.domRow) {
                var tEvent = this_.props.dragStatus.event,
                    tX = tEvent.clientX,
                    tY = tEvent.clientY,
                    tRect = this_.domRow.getBoundingClientRect();
                tResult = tX >= tRect.left && tX < tRect.right &&
                          tY >= tRect.top && tY < tRect.bottom;
              }
              this_.dragIsInMe = tResult;
              return tResult;
            }

            function handleDropIfAny() {
              if (this_.dragIsInMe && this_.props.dragStatus &&
                  this_.props.dragStatus.op === SC.DRAG_LINK &&
                  this_.props.dropCallback) {
                var tAttr = this_.props.dragStatus.dragObject.data.attribute,
                    tCallback = this_.props.dropCallback;
                // Postpone the actual change so that we'll be outside this render
                setTimeout(function () {
                  // Use SC.run to make Sproutcore happy with invokeLaters that will be called
                  SC.run(function () {
                    tCallback(tAttr);
                  });
                }, 0);
              }
            }

            var renderStaticLabel = function(iCollectionClient, iCollectionName, iNumCases) {
              var numSelected = iCollectionClient
                      ? iCollectionClient.getPath('casesController.selection').toArray().length
                      : 0,
                  headerLabel = numSelected > 0
                      ? 'DG.CaseCard.namePlusSelectionCount'.loc(numSelected, iNumCases, iCollectionName)
                      : 'DG.CaseCard.namePlusCaseCount'.loc(iNumCases, iCollectionName);
              return (
                div({
                  className: 'collection-label',
                  onClick: function() {
                    this.setState({ isEditingLabel: true });
                  }.bind(this)
                }, headerLabel)
              );
            }.bind(this);

            var renderEditableLabel = function(iCollectionName) {
              return (
                DG.React.SimpleEdit({
                  className: 'collection-label',
                  value: iCollectionName,
                  onCompleteEdit: function(iNewName) {
                    if (iNewName && (iNewName !== iCollectionName) && this.props.onCollectionNameChange) {
                      this.props.onCollectionNameChange(iCollectionName, iNewName);
                    }
                    this.setState({ isEditingLabel: false });
                  }.bind(this)
                })
              );
            }.bind(this);

            handleDropIfAny();

            var tCollClient = this.props.collClient,
                tCaseID = this.props.caseID,
                tIndex = this.props.index,
                tRowClass = 'collection-header-row' + (dragIsInMe() ? ' drop' : ''),
                tCollection = tCollClient.get('collection'),
                tName = tCollection.get('name'),
                tNumCases = tCollection.get('cases').length,
                tCaseIndex = SC.none(tCaseID) ? null : tCollection.getCaseIndexByID(tCaseID) + 1,
                tNavButtons = DG.React.Components.NavButtons({
                  collectionClient: tCollClient,
                  caseIndex: tCaseIndex,
                  numCases: tNumCases,
                  onPrevious: this.props.onPrevious,
                  onNext: this.props.onNext,
                  onNewCase: this.props.onNewCase,
                  onDeselect: this.props.onDeselect
                });
            return (
              tr({
                  key: 'coll-' + tIndex,
                  className: tRowClass,
                  ref: function(elt) { this.domRow = elt; }.bind(this)
                },
                th({
                    colSpan: 2,
                    style: { paddingLeft: (tIndex * 10 + 5) + 'px' },
                    className: 'collection-header-cell',
                  },
                  div({ className: 'collection-header-contents' }, 
                      this.state.isEditingLabel
                        ? renderEditableLabel(tName)
                        : renderStaticLabel(tCollClient, tName, tNumCases),
                      div({ className: 'nav-header' }, tNavButtons)
                  )
                )
              )
            );
          }
        };
      }()), []);

});

/* >>>>>>>>>> BEGIN source/components/case_card/drag_case_card_item_handler.js */
// ==========================================================================
//                            DG.DragCaseCardItemHandler
//
//  Author:   William Finzer
//
//  Copyright ©2017 Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class  DG.DragCaseCardItemHandler - Similar to DG.DragLabelHandler but made to work with the React-based
 * CaseCard.

 @extends SC.Object
 */
DG.DragCaseCardItemHandler = SC.Object.extend(
    (function () {

          /** @scope DG.DragCaseCardItemHandler.prototype */
          return {
            /**
             * @property{SC.View}
             */
            viewToAddTo: null,

            /**
             * @property{SC.View}
             */
            dragView: null,

            /**
             * @property{DG.Attribute}
             */
            attribute: null,

            /**
             * @property {String}
             */
            attributeName: function () {
              return this.getPath('attribute.name');
            }.property(),

            /**
             * @property{DG.DataContext}
             */
            dataContext: null,

            receivedStartDrag: false,
            receivedDoDrag: false,

            /**
             * @param iX {number} x coordinate of pointer
             * @param iY {number} y coordinate of pointer
             * @param iEvent
             */
            handleStartDrag: function (iEvent) {
              var tDragView = SC.LabelView.create({
                classNames: 'dg-drag-label'.w(),
                layout: {width: 100, height: 20, top: -100, left: 0},
                value: this.get('attributeName')
              });
              this.set('dragView', tDragView);
              SC.run(function () {
                // Make sure dragView is in front. Won't actually happen without this runloop.
                if (tDragView.isDescendantOf(this.viewToAddTo))
                  this.viewToAddTo.removeChild(tDragView);
                this.viewToAddTo.appendChild(tDragView);
              }.bind(this));

              this.receivedStartDrag = true;
              this.receivedDoDrag = false;
            },

            /**
             * Handles a drag movement.
             * @param idX {number} delta x from initial position
             * @param idY delta y from initial position
             * @param iX {number}
             * @param iY {number}
             * @param iEvent {Event}
             */
            handleDoDrag: function (idX, idY, iX, iY, iEvent) {
              if (this.receivedStartDrag && !this.receivedDoDrag) {
                this.receivedDoDrag = true;
                var tDragView = this.get('dragView'),
                    tAttributeName = this.get('attributeName'),
                    tAttribute = this.get('attribute'),
                    tCollection = this.getPath('attribute.collection'),
                    tContext = this.get('dataContext');
                if (!tAttribute)
                  return;
                // Initiate a drag
                SC.run(function () {
                  DG.Drag.start({
                    event: iEvent,
                    source: this.viewToAddTo,
                    dragView: tDragView,
                    ghost: YES,
                    ghostActsLikeCursor: YES,
                    slideBack: YES,
                    origin: {x: iEvent.clientX, y: iEvent.clientY},
                    data: {
                      context: tContext,
                      collection: tCollection,
                      attribute: tAttribute,
                      text: tAttributeName
                    }  // For use by clients like the text box
                  });
                }.bind(this));
              }
            }
          };
        }
        ()
    ));


/* >>>>>>>>>> BEGIN source/components/case_card/dropdown/dropdown-content.js */
// ==========================================================================
//                              DG.React.Components.DropdownContent
//
//  Copyright (c) 2018 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/* global ReactDOMFactories */
// sc_require('react/dg-react');

DG.React.ready(function () {
  var
      div = ReactDOMFactories.div;

  DG.React.Components.DropdownContent = DG.React.createComponent(
      (function () {

        return {

          getInitialState: function () {
            return {
              location: {
                left: -1000,
                top: -1000
              }
            };
          },

          render: function () {

            var tChildren = this.props.children,
                tLocation = this.props.location || this.state.location;
            return DG.React.Components.RenderInBody({}, div({
              className: 'dropdown__content dg-wants-touch',
              style: {
                left: tLocation.left,
                top: tLocation.top
              },
            }, tChildren));
          }
        };
      }()), []);

});

/* >>>>>>>>>> BEGIN source/components/case_card/dropdown/dropdown-item.js */
// ==========================================================================
//                              DG.React.Components.DropdownItem
//
//  Copyright (c) 2018 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/* global ReactDOMFactories */
// sc_require('react/dg-react');

DG.React.ready(function () {
  var
      div = ReactDOMFactories.div;

  /**
   * props
   *  disabled: Boolean
   *  clickHandler: function
   *
   */

  DG.React.Components.DropdownItem = DG.React.createComponent(
      (function () {

        return {
          classNameDefault: 'react-data-card-attribute-menu-item',

          render: function () {

            var tClassName = this.classNameDefault + (this.props.disabled ? ' disabled' : ''),
                tClickHandler = this.props.disabled ? null : this.props.clickHandler;

            return div({
              className: tClassName,
              onMouseDown: tClickHandler,
              onTouchStart: tClickHandler
            }, this.props.children);
          }
        };
      }()), []);

});

/* >>>>>>>>>> BEGIN source/components/case_card/dropdown/dropdown-trigger.js */
// ==========================================================================
//                              DG.React.Components.DropdownTrigger
//
//  Copyright (c) 2018 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/* global ReactDOMFactories */
// sc_require('react/dg-react');

DG.React.ready(function () {
  var
      a = ReactDOMFactories.a;

  DG.React.Components.DropdownTrigger = DG.React.createComponent(
      (function () {

        return {

          render: function () {
            var tChildren = this.props.children,
                tClassName = this.props.className || '',
                tDropdownTriggerProps = Object.assign({}, this.props);
            delete tDropdownTriggerProps.children;
            tDropdownTriggerProps.className = 'dropdown__trigger ' + tClassName;
            return a( tDropdownTriggerProps, tChildren);
          }
        };
      }()), []);

});

/* >>>>>>>>>> BEGIN source/components/case_card/dropdown/dropdown.js */
// ==========================================================================
//                              DG.React.Components.Dropdown
//
//  Copyright (c) 2018 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/* global ReactDOMFactories */

DG.React.ready(function () {
  var
      div = ReactDOMFactories.div;

  DG.React.Components.Dropdown = DG.React.createComponent(
      (function () {

        return {

          getInitialState: function () {
            return {
              active: false
            };
          },

          componentDidMount: function () {
            window.addEventListener("touchstart", this._onWindowClick, true);
            window.addEventListener("mousedown", this._onWindowClick, true);
          },

          componentWillUnmount: function () {
            window.removeEventListener("touchstart", this._onWindowClick, true);
            window.removeEventListener("mousedown", this._onWindowClick, true);
          },

          hide: function () {
            this.setState({
              active: false,
              location: null
            });
          },

          show: function ( iLocation) {
            this.setState({
              active: true,
              location: iLocation
            });
          },

          _onWindowClick: function( event) {
            if (this.state.active &&
                !event.target.classList.contains("react-data-card-attribute-menu-item") &&
                !event.target.classList.contains("dropdown__content")) {
              this.hide();
            }
          },

          _onToggleClick: function( event) {
            event.preventDefault();
            if (this.state.active) {
              this.hide();
            } else {
              this.show({ left: event.clientX, top: event.clientY + 12 });
            }
          },

          render: function () {
            var tClassName = this.props.className || '',
                tDisabled = this.props.disabled,
                tActive = this.state.active,
                tClasses = 'dropdown' + (tActive ? ' dropdown--active' : '') + (tDisabled ? ' dropdown--disabled' : ''),
                tTrigger = DG.React.Components.DropdownTrigger({},
                    div({
                      onClick: function( iEvent) {
                        if( !tDisabled) {
                          this._onToggleClick( iEvent);
                        }
                      }.bind( this)
                    }, this.props.trigger)),
                tMenuItems = tActive ?
                    DG.React.Components.DropdownContent({
                  location: this.state.location
                }, this.props.menuItems) : null,
                tCleanProps = Object.assign({
                  ref: function( iElement) {
                    this.props.onRefCallback( iElement);
                  }.bind( this)
                }, this.props);
            delete tCleanProps.onRefCallback;
            delete tCleanProps.trigger;
            delete tCleanProps.menuItems;
            tCleanProps.className = tClasses + ' ' + tClassName;
            return div( tCleanProps, tTrigger, tMenuItems);
          }
        };
      }()), []);

});

/* >>>>>>>>>> BEGIN source/components/case_card/dropdown/render-in-body.js */
// ==========================================================================
//                              DG.React.Components.RenderInBody
//
//  Copyright (c) 2018 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/* global ReactDOM, ReactDOMFactories */
// sc_require('react/dg-react');

DG.React.ready(function () {
  var
      div = ReactDOMFactories.div;
  DG.React.Components.RenderInBody = DG.React.createComponent(
      (function () {
        return {

          componentDidMount: function () {
            this.popup = document.createElement("div");
            document.body.appendChild(this.popup);
            this._renderLayer();
          },


          componentDidUpdate: function () {
            this._renderLayer();
          },


          componentWillUnmount: function () {
            ReactDOM.unmountComponentAtNode(this.popup);
            document.body.removeChild(this.popup);
          },


          _renderLayer: function () {
            ReactDOM.render( this.props.children, this.popup);
          },


          render: function () {
            return div({});
          }
        };
      }()), []);

});
/* >>>>>>>>>> BEGIN source/components/case_card/nav_buttons.js */
/* global ReactDOMFactories */
// sc_require('react/dg-react');

DG.React.ready(function () {
  var
      // img = ReactDOMFactories.img,
      br = ReactDOMFactories.br,
      button = ReactDOMFactories.button,
      span = ReactDOMFactories.span;

  DG.React.Components.NavButtons = DG.React.createComponent(
      (function () {

        return {

          getPrevious: function () {
            this.props.onPrevious(this.props.collectionClient, this.props.caseIndex);
          },

          deselect: function () {
            this.props.onDeselect();
          },

          getNext: function () {
            this.props.onNext(this.props.collectionClient, this.props.caseIndex);
          },

          getNewCase: function () {
            this.props.onNewCase(this.props.collectionClient);
          },

          render: function () {
            var tCaseIndex = this.props.caseIndex,
                tNumCases = this.props.numCases,
                tNumSelected = this.props.collectionClient
                    ? this.props.collectionClient.getPath('casesController.selection').toArray().length
                    : 0,
                tFirstTitle,
                tFirstButton,
                tDeselectTitle,
                tDeselectButton,
                tSecondTitle,
                tSecondButton,
                tAddCaseButton;
            if (!(tNumCases === 0 || (!SC.none(tCaseIndex) && tCaseIndex <= 1))) {
              tFirstTitle = !SC.none( tCaseIndex) ? 'DG.CaseCard.navPrevCase' : 'DG.CaseCard.navLastCase';
              tFirstButton = span({
                className: 'moonicon-icon-reverse-play',
                style: {paddingRight: '4px'},
                onClick: this.getPrevious,
                title: tFirstTitle.loc()
              });
            }
            tDeselectTitle = tNumSelected === 0 ? 'DG.CaseCard.noDeselect' : 'DG.CaseCard.deselect';
            tDeselectButton = button({
              className: 'dg-card-deselect',
              disabled: tNumSelected === 0,
              onClick: this.deselect,
              title: tDeselectTitle.loc()
            });
            if(!(this.props.numCases === 0 || (!SC.none(tCaseIndex) && tCaseIndex >= this.props.numCases))) {
              tSecondTitle = !SC.none( tCaseIndex) ? 'DG.CaseCard.navNextCase' : 'DG.CaseCard.navFirstCase';
              tSecondButton = span({
                className: 'moonicon-icon-play',
                onClick: this.getNext,
                title: tSecondTitle.loc()
              });
            }
            else {
              tSecondButton = span({
                className: 'moonicon-icon-play',
                style: { 'color': 'transparent', 'cursor': 'default'}
              });
            }
            var tAddCaseLabelWords = "DG.CaseCard.addCaseButton".loc(),
                tSpaceIndex = tAddCaseLabelWords.indexOf(' '),
                tFirstWord = tSpaceIndex >= 0 ? tAddCaseLabelWords.substring(0, tSpaceIndex) : tAddCaseLabelWords,
                tRemainder = tSpaceIndex >= 0 ? tAddCaseLabelWords.substring(tSpaceIndex) : '',
                tLabel = span({},tFirstWord,br(),tRemainder);
            tAddCaseButton =
                button({
                  className: 'dg-floating-button-right',
                  title: 'DG.CaseCard.newCaseToolTip'.loc(),
                  onClick: this.getNewCase
                }, tLabel);

            return span({className: 'nav-buttons dg-wants-touch'},
                tFirstButton, tDeselectButton, tSecondButton, tAddCaseButton);
          }
        };
      }()), []);

});

/* >>>>>>>>>> BEGIN source/react/custom_hooks.js */
sc_require('react/dg-react');
/* global React */

(function() {

  /**
   * cf. https://reactjs.org/docs/hooks-faq.html#how-to-get-the-previous-props-or-state
   * cf. https://usehooks.com/usePrevious/
   * @param {*} value 
   */
  var usePrevious = function(value) { 
    var ref = React.useRef();
    React.useEffect(function() {
      ref.current = value;
    }, [value]);
    return ref.current;
  };
  DG.React.usePrevious = usePrevious;

  /**
   * Combines useState and useRef hooks to provide a state value that can be referenced
   * from function callbacks that would otherwise close around a stale state value.
   * cf. https://blog.castiel.me/posts/2019-02-19-react-hooks-get-current-state-back-to-the-future/
   * @param {*} initialValue 
   */
  var useRefState = function(initialValue) {
    var stateArray = React.useState(initialValue),
        state = stateArray[0],
        setState = stateArray[1],
        stateRef = React.useRef(state);
    React.useEffect(function() {
      stateRef.current = state;
    }, [state]);
    return [state, stateRef, setState];
  };
  DG.React.useRefState = useRefState;

  /**
   * Calls the specified callback function on a touch/click outside the element.
   * @param {ReactReference} elementRef 
   * @param {function} callback(elt) where elt is the DOM element
   */
  var useCallbackOnOutsideEvent = function(elementRef, callback) {
    React.useEffect(function() {
      function onWindowClick(evt) {
        var elt = elementRef.current;
        if (elt && (evt.target !== elt) && !elt.contains(evt.target)) {
          callback(elt);
        }
      }

      // didMount
      window.addEventListener("touchstart", onWindowClick, true);
      window.addEventListener("mousedown", onWindowClick, true);

      // willUnmount
      return function() {
        window.removeEventListener("touchstart", onWindowClick, true);
        window.removeEventListener("mousedown", onWindowClick, true);
      };
    // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
  };
  DG.React.useCallbackOnOutsideEvent = useCallbackOnOutsideEvent;

  /**
   * Focuses and selects the content of the specified element on mounting the component.
   * @param {ReactReference} elementRef - the element (e.g. <input>) to focus
   */
  var useFocusSelectOnMount = function(elementRef) {
    // focus/select the contents initially
    React.useEffect(function() {
      // didMount
      setTimeout(function() {
        var elt = elementRef.current;
        elt && elt.focus();
        elt && elt.select();
      });
    // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
  };
  DG.React.useFocusSelectOnMount = useFocusSelectOnMount;

  /**
   * Initiates a drag by installing the relevant mouse/touch handlers.
   * @param {string} touchId
   * @param {function(MouseEvent/Touch)} onUpdateDrag
   * @param {function(MouseEvent/Touch)} onEndDrag
   */
  var useDragOnDemand = function(touchId, onUpdateDrag, onEndDrag) {

    React.useEffect(function() {
      function handleMouseMove(e) {
        onUpdateDrag(e);
        stop(e);
      }

      function handleMouseUp(e) {
        onEndDrag();
        stop(e);
      }

      function handleTouch(e) {
        for (var i = 0; i < e.touches.length; ++i) {
          if (e.touches[i].identifier === touchId) {
            // touch is still active
            onUpdateDrag(e.touches[i]);
            return;
          }
        }
        // touch is no longer active
        onEndDrag();
      }

      if (touchId) {
        // An individual 'touchstart' or 'touchmove' may be for some other touch, so we
        // don't care about the type of event, only whether the resize touch is still active.
        document.addEventListener('touchstart', handleTouch, true);
        document.addEventListener('touchmove', handleTouch, true);
        document.addEventListener('touchcancel', handleTouch, true);
        document.addEventListener('touchend', handleTouch, true);
      }
      else {
        document.addEventListener('mousemove', handleMouseMove, true);
        document.addEventListener('mouseup', handleMouseUp, true);
      }

      return function() {
        if (touchId) {
          document.removeEventListener('touchstart', handleTouch, true);
          document.removeEventListener('touchmove', handleTouch, true);
          document.removeEventListener('touchcancel', handleTouch, true);
          document.removeEventListener('touchend', handleTouch, true);
        }
        else {
          document.removeEventListener('mousemove', handleMouseMove, true);
          document.removeEventListener('mouseup', handleMouseUp, true);
        }
      };
    // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [touchId]);

  };
  DG.React.useDragOnDemand = useDragOnDemand;

})();

/* >>>>>>>>>> BEGIN source/components/case_card/simple-edit.js */
sc_require('react/dg-react');
sc_require('react/custom_hooks');
/* global createReactFC, PropTypes, React, ReactDOMFactories */

DG.React.ready(function () {
  var useCallbackOnOutsideEvent = DG.React.useCallbackOnOutsideEvent,
      useFocusSelectOnMount = DG.React.useFocusSelectOnMount,
      input = ReactDOMFactories.input;

  /**
   * This uncontrolled component (https://reactjs.org/docs/uncontrolled-components.html)
   * wraps a regular <input> element to provide a simple reusable editing component.
   */
  var config = {
    displayName: "SimpleEdit",
    propTypes: {
      // className attribute applied to the input element
      className: PropTypes.string,
      // initial value of edit
      value: PropTypes.string,
      // onCompleteEdit(value?: string)
      // Called with final value at completion of edit;
      //  `undefined` => canceled/completed with no change.
      onCompleteEdit: PropTypes.func.isRequired
    }
  };
  function SimpleEdit(props) {
    // reference to <input> DOM element
    var inputRef = React.useRef();

    // complete the edit on outside touches/clicks
    useCallbackOnOutsideEvent(inputRef, function(elt) { elt.blur(); });

    // focus/select the contents initially
    useFocusSelectOnMount(inputRef);

    function cancelEdit() {
      props.onCompleteEdit();
    }

    function completeEdit(value) {
      props.onCompleteEdit(value !== props.value ? value : undefined);
    }

    return input({
      className: props.className + ' dg-wants-mouse dg-wants-touch',
      type: 'text',
      ref: inputRef,
      defaultValue: props.value || "",
      onKeyDown: function (evt) {
        var handled = true;
        switch (evt.keyCode) {
          case 27:
            cancelEdit();
            break;
          case 13:
            completeEdit(evt.target.value);
            break;
          default:
            handled = false;
            break;
        }
        if (handled) {
          evt.preventDefault();
          evt.stopPropagation();
        }
      },
      onBlur: function(evt) {
        completeEdit(evt.target.value);
      }
    });
  }
  // two-stage definition required for React-specific eslint rules
  DG.React.SimpleEdit = createReactFC(config, SimpleEdit);
});

/* >>>>>>>>>> BEGIN source/components/case_display_common/case_display_utils.js */
// ==========================================================================
//  
//  Author:   kswenson
//
//  Copyright (c) 2020 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
//
DG.CaseDisplayUtils = {

  /**
   *
   * @param iAttribute {DG.Attribute} attribute for tooltip
   */
  getTooltipForAttribute: function (iAttribute) {
    var name = iAttribute.get('name'),
        unit = iAttribute.get('unit'),
        description = iAttribute.get('description'),
        formula = iAttribute.get('formula');
    if (!description && !formula)
      return unit ? 'DG.CaseCard.attrHintUnitsOnly'.loc(name, unit)
                  : 'DG.CaseCard.attrHintPlain'.loc(name);
    if (!formula)
      return 'DG.CaseCard.attrHintDescription'.loc(name, description);
    if (!description)
      return 'DG.CaseCard.attrHintFormula'.loc(name, formula);
    return 'DG.CaseCard.attrHintDescriptionAndFormula'.loc(name, description, formula);
  },

  setCollectionNameWithCommand: function (iDataContext, iOldName, iNewName) {

    function setCollectionName(currName, newName) {
      var tCollectionClient = iDataContext.getCollectionByName(currName);
      if (tCollectionClient) {
        iDataContext.applyChange({
          operation: 'updateCollection',
          collection: tCollectionClient,
          properties: { name: newName }
        });
      }
    }

    DG.UndoHistory.execute(DG.Command.create({
      name: 'caseTable.collectionNameChange',
      undoString: 'DG.Undo.caseTable.collectionNameChange',
      redoString: 'DG.Redo.caseTable.collectionNameChange',
      execute: function () {
        setCollectionName(iOldName, iNewName);
        this.log = "Change collection name from '%@' to '%@'".fmt(iOldName, iNewName);
      },
      undo: function () {
        setCollectionName(iNewName, iOldName);
      },
      redo: function() {
        setCollectionName(iOldName, iNewName);
      }
    }));
  }

};

/* >>>>>>>>>> BEGIN source/views/inspector/picker_title_view.js */
// ==========================================================================
//                              DG.PickerTitleView
// 
//  DG.PickerTitleView lays out a small icon and text at the top of a PickerPane
//  that pops up from the inspector view.
//  
//  Authors:  William Finzer
//
//  Copyright (c) 2015 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

    A PickerTitleView displays a small icon on the left next to a LabelView.

 @extends SC.View
 */
DG.PickerTitleView = SC.View.extend(
    /** @scope DG.PickerTitleView.prototype */ {

      /**
       URL of the icon to display
       @property {String}
       */
      iconURL: null,

      /**
       The text to display
       @property {SC.String}
       */
      title: null,

      layout: {height: 26, right: 0},

      childViews: 'iconView titleView'.w(),

      iconView: SC.ImageView.extend(
          {
            classNames: 'dg-inspector-picker-icon'.w(),
            layout: {width: 18, height: 18}
          }
      ),

      titleView: SC.LabelView.extend({
        classNames: 'dg-inspector-picker-title'.w(),
        layout: {left: 27},
        localize: true
      }),

      init: function () {
        arguments.callee.base.apply(this,arguments);
        this.setPath('iconView.value', this.get('iconURL'));
        this.setPath('titleView.value', this.get('title'));
      }
    });


/* >>>>>>>>>> BEGIN source/views/inspector/picker_control_view.js */
// ==========================================================================
//                              DG.PickerControlView
// 
//  SC.PickerControlView lays out a label on the left, and a control on the right.
//  It's commonly used in Inspector Picker panes.
//  
//  Authors:  William Finzer
//
//  Copyright (c) 2015 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

    A PickerControlView displays a LabelView on the left and control view on the right.

 @extends SC.View
 */
DG.PickerControlView = SC.View.extend(
    /** @scope DG.PickerControlView.prototype */ {

      /**
       Label displayed on the left
       @property {String}
       */
      label: null,

      toolTip: null,

      toolTipDidChange: function() {
        this.setPath('labelView.toolTip', this.get('toolTip'));
      }.observes('toolTip'),

      childViews: 'labelView controlView'.w(),

      labelView: SC.LabelView.extend({
        classNames: 'dg-inspector-picker-tag'.w(),
        localize: true
      }),

      /**
       @property {SC.View}
       */
      controlView: null,

      init: function () {
        arguments.callee.base.apply(this,arguments);
        var tControlView = this.get('controlView');
        if (tControlView) {
          tControlView.adjust('right', 10);
        }
        this.setPath('labelView.value', this.get('label'));
        this.setPath('labelView.toolTip', this.get('toolTip'));
      }
    });


/* >>>>>>>>>> BEGIN source/components/case_display_common/dataset_metadata_view.js */
// ==========================================================================
//  
//  Author:   jsandoe
//
//  Copyright (c) 2016 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
sc_require('views/inspector/picker_title_view');
sc_require('views/inspector/picker_control_view');
/** @class

   Provides an editor view for examining and modifying dataset metadata.
   Dataset metadata includes a free form description, the file or url from which the data
   was drawn, time of creation, ...

 @extends SC.View
 */
DG.DatasetMetadataView = SC.PalettePane.extend( (function() // closure
    /** @scope DG.DatasetMetadataView.prototype */ {
  var kLeading = 5;

  var kPaneWidth = 290;
  var kControlWidth = 200;
  var kButtonWidth = 90;
  var kCancelSaveWidth = kPaneWidth;

  var kPaneHeight = 310;
  var kTitleHeight = 26;
  var kRowHeight = 20;
  var kControlHeight = kRowHeight - 2;
  var kButtonHeight = kControlHeight + 6;
  var kCancelSaveHeight = kControlHeight + 10;

  var kDescriptionLines = 8;

  return {
      dataContext: null,
      buttonIconClass: 'moonicon-icon-styles',  // So we can identify closure through click on button icon
      classNames: 'dg-inspector-picker'.w(),
      layout: {width: kPaneWidth, height: kPaneHeight, centerX: 0, centerY: 0},
      isModal: true,
      contentView: SC.View.extend(SC.FlowedLayout, {
        layoutDirection: SC.LAYOUT_VERTICAL,
        isResizable: false,
        isClosable: false,
        defaultFlowSpacing: {left: 0, right: 0, bottom: kLeading},
        canWrap: false,
        align: SC.ALIGN_TOP,
        childViews: [
          'title',
          'nameCtl',
          'urlCtl',
          'creationDateCtl',
          'descriptionCtl',
          'applyOrCancelCtl'
        ],

        title: DG.PickerTitleView.extend({
          layout: {height: kTitleHeight, width: kPaneWidth},
          flowSpacing: {left: 0, right: 0, bottom: kLeading},
          title: 'DG.TableController.datasetMetadata.title',
          localize: true,
        }),

        nameCtl: DG.PickerControlView.design({
          layout: {height: kRowHeight},
          label: 'DG.CaseTable.attributeEditor.name',
          localize: true,
          toolTip: 'DG.TableController.attrEditor.nameHint',
          controlView: SC.TextFieldView.extend({
            layout: {
              centerY: 0,
              width: kControlWidth,
              height: kControlHeight
            },
            backgroundColor: 'white'
          })
        }),

        urlCtl: DG.PickerControlView.design({
          layout: {height: kRowHeight},
          label: 'DG.CaseTable.datasetMetadata.url',
          localize: true,
          toolTip: 'DG.TableController.datasetMetadata.urlHint',
          controlView: SC.TextFieldView.extend({
            layout: {
              centerY: 0,
              width: kControlWidth,
              height: kControlHeight
            },
            backgroundColor: 'white'
          })
        }),

        creationDateCtl: DG.PickerControlView.design({
          layout: {height: kRowHeight},
          label: 'DG.CaseTable.datasetMetadata.creationDate',
          localize: true,
          toolTip: 'DG.TableController.datasetMetadata.creationDateHint',
          controlView: SC.TextFieldView.extend({
            layout: {
              centerY: 0,
              width: kControlWidth,
              height: kControlHeight
            },
            backgroundColor: 'white'
          })
        }),

        descriptionCtl: DG.PickerControlView.design({
          layout: {height: kRowHeight * kDescriptionLines},
          label: 'DG.CaseTable.attributeEditor.description',
          localize: true,
          controlView: SC.TextFieldView.extend({
            layout: {
              centerY: 0,
              width: kControlWidth,
              height: kControlHeight * kDescriptionLines
            },
            isTextArea: true,
            backgroundColor: 'white',
            hint: 'DG.TableController.datasetMetadata.descriptionHint',
            localize: true
          })
        }),

        applyOrCancelCtl: SC.View.design(SC.FlowedLayout, {
          layoutDirection: SC.LAYOUT_VERTICAL,
          defaultFlowSpacing: 5,
          align: SC.ALIGN_CENTER,
          layout: {
            width: kCancelSaveWidth,
            height: kCancelSaveHeight,
          },
          childViews: 'cancel apply'.w(),
          cancel: SC.ButtonView.design({
            layout: {  width: kButtonWidth, height: kButtonHeight },
            titleMinWidth: 0,
            title: 'DG.AttrFormView.cancelBtnTitle',  // "Cancel"
            target: null,
            action: 'close',
            toolTip: 'DG.AttrFormView.cancelBtnTooltip',  // "Dismiss the dialog without making any changes"
            localize: true,
            isCancel: true
          }),
          apply: SC.ButtonView.design({
            layout: { width: kButtonWidth, height: kButtonHeight },
            titleMinWidth: 0,
            title: 'DG.AttrFormView.applyBtnTitle', // "Apply"
            target: null,
            action: 'update',
            toolTip: '',
            localize: true,
            isDefault: true
          })
        })
      }),

      dataContextDidChange: function () {
        var dataContext = this.get('dataContext');
        var metadata = dataContext.getPath('model.metadata') || {};
        var importDate = metadata.importDate;
        if (DG.DateUtilities.isDate(importDate) || DG.DateUtilities.isDateString(importDate)) {
          importDate = DG.DateUtilities.formatDate(importDate, DG.Attribute.DATE_PRECISION_MINUTE);
        }
        var contentView = this.get('contentView');
        if (dataContext) {
          contentView.setPath('nameCtl.controlView.value', dataContext.get('title'));
          contentView.setPath('urlCtl.controlView.value', metadata.source);
          contentView.setPath('creationDateCtl.controlView.value', importDate);
          contentView.setPath('descriptionCtl.controlView.value', metadata.description);
        }
      }.observes('dataContext'),

      update: function () {
        var dataContext = this.get('dataContext');
        var metadata = dataContext.getPath('model.metadata') || {};
        var contentView = this.get('contentView');
        dataContext.set('title', contentView.getPath('nameCtl.controlView.value'));
        metadata.source = contentView.getPath('urlCtl.controlView.value');
        metadata.importDate = contentView.getPath('creationDateCtl.controlView.value');
        metadata.description = contentView.getPath('descriptionCtl.controlView.value');
        dataContext.setPath('model.metadata', metadata);

        DG.log('setting metadata: ' + JSON.stringify(metadata));
        this.close();
      },
      close: function () {
        DG.log('Closing Attribute Editor');
        this.remove();
        this.destroy();
      },
      init: function () {
        arguments.callee.base.apply(this,arguments);
        if (this.get('dataContext')) {
          this.dataContextDidChange();
        }
      }
    };
  }())
);

/* >>>>>>>>>> BEGIN source/components/case_display_common/table_card_registry.js */
// ==========================================================================
//  
//  Author:   jsandoe
//
//  Copyright (c) 2019 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
//
// Keeps track of case tables and case cards in the current document.
DG.TableCardRegistry = SC.Object.extend({

  contextCardMap: null,

  contextTableMap: null,

  init: function () {
    this.contextCardMap = {};
    this.contextTableMap = {};
  },

  reset: function () {
    this.contextCardMap = {};
    this.contextTableMap = {};
  },

  /**
   *
   * @param dataContext {DG.DataContext || string} dataContext or id of one.
   * @param view {DG.CaseCardView | DG.CaseTableView}
   */
  registerView: function (dataContext, view) {
    var contextID = (typeof dataContext === 'object')? dataContext.get('id'): dataContext;
    if (contextID != null && view) {
      var tContentView = view.get('contentView');
      if (view && tContentView instanceof DG.HierTableView) {
        this.contextTableMap[contextID] = view;
      } else if (view && tContentView instanceof DG.CaseCardView) {
        this.contextCardMap[contextID] = view;
      } else {
        DG.log("TableCardRegistry: unrecognized view");
      }
    } else {
      DG.log('TableCardRegistry: Context: no id');
    }
  },

  deregisterViews: function (dataContext) {
    var contextID = (typeof dataContext === 'object')? dataContext.get('id'): dataContext;
    delete this.contextCardMap[contextID];
    delete this.contextTableMap[contextID];
  },

  /**
   *
   * @param dataContext {DG.DataContext || string} dataContext or id of one.
   */
  getViewForContext: function (dataContext) {
    var contextID = (typeof dataContext === 'object')? dataContext.get('id'): dataContext;
    var cardView = this.contextCardMap[contextID];
    var tableView = this.contextTableMap[contextID];
    var view = (cardView && cardView.getPath('model.content.isActive'))? cardView:
        (tableView && tableView.getPath('model.content.isActive'))? tableView: null;
    return view;
  },

  getTableView: function (dataContext) {
    var contextID = (typeof dataContext === 'object')? dataContext.get('id'): dataContext;
    return this.contextTableMap[contextID];
  },

  getCardView: function (dataContext) {
    var contextID = (typeof dataContext === 'object')? dataContext.get('id'): dataContext;
    return this.contextCardMap[contextID];
  },

  getActiveViewTypeForContext: function (dataContext) {
    var view = this.getViewForContext(dataContext);
    if (view) {
      return view.getPath('model.type');
    }
  }

});
/* >>>>>>>>>> BEGIN source/components/case_table/attribute_editor_view.js */
// ==========================================================================
//  
//  Author:   jsandoe
//
//  Copyright (c) 2016 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
sc_require('models/attribute_model');
sc_require('views/inspector/picker_title_view');
sc_require('views/inspector/picker_control_view');
/** @class

   Provides an editor view for examining and modifying case attribute properties.

 @extends SC.View
 */
DG.AttributeEditorView = SC.PalettePane.extend( (function() // closure
    /** @scope DG.AttributeEditorView.prototype */ {
    var kRowHeight = 20;
    var kControlHeight = kRowHeight - 2;
    var kTitleHeight = 26;
    var kControlWidth = 140;
    var kMargin = 10;
    var kLeading = 5;

    return {
      attrRef: null,
      attrUpdater: null,
      buttonIconClass: 'moonicon-icon-styles',  // So we can identify closure through click on button icon
      classNames: 'dg-inspector-picker'.w(),
      layout: {width: 250, height: 280, centerX: 0, centerY: 0},
      isModal: true,
      contentView: SC.View.extend(SC.FlowedLayout, {
        layoutDirection: SC.LAYOUT_VERTICAL,
        isResizable: false,
        isClosable: false,
        defaultFlowSpacing: {left: kMargin, right: kMargin, bottom: kLeading},
        canWrap: false,
        align: SC.ALIGN_TOP,
        layout: {right: 5},
        childViews: [
          'title',
          'nameCtl',
          'descriptionCtl',
          'typeCtl',
          'unitCtl',
          'precisionCtl',
          'editableCtl',
          'applyOrCancelCtl'
        ],

        title: DG.PickerTitleView.extend({
          layout: {height: kTitleHeight},
          flowSpacing: {left: 0, right: 0, bottom: kLeading},
          title: 'DG.TableController.attributeEditor.title',
          localize: true,
        }),

        nameCtl: DG.PickerControlView.design({
          layout: {height: kRowHeight},
          label: 'DG.CaseTable.attributeEditor.name',
          localize: true,
          toolTip: 'DG.TableController.attrEditor.nameHint',
          controlView: SC.TextFieldView.extend({
            layout: {
              centerY: 0,
              width: kControlWidth,
              height: kControlHeight
            },
            backgroundColor: 'white'
          })
        }),

        descriptionCtl: DG.PickerControlView.design({
          layout: {height: kRowHeight*4},
          label: 'DG.CaseTable.attributeEditor.description',
          localize: true,
          controlView: SC.TextFieldView.extend({
            layout: {
              centerY: 0,
              width: kControlWidth,
              height: kControlHeight*4
            },
            isTextArea: true,
            backgroundColor: 'white',
            hint: 'DG.TableController.attrEditor.descriptionHint',
            localize: true
          })
        }),

        typeCtl: DG.PickerControlView.design({
          layout: {height: kRowHeight * 1.5},
          label: 'DG.CaseTable.attributeEditor.type',
          localize: true,
          toolTip: 'DG.TableController.attrEditor.typeHint',
          controlView: SC.SelectView.extend({
            layout: {
              width: kControlWidth,
              height: 24
            },
            itemTitleKey: 'title',
            itemValueKey: 'value',
            items: DG.Attribute.attributeTypes.map(function (type) {
              return {
                value: type,
                title: 'DG.CaseTable.attribute.type.' + type
              };
            }),
            value: null
          })
        }),

        unitCtl: DG.PickerControlView.design({
          layout: {height: kRowHeight},
          label: 'DG.CaseTable.attributeEditor.unit',
          localize: true,
          toolTip: 'DG.TableController.attrEditor.unitHint',
          controlView: SC.TextFieldView.extend({
            layout: {
              width: kControlWidth,
              height: kControlHeight
            },
            backgroundColor: 'white',
            localize: true
          })
        }),

        precisionCtl: DG.PickerControlView.design({
          layout: {height: kRowHeight * 1.5},
          label: 'DG.CaseTable.attributeEditor.precision',
          localize: true,
          controlView: SC.SelectView.extend({
            layout: {
              width: kControlWidth,
              height: 24
            },
            itemTitleKey: 'title',
            itemValueKey: 'value'
          })
        }),

        editableCtl: DG.PickerControlView.design({
          layout: {height: kRowHeight},
          label: 'DG.CaseTable.attributeEditor.editable',
          localize: true,
          toolTip: 'DG.TableController.attrEditor.editableHint',
          controlView: SC.RadioView.extend({
            layout: {width: kControlWidth},
            items: [
              { title: 'True', value: true, enabled: true},
              { title: 'False', value: false, enabled: true}
            ],
            value: [true],
            itemTitleKey: 'title',
            itemValueKey: 'value',
            itemIsEnabledKey: 'enabled',
            layoutDirection: SC.LAYOUT_HORIZONTAL,
            localize: true
          })
        }),

        applyOrCancelCtl: SC.View.design(SC.FlowedLayout, {
          layoutDirection: SC.LAYOUT_VERTICAL,
          defaultFlowSpacing: 5,
          align: SC.ALIGN_CENTER,
          layout: {
            width: kControlWidth,
            height: 24,
          },
          childViews: 'cancel apply'.w(),
          cancel: SC.ButtonView.design({
            layout: {  width: 90 },
            titleMinWidth: 0,
            title: 'DG.AttrFormView.cancelBtnTitle',  // "Cancel"
            target: null,
            action: 'close',
            toolTip: 'DG.AttrFormView.cancelBtnTooltip',  // "Dismiss the dialog without making any changes"
            localize: true,
            isCancel: true
          }),
          apply: SC.ButtonView.design({
            layout: { width: 90 },
            titleMinWidth: 0,
            title: 'DG.AttrFormView.applyBtnTitle', // "Apply"
            target: null,
            action: 'update',
            toolTip: '',
            localize: true,
            isDefault: true
          })
        })
      }),

      typeDidChange: function() {
        this.updatePrecisionMenu( this.getPath('contentView.typeCtl.controlView.value'),
            this.getPath('attrRef.attribute.precision'));
      }.observes('contentView.typeCtl.controlView.value'),

      updatePrecisionMenu: function( iType, iPrecisionValue) {
        var tNumericPrecisions = [' ','0','1','2','3','4','5','6','7','8'],
            tDatePrecisions = DG.Attribute.datePrecisionOptions;

        function isValueOfGivenType() {
          var result = false;
          if( iType === 'date')
            result = tDatePrecisions.indexOf( iPrecisionValue) >= 0;
          else
            result = tNumericPrecisions.indexOf( String(iPrecisionValue)) >= 0;
          return result;
        }

        var control = this.getPath('contentView.precisionCtl.controlView'),
            precisionList;
        control.set('isEnabled', true);
        if( isValueOfGivenType())
          control.set('value', String(iPrecisionValue));
        else control.set('value', '');
        this.setPath('contentView.precisionCtl.toolTip', 'DG.TableController.attrEditor.precisionNumericHint'.loc());
        switch (iType) {
          case 'numeric':
          case 'none':
            precisionList = tNumericPrecisions.map(function (iInteger) {
              return {
                value: iInteger.trim(),
                title: iInteger
              };
            });
            break;
          case 'date':
            precisionList = "DG.CaseTable.attributeEditor.datePrecisionOptions".loc().w();
            precisionList.unshift(" ");
            precisionList = precisionList.map(function (iOption, iIndex) {
              var tValue = DG.Attribute.datePrecisionOptions[iIndex];
              return {
                value: tValue,
                title: iOption
              };
            });
            this.setPath('contentView.precisionCtl.toolTip', 'DG.TableController.attrEditor.precisionDateHint'.loc());
            break;
          default:
            control.set('isEnabled', false);
        }
        control.set('items', precisionList);
      },

      attrRefDidChange: function () {
        var attrRef = this.get('attrRef');
        var attr = attrRef.attribute;
        var contentView = this.get('contentView');
        if (attrRef) {
          DG.ObjectMap.forEach(attr.toArchive(), function(key, val) {
            var ctlName = key + 'Ctl';
            // Don't allow non-renameable attributes to be renamed
            if (key === 'name') {
              var isEditable = attr.get('renameable');
              contentView.setPath('nameCtl.controlView.enabledState',
                                  isEditable ? SC.CoreView.ENABLED : SC.CoreView.DISABLED);
            }
            // Convert attribute type nominal to categorical
            if (key === 'type' && val === DG.Attribute.TYPE_NOMINAL) {
              val = DG.Attribute.TYPE_CATEGORICAL;
            }
            if (!SC.none(contentView.get(ctlName)) && !SC.none(val)) {
              contentView.setPath(ctlName + '.controlView.value', val);
            }
          }.bind(this));
          this.updatePrecisionMenu(this.getPath('contentView.typeCtl.controlView.value'),
              this.getPath('attrRef.attribute.precision'));
        }
      }.observes('attrRef'),

      update: function () {
        var attr = {
          name: this.getPath('contentView.nameCtl.controlView.value'),
          description: this.getPath('contentView.descriptionCtl.controlView.value'),
          type: this.getPath('contentView.typeCtl.controlView.value'),
          unit: this.getPath('contentView.unitCtl.controlView.value'),
          precision: this.getPath('contentView.precisionCtl.controlView.value'),
          editable: this.getPath('contentView.editableCtl.controlView.value')
        };
        DG.log('setting attribute: ' + JSON.stringify(attr));
        this.attrUpdater.updateAttribute(this.get('attrRef'), attr);
        this.close();
      },
      close: function () {
        DG.log('Closing Attribute Editor');
        this.remove();
        this.destroy();
      },
      init: function () {
        arguments.callee.base.apply(this,arguments);
        this.setPath( 'contentView.applyOrCancelCtl.cancel.target', this );
        this.setPath( 'contentView.applyOrCancelCtl.cancel.action', 'close' );
        this.setPath( 'contentView.applyOrCancelCtl.apply.target', this );
        this.setPath( 'contentView.applyOrCancelCtl.apply.action', 'update' );
        if (this.get('attrRef')) {
          this.attrRefDidChange();
        }
      }
    };
  }())
);

/* >>>>>>>>>> BEGIN source/components/case_table/case_table_adapter.js */
// ==========================================================================
//                        DG.CaseTableAdapter
//
//  Adapts the DG data to the form required for the SlickGrid table.
//  Builds the necessary SlickGrid data structures from the DG data.
//
//  Author:   Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

  Adapter for displaying DG data for a single collection in a SlickGrid.

  @extends SC.Object
 */
/* global tinycolor */
var kMultilineRowHeightThreshold = 24;

DG.CaseTableAdapter = SC.Object.extend( (function() // closure
/** @scope DG.CaseTableAdapter.prototype */ {

      // Cell layout constants
  var kIndexColumnID = '__INDEX__',
      kDefaultColumnWidth = 60,
      kDefaultQualWidth = 60,
      kIndexColumnWidth = 35,
      kMinIndexColumnWidth = 35,
      kMinDataColumnWidth = 45,
      kDefaultRowHeight = 18,
      kDefaultColorWidth = 20,
      kMaxStringLength = 256,

      getColumnHeaderString = function( iAttribute) {
        var tName = iAttribute.get('name' ),
            tUnit = iAttribute.get('unit');
        return tName + (!SC.empty( tUnit) ? ' (' + tUnit + ')' : '');
      },

      indexFormatter = function  (rowIndex, colIndex, cellValue, colInfo, rowItem) {
        return rowItem && rowItem._isProtoCase
                ? '<img src="' + '../../../../static/dg/de/cert/resources/images/drag-indicator.svg' +
                      '" title="' + "DG.CaseTable.indexProto.tooltip".loc() + '"/>'
                : '<span class="dg-index">' + cellValue + '</span>';
      },

      /**
       * Formats table cells.
       *
       * Implements slickgrid cellFormatter api.
       *
       * @param rowIndex {number}
       * @param colIndex {number}
       * @param cellValue {DG.Case}
       * @param colInfo {Object} Slickgrid colInfo object.
       * @param rowItem
       * @return {DOMElement|string} formatted cell contents
       */
      cellFormatter = function (rowIndex, colIndex, cellValue, colInfo, rowItem) {
        function isBoolean(v) {
          if (typeof v === 'string') { v = v.toLowerCase(); }
          return ['','false','true',false, true, null].includes(v) || v === undefined;
        }
        var result;
        try {
          var attr = colInfo.attribute;
          var type = attr && attr.get('type');
          var precision = attr && attr.get('precision');
          if( cellValue && cellValue.jsonBoundaryObject)
            type = DG.Attribute.TYPE_BOUNDARY;

          if (cellValue instanceof Error) {
            result = errorFormatter(cellValue);
          } else if (type === DG.Attribute.TYPE_QUALITATIVE) {
            result = qualBarFormatter(cellValue);
          } else if (cellValue instanceof DG.SimpleMap) {
            result = stringFormatter(cellValue.toString(), this, colInfo);
          } else if (type === DG.Attribute.TYPE_BOUNDARY) {
            result = boundaryFormatter(cellValue);
          } else if (type === DG.Attribute.TYPE_CHECKBOX
              && isBoolean(cellValue)
              && (rowItem instanceof DG.Case)) {
            result = checkboxFormatter(cellValue, this, colInfo);
          } else if (SC.none(cellValue)) {
            result = "";
          } else if (typeof cellValue === 'boolean') {
            result = String(cellValue);
          } else if (DG.isDate(cellValue) || type === DG.Attribute.TYPE_DATE) {
            result = dateFormatter(cellValue, precision, type);
          } else if (DG.isNumeric(cellValue) || type === DG.Attribute.TYPE_NUMERIC) {
            result = numberFormatter(cellValue, type, precision);
          } else if (DG.isColorSpecString(cellValue)) {
            result = colorFormatter(rowIndex, colIndex, cellValue, colInfo,
                rowItem);
          } else if (typeof cellValue === 'string') {
            result = stringFormatter(cellValue, this, colInfo);
          } else {
            DG.log('caseTableAdapter.cellFormatter: unhandled value type ' +
                'for %@: %@'.loc(colInfo.name, cellValue.toString()));
            result = '';
          }

        } catch (ex) {
          DG.logWarn('Error in cell formatter: ' + ex + '/row,col,value/' + [rowIndex,colIndex,cellValue].join() + '/');
          result = 'error';
        }
        return result;
      },

      dateFormatter = function (cellValue, precision, type) {
        var date = DG.isDate(cellValue)? cellValue: DG.parseDate(cellValue, type === DG.Attribute.TYPE_DATE);
        return  date?('<span class="dg-date">'+ DG.formatDate(date, precision) + '</span>'): '"' + cellValue + '"';
      },

      numberFormatter = function (cellValue, type, precision) {
        var value = DG.isNumeric(cellValue)
                ? DG.getNumeric(cellValue)
                : DG.MathUtilities.extractNumeric(cellValue),
            roundDigits = !SC.empty(precision)? precision : 2,
            formattedValue;

        if (value != null && value !== '') {
          // if numeric and doesn't look like its a year format with grouped separators
          if (type === DG.Attribute.TYPE_NUMERIC && DG.MathUtilities.notAYear(value)) {
            formattedValue = Intl.NumberFormat(DG.get('currentLanguage'),
                {maximumFractionDigits: roundDigits}).format(value);
          } else {
            var multiplier = !SC.empty(roundDigits) ? Math.pow(10,roundDigits) : 1;
            formattedValue = Math.round( multiplier * value) / multiplier;
          }
          return '<span class="dg-numeric">' + formattedValue + '</span>';
        } else {
          return stringFormatter(cellValue);
        }
      },

      /**
       * Formats an error
       * @param error {Error}
       * @return {*}
       */
      errorFormatter = function (error) {
        return stringFormatter(error.toString());
      },

      computeTruncateSize = function (rowHeight, colInfo) {
        var rows = Math.floor((rowHeight - 4) / (kDefaultRowHeight - 4));
        // assume 8 bytes per character
        var cols = Math.floor((colInfo? colInfo.width: kDefaultColumnWidth) / 5);
        return Math.max(rows * cols, kMaxStringLength);
      },

      /**
       * Formats a string for display
       * @param cellValue {string}
       * @param [caseTableAdapter] {DG.CaseTableAdapter}
       * @param [colInfo] {Object} Slickgrid column info object
       * @return {string}
       */
      stringFormatter = function (cellValue, caseTableAdapter, colInfo) {
        // if we have a long string, truncate string to a value that is larger
        // than displayable in the cell.
        if (!(cellValue.length && cellValue.length < kMaxStringLength) && caseTableAdapter) {
          cellValue = cellValue.substring(0, computeTruncateSize(caseTableAdapter.get('rowHeight'), colInfo));
        }
        // standard values are HTML-escaped
        return cellValue.replace(/&/g, '&amp;')
            .replace(/</g, '&lt;')
            .replace(/>/g, '&gt;');
      },

      qualBarFormatter = function (value) {
        if (value === null || value === undefined || value === "") {
          return "";
        }

        var color = DG.PlotUtilities.kDefaultPointColor;
        return "<span class='dg-qualitative-backing'>" +
        "<span class='dg-qualitative-bar' style='background:" + color + ";width:" + value + "%'></span></span>";
      },

      boundaryFormatter = function ( value) {
        var tResult = '',
            tBoundaryObject = DG.GeojsonUtils.boundaryObjectFromBoundaryValue(value),
            tThumb = tBoundaryObject && tBoundaryObject.jsonBoundaryObject &&
                tBoundaryObject.jsonBoundaryObject.properties &&
                tBoundaryObject.jsonBoundaryObject.properties.THUMB;
        // we found a thumbnail
        if (tThumb !== null && tThumb !== undefined) {
          tResult = "<span class='dg-boundary-thumb'>" +
              "<img src=\'" + tThumb + "\' alt='thumb' height='14'></span>";
        }
        // we found a Boundary object, but it's an error
        else if( tBoundaryObject && (tBoundaryObject.jsonBoundaryObject instanceof  Error)) {
          tResult = errorFormatter(tBoundaryObject.jsonBoundaryObject);
        }
        // We found a boundary but not a thumbnail
        else if (tBoundaryObject) {
          tResult = "A Boundary";
        }
        // not an object
        else if( !SC.empty(value)) {
          tResult = value;
        }
        return tResult;
      },

      colorFormatter = function (row, cell, value, columnDef, dataContext) {
        var tColor = tinycolor( value.toLowerCase().replace(/\s/gi,''));
        return "<span class='dg-color-table-cell' style= 'background:" + tColor.toString(
            'rgb') + "'></span>";
      },

      checkboxFormatter = function (cellValue, caseTableAdapter, colInfo) {

        cellValue = (typeof cellValue === 'string')? cellValue.toLowerCase(): cellValue;
        var attr = colInfo.attribute;
        var readOnly = (attr && (attr.formula || !attr.editable));
        var valueString = (cellValue && cellValue !== 'false')? ' checked': '';
        var disabledString = readOnly ? ' disabled': '';

        return '<span class="dg-checkbox-cell dg-wants-mouse dg-wants-touch"><input type="checkbox" title="' +
            cellValue + '"' + valueString + disabledString + '/></span>';
      },

      /**
       * Called when attribute has type "checkbox". For the given cellNode determine whether the attribute's
       * value is neither true nor false. If so, set the node's indeterminate property to true.
       * @param cellNode
       * @param row
       * @param dataContext
       * @param colDef
       */
      formatIndeterminate = function(cellNode, row, iCase, colDef) {
        var tInput = cellNode && cellNode.querySelector('input');
        var value = iCase.getValue(colDef.attribute.get('id')) ,
                // iCase.item && String(iCase.item.values[Number(colDef.attribute.get('id'))]),
            isIndeterminate = ![true, 'true', false, 'false'].includes(value) ;
        if( isIndeterminate && tInput)
          tInput.indeterminate = true;
      },

      tooltipFormatter = function(row, cell, cellValue, formattedValue, columnDef, dataContext) {
        // don't show tooltips for DG-formatted HTML values
        var tooltipValue = /<span.*class=["']dg-.*["'].*<\/span>/.test(formattedValue) ? "" : formattedValue;
        // HTML-escape tooltips for other values
        return tooltipValue && formattedValue.replace
                ? formattedValue.replace(/&/g, '&amp;')
                                .replace(/</g, '&lt;')
                                .replace(/>/g, '&gt;')
                                .replace(/"/g, '&quot;')
                : "";
      };

  return {  // return from closure

    minRowHeight: kDefaultRowHeight,

    /**
      The data context for the collections viewed in the table.
      @property   {DG.DataContext}
     */
    dataContext: null,

    /**
      The collection containing the cases viewed in the table.
      @property   {DG.CollectionClient}
     */
    collection: null,

    /**
     * A helper property to manage the collection name.
     * @type {String}
     */
    collectionName: function (key, value) {
      if (value !== undefined) {
        this.dataContext.applyChange({
          operation: 'updateCollection',
          collection: this.collection,
          properties: {name: value}
        });
      }
      return this.getPath('collection.name');
    }.property().cacheable(),

    collectionNameDidChange: function () {
      this.notifyPropertyChange('collectionName');
    }.observes('*collection.name'),

    /**
     * The Case Table Model
     * @type {DG.CaseTableModel}
     */
    model: null,

    /**
     * The row height for the table
     * @property {number}
     */
    rowHeight: function(key, value) {
      var model = this.get('model'),
          collectionId = this.getPath('collection.id');
      if (model && collectionId) {
        if (value != null) {
          model.setTableRowHeight(collectionId, value);
        }
        return model.getTableRowHeight(collectionId) || kDefaultRowHeight;
      }
    }.property(),

    /**
     * True if the row height supports multiline text formatting, false otherwise
     * @property {boolean}
     */
    isMultilineRowHeight: function() {
      return this.get('rowHeight') >= kMultilineRowHeightThreshold;
    }.property(),

    /**
      Returns true if there are formulas with aggregate functions in this adapter's collection.
      @property   {Boolean}
     */
    hasAggregates: function() {
      return this.getPath('collection.hasAggregates');
    }.property(),

    /**
      Should group header rows be shown for all groups (true) or only for collapsed groups (false)?
      @property   {Boolean}
     */
    showExpandedGroupRows: false,

    /**
      The SlickGrid DataView responsible for accessing/filtering the cases.
      @property   {Slick.Data.DataView}
     */
    gridDataView: null,

    /**
      Array of row/case info objects.
      @property   {[Object]}
     */
    gridData: null,

    /**
      Array of column info objects.
      @property   {[Object]}
     */
    gridColumns: null,

    /**
      Additional SlickGrid options.
      @property   {Object}
     */
    gridOptions: null,

    /**
      Initialization method.
     */
    init: function() {
      arguments.callee.base.apply(this,arguments);

      this.gridDataView = DG.CaseTableDataManager.create({
        context: this.dataContext,
        collection: this.collection,
        adapter: this,
        model: this.model
      });

      if( this.get('dataContext'))
        this.dataContextDidChange();
    },

    destroy: function() {
      if (this.gridDataView) {
        this.gridDataView.destroy();
        this.gridDataView = null;
      }
      arguments.callee.base.apply(this,arguments);
    },

    /**
      Returns true if this adapter's collection has a parent collection,
      false if it is the most senior collection, i.e. has no parent.
      @returns  {Boolean}   True if this collection has a parent collection
     */
    hasParentCollection: function() {
      var context = this.get('dataContext'),
          collectionID = this.getPath('collection.id'),
          firstCollection = context && context.getCollectionAtIndex( 0),
          firstCollectionID = firstCollection && firstCollection.get('id');
      return collectionID !== firstCollectionID;
    }.property(),

    isCollectionReorgAllowed: function () {
      var dataContext = this.get('dataContext'),
          isTopLevel = !this.get('hasParentCollection');
        return !isTopLevel || !DG.DataContextUtilities.isTopLevelReorgPrevented(dataContext);
    }.property(),

    /**
     * Refresh the table when the dataContext metadata changes, e.g. when the context gets
     * a new managingController, which can determine whether to show the input row.
     */
    dataContextMetadataDidChange: function () {
      this.refresh();
    }.observes('*dataContext.metadataChangeCount'),

    /**
      The number of visible rows in the table, that is the number of rows adjusted
      for the effect of collapsed rows. This is _not_ the number of rows that can be
      seen in the current viewport.
      @property {Number}
     */
    visibleRowCount: function() {
      return this.gridDataView.getLength();
    }.property(),

    /**
      Map row ID to row index, where row ID is generally the same as case ID.
      The return row index is the index of visible rows, rather than total rows.
      Collapsed rows return an invalid index.
      @param    {String}    iRowID - The ID of the specified row/case
      @returns  {Number}    The index of the row with the specified ID
     */
    getIndexForID: function( iRowID) {
      var dataView = this.get('gridDataView');
      return dataView && dataView.getRowById( iRowID);
    },

    /**
     * Returns the user selected column width for this attribute or the default,
     * if not defined.
     *
     * @param attributeID {number}
     */
    getPreferredColumnWidth: function (attributeID) {
      var this_ = this;

      function isNewContext() {
        return this_.getPath('collection.collection.attrs').length === 1 &&
            this_.getPath('collection.collection.cases').length === 0;
      }

      var model = this.model;
      var prefWidth = model && model.getPreferredAttributeWidth(attributeID);
      var columnWidth = prefWidth || kDefaultColumnWidth;
      // Special case for a new context's table we want a double-wide column
      if( !prefWidth && isNewContext()) {
        columnWidth *= 2;
        model.setPreferredAttributeWidth( attributeID, columnWidth);
      }
      return columnWidth;
    },

    /**
     *
     * @param iIndex {number}
     * @return {DG.Attribute}
     */
    getAttributeFromColumnIndex: function (iIndex) {
      return this.gridColumns[iIndex].attribute;
    },

    getColumnIndexFromAttribute: function (attr) {
      return this.gridColumns.findIndex(function (columnInfo) {
        return columnInfo.attribute && (attr.id === columnInfo.attribute.id);
      });
    },

    getColumnFromAttribute: function (attr) {
      return this.gridColumns.find(function (columnInfo) {
        return columnInfo.attribute && (attr.id === columnInfo.attribute.id);
      });
    },

    getColumnWidthStats: function (attr) {
      var columnInfo = this.getColumnFromAttribute(attr);

      var cellStyle = {
        display: 'block',
        'font-family': 'Montserrat-Regular, sans-serif',
        'font-size': '10.6667px',
        'font-style':'normal',
        'font-weight': 'normal',
        'text-align': 'left',
        padding: '1px 4px 2px'
      };
      var headerStyle = {
        display: 'block',
        'font-family': 'Montserrat-Regular, sans-serif',
        'font-size': '10.6667px',
        'font-style':'normal',
        'font-weight': 'normal',
        'text-align': 'left'
      };
      var minWidth = Number.MAX_VALUE;
      var maxWidth = 0;
      var sum = 0;
      var ct = 0;

    var dimensions = DG.measureText(getColumnHeaderString(attr), headerStyle);
    var headerWidth = dimensions && dimensions.width;

      this.collection.casesController.slice(0,500).forEach( function (myCase) {
        var attrValue = myCase.getValue(attr.id);
        var valueString;
      var dimensions;
        var width;
        if (DG.isColorSpecString(attrValue)) {
          width = kDefaultColorWidth;
        } else if (attr.type === DG.Attribute.TYPE_QUALITATIVE){
          width = kDefaultQualWidth;
        } else {
          valueString = cellFormatter(0, 0, attrValue, columnInfo, myCase);
        dimensions = DG.measureText(valueString, cellStyle);
        width = dimensions && dimensions.width + 1;
        }
        maxWidth = Math.max(maxWidth, width);
        minWidth = Math.min(minWidth, width);
        ct ++;
        sum += width;
      });

      return {
        headerWidth: headerWidth,
        minWidth: minWidth,
        maxWidth: maxWidth,
        meanWidth: sum/ct,
        count: ct
      };
    },

    autoResizeColumn: function (attr) {
      var stats = this.getColumnWidthStats(attr);
      var width = Math.max(Math.ceil(3 +stats.headerWidth/2), Math.min(stats.maxWidth, 200)) + 11;
      // DG.log('Resizing stats: ' + JSON.stringify(stats));
      // DG.log('Resizing column %@ from %@ to %@'.loc(attr.name, this.model.getPreferredAttributeWidth(attr.id), width));
      this.model.setPreferredAttributeWidth(attr.id, width);
    },

    autoResizeAllColumns: function () {
      this.collection.forEachAttribute(function (attr) {
        if( !attr.get('hidden'))
          this.autoResizeColumn(attr);
      }.bind(this));
    },

    getProtoCase: function() {
      var dataView = this.get('gridDataView');
      var collection = this.get('collection');
      return dataView && collection ? dataView.getProtoCase(collection) : undefined;
    },

    isCellEditable: function(row, column) {
      var dataView = this.get('gridDataView'),
          dataContext = this.get('dataContext'),
          aCase = dataView.getItem(row),
          colInfo = this.gridColumns[column],
          attr = colInfo && colInfo.attribute,
          attrIsEditable = attr && attr.get('editable') && !attr.get('hasFormula'),
          caseIsEditable = DG.DataContextUtilities.isCaseEditable(dataContext, aCase);
      return attrIsEditable && caseIsEditable;
    },

    isCellRowSelectable: function(row, column) {
      var tDataView = this.get('gridDataView'),
          tCase = tDataView.getItem(row);
      return tCase && !tCase._isProtoCase;
    },

    /**
      Builds the array of column definitions required by SlickGrid from the data context.

      @returns  {[Object]} The properties of each object define the column
     */
    updateColumnInfo: function() {
      var context = this.get('dataContext'),
          collection = this.get('collection'),
          existColumnDefs = {},
          columnDefs = [];
      if( !collection) return columnDefs;

      if( this.gridColumns) {
        // Build a map of the existing column definitions so we can reuse them.
        // This preserves any user settings like column widths, etc.
        this.gridColumns.forEach( function( iColumn) {
                                    existColumnDefs[iColumn.id] = iColumn;
                                  });
      }

      function updateDynamicColumnProperties( iAttribute, ioColumnInfo) {
        // cell-specific editability handled by isCellEditable() method
        ioColumnInfo.editor = DG.CaseTableCellEditor;
      }

      function addIndexColumn() {
        var indexColumnName = 'DG.CaseTable.indexColumnName'.loc(),
            columnInfo = {
              context: context,
              id: kIndexColumnID,
              name: indexColumnName,
              field: indexColumnName,
              toolTip: 'DG.CaseTable.indexColumnTooltip'.loc(),
              focusable: false,
              cssClass: 'dg-index-column',
              formatter: indexFormatter,
              width: kIndexColumnWidth,
              minWidth: kMinIndexColumnWidth
            };
        columnDefs.push(columnInfo);
      }

      // Build the columnInfo for a single attribute
      function processAttribute( iAttribute) {
        var attrID = iAttribute.get('id').toString(),
            collection = iAttribute.get('collection'),
            attrName = iAttribute.get('name'),
            hasFormula = iAttribute.hasFormula(),
            hasDeletedFormula = iAttribute.hasDeletedFormula(),
            isCheckbox = iAttribute.get('type') === 'checkbox',
            columnInfo = {
              context: context,
              collection: collection,
              collectionID: collection.get('id').toString(),
              attribute: iAttribute,
              // Slick.Grid properties
              id: attrID,
              name: getColumnHeaderString( iAttribute),
              field: attrName,
              focusable: !hasFormula,
              cssClass: hasFormula? 'dg-formula-column': undefined,
              toolTip: DG.CaseDisplayUtils.getTooltipForAttribute( iAttribute),
              formatter: cellFormatter.bind(this),
              asyncPostRender: isCheckbox ? formatIndeterminate : null,
              tooltipFormatter: tooltipFormatter,
              width: this.getPreferredColumnWidth(iAttribute.get('id')),
              minWidth: kMinDataColumnWidth,
              hasDependentInteractive: function () {
                return this.context.get('hasGameInteractive');
              },
              header: {
                menu : {
                  items: [
                    {
                      title: 'DG.TableController.headerMenuItems.renameAttribute'.loc(),
                      command: 'cmdEditName',
                      updater: function( iColumn, iMenu, ioMenuItem) {
                        ioMenuItem.disabled = false;
                      }
                    },
                    {
                      title: 'DG.TableController.headerMenuItems.resizeColumn'.loc(),
                      command: 'cmdResizeAttribute',
                      updater: function( iColumn, iMenu, ioMenuItem) {
                        ioMenuItem.disabled = false;
                      }
                    },
                    {
                      title: 'DG.TableController.headerMenuItems.editAttribute'.loc(),
                      command: 'cmdEditAttribute',
                      updater: function( iColumn, iMenu, ioMenuItem) {
                        ioMenuItem.disabled = false;
                      }
                    },
                    {
                      title: 'DG.TableController.headerMenuItems.editFormula'.loc(),
                      command: 'cmdEditFormula',
                      updater: function( iColumn, iMenu, ioMenuItem) {
                        ioMenuItem.disabled = !iColumn.attribute.get('editable');
                      }
                    },
                    {
                      title: hasDeletedFormula ? 'DG.TableController.headerMenuItems.recoverFormula'.loc() : 'DG.TableController.headerMenuItems.deleteFormula'.loc(),
                      command: hasDeletedFormula ? 'cmdRecoverDeletedFormula' : 'cmdDeleteFormulaKeepValues',
                      updater: function ( iColumn, iMenu, ioMenuItem) {
                        ioMenuItem.disabled = !iColumn.attribute.get('editable') || (!hasFormula && !hasDeletedFormula);
                      }
                    },
                    {
                      title: 'DG.TableController.headerMenuItems.randomizeAttribute'.loc(),
                      command: 'cmdRandomizeAttribute',
                      updater: function( iColumn, iMenu, ioMenuItem) {
                        ioMenuItem.disabled = !DG.DataContextUtilities.attributeCanBeRandomized(context, attrID);
                      }
                    },
                    {
                      title: 'DG.TableController.headerMenuItems.sortAscending'.loc(),
                      command: 'cmdSortAscending',
                      updater: function( iColumn, iMenu, ioMenuItem) {
                        ioMenuItem.disabled = false;
                      }
                    },
                    {
                      title: 'DG.TableController.headerMenuItems.sortDescending'.loc(),
                      command: 'cmdSortDescending',
                      updater: function( iColumn, iMenu, ioMenuItem) {
                        ioMenuItem.disabled = false;
                      }
                    },
                    {
                      title: 'DG.TableController.headerMenuItems.hideAttribute'.loc(),
                      command: 'cmdHideAttribute',
                      updater: function( iColumn, iMenu, ioMenuItem) {
                        // we disable the menu item if the column corresponds to the last
                        // attribute in its collection
                        ioMenuItem.disabled = iColumn.collection.numberOfVisibleAttributes() === 1;
                      }
                    },
                    {
                      title: 'DG.TableController.headerMenuItems.deleteAttribute'.loc(),
                      command: 'cmdDeleteAttribute',
                      updater: function( iColumn, iMenu, ioMenuItem) {
                        // we disable the menu item if not deleteable or the
                        // context is owned by a data interactive that speaks the Game API
                        ioMenuItem.disabled = !iColumn.attribute.get('deleteable') ||
                                                iColumn.hasDependentInteractive() ||
                                                !DG.DataContextUtilities.isAttributeDeletable(context, iAttribute);
                      }
                    }
                  ]
                }
              }
            };
        updateDynamicColumnProperties( iAttribute, columnInfo);
        if(! iAttribute.get('hidden')) {
          columnDefs.push( columnInfo);
        }
      }

      if (this.model && !this.model.get('isIndexHidden')) {
        addIndexColumn();
      }

      // Process the attributes in the collection
      collection.forEachAttribute( processAttribute.bind(this));

      this.gridColumns = columnDefs;

      return columnDefs;
    },

    /**
      Returns the column info for the specified attribute.
      @param    {string}    iAttrName -- The name of the attribute whose column should be returned
      @returns  {object}    The column info for the specified attribute
     */
    getAttributeColumn: function(iAttrName) {
      var dataContext = this.get('dataContext'),
          attr = dataContext && dataContext.getAttributeByName(iAttrName),
          columnIndex = this.gridColumns.findIndex(
                                          function(iColumn) {
                                            return attr && (attr.get('id').toString() === iColumn.id);
                                          }),
          columnInfo = columnIndex >= 0 ? this.gridColumns[columnIndex] : null;
      return columnInfo ? { columnIndex: columnIndex, columnInfo: columnInfo } : null;
    },

    /**
      Updates the column information for the specified attribute.
      @param    {DG.Attribute}    iAttribute -- The attribute whose column should be updated
      @returns  {Boolean}         True if the attribute exists and was updated, false otherwise
                                  Clients can call this method for multiple adapters and use
                                  the return value to determine which table was affected.
     */
    updateColumnForAttribute: function( iAttribute) {
      var column = DG.ArrayUtils.firstMatch( this.gridColumns,
                                            function( iColumn) {
                                              return iAttribute.get('id').toString() === iColumn.id;
                                            });
      if( column) {
        column.name = getColumnHeaderString( iAttribute);
        column.field = iAttribute.get('name');
        column.toolTip = DG.CaseDisplayUtils.getTooltipForAttribute( iAttribute);
        column.formatter = cellFormatter;
        column.cssClass = iAttribute.get('hasFormula')? 'dg-formula-column': undefined;
        if( iAttribute.get('editable') && !iAttribute.get('hasFormula'))
          column.editor = DG.CaseTableCellEditor;
        else
          delete column.editor;

        this.gridDataView.refresh();
        return true;
      }
      return false;
    },

    /**
      Returns the grid option in a form suitable for passing to the SlickGrid.
      The most important options (currently) are the default rowHeight and the
      dataItemColumnValueExtractor(), which extracts individual values from the model.
      @returns  {Object}  An object describing the SlickGrid options to be utilized.
     */
    buildGridOptions: function() {

      var getCaseIndex = function(iRowItem) {
        var id = iRowItem && iRowItem.get('id'),
            idToIndexMap = this.getPath('collection.collection.caseIDToGroupedIndexMap'),
            index = idToIndexMap && id && idToIndexMap[id];
        return (index !== null && index !== undefined) ? (index + 1).toString() : "";
      }.bind(this);

      this.gridOptions = {
                rowHeight: this.get('rowHeight'),
                headerRowHeight: kDefaultRowHeight*2,
                enableColumnReorder: false,
                syncColumnCellResize: true,
                leaveSpaceForNewRows: false,
                editable: true, // user-editable cells for columns with an 'editable' property only
                enableAddRow: false, // don't add an extra blank row at the end
                asyncEditorLoading: false,
                enableAsyncPostRender: true,
                autoEdit: false, // double click to edit an 'editable' attribute's cell
                editCommandHandler: function( iItem, iColumn, iEditCommand) {
                                      // Called after the cell edit has been deactivated
                                      SC.run(function() {
                                        iEditCommand.execute();
                                      });
                                    },
                dataItemColumnValueExtractor: function (iRowItem, iColumnInfo) {
                  return iColumnInfo.id === kIndexColumnID ? getCaseIndex(
                      iRowItem) : iRowItem.getValue(iColumnInfo.id);
                }
             };
      return this.gridOptions;
    },

    /**
      Rebuilds the adapter by rebuilding the column header info, the row data, and the options.
     */
    rebuild: function() {
      this.updateColumnInfo();
      this.buildGridOptions();
    },

    /**
      Rebuilds the table when the data context changes.
     */
    dataContextDidChange: function() {
      this.beginPropertyChanges();
      this.setPath('gridDataView.context', this.get('dataContext'));
      this.setPath('gridDataView.collection', this.get('collection'));
      this.endPropertyChanges();
      this.rebuild();
    }.observes('dataContext'),

    /**
      Rebuilds the column descriptions when attribute formulas change.
     */
    attributeFormulaDidChange: function( iNotifier, iKey) {
      if( iKey === 'attrFormulaChanges')
        this.updateColumnInfo();
      this.markCasesChanged();
      this.gridDataView.refresh();
    }.observes('.collection.attrFormulaChanges'),

    /**
      Refreshes the contents of the table.
     */
    refresh: function() {
      this.set('lastRefresh', null);
      this.invokeOnce(function() {
        this.set('lastRefresh', null);
        var gridDataView = this.get('gridDataView');
        if( gridDataView) {
          gridDataView.refresh();
          this.notifyPropertyChange('tableDidRefresh');
        }
        this.set('lastRefresh', new Date());
      }.bind(this));
      this.set('lastRefresh', new Date());
    },

    /**
      Returns the set of selected row indices for the table.
      Note: We could potentially speed this up by only considering rows
      that are currently visible on screen, although this would require
      additional synchronization of selection when scrolling, for instance.
      @returns  {[number]}   The indices of the selected cases
     */
    getSelectedRows: function() {
      var dataContext = this.get('dataContext'),
          collection = this.get('collection'),
          dataView = this.get('gridDataView'),
          selection = this.getPath('collection.casesController.selection'),
          selectedRows = [],
          collectionClient;
      // add selected cases from our main collection
      if( selection) {
        selection.forEach( function( iCase) {
                            // Use visible row indices
                            var index = dataView.getRowById( iCase.get('id').toString());
                            if( index >= 0)
                              selectedRows.push( index);
                          });
      }
      // add selected cases from our parent collection shown in group header rows
      var i, rowCount = this.get('visibleRowCount'),
          parentCollection = dataContext && dataContext.getParentCollection( collection);
      if( parentCollection && dataView && (rowCount > 0)) {
        for( i = 0; i < rowCount; ++i) {
          var myCase = dataView.getItem( i);
          if (myCase.collection.get('id') !== collection.get('id')) {
            collectionClient = dataContext.getCollectionByID(myCase.collection.get('id'));
            if (collectionClient) {
              if(collectionClient.isCaseSelected(myCase)) {
                selectedRows.push(i);
              }
            } else {
              DG.log('CaseTableAdapter.getSelectedRows: collectionClient for case ' +
                  myCase.id + ' not found: ' + myCase.collection.get('id'));
            }
          }
        }
      }
      return selectedRows;
    },

    /**
      Selects the cases in the range of rows specified.
      @param    {Number}    iMinRow -- The starting row index
      @param    {Number}    iMaxRow -- The ending row index
     */
    selectRowsInRange: function( iMinRow, iMaxRow) {
      var tDataView = this.get('gridDataView'),
          tContext = this.get('dataContext'),
          tCollection = this.get('collection'),
          tCases = [];
      for( var i = iMinRow; i <= iMaxRow; ++i) {
        var tCase = tDataView.getItem( i),
            tGroupCaseID = tCase && tCase.__group && tCase.id;
        if( !SC.empty( tGroupCaseID)) {
          tCase = tContext.getCaseByID(tGroupCaseID);
        }
        if( tCase) tCases.push( tCase);
      }
      if( tCases.length) {
        var tChange = {
              operation: 'selectCases',
              collection: tCollection,
              cases: tCases,
              select: true,
              extend: false
            };
        tContext.applyChange( tChange);
      }
    },

    /**
     * Selects a range of cases based on an array of row indices.
     * @param iRowIndices {[number]} Array of row indices
     */
    selectRowsInList: function (iRowIndices) {
      var tDataView = this.get('gridDataView'),
          tContext = this.get('dataContext'),
          tCollection = this.get('collection'),
          tChange = {
            operation: 'selectCases',
            collection: tCollection,
            cases: iRowIndices.map(function (iRowIndex) {
              return tDataView.getItem( iRowIndex);
            }).filter( function( iCase) {
              // We filter because, at least in FireFox, we can get to a row that is one beyond the end
              // which therefore has no case
              return iCase && !iCase._isProtoCase;
            }),
            select: true,
            extend: false
          };
      if (tChange.cases.length)
        tContext.applyChange( tChange);
    },

    deselectAllCases: function() {
      var selectedRows = this.getSelectedRows();
      if (selectedRows && selectedRows.length)
        this.get('dataContext').applyChange({ operation: 'selectCases', select: false });
    },

    /**
      Invalidates the rows corresponding to the specified cases.
      @param  iCases {[DG.Case]}  The set of cases to mark as changed.
                                  If null/undefined, mark all cases changed.
     */
    markCasesChanged: function( iCases) {
      var dataView = this.get('gridDataView'),
          // if no cases are specified, mark all cases changed
          cases = iCases || this.getPath('collection.casesController');
      dataView.beginUpdate();
      cases.forEach( function( iCase) {
                        var caseID = iCase.get('id').toString(),
                            item = dataView.getItemById( caseID);
                        if( item)
                          dataView.updateItem( caseID, item);
                      });
      dataView.endUpdate();
      this.refresh();
    },

    /**
     * We want to move attribute, attr, from its collection to
     * the indicated position (an index) in the current collection.
     *
     * @param {DG.Attribute} attr
     * @param {number} position: position in the case table. This will correspond
     *          to the position in the collection when there are no hidden
     *          attributes. If there are hidden attributes we must adjust for this.
     */
    requestMoveAttribute: function (attr, position) {
      var tContext = this.get('dataContext'),
          tCollection = tContext && this.get('collection'),
          tAttrs = tCollection && tCollection.getPath('collection.attrs'),
          tAttrIndex = 0,
          tChange = {
            operation: 'moveAttribute',
            attr: attr,
            toCollection: tCollection,
            fromCollection: attr.get('collection'),
            position: null
          };
      if (!tAttrs) {
        return;
      }
      // subtract one for index column, which doesn't correspond to an attribute
      position -= 1;
      // have position in case table, find position in collection's attribute
      // list.
      while (position > 0 && tAttrs[tAttrIndex]) {
        if (!tAttrs[tAttrIndex].hidden) {
          position--;
        }
        tAttrIndex++;
      }
      tChange.position = tAttrIndex;
      tContext.applyChange(tChange);
    },

    /**
     * Returns whether the attribute can be dropped in the case table associated
     * with this adapter.
     *
     * Drop is disabled if any of the following are true
     *   (a) the dataContext prevents the drop
     *   (b) the dragged attribute is from another dataContext,
     *   (c) the plugin prevents the drop
     * see DG.DataContextUtilities.canAcceptAttributeDrop() for details
     *
     * @param attr
     * @returns {boolean}
     */
    canAcceptDrop: function (attr) {
      var dataContext = this.get('dataContext');
      var isTopLevelDrop = !this.get('hasParentCollection');
      return DG.DataContextUtilities
                .canAcceptAttributeDrop(dataContext, attr, isTopLevelDrop, true);
    }

  }; // end return from closure

}())); // end closure


/**
 * Slickgrid cell editor based on Slick.Editors.Text
 * @param args {{container: {element}, column: {object}, grid: {object}}}
 * @constructor
 */
DG.CaseTableCellEditor = function CaseTableCellEditor(args) {

  var $input;
  var defaultValue;

  this.init = function () {

    var kLeftArrowKeyCode = 37,
        kRightArrowKeyCode = 39,
        grid = args.grid,
        gridOptions = grid.getOptions(),
        // column = args.column,
        tag = gridOptions.rowHeight >= kMultilineRowHeightThreshold ? "textarea" : "input";
    $input = SC.$("<" + tag + " type=text class='dg-editor-text' />")
      .appendTo(args.container)
      .bind("keydown.nav", function (e) {
        if (e.keyCode === kLeftArrowKeyCode || e.keyCode === kRightArrowKeyCode) {
          e.stopImmediatePropagation();
        }
      })
      .bind("blur", function(e) {
        // Attempt to complete the edit whenever we lose focus
        DG.globalEditorLock.commitCurrentEdit();
      })
      .bind('mousedown', function(e) { e.stopImmediatePropagation(); })
      .bind('mouseup', function(e) { e.stopImmediatePropagation(); })
      .bind('click', function (e) {
        e.preventDefault();
        e.stopImmediatePropagation();
      })
      .focus()
      .select();
  };

  this.destroy = function () {
    $input.remove();
  };

  this.focus = function () {
    $input.focus();
  };

  this.getValue = function () {
    return $input.val();
  };

  this.setValue = function (val) {
    $input.val(val);
  };

  /**
   * Load the initial value to edit in the cell.
   * Instead we get it from our case data.
   * @param item {DG.Case} the row case
   */
  this.loadValue = function (item) {
    var attributeID = Number( args.column.id),
        caseAttributeValue = item && item.getValue(attributeID);

    // SlickGrid wants a string in 'defaultValue'
    defaultValue = SC.none( caseAttributeValue ) ? "" : caseAttributeValue.toString();

    // Unchanged from TextEditor.loadValue() :
    $input.val(defaultValue);
    $input[0].defaultValue = defaultValue;
    $input.select();
  };

  this.serializeValue = function () {
    return $input.val();
  };

  this.saveEditState = function () {
    return {
      item: args.item,
      column: args.column,
      value: $input.val(),
      selectionStart: $input[0].selectionStart,
      selectionEnd: $input[0].selectionEnd,
      selectionDirection: $input[0].selectionDirection
    };
  };

  this.restoreEditState = function (state) {
    $input.val(state.value);
    $input[0].setSelectionRange(state.selectionStart, state.selectionEnd, state.selectionDirection);
  };

  /**
   * Apply the edited value, by storing it in the DG data context.
   * Here we override the standard TextEditor.applyValue() method
   * Because the default editor modifies our row data, instead
   * of allowing the adapter to do it.  With this override we
   * don't need to handle the "onCellChanged" event.
   * @param item {DG.Case}
   * @param state {String} -- the edited string value
   */
  this.applyValue = function (item, state) {
    var attrID = Number( args.column.id ),
        tCase = item,
        isRealCaseEdit = tCase instanceof DG.Case, // not proto-case
        originalValue = isRealCaseEdit
                          ? tCase.getStrValue(attrID)
                          : tCase.getValue(args.column.id),
        newValue = DG.DataUtilities.canonicalizeInputValue(state),
        context = args.column.context,
        contextName = context.get('name'),
        collection = tCase.get('collection'),
        collectionName = collection && collection.get('name') || "",
        attr = collection && collection.getAttributeByID(attrID),
        attrName = attr && attr.get('name'),
        caseIndex = args.grid.getData().getIdxById(tCase.id);

    function applyEditChange(attrID, iValue, isUndoRedo) {
      if (isRealCaseEdit) {
        context.applyChange({
                  operation: 'updateCases',
                  cases: [ tCase ],
                  attributeIDs: [ attrID ],
                  values: [ [iValue] ]
                });
      }
      else if (!isUndoRedo) {
        // update proto-case value
        tCase.setValue(args.column.id, newValue);
      }
    }

    var cmd = DG.Command.create({
                name: 'caseTable.editCellValue',
                undoString: 'DG.Undo.caseTable.editCellValue',
                redoString: 'DG.Redo.caseTable.editCellValue',
                log: "editValue: { collection: %@, case: %@, attribute: '%@', old: '%@', new: '%@' }"
                      .fmt(collectionName, caseIndex + 1, attrID, originalValue, newValue),
                causedChange: isRealCaseEdit,
                execute: function() {
                  applyEditChange(attrID, newValue);
                },
                undo: function() {
                  applyEditChange(attrID, originalValue, true);
                },
                redo: function() {
                  context = DG.currDocumentController().getContextByName(contextName);
                  collection = context && context.getCollectionByName(collectionName);
                  attr = collection && collection.getAttributeByName(attrName);
                  attrID = attr.get('id');
                  var cases = collection && collection.get('casesController');
                  tCase = cases && cases.objectAt(caseIndex);
                  if (tCase)
                    applyEditChange(attrID, newValue, true);
                }
              });
    DG.UndoHistory.execute(cmd);
  };

  this.isValueChanged = function () {
    return (!($input.val() === "" && SC.none(defaultValue))) && ($input.val() !== defaultValue);
  };

  this.validate = function () {
    if (args.column.validator) {
      var validationResults = args.column.validator($input.val());
      if (!validationResults.valid) {
        return validationResults;
      }
    }

    return {
      valid: true,
      msg: null
    };
  };

  this.init();

};

/* >>>>>>>>>> BEGIN source/components/case_table/case_table_controller.js */
// ==========================================================================
//                      DG.CaseTableController
//
//  The controller for tables.
//
//  Authors:  William Finzer, Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/case_display_common/case_display_controller');
sc_require('components/case_table/attribute_editor_view');

/** @class

  DG.CaseTableController provides controller functionality for DG.TableViews.

  @extends DG.CaseDisplayController
*/
DG.CaseTableController = DG.CaseDisplayController.extend(
/** @scope DG.CaseTableController.prototype */
  (function() {
    return {

      /**
        @private
        Used internally to track changes to the data context.
       */
      _prevDataContext: null,

      /**
        The set of DG.CaseTableAdapters for the subtables in parent-->child order.
        @property {Array of DG.CaseTableAdapter}
       */
      caseTableAdapters: null,

      /**
        The content view for this controller, i.e. the DG.HierTableView.
        @property {DG.HierTableView}
       */
      contentView: null,

      newAttributeDialog: null,

      /**
        Initialization function.
       */
      init: function() {
        arguments.callee.base.apply(this,arguments);
        this.get('specialTitleBarButtons').push(
            DG.CaseCardToggleButton.create()
        );
        this.caseTableAdapters = [];
        // Init is called when the case table controller may not be fully
        // constructed, so, delay to the next Run Loop.
        this.invokeLater(function () {
          if( this.get('dataContext') && this.get('model')) {
            this.dataContextDidChange();
          } else {
            DG.logWarn('Case table controller unable to complete initialization: missing dataContext or model');
          }
        });
      },

      /**
        Destruction function.
       */
      destroy: function() {
        var dataContext = this.get('dataContext');
        if( dataContext)
          dataContext.removeObserver('changeCount', this, 'contextDataDidChange');
        this.caseTableAdapters = null;
        arguments.callee.base.apply(this,arguments);
      },

      // Utility function for identifying existing adapters for the specified collection
      findAdapterForCollection: function(iCollectionID) {
        var i, count, adapters = this.caseTableAdapters;
        if (adapters) {
          count = adapters.length;
          for( i = 0; i < count; ++i) {
            if( adapters[i] && (adapters[i].getPath('collection.id') === iCollectionID))
              return adapters[i];
          }
        }
        return null;
      },

      /**
        Builds an appropriate DG.CaseTableAdapter for each collection.
       */
      updateTableAdapters: function() {
        var dataContext = this.get('dataContext'),
            collectionRecords = dataContext && dataContext.get('collections') || [],
            // The controller model is a component object. We want the model for the
            // component's content.
            caseTableModel = this.model && this.model.get('content'),
            // new array to capture adapter order
            newAdapters = [];

        /**
         *
         * @param {DG.Collection} iCollectionRecord
         */
        function hasDisplayableAttributes(iCollectionRecord) {
          var attrs = iCollectionRecord.get('attrs');
          return !!attrs.find(function (attr) {return !attr.get('hidden');});
        }

        // Utility function for finding or creating (if necessary) an appropriate
        // adapter for the specified collection.
        var guaranteeAdapterForCollectionRecord = function( iCollectionRecord) {
          var collectionID = iCollectionRecord.get('id'),
              collection = dataContext.getCollectionByID( collectionID),
              // try to find an existing adapter for the specified collection
              adapter = this.findAdapterForCollection( collectionID);
          if( adapter) {
            adapter.beginPropertyChanges();
            adapter.set('dataContext', dataContext);
            adapter.set('collection', collection);
            adapter.endPropertyChanges();
          }
          else {
            // create a new adapter for the specified collection
            adapter = DG.CaseTableAdapter.create({
              dataContext: dataContext,
              collection: collection,
              model: caseTableModel
            });
          }
          newAdapters.push(adapter);
        }.bind(this);

        collectionRecords
            .filter(function (cr) { return hasDisplayableAttributes(cr); })
            .forEach( guaranteeAdapterForCollectionRecord);
        this.set('caseTableAdapters', newAdapters);
      },

      resetProtoCaseRows: function() {
        this.get('caseTableAdapters').forEach(function(adapter) {
          var gridDataView = adapter.get('gridDataView');
          if (gridDataView) gridDataView.resetProtoCases();
        });
      },

      /**
        Configure the table for the new data context.
       */
      dataContextDidChange: function() {
        var dataContext = this.get('dataContext');

        this.updateTableAdapters();

        var contentView = this.getPath('view.contentView');

        // Handle divider views for the drag-attribute listener setup.
        if (contentView) {
          var dividerDropDataCallback = function (iDivider) {
            var dropData = iDivider.getPath('dropData');
            if (SC.none(dropData)) {
              return;
            }
            var context = iDivider.getPath('dataContext');
            var parentTable = iDivider.getPath('leftTable');

            this.resetProtoCaseRows();
            DG.UndoHistory.execute(DG.DataContextUtilities.createCollectionCommand(dropData.attribute, dropData.collection, context, parentTable.getPath('gridAdapter.collection.id')));

            iDivider.setPath('dropData', null);
          }.bind(this);

          contentView.set('dataContext', dataContext);

          // Remove the observer and destroy stray divider views before the new setup.
          var oldDividerViews = contentView.getPath('dividerViews');
          oldDividerViews.forEach(function (iDividerView) {
            iDividerView.removeObserver('dropData', dividerDropDataCallback);
            iDividerView.destroy();
          });

          // This creates new divider views along with other stuff.
          contentView.setCaseTableAdapters(this.get('caseTableAdapters'));

          // Setup an observer for the drop-target divider views.
          var dividerViews = contentView.getPath('dividerViews');
          dividerViews.forEach(function (iDividerView) {
            iDividerView.addObserver('dropData', dividerDropDataCallback);
          });
        }

        if( dataContext !== this._prevDataContext) {
          if( this._prevDataContext)
            this._prevDataContext.removeObserver('changeCount', this, 'contextDataDidChange');
          if( dataContext)
            dataContext.addObserver('changeCount', this, 'contextDataDidChange');
          this._prevDataContext = dataContext;
          // In case the previous dataContext was destroyed, we are removed from the registry, so reregister
          DG.currDocumentController().tableCardRegistry.registerView(dataContext, this.get('view'));
        }

        var childCollection = this.getPath('dataContext.childCollection');
        if( childCollection) {
          // old-style notification support -- Remove once new-style notifications are completed.
          var this_ = this;
          //childCollection.casesController.addObserver('[]', this, 'caseCountDidChange');
          dataContext.forEachCollection( function( iCollection) {
                                          iCollection.attrsController.
                                            addObserver('[]', this_, 'attributesDidChange');
                                         });
        }
        this.doResetCollections();
      }.observes('dataContext'),

      getCaseCountMessage: function () {
        var dataContext = this.get('dataContext');
        var collectionRecords = dataContext.get('collections');
        var messages = [];
        var tStatusMessage = "";

        collectionRecords.forEach(function (collectionRecord) {
          var collectionClient = dataContext.getCollectionByName(collectionRecord.get('name'));
          var message = dataContext.getCaseCountString(collectionClient, collectionClient.getCaseCount() || 0);
          messages.push(message);
        });
        tStatusMessage = messages.join('/');
        if (SC.empty(tStatusMessage)) {
          DG.logWarn('No status message for case table: no collections');
        }

        //DG.logInfo("UpdateStatus: "  + tStatusMessage);
        return tStatusMessage;
      },

      createComponentStorage: function() {
        var caseTableModel = this.getPath('model.content'),
            dataContext = caseTableModel.get('context'),
            isActive = caseTableModel.get('isActive'),
            horizontalScrollOffset = caseTableModel.get('horizontalScrollOffset'),
            collapsedNodes = caseTableModel.get('collapsedNodes'),
            isIndexHidden = caseTableModel.get('isIndexHidden'),
            attributeWidths = [],
            rowHeights = [],
            storage = {
              isActive: isActive,
              horizontalScrollOffset: horizontalScrollOffset,
              isIndexHidden: isIndexHidden
            };
        if( dataContext) {
          this.addLink(storage, 'context', dataContext);
        }

        DG.ObjectMap.forEach(caseTableModel.get('preferredAttributeWidths'), function (key, width) {
          var obj = {};
          var attrRef = dataContext.getAttrRefByID(key);
          if (attrRef) {
            this.addLink(obj, 'attr', attrRef.attribute);
            obj.width = width;
            attributeWidths.push(obj);
          }
        }.bind(this));
        storage.attributeWidths = attributeWidths;

        DG.ObjectMap.forEach(caseTableModel.get('tableRowHeights'), function (collectionId, rowHeight) {
          var obj = {};
          var collection = dataContext.getCollectionByID(collectionId);
          if (collection) {
            this.addLink(obj, 'collection', collection);
            obj.rowHeight = rowHeight;
            rowHeights.push(obj);
          }
        }.bind(this));
        storage.rowHeights = rowHeights;

        collapsedNodes.forEach(function (caseID, key) {
          var tCase = dataContext.getCaseByID(caseID);
          if (tCase) {
            this.addLink(storage, 'collapsedNodes', tCase);
          }
        }.bind(this));

        return storage;
      },

      restoreComponentStorage: function( iStorage, iDocumentID) {
        arguments.callee.base.apply(this,arguments);
        var caseTableModel = this.getPath('model.content');
        if (caseTableModel) {
          var contextID = this.getLinkID( iStorage, 'context'),
              collapsedNodesCount = DG.ArchiveUtils.getLinkCount(iStorage,
                  'collapsedNodes'),
              dataContext = contextID
                  && DG.currDocumentController().getContextByID(contextID),
              attributeWidths = {},
              rowHeights = {},
              isActive = iStorage.isActive,
              ix = 0;
          if (iStorage.attributeWidths) {
            iStorage.attributeWidths.forEach(function (obj) {
              var id = this.getLinkID(obj, 'attr');
              attributeWidths[id] = obj.width;
            }.bind(this));
            caseTableModel.set('preferredAttributeWidths', attributeWidths);
          }
          if (iStorage.rowHeights) {
            iStorage.rowHeights.forEach(function (obj) {
              var collectionId = this.getLinkID(obj, 'collection');
              rowHeights[collectionId] = obj.rowHeight;
            }.bind(this));
            caseTableModel.set('tableRowHeights', rowHeights);
          }
          if( dataContext) {
            caseTableModel.set('context', dataContext);
            this.set('dataContext', dataContext);
          }
          caseTableModel.set('isActive', isActive);
          caseTableModel.set('isIndexHidden', iStorage.isIndexHidden);
          caseTableModel.set('horizontalScrollOffset', iStorage.horizontalScrollOffset);
          if (collapsedNodesCount > 0) {
            while(ix < collapsedNodesCount) {
              caseTableModel.collapseNode(DG.store.find('DG.Case',
                  DG.ArchiveUtils.getLinkID(iStorage, 'collapsedNodes', ix)));
              ix += 1;
            }
          }
        }
        // Todo: This low-level call to get a refresh is problematic. Figure out a better way
        if( this.get('contentView')) {
          this.get('contentView').frameDidChange();
        }
      },

      /**
        Process commands such as those dispatched by the SlickGrid column header menus.
        @param  {Object}  iArgs
                  {String}  iArgs.command
                  {Object}  iArgs.column
                    {String}  iArgs.column.id
       */
      doCommand: function( iArgs) {
        var columnID = Number( iArgs.column.id);
        switch( iArgs.command) {
        case 'cmdEditFormula':
          this.editAttributeFormula( columnID);
          break;
        case 'cmdDeleteFormulaKeepValues':
          this.deleteFormulaKeepValues( columnID);
          break;
        case 'cmdRecoverDeletedFormula':
          this.recoverDeletedFormula( columnID);
          break;
        case 'cmdEditName':
          this.editName( columnID, iArgs.grid.getHeaderRowColumn(columnID));
          break;
        case 'cmdResizeAttribute':
          this.resizeColumn(columnID, iArgs.grid.getHeaderRowColumn(columnID));
           break;
        case 'cmdEditAttribute':
          this.editAttribute( columnID, iArgs.grid.getHeaderRowColumn(columnID));
          break;
        case 'cmdRandomizeAttribute':
          DG.DataContextUtilities.randomizeAttribute( this.get('dataContext'), columnID);
          break;
        case 'cmdSortAscending':
          this.sortAttribute( columnID);
          break;
        case 'cmdSortDescending':
          this.sortAttribute( columnID, true);
          break;
        case 'cmdHideAttribute':
          DG.DataContextUtilities.hideAttribute( this.get('dataContext'), columnID);
          break;
        case 'cmdDeleteAttribute':
          DG.DataContextUtilities.deleteAttribute( this.get('dataContext'), columnID);
          break;
        }
      },

      /**
        Observer function called when the data context notifies that it has changed.
       */
      contextDataDidChange: function() {
        var changes = this.getPath('dataContext.newChanges'),
            // most changes are sufficient to require aggregate invalidation
            invalidateAggregates = true;

        /**
          Process each change that has occurred since the last notification.
         */
        var handleOneChange = function( iChange) {
          var operation = iChange && iChange.operation;
          switch( operation) {
          case 'createCollection':
            // Hook up the table to the new collection
            this.dataContextDidChange();
            break;
          case 'deleteCollection':
            this.dataContextDidChange();
            break;
          case 'createCase':
          case 'createCases':
          case 'moveCases':
            this.doCreateCases( iChange);
            invalidateAggregates = false; // handled by doDependentCases
            break;
          case 'updateCases':
            this.doUpdateCases( iChange);
            invalidateAggregates = false; // handled by doDependentCases
            break;
          case 'deleteCases':
            this.doDeleteCases( iChange);
            invalidateAggregates = false; // handled by doDependentCases
            break;
          case 'selectCases':
            this.doSelectCases( iChange);
            // selection changes don't require aggregate invalidation
            invalidateAggregates = false;
            break;
          case 'dependentCases':
            this.doDependentCases(iChange);
            invalidateAggregates = false; // handled by doDependentCases
            break;
          case 'createAttributes':
            this.doCreateAttributes(iChange);
            break;
          case 'hideAttributes':
          case 'unhideAttributes':
            this.dataContextDidChange(iChange);
            this.attributesDidChange(iChange);
            break;
          case 'updateAttributes':
            this.dataContextDidChange(iChange);
            this.attributesDidChange(iChange);
            break;
          case 'deleteAttributes':
            this.doDeleteAttributes(iChange);
            break;
          case 'moveAttribute':
            this.dataContextDidChange(iChange);
            this.doMoveAttributes(iChange);
            break;
          case 'sortAttribute':
            this.dataContextDidChange(iChange);
            break;
          case 'resetCollections':
            this.caseCountDidChange( iChange);
            this.dataContextDidChange();
            break;
          case 'deleteDataContext':
            this.dataContextWasDeleted();
            break;
          case 'updateDataContext':
          case 'updateCollection':
          case 'createItems':
          case 'updateItems':
          case 'deleteItems':
          case 'moveItems':
            // Nothing to do here because we'll receive corresponding case notifications
            break;
          default:
            DG.logWarn("DG.CaseTableController -- Unhandled operation: " + iChange.operation);
          }
        }.bind( this);

        // Process all changes that have occurred since the last notification.
        if( changes) {
          changes.forEach( function( iChange) {
                              handleOneChange( iChange);
                            });
        }
        // If there are aggregate functions, we may have to mark all cases as changed.
        // With the introduction of the dependency manager, this should be less frequent.
        if( invalidateAggregates) {
          var adapters = this.get('caseTableAdapters');
          if( adapters) {
            adapters.forEach( function( iAdapter) {
                                if( iAdapter.get('hasAggregates'))
                                  iAdapter.markCasesChanged();
                              });
          }
        }
      },
      doCreateCases: function (iChange) {
        this.caseCountDidChange( iChange);
        if (iChange.result && iChange.result.caseIDs) {
          // The dataView is not necessarily updated until the end of the run loop,
          // so we defer scrolling...
          this.invokeNext(function () {
            this.get('contentView').scrollToCaseByID(iChange.collection,
                iChange.result.caseIDs[iChange.result.caseIDs.length - 1]);
          });
        }
      },
      doUpdateCases: function (iChange) {
        this.doChangeCaseValues(iChange);
      },
      doDeleteCases: function (iChange) {
        var caseTableModel = this.getPath('model.content');
        this.caseCountDidChange( iChange);
        this.doSelectCases(iChange);
        caseTableModel.didDeleteCases(iChange.cases);
        this.resetProtoCaseRows();
      },
      doDependentCases: function(iChange) {
        if (iChange.changes) {
          iChange.changes.forEach(function(iChange) {
            var collection = iChange.collection,
                collectionID = collection && collection.get('id'),
                invalidCases = iChange.cases && iChange.cases.length
                                  ? iChange.cases : undefined,
                adapter = this.findAdapterForCollection(collectionID);
            if (adapter) {
              adapter.markCasesChanged(invalidCases);
            }
          }.bind(this));
        }
      },
      doCreateAttributes: function (iChange) {
        this.attributesDidChange( iChange);
      },
      doDeleteAttributes: function (iChange) {
        this.attributesDidChange( iChange);
      },
      doMoveAttributes: function (iChange) {
        this.attributesDidChange( iChange);
      },
      doResetCollections: function (iChange) {
        function processAdapter(iAdapter) {
          iAdapter.rebuild();
          iAdapter.refresh();
        }
        var adapters = this.get('caseTableAdapters');
        adapters.forEach( processAdapter);
      },
      /**
        Called when the data context notifies that the set of selected cases has changed.
        @param iChange {Object}  An object describing the nature of the change
       */
      doSelectCases: function( iChange) {
        var hierTableView = this.getPath('view.contentView');
        // DG.log('Select Cases(' + iChange.operation + '): ' + (iChange.cases && iChange.cases.map(function(iCase) {
        //   return iCase.id;
        // }).join()));
        var scrollToCase = (iChange.operation === 'selectCases') && iChange.cases && iChange.cases[0];
        this.invokeOnceLater(function () {
          if( hierTableView) {
            hierTableView.updateSelectedRows();
            hierTableView.scrollSelectionToView(scrollToCase);
          }
        });
      },

      /**
        Called when the data context notifies that case values have changed.
        @param iChange {Object}  An object describing the nature of the change
       */
      doChangeCaseValues: function( iChange) {
        var adapters = {};
        this.get('caseTableAdapters')
            .forEach(function(iAdapter) {
              var collectionID = iAdapter.getPath('collection.id');
              adapters[collectionID] = { adapter: iAdapter, cases: [] };
            });

        function identifyCasesChanged(iCases) {
          if (iCases) {
            iCases.forEach(function(iCase) {
              var collectionID = iCase.getPath('collection.id'),
                  adapter = adapters[collectionID];
              if (adapter) {
                adapter.cases.push(iCase);
                identifyCasesChanged(iCase.get('children'));
              }
            });
          }
        }

        // recursively identify all affected cases
        identifyCasesChanged(iChange.cases);

        DG.ObjectMap.forEach(adapters, function(id, iAdapter) {
          if (iAdapter.cases.length > 0)
            iAdapter.adapter.markCasesChanged(iAdapter.cases);
        });
        this.getPath('view.contentView').refresh();
      },

      /**
        Called when the data context notifies that attribute properties have changed.
        @param  iChange {Object}  An object describing the nature of the change
       */
      doUpdateAttributes: function( iChange) {
        var hierTableView = this.getPath('view.contentView'),
            adapters = this.get('caseTableAdapters'),
            updatedAdapters = [],
            attributes = (iChange && iChange.result && iChange.result.attrs) ||
                this.dataContext.getAttributes();

        function processAdapter( iAdapter) {
          if( attributes) {
            attributes.forEach( function( iAttribute) {
                                  if( iAdapter.updateColumnForAttribute( iAttribute))
                                    updatedAdapters.push( iAdapter);
                                });
          }
        }

        if( adapters) {
          adapters.forEach( processAdapter);
          if( hierTableView) {
            hierTableView.get('childTableViews').
              forEach( function( iCaseTableView) {
                var tableAdapter = iCaseTableView.get('gridAdapter');
                var columns;
                if( updatedAdapters.indexOf( tableAdapter) >= 0) {
                  columns = tableAdapter.get('gridColumns').filter(function (column) {
                    return !column.attribute || !column.attribute.hidden;
                  });
                  iCaseTableView.setColumns( columns);
                }
              });
          }
        }
      },

      /**
        Called when the array observer indicates that the number of cases has changed.
       */
      caseCountDidChange: function( iChange) {
        var hierTableView = this.getPath('view.contentView'),

            // if the change event includes an index, then we're inserting a new row in an
            // arbitrary location, so we need to force the table to re-index the rows
            forceRedraw   = iChange.properties && !SC.none(iChange.properties.index);

        if( hierTableView) {
          hierTableView.updateRowCount(forceRedraw);
        }
      },

      /**
        Called when the array observer indicates that the number of attributes has changed.
       */
      attributesDidChange: function() {
        var hierTableView = this.getPath('view.contentView');
        if( hierTableView) {
          hierTableView.updateColumnInfo();
          hierTableView.updateRowCount();
          hierTableView.updateSelectedRows();
        }
      },

      modelDidChange: function() {
      }.observes('model'),

      /**
       * We do not close case tables and case cards. We hide and show them.
       */
      toggleViewVisibility: function() {
        var tCaseTableView = this.get('view'),
            tOperation = tCaseTableView.get('isVisible') ? 'delete' : 'add',
            tViewName = 'caseTableView';
        DG.UndoHistory.execute(DG.Command.create({
          name: 'component.toggle.delete',
          undoString: 'DG.Undo.toggleComponent.' + tOperation + '.' + tViewName,
          redoString: 'DG.Redo.toggleComponent.' + tOperation + '.' + tViewName,
          log: 'Toggle component: %@'.fmt('caseTable'),
          execute: function () {
            var isVisible = tCaseTableView.toggleProperty('isVisible'),
                layout = tCaseTableView.get('layout'),
                operation = isVisible ? 'create' : 'delete';
            tCaseTableView.set('savedLayout', layout);
            if( !isVisible && tCaseTableView.parentView && tCaseTableView.parentView.select)
              tCaseTableView.parentView.select(null);
            DG.currDocumentController().notificationManager.sendNotification({
              action: 'notify',
              resource: 'component',
              values: {
                operation: operation,
                type: tCaseTableView.getPath('model.type'),
                id: tCaseTableView.getPath('model.id'),
                title: tCaseTableView.getPath('model.title')
              }
            });
          },
          undo: function () {
            this.execute();
          },
          redo: function () {
            this.execute();
          }
        }));
      },

      viewDidChange: function() {
        var tComponentView = this.get('view'),
            tContentView = tComponentView.get('contentView');
        this.set('contentView', tContentView);

        if( !this.getPath('caseTableAdapters.length'))
          this.updateTableAdapters();

        if( tContentView) {
          tContentView.bind('dataContext', this, 'dataContext');

          tContentView.setCaseTableAdapters( this.get('caseTableAdapters') || []);
        }

        var gearView = this.getPath('view.containerView.titlebar.gearView');
        if( gearView)
          gearView.set('contentView', tComponentView);
      }.observes('view'),

      /**
        Handler for sendAction('newAttributeAction')
       */
      newAttributeAction: function(iSender, iContext) {
        this.newAttribute(iContext);
        return YES;
      },

      /**
       * Creates a new attribute and begins to edit the attribute name in place.
       */
      newAttribute: function(properties) {
        var dataContext = this.get('dataContext'),
            collection = properties.collection,
            collectionID = collection && collection.get('id'),
            hierTableView = this.getPath('view.contentView'),
            caseTableView = hierTableView && hierTableView.getChildTableViewForCollection(collectionID);

        DG.DataContextUtilities.newAttribute( dataContext, collection, null,
            caseTableView, properties.autoEditName);

    },

      /**
       * Method to create a new attribute with formula.
       * NOTE: this method will also replace the formula of an existing attribute of the same name (case sensitive)
       * @param iProperties --properties to pass on to the applyNewAttribute() method.
       * @param iDefaultAttrName {string} --(optional) default attribute name for the new attribute dialog
       * @param iDefaultAttrFormula {string} --(optional) default attribute formula string for the new attribute dialog
       */
      editAttributeProperties: function( iProperties, iDefaultAttrName, iDefaultAttrFormula ) {
        var tDataContext = this.get('dataContext'),
            defaultAttrName = iDefaultAttrName || '',
            defaultAttrFormula = iDefaultAttrFormula || '',
            result = DG.AttributeFormulaView.buildOperandsMenuAndCompletionData(tDataContext);

          // Use SC.mixin() to combine iProperties with the rest of the default properties
          // that are passed to the new attribute dialog.
        this.newAttributeDialog = DG.CreateAttributeFormulaView(SC.mixin({
              applyTarget: this,
              applyAction: 'applyNewAttribute',
              applyTooltip: 'DG.TableController.newAttrDlg.applyTooltip', // "Define the new attribute using the name and (optional) formula"
              attrNameHint: 'DG.TableController.newAttrDlg.attrNameHint',
              attrNameValue: defaultAttrName,
              attrNameIsEnabled: SC.empty( iDefaultAttrName ), // disable attribute name changes if editing an existing attribute
              formulaValue: defaultAttrFormula,
              //formulaNames: tFormulaNames,  // no type-ahead
              formulaCompletions: result.completionData,
              formulaOperands: result.operandsMenu,
              formulaHint: 'DG.TableController.newAttrDlg.formulaHint'  // "If desired, type a formula for computing values of this attribute"
            }, iProperties));
      },

      applyNewAttribute: function() {
        var tContext = this.get('dataContext'),
            tAttributeName = this.newAttributeDialog.get('attributeName'),
            tRef = tContext.getAttrRefByName( tAttributeName),
            tAttrFormula = tRef && tRef.attribute.get('formula'),
            isNew = this.newAttributeDialog.get('attrNameIsEnabled');
        // Should also test for attribute name validity as well
        if( !SC.empty( tAttributeName)) {
          // Retrieve the name of the target collection that was passed by the client originally.
          var tCollection = this.newAttributeDialog.get('collection'),
              tFormula = this.newAttributeDialog.get('formula');

          DG.UndoHistory.execute(DG.Command.create({
            name: isNew ? "caseTable.createAttribute" : "caseTable.editAttributeFormula",
            undoString: isNew ? 'DG.Undo.caseTable.createAttribute' : 'DG.Undo.caseTable.editAttributeFormula',
            redoString: isNew ? 'DG.Redo.caseTable.createAttribute' : 'DG.Redo.caseTable.editAttributeFormula',
            _componentId: this.getPath('model.id'),
            _controller: function() {
              return DG.currDocumentController().componentControllersMap[this._componentId];
            },
            executeNotification: {
              action: 'notify',
              resource: 'component',
              values: {
                operation: 'edit formula',
                type: 'DG.CaseTable'
              }
            },
            execute: function() {
              tRef = tContext.getAttrRefByName( tAttributeName);
              var tChange = {
                          operation: 'createAttributes',
                          collection: tCollection,
                          attrPropsArray: [{ name: tAttributeName, formula: tFormula }]
                        },
                  tResult = tContext && tContext.applyChange( tChange);
              if( tResult.success) {
                var action = isNew ? "attributeCreate" : "attributeEditFormula";
                this.log = "%@: { name: '%@', collection: '%@', formula: '%@' }".fmt(
                            action, tAttributeName, tCollection.get('name'), tFormula);
              } else {
                this.set('causedChange', false);
              }
            },
            undo: function() {
              var tChange, tResult, action; // eslint-disable-line no-unused-vars
              tContext = this._controller().get('dataContext');
              if (isNew) {
                tRef = tContext.getAttrRefByName( tAttributeName);
                tChange = {
                            operation: 'deleteAttributes',
                            collection: tCollection,
                            attrs: [{ id: tRef.attribute.get('id'), attribute: tRef.attribute }]
                          };
              } else {
                tChange = {
                            operation: 'createAttributes',
                            collection: tCollection,
                            attrPropsArray: [{ name: tAttributeName, formula: tAttrFormula }],
                            isUndo: true
                          };
              }
              tResult = tContext && tContext.applyChange( tChange);
              if( tResult.success) {
                action = isNew ? "attributeCreate" : "attributeEditFormula";
              } else {
                this.set('causedChange', false);
              }
            },
            redo: function() {
              tContext = this._controller().get('dataContext');
              this.execute();
            }
          }));
        }
        else {
          // Alert if user doesn't enter an attribute name
          DG.AlertPane.show({
              localize: true,
              message: 'DG.TableController.newAttrDlg.mustEnterAttrNameMsg'
          });
          return; // Return without closing the dialog
        }
        this.newAttributeDialog.close();
        this.newAttributeDialog = null;
      },

      willDestroy: function() {
        if( this.newAttributeDialog) {
          this.newAttributeDialog.close();
          this.newAttributeDialog = null;
        }
        arguments.callee.base.apply(this,arguments);
      },

      editName: function(iAttrID, iMenuItem) {
        var tDataContext = this.get('dataContext'),
            tAttrRef = tDataContext && tDataContext.getAttrRefByID( iAttrID),
            tAttr = tAttrRef && tAttrRef.attribute,
            collection = tAttrRef && tAttrRef.collection,
            collectionID = collection && collection.get('id'),
            hierTableView = this.getPath('view.contentView'),
            caseTableView = hierTableView && hierTableView.getChildTableViewForCollection(collectionID);


        if( !DG.assert( tAttr, "editName() is missing the attribute reference"))
          return;

        caseTableView.beginEditAttributeName(tAttr.get('name'));
      },
      resizeColumn: function (iAttrID, iMenuItem) {
        var _this = this,
            tDataContext = this.get('dataContext'),
            tAttrRef = tDataContext && tDataContext.getAttrRefByID( iAttrID),
            tAttr = tAttrRef && tAttrRef.attribute,
            collection = tAttrRef && tAttrRef.collection,
            collectionID = collection && collection.get('id'),
            adapter = collectionID && this.findAdapterForCollection(collectionID),
            lastWidth;
        if (adapter) {
          lastWidth = adapter.getPreferredColumnWidth(iAttrID);
          DG.UndoHistory.execute(DG.Command.create({
            name: 'caseTable.resizeColumn',
            undoString: 'DG.Undo.caseTable.resizeColumn',
            redoString: 'DG.Undo.caseTable.resizeColumn',
            log: 'Fit Column Width: {collection: %@, attribute: %@}'
                .fmt(collection.get('name'), tAttr.get('name')),
            executeNotification: {
              action: 'notify',
              resource: 'component',
              values: {
                operation: 'resize column',
                type: 'DG.CaseTable'
              }
            },
            execute: function() {
              adapter.autoResizeColumn(tAttr);
              _this.attributesDidChange();
            },
            undo: function() {
              adapter.model.setPreferredAttributeWidth(iAttrID, lastWidth);
              _this.attributesDidChange();
            }
          }));
        } else {
          DG.logWarn('Could not find adapter for attr: ' + iAttrID);
        }
      },
      /**
       * Edit an attribute's properties. Brings up the Edit Attribute dialog.
       *
       */
      editAttribute: function( iAttrID, iMenuItem) {
        var tDataContext = this.get('dataContext'),
            tAttrRef = tDataContext && tDataContext.getAttrRefByID( iAttrID);

        if( !DG.assert( tAttrRef, "editAttribute() is missing the attribute reference"))
          return;

        this.showEditAttributePane(tAttrRef, iMenuItem);
      },

      /**
       * Updates an attribute undo-ably based on attribute properties.
       *
       * This method is called from the attribute editing dialog.
       *
       * @param iAttrRef {{collection:  {DG.CollectionClient}
   *                       attribute:   {DG.Attribute}
   *                       position:    {number}}}
       * @param iChangedAttrProps {object}
       */
      updateAttribute: function(iAttrRef, iChangedAttrProps) {
        DG.DataContextUtilities.updateAttribute( this.get('dataContext'), iAttrRef && iAttrRef.collection,
            iAttrRef.attribute, iChangedAttrProps);
      },

      showEditAttributePane: function (iAttrRef, menuItem) {
        var attributePane = DG.AttributeEditorView.create({attrRef: iAttrRef, attrUpdater: this});
        attributePane.append();
      },

      /**
       * Sort by an attribute.
       *
       * If the attribute is in a child collection, the sorting should _not_
       * affect the order of the parent collection. In other words, the sorting
       * is among the children of the same parent.
       * @param attrID {string|number}
       * @param isDescending {boolean}
       */
      sortAttribute: function(attrID, isDescending) {
        var dataContext = this.get('dataContext'),
            dataSet = dataContext && dataContext.getPath('model.dataSet'),
            childCollection = dataContext && dataContext.get('childCollection'),
            childCollectionID = childCollection && childCollection.get('id'),
            compareFunc = isDescending
                            ? DG.DataUtilities.compareDescending
                            : DG.DataUtilities.compareAscending,
            attribute = DG.Attribute.getAttributeByID(attrID),
            isNumeric = attribute.get('type') === 'numeric',
            collection = attribute && attribute.get('collection'),
            collectionID = collection && collection.get('id'),
            parentCollection = collection.get('parent'),
            hierTableView = this.getPath('view.contentView'),
            oldClientMap, newClientMap;

        function accessFunc(itemID, attrID) {
          var tCase = DG.Case.findCase(childCollectionID, itemID);

          while (tCase && (tCase.getPath('collection.id') !== collectionID))
            tCase = tCase.get('parent');

          return tCase;
        }

        function getValue(iCase, attrID) {
          var rawValue = iCase && iCase.getRawValue(attrID);
          var numValue = iCase && (isNumeric? iCase.getForcedNumericValue(attrID): null);
          return iCase && (SC.empty(numValue)? rawValue: numValue);
        }

        function makeCompare(attrID, isDescending, parentCollection) {
          var compareIndex = function (a,b) {return a-b;};
          if (parentCollection) {
            return function (caseA, caseB) {
              var caseAParentIndex = caseA && parentCollection.caseIDToIndexMap[caseA.getPath(
                  'parent.id')];
              var caseBParentIndex = caseB && parentCollection.caseIDToIndexMap[caseB.getPath(
                  'parent.id')];
              if (caseAParentIndex !== caseBParentIndex) {
                return compareIndex(caseAParentIndex, caseBParentIndex);
              } else {
                return compareFunc(getValue(caseA, attrID), getValue(caseB, attrID));
              }
            };
          }
          else {
            return function (caseA, caseB) {
              return compareFunc(getValue(caseA, attrID), getValue(caseB, attrID));
            };
          }
        }

        function refreshTable() {
          dataContext.regenerateCollectionCases(null, 'moveCases');
          if (hierTableView)
            hierTableView.updateRowData();
        }

        if (dataSet) {
          DG.UndoHistory.execute(DG.Command.create({
            name: 'caseTable.sortCases',
            undoString: 'DG.Undo.caseTable.sortCases',
            redoString: 'DG.Redo.caseTable.sortCases',
            log: "sort cases by attribute: %@ (\"%@\")".fmt(attrID, attribute && attribute.get('name')),
            execute: function() {
              oldClientMap = dataSet.sortItems(attrID, accessFunc, makeCompare(attrID, isDescending, parentCollection));
              newClientMap = dataSet.getClientIndexMapCopy();
              refreshTable();
            },
            undo: function() {
              dataSet.setClientIndexMap(oldClientMap);
              refreshTable();
            },
            redo: function() {
              dataSet.setClientIndexMap(newClientMap);
              refreshTable();
            }
          }));
        }
      },

      /**
       * Edit a formula attribute, if given the attribute ID.
       * Initiates an Edit Attribute Formula dialog for the given attribute.
       *
       */
      editAttributeFormula: function( iAttrID ) {
        var tDataContext = this.get('dataContext'),
            tRef = tDataContext && tDataContext.getAttrRefByID( iAttrID),
            tAttrName = tRef && tRef.attribute.get('name'),
            tAttrFormula = tRef.attribute.get('formula');

        DG.assert( tRef && tAttrName, "editAttributeFormula() is missing the attribute reference or attribute name" );
        // for now we use the newAttribute() method which will replace one attribute formula with another
        // if the new attribute has the same name as the old.

        this.editAttributeProperties({ collection: tRef.collection }, tAttrName, tAttrFormula || '' );
      },

      /**
       * Converts the formula output to raw values.
       * @param iAttrID
       */
      deleteFormulaKeepValues: function (iAttrID ) {
        var callback = this.getPath('view.contentView').updateColumnInfo.bind(this);
        DG.DataContextUtilities.deleteAttributeFormula(this.get('dataContext'), iAttrID, callback);
      },

      /**
       * If a formula has been deleted recently, restore it from the attribute property.
       * @param iAttrID
       */
      recoverDeletedFormula: function (iAttrID) {
        var callback = this.getPath('view.contentView').updateColumnInfo.bind(this);
        DG.DataContextUtilities.recoverAttributeFormula(this.get('dataContext'), iAttrID, callback);
      },

      createNewAttributesButtons: function() {
        var tDataContext = this.get('dataContext'),
            collectionRecords = tDataContext.get('collections') || [],
            tNewAttrMenuItemStringKey = 'DG.Inspector.newAttribute',
            tItems = [];
        collectionRecords.forEach(function (collection) {
          var adapter = this.findAdapterForCollection(collection.id),
              isEnabled = adapter && adapter.get('isCollectionReorgAllowed');
          tItems.push({
            title: tNewAttrMenuItemStringKey.loc( collection.name),
            target: this,
            args: [{collection: tDataContext.getCollectionByName(collection.name),
              autoEditName: true }],
            dgAction: 'newAttribute',
            isEnabled: isEnabled
          });
        }.bind(this));
        return tItems;
      },

      showAttributesPopup: function() {
        var tItems = this.createNewAttributesButtons();
        tItems.push(this.createRandomizeButton());
        tItems.push(this.createExportCaseButton());
        tItems.push(this.createCopyToClipboardButton());
        tItems.push(this.createGetFromClipboardButton());

        DG.MenuPane.create({
          classNames: 'dg-attributes-popup'.w(),
          layout: {width: 200, height: 150},
          items: tItems
        }).popup(this.get('inspectorButtons')[1]);
      },

      resizeColumns: function () {
        var dataContext = this.dataContext;
        var caseTableModel = this.getPath('model.content');
        var adapters = this.get('caseTableAdapters');
        var columnWidths = dataContext.getAttributes().map(function (attr) {
          var id =  attr && attr.id;
          return {id: id, width: caseTableModel.getPreferredAttributeWidth(id)};
        }.bind(this));
        // var componentWidth = this.contentView.get('frame').width;
        DG.UndoHistory.execute(DG.Command.create({
          name: 'caseTable.resizeColumns',
          undoString: 'DG.Undo.caseTable.resizeColumns',
          redoString: 'DG.Redo.caseTable.resizeColumns',
          log: "resizeColumns: { dataContext: % }".fmt(dataContext),
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'resize columns',
              type: 'DG.CaseTable'
            }
          },
          execute: function () {
            adapters.forEach( function (adapter) {
              adapter.autoResizeAllColumns();
            });
            this.attributesDidChange();
          }.bind(this),
          undo: function () {
            columnWidths.forEach(function (oldWidth) {
              if (oldWidth) {
                caseTableModel.setPreferredAttributeWidth(oldWidth.id, oldWidth.width);
              }
            }.bind(this));
            this.attributesDidChange();
          }.bind(this)
        }));
      },
      /**
       *
       * @returns {Array}
       */
      createInspectorButtons: function() {
        var tButtons = arguments.callee.base.apply(this,arguments);
        tButtons.push(this.createInfoButton());
        // rescale item
        tButtons.push(DG.IconButton.create({
          layout: {width: 32, left: 0, height: 25},
          classNames: 'display-rescale'.w(),
          iconClass: 'moonicon-icon-scaleData',
          iconExtent: {width: 30, height: 25},
          target: this,
          action: 'resizeColumns',
          toolTip: 'DG.Inspector.resize.toolTip',  // "Rescale graph axes to encompass data"
          localize: true
        }));

        tButtons.push(this.createTrashButton());
        tButtons.push(this.createHideShowButton());
        tButtons.push(this.createRulerButton());

        return tButtons;
      },

      /**
       * Handles drop to leftDropZone.
       */
      leftDropZoneDidAcceptDrop: function () {
        var dropData = this.getPath('contentView.leftDropTarget.dropData');
        if (SC.none(dropData)) {
          return;
        }
        var context = this.dataContext;
        this.resetProtoCaseRows();
        DG.UndoHistory.execute(DG.DataContextUtilities.createCollectionCommand(dropData.attribute,
            dropData.collection, context));
        this.setPath('contentView.leftDropTarget.dropData', null);
      }.observes('contentView.leftDropTarget.dropData')
    };
  }()) // function closure
);

/* >>>>>>>>>> BEGIN source/components/case_table/case_table_data_manager.js */
// ==========================================================================
//
//  Author:   jsandoe
//
//  Copyright (c) 2016 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
/* global Slick:true */
/**
 * @class CaseTableDataManager
 *
 * A specialized, on demand, implementation of the SlickGrid DataView interface.
 * See https://github.com/mleibman/SlickGrid/wiki/DataView.
 * We implement getLength() and getItem(index) from the API.
 *
 * @extends SC.Object
 */
DG.CaseTableDataManager = SC.Object.extend({

  /**
   * @type {DG.DataContext}
   */
  context: null,

  /**
   * The collection that this case table is presenting.
   * @type {DG.CollectionClient}
   */
  collection: null,

  /**
   * @type {DG.CaseTableModel}
   */
  model: null,

  /**
   * Home for column info
   * @type {DG.CaseTableAdapter}
   */
  adapter: null,

  /**
   * @type {boolean}
   */
  suspended: false,

  /**
   * Cache of mappings from row index to case.
   * @type {[DG.Case]}
   */
  _rowCaseMap: null,

  /**
   * Map from collection ID to proto-case.
   * @type {Object}
   */
  _protoCases: null,

  /**
   *
   */
  _collapsedNodeInfoCache: null,

  caseTableLength: function () {
    return this._rowCaseMap.length;
  }.property(),

  init: function () {
    this._rowCaseMap = [];
    this._protoCases = {};
    this.onRowCountChanged = new Slick.Event();
    this.onRowsChanged = new Slick.Event();
  },

  /**
   * Returns the number of rows in the table.
   *
   * Signature defined by Slick Grid DataView API.
   *
   * Implements a method of the SlickGrid DataView API.
   * The number of rows counts a collapsed group as a
   * single row.
   *
   * @returns {Number}
   */
  getLength: function () {
    return this.get('caseTableLength');
  },

  /**
   * Returns the contents of the given row as a Case.
   *
   * If this particular row is a collapsed group indicator, returns the collapsed
   * case, which is a member of a parent or other ancestor collection. We can
   * tell, then, that the row corresponds to a collapsed group by comparing the
   * case's collection with the case table's collection.
   *
   * Signature defined by Slick Grid DataView API.
   *
   * @param row {number}
   * @returns {DG.Case}
   */
  getItem: function (row) {
    return this._rowCaseMap[row];
  },

  /**
   * Returns metadata for the selected row, if any.
   *
   * We use this API to construct collapsed rows.
   *
   * Signature defined by Slick Grid DataView API.
   *
   * @param row {number}
   * @returns {object} See slickgrid documentation.
   */
  getItemMetadata: function (row) {
    function computeProtoRowMetadata(columns) {
      var metadata = {};
      columns.forEach(function (column) {
        var attr = column.attribute;
        var focusable = attr? !attr.hasFormula() : column.focusable;
        metadata[column.id] = {
          id: column.id,
          focusable: focusable
        };
      });
      return {
        cssClasses: 'dg-proto-row',
        columns: metadata
      };
    }
    var myCase = this.getItem(row);
    if (myCase && (myCase instanceof DG.Case)) {
      if (myCase.collection.get('id') !== this.collection.get('id') ) {
        return {
          cssClasses: 'dg-collapsed-row',
          columns: {
            0: {
              colspan: "*"
            }
          },
          formatter: function (row, cell, cellValue, colInfo, rowItem) {
            var caseCount = this.subcaseCount(this._rowCaseMap[row]);
            var nonemptyCaseCount = this.subcaseCount(this._rowCaseMap[row], true);
            var hasEmptyCases = !!(caseCount-nonemptyCaseCount);
            var setName = hasEmptyCases
                ?this.context.getCaseNameForCount(this.collection, nonemptyCaseCount)
                :this.context.getCaseNameForCount(this.collection, caseCount);
            return hasEmptyCases?
                "DG.CaseTable.closedGroup.summary-nonempty".loc(nonemptyCaseCount, setName):
                "DG.CaseTable.closedGroup.summary".loc(caseCount, setName);
          }.bind(this)
        };
      }
      else if (myCase.get('isEmpty')) {
        return {
          cssClasses: 'dg-empty-case-row'
        };
      }
    }
    else {
      return computeProtoRowMetadata(this.adapter.gridColumns);
    }
  },

  /*
   * To support creating new cases in the case table, we introduce the notion
   * of a proto-case which mocks some of the methds of DG.Case and can contain
   * a number of attribute/value pairs until the proto-case gets committed at
   * which point its values are transferred to a real case. Because there can
   * be multiple data sets, each collection can have its own proto-case.
   */
  getProtoCase: function(collection) {
    if (!collection) collection = this.get('collection');
    var collectionID = collection && collection.get('id'),
        protoCase = collectionID && this._protoCases[collectionID];
    if (!collectionID) return null;
    if (!protoCase) {
      // Proto-case is an SC.Object rather than a DG.Case.
      // Proto-case can be tested for explicitly via _isProtoCase property,
      // or in the negative by `item instanceof DG.Case` being false.
      protoCase = this._protoCases[collectionID] = SC.Object.create({
        id: Math.pow(2, 32) - collectionID,

        collection: collection,

        _isProtoCase: true,

        // id of case in this collection which proto-case should be before
        beforeCaseID: null,

        // id of parent case in next-level collection; defaults to null,
        // which is interpreted as last case in next-level collection
        parentCaseID: null,

        children: [],

        _values: null,

        init: function() {
          arguments.callee.base.apply(this,arguments);
          this._values = {};
        },

        getStrValue: function(columnID) {
          var value = this._values[columnID];
          return DG.isDate(value)
                    ? DG.formatDate(value)
                    : value;
        },

        getValue: function(columnID) {
          return this._values[columnID];
        },

        setValue: function(columnID, value) {
          this._values[columnID] = value;
        }
      });
    }
    return protoCase;
  },

  /**
   * Resets the data entry rows (proto-cases) to their default location
   * at the bottom of the table.
   *
   * If iParentCaseID is specified, then only resets data entry rows
   * associated with that particular parent case.
   */
  resetProtoCases: function (iParentCaseID) {
    // collapsing a group with the entry row moves the entry row to its default location
    DG.ObjectMap.forEach(this._protoCases, function(collectionID, protoCase) {
      if (!iParentCaseID || (protoCase.get('parentCaseID') === iParentCaseID)) {
        protoCase.set('beforeCaseID', null);
        protoCase.set('parentCaseID', null);
      }
    });
  },

  /**
   * Resets this object in response to state changes such as:
   *   expand or collapse of a case, addition or deletion of a case.
   *
   * Method signature matches method of Slick Grid default DataView.
   */
  refresh: function () {
    // returns an array of this collection and its ancestor collections.
    function makeCollections(iCollection) {
      var arr = [];
      var col = iCollection;
      var colID;
      while ( col ) {
        arr.push(col);
        colID = col.getParentCollectionID();
        if (!SC.none(colID)) {
          col = context.getCollectionByID(colID);
        } else {
          col = null;
        }
      }
      return arr.reverse();
    }
    // recursively visits a set of nodes assembling a row index to case mapping.
    function visit(nodes, level) {
      nodes.forEach(function (node) {
        if (level === collections.length - 1) {
          rowCaseIndex.push(node);
        } else {
          if (model.isCollapsedNode(node)) {
            rowCaseIndex.push(node);
          } else {
            visit(node.get('children'), level + 1);
          }
        }
      });
    }

        // ---- BEGIN ----
    if (this.get('suspended')) {
      this.set('refreshNeeded', true);
      return;
    }
    var beforeCount = this._rowCaseMap.length;
    var rowCaseIndex = [];
    var myCollection = this.collection;
    var context = this.context;
    var model = this.model;
    var collections = makeCollections(myCollection);
    visit(collections[0].casesController, 0);
    this._rowCaseMap = rowCaseIndex;
    if (this.getPath('adapter.isCollectionReorgAllowed')) {
      // add proto-case to support data entry row
      var protoCase = this.getProtoCase(myCollection);
      var protoCaseBeforeID = protoCase.get('beforeCaseID');
      var protoCaseParentID = protoCase.get('parentCaseID');
      var protoCaseIndex = -1;
      if (protoCaseBeforeID) {
        this._rowCaseMap.forEach(function(aCase, i) {
          if (aCase.getPath('id') === protoCaseBeforeID) {
            protoCaseIndex = i;
          }
        });
      }
      if ((protoCaseIndex < 0) && protoCaseParentID) {
        this._rowCaseMap.forEach(function(aCase, i) {
          if (aCase.getPath('parent.id') === protoCaseParentID) {
            protoCaseIndex = i + 1;
          }
        });
      }
      if (protoCaseIndex >= 0) {
        this._rowCaseMap.splice(protoCaseIndex, 0, protoCase);
      }
      else {
        this._rowCaseMap.push(protoCase);
      }
    }
    if (this._rowCaseMap.length !== beforeCount) {
      this.onRowCountChanged.notify({previous: beforeCount, current: this._rowCaseMap.length}, null, this);
    }
    else {
      this.onRowsChanged.notify({rows: null}, null, this);
    }
    this.set('refreshNeeded', false);
  },

  /**
   * Event handler fired when Row data changes.
   *
   * Initialized in init to avoid issues resolving slickgrid library.
   *
   * Method signature matches method of Slick Grid default DataView.
   */
  onRowsChanged: null,

  /**
   * Event handler fired when row count changes.
   *
   * Initialized in init to avoid issues resolving slickgrid library.
   *
   * Method signature matches method of Slick Grid default DataView.
   */
  onRowCountChanged: null,


  /**
   * Called before a sequence of operations to avoid premature refreshes.
   *
   * Method signature matches method of Slick Grid default DataView.
   */
  beginUpdate: function () {
    this.set('suspended', true);
  },

  /**
   * Called at the end of a sequence of operations.
   *
   * Invokes refresh if necessary.
   *
   * Method signature matches method of Slick Grid default DataView.
   */
  endUpdate: function () {
    this.set('suspended', false);
    if (this.get('refreshNeeded')) {
      this.refresh();
    }
  },

  /**
   * No-op
   *
   * Method signature matches method of Slick Grid default DataView.
   */
  setItems: function (arr) {},

  /** Unsupported
   *
   * Method signature matches method of Slick Grid default DataView.
   *
   * @returns {null}
   */
  //getItems: function () {
  //  return this.collection.casesController;
  //},

  /**
   * Searches for an item by its id.
   *
   * Method signature matches method of Slick Grid default DataView.
   */
  getItemById: function (id) {
    return this.collection.getCaseByID(id);
  },

  /**
   * Returns the case index of a case by id.
   *
   * Method signature matches method of Slick Grid default DataView.
   * @param id
   * @returns {*|number|undefined}
   */
  getIdxById: function (id) {
    return this.collection.getCaseIndexByID(id);
  },

  /**
   * Gets the index of the case table row, given a case (or proto-case) id.
   *
   * Method signature matches method of Slick Grid default DataView.
   *
   * Note that a case that is part of a collapsed group is not considered
   * to be a part of the case table.
   *
   * @param iCaseID {number}
   * @returns {Number}
   */
  getRowById: function (iCaseID) {
    return this._rowCaseMap
            .findIndex(function(rowCase) {
              // allow number/string matches
              return rowCase && (rowCase.get('id') == iCaseID); // eslint-disable-line eqeqeq
            });
  },

  /**
   * No-op
   *
   * Method signature matches method of Slick Grid default DataView.
   */
  insertItem: function (item) {},

  /**
   * No-op
   *
   * Method signature matches method of Slick Grid default DataView.
   */
  addItem: function (item) {},

  /**
   * Called for updateCase.
   *
   * We simply refresh.
   * TODO: consider refreshing only if the item is visible.
   *
   * Method signature matches method of Slick Grid default DataView.
   */
  updateItem: function (id, item) {
    this.refresh();
  },

  /**
   * No-op
   *
   * Method signature matches method of Slick Grid default DataView.
   */
  setGrouping: function (obj) {},

  /**
   * Marks the identified case as collapsed.
   *
   * Method signature matches method of Slick Grid default DataView.
   * @param iCaseID {number}
   */
  collapseGroup: function (iCaseID) {
    var myCase = DG.store.find('DG.Case', iCaseID);
    if (myCase) {
      this.model.collapseNode(myCase);
    }
  },

  /**
   * Marks the identified case as expanded.
   *
   * Method signature matches method of Slick Grid default DataView.
   * @param iCaseID {number} A case id.
   */
  expandGroup: function (iCaseID) {
    var myCase = DG.store.find('DG.Case', iCaseID);
    if (myCase) {
      this.model.expandNode(myCase);
    }
  },

  /**
   * Whether the indicated node is collapsed.
   *
   * Method signature matches method of Slick Grid default DataView.
   *
   * @param iCaseID {number} A case id.
   * @returns {boolean}
   */
  isGroupCollapsed: function (iCaseID) {
    var myCase = this.collection.getCaseByID(iCaseID);
    if (myCase) {
      return this.model.isCollapsedNode(myCase);
    }
  },

  /**
   * No-op
   *
   * Method signature matches method of Slick Grid default DataView.
   */
  setRefreshHints: function (obj) {},

  /**
   * A property defining the expand and collapsed counts for this collection.
   *
   * Used for determining the state of the expand all/collapse all buttons.
   */
  expandCollapseCounts: function () {
    var model = this.model;
    var counts = {
      expanded: 0,
      collapsed: 0
    };
    this.collection.casesController.forEach(function (myCase) {
      if (model.isCollapsedNode(myCase)) {
        counts.collapsed += 1;
      } else {
        counts.expanded += 1;
      }
    });
    return counts;
  }.property(),

  /**
   * Counts the cases at this level of the case table hierarchy which descend
   * from the given case.
   *
   * Used for creating a collapsed row message.
   *
   * @param iCase
   * @returns {number}
   */
  subcaseCount: function (iCase, deductEmpty) {
    var count = 0;
    if (iCase.collection.id === this.collection.get('id')) {
      count = 1;
    } else {
      iCase.children.forEach(function (myCase) {
        if (!deductEmpty || !myCase.get('isEmpty')) {
          count += this.subcaseCount(myCase);
        }
      }.bind(this));
    }
    return count;
  }
});

/* >>>>>>>>>> BEGIN source/components/case_table/case_table_drag_helpers.js */
// ==========================================================================
//                        DG.CaseTableOwnAttributeDragHelper
//                        DG.CaseTableForeignAttributeDragHelper
//
//  One of these helpers gets created during an attribute drag operation
//
//  Author:   William Finzer
//
//  Copyright (c) 2020 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class
    A CaseTableDragHelper is the base class for the two kinds of helpers
 @extends SC.Object
 */
DG.CaseTableDragHelper = SC.Object.extend((function () // closure
    /** @scope DG.CaseTableDragHelper.prototype */ {

  return {  // return from closure

    /**
     * @property {DG.CaseTableView}
     */
    caseTableView: null,

    dragInfo: null,

    dataObject: null,

    /**
     * @property {DG.TipView}
     */
    tipView: null,

    tipString: null,

    init: function() {
      arguments.callee.base.apply(this,arguments);
      this.tipView = DG.mainPage.getPath('mainPane.tipView');
    },

    destroy: function () {
      this.caseTableView = null;
      this.tipView = null;
      arguments.callee.base.apply(this,arguments);
    },

    computeDragOperations: function (iDrag) {
      if (this.isValidAttribute(iDrag))
        return SC.DRAG_LINK;
      else
        return SC.DRAG_NONE;
    },

    dragStarted: function (iDrag) {
      this.set('dataObject', iDrag.data);
    },

    dragEnded: function () {
      this.set('dataObject', null);
    },

    dragEntered: function (iDragObject, iEvent) {
    },

    removeHighliting: function() {
      if (this.dragInfo) {
        this.caseTableView.$(this.dragInfo.headerNode)
            .removeClass(this.dragInfo.highliteClass);
      }
      this.get('tipView').hide();
    },

    acceptDragOperation: function (drag, op) {
      $('.sc-ghost-view').hide();
      var $dragTarget = $(document.elementFromPoint(drag.location.x, drag.location.y));//$(drag.event.target);
      var isOverHeader = $dragTarget.parents('.slick-header').length > 0;
      $('.sc-ghost-view').show();
      if (!isOverHeader) {
        this.removeHighliting();
      }
      return isOverHeader;
    },

    /**
     *
     * @param location{{x:number, y:number}}
     */
    updateHighliting: function (location) {
      var tParentView = this.caseTableView.parentView,
          slickGrid = tParentView._slickGrid,
          newDragInfo = this._computeDragInfo(slickGrid, location);

      if (newDragInfo) {
        newDragInfo.headerNode = (newDragInfo.columnIndex >= 0)
            && this.caseTableView.$('.slick-header-column',
                slickGrid.getHeaderRow())[newDragInfo.columnIndex];

        // if unchanged, we are done
        if (this.dragInfo &&
            (this.dragInfo.columnIndex === newDragInfo.columnIndex)
            && (this.dragInfo.nearerBound === newDragInfo.nearerBound)) {
          return;
        }
      }
      this.removeHighliting();
      this.dragInfo = newDragInfo;
      if (this.dragInfo) {
        this.dragInfo.highliteClass = this.highliteClassFor( this.dragInfo);
        this.caseTableView.$(this.dragInfo.headerNode).addClass(this.dragInfo.highliteClass);
        var tTipString = this.get('tipString');
        if( tTipString) {
          var tCellBox = slickGrid.getCellNodeBox(0, this.dragInfo.columnIndex),
              tBoxHeight = tCellBox.bottom - tCellBox.top,
              tTopLeft = DG.ViewUtilities.viewToWindowCoordinates(
                  {x: tCellBox.left, y: tCellBox.bottom + tBoxHeight}, this.caseTableView);
          this.get('tipView').show(tTopLeft, tTipString);
        }
      }
    },

    dragUpdated: function (iDragObject, iEvent) {
      this.updateHighliting(iDragObject.location);
    },

    dragExited: function (iDragObject, iEvent) {
      this.removeHighliting();
      this.dragInfo = null;
    },

    performDragOperation: function (iDragObject, iDragOp) {
      this.removeHighliting();
      var dragData = iDragObject.data;
      this._performDragOperation(dragData);
    }

  };
})()); // end closure

/** @class
    A CaseTableOwnAttributeDragHelper helps when the attribute being dragged is one of the attributes
 belonging to the table's data context.
 @extends DG.CaseTableDragHelper
 */
DG.CaseTableOwnAttributeDragHelper = DG.CaseTableDragHelper.extend((function () // closure
    /** @scope DG.CaseTableOwnAttributeDragHelper.prototype */ {

  return {

    highliteClassFor: function( iDragInfo) {
      return 'drag-insert-' + iDragInfo.nearerBound;
    },

    _performDragOperation: function (dragData) {
      var attr = dragData.attribute;
      var position;
      // if we have an insert point, then we initiate the move.
      // Otherwise we ignore the drop.
      if (this.dragInfo) {
        position = (this.dragInfo.nearerBound === 'right')
            ? this.dragInfo.columnIndex + 1
            : this.dragInfo.columnIndex;
        this.caseTableView.parentView.gridAdapter.requestMoveAttribute(attr, position);
      }
    },

    isValidAttribute: function (iDrag) {
      var tDragAttr = iDrag.data.attribute;
      return !SC.none(tDragAttr)
          && this.caseTableView.parentView.gridAdapter.canAcceptDrop(iDrag.data.attribute);
    },

    /**
     *
     * @param slickGrid
     * @param location {{x:number,y:number}}
     * @return {{columnIndex: number, nearerBound: string}|{columnIndex: *, nearerBound: string}}
     * @private
     */
    _computeDragInfo: function (slickGrid, location) {
      var gridPosition = slickGrid.getGridPosition(),
          headerRowHeight = slickGrid.getOptions().headerRowHeight,
          // compute cursor location relative to grid
          loc = {x: location.x - gridPosition.left, y: location.y - gridPosition.top},
          locX = loc.x,
          inHeader = loc.y < headerRowHeight,
          newDragInfo = null;
      if (inHeader) {
        var columnDefs = slickGrid.getColumns(),
            x = 0,
            colMiddle,
            colWidth,
            // Find the column with the closest boundary to locX. That is,
            // find the first column index whose midpoint is greater than locX.
            // If we don't find it, then the last column must be it.
            columnIndex = columnDefs.findIndex(function (def, ix, defs) {
              var result = false;
              colWidth = def.width || 0;
              colMiddle = x + (colWidth / 2);
              // skip row index
              if (ix > 0 && locX < colMiddle) {
                result = true;
              }
              x += colWidth;
              return result;
            });

        if (columnIndex >= 0) {
          newDragInfo = {
            columnIndex: columnIndex,
            nearerBound: 'left'
          };
        } else {
          newDragInfo = {
            columnIndex: columnDefs.length - 1,
            nearerBound: 'right'
          };
        }
      }
      return newDragInfo;
    }
  };
})()); // end closure

/** @class
    A CaseTableForeignAttributeDragHelper helps when the attribute being dragged belongs to a foreign
 data context.
 @extends DG.CaseTableDragHelper
 */
DG.CaseTableForeignAttributeDragHelper = DG.CaseTableDragHelper.extend((function () // closure
    /** @scope DG.CaseTableForeignAttributeDragHelper.prototype */ {

  return {

    highliteClassFor: function( iDragInfo) {
      return 'drag-hover';
    },

    /**
     * @property {string | null}
     */
    tipString: function() {
      var tResult = null,
          tDataObject = this.get('dataObject');
      if( tDataObject) {
        var tSourceKeyAttributeName = tDataObject.attribute.get('name'),
            tSourceCollectionName = tDataObject.collection.get('name'),
            tSourceContextName = tDataObject.context.get('name'),
            tGridAdapter = this.caseTableView.parentView.gridAdapter,
            tDestCollectionName = tGridAdapter && tGridAdapter.getPath('collection.name'),
            tDestContextName = tGridAdapter && tGridAdapter.getPath('dataContext.name'),
            tDestKeyAttributeName = tGridAdapter &&
                tGridAdapter.getAttributeFromColumnIndex(this.dragInfo.columnIndex).get('name');
        tResult = "DG.Collection.joinTip".loc(tSourceCollectionName,
            tSourceContextName, tDestCollectionName, tDestContextName,
            tSourceKeyAttributeName, tDestKeyAttributeName);
      }
      return tResult;
    }.property(),

    /**
     * We will define as many new attributes for each of the attributes in the foreign collection except
     *    the one being dragged.
     * The attribute being dragged will function as the "key attribute" in the "other dataset".
     * The attribute for the column we are on top of will be the "key value attribute."
     * The formula we will be writing will look like:
     *    lookupByKey("other dataset name", "name of attribute from other collection whose value we want",
     *                "name of key attribute", key value attribute)
     * @param dragData
     * @private
     */
    _performDragOperation: function (dragData) {
      var tKeyAttribute = dragData.attribute,
          tGridAdapter = this.caseTableView.parentView.gridAdapter,
          tThisContext = tGridAdapter && tGridAdapter.get('dataContext'),
          tThisCollection = tGridAdapter && tGridAdapter.get('collection'),
          tKeyValueAttribute = tGridAdapter && tGridAdapter.getAttributeFromColumnIndex(this.dragInfo.columnIndex);
      if( tKeyAttribute && tKeyValueAttribute && tThisContext) {
        DG.DataContextUtilities.joinSourceToDestCollection( tKeyAttribute, tThisContext,
            tThisCollection, tKeyValueAttribute);
      }
    },

    /**
     * If we've gotten here we can be sure our table view's context does not own the attribute.
     * We just need to make sure the attribute exists and has a collection.
     * @param iDrag
     * @return {boolean|*}
     */
    isValidAttribute: function (iDrag) {
      var tDragAttr = iDrag.data.attribute;
      return !SC.none(tDragAttr)
          && tDragAttr && tDragAttr.collection;
    },
    /**
     *
     * @param slickGrid
     * @param location {{x:number,y:number}}
     * @return {{columnIndex: number, nearerBound: string}|{columnIndex: *, nearerBound: string}}
     * @private
     */
    _computeDragInfo: function (slickGrid, location) {
      var gridPosition = slickGrid.getGridPosition(),
          headerRowHeight = slickGrid.getOptions().headerRowHeight,
          // compute cursor location relative to grid
          loc = {x: location.x - gridPosition.left, y: location.y - gridPosition.top},
          locX = loc.x,
          inHeader = loc.y < headerRowHeight,
          newDragInfo = null;
      if (inHeader) {
        var columnDefs = slickGrid.getColumns(),
            x = 0,
            colWidth,
            // Find the column with the closest boundary to locX. That is,
            // find the first column index whose midpoint is greater than locX.
            // If we don't find it, then the last column must be it.
            columnIndex = columnDefs.findIndex(function (def, ix, defs) {
              var result = false;
              colWidth = def.width || 0;
              // skip row index
              if (ix > 0 && locX < x + colWidth) {
                result = true;
              }
              x += colWidth;
              return result;
            });

        if (columnIndex >= 0) {
          newDragInfo = {
            columnIndex: columnIndex,
          };
        } else {
          newDragInfo = {
            columnIndex: columnDefs.length - 1,
          };
        }
      }
      return newDragInfo;
    }

  };
})()); // end closure

/**
 *
 * @param iTableView {DG.CaseTableView}
 * @param iDrag
 * @return {DG.CaseTableDragHelper || null}
 */
DG.CaseTableDragHelper.createHelper = function (iTableView, iDrag) {
  var tAttribute = iDrag.data.attribute,
      tContext = iTableView.parentView.gridAdapter && iTableView.parentView.gridAdapter.get('dataContext'),
      tAttributeCollection = tAttribute && tAttribute.collection,
      tContextOwnsAttribute = !!(tAttribute && tContext &&
          !SC.none(tContext.getCollectionByID(tAttributeCollection.id)));
  return tContextOwnsAttribute ?
      DG.CaseTableOwnAttributeDragHelper.create({caseTableView: iTableView}) :
      (tAttributeCollection ?
          DG.CaseTableForeignAttributeDragHelper.create({caseTableView: iTableView}) :
          null);
};
/* >>>>>>>>>> BEGIN source/components/case_table/case_table_drop_target.js */
// ==========================================================================
//  
//  Author:   jsandoe
//
//  Copyright (c) 2015 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
/**
 * @class  DG.CaseTableDropTarget
 */
DG.CaseTableDropTarget = SC.View.extend(SC.SplitChild, (function () {

      return {
        /**
         * An arbitrary name
         * @type {String}
         */
        name: null,

        /**
         * The data context defining the valid attributes for a drop.
         * @type {DG.DataContext}
         */
        dataContext: null,

        /**
         * @type {[string]}
         */
        classNames: 'dg-table-drop-target'.w(),

        /**
         * @type {Object}
         */
        layout: { width: 50 },

        /**
         * Is the top-level drop target
         * @type {Boolean}
         */
        isTopLevel: false,

        /**
         * This is a drop target.
         * @type {boolean}
         */
        isDropTarget: function () {
          return YES;
        }.property(),

        /**
         * Drop is disabled if any of the following are true
         *   (a) the dataContext prevents the drop
         *   (b) the dragged attribute is from another dataContext,
         *   (c) the plugin prevents the drop
         * see DG.DataContextUtilities.canAcceptDrop() for details
         */
        isDropEnabled: function () {
          var dragAttribute = this.get('dragAttribute');
          var isTopLevelDrop = this.get('isTopLevel');
          return DG.DataContextUtilities
                    .canAcceptAttributeDrop(this.dataContext, dragAttribute, isTopLevelDrop);
        }.property('dragAttribute'),

        isDropEnabledDidChange: function () {
          this.notifyPropertyChange('isDropEnabled');
        }.observes('*dataContext.hasDataInteractive'),

        /**
         * @type {DG.Attribute|null}
         */
        dragAttribute: null,

        /**
         * Whether drag is in progress
         * @type {boolean}
         */
        isDragInProgress: false,

        /**
         * Whether drag has entered this view
         * @type {boolean}
         */
        isDragEntered: false,
        minimumSize: 10,
        size: 30,


        dropData: null,

        childViews: 'labelView'.w(),

        classNameBindings: [
          'isDragInProgress:dg-table-drop-target-show',
          'isDragEntered:dg-table-drop-target-highlight'
        ],

        labelView: SC.LabelView.extend({
          value: '',
          layout: {
            left: 2, right: 2, top: 2, bottom: 2
          }
        }),

        showDropHint: function () {
          this.set('isDragEntered', true);
          this.labelView.set('value', 'DG.CaseTableDropTarget.dropMessage'.loc());
        },

        hideDropHint: function () {
          this.labelView.set('value', '');
          this.set('isDragEntered', false);
        },

        extractDragInfo: function( iDrag) {
          if (iDrag && iDrag.data ) {
            this.set('dragAttribute', iDrag.data.attribute);
          }
        },

        /**
         * Adjustments needed to accommodate shared embedded mode CODAP
         * @override View.convertFrameToView
         **/
        convertFrameToView: function (frame, targetView) {
          var tOffset = $(this.containerLayer()).offset();
          return { x: tOffset.left - window.pageXOffset, y: tOffset.top - window.pageYOffset, width: frame.width, height: frame.height };
        },

        computeDragOperations: function( iDrag) {
          this.extractDragInfo( iDrag);
          if( this.get('isDropEnabled'))
            return SC.DRAG_LINK;
          else
            return SC.DRAG_NONE;
        },

        dragStarted: function( iDrag) {
          this.extractDragInfo(iDrag);
          if (this.get('isDropEnabled')) {
            this.set('isDragInProgress', true);
          }
        },

        dragEnded: function () {
          this.set('dragAttribute', null);
          this.set('isDragInProgress', false);
        },

        dragEntered: function( iDragObject, iEvent) {
          if (this.get('isDropEnabled')) {
            this.showDropHint();
          }
        },

        dragExited: function( iDragObject, iEvent) {
          this.hideDropHint();
        },

        acceptDragOperation: function() {
          return this.get('isDropEnabled');
        },

        performDragOperation:function ( iDragObject, iDragOp ) {
          this.hideDropHint();
          this.set('dropData', iDragObject.data);
        },

        /**
         * These methods -- dataDragEntered, dataDragHovered, dataDragDropped,
         * and dataDragExited -- support drags initiated outside the page,
         * specifically drags from plugins.
         */
        _externalDragObject: function () {
          var data = DG.mainPage.getPath('mainPane.dragAttributeData');
          if (data && data.context === this.get('dataContext')) {
            return {
              data: data
            };
          }
        }.property(),

        externalDragDidChange: function () {
          var tDrag = this.get('_externalDragObject');
          if (!tDrag) {
            return;
          }
          if (DG.mainPage.getPath('mainPane._isDraggingAttr')) {
            this.dragStarted(tDrag);
          } else {
            this.dragEnded();
          }
        }.observes('DG.mainPage.mainPane._isDraggingAttr'),

        dataDragEntered: function (iEvent) {
          var externalDragObject = this.get('_externalDragObject');
          if (externalDragObject) {
            this.dragEntered(null, externalDragObject);
            iEvent.preventDefault();
          }
        },
        dataDragHovered: function (iEvent) {
          var externalDragObject = this.get('_externalDragObject');
          if (externalDragObject ) {
            iEvent.dataTransfer.dropEffect = 'copy';
            iEvent.preventDefault();
            iEvent.stopPropagation();
          } else {
            return false;
          }
        },
        dataDragDropped: function(iEvent) {
          var externalDragObject = this.get('_externalDragObject');
          if (externalDragObject) {
            var data = DG.mainPage.getPath('mainPane.dragAttributeData');
            this.set('dropData', data);
            iEvent.preventDefault();
          } else {
            return false;
          }
        },
        dataDragExited: function (iEvent) {
          var externalDragObject = this.get('_externalDragObject');
          if (externalDragObject) {
            this.dragExited(null, externalDragObject);
            iEvent.preventDefault();
          }
        },
        click: function () {
          DG.globalEditorLock.commitCurrentEdit();

          var tComponentView = DG.ComponentView.findComponentViewParent( this);
          var dataContext = this.get('dataContext');
          var tChange = {
            operation: 'selectCases',
            cases: [],
            select: true,
            extend: false
          };
          if (tComponentView && !tComponentView.get('isSelected')) {
            tComponentView.select();
            return NO;
          }
          dataContext.applyChange(tChange);
        },
        touchStart: function() {
          return YES;
        },
        touchEnd: function(evt) {
          evt.allowDefault();
          return YES;
        },
        mouseDown: function () {
          return YES;
        }
      };
    }())
);

/* >>>>>>>>>> BEGIN source/components/case_table/case_table_model.js */
// ==========================================================================
//
//  Author:   jsandoe
//
//  Copyright (c) 2015 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/case_table/data_context_base_model');

/** @class  DG.CaseTableModel - The model for a case table.

 @extends DG.DataContextBaseModel
 */
DG.CaseTableModel = DG.DataContextBaseModel.extend(/** @scope DG.CaseTableModel.prototype */ {
  /**
   * Attribute widths as requested by the user, keyed by attribute id.
   *
   * @property {Object} a hash of widths (pixels) keyed by attribute id.
   */
  preferredAttributeWidths: null,

  /**
   * Case table widths as requested by the user, keyed by caseTable id.
   *
   * @property {Object} a hash of widths (pixels) keyed by caseTable id.
   */
  // preferredTableWidths: null,

  /**
   * Case table row heights as requested by the user, keyed by collection id.
   *
   * @property {Object} a hash of row heights (pixels) keyed by collection id.
   */
  tableRowHeights: null,

  /**
   * A hash of case ids and their collapsed state and whether they are visible
   * or superseded by a collapsed case in a higher order table.
   * @type [{{isCollapsed: boolean, isHidden: boolean, collapsedCase: DG.Case}}]
   */
  _collapsedNodes: null,

  /**
   * @type {number}
   */
  horizontalScrollOffset: 0,

  /**
   * @type {boolean}
   */
  isIndexHidden: false,

  init: function () {
    arguments.callee.base.apply(this,arguments);
    this.preferredAttributeWidths = this.preferredAttributeWidths || {};
    // this.preferredTableWidths = this.preferredTableWidths || {};
    this.tableRowHeights = this.tableRowHeights || {};
    this._collapsedNodes = this._collapsedNodes || {};
  },

  getPreferredAttributeWidth: function (attrID) {
    return this.preferredAttributeWidths[attrID];
  },

  setPreferredAttributeWidth: function(attrID, width) {
    this.preferredAttributeWidths[attrID] = width;
  },

  getTableRowHeight: function(collectionId) {
    return this.tableRowHeights[collectionId];
  },

  setTableRowHeight: function(collectionId, rowHeight) {
    this.tableRowHeights[collectionId] = rowHeight;
  },

  didDeleteCases: function (iCases) {
    if (iCases) {
      iCases.forEach(function (iCase) {
        var id = iCase.get('id');
        delete this._collapsedNodes[id];
      }.bind(this));
    }
  },

  /**
   * Whether node is collapsed and not hidden by another collapsed node.
   * @param iCase {DG.Case}
   * @returns {*|boolean}
   */
  isCollapsedNode: function (iCase) {
    return (this._collapsedNodes[iCase.id] && !this.isHiddenNode(iCase));
  },

  /**
   * Whether the case is within a collapsed node.
   * @param iCase {DG.Case}
   */
  isHiddenNode: function (iCase) {
    var parent = iCase.get('parent');
    if (parent) {
      if (this._collapsedNodes[parent.id]) {
        return true;
      } else {
        return this.isHiddenNode(parent);
      }
    } else {
      return false;
    }
  },

  /**
   * Marks a case as collapsed. In subordinate case tables the group of cases
   * descending from this case will appear only in summary.
   *
   * Will mark any collapsed cases that are descendents as hidden. The fact of
   * their collapsed state will be retained, but will have no effect unless this
   * case is expanded again.
   *
   * @param iCase {DG.Case}
   */
  collapseNode: function(iCase) {
    if (iCase) {
      this._collapsedNodes[iCase.id] = true;
    }
  },

  /**
   * Marks a case as not collapsed.
   *
   * Will reset any hidden collapsed cases to their correct state.
   *
   * @param iCase {DG.Case}
   */
  expandNode: function (iCase) {
    delete this._collapsedNodes[iCase.id];
  },

  /**
   * Returns an array of case IDs corresponding to collapsed nodes whether hidden or not.
   */
  collapsedNodes: function () {
    var key;
    var rtn = [];
    for(key in this._collapsedNodes) {
      if (this._collapsedNodes.hasOwnProperty(key)) {
        rtn.push(key);
      }
    }
    return rtn;
  }.property()

});

/* >>>>>>>>>> BEGIN source/components/case_table/case_table_row_selection_model.js */
// ==========================================================================
//
//  Author:   jsandoe
//
//  Copyright (c) 2016 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
//
// This file borrows significantly from the Slickgrid plugin,
// slick.rowselectionmodel.js. It implements CODAP-specific adjustments to this
// plugin to integrate CODAP and Slickgrid selection models.
//
/* global Slick */
DG.CaseTableRowSelectionModel = function (options) {
  var _grid;
  var _caseTableAdapter;
  var _gridDataView;
  var _ranges = [];
  var _self = this;
  var _handler = new Slick.EventHandler();
  var _inHandler;
  var _options;
  var _dragStartRow;
  var _dragStartY = null;
  var _dragStartClientX = null;
  var _dragStartClientY = null;
  var _dragClientY = null;
  var _dragInputRow = null;
  var _dragInputBounds = null;
  var _gridViewport = null;
  var _gridViewportBounds = null;
  var _dragInputRowClone = null;
  var _dragInputRowTargets = null;
  var _topAutoScrollTimer = null;
  var _bottomAutoScrollTimer = null;
  var kAutoScrollMargin = 20;
  var kAutoScrollInterval = 100;

  var _defaults = {
    selectActiveRow: true
  };

  function init(grid) {
    _options = $.extend(true, {}, _defaults, options);
    _caseTableAdapter = _options.caseTableAdapter;
    _gridDataView = _caseTableAdapter.gridDataView;
    _grid = grid;
    // _handler.subscribe(_grid.onActiveCellChanged,
    //     wrapHandler(handleActiveCellChange));
    _handler.subscribe(_grid.onKeyDown, wrapHandler(handleKeyDown));
    _handler.subscribe(_grid.onClick, wrapHandler(handleClick));
    _handler.subscribe(_grid.onDragInit, wrapHandler(handleDragInit));
    _handler.subscribe(_grid.onDragStart, wrapHandler(handleDragStart));
    _handler.subscribe(_grid.onDrag, wrapHandler(handleDrag));
    _handler.subscribe(_grid.onDragEnd, wrapHandler(handleDragEnd));
  }

  function destroy() {
    _handler.unsubscribeAll();
  }

  function notifyContextOfSelectionChange(rows) {
    SC.run(function () {
      _caseTableAdapter.selectRowsInList(rows);
    });
  }

  function wrapHandler(handler) {
    return function () {
        var result;
        if (!_inHandler) {
          _inHandler = true;
          result = handler.apply(this, arguments);
          _inHandler = false;
          return result;
        }
    };
  }

  function rangesToRows(ranges) {
    var rows = [];
    for (var i = 0; i < ranges.length; i++) {
      for (var j = ranges[i].fromRow; j <= ranges[i].toRow; j++) {
        rows.push(j);
      }
    }
    return rows;
  }

  function rowsToRanges(rows) {
    var ranges = [];
    var lastCell = _grid.getColumns().length - 1;
    for (var i = 0; i < rows.length; i++) {
      ranges.push(new Slick.Range(rows[i], 0, rows[i], lastCell));
    }
    return ranges;
  }

  function getRowsRange(from, to) {
    var i, rows = [];
    for (i = from; i <= to; i++) {
      rows.push(i);
    }
    for (i = to; i < from; i++) {
      rows.push(i);
    }
    return rows;
  }

  function getSelectedRows() {
    return rangesToRows(_ranges);
  }

  function setSelectedRows(rows) {
    setSelectedRanges(rowsToRanges(rows));
  }

  function setSelectedRanges(ranges) {
    _ranges = ranges;
    _self.onSelectedRangesChanged.notify(_ranges);
  }

  function getSelectedRanges() {
    return _ranges;
  }

  // function handleActiveCellChange(e, data) {
  //   var selectedRows = getSelectedRows();
  //
  //   if (_options.selectActiveRow
  //       && data.row != null
  //       && (selectedRows.indexOf(data.row) < 0)) {
  //     // notifyContextOfSelectionChange([data.row]);
  //   }
  // }

  function handleKeyDown(e) {
    var editLock = _grid.getEditorLock();
    var editActive = (editLock && editLock.isActive());
    var activeCell = _grid.getActiveCell();

    var kUpArrowKeyCode = 38;
    var kDownArrowKeyCode = 40;
    var increment, currRow, numRows, newRow, newItem, selectedRows, top, bottom, active;

    // handle shift-upArrow and shift-downArrow
    // Do not handle keypress if editing or there is no active cell.
    if (!editActive && activeCell && !e.ctrlKey && !e.altKey && !e.metaKey &&
        (e.which === kUpArrowKeyCode || e.which === kDownArrowKeyCode)) {
      increment = (e.which === kUpArrowKeyCode)? -1: 1;
      currRow = activeCell.row;

      if (e.shiftKey) {
        selectedRows = getSelectedRows();
        selectedRows.sort(function (x, y) {
          return x - y;
        });

        if (!selectedRows.length) {
          selectedRows = [activeCell.row];
        }

        top = selectedRows[0];
        bottom = selectedRows[selectedRows.length - 1];

        if (e.which === kDownArrowKeyCode) {
          active = currRow < bottom || top === bottom ? ++bottom : ++top;
        } else {
          active = currRow < bottom ? --bottom : --top;
        }

        if (active >= 0 && active < _grid.getDataLength()) {
          _grid.scrollRowIntoView(active);
          notifyContextOfSelectionChange(getRowsRange(top, bottom));
        }
      } else {
        numRows = _grid.getDataLength();
        newRow = Math.min(Math.max(0, currRow + increment), numRows);
        newItem = _gridDataView.getItem(newRow);
        if (newItem._isProtoCase) newRow = currRow;
        notifyContextOfSelectionChange([newRow]);
        _grid.setActiveCell(newRow, activeCell.cell);
      }

      // e.preventDefault();
      e.stopImmediatePropagation();
    }
  }

  function handleDragInit(e) {
    if (_grid.getActiveCell()) {
      _grid.getEditorLock().commitCurrentEdit();
      _grid.focus();
    }

    e.stopImmediatePropagation();
  }

  function handleDragStart(e) {
    _caseTableAdapter.set('isModelDragging', true);
    var activeCell = _grid.getCellFromEvent(e);
    var activeCellBox = _grid.getCellNodeBox(activeCell.row, activeCell.cell);
    // We prepare for computing future drag offsets by capturing the current
    // row, its reported vertical coordinate and the 'client' coordinate.
    // These are needed to compute the current vertical position in the grid's
    // coordinate system.
    _dragStartRow = activeCell && activeCell.row;
    _dragStartY = (activeCellBox.top + activeCellBox.bottom) / 2;
    _dragStartClientX = e.clientX;
    _dragStartClientY = _dragClientY = e.clientY;
    for (var elt = e.target; elt; elt = elt.parentElement) {
      if (elt && $(elt).hasClass("dg-proto-row")) {
        _dragInputRow = elt;
        _dragInputBounds = _dragInputRow.getBoundingClientRect();
      }
      if (elt && $(elt).hasClass("slick-viewport")) {
        _gridViewport = elt;
        _gridViewportBounds = _gridViewport.getBoundingClientRect();
        break;
      }
    }
    if (_dragInputRow) {
      $(_dragInputRow).addClass('drag-source');

      _dragInputRowClone = _dragInputRow.cloneNode(true);
      $(_dragInputRowClone).addClass('drag-preview');
      $(_dragInputRowClone).find('.slick-row-resizer').remove();
      $(_gridViewport).append(_dragInputRowClone);
    }

    var selection = !_dragInputRow && activeCell && [activeCell.row];

    if (selection) {
      notifyContextOfSelectionChange(selection);
    }

    e.stopImmediatePropagation();
  }

  function nextSiblingRow(rowElt) {
    if (!rowElt) return rowElt;
    var $elt = $(rowElt);
    var rowId = $elt.data('row-id');
    var rowIndex = _gridDataView.getRowById(rowId);
    var nextRowItem = _gridDataView.getItem(rowIndex + 1);
    var nextRowId = nextRowItem && nextRowItem.get('id');
    var $next = nextRowId && $(_gridViewport).find('[data-row-id="' + nextRowId + '"]');
    if ($next && $next.hasClass('dg-collapsed-row'))
      return null;
    return $next && $next[0] || null;
  }

  function prevSiblingRow(rowElt) {
    if (!rowElt) return rowElt;
    var $elt = $(rowElt);
    var rowId = $elt.data('row-id');
    var rowIndex = _gridDataView.getRowById(rowId);
    var prevRowItem = _gridDataView.getItem(rowIndex - 1);
    var prevRowId = prevRowItem && prevRowItem.get('id');
    var $prev = prevRowId && $(_gridViewport).find('[data-row-id="' + prevRowId + '"]');
    if ($prev && $prev.hasClass('dg-collapsed-row'))
      return null;
    return $prev && $prev[0] || null;
  }

  function rowTargetsFromPoint() {
    var targets = [], prevSibling, nextSibling;
    var viewportBounds = _gridViewport.getBoundingClientRect();
    var x = _dragStartClientX, y = _dragClientY;
    y = Math.max(y, viewportBounds.top + 1);
    y = Math.min(y, viewportBounds.bottom - 1);
    var elts = isFinite(y) ? document.elementsFromPoint(x, y) : [];
    for (var ix = 0; ix < elts.length; ++ix) {
      var elt = elts[ix];
      if ($(elt).hasClass('slick-row') && !$(elt).hasClass('drag-preview')) {
        var bounds = elt.getBoundingClientRect();
        if (!$(elt).hasClass('dg-collapsed-row')) {
          if (y > (bounds.top + bounds.bottom) / 2)
            nextSibling = nextSiblingRow(elt);
          else
            prevSibling = prevSiblingRow(elt);
        }
        if (prevSibling !== undefined)
          targets.push(prevSibling);
        targets.push(elt);
        if (nextSibling !== undefined)
          targets.push(nextSibling);
        if ((prevSibling === undefined) && (nextSibling === undefined))
          targets.push(elt);
        break;
      }
    }
    return targets;
  }

  function updateRowHighlighting() {
    var i;
    var targets = rowTargetsFromPoint();
    if (_dragInputRowTargets) {
      for (i = 0; i < _dragInputRowTargets.length; ++i) {
        $(_dragInputRowTargets[i]).removeClass('drag-hilite');
      }
    }
    for (i = 0; i < targets.length; ++i) {
      $(targets[i]).addClass('drag-hilite');
    }
    _dragInputRowTargets = targets;
  }

  function adjustDragPreviewTop() {
    var yOffset = _dragStartClientY - _dragInputBounds.top;
    var newTop = _gridViewport.scrollTop + _dragClientY - _gridViewportBounds.top - yOffset;
    var viewportRows = _grid.getViewport();
    var maxVisibleRow = Math.min(viewportRows.bottom, _gridDataView.get('caseTableLength'));
    var rowHeight = _caseTableAdapter.get('rowHeight');
    newTop = Math.max(_gridViewport.scrollTop, newTop);
    newTop = Math.min(Math.max(maxVisibleRow - 1, 0) * rowHeight, newTop);
    $(_dragInputRowClone).css('top', newTop + "px");
  }

  function handleAutoScrollTop() {
    var viewportRows = _grid.getViewport();
    if (viewportRows.top > 0) {
      var newTopRow = viewportRows.top - 1;
      _grid.scrollRowIntoView(newTopRow);
      adjustDragPreviewTop();
      updateRowHighlighting();
      _topAutoScrollTimer = newTopRow > 0
                              ? setTimeout(handleAutoScrollTop, kAutoScrollInterval)
                              : null;
    }
  }

  function handleAutoScrollBottom() {
    var viewportRows = _grid.getViewport();
    var rowCount = _gridDataView.get('caseTableLength');
    if (viewportRows.bottom < rowCount) {
      var newBottomRow = viewportRows.bottom + 1;
      _grid.scrollRowIntoView(newBottomRow);
      adjustDragPreviewTop();
      updateRowHighlighting();
      _bottomAutoScrollTimer = newBottomRow < rowCount
        ? setTimeout(handleAutoScrollBottom, kAutoScrollInterval)
        : null;
    }
  }

  function handleDrag(e) {
    // Compute the active cell from the pixel offset from the starting position
    // Cannot use the target to compute the offset since, on mobile, the target
    // never varies from the original target of the drag start.
    var yOffset = _dragStartY + (e.clientY - _dragStartClientY);
    var activeCell = _grid.getCellFromPoint(0, yOffset);
    var selection;
    var ix, start, end;
    _dragClientY = e.clientY;

    // handle row selection
    if (activeCell && (_dragStartRow != null) && !_dragInputRow) {
      selection = [];
      start = Math.min(_dragStartRow, activeCell.row);
      end = Math.max(_dragStartRow, activeCell.row);
      for (ix = start; ix <= end; ix += 1) {
        selection.push(ix);
      }
      notifyContextOfSelectionChange(selection);
    }

    // handle input row drag
    else if (_dragInputRow) {
      adjustDragPreviewTop();
      updateRowHighlighting();

      // autoscroll support
      var viewportBounds = _gridViewport.getBoundingClientRect();
      var viewportRows = _grid.getViewport();
      var rowCount = _gridDataView.get('caseTableLength');
      var isInTopAutoScrollZone = e.clientY - viewportBounds.top < kAutoScrollMargin;
      if (isInTopAutoScrollZone) {
        if (!_topAutoScrollTimer && (_gridViewport.scrollTop > 0)) {
          _topAutoScrollTimer = setTimeout(handleAutoScrollTop, kAutoScrollInterval);
        }
      }
      else {
        if (_topAutoScrollTimer) {
          clearInterval(_topAutoScrollTimer);
          _topAutoScrollTimer = null;
        }

        var isInBottomAutoScrollZone = viewportBounds.bottom - e.clientY < kAutoScrollMargin;
        if (isInBottomAutoScrollZone) {
          if (!_bottomAutoScrollTimer && (viewportRows.bottom < rowCount)) {
            _bottomAutoScrollTimer = setTimeout(handleAutoScrollBottom, kAutoScrollInterval);
          }
        }
        else if (_bottomAutoScrollTimer) {
          clearInterval(_bottomAutoScrollTimer);
          _bottomAutoScrollTimer = null;
        }
      }
    }

    e.stopImmediatePropagation();
  }

  function handleDragEnd(e) {
    e.stopImmediatePropagation();

    var dataContext = _caseTableAdapter.get('dataContext');
    var targets = _dragInputRow && rowTargetsFromPoint();
    var afterRow = targets && (targets.length >= 1) && targets[0];
    var afterRowIsCollapsed = afterRow && $(afterRow).hasClass('dg-collapsed-row');
    var afterCaseID = afterRow && $(afterRow).data('row-id');
    var afterCase = dataContext && afterCaseID && dataContext.getCaseByID(afterCaseID);
    var afterCaseIsProtoCase = afterRow && $(afterRow).hasClass('dg-proto-row');
    var afterParentCase = afterRowIsCollapsed
                            ? afterCase
                            : afterCase && afterCase.get('parent');
    var afterParentCaseID = afterParentCase && afterParentCase.get('id') || null;
    var beforeRow = targets && (targets.length >= 2) && targets[1];
    var beforeRowIsCollapsed = beforeRow && $(beforeRow).hasClass('dg-collapsed-row');
    var beforeCaseID = beforeRow && $(beforeRow).data('row-id');
    var beforeCase = dataContext && beforeCaseID && dataContext.getCaseByID(beforeCaseID);
    var beforeCaseIsProtoCase = beforeRow && $(beforeRow).hasClass('dg-proto-row');
    var beforeParentCase = beforeRowIsCollapsed
                            ? beforeCase
                            : beforeCase && beforeCase.get('parent');
    var beforeParentCaseID = beforeParentCase && beforeParentCase.get('id') || null;
    var parentCaseID = afterParentCaseID || beforeParentCaseID;
    var hasSameParentCase = afterCase && beforeCase && (afterParentCaseID === beforeParentCaseID);
    var hasNoParentCase = (afterCase == null) && (beforeCase == null);
    var protoCase = _gridDataView.getProtoCase();
    if (protoCase &&
        // allow dragging between end of one group and beginning of next group
        !(afterCaseIsProtoCase && hasSameParentCase) &&
        !(beforeCaseIsProtoCase && hasSameParentCase)) {
      protoCase.set('beforeCaseID',
                    !afterRow || hasNoParentCase || hasSameParentCase || afterCaseIsProtoCase
                      ? beforeCaseID || null : null);
      protoCase.set('parentCaseID', parentCaseID || null);
      SC.run(function() {
        if (afterRowIsCollapsed)
          _gridDataView.expandGroup(afterCaseID);
        _caseTableAdapter.refresh();
        setTimeout(function() {
          var protoCaseIndex = _gridDataView.getRowById(protoCase.get('id'));
          if (protoCaseIndex)
            _grid.scrollRowIntoView(protoCaseIndex);
        }, 50);
      });
    }

    _dragStartRow = undefined;
    _dragStartY = null;
    _dragStartClientX = null;
    _dragStartClientY = null;
    _dragClientY = null;
    if (_dragInputRow) {
      $(_dragInputRow).removeClass('drag-source');
      _dragInputRow = null;
    }
    _dragInputBounds = null;
    if (_dragInputRowClone) {
      $(_dragInputRowClone).remove();
      _dragInputRowClone = null;
    }
    if (_dragInputRowTargets) {
      for (var ix = 0; ix < _dragInputRowTargets.length; ++ix) {
        $(_dragInputRowTargets[ix]).removeClass('drag-hilite');
      }
      _dragInputRowTargets = null;
    }
    if (_topAutoScrollTimer) {
      clearTimeout(_topAutoScrollTimer);
      _topAutoScrollTimer = null;
    }
    if (_bottomAutoScrollTimer) {
      clearTimeout(_bottomAutoScrollTimer);
      _bottomAutoScrollTimer = null;
    }
    _gridViewport = null;
    _gridViewportBounds = null;
    _caseTableAdapter.set('isModelDragging', false);
}

  function handleClick(e) {
    var cell = _grid.getCellFromEvent(e);
    if (!cell) return false;
    if (!_grid.canCellBeActive(cell.row, cell.cell) &&
          !_caseTableAdapter.isCellRowSelectable(cell.row, cell.cell)) {
      return false;
    }

    var selection = rangesToRows(_ranges);
    var idx = $.inArray(cell.row, selection);

    if (!e.ctrlKey && !e.shiftKey && !e.metaKey) {
      //   selection = [cell.row];
      //   notifyContextOfSelectionChange(selection);
      return false;
    }
    else if (_grid.getOptions().multiSelect) {
      if (idx === -1 && (e.ctrlKey || e.metaKey)) {
        selection.push(cell.row);
        _grid.setActiveCell(cell.row, cell.cell);
      } else if (idx !== -1 && (e.ctrlKey || e.metaKey)) {
        selection = $.grep(selection, function (o, i) {
          return (o !== cell.row);
        });
        _grid.setActiveCell(cell.row, cell.cell);
      } else if (selection.length && e.shiftKey) {
        selection.sort(function (a, b) {return a-b;});
        var first = selection[0];
        var last = selection[selection.length - 1];
        var from = Math.min(cell.row, first);
        var to = Math.max(cell.row, last);
        selection = [];
        for (var i = from; i <= to; i++) {
          selection.push(i);
        }
        _grid.setActiveCell(cell.row, cell.cell);
      }
    }

    notifyContextOfSelectionChange(selection);
    e.stopImmediatePropagation();

    return true;
  }

  $.extend(this, {
    "getSelectedRows": getSelectedRows,
    "setSelectedRows": setSelectedRows,

    "getSelectedRanges": getSelectedRanges,
    "setSelectedRanges": setSelectedRanges,

    "init": init,
    "destroy": destroy,

    "onSelectedRangesChanged": new Slick.Event()
  });
};

/* >>>>>>>>>> BEGIN source/components/case_table/scroll_animation_utility.js */
// ==========================================================================
//                          DG.ScrollAnimationUtility
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class  DG.ScrollAnimationUtility - controls the animation of a scroll bar
 * from one position to the next.

  @extends SC.Object
*/
DG.ScrollAnimationUtility = SC.Object.extend(
/** @scope DG.ScrollAnimationUtility.prototype */
{
  kAnimationTime: 1000, // milliseconds
  /**
    @type {Boolean}
  */
  isAnimating: false,

  /**
    The time that the animation started.
    @type { Number }
  */
  startTime: null,

  /**
   * The animation target.
   * @type {DG.CaseTableView}
   */
  targetView: null,

  /**
   * destroy - break loops that prevent garbage collection
   */
  destroy: function() {
    this.endAnimation();
    //this.plot = null;
    //this.axisInfoArray = null;
    //this.savedAxisInfoArray = null;
    arguments.callee.base.apply(this,arguments);
  },

  /**
   * We assume that my properties have been set to the aspects of the scroll that are to
   * be animated. If there is an animation already in progress, we end it.
   *
   */
  animate: function( targetView, iStart, iEnd) {
    var this_ = this,
        kInterval = 50, // milliseconds
        kTargetDuration = this.kAnimationTime; //milliseconds

    this.targetView = targetView;
    this.startValue = iStart;
    this.endValue = iEnd;

    // animationLoop - This function is called up to 20 times per second. With each call
    //  it moves the animation to the position appropriate for the amount of time that
    //  has passed since the animation was initiated. Note that it schedules itself using
    //  an SC.Timer until the animation is complete.
    var animationLoop = function () {
      var tCurrTime = (new Date()).valueOf(),
          tCurrProportion = (tCurrTime - this_.startTime) / kTargetDuration,
          tAnimationProportion;

      // getAnimationProportion - Return DefaultAnimationTween for the given proportion
      //  with a bit of bounds checking.
      function getAnimationProportion( iProportion) {
        if( iProportion >= 1)
          return 1;
        else
          return DG.AnimationMath.DefaultAnimationTween( iProportion);
      }

      // tween - Simple tween using iAnimationProportion
      function tween( iStart, iEnd, iAnimationProportion) {
        return iStart + iAnimationProportion * (iEnd - iStart);
      }

      tAnimationProportion = getAnimationProportion( tCurrProportion);

      this_.get('targetView').scrollToRow(tween(this_.startValue, this.endValue, tAnimationProportion));

      if( tCurrProportion < 1) {
        DG.assert( !this_.animationTimer.get( 'isPaused'));
      }
      else {
        this_.endAnimation();
      }
    }.bind(this); // animationLoop

    if( this.isAnimating) {
      this.endAnimation();
    }

    this.isAnimating = true;

    this.startTime = (new Date()).valueOf();

    if( SC.none( this.animationTimer))
      this.animationTimer = SC.Timer.schedule( { action: animationLoop, interval: kInterval,
                    repeats: YES, until: false });
    this.animationTimer.set( 'isPaused', NO);

    animationLoop();
  },

  /**
    We assume that my properties have been set to the aspects of the plot that are to
    be animated. If there is an animation already in progress, we end it.
  */
  endAnimation: function( iTarget, iCompletionFunc) {
    if (this.animationTimer) {
      this.animationTimer.set( 'isPaused', YES);
      this.endTime = (new Date()).valueOf();
    }
    this.isAnimating = false;
  }

});


/* >>>>>>>>>> BEGIN source/views/image_view.js */
// ==========================================================================
//                              DG.ImageView
// 
//  Overrides SC.ImageView to provide some missing behaviors.
//  
//  Authors:  William Finzer
//
//  Copyright (c) 2015 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

  A TableView contains a scrollable view that, in turn, contains a table.

  @extends SC.ImageView
*/
DG.ImageView = SC.ImageView.extend(
/** @scope DG.ImageView.prototype */ {

  /**
    The alternate text to use for the ALT attribute of the image.
    The ALT attribute specifies alternate text to be used by user agents
    (e.g. browsers, screen readers) that cannot display images.
    @property {String}
   */
  altText: null,
  
  /**
    Set to true to indicate that the 'altText' property should be localized.
    @property {Boolean}
   */
  localize: false,
  
  /**
    [Computed] Returns the string to use for the ALT attribute.
    @returns  {String}  The string to use for the ALT attribute.
   */
  displayAltText: function() {
    var altText = this.get('altText') || this.get('toolTip') || "";
    return !SC.empty( altText) && this.get('localize') ? altText.loc() : altText;
  }.property('altText', 'toolTip', 'localize'),

  /**
    Install the toolTip and alternate text at render time.
    @param {SC.RenderContext} context the render context instance
  */
  render: function(context) {
    arguments.callee.base.apply(this,arguments);

    // Alternative text description of image
    var altText = this.get('displayAltText');
    if( !SC.empty( altText))
      context.setAttr('alt', altText);

    // 'displayToolTip' is auto-localized if 'localize' is true
    var toolTip = this.get('displayToolTip');
    if( !SC.empty( toolTip))
      context.setAttr('title', toolTip);
  }
});


/* >>>>>>>>>> BEGIN source/views/mouse_and_touch_view.js */
// ==========================================================================
//                          DG.MouseAndTouchView
// 
//  A view that allows user to initiate an action when mouse or touch begins in the
// view and ends in the view.
//  
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

    DG.MouseAndTouchView is a base class for the close and minimize buttons in a component view's title bar.

 @extends SC.View
 */
DG.MouseAndTouchView = {
  allowParent: YES,  // determines whether we pass events to parent view
  isMouseDown: NO,
  isMouseOver: NO,
  isActive: NO,
  mouseMoved: function (evt) {
    this.mouseOver(evt);
    return YES;
  },
  mouseOver: function (evt) {
    if (this.get('isMouseDown')) {
      this.set('isActive', YES);
    }
    this.set('isMouseOver', YES);
    return YES;
  },
  mouseExited: function (evt) {
    this.set('isActive', NO);
    this.set('isMouseOver', NO);
    return YES;
  },
  /**
   * In mouseDown, mouseDragged, and mouseUp below we're allowing our parent view to participate
   * in case it can handle mouseDragged (as does DragBorderView). We've arranged things so that
   * dragging will be handled by the parent view but a simple mouseDown followed by mouseUp (a click)
   * will be handled by this view.
   */
  mouseDown: function (evt) {
    if (!this.get('isMouseDown')) {
      this.set('isMouseDown', YES);
      this.set('isActive', YES);
    }
    if (this.allowParent && this.parentView.mouseDown)
      return this.parentView.mouseDown(evt); // We want to allow mouseDrag in parent
    else
      return YES;
  },
  mouseDragged: function (evt) {
    if (this.allowParent && this.parentView.mouseDragged) {
      this.set('isActive', NO);
      return this.parentView.mouseDragged(evt);
    } else return NO;
  },
  mouseUp: function (evt) {
    if (this.get('isActive')) {
      this.set('isActive', NO);
      this.set('isMouseOver', NO);
      this.set('isMouseDown', NO);
      this.doIt();
      DG.mainPage.docView.coverUpComponentViews('uncover');
    } else {
      this.set('isMouseDown', NO);
      this.mouseExited(evt);
      if (this.allowParent && this.parentView.mouseUp)
        return this.parentView.mouseUp(evt);
    }
    return YES;
  },
  touchStart: function (iTouch) {
    return YES;
  },
  touchEnd: function (iTouch) {
    this.doIt();
  },
  doIt: null
}
;
/* >>>>>>>>>> BEGIN source/components/case_table/case_table_view.js */
// ==========================================================================
//                        DG.CaseTableView
//
//  A wrapper view that holds a SlickGridView.
//
//  Author:   Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
/*global Slick */

sc_require('components/case_table/scroll_animation_utility');
sc_require('components/case_table/case_table_row_selection_model');
sc_require('views/image_view');
sc_require('views/mouse_and_touch_view');
/** @class

  A CaseTableView contains a scrollable data grid view.
  In DG, it corresponds to a table of cases from a single collection.

  @extends SC.View
*/
DG.CaseTableView = SC.View.extend( (function() // closure
/** @scope DG.CaseTableView.prototype */ {

  /*
   * kHeaderHeight is used purely for event-handling purposes, particularly
   * the touch-handling code, for converting clicks in the SproutCore
   * view to the cells in which those clicks occurred. It should be set
   * so that clicks on row boundaries have the expected user effect.
   */
  var kHeaderHeight = 59,//29,
                                  // eslint-disable-next-line no-unused-vars
      kAutoScrollInterval = 200;  // jshint ignore: line
                                  // msec == 5 rows/sec

  // returns the component controller associated with the specified view
  function getController(view) {
    var controller;
    for ( ; view && !controller; view = view.get('parentView')) {
      controller = view.get('controller');
    }
    return controller;
  }

  return {  // return from closure

    classNames: 'dg-case-table-view',

    childViews: 'titleBarContainer tableView _hiddenDragView'.w(),

    dataContext: function () {
      return this.getPath('gridAdapter.dataContext');
    }.property(),
    dataContextDidChange: function() {
      this.respondToDataContextAndGridAdapterChanges();
    }.observes('gridAdapter.dataContext'),

    titleBarContainer: SC.View.extend({
      childViews: 'titleBar'.w(),
      classNames: ['dg-case-table-title-bar-container'],
      layout: {left: 0, right: 0, top: 0, height: 22},
      mouseDown: function (ev) {
        // if not in a current edit, background clicks should complete any edit
        if (ev.target.tagName !== 'INPUT') {
          DG.globalEditorLock.commitCurrentEdit();
        }
        return NO;
      },
      titleBar: SC.View.extend({
        childViews: 'titleView newAttrButtonView'.w(),
        classNames: 'dg-case-table-title-bar newAttrButtonView'.w(),
        refView: function () {
          var parentView = this.parentView;
          return parentView && parentView.parentView;
        }.property(),
        titleView: SC.LabelView.extend(DG.MouseAndTouchView, SC.AutoResize, {
          refView: function () {
            var parentView = this.parentView;
            return parentView && parentView.get('refView');
          }.property(),
          layout: {left: 0, top: 3, right: 22, height: 22},
          exampleNode: null,
          classNames: 'dg-case-table-title'.w(), // layout: { left: 0, right: 0, top: 0, height: 22 },
          isEditable: function () {
            var owningDataInteractive = this.getPath('refView.dataContext.owningDataInteractive');
            var owningInteractivePreventsReorg = owningDataInteractive && owningDataInteractive.get('preventDataContextReorg');
            return !owningDataInteractive || !owningInteractivePreventsReorg;
          }.property(),

          /**
           * Assembles the value from collection name and count.
           */
          value: function () {
            var collectionName = this.getPath('refView.collectionName');
            var caseCount = this.getPath('refView.caseCount');
            var nonemptyCaseCount = this.getPath('refView.nonemptyCaseCount');
            var noEmpties = (caseCount === nonemptyCaseCount);
            var hasChildTable = !!this.getPath('refView.childTable');
            var setAsideCount = hasChildTable ? 0 : this.getPath(
                'refView.dataContext.setAsideCount');
            if (hasChildTable || (noEmpties && !setAsideCount) ) {
              return 'DG.TableController.collectionTitleText'.loc(collectionName,
                  caseCount);
            } else if (noEmpties && setAsideCount) {
              return 'DG.TableController.collectionTitleTextWithSetAside'.loc(
                  collectionName, caseCount, setAsideCount);
            } else if (!noEmpties && !setAsideCount) {
              return 'DG.TableController.collectionTitleText-nonempty'.loc(
                  collectionName, nonemptyCaseCount, setAsideCount);
            } else {
                return 'DG.TableController.collectionTitleTextWithSetAside-nonempty'.loc(
                    collectionName, nonemptyCaseCount, setAsideCount);
            }
          }.property(),

          valueDidChange: function (l) {
            this.notifyPropertyChange('value');
            this.set('toolTip', this.get('value'));
          }.observes('*refView.collectionName', '*refView.caseCount', '*refView.nonemptyCaseCount', '*refView.dataContext.setAsideCount'),

          toolTip: '',

          /**
           * We are displaying the collection name and count. We only want to
           * edit the name.
           * @override SC.InlineEditorDelegate
           * @param editor
           * @param value
           * @param editable
           */
          inlineEditorWillBeginEditing: function (editor, value, editable) {
            arguments.callee.base.apply(this,arguments);
            editor.set('value', this.getPath('refView.collectionName'));
            var exampleNode = this.get('exampleNode');
            var tParent = this.get('parentView');
            var tFrame = tParent.get('frame');
            var kXGap = 4, kYGap = 2;
            var tOrigin = DG.ViewUtilities.viewToWindowCoordinates({x: kXGap, y: kYGap}, tParent);
            if (!exampleNode) {
              exampleNode = this.get('layer').cloneNode(false);
              exampleNode.id = exampleNode.id + "-clone";
              exampleNode.style.visibility = 'hidden';
              exampleNode.style.textAlign = 'center';
              exampleNode.className = exampleNode.className.replace('dg-case-table-title', '');
              tParent.get('layer').appendChild(exampleNode);
              this.set('exampleNode', exampleNode);
            }
            exampleNode.style.left = 3 + 'px';
            exampleNode.style.top = 9 + 'px';

            editor.set({
              exampleElement: exampleNode,
              exampleFrame: {
                x: tOrigin.x, y: tOrigin.y,
                width: tFrame.width - 2 * kXGap, height: tFrame.height - 2 * kYGap
              }
            });

          },
          /**
           * Capture the edit result.
           * @override SC.InlineEditorDelegate
           * @param editor
           * @param value
           * @param editable
           * @returns {*}
           */
          inlineEditorDidCommitEditing: function (editor, value, editable) {
            var tController = getController(this),
                tDataContext = tController && tController.get('dataContext'),
                tCollectionName = this.getPath('refView.collectionName');
            if (tDataContext) {
              DG.CaseDisplayUtils
                  .setCollectionNameWithCommand(tDataContext, tCollectionName,
                      value);
            }
            return arguments.callee.base.apply(this,arguments);
          },

          localize: true,
          doIt: function () {
            this.beginEditing();
          },
        }),
        newAttrButtonView: DG.ImageView.extend({
          refView: function () {
            return this.parentView && this.parentView.get('refView');
          }.property(),
          classNames: ['dg-floating-plus'],
          classNameBindings: ['disabled'],
          layout: {
            top: 0,
            right: 0,
            width: 22,
            height: 22
          }, // https://www.materialui.co/icon/add-circle
          value: '../../../../static/dg/de/cert/source/resources/images/add_circle_grey_72x72.png',
          tooltip: 'DG.TableController.newAttributeTooltip'.loc(),
          disabled: function () {
            var context = this.getPath('refView.gridAdapter.dataContext');
            var isTopLevel = !this.getPath(
                'refView.gridAdapter.hasParentCollection');
            return context && isTopLevel && DG.DataContextUtilities.isTopLevelReorgPrevented(
                context);
          }.property('_dataContextDidChange'),
          dataContextDidChange: function () {
            this.notifyPropertyChange('_dataContextDidChange');
          }.observes('refView.gridAdapter.dataContext.metadataChangeCount'),
          didAppendToDocument: function () {
            arguments.callee.base.apply(this,arguments);

            var tooltip = this.get('tooltip');
            if (tooltip) this.$().attr('title', tooltip);
          },
          mouseDown: function (evt) {
            var tableController = getController(this),
                collection = this.getPath('refView.gridAdapter.collection');
            // only respond to left-button clicks; see SC.Event for constant
            if (tableController && collection && (evt.which === 1)) {
              SC.RootResponder.responder
                  .sendAction('newAttributeAction', tableController, this,
                      this.get('pane'),
                      {collection: collection, autoEditName: true});
            }
            return YES;
          },
          touchStart: function (evt) {
            return YES;
          },
          touchEnd: function (evt) {
            evt.allowDefault();
            return YES;
          }
        }),

      }),
    }),

    tableView: SC.View.extend({
      classNames: ['dg-case-table'],
      layout: {left: 0, right: 0, top: 22, bottom: 0},
      backgroundColor: "white",

      isDropTarget: true,

      classNameBindings: ['isDragInProgress:dg-table-drop-target-show'],

      /**
       * @property {DG.CaseTableDragHelper}
       */
      dragHelper: null,

      computeDragOperations: function (iDrag) {
        if( this.isValidAttribute( iDrag))
          return SC.DRAG_LINK;
        else
          return SC.DRAG_NONE;
      },

      /**
       * We determine the drag helper appropriate to the attribute being dragged and pass responsibility
       * to it for all drag functions.
       * @param iDrag
       */
      dragStarted: function (iDrag) {
        var tHelper = DG.CaseTableDragHelper.createHelper(this, iDrag);
        if (tHelper) {
          this.set('dragHelper', tHelper);
          this.get('dragHelper').dragStarted(iDrag);
        }
      },

      dragEnded: function () {
        var tDragHelper = this.get('dragHelper');
        tDragHelper.dragEnded();
        tDragHelper.destroy();
        this.set('dragHelper', null);
      },

      dragEntered: function (iDragObject, iEvent) {
        this.get('dragHelper').dragEntered(iDragObject, iEvent);
      },

      dragUpdated: function (iDragObject, iEvent) {
        this.get('dragHelper').dragUpdated(iDragObject, iEvent);
      },

      dragExited: function (iDragObject, iEvent) {
        this.get('dragHelper').dragExited(iDragObject, iEvent);
      },

      acceptDragOperation: function (drag, op) {
        return this.get('dragHelper').acceptDragOperation(drag, op);
      },

      performDragOperation: function (iDragObject, iDragOp) {
        this.get('dragHelper').performDragOperation(iDragObject, iDragOp);
      },

      isValidAttribute: function (iDrag) {
        return this.get('dragHelper').isValidAttribute(iDrag);
      },

      /**
       * These methods -- dataDragEntered, dataDragHovered, dataDragDropped,
       * and dataDragExited -- support drags initiated outside the page,
       * specifically drags from plugins.
       */
      _externalDragObject: function () {
        var data = DG.mainPage.getPath('mainPane.dragAttributeData');
        if (data && data.context === this.parentView.get('dataContext')) {
          return {
            data: data
          };
        }
      }.property(),
      externalDragDidChange: function () {
        var tDrag = this.get('_externalDragObject');
        if (!tDrag) {
          return;
        }
        if (DG.mainPage.getPath('mainPane._isDraggingAttr')) {
          this.dragStarted(tDrag);
        } else {
          this.dragEnded();
        }
      }.observes('DG.mainPage.mainPane._isDraggingAttr'),

      dataDragEntered: function (iEvent) {
        var externalDragObject = this.get('_externalDragObject');
        if (externalDragObject && this.isValidAttribute(externalDragObject)) {
          this.dragEntered(null, externalDragObject);
          iEvent.preventDefault();
        }
      },
      dataDragHovered: function (iEvent) {
        var externalDragObject = this.get('_externalDragObject');
        if (externalDragObject && this.isValidAttribute(externalDragObject)) {
          iEvent.dataTransfer.dropEffect = 'copy';
          iEvent.preventDefault();
          iEvent.stopPropagation();
          this._computeInsertionPoint({x: iEvent.clientX, y: iEvent.clientY});
        } else {
          return false;
        }
      },
      dataDragDropped: function (iEvent) {
        var externalDragObject = this.get('_externalDragObject');
        if (externalDragObject && this.isValidAttribute(externalDragObject)) {
          iEvent.preventDefault();
          var data = DG.mainPage.getPath('mainPane.dragAttributeData');
          this._performDragOperation(data);
        } else {
          return false;
        }
      },
      dataDragExited: function (iEvent) {
        var externalDragObject = this.get('_externalDragObject');
        if (externalDragObject && this.isValidAttribute(externalDragObject)) {
          this.dragExited(null, externalDragObject);
          iEvent.preventDefault();
        }
      }

    }),

    parentTable: null,

    childTable: null,

    _hiddenDragView: SC.LabelView.design({
      classNames: 'dg-drag-label'.w(),
      layout: {width: 100, height: 20, top: -50, left: 0},
      value: ''
//    cursor: DG.Browser.customCursorStr('../../../../static/dg/de/cert/resources/cursors/ClosedHandXY.cur', 8, 8)
    }),

    ancestorViewDidResizeOrScroll: function () {
      this.invokeLater(function () {
        var visibleFrameBounds = this.get('visibleFrameBounds');
        var titleBar = this.getPath('titleBarContainer.titleBar');
        if (visibleFrameBounds) {
          titleBar.adjust({
            left: visibleFrameBounds.x,
            width: visibleFrameBounds.width,
            right: null
          });
        }
      }.bind(this));
    },

    frameBounds: function () {
      var pv = this.get('parentView'), frame = this.get('frame');
      return pv ? pv.convertFrameToView(frame, null) : frame;
    }.property(),

    visibleFrameBounds: function () {
      var view = this, pv = this.get('parentView'), frame = this.get('frame'),
          baseFrame = pv ? pv.convertFrameToView(frame, null) : frame,
          visibleBounds = {}, right, bottom;
      // find boundary of the hierarchical table view
      while (pv && !(view instanceof DG.HierTableView)) {
        view = pv;
        pv = view.get('parentView');
      }
      if (!pv) {
        return;
      }
      var boundingFrame = pv.convertFrameToView(view.get('frame'), null);
      visibleBounds.x = Math.max(boundingFrame.x, baseFrame.x);
      visibleBounds.y = Math.max(boundingFrame.y, baseFrame.y);
      right = Math.min(boundingFrame.x + boundingFrame.width,
          baseFrame.x + baseFrame.width);
      bottom = Math.min(boundingFrame.y + boundingFrame.height,
          baseFrame.y + baseFrame.height);
      visibleBounds.width = Math.max(right - visibleBounds.x, 0);
      visibleBounds.height = Math.max(bottom - visibleBounds.y, 0);

      return this.convertFrameFromView(visibleBounds, null);
    }.property(),

    layout: {left: 0, right: 0, top: 0, bottom: 0},

    backgroundColor: "white",

    /**
     * Manages name of the current collection.
     * @return {String}
     */
    collectionName: function (key, value) {
      if (value !== undefined) {
        this.setPath('gridAdapter.collectionName', value);
      }
      return this.getPath('gridAdapter.collectionName');
    }.property(),

    collectionNameDidChange: function () {
      this.notifyPropertyChange('collectionName');
    }.observes('*gridAdapter.collectionName'),

    /**
     * Count for the current collection.
     * @return {number}
     */
    caseCount: function () {
      return this.getPath('gridAdapter.collection.caseCount');
    }.property(),

    nonemptyCaseCount: function () {
      return this.getPath('gridAdapter.collection.nonemptyCaseCount');
    }.property(),

    caseCountDidChange: function () {
      this.notifyPropertyChange('caseCount');
    }.observes('*gridAdapter.collection.caseCount'),

    nonemptyCaseCountDidChange: function () {
      this.notifyPropertyChange('nonemptyCaseCount');
    }.observes('*gridAdapter.collection.nonemptyCaseCount'),

    /**
     The adapter used for adapting the case data for use in SlickGrid.
     @property   {DG.CaseTableAdapter}
     */
    gridAdapter: null,

    /**
     The SlickGrid DataView object for filtering/accessing the row data.
     @property   {Slick.Data.DataView}
     */
    gridDataView: null,

    /**
     Notification-only property. The value of this property is meaningless.
     It is used purely as a property name to notify when clients should
     respond to a complete change in the underlying SlickGrid. We don't
     want clients to have access to the private _slickGrid Property, however,
     so we signal changes by notifying with this property name instead.
     @property   {undefined}
     */
    gridView: undefined,

    /**
     The SlickGrid itself.
     @property   {Slick.Grid}
     @private
     */
    _slickGrid: null,

    /**
     The event handler for registering interest in SlickGrid events.
     @property   {Slick.EventHandler}
     */
    _gridEventHandler: null,

    /**
     @private
     The current width of the table/grid. Used to compute the gridWidth()
     and gridWidthChange() properties.
     @property   {Number}
     */
    _gridWidth: 0,

    /**
     @private
     The previous width of the table/grid. Used to compute the gridWidthChange() property.
     @property   {Number}
     */
    _prevGridWidth: 0,

    /**
     @private
     A timer for use in tracking proto-case editing.
     @property   {Number}  timerID
     */
    _protoCaseTimer: null,

    /**
     * Used so that we know when all cued invokeLast's inside viewDidResize has fired off so that
     * we can cause slickGrid to refresh one last time
     */
    _canvasResizeCounter: 0,

    /**
     To commit proto-case values as a new case when the user finishes entering values,
     we set a timer whenever a proto-case cell is exited, and then clear it whenever
     a proto-case cell is entered. When the user finishes entering values, the timer
     expires and the case is created. This handles situations when the user exits the
     case table entirely, for instance, which would be tricky to handle otherwise.
     */
    clearProtoCaseTimer: function () {
      if (this._protoCaseTimer) {
        clearTimeout(this._protoCaseTimer);
        this._protoCaseTimer = null;
      }
    },

    resetProtoCaseTimer: function () {
      this.clearProtoCaseTimer();

      this._protoCaseTimer = setTimeout(function () {
        // timer can outlive table
        if (!this._slickGrid) return;
        var rowCount = this._slickGrid.getDataLength(),
            lastRowItem = this._slickGrid.getDataItem(rowCount - 1),
            hasProtoCase = lastRowItem && lastRowItem._isProtoCase && DG.ObjectMap.length(
                lastRowItem._values);
        if (hasProtoCase) {
          SC.run(function () {
            this.commitProtoCase(lastRowItem);
          }.bind(this));
        }
      }.bind(this), 300);
    },

    /**
     Creates a new case with the specified proto-case values.
     */
    commitProtoCase: function (protoCase) {
      function getParentCase(context, collection) {
        var parentCollectionID = collection.getParentCollectionID(),
            parentCollection = parentCollectionID && context.getCollectionByID(parentCollectionID),
            parentCase = protoCase && protoCase.parentCaseID && parentCollection &&
                          parentCollection.getCaseByID(protoCase.parentCaseID);
        // if the proto-case is associated with a particular parent case, return it
        if (parentCase) return parentCase;
        // otherwise, associate it with the last parent case
        var parentCaseCount = parentCollection && parentCollection.getCaseCount();
        if (!SC.none(parentCaseCount)) {
          return parentCollection.getCaseAt(parentCaseCount - 1);
        }
      }

      var gridAdapter = this.get('gridAdapter'),
          gridDataView = gridAdapter.get('gridDataView'),
          collection = protoCase && protoCase.collection,
          attrIDs = collection && collection.getAttributeIDs(),
          beforeCaseID = protoCase && protoCase.get('beforeCaseID'),
          parentCase = getParentCase(this.get('dataContext'), collection),
          parentCaseID = parentCase && parentCase.get('id'),
          values;
      if (!collection || !attrIDs) return;

      values = attrIDs.map(function (attrID) {
        var value = protoCase._values[attrID];
        return value != null ? value : "";
      });
      protoCase._values = {};

      if (gridDataView && parentCaseID) {
        // cell navigation happens within invokeNext(); group expansion is next after that
        this.invokeNext(function() {
          this.invokeNext(function() {
            gridDataView.expandGroup(parentCaseID);
            gridAdapter.refresh();
          }.bind(this));
        }.bind(this));
      }

      DG.DataContextUtilities.createCaseUndoable(this.get('dataContext'), {
        collection: collection,
        attrIDs: attrIDs,
        values: values,
        beforeCaseID: beforeCaseID,
        parent: parentCase
      });
    },

    /**
     * Returns the visible limits of the grid in row,pixel coordinates.
     * See https://github.com/mleibman/SlickGrid/wiki/Slick.Grid#getViewport
     * @property {{
     *    top: {number},
     *    bottom: {number},
     *    leftPx: {number},
     *    rightPx: {number}
     * }}
     */
    gridViewport: function () {
      return this.get('_slickGrid').getViewport();
    }.property('_slickGrid'),

    /**
     The current width of the table/grid. Designed to be used for clients to observe
     when the table width changes and to respond appropriately.
     @property   {Number}
     */
    gridWidth: function (iKey, iValue) {
      if (!SC.none(iValue)) {
        this._prevGridWidth = this._gridWidth;
        this._gridWidth = iValue;
        return this;
      }
      return this._gridWidth;
    }.property(),

    /**
     The delta from the previous width to the current width.
     Clients may use this to determine how much adjustment is required.
     @property   {Number}
     */
    gridWidthChange: function () {
      return this._gridWidth - this._prevGridWidth;
    }.property(),

    gridWidthDidChange: function () {
      var parentView = this.get('parentView');
      // Apparently, we can get gridWidthDidChange before the parent view is
      // established. This occurs on Chrome, W8.1 or MacOS Mavericks, but not
      // MacOS Yosemite.
      if (parentView) {
        parentView.gridWidthDidChange(this);
      }
    }.observes('gridWidth'),

    /**
     * Returns a hashmap mapping attribute ids to widths in pixels
     * @return {{attr_id: number}}
     */
    columnWidths: function () {
      var columns = this._slickGrid.getColumns();
      var rtn = {};
      if (!SC.none(columns)) {
        columns.forEach(function (column) {
          rtn[column.id] = column.width;
        });
      }
      return rtn;
    }.property(),

    sizeDidChange: function () {
      var parentView = this.get('parentView');
      // Protect against the possibility we don't have a parent view
      if (parentView) {
        parentView.childTableLayoutDidChange(this);
      }
    }.observes('size'),

    rowCountDidChange: function () {
      // rowCount notification can happen while case tables are being rearranged
      // this is a transient situation and we will recreate the full table after,
      // so we can ignore, now.
      if (!SC.none(this.get('parentView'))) {
        this.get('parentView').rowCountDidChange(this);
      }
    }.observes('rowCount'),

    tableDidScroll: function () {
      // scroll notification can happen while case tables are being rearranged
      // this is a transient situation and we will recreate the full table after,
      // so we can ignore, now.
      if (!SC.none(this.get('parentView'))) {
        this.get('parentView').tableDidScroll(this);
      }
    }.observes('scrollPos'),

    tableDidExpandCollapse: function () {
      var parentView = this.get('parentView');
      if (parentView) {
        parentView.tableDidExpandCollapse(this);
      }
    }.observes('expandCollapseCount'),

    /**
     The number of rows in the table. This property is updated as rows are added/removed.
     Clients may observe or bind to it to be notified when the rowCount changes.
     @property   {Number}
     */
    rowCount: 0,

    /**
     The current scroll position within the table. This property is updated as the table
     is scrolled. Clients may observe or bind to it to be notified when scroll pos changes.
     @property   {Object}  scrollPos
     {Number}  scrollPos.scrollTop -- The vertical scroll position
     {Number}  scrollPos.scrollLeft -- The horizontal scroll position
     */
    scrollPos: null,

    /**
     Incremented whenever an expand/collapse occurs.
     Clients may observe this property to respond.
     @property   {Number}
     */
    expandCollapseCount: 0,

    scrollAnimator: null,

    displayProperties: ['gridAdapter', 'gridDataView', '_slickGrid'],

    init: function () {
      this.beginPropertyChanges();
      arguments.callee.base.apply(this,arguments);
      this.scrollAnimator = DG.ScrollAnimationUtility.create();
      this.endPropertyChanges();
      this.invokeLater(function () {
        this.ancestorViewDidResizeOrScroll();
      });
    },

    /**
     Called when the view is resized, in which case the SlickGrid should resize as well.
     */
    viewDidResize: function () {
      arguments.callee.base.apply(this,arguments);
      /**
       * The layout has changed but the DOM has not yet changed, so we invokeLast.
       * Even worse, an animation can cause changes to happen to the layout _after_
       * the invokeLast, changes that aren't covered here. For that reason, we keep
       * a counter and when it's zero, we fire off an invokeLater with a timer equal
       * to a typical animation duration. Ugh!
       */
      this._canvasResizeCounter++;
      this.invokeLast(function () {
        this._canvasResizeCounter--;
        if (this._slickGrid) {
          this._slickGrid.resizeCanvas();
          this.setIfChanged('gridWidth',
              this._slickGrid.getContentSize().width);
          if( this._canvasResizeCounter === 0)
            this.invokeLater( function() {
              if (this._slickGrid) this._slickGrid.resizeCanvas();
            }.bind(this), 400);
        }
      }.bind(this));
    },

    /**
     * Slick grid header menu plugin.
     * @type {Slick.Plugins.HeaderMenu}
     */
    headerMenu: null,

    hideHeaderMenu: function () {
      if (this.headerMenu) {
        this.headerMenu.hideMenu();
      }
    },

    /**
     Initializes the SlickGrid from the contents of the adapter (DG.CaseTableAdapter).
     */
    initGridView: function () {
      var gridLayer = this.tableView.get('layer'),
          gridAdapter = this.get('gridAdapter'),
          dataView = gridAdapter && gridAdapter.gridDataView,
          hierTableView = this.get('parentView');
      this._slickGrid = new Slick.Grid(gridLayer, gridAdapter.gridDataView,
          gridAdapter.gridColumns, gridAdapter.gridOptions);

      this._slickGrid.setSelectionModel(new DG.CaseTableRowSelectionModel({
        selectActiveRow: true, caseTableAdapter: this.gridAdapter, caseTableView: this
      }));

      if (this.getPath('gridAdapter.isMultilineRowHeight'))
        this.$('.slick-viewport').addClass('slick-multiline-cells');

      /*
       * Add a column header menu to each column.
       */
      if (DG.supports('caseTableHeaderMenus')) {
        this.headerMenu = new Slick.Plugins.HeaderMenu({
          buttonIsCell: true, buttonImage: '../../../../static/dg/de/cert/source/resources/slickgrid/images/down.gif'
        });
        this._slickGrid.registerPlugin(this.headerMenu);
        this.$('.slick-viewport').addClass('dg-wants-touch').addClass('dg-wants-wheel');

        this.headerMenu.onBeforeMenuShow.subscribe(function (e, args) {
          hierTableView.hideHeaderMenus();
          var enabledItems = 0;
          // call any associated updater functions, e.g. to enable/disable
          if (args.menu && args.menu.items && args.menu.items.length) {
            args.menu.items.forEach(function (ioMenuItem) {
              if (ioMenuItem.updater) {
                ioMenuItem.updater(args.column, args.menu, ioMenuItem);
              }
              if (!ioMenuItem.disabled) ++enabledItems;
            });
            // add 'dg-wants-touch' class to menus
            setTimeout(function () {
              $('.slick-header-menu')
                  .addClass(function (index, classes) {
                    return (!classes || (classes.indexOf(
                        'dg-wants-touch') < 0)) ? 'dg-wants-touch' : '';
                  });
            }, 10);
          }
          // Only show the menu if there's at least one enabled item
          return (enabledItems > 0);
        });

        this.headerMenu.onCommand.subscribe(function (e, args) {
          SC.run(function () {
            var controller = getController(this);
            // Dispatch the command to the controller
            if (controller) controller.doCommand(args);
          }.bind(this));
        }.bind(this));
      } // DG.supports('caseTableHeaderMenus')

      this._gridEventHandler = new Slick.EventHandler();

      // Subscribe to SlickGrid events which call our event handlers directly.
      this.subscribe('onClick', this.handleClick);
      this.subscribe('onKeyDown', this.handleKeyDown);
      this.subscribe('onScroll', this.handleScroll);
      this.subscribe('onHeaderClick', this.handleHeaderClick);
      this.subscribe('onHeaderDragInit', function (iEvent, iDragData) {
        // dragging should complete any current edit
        DG.globalEditorLock.commitCurrentEdit();
        // prevent the grid from cancelling drag'n'drop by default
        iEvent.stopImmediatePropagation();
      });
      this.subscribe('onHeaderDragStart', this.handleHeaderDragStart);
      this.subscribe('onRowResizeDragInit', this.handleRowResizeDragInit);
      this.subscribe('onRowResizeDragStart', this.handleRowResizeDragStart);
      this.subscribe('onRowResizeDrag', this.handleRowResizeDrag);
      this.subscribe('onRowResizeDragEnd', this.handleRowResizeDragEnd);
      this.subscribe('onBeforeAutoEditCell', this.handleBeforeAutoEditCell);
      this.subscribe('onBeforeEditCell', this.handleBeforeEditCell);
      this.subscribe('onCanvasWidthChanged', function (e, args) {
        SC.run(function () {
          this.setIfChanged('gridWidth',
              this._slickGrid.getContentSize().width);
        }.bind(this));
      }.bind(this));
      this.subscribe('onColumnsResized', this.handleColumnsResized);
      this.subscribe('onColumnResizing', this.handleColumnResizing);
      this.subscribe('onSelectedRowsChanged', this.handleSelectedRowsChanged);

      var sgEditController = this._slickGrid.getEditController(),
          commitFunction = sgEditController.commitCurrentEdit,
          cancelFunction = sgEditController.cancelCurrentEdit;
      sgEditController.commitCurrentEdit = function () {
        var activeCell = this._slickGrid.getActiveCell(),
            dataItem = activeCell && this._slickGrid.getDataItem(
                activeCell.row);
        if (dataItem && dataItem._isProtoCase) {
          this.resetProtoCaseTimer();
        }
        return commitFunction();
      }.bind(this);
      sgEditController.cancelCurrentEdit = function () {
        var activeCell = this._slickGrid.getActiveCell(),
            dataItem = activeCell && this._slickGrid.getDataItem(
                activeCell.row);
        if (dataItem && dataItem._isProtoCase) {
          this.resetProtoCaseTimer();
        }
        return cancelFunction();
      }.bind(this);


      // wire up model events to drive the grid
      dataView.onRowCountChanged.subscribe(function (e, args) {
        SC.run(function () {
          if (this._slickGrid) {
            var editState = this.saveEditState();
            this._slickGrid.invalidate();
            this.set('rowCount', args.current);
            if (editState) {
              this.restoreEditStateWhenReady(editState);
            }
          }
        }.bind(this));
      }.bind(this));

      dataView.onRowsChanged.subscribe(function (e, args) {
        SC.run(function () {
          if (this._slickGrid) {
            var editState = this.saveEditState();
            this._slickGrid.invalidate();
            if (editState) {
              this.restoreEditStateWhenReady(editState);
            }
          }
        }.bind(this));
      }.bind(this));

      $(gridLayer).on('change', '.dg-checkbox-cell input:checkbox', {slickGrid: this._slickGrid}, this.handleCheckboxChange);
      $(gridLayer).show();

      this.adjustHeaderForOverflow();
      // Let clients know when there's a new _slickGrid
      this.notifyPropertyChange('gridView');
    },
    handleCheckboxChange: function (ev) {
      function updateCheckboxValue (iCase, iAttrID, iContext, iNewValue) {
        var attrID = iAttrID,
            tCase = iCase,
            originalValue = tCase.getValue(iAttrID),
            newValue = iNewValue,
            context = iContext,
            contextName = context.get('name'),
            collection = tCase.get('collection'),
            collectionName = collection && collection.get('name') || "",
            attr = collection && collection.getAttributeByID(Number(attrID)),
            attrName = attr && attr.get('name'),
            caseID = tCase.id;

        function applyEditChange(attrID, iValue, isUndoRedo) {
          context.applyChange({
            operation: 'updateCases',
            cases: [ tCase ],
            attributeIDs: [ attrID ],
            values: [ [iValue] ]
          });
        }

        var cmd = DG.Command.create({
          name: 'caseTable.editCellValue',
          undoString: 'DG.Undo.caseTable.editCellValue',
          redoString: 'DG.Redo.caseTable.editCellValue',
          log: "editValue: { collection: %@, case: %@, attribute: '%@', old: '%@', new: '%@' }"
              .fmt(collectionName, caseID, attrID, originalValue, newValue),
          execute: function() {
            applyEditChange(attrID, newValue);
          },
          undo: function() {
            applyEditChange(attrID, originalValue, true);
          },
          redo: function() {
            context = DG.currDocumentController().getContextByName(contextName);
            collection = context && context.getCollectionByName(collectionName);
            attr = collection && collection.getAttributeByName(attrName);
            attrID = attr.get('id');
            // var cases = collection && collection.get('casesController');
            // tCase = cases && cases.objectAt(caseIndex);
            if (tCase)
              applyEditChange(attrID, newValue, true);
          }
        });
        DG.UndoHistory.execute(cmd);
      }

      var slickGrid = ev.data.slickGrid;
      var gridCoord = slickGrid.getCellFromEvent(ev);
      // DG.log('checkbox: ' + gridCoord.row + ', ' + gridCoord.cell);
      var tCase = slickGrid.getDataItem(gridCoord.row);
      var tColumn = slickGrid.getColumns()[gridCoord.cell];
      var tAttrID = tColumn.id;
      var tContext = tColumn.context;
      var tValue = this.checked?'true':'false';
      updateCheckboxValue(tCase, tAttrID, tContext, tValue);

      ev.preventDefault();
      ev.stopPropagation();
    },

    _refreshDataView: function (recurse) {
      var childTable = this.get('childTable');
      var gridAdapter = this.get('gridAdapter');
      if (gridAdapter) {
        gridAdapter.gridDataView.refresh();
      } else {
        DG.logWarn('CaseTableView._resetDataView: no data view');
      }
      if (childTable && recurse) {
        childTable._refreshDataView(recurse);
      }
    },

    /**
     * Gets the row position of a case in relative to the top of the viewport.
     * If the row position is not visible in the viewport returns undefined.
     * @param iCaseID {number}
     * @returns {number|undefined}
     */
    getViewportPosition: function (iCaseID) {
      var gridDataView = this.getPath('gridAdapter.gridDataView');
      var row = gridDataView.getRowById(iCaseID);
      var viewport = this.get('gridViewport');
      var viewHeight = viewport.bottom - viewport.top;
      var offset = row - viewport.top;
      if (offset >= 0 && offset <= viewHeight) {
        return row - viewport.top;
      } else {
        return undefined;
      }
    },

    /**
     * Aligns the row containing the matching case ids in child tables of this table.
     *
     * This method is intended to align collapsed rows.
     * Collapsed rows are assumed to be mapped in child tables to the collapsed
     * row, perhaps in a higher level collection.
     *
     * @param iViewportPosition {number}
     * @param iCaseID {number}
     */
    alignChildTables: function (iViewportPosition, iCaseID) {
      var childView = this.get('childTable');
      if (!childView) {
        return;
      }
      var row = childView.getPath('gridAdapter.gridDataView').getRowById(
          iCaseID);
      childView.animateScrollToTop(row - iViewportPosition);
      childView.alignChildTables(iViewportPosition, iCaseID);
    },

    showCaseIndexPopup: function (iEvent, iCell) {
      var tDataContext = this.get('dataContext'),
          tIsEnabled = this.getPath('gridAdapter.isCollectionReorgAllowed'),
          tSelection = tDataContext && tDataContext.getSelectedCases(),
          tSelectionCount = tSelection && tSelection.get('length'),
          tDeleteIsEnabled = tSelectionCount > 0,
          tDeleteSingle = tSelectionCount === 1,
          tDataItem = this._slickGrid.getDataItem(iCell.row),
          isProtoCase = tDataItem && tDataItem._isProtoCase,
          isEmptyCase = tDataItem && tDataItem.get('isEmpty'),
          tItems = [{
              title: 'DG.CaseTable.indexMenu.moveEntryRow',
              localize: true,
              target: this,
              action: 'moveDataEntryRow',
              isEnabled: !isProtoCase
            }, {
              title: 'DG.CaseTable.indexMenu.insertCase',
              localize: true,
              target: this,
              action: 'insertCase'
            }, {
              title: 'DG.CaseTable.indexMenu.insertCases',
              localize: true,
              target: this,
              action: 'insertCases'
            }, {
              title: tDeleteSingle ? 'DG.CaseTable.indexMenu.deleteCase' : 'DG.CaseTable.indexMenu.deleteCases',
              localize: true,
              target: getController(this),
              action: 'deleteSelectedCases',
              isEnabled: tDeleteIsEnabled
          }],
          tMenu = DG.MenuPane.create({
            classNames: 'dg-case-index-popup',
            layout: {width: 200, height: 150},
            items: tItems
          });
      if (tIsEnabled && !isEmptyCase) {
        this._caseIndexMenuCell = SC.copy(iCell);
        tMenu.popup(iEvent.target);
      }
    },

    collapseGroup: function (iCaseID) {
      this.getPath('gridAdapter.gridDataView').collapseGroup(iCaseID);
      var childDataView = this.getPath('childTable.gridAdapter.gridDataView');
      if (childDataView) childDataView.resetProtoCases(iCaseID);
    },

    /**
     * Collapses a node in the case tree and resets all case tables below.
     * @param iCaseID {number}
     */
    collapseCase: function (iCaseID) {
      var childTable = this.get('childTable');
      var viewportRow;
      this.collapseGroup(iCaseID);
      if (childTable) {
        childTable._refreshDataView(true);
        viewportRow = this.getViewportPosition(iCaseID);
        this.alignChildTables(viewportRow, iCaseID);
      }
    },

    /**
     * Collapses a node in the case tree and resets all case tables below.
     *
     * @param iCaseID {number}
     */
    expandCase: function (iCaseID) {
      var childTable = this.get('childTable');
      this.getPath('gridAdapter.gridDataView').expandGroup(iCaseID);
      if (childTable) {
        childTable._refreshDataView(true);
      }
    },

    moveDataEntryRow: function () {
      var adapter = this.get('gridAdapter'),
          dataView = adapter.get('gridDataView'),
          clickCaseIndex = this._caseIndexMenuCell.row,
          clickCase = dataView && dataView.getItem(clickCaseIndex),
          parentCase = clickCase && clickCase.get('parent'),
          collection = clickCase && clickCase.get('collection'),
          protoCase = dataView && dataView.getProtoCase(collection);
      if (protoCase && clickCase && !clickCase._isProtoCase) {
        protoCase.set('beforeCaseID', clickCase.get('id'));
        protoCase.set('parentCaseID', parentCase && parentCase.get('id'));
        adapter.deselectAllCases();
        adapter.refresh();
      }
    },

    insertCase: function () {
      this.doInsertCases(1);
    },

    doInsertCases: function (caseCount, insertAfter) {
      var dataContext = this.get('dataContext'),
          dataView = this.getPath('gridAdapter.gridDataView'),
          clickCaseIndex = this._caseIndexMenuCell.row,
          clickCase = dataView && dataView.getItem(clickCaseIndex),
          beforeCaseIndex = insertAfter ? clickCaseIndex + 1 : clickCaseIndex,
          beforeRow = dataView && dataView.getItem(beforeCaseIndex),
          beforeCase = beforeRow && beforeRow._isProtoCase
                        ? dataView.getItem(beforeCaseIndex + 1)
                        : beforeRow,
          collectionID = clickCase.getPath('collection.id'),
          beforeItemID = beforeCase && beforeCase.getPath('item.id'),
          newItem = {}, newItems = [newItem], parentCase, newCaseIDs;

      // new case is child of same parent case(s)
      while ((parentCase = clickCase.get('parent'))) {
        $.extend(newItem, parentCase.copyValues());
        clickCase = parentCase;
      }

      for (var i = 1; i < caseCount; ++i) {
        newItems.push(DG.clone(newItem));
      }

      // insert the new case
      DG.UndoHistory.execute(DG.Command.create({
        name: "caseTable.insertCases",
        undoString: 'DG.Undo.caseTable.insertCases',
        redoString: 'DG.Redo.caseTable.insertCases',
        log: "insert %@ cases in table".fmt(caseCount),
        execute: function () {
          newCaseIDs = dataContext.addItems(newItems, beforeItemID).caseIDs;
        },
        undo: function () {
          var cases = newCaseIDs.map(function (caseID) {
            return DG.store.find('DG.Case', caseID);
          });
          dataContext.deleteCasesAndChildren(
              {operation: 'deleteCases', cases: cases});
        },
        redo: function () {
          this.execute();
        }
      }));

      // synchronize selection after case insertion
      if (newCaseIDs) {
        var newSiblingCases = [];
        // auto-select the new case that is a sibling of the one clicked
        newCaseIDs.forEach(function (caseID) {
          var newCase = dataContext.getCaseByID(caseID),
              newCaseCollectionID = newCase && newCase.getPath('collection.id');
          if (newCaseCollectionID === collectionID) newSiblingCases.push(
              newCase);
        });
        if (newSiblingCases.length) {
          this.invokeLater(function () {
            dataContext.applyChange({
              operation: 'selectCases',
              cases: newSiblingCases,
              select: true
            });
          });
        }
      }
    },

    insertCases: function () {
      var dataContext = this.get('dataContext'),
          selectedCases = dataContext && dataContext.getSelectedCases(),
          selectedCount = selectedCases && selectedCases.get('length'),
          insertCasesPane = DG.InsertCasesDialog.create({
            caseTableView: this, initialCaseCount: selectedCount
          });
      insertCasesPane.append();
    },

    /**
     Destroys the SlickGrid object and its DataView.
     Used to respond to a change of game, where we recreate the SlickGrid from scratch.
     */
    destroySlickGrid: function () {
      if (this._slickGrid) this._slickGrid.destroy();
      this._slickGrid = null;
      this.gridDataView = null;
    },

    /**
     Destroys the SlickGrid object, its DataView object, and the CaseTableAdapter.
     */
    _destroy: function () {
      if (this.scrollAnimator) {
        if (this.scrollAnimator.destroy) this.scrollAnimator.destroy();
        this.scrollAnimator = null;
      }
      this.destroySlickGrid();

      if (this.gridAdapter) this.gridAdapter.destroy();
      this.gridAdapter = null;
    },

    /**
     Called when the component is about to be destroyed.
     */
    willDestroy: function () {
      this._destroy();
    },

    /**
     Destroys the DG.CaseTableView instance.
     */
    destroy: function () {
      this._destroy();
      arguments.callee.base.apply(this,arguments);
    },

    /**
     Utility function to assist with subscribing to (expressing interest in)
     SlickGrid events.
     @param    {String}    iEventName
     @param    {Function}  iHandler -- The function to be called when the event occurs
     */
    subscribe: function (iEventName, iHandler) {
      var _inHandler, wrapHandler = function (iHandler) {
        return function () {
          var result;
          if (!_inHandler) {
            _inHandler = true;
            result = iHandler.apply(this, arguments);
            _inHandler = false;
            return result;
          }
        }.bind(this);
      }.bind(this);

      this._gridEventHandler.subscribe(this._slickGrid[iEventName],
          wrapHandler(iHandler));
    },

    /**
     Returns the bounding rectangle of the specified row of the table.
     The rectangle returned is relative to the content of the table --
     the header row is not included, so the initial top coordinate is 0.

     @param   {Number}  iRowIndex -- the index of the row whose bounds are being requested
     @returns {Object}  The bounding rectangle of the specified row
     Object.left -- the left edge of the bounding rectangle
     Object.top -- the top edge of the bounding rectangle
     Object.right -- the right edge of the bounding rectangle
     Object.bottom -- the bottom edge of the bounding rectangle
     */
    getRowBounds: function (iRowIndex) {
      // start with the bounds of the first (left-most) cell in the row
      var rowBounds = this._slickGrid && this._slickGrid.getCellNodeBox(iRowIndex, 0),
          columns = this._slickGrid && this._slickGrid.getColumns(),
          colCount = columns && columns.length;
      if (rowBounds && colCount) {
        // Expand the right edge to include the bounds of the last cell in the row
        var lastCellBounds = this._slickGrid.getCellNodeBox(iRowIndex, colCount - 1);
        rowBounds.right = lastCellBounds.right;
      }
      return rowBounds;
    },

    /**
     Respond to a change in DG.CaseTableAdapter by destroying the SlickGrid.
     A new one will be recreated on render() if there is a valid adapter.
     */
    gridAdapterDidChange: function () {
      this.respondToDataContextAndGridAdapterChanges();
    }.observes('gridAdapter'),

    respondToDataContextAndGridAdapterChanges: function() {
      if (this._slickGrid) {
        this.destroySlickGrid();
        this.displayDidChange();
        this.notifyPropertyChange('gridView');
      }
    },

    /**
     Refreshes the Slick.DataView and re-renders the Slick.Grid.
     */
    refresh: function () {
      this.setPath('gridAdapter.lastRefresh', null);

      var editState = this.saveEditState();
      var gridAdapter = this.get('gridAdapter');
      if (gridAdapter) gridAdapter.refresh();
      if (this._slickGrid) {
        this._slickGrid.invalidate();
        if (editState) {
          this.restoreEditStateWhenReady(editState);
        }
      }
      // hack: force collection title to be reevaluated
      this.caseCountDidChange();
      this.setPath('gridAdapter.lastRefresh', new Date());
    },

    /**
     SproutCore render method.
     * @param {SC.RenderContext} iContext
     * @param {boolean} iFirstTime
     */
    render: function (iContext, iFirstTime) {
      arguments.callee.base.apply(this,arguments);

      if (this._slickGrid) {
        var gridAdapter = this.get('gridAdapter');
        if (this._rowDataDidChange) {
          gridAdapter.refresh();
        }
        // Render with our changes
        this._slickGrid.render();

        // Clear our invalidation flags
        this._rowDataDidChange = false;
        this._renderRequired = false;
      }
    },

    didAppendToDocument: function () {
      var gridAdapter = this.get('gridAdapter');
      if (!this._slickGrid && SC.none(gridAdapter)) {
        console.log(
            "DG.CaseTableView.didAppendToDocument: Can't initialize _slickGrid!");
        return;
      }

      if (!this._slickGrid) {
        this.initGridView();
        this.set('gridWidth', this._slickGrid.getContentSize().width);
      }

      // initial layout
      this.invokeLater(function () {
        this.ancestorViewDidResizeOrScroll();
      }.bind(this));
    },

    /**
     Returns the touch position in view coordinates.
     @param    {Object}    iTouch The touch event
     @returns  {Object}    The { x:, y: } location of the touch in view coordinates
     */
    touchPosInView: function (iTouch) {
      return this.convertFrameFromView({x: iTouch.pageX, y: iTouch.pageY}, null,
          true);
    },

    /**
     Returns the touch position in table body content coordinates.
     @param    {Object}    iTouch The touch event
     @returns  {Object}    The { x:, y: } location of the touch in table body content coordinates
     */
    touchPosInBodyContent: function (iTouch) {
      var touchPos = this.touchPosInView(iTouch),
          scrollPos = this.get('scrollPos');
      touchPos.y -= kHeaderHeight;
      if (scrollPos) {
        touchPos.x += scrollPos.scrollLeft;
        touchPos.y += scrollPos.scrollTop;
      }
      return touchPos;
    },

    /**
     Returns the cell in which the specified touch event occurred.
     @param    {Object}    iTouch The touch event
     @returns  {Object}    The { row:, cell: } indices of the touched cell
     */
    cellFromTouch: function (iTouch) {
      var cell = {}, touchPos = this.touchPosInView(iTouch);
      if (touchPos.y < kHeaderHeight) {
        // we only care about the column here
        cell = this._slickGrid.getCellFromPoint(touchPos.x, 0);
        cell.row = -1;  // signals header row
      } else {
        cell = this.bodyCellFromTouch(iTouch);
      }
      return cell;
    },

    bodyCellFromTouch: function (iTouch) {
      var touchPos = this.touchPosInBodyContent(iTouch);
      return this._slickGrid.getCellFromPoint(touchPos.x, touchPos.y);
    },

    _touchStartTouch: null,
    _touchStartCell: null,
    _touchDragCell: null,

    captureTouch: function (touch) {
      return YES;
    },

    /**
     Called when the table is scrolled.
     @param  {Slick.Event}   iEvent -- the event which triggered the scroll
     @param  {*} iArgs {{scrollTop: number, scrollLeft: number}}
     */
    handleScroll: function (iEvent, iArgs) {
      this.set('scrollPos', iArgs);
    },

    handleBeforeAutoEditCell: function (iEvent, iArgs) {
      // enable autoEdit for keyboard navigation and for the proto-case row
      var activeRowItem = this._slickGrid.getDataItem(iArgs.row);
      return (iArgs.source === 'navigate') || (activeRowItem && activeRowItem._isProtoCase);
    },

    handleBeforeEditCell: function (iEvent, iArgs) {
      var activeRowItem = this._slickGrid.getDataItem(iArgs.row),
          rowCount = this._slickGrid.getDataLength(),
          lastRowItem = this._slickGrid.getDataItem(rowCount - 1),
          hasProtoCase = lastRowItem && lastRowItem._isProtoCase && DG.ObjectMap.length(
              lastRowItem._values), retval = true;

      this.clearProtoCaseTimer();

      SC.run(function () {
        // editing another case commits the proto-case
        if (!activeRowItem._isProtoCase && hasProtoCase) this.commitProtoCase(
            lastRowItem);

        // editing the proto-case deselects other rows
        if (activeRowItem._isProtoCase) {
          this.get('gridAdapter').deselectAllCases();
        }
        // if attribute not editable and not the proto-case row, then can't edit
        else if (!this.get('gridAdapter').isCellEditable(iArgs.row,
            iArgs.cell)) {
          retval = false;
        } else {
          this.get('gridAdapter').deselectAllCases();
        }
      }.bind(this));
      return retval;
    },

    /**
     Called when a drag is started in a column header cell.
     @param  {Slick.Event}   iEvent -- the event corresponding to the mouse click
     @param  {Object}        iDragData -- additional information about the drag
     */
    handleHeaderDragStart: function (iEvent, iDragData) {
      DG.TouchTooltips.hideAllTouchTooltips();
      // don't show a touch-tooltip after starting a drag
      this.cancelAttrTapHold();

      var column = iDragData.column;
      var hierTableView = this.get('parentView');

      // If we actually don't have an attribute associated with the column
      // (e.g. the '+' column), bail
      if (!column.attribute) {
        return;
      }

      // stopImmediatePropagation() doesn't exist (and apparently isn't necessary)
      // when handling touch events.
      if (iEvent.stopImmediatePropagation) iEvent.stopImmediatePropagation();

      hierTableView.hideHeaderMenus();
      // We make this funky call to mainPane because (we think) SlickGrid has swallowed the mousedown
      // that would normally allow mainPane to hide the inspector picker.
      DG.mainPage.mainPane.hideInspectorPicker();
      var tDragView = this._hiddenDragView,
          tAttributeName = column.attribute.get('name');
      SC.run(function () {
        tDragView.set('value', tAttributeName);
        this.removeChild(tDragView);
        this.appendChild(tDragView);
      }.bind(this));
      // setting attribute and starting drag need to be in separate run loops.
      SC.run(function () {
        // Make sure dragView is in front. Won't actually happen without this runloop.
        // We could dynamically adjust the width here, but since the font used for the
        // drag image is currently different than the one used in the table, it's not
        // clear what the appropriate size should be, so we skip it for now.
        //if( column.width)
        //  tDragView.adjust('width', column.width);
        // Initiate a drag
        DG.Drag.start({
          event: iEvent,
          source: this,
          dragView: tDragView,
          ghost: YES,
          ghostActsLikeCursor: YES,
          slideBack: YES, // The origin is supposed to be the point that the drag view will slide back to,
          // but this is not working.
          origin: {x: iEvent.clientX, y: iEvent.clientY},
          data: {
            context: column.context,
            collection: column.collection,
            attribute: column.attribute,
            text: tAttributeName
          }  // For use by clients like the text box
        });
      });
    },

    /**
     Called when a drag is started in a row resize splitter.
     @param  {Slick.Event}   iEvent -- the event corresponding to the mouse click
     @param  {Object}        iDragData -- additional information about the drag
     */
    handleRowResizeDragInit: function (iEvent, iDragData) {
      DG.TouchTooltips.hideAllTouchTooltips();
      iEvent.stopImmediatePropagation();
    },

    /**
     Called when a drag is started in a row resize splitter.
     @param  {Slick.Event}   iEvent -- the event corresponding to the mouse click
     @param  {Object}        iDragData -- additional information about the drag
     */
    handleRowResizeDragStart: function (iEvent, iDragData) {
      this.$('.slick-viewport').addClass('slick-resizing-row');
      iEvent.stopImmediatePropagation();
    },

    setRowHeight: function (rowHeight) {
      SC.run(function() {
        this.setPath('gridAdapter.rowHeight', rowHeight);
        if (this.getPath('gridAdapter.isMultilineRowHeight'))
          this.$('.slick-viewport').addClass('slick-multiline-cells');
        else
          this.$('.slick-viewport').removeClass('slick-multiline-cells');
        this._slickGrid.setOptions({ rowHeight: rowHeight });
        // force a full re-render
        this.setColumns(this._slickGrid.getColumns());
      }.bind(this));
    },

    /**
     Called when a drag is continued in a row resize splitter.
     @param  {Slick.Event}   iEvent -- the event corresponding to the mouse click
     @param  {Object}        iDragData -- additional information about the drag
     */
    handleRowResizeDrag: function (iEvent, iDragData) {
      this.setRowHeight(iDragData.rowHeight);
    },

    /**
     Called when a drag is ended in a row resize splitter.
     @param  {Slick.Event}   iEvent -- the event corresponding to the mouse click
     @param  {Object}        iDragData -- additional information about the drag
     */
    handleRowResizeDragEnd: function (iEvent, iDragData) {
      this.$('.slick-viewport').removeClass('slick-resizing-row');
    },

    inProgressAttributeEditElementName: null,
    completeEditAttributeName: function () {
      var attrName = this.inProgressAttributeEditElementName;
      var elt = this.$('#attribute-name-editor');
      if (attrName) {
        SC.run(function () {
          var $input = elt, dataContext = this.get('dataContext'),
              newName = dataContext.getUniqueAttributeName($input.val(),
                  [attrName]);
          if (newName !== attrName) {
            var controller = getController(this),
                attrRef = dataContext && dataContext.getAttrRefByName(attrName);
            var changes = {};
            if (newName) {
              changes.name = newName;
            }
            controller.updateAttribute(attrRef, changes);
          }
          else {
            this.updateColumnInfo();
          }
          this.inProgressAttributeEditElementName = null;
        }.bind(this));
      }
    },
    cancelEditAttributeElement: function () {
      SC.run(function () {
        this.updateColumnInfo();
        this.inProgressAttributeEditElementName = null;
      }.bind(this));
    },
    commitCurrentEdit: function () {
      this.completeEditAttributeName();
      DG.globalEditorLock.deactivate(this);
    },
    resetActiveCell: function () {
      this._slickGrid.resetActiveCell();
    },
    cancelCurrentEdit: function () {
      this.cancelEditAttributeElement();
      DG.globalEditorLock.deactivate(this);
    },
    /**
     Makes the attribute name editable in the appropriate column header.
     Since SlickGrid doesn't support editable column headers natively, we use
     jQuery to install an <input> element and manage it completely outside SlickGrid.
     @param  {string}  attrName -- the name of the attribute to be edited
     */
    beginEditAttributeName: function (attrName) {
      var _this = this, gridAdapter = this.get('gridAdapter'),
          column = gridAdapter && gridAdapter.getAttributeColumn(attrName),
          columnIndex = column && column.columnIndex,
          headerColumns = this.$('.slick-header-column'),
          $el = column && $(headerColumns[columnIndex]),
          $nameEl = $el && $el.find('.slick-column-name');

      DG.globalEditorLock.commitCurrentEdit();
      DG.globalEditorLock.activate(this);
      this.inProgressAttributeEditElementName = attrName;
      if ($nameEl) {
        $nameEl.empty().append(
            $('<input>').addClass('dg-attr-name-edit-input').val(attrName));
        this.getPath(
            'parentView.parentView.parentView').scrollDOMElementHorizontallyToView(
            $nameEl[0]);
        var $input = $nameEl.find('input');
        $input.attr({
          type: 'text',
          autocapitalize: 'none',
          autocomplete: 'off',
          autocorrect: 'off',
          inputmode: 'latin-name',
          spellcheck: false,
          id: 'attribute-name-editor'
        })
            .on('mousedown', function (evt) {
              evt.stopImmediatePropagation();
            })
            .on('mouseup', function (evt) {
              evt.stopImmediatePropagation();
            })
            .on('touchstart', function (evt) {
              evt.stopImmediatePropagation();
            })
            .on('touchend', function (evt) {
              evt.stopImmediatePropagation();
            })
            .on('dragstart', function () {
              return false;
            })
            .on('click', function (evt) {
              evt.preventDefault();
              evt.stopImmediatePropagation();
            })
            .on('change', function () {
              _this.completeEditAttributeName(this);
            })
            .on('blur', function () {
              _this.completeEditAttributeName(this);
            })
            .on('keydown', function (evt) {
              switch (evt.keyCode) {
                case 13:
                  _this.completeEditAttributeName(this);
                  break;
                case 27:
                  _this.cancelEditAttributeName(this);
                  break;
              }
            })
            .focus()
            .select();
        // $plusEl.addClass('disabled');
      }
    },

    /**
     Called when a table header cell is clicked.
     @param  {Slick.Event}   iEvent -- the event corresponding to the mouse click
     */
    handleHeaderClick: function (iEvent, iArgs) {
      DG.globalEditorLock.commitCurrentEdit();
    },

    /**
     * Clear menu, if present
     * @param iEvent
     */
    handleClick: function (iEvent, iCell) {
      SC.run(function () {
        function findHierTableViewParent(iView) {
          while (iView && !(iView instanceof DG.HierTableView))
            iView = iView.get('parentView');

          return iView;
        }
        var hierTableView = findHierTableViewParent(this);
        hierTableView.selectComponent();
        hierTableView.contentView.hideHeaderMenus();

        var dataContext = this.get('dataContext'),
            dataItem = this._slickGrid.getDataItem(iCell.row),
            collection = this.getPath(
                'gridAdapter.collection'), // when a group is closed, its slickgrid dataItem is the parent case,
            // so its collection will not match the collection for the current view
            isClosedGroup = dataItem && collection && (dataItem.get(
                'collection').get('id') !== collection.get('id'));
        if (iCell.cell === 0 && !hierTableView.getPath('model.isIndexHidden')) {
          if (DG.DataContextUtilities.isCaseEditable(dataContext, dataItem) && !isClosedGroup)
            this.showCaseIndexPopup(iEvent, iCell);
        }
      }.bind(this));
    },

    /**
     * Handle SlickGrid KeyDown events
     * @param iEvent
     */
    handleKeyDown: function (iEvent) {
      function findLastFocusableColumn(columns) {
        var columnIndex = 0;
        var lastFocusableCell = null;
        while (columnIndex < columns.length) {
          if (columns[columnIndex] && columns[columnIndex].focusable) {
            lastFocusableCell = columnIndex;
          }
          columnIndex += 1;
        }
        return lastFocusableCell;
      }

      function findFirstFocusableColumn(columns) {
        var columnIndex = 0;
        while (columnIndex < columns.length) {
          if (columns[columnIndex] && columns[columnIndex].focusable) {
            return columnIndex;
          }
          columnIndex += 1;
        }
        return null;
      }

      var editorLock = this._slickGrid.getEditorLock(),
          editorIsActive = editorLock && editorLock.isActive(),
          columns = this._slickGrid.getColumns(),
          activeCell = this._slickGrid.getActiveCell(),
          dataItem = activeCell && this._slickGrid.getDataItem(activeCell.row),

          handlePrev = function () {
            this.clearProtoCaseTimer();

            if (!dataItem._isProtoCase || (activeCell.cell > findFirstFocusableColumn(
                columns))) {
              this._slickGrid.navigatePrev();
            }
            // navigating off the proto-case commits it
            else if (editorLock.commitCurrentEdit() && dataItem._isProtoCase && DG.ObjectMap.length(
                dataItem._values)) {
              SC.run(function () {
                this.commitProtoCase(dataItem);
                // wait until everything has refreshed to navigate to the next row
                this.invokeNext(function () {
                  this._slickGrid.navigatePrev();
                }.bind(this));
              }.bind(this));
            } else {
              this._slickGrid.navigatePrev();
            }

            iEvent.stopImmediatePropagation();
          }.bind(this),

          handleNext = function () {
            this.clearProtoCaseTimer();

            if (!dataItem._isProtoCase || (activeCell.cell < findLastFocusableColumn(
                columns))) {
              this._slickGrid.navigateNext();
            }
            // navigating off the proto-case commits it
            else if (editorLock.commitCurrentEdit() && dataItem._isProtoCase && DG.ObjectMap.length(
                dataItem._values)) {
              SC.run(function () {
                this.commitProtoCase(dataItem);
                // wait until everything has refreshed to navigate to the next row
                this.invokeNext(function () {
                  this._slickGrid.navigateNext();
                }.bind(this));
              }.bind(this));
            } else {
              this._slickGrid.editActiveCell();
            }

            iEvent.stopImmediatePropagation();
          }.bind(this),

          handleUp = function () {
            if (!dataItem._isProtoCase) {
              this._slickGrid.navigateUp();
            }
            // navigating off the proto-case commits it
            else if (dataItem._isProtoCase && editorLock.commitCurrentEdit() && DG.ObjectMap.length(
                dataItem._values)) {
              SC.run(function () {
                this.clearProtoCaseTimer();
                this.commitProtoCase(dataItem);
                // wait until everything has refreshed to navigate to the next row
                this.invokeNext(function () {
                  this._slickGrid.navigateUp();
                }.bind(this));
              }.bind(this));
            } else {
              this.clearProtoCaseTimer();
              this._slickGrid.navigateUp();
            }

            iEvent.stopImmediatePropagation();
          }.bind(this),

          handleDown = function () {
            if (!dataItem._isProtoCase) {
              this._slickGrid.navigateDown();
            }
            // navigating off the proto-case commits it
            else if (editorLock.commitCurrentEdit() && dataItem._isProtoCase && DG.ObjectMap.length(
                dataItem._values)) {
              SC.run(function () {
                this.clearProtoCaseTimer();
                this.commitProtoCase(dataItem);
                // wait until everything has refreshed to navigate to the next row
                this.invokeNext(function () {
                  this._slickGrid.navigateDown();
                }.bind(this));
              }.bind(this));
            } else {
              this._slickGrid.editActiveCell();
            }

            iEvent.stopImmediatePropagation();
          }.bind(this);

      if (editorIsActive && dataItem) {
        switch (iEvent.keyCode) {
          case 9:
            if (iEvent.shiftKey) handlePrev(); else handleNext();
            break;
          case 13:
            if (iEvent.shiftKey) handleUp(); else handleDown();
            break;
          case 38:
            handleUp();
            break;
          case 40:
            handleDown();
            break;
        }
      }
    },

    /**
     * Called when column widths changed
     * @param iEvent
     * @param {{grid: SlickGrid}}iArgs
     */
    handleColumnsResized: function (iEvent, iArgs) {
      var parentView = this.get('parentView');
      var model = parentView && parentView.get('model');
      var columnWidths = this.get('columnWidths');
      var oldColumnWidths = {};
      if (model) {
        Object.keys(columnWidths).forEach(function (key) {
          oldColumnWidths[key] = model.getPreferredAttributeWidth(key);
        });
        DG.UndoHistory.execute(DG.Command.create({
          name: 'caseTable.columnResize',
          undoString: 'DG.Undo.caseTable.resizeOneColumn',
          redoString: 'DG.Redo.caseTable.resizeOneColumn',
          log: 'Resize one case table column',
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'resize column',
              type: 'DG.CaseTable'
            }
          },
          execute: function () {
            DG.ObjectMap.forEach(columnWidths, function (key, value) {
              model.setPreferredAttributeWidth(key, value);
            });
            this.updateColumnInfo();
          }.bind(this),
          undo: function () {
            DG.ObjectMap.forEach(oldColumnWidths, function (key, value) {
              model.setPreferredAttributeWidth(key, value);
            });
            this.updateColumnInfo();
          }.bind(this)
        }));
      }
    },

    handleColumnResizing: function (iEvent, iArgs) {
      this.adjustHeaderForOverflow();
    },

    adjustHeaderForOverflow: function () {
      if (this.isComponentDetached()) {
        return;
      }

      /**
       * reverse a string: while doing so, reverse the direction of bracket-like
       * characters.
       */
      function reverse(str) {
        // str.split("").reverse().join("");
        var rMap = {
          '[': ']', ']': '[', '{': '}', '}': '{', '(': ')', ')': '('
        };
        if (!str) return str;
        var s = str.split('');
        var c;
        var ix;
        var n = [];
        for (ix = s.length - 1; ix >= 0; ix -= 1) {
          c = s[ix];
          if (rMap[c]) c = rMap[c];
          n.push(c);
        }
        return n.join('');
      }

      function makeLinePair($el) {
        var text = $el.text().replace(/_/g, ' ');
        var $line1 = $('<span>').addClass('two-line-header-line-1').text(text);
        var $line2 = $('<span>').addClass('two-line-header-line-2').text(
            reverse(text));
        $el.empty().append($line1).append($line2);
      }

      function computeMiddleEllipsis($el) {
        var width = $el.width();
        var height = $el.height();
        var v1 = $('.two-line-header-line-1', $el);
        var style = [
          'font-style:' + v1.css('font-style'),
          'font-variant:' + v1.css('font-variant'),
          'font-weight:' + v1.css('font-weight'),
          'font-stretch:' + v1.css('font-stretch'),
          'line-height:' + v1.css('line-height'),
          'font-size:' + v1.css('font-size'),
          'font-family:' + v1.css('font-family'),
          'width:' + width + 'px',
          'height:' + height + 'px',
          'overflow: auto',
          'white-space: normal',
          '-webkit-hyphens: auto',
          '-ms-hyphens: auto',
          'hyphens: auto',
          'overflow-wrap: break-word'
          ].join(
            ';');

        var text = v1.text();
        var textMeasure = DG.measureText(text, style);
        // DG.log('text, height, width, textMeasure.height, textMeasure.width, ' +
        //     'textMeasure.isOverflowed: ' +
        //     [text, height, width, textMeasure.height, textMeasure.width,
        //       textMeasure.hasOverflowed].join());
        if (textMeasure.hasOverflowed) {
          $el.addClass('two-line-header-truncating');
        } else {
          $el.removeClass('two-line-header-truncating');
        }
      }

      $(this.get('layer')).find('.slick-header-column').each(
          function (ix, cell) {
            // if we are mid-edit of a header field, ignore this attr.
            if ($(cell).find('input').length) {
              return;
            }
            var $nameElement = $(cell).find('.slick-column-name');
            var $line1 = $nameElement.find('.two-line-header-line-1');
            if (!$line1.length) {
              makeLinePair($nameElement);
            }
            computeMiddleEllipsis($nameElement);
          });
    },

    /**
     * Called when column widths changed
     * @param iEvent
     * @param {{grid: SlickGrid}}iArgs
     */
    handleSelectedRowsChanged: function (iEvent, iArgs) {
      var selectedRows = iArgs.rows,
          selectedRowCount = selectedRows && selectedRows.length,
          editorLock = this._slickGrid.getEditorLock(),
          rowCount = this._slickGrid.getDataLength(),
          lastRowItem = this._slickGrid.getDataItem(rowCount - 1),
          hasProtoCase = lastRowItem && lastRowItem._isProtoCase,
          activeCell = this._slickGrid.getActiveCell(),
          isActiveProtoCase = hasProtoCase && activeCell && (activeCell.row === rowCount - 1);

      // if non-proto-case rows are selected, commit the proto-case
      if (selectedRowCount) {
        editorLock.commitCurrentEdit();
        if (isActiveProtoCase && DG.ObjectMap.length(lastRowItem._values)) {
          this.invokeLater(function () {
            SC.run(function () {
              this.commitProtoCase(lastRowItem);
            }.bind(this));
          });
        }
      }
    },

    /**
     Refreshes the column headers to accommodate new attributes.
     Call when the column header info is required for new attributes.
     */
    updateColumnInfo: function () {
      if (this._slickGrid) {
        this.setColumns(this.get('gridAdapter').updateColumnInfo());
        this._slickGrid.invalidate();
      }
    },

    /**
     Refreshes the column headers when attribute information has changed.
     @param  {[object]}  iColumnsInfo -- Array of column entries
     */
    setColumns: function (iColumnsInfo) {
      if (this._slickGrid) {
        this._slickGrid.setColumns(iColumnsInfo);
        this._slickGrid.render();
        // give slickgrid a chance to complete the render.
        this.invokeNext(function () {
          this.adjustHeaderForOverflow();
        });
      }
    },

    /**
     Returns the currently active edit state (if any).
     */
    saveEditState: function () {
      var editor = this._slickGrid && this._slickGrid.getCellEditor(),
          editState = editor && editor.saveEditState(),
          editController = editState && this._slickGrid.getEditController();
      // cancel current edit so it doesn't get committed before restoration
      if (editController) editController.cancelCurrentEdit();
      return editState;
    },

    /**
     Restores a previously active edit state.
     */
    restoreEditState: function (state) {
      var editCase = state && state.item,
          caseId = editCase && editCase.id, editColumn = state && state.column,
          editAttr = editColumn && editColumn.attribute,

          gridAdapter = this.get('gridAdapter'),
          gridDataView = gridAdapter && gridAdapter.get('gridDataView'),
          editRow = gridDataView.getRowById(caseId),
          editCell = editAttr && gridAdapter.getColumnIndexFromAttribute(editAttr);
      if ((editRow != null) && (editRow >= 0) && (editCell != null) && (editCell >= 0)) {
        this._slickGrid.setActiveCell(editRow, editCell);
        this._slickGrid.editActiveCell();
        var activeEditor = this._slickGrid.getCellEditor();
        activeEditor && activeEditor.restoreEditState(state);
      }
    },

    /**
     Waits to update a previously active edit state until sufficient time
     has elapsed since the last table refresh. This allows us to wait until
     the dust settles so that we don't try to restore a previous edit state
     in the middle of a sequence of operations that will just wipe out the
     active edit again.
     */
    restoreEditStateWhenReady: function (state) {
      var restoreWhenReady = function () {
        if (state) {
          var lastRefresh = this.getPath('gridAdapter.lastRefresh'),
              elapsed = lastRefresh ? new Date() - lastRefresh : 0,
              kThreshold = 50;
          if (elapsed >= kThreshold) {
            this.restoreEditState(state);
          } else {
            setTimeout(restoreWhenReady, kThreshold - elapsed);
          }
        }
      }.bind(this);

      if (state) {
        restoreWhenReady();
      }
    },

    /**
     Expands/collapses all of the row groups at once.
     @param    {Boolean}   iExpand -- Expands all row groups if truthy;
     collapses all row groups otherwise
     */
    expandCollapseAll: function (iExpand) {
      var collection = this.getPath('gridAdapter.collection');
      var cases = collection.get('casesController');
      var dataView = this.getPath('gridAdapter.gridDataView');
      var model = this.parentView.get('model');

      DG.assert(collection);
      DG.assert(cases);
      var priorExpCoState = model.get('collapsedNodes');

      DG.UndoHistory.execute(DG.Command.create({
        name: 'caseTable.groupToggleExpandCollapseAll',
        undoString: 'DG.Undo.caseTable.groupToggleExpandCollapseAll',
        redoString: 'DG.Redo.caseTable.groupToggleExpandCollapseAll',
        log: 'Expand/Collapse all',
        executeNotification: {
          action: 'notify',
          resource: 'component',
          values: {
            operation: 'expand/collapse all',
            type: 'DG.CaseTable'
          }
        },
        execute: function () {
          //DG.log('expandCollapseAll: [expand/collection/cases]: '
          //    + [iExpand, this.get('collectionName'), cases.get('length')].join('/'));
          this.beginDataViewUpdate(true);
          cases.forEach(function (myCase) {
            try {
              if (iExpand) {
                dataView.expandGroup(myCase.id);
              } else {
                this.collapseGroup(myCase.id);
              }
            } catch (e) {
              DG.logError('expandCollapseAll: ' + e);
            }
          }.bind(this));
          this.endDataViewUpdate(true);
          this.childTable._refreshDataView(true);
        }.bind(this),
        undo: function () {
          this.beginDataViewUpdate(true);
          cases.forEach(function (myCase) {
            dataView.expandGroup(myCase.id);
          });
          priorExpCoState.forEach(function (caseID) {
            this.collapseGroup(caseID);
          }.bind(this));
          this.updateSelectedRows(true);
          this.incrementProperty('expandCollapseCount');
          this.endDataViewUpdate(true);
          this.childTable._refreshDataView(true);
        }.bind(this),
        redo: function () {
          this.execute();
        }
      }));

    },

    /**
     * This method should be called at the beginning of a multipart update
     * affecting the gridDataView so as to prevent potentially expensive
     * redundant calculations. GridDataView.refresh() will be bypassed until
     * endDataViewUpdate is called.
     * @param recurse {boolean}
     */
    beginDataViewUpdate: function (recurse) {
      var dataView = this.getPath('gridAdapter.gridDataView');
      var childTable = this.get('childTable');
      DG.assert(dataView);
      dataView.beginUpdate();
      if (recurse && childTable) {
        childTable.beginDataViewUpdate(recurse);
      }
    },

    /**
     * Should be called at the end of a multipart update affecting the gridDataView.
     *
     * @param recurse {boolean}
     */
    endDataViewUpdate: function (recurse) {
      var dataView = this.getPath('gridAdapter.gridDataView');
      var childTable = this.get('childTable');
      DG.assert(dataView);
      dataView.endUpdate();
      if (recurse && childTable) {
        childTable.endDataViewUpdate(recurse);
      }
    },

    /**
     Refreshes the row data. Call when the table body needs to be refreshed.
     */
    updateRowData: function () {
      this._rowDataDidChange = true;
      this._renderRequired = true;
      this.displayDidChange();
    },

    /**
     Synchronizes the number of table rows with the number of cases.
     Tries to do so efficiently, but has to rebuild the table in some cases.

     @param  forceRedraw {Boolean} Whether to force a re-indexing of the rows
     */
    updateRowCount: function (forceRedraw) {
      if (!this._slickGrid) return;

      // For now, additions and deletions require complete rebuild.
      // When deletion is handled via DataContext API we can do better.
      this.updateRowData();
      this.updateSelectedRows(true);

      //this._slickGrid.render();
    },

    /**
     * Scrolls the grid to make at least a part of the range of rows in the
     * current view.
     * @param {[number]} rowIndices
     */
    scrollToView: function (rowIndices) {
      var viewport = this.get('gridViewport');
      // if at least one of the specified rows is visible, no need to scroll
      for (var i = 0; i < rowIndices.length; ++i) {
        if ((rowIndices[i] >= viewport.top) && (rowIndices[i] <= viewport.bottom)) return;
      }
      // The bailout above was added because the code below was seen to
      // scroll undesirably in situations in which no scroll was necessary
      // while developing the rowHeight-changing code.
      var minDeltaFromMidViewPort = this.getMinScrollDelta(rowIndices); // in rows
      var viewportHeight = viewport.bottom - viewport.top; // in rows
      var viewportCenterHeight = Math.max(viewportHeight - 4, 0);
      var viewportCenterDelta = (viewportHeight - viewportCenterHeight - 1) / 2;
      var isARowVisible = (Math.abs(
          minDeltaFromMidViewPort) <= (viewportCenterHeight / 2));
      var newTop = Math.max(
          viewport.top + viewportCenterDelta - minDeltaFromMidViewPort, 0);
      // DG.log('collection,minDeltaFromMidViewPort,viewportHeight,viewportCenterHeight,viewportCenterDelta,isARowVisible,newTop=['+[this.get('collectionName'),minDeltaFromMidViewPort,viewportHeight,viewportCenterHeight,viewportCenterDelta,isARowVisible,newTop].join() + ']');
      // The slickgrid viewport is measured in rows and includes the
      // header and partial rows. To guarantee the value is within the visible
      // viewport we add subtract from the viewport height two, for the header
      // rows and one for the partial row.
      if (!isARowVisible && viewport.top !== newTop) {
        this.scrollAnimator.animate(this, viewport.top, newTop);
      }
    },

    animateScrollToTop: function (rowIndex) {
      var viewport = this._slickGrid.getViewport();
      this.scrollAnimator.animate(this, viewport.top, rowIndex);
    },

    /**
     * It is possible that the DOM and SlickGrid get out of sync. This method
     * makes the DOM match Slickgrid's idea of the current scroll state.
     */
    refreshScroll: function () {
      var rowIx = this._slickGrid.getViewport().top;
      this.scrollToRow(0);
      this.scrollToRow(rowIx);
    },

    /**
     * Scrolls the table so that the indicated row is at the top of the displayed
     * region, if possible.
     */
    scrollToRow: function (rowIx) {
      this._slickGrid.scrollRowToTop(rowIx);
    },

    /**
     * Returns the minimum distance of an array of rows to the viewport middle in row units.
     * @param  rowArray {[Number]}   Array of indices of rows
     * @return {Number} number of rows distant
     */
    getMinScrollDelta: function (rowArray) {
      var viewport = this._slickGrid.getViewport(); // viewport.top, .bottom: row units
      var viewMiddle = (viewport.top/* + 3*/ + viewport.bottom) / 2;
      var distances = rowArray.map(function (row) {
        return viewMiddle - row;
      });
      return distances.reduce(function (minimumDist, dist) {
        return (Math.abs(minimumDist) > Math.abs(dist)) ? dist : minimumDist;
      }, Number.MAX_VALUE);
    },

    /**
     * Sets the set of selected rows.
     * @param  iSelectedRows {[Number]}   Array of indices of selected rows
     */
    setSelectedRows: function (iSelectedRows) {
      if (this._slickGrid) {
        this._slickGrid.setSelectedRows(iSelectedRows);
      }
    },

    isComponentDetached: function () {
      var controller = getController(this);
      return controller && !controller.getPath('view.isVisible');
    },

    scrollSelectionToView: function (primaryCase) {
      if (this.isComponentDetached()) {
        return;
      }
      var selectedRows = this._slickGrid.getSelectedRows();
      var collection = this.getPath('gridAdapter.collection');
      if (primaryCase && (primaryCase.getPath(
          'collection.id') === collection.get('id'))) {
        this.scrollToCase(primaryCase.get('id'));
      } else {
        if (selectedRows.length > 0) {
          this.scrollToView(selectedRows);
        } else {
          this._slickGrid.render();
        }
      }
    },

    scrollToCase: function (iCaseID) {
      if (SC.none(iCaseID)) {
        return;
      }
      var dataView = this.getPath('gridAdapter.gridDataView');

      var row = dataView.getRowById(iCaseID);
      if (row < 0) {
        return;
      }
      this.scrollToView([row]);
    },

    /**
     * Reset selection display. If recurse is set will reset child table
     *
     * @param recurse {boolean}
     */
    updateSelectedRows: function (recurse) {
      var adapter = this.get('gridAdapter'),
          selection = adapter && adapter.getSelectedRows(),
          childView = this.get('childTable');
      if (selection) {
        this.setSelectedRows(selection);
      }
      if (recurse && childView) {
        childView.updateSelectedRows(recurse);
      }
    },

    _scrollEventCount: 0,

    /**
     * Scrolls to maintain its relationship with the table on its left.
     *
     * The relationship is defined by the rule that any visible case's parent
     * should be visible.
     *
     * In this case we will scroll this table if first child of the left table's
     * top visible row is lower than the top of this table or the last child of
     * the left table's bottom visible row is higher than the last row.
     *
     * @returns {boolean} Whether a scroll was performed.
     */
    scrollToAlignWithLeft: function () {
      function getRightRowRange(iCase) {
        if (!iCase) {
          DG.log('No case: scrollToAlignWithLeft: %@',
              leftTable.get('collectionName'));
          return;
        }

        if (iCase._isProtoCase) {
          return dataView.getLength() - 1;
        }

        var children = iCase.get('children');
        var c0 = children && children[0];
        var cn = children && children[children.length - 1];
        var rtn;
        if (model.isCollapsedNode(iCase)) {
          rtn = {
            first: dataView.getRowById(iCase)
          };
          rtn.last = rtn.first;
        } else if (c0 && cn) {
          rtn = {
            first: dataView.getRowById(c0.id), last: dataView.getRowById(cn.id)
          };
        }
        return rtn;
      }

      var model = this.getPath('parentView.model');
      var viewport = this.get('gridViewport');
      var viewportHeight = viewport.bottom - viewport.top - 1;
      var dataView = this.getPath('gridAdapter.gridDataView');
      var leftTable = this.get('parentTable');
      var leftViewport = leftTable.get('gridViewport');
      var leftDataView = leftTable.getPath('gridAdapter.gridDataView');
      var didScroll = false;
      if (dataView.getLength() === 0 || leftDataView.getLength() === 0) {
        // nothing to do
        return false;
      }

      function lastItemIndex(dataView, viewport) {
        return Math.max(0, Math.min(dataView.getLength() - 1, viewport.bottom));
      }

      // Find row in this table of first child of top item in left viewport
      var leftTopCase = leftDataView.getItem(leftViewport.top);
      var rightTopRange = getRightRowRange(leftTopCase);

      // Find row in this table of the last child of bottom item in left viewport
      var leftBottomCase = leftDataView.getItem(
          lastItemIndex(leftDataView, leftViewport));
      var rightBottomRange = getRightRowRange(leftBottomCase);

      // If viewport top is less than c0Row, then scroll c0Row to top.
      if (rightTopRange && (rightTopRange.first > viewport.top)) {
        this._slickGrid.scrollRowToTop(rightTopRange.first);
        didScroll = true;
      } else if (rightBottomRange && (rightBottomRange.last < lastItemIndex(
          dataView, viewport))) {
        // if viewport bottom is greater than cnRow, then scroll cnRow to bottom.
        this._slickGrid.scrollRowToTop(rightBottomRange.last - viewportHeight);
        didScroll = true;
      }
      return didScroll;
    },

    /**
     * Scrolls to maintain its relationship with the table on its right.
     *
     * The relationship is defined by the rule that any visible case's parent
     * should be visible.
     *
     * In this case we will scroll this table if the parent of the right table's
     * top visible row is higher than the top of this table or the parent of the
     * table's bottom visible row is lower than the last row of this table.
     *
     * @returns {boolean} Whether a scroll was performed.
     */
    scrollToAlignWithRight: function () {
      //
      function getParentRow(iCase) {
        if (!iCase) {
          DG.log('No case: scrollToAlignWithRight: %@',
              rightTable.get('collectionName'));
          return;
        }
        if (iCase._isProtoCase) {
          return dataView.getLength() - 1;
        }
        var caseInLeftRow = iCase;
        if (!model.isCollapsedNode(iCase)) {
          caseInLeftRow = iCase.get('parent');
        }
        return dataView.getRowById(caseInLeftRow.id);
      }

      var model = this.getPath('parentView.model');
      var viewport = this.get('gridViewport');
      var viewportHeight = viewport.bottom - viewport.top - 1;
      var dataView = this.getPath('gridAdapter.gridDataView');
      var rightTable = this.get('childTable');
      var rightViewport = rightTable && rightTable.get('gridViewport');
      var rightDataView = rightTable && rightTable.getPath(
          'gridAdapter.gridDataView');
      var didScroll = false;
      if (!dataView || (dataView.getLength() === 0) || !rightDataView || (rightDataView.getLength() === 0)) {
        // nothing to do
        return false;
      }


      // Find row in right table of first child, p0Row, of top item in this table
      var topRightCase = rightDataView.getItem(rightViewport.top);
      var p0Row = getParentRow(topRightCase);

      // Find row in right table of the last child, pnRow, of bottom item in left table
      var bottomRightCase = rightDataView.getItem(
          Math.min(rightDataView.getLength() - 1, rightViewport.bottom));
      // if right table DOM not ready yet, this case will not exist. We return.
      var pnRow = getParentRow(bottomRightCase);

      // If viewport top is less than p0Row, then scroll p0Row to top.
      if (p0Row < viewport.top) {
        this._slickGrid.scrollRowToTop(p0Row);
        didScroll = true;
      } else if (pnRow >= Math.min(dataView.getLength() - 1, viewport.bottom)) {
        // if viewport bottom is greater than pnRow, then scroll pnRow to bottom.
        this._slickGrid.scrollRowToTop(pnRow - viewportHeight);
        didScroll = true;
      }
      return didScroll;
    },

    /**
     * Handles click
     *
     * Note that there are two places this click event may be handled: here and
     * in the case_table_row_selection_model. This handler responds to clicks that
     * are not in any case table or menu. The case_table_row_selection_model cannot
     * make decisions, however, depending on whether the component is selected,
     * since the component is always selected by the time the event is fired.
     *
     * @param iEvent {Event}
     * @return {boolean}
     */
    click: function (iEvent) {
      function isInHeader(e) {
        return !!($(e.target).closest(".slick-header-column",
            ".slick-header-columns").length);
      }

      if (this.getPath('gridAdapter.isModelDragging')) return NO;

      var clickedCell = this._slickGrid.getCellFromEvent(iEvent);

      // if we are in the header, bail. This will be handled later.
      if (isInHeader(iEvent)) {
        return NO;
      }

      var tComponentView = DG.ComponentView.findComponentViewParent(this);
      var tIsComponentSelected = tComponentView && tComponentView.get('isSelected');
      var dataContext = this.get('dataContext');
      var selectedCases = dataContext.getSelectedCases();
      var tChange = {
        operation: 'selectCases', cases: [], select: true, extend: false
      };

      // if we clicked in the table body and the component is unselected then we
      // want to select cases iff they were not selected. If the component is
      // selected, we let that pass through.
      if (clickedCell) {
        var clickedCase = this._slickGrid.getDataItem(clickedCell.row);
        if (clickedCase && clickedCase._isProtoCase) {
          dataContext.applyChange({ operation: 'selectCases', select: false });
          return YES;
        }
        if (selectedCases
            && clickedCase
            && (tIsComponentSelected || !(selectedCases.indexOf(clickedCase) >=0))) {
          tChange.cases = [clickedCase];
          dataContext.applyChange(tChange);
          return YES;
        }
      } else if (tIsComponentSelected) {
        dataContext.applyChange(tChange);
      }
      return NO;
    },

    mouseDown: function () {
      DG.TouchTooltips.hideAllTouchTooltips();
      return YES;
    },

    cancelAttrTapHold: function (evt) {
      if (this._attrTapHoldTimer) {
        clearTimeout(this._attrTapHoldTimer);
        this._attrTapHoldTimer = null;
      }
    },

    touchStart: function (evt) {
      DG.TouchTooltips.hideAllTouchTooltips();
      var elt = document.elementFromPoint(evt.clientX, evt.clientY);
      while (elt && !elt.classList.contains('slick-header-column')) {
        elt = elt.parentElement;
      }
      if (elt) {
        this._attrTapHoldTimer = setTimeout(function () {
          DG.TouchTooltips.showTouchTooltip(evt, elt, elt.title);
          this._attrTapHold = null;
        }.bind(this), 500);
      }
      // claim the event so we get the touchEnd
      return YES;
    },

    touchEnd: function (evt) {
      this.cancelAttrTapHold();
      // allows the browser to generate mouse events
      // cf. DG.mainPage.scrollView.touchStart() for details
      evt.allowDefault();
      return YES;
    },

    widenColumnsProportionally: function (factor) {
      var model = this.getPath('parentView.model');
      var columns = this._slickGrid.getColumns();
      columns.forEach(function (column) {
        if (column.attribute) {
          column.width = column.width * factor;
          if (model) {
            model.setPreferredAttributeWidth(column.id, column.width);
          }
        }
      });
      this.setColumns(columns);
    },

    /**
     * Resizes the last column of this case table by delta.
     * @param delta {number} Pixels
     */
    resizeLastColumn: function(delta) {
      var model = this.getPath('parentView.model');
      var columns = this._slickGrid.getColumns();
      var lastColumn = columns[columns.length - 1];
      var lastColumnId = lastColumn.id;
      lastColumn.width = Math.max(lastColumn.width + delta, lastColumn.minWidth);
      if (model) {
        model.setPreferredAttributeWidth(lastColumnId, lastColumn.width);
      }
      this.setColumns(columns);
    }
  };
}())); // end closure

/* >>>>>>>>>> BEGIN source/libraries/raphael.js */
// ┌────────────────────────────────────────────────────────────────────┐ \\
// │ Raphaël 2.1.4 - JavaScript Vector Library                          │ \\
// ├────────────────────────────────────────────────────────────────────┤ \\
// │ Copyright © 2008-2012 Dmitry Baranovskiy (http://raphaeljs.com)    │ \\
// │ Copyright © 2008-2012 Sencha Labs (http://sencha.com)              │ \\
// ├────────────────────────────────────────────────────────────────────┤ \\
// │ Licensed under the MIT (http://raphaeljs.com/license.html) license.│ \\
// └────────────────────────────────────────────────────────────────────┘ \\
// Copyright (c) 2013 Adobe Systems Incorporated. All rights reserved.
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
// 
// http://www.apache.org/licenses/LICENSE-2.0
// 
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
// ┌────────────────────────────────────────────────────────────┐ \\
// │ Eve 0.4.2 - JavaScript Events Library                      │ \\
// ├────────────────────────────────────────────────────────────┤ \\
// │ Author Dmitry Baranovskiy (http://dmitry.baranovskiy.com/) │ \\
// └────────────────────────────────────────────────────────────┘ \\

(function (glob) {
    var version = "0.4.2",
        has = "hasOwnProperty",
        separator = /[\.\/]/,
        wildcard = "*",
        fun = function () {},
        numsort = function (a, b) {
            return a - b;
        },
        current_event,
        stop,
        events = {n: {}},
    /*\
     * eve
     [ method ]

     * Fires event with given `name`, given scope and other parameters.

     > Arguments

     - name (string) name of the *event*, dot (`.`) or slash (`/`) separated
     - scope (object) context for the event handlers
     - varargs (...) the rest of arguments will be sent to event handlers

     = (object) array of returned values from the listeners
    \*/
        eve = function (name, scope) {
			name = String(name);
            var e = events,
                oldstop = stop,
                args = Array.prototype.slice.call(arguments, 2),
                listeners = eve.listeners(name),
                z = 0,
                f = false,
                l,
                indexed = [],
                queue = {},
                out = [],
                ce = current_event,
                errors = [];
            current_event = name;
            stop = 0;
            for (var i = 0, ii = listeners.length; i < ii; i++) if ("zIndex" in listeners[i]) {
                indexed.push(listeners[i].zIndex);
                if (listeners[i].zIndex < 0) {
                    queue[listeners[i].zIndex] = listeners[i];
                }
            }
            indexed.sort(numsort);
            while (indexed[z] < 0) {
                l = queue[indexed[z++]];
                out.push(l.apply(scope, args));
                if (stop) {
                    stop = oldstop;
                    return out;
                }
            }
            for (i = 0; i < ii; i++) {
                l = listeners[i];
                if ("zIndex" in l) {
                    if (l.zIndex == indexed[z]) {
                        out.push(l.apply(scope, args));
                        if (stop) {
                            break;
                        }
                        do {
                            z++;
                            l = queue[indexed[z]];
                            l && out.push(l.apply(scope, args));
                            if (stop) {
                                break;
                            }
                        } while (l)
                    } else {
                        queue[l.zIndex] = l;
                    }
                } else {
                    out.push(l.apply(scope, args));
                    if (stop) {
                        break;
                    }
                }
            }
            stop = oldstop;
            current_event = ce;
            return out.length ? out : null;
        };
		// Undocumented. Debug only.
		eve._events = events;
    /*\
     * eve.listeners
     [ method ]

     * Internal method which gives you array of all event handlers that will be triggered by the given `name`.

     > Arguments

     - name (string) name of the event, dot (`.`) or slash (`/`) separated

     = (array) array of event handlers
    \*/
    eve.listeners = function (name) {
        var names = name.split(separator),
            e = events,
            item,
            items,
            k,
            i,
            ii,
            j,
            jj,
            nes,
            es = [e],
            out = [];
        for (i = 0, ii = names.length; i < ii; i++) {
            nes = [];
            for (j = 0, jj = es.length; j < jj; j++) {
                e = es[j].n;
                items = [e[names[i]], e[wildcard]];
                k = 2;
                while (k--) {
                    item = items[k];
                    if (item) {
                        nes.push(item);
                        out = out.concat(item.f || []);
                    }
                }
            }
            es = nes;
        }
        return out;
    };
    
    /*\
     * eve.on
     [ method ]
     **
     * Binds given event handler with a given name. You can use wildcards “`*`” for the names:
     | eve.on("*.under.*", f);
     | eve("mouse.under.floor"); // triggers f
     * Use @eve to trigger the listener.
     **
     > Arguments
     **
     - name (string) name of the event, dot (`.`) or slash (`/`) separated, with optional wildcards
     - f (function) event handler function
     **
     = (function) returned function accepts a single numeric parameter that represents z-index of the handler. It is an optional feature and only used when you need to ensure that some subset of handlers will be invoked in a given order, despite of the order of assignment. 
     > Example:
     | eve.on("mouse", eatIt)(2);
     | eve.on("mouse", scream);
     | eve.on("mouse", catchIt)(1);
     * This will ensure that `catchIt()` function will be called before `eatIt()`.
	 *
     * If you want to put your handler before non-indexed handlers, specify a negative value.
     * Note: I assume most of the time you don’t need to worry about z-index, but it’s nice to have this feature “just in case”.
    \*/
    eve.on = function (name, f) {
		name = String(name);
		if (typeof f != "function") {
			return function () {};
		}
        var names = name.split(separator),
            e = events;
        for (var i = 0, ii = names.length; i < ii; i++) {
            e = e.n;
            e = e.hasOwnProperty(names[i]) && e[names[i]] || (e[names[i]] = {n: {}});
        }
        e.f = e.f || [];
        for (i = 0, ii = e.f.length; i < ii; i++) if (e.f[i] == f) {
            return fun;
        }
        e.f.push(f);
        return function (zIndex) {
            if (+zIndex == +zIndex) {
                f.zIndex = +zIndex;
            }
        };
    };
    /*\
     * eve.f
     [ method ]
     **
     * Returns function that will fire given event with optional arguments.
	 * Arguments that will be passed to the result function will be also
	 * concated to the list of final arguments.
 	 | el.onclick = eve.f("click", 1, 2);
 	 | eve.on("click", function (a, b, c) {
 	 |     console.log(a, b, c); // 1, 2, [event object]
 	 | });
     > Arguments
	 - event (string) event name
	 - varargs (…) and any other arguments
	 = (function) possible event handler function
    \*/
	eve.f = function (event) {
		var attrs = [].slice.call(arguments, 1);
		return function () {
			eve.apply(null, [event, null].concat(attrs).concat([].slice.call(arguments, 0)));
		};
	};
    /*\
     * eve.stop
     [ method ]
     **
     * Is used inside an event handler to stop the event, preventing any subsequent listeners from firing.
    \*/
    eve.stop = function () {
        stop = 1;
    };
    /*\
     * eve.nt
     [ method ]
     **
     * Could be used inside event handler to figure out actual name of the event.
     **
     > Arguments
     **
     - subname (string) #optional subname of the event
     **
     = (string) name of the event, if `subname` is not specified
     * or
     = (boolean) `true`, if current event’s name contains `subname`
    \*/
    eve.nt = function (subname) {
        if (subname) {
            return new RegExp("(?:\\.|\\/|^)" + subname + "(?:\\.|\\/|$)").test(current_event);
        }
        return current_event;
    };
    /*\
     * eve.nts
     [ method ]
     **
     * Could be used inside event handler to figure out actual name of the event.
     **
     **
     = (array) names of the event
    \*/
    eve.nts = function () {
        return current_event.split(separator);
    };
    /*\
     * eve.off
     [ method ]
     **
     * Removes given function from the list of event listeners assigned to given name.
	 * If no arguments specified all the events will be cleared.
     **
     > Arguments
     **
     - name (string) name of the event, dot (`.`) or slash (`/`) separated, with optional wildcards
     - f (function) event handler function
    \*/
    /*\
     * eve.unbind
     [ method ]
     **
     * See @eve.off
    \*/
    eve.off = eve.unbind = function (name, f) {
		if (!name) {
		    eve._events = events = {n: {}};
			return;
		}
        var names = name.split(separator),
            e,
            key,
            splice,
            i, ii, j, jj,
            cur = [events];
        for (i = 0, ii = names.length; i < ii; i++) {
            for (j = 0; j < cur.length; j += splice.length - 2) {
                splice = [j, 1];
                e = cur[j].n;
                if (names[i] != wildcard) {
                    if (e[names[i]]) {
                        splice.push(e[names[i]]);
                    }
                } else {
                    for (key in e) if (e[has](key)) {
                        splice.push(e[key]);
                    }
                }
                cur.splice.apply(cur, splice);
            }
        }
        for (i = 0, ii = cur.length; i < ii; i++) {
            e = cur[i];
            while (e.n) {
                if (f) {
                    if (e.f) {
                        for (j = 0, jj = e.f.length; j < jj; j++) if (e.f[j] == f) {
                            e.f.splice(j, 1);
                            break;
                        }
                        !e.f.length && delete e.f;
                    }
                    for (key in e.n) if (e.n[has](key) && e.n[key].f) {
                        var funcs = e.n[key].f;
                        for (j = 0, jj = funcs.length; j < jj; j++) if (funcs[j] == f) {
                            funcs.splice(j, 1);
                            break;
                        }
                        !funcs.length && delete e.n[key].f;
                    }
                } else {
                    delete e.f;
                    for (key in e.n) if (e.n[has](key) && e.n[key].f) {
                        delete e.n[key].f;
                    }
                }
                e = e.n;
            }
        }
    };
    /*\
     * eve.once
     [ method ]
     **
     * Binds given event handler with a given name to only run once then unbind itself.
     | eve.once("login", f);
     | eve("login"); // triggers f
     | eve("login"); // no listeners
     * Use @eve to trigger the listener.
     **
     > Arguments
     **
     - name (string) name of the event, dot (`.`) or slash (`/`) separated, with optional wildcards
     - f (function) event handler function
     **
     = (function) same return function as @eve.on
    \*/
    eve.once = function (name, f) {
        var f2 = function () {
            eve.unbind(name, f2);
            return f.apply(this, arguments);
        };
        return eve.on(name, f2);
    };
    /*\
     * eve.version
     [ property (string) ]
     **
     * Current version of the library.
    \*/
    eve.version = version;
    eve.toString = function () {
        return "You are running Eve " + version;
    };
    (typeof module != "undefined" && module.exports) ? (module.exports = eve) : (typeof define != "undefined" ? (define("eve", [], function() { return eve; })) : (glob.eve = eve));
})(this);
// ┌─────────────────────────────────────────────────────────────────────┐ \\
// │ "Raphaël 2.1.2" - JavaScript Vector Library                         │ \\
// ├─────────────────────────────────────────────────────────────────────┤ \\
// │ Copyright (c) 2008-2011 Dmitry Baranovskiy (http://raphaeljs.com)   │ \\
// │ Copyright (c) 2008-2011 Sencha Labs (http://sencha.com)             │ \\
// │ Licensed under the MIT (http://raphaeljs.com/license.html) license. │ \\
// └─────────────────────────────────────────────────────────────────────┘ \\

(function (glob, factory) {
    // AMD support
    if (typeof define === "function" && define.amd) {
        // Define as an anonymous module
        define(["eve"], function( eve ) {
            return factory(glob, eve);
        });
    } else {
        // Browser globals (glob is window)
        // Raphael adds itself to window
        factory(glob, glob.eve || (typeof require == "function" && require('eve')) );
    }
}(this, function (window, eve) {
    /*\
     * Raphael
     [ method ]
     **
     * Creates a canvas object on which to draw.
     * You must do this first, as all future calls to drawing methods
     * from this instance will be bound to this canvas.
     > Parameters
     **
     - container (HTMLElement|string) DOM element or its ID which is going to be a parent for drawing surface
     - width (number)
     - height (number)
     - callback (function) #optional callback function which is going to be executed in the context of newly created paper
     * or
     - x (number)
     - y (number)
     - width (number)
     - height (number)
     - callback (function) #optional callback function which is going to be executed in the context of newly created paper
     * or
     - all (array) (first 3 or 4 elements in the array are equal to [containerID, width, height] or [x, y, width, height]. The rest are element descriptions in format {type: type, <attributes>}). See @Paper.add.
     - callback (function) #optional callback function which is going to be executed in the context of newly created paper
     * or
     - onReadyCallback (function) function that is going to be called on DOM ready event. You can also subscribe to this event via Eve’s “DOMLoad” event. In this case method returns `undefined`.
     = (object) @Paper
     > Usage
     | // Each of the following examples create a canvas
     | // that is 320px wide by 200px high.
     | // Canvas is created at the viewport’s 10,50 coordinate.
     | var paper = Raphael(10, 50, 320, 200);
     | // Canvas is created at the top left corner of the #notepad element
     | // (or its top right corner in dir="rtl" elements)
     | var paper = Raphael(document.getElementById("notepad"), 320, 200);
     | // Same as above
     | var paper = Raphael("notepad", 320, 200);
     | // Image dump
     | var set = Raphael(["notepad", 320, 200, {
     |     type: "rect",
     |     x: 10,
     |     y: 10,
     |     width: 25,
     |     height: 25,
     |     stroke: "#f00"
     | }, {
     |     type: "text",
     |     x: 30,
     |     y: 40,
     |     text: "Dump"
     | }]);
    \*/
    function R(first) {
        if (R.is(first, "function")) {
            return loaded ? first() : eve.on("raphael.DOMload", first);
        } else if (R.is(first, array)) {
            return R._engine.create[apply](R, first.splice(0, 3 + R.is(first[0], nu))).add(first);
        } else {
            var args = Array.prototype.slice.call(arguments, 0);
            if (R.is(args[args.length - 1], "function")) {
                var f = args.pop();
                return loaded ? f.call(R._engine.create[apply](R, args)) : eve.on("raphael.DOMload", function () {
                    f.call(R._engine.create[apply](R, args));
                });
            } else {
                return R._engine.create[apply](R, arguments);
            }
        }
    }
    R.version = "2.1.2";
    R.eve = eve;
    var loaded,
        separator = /[, ]+/,
        elements = {circle: 1, rect: 1, path: 1, ellipse: 1, text: 1, image: 1},
        formatrg = /\{(\d+)\}/g,
        proto = "prototype",
        has = "hasOwnProperty",
        g = {
            doc: document,
            win: window
        },
        oldRaphael = {
            was: Object.prototype[has].call(g.win, "Raphael"),
            is: g.win.Raphael
        },
        Paper = function () {
            /*\
             * Paper.ca
             [ property (object) ]
             **
             * Shortcut for @Paper.customAttributes
            \*/
            /*\
             * Paper.customAttributes
             [ property (object) ]
             **
             * If you have a set of attributes that you would like to represent
             * as a function of some number you can do it easily with custom attributes:
             > Usage
             | paper.customAttributes.hue = function (num) {
             |     num = num % 1;
             |     return {fill: "hsb(" + num + ", 0.75, 1)"};
             | };
             | // Custom attribute “hue” will change fill
             | // to be given hue with fixed saturation and brightness.
             | // Now you can use it like this:
             | var c = paper.circle(10, 10, 10).attr({hue: .45});
             | // or even like this:
             | c.animate({hue: 1}, 1e3);
             |
             | // You could also create custom attribute
             | // with multiple parameters:
             | paper.customAttributes.hsb = function (h, s, b) {
             |     return {fill: "hsb(" + [h, s, b].join(",") + ")"};
             | };
             | c.attr({hsb: "0.5 .8 1"});
             | c.animate({hsb: [1, 0, 0.5]}, 1e3);
            \*/
            this.ca = this.customAttributes = {};
        },
        paperproto,
        appendChild = "appendChild",
        apply = "apply",
        concat = "concat",
        supportsTouch = ('ontouchstart' in g.win) || g.win.DocumentTouch && g.doc instanceof DocumentTouch, //taken from Modernizr touch test
        E = "",
        S = " ",
        Str = String,
        split = "split",
        events = "click dblclick mousedown mousemove mouseout mouseover mouseup touchstart touchmove touchend touchcancel"[split](S),
        touchMap = {
            mousedown: "touchstart",
            mousemove: "touchmove",
            mouseup: "touchend"
        },
        lowerCase = Str.prototype.toLowerCase,
        math = Math,
        mmax = math.max,
        mmin = math.min,
        abs = math.abs,
        pow = math.pow,
        PI = math.PI,
        nu = "number",
        string = "string",
        array = "array",
        toString = "toString",
        fillString = "fill",
        objectToString = Object.prototype.toString,
        paper = {},
        push = "push",
        ISURL = R._ISURL = /^url\(['"]?(.+?)['"]?\)$/i,
        colourRegExp = /^\s*((#[a-f\d]{6})|(#[a-f\d]{3})|rgba?\(\s*([\d\.]+%?\s*,\s*[\d\.]+%?\s*,\s*[\d\.]+%?(?:\s*,\s*[\d\.]+%?)?)\s*\)|hsba?\(\s*([\d\.]+(?:deg|\xb0|%)?\s*,\s*[\d\.]+%?\s*,\s*[\d\.]+(?:%?\s*,\s*[\d\.]+)?)%?\s*\)|hsla?\(\s*([\d\.]+(?:deg|\xb0|%)?\s*,\s*[\d\.]+%?\s*,\s*[\d\.]+(?:%?\s*,\s*[\d\.]+)?)%?\s*\))\s*$/i,
        isnan = {"NaN": 1, "Infinity": 1, "-Infinity": 1},
        bezierrg = /^(?:cubic-)?bezier\(([^,]+),([^,]+),([^,]+),([^\)]+)\)/,
        round = math.round,
        setAttribute = "setAttribute",
        toFloat = parseFloat,
        toInt = parseInt,
        upperCase = Str.prototype.toUpperCase,
        availableAttrs = R._availableAttrs = {
            "arrow-end": "none",
            "arrow-start": "none",
            blur: 0,
            "clip-rect": "0 0 1e9 1e9",
            cursor: "default",
            cx: 0,
            cy: 0,
            fill: "#fff",
            "fill-opacity": 1,
            font: '10px "Arial"',
            "font-family": '"Arial"',
            "font-size": "10",
            "font-style": "normal",
            "font-weight": 400,
            gradient: 0,
            height: 0,
            href: "http://raphaeljs.com/",
            "letter-spacing": 0,
            opacity: 1,
            path: "M0,0",
            r: 0,
            rx: 0,
            ry: 0,
            src: "",
            stroke: "#000",
            "stroke-dasharray": "",
            "stroke-linecap": "butt",
            "stroke-linejoin": "butt",
            "stroke-miterlimit": 0,
            "stroke-opacity": 1,
            "stroke-width": 1,
            target: "_blank",
            "text-anchor": "middle",
            title: "Raphael",
            transform: "",
            width: 0,
            x: 0,
            y: 0
        },
        availableAnimAttrs = R._availableAnimAttrs = {
            blur: nu,
            "clip-rect": "csv",
            cx: nu,
            cy: nu,
            fill: "colour",
            "fill-opacity": nu,
            "font-size": nu,
            height: nu,
            opacity: nu,
            path: "path",
            r: nu,
            rx: nu,
            ry: nu,
            stroke: "colour",
            "stroke-opacity": nu,
            "stroke-width": nu,
            transform: "transform",
            width: nu,
            x: nu,
            y: nu
        },
        whitespace = /[\x09\x0a\x0b\x0c\x0d\x20\xa0\u1680\u180e\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200a\u202f\u205f\u3000\u2028\u2029]/g,
        commaSpaces = /[\x09\x0a\x0b\x0c\x0d\x20\xa0\u1680\u180e\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200a\u202f\u205f\u3000\u2028\u2029]*,[\x09\x0a\x0b\x0c\x0d\x20\xa0\u1680\u180e\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200a\u202f\u205f\u3000\u2028\u2029]*/,
        hsrg = {hs: 1, rg: 1},
        p2s = /,?([achlmqrstvxz]),?/gi,
        pathCommand = /([achlmrqstvz])[\x09\x0a\x0b\x0c\x0d\x20\xa0\u1680\u180e\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200a\u202f\u205f\u3000\u2028\u2029,]*((-?\d*\.?\d*(?:e[\-+]?\d+)?[\x09\x0a\x0b\x0c\x0d\x20\xa0\u1680\u180e\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200a\u202f\u205f\u3000\u2028\u2029]*,?[\x09\x0a\x0b\x0c\x0d\x20\xa0\u1680\u180e\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200a\u202f\u205f\u3000\u2028\u2029]*)+)/ig,
        tCommand = /([rstm])[\x09\x0a\x0b\x0c\x0d\x20\xa0\u1680\u180e\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200a\u202f\u205f\u3000\u2028\u2029,]*((-?\d*\.?\d*(?:e[\-+]?\d+)?[\x09\x0a\x0b\x0c\x0d\x20\xa0\u1680\u180e\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200a\u202f\u205f\u3000\u2028\u2029]*,?[\x09\x0a\x0b\x0c\x0d\x20\xa0\u1680\u180e\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200a\u202f\u205f\u3000\u2028\u2029]*)+)/ig,
        pathValues = /(-?\d*\.?\d*(?:e[\-+]?\d+)?)[\x09\x0a\x0b\x0c\x0d\x20\xa0\u1680\u180e\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200a\u202f\u205f\u3000\u2028\u2029]*,?[\x09\x0a\x0b\x0c\x0d\x20\xa0\u1680\u180e\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200a\u202f\u205f\u3000\u2028\u2029]*/ig,
        radial_gradient = R._radial_gradient = /^r(?:\(([^,]+?)[\x09\x0a\x0b\x0c\x0d\x20\xa0\u1680\u180e\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200a\u202f\u205f\u3000\u2028\u2029]*,[\x09\x0a\x0b\x0c\x0d\x20\xa0\u1680\u180e\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200a\u202f\u205f\u3000\u2028\u2029]*([^\)]+?)\))?/,
        eldata = {},
        sortByKey = function (a, b) {
            return a.key - b.key;
        },
        sortByNumber = function (a, b) {
            return toFloat(a) - toFloat(b);
        },
        fun = function () {},
        pipe = function (x) {
            return x;
        },
        rectPath = R._rectPath = function (x, y, w, h, r) {
            if (r) {
                return [["M", x + r, y], ["l", w - r * 2, 0], ["a", r, r, 0, 0, 1, r, r], ["l", 0, h - r * 2], ["a", r, r, 0, 0, 1, -r, r], ["l", r * 2 - w, 0], ["a", r, r, 0, 0, 1, -r, -r], ["l", 0, r * 2 - h], ["a", r, r, 0, 0, 1, r, -r], ["z"]];
            }
            return [["M", x, y], ["l", w, 0], ["l", 0, h], ["l", -w, 0], ["z"]];
        },
        ellipsePath = function (x, y, rx, ry) {
            if (ry == null) {
                ry = rx;
            }
            return [["M", x, y], ["m", 0, -ry], ["a", rx, ry, 0, 1, 1, 0, 2 * ry], ["a", rx, ry, 0, 1, 1, 0, -2 * ry], ["z"]];
        },
        getPath = R._getPath = {
            path: function (el) {
                return el.attr("path");
            },
            circle: function (el) {
                var a = el.attrs;
                return ellipsePath(a.cx, a.cy, a.r);
            },
            ellipse: function (el) {
                var a = el.attrs;
                return ellipsePath(a.cx, a.cy, a.rx, a.ry);
            },
            rect: function (el) {
                var a = el.attrs;
                return rectPath(a.x, a.y, a.width, a.height, a.r);
            },
            image: function (el) {
                var a = el.attrs;
                return rectPath(a.x, a.y, a.width, a.height);
            },
            text: function (el) {
                var bbox = el._getBBox();
                return rectPath(bbox.x, bbox.y, bbox.width, bbox.height);
            },
            set : function(el) {
                var bbox = el._getBBox();
                return rectPath(bbox.x, bbox.y, bbox.width, bbox.height);
            }
        },
        /*\
         * Raphael.mapPath
         [ method ]
         **
         * Transform the path string with given matrix.
         > Parameters
         - path (string) path string
         - matrix (object) see @Matrix
         = (string) transformed path string
        \*/
        mapPath = R.mapPath = function (path, matrix) {
            if (!matrix) {
                return path;
            }
            var x, y, i, j, ii, jj, pathi;
            path = path2curve(path);
            for (i = 0, ii = path.length; i < ii; i++) {
                pathi = path[i];
                for (j = 1, jj = pathi.length; j < jj; j += 2) {
                    x = matrix.x(pathi[j], pathi[j + 1]);
                    y = matrix.y(pathi[j], pathi[j + 1]);
                    pathi[j] = x;
                    pathi[j + 1] = y;
                }
            }
            return path;
        };

    R._g = g;
    /*\
     * Raphael.type
     [ property (string) ]
     **
     * Can be “SVG”, “VML” or empty, depending on browser support.
    \*/
    R.type = (g.win.SVGAngle || g.doc.implementation.hasFeature("http://www.w3.org/TR/SVG11/feature#BasicStructure", "1.1") ? "SVG" : "VML");
    if (R.type == "VML") {
        var d = g.doc.createElement("div"),
            b;
        d.innerHTML = '<v:shape adj="1"/>';
        b = d.firstChild;
        b.style.behavior = "url(#default#VML)";
        if (!(b && typeof b.adj == "object")) {
            return (R.type = E);
        }
        d = null;
    }
    /*\
     * Raphael.svg
     [ property (boolean) ]
     **
     * `true` if browser supports SVG.
    \*/
    /*\
     * Raphael.vml
     [ property (boolean) ]
     **
     * `true` if browser supports VML.
    \*/
    R.svg = !(R.vml = R.type == "VML");
    R._Paper = Paper;
    /*\
     * Raphael.fn
     [ property (object) ]
     **
     * You can add your own method to the canvas. For example if you want to draw a pie chart,
     * you can create your own pie chart function and ship it as a Raphaël plugin. To do this
     * you need to extend the `Raphael.fn` object. You should modify the `fn` object before a
     * Raphaël instance is created, otherwise it will take no effect. Please note that the
     * ability for namespaced plugins was removed in Raphael 2.0. It is up to the plugin to
     * ensure any namespacing ensures proper context.
     > Usage
     | Raphael.fn.arrow = function (x1, y1, x2, y2, size) {
     |     return this.path( ... );
     | };
     | // or create namespace
     | Raphael.fn.mystuff = {
     |     arrow: function () {…},
     |     star: function () {…},
     |     // etc…
     | };
     | var paper = Raphael(10, 10, 630, 480);
     | // then use it
     | paper.arrow(10, 10, 30, 30, 5).attr({fill: "#f00"});
     | paper.mystuff.arrow();
     | paper.mystuff.star();
    \*/
    R.fn = paperproto = Paper.prototype = R.prototype;
    R._id = 0;
    R._oid = 0;
    /*\
     * Raphael.is
     [ method ]
     **
     * Handful of replacements for `typeof` operator.
     > Parameters
     - o (…) any object or primitive
     - type (string) name of the type, i.e. “string”, “function”, “number”, etc.
     = (boolean) is given value is of given type
    \*/
    R.is = function (o, type) {
        type = lowerCase.call(type);
        if (type == "finite") {
            return !isnan[has](+o);
        }
        if (type == "array") {
            return o instanceof Array;
        }
        return  (type == "null" && o === null) ||
                (type == typeof o && o !== null) ||
                (type == "object" && o === Object(o)) ||
                (type == "array" && Array.isArray && Array.isArray(o)) ||
                objectToString.call(o).slice(8, -1).toLowerCase() == type;
    };

    function clone(obj) {
        if (typeof obj == "function" || Object(obj) !== obj) {
            return obj;
        }
        var res = new obj.constructor;
        for (var key in obj) if (obj[has](key)) {
            res[key] = clone(obj[key]);
        }
        return res;
    }

    /*\
     * Raphael.angle
     [ method ]
     **
     * Returns angle between two or three points
     > Parameters
     - x1 (number) x coord of first point
     - y1 (number) y coord of first point
     - x2 (number) x coord of second point
     - y2 (number) y coord of second point
     - x3 (number) #optional x coord of third point
     - y3 (number) #optional y coord of third point
     = (number) angle in degrees.
    \*/
    R.angle = function (x1, y1, x2, y2, x3, y3) {
        if (x3 == null) {
            var x = x1 - x2,
                y = y1 - y2;
            if (!x && !y) {
                return 0;
            }
            return (180 + math.atan2(-y, -x) * 180 / PI + 360) % 360;
        } else {
            return R.angle(x1, y1, x3, y3) - R.angle(x2, y2, x3, y3);
        }
    };
    /*\
     * Raphael.rad
     [ method ]
     **
     * Transform angle to radians
     > Parameters
     - deg (number) angle in degrees
     = (number) angle in radians.
    \*/
    R.rad = function (deg) {
        return deg % 360 * PI / 180;
    };
    /*\
     * Raphael.deg
     [ method ]
     **
     * Transform angle to degrees
     > Parameters
     - rad (number) angle in radians
     = (number) angle in degrees.
    \*/
    R.deg = function (rad) {
        return Math.round ((rad * 180 / PI% 360)* 1000) / 1000;
    };
    /*\
     * Raphael.snapTo
     [ method ]
     **
     * Snaps given value to given grid.
     > Parameters
     - values (array|number) given array of values or step of the grid
     - value (number) value to adjust
     - tolerance (number) #optional tolerance for snapping. Default is `10`.
     = (number) adjusted value.
    \*/
    R.snapTo = function (values, value, tolerance) {
        tolerance = R.is(tolerance, "finite") ? tolerance : 10;
        if (R.is(values, array)) {
            var i = values.length;
            while (i--) if (abs(values[i] - value) <= tolerance) {
                return values[i];
            }
        } else {
            values = +values;
            var rem = value % values;
            if (rem < tolerance) {
                return value - rem;
            }
            if (rem > values - tolerance) {
                return value - rem + values;
            }
        }
        return value;
    };

    /*\
     * Raphael.createUUID
     [ method ]
     **
     * Returns RFC4122, version 4 ID
    \*/
    var createUUID = R.createUUID = (function (uuidRegEx, uuidReplacer) {
        return function () {
            return "xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(uuidRegEx, uuidReplacer).toUpperCase();
        };
    })(/[xy]/g, function (c) {
        var r = math.random() * 16 | 0,
            v = c == "x" ? r : (r & 3 | 8);
        return v.toString(16);
    });

    /*\
     * Raphael.setWindow
     [ method ]
     **
     * Used when you need to draw in `&lt;iframe>`. Switched window to the iframe one.
     > Parameters
     - newwin (window) new window object
    \*/
    R.setWindow = function (newwin) {
        eve("raphael.setWindow", R, g.win, newwin);
        g.win = newwin;
        g.doc = g.win.document;
        if (R._engine.initWin) {
            R._engine.initWin(g.win);
        }
    };
    var toHex = function (color) {
        if (R.vml) {
            // http://dean.edwards.name/weblog/2009/10/convert-any-colour-value-to-hex-in-msie/
            var trim = /^\s+|\s+$/g;
            var bod;
            try {
                var docum = new ActiveXObject("htmlfile");
                docum.write("<body>");
                docum.close();
                bod = docum.body;
            } catch(e) {
                bod = createPopup().document.body;
            }
            var range = bod.createTextRange();
            toHex = cacher(function (color) {
                try {
                    bod.style.color = Str(color).replace(trim, E);
                    var value = range.queryCommandValue("ForeColor");
                    value = ((value & 255) << 16) | (value & 65280) | ((value & 16711680) >>> 16);
                    return "#" + ("000000" + value.toString(16)).slice(-6);
                } catch(e) {
                    return "none";
                }
            });
        } else {
            var i = g.doc.createElement("i");
            i.title = "Rapha\xebl Colour Picker";
            i.style.display = "none";
            g.doc.body.appendChild(i);
            toHex = cacher(function (color) {
                i.style.color = color;
                return g.doc.defaultView.getComputedStyle(i, E).getPropertyValue("color");
            });
        }
        return toHex(color);
    },
    hsbtoString = function () {
        return "hsb(" + [this.h, this.s, this.b] + ")";
    },
    hsltoString = function () {
        return "hsl(" + [this.h, this.s, this.l] + ")";
    },
    rgbtoString = function () {
        return this.hex;
    },
    prepareRGB = function (r, g, b) {
        if (g == null && R.is(r, "object") && "r" in r && "g" in r && "b" in r) {
            b = r.b;
            g = r.g;
            r = r.r;
        }
        if (g == null && R.is(r, string)) {
            var clr = R.getRGB(r);
            r = clr.r;
            g = clr.g;
            b = clr.b;
        }
        if (r > 1 || g > 1 || b > 1) {
            r /= 255;
            g /= 255;
            b /= 255;
        }

        return [r, g, b];
    },
    packageRGB = function (r, g, b, o) {
        r *= 255;
        g *= 255;
        b *= 255;
        var rgb = {
            r: r,
            g: g,
            b: b,
            hex: R.rgb(r, g, b),
            toString: rgbtoString
        };
        R.is(o, "finite") && (rgb.opacity = o);
        return rgb;
    };

    /*\
     * Raphael.color
     [ method ]
     **
     * Parses the color string and returns object with all values for the given color.
     > Parameters
     - clr (string) color string in one of the supported formats (see @Raphael.getRGB)
     = (object) Combined RGB & HSB object in format:
     o {
     o     r (number) red,
     o     g (number) green,
     o     b (number) blue,
     o     hex (string) color in HTML/CSS format: #••••••,
     o     error (boolean) `true` if string can’t be parsed,
     o     h (number) hue,
     o     s (number) saturation,
     o     v (number) value (brightness),
     o     l (number) lightness
     o }
    \*/
    R.color = function (clr) {
        var rgb;
        if (R.is(clr, "object") && "h" in clr && "s" in clr && "b" in clr) {
            rgb = R.hsb2rgb(clr);
            clr.r = rgb.r;
            clr.g = rgb.g;
            clr.b = rgb.b;
            clr.hex = rgb.hex;
        } else if (R.is(clr, "object") && "h" in clr && "s" in clr && "l" in clr) {
            rgb = R.hsl2rgb(clr);
            clr.r = rgb.r;
            clr.g = rgb.g;
            clr.b = rgb.b;
            clr.hex = rgb.hex;
        } else {
            if (R.is(clr, "string")) {
                clr = R.getRGB(clr);
            }
            if (R.is(clr, "object") && "r" in clr && "g" in clr && "b" in clr) {
                rgb = R.rgb2hsl(clr);
                clr.h = rgb.h;
                clr.s = rgb.s;
                clr.l = rgb.l;
                rgb = R.rgb2hsb(clr);
                clr.v = rgb.b;
            } else {
                clr = {hex: "none"};
                clr.r = clr.g = clr.b = clr.h = clr.s = clr.v = clr.l = -1;
            }
        }
        clr.toString = rgbtoString;
        return clr;
    };
    /*\
     * Raphael.hsb2rgb
     [ method ]
     **
     * Converts HSB values to RGB object.
     > Parameters
     - h (number) hue
     - s (number) saturation
     - v (number) value or brightness
     = (object) RGB object in format:
     o {
     o     r (number) red,
     o     g (number) green,
     o     b (number) blue,
     o     hex (string) color in HTML/CSS format: #••••••
     o }
    \*/
    R.hsb2rgb = function (h, s, v, o) {
        if (this.is(h, "object") && "h" in h && "s" in h && "b" in h) {
            v = h.b;
            s = h.s;
            o = h.o;
            h = h.h;
        }
        h *= 360;
        var R, G, B, X, C;
        h = (h % 360) / 60;
        C = v * s;
        X = C * (1 - abs(h % 2 - 1));
        R = G = B = v - C;

        h = ~~h;
        R += [C, X, 0, 0, X, C][h];
        G += [X, C, C, X, 0, 0][h];
        B += [0, 0, X, C, C, X][h];
        return packageRGB(R, G, B, o);
    };
    /*\
     * Raphael.hsl2rgb
     [ method ]
     **
     * Converts HSL values to RGB object.
     > Parameters
     - h (number) hue
     - s (number) saturation
     - l (number) luminosity
     = (object) RGB object in format:
     o {
     o     r (number) red,
     o     g (number) green,
     o     b (number) blue,
     o     hex (string) color in HTML/CSS format: #••••••
     o }
    \*/
    R.hsl2rgb = function (h, s, l, o) {
        if (this.is(h, "object") && "h" in h && "s" in h && "l" in h) {
            l = h.l;
            s = h.s;
            h = h.h;
        }
        if (h > 1 || s > 1 || l > 1) {
            h /= 360;
            s /= 100;
            l /= 100;
        }
        h *= 360;
        var R, G, B, X, C;
        h = (h % 360) / 60;
        C = 2 * s * (l < .5 ? l : 1 - l);
        X = C * (1 - abs(h % 2 - 1));
        R = G = B = l - C / 2;

        h = ~~h;
        R += [C, X, 0, 0, X, C][h];
        G += [X, C, C, X, 0, 0][h];
        B += [0, 0, X, C, C, X][h];
        return packageRGB(R, G, B, o);
    };
    /*\
     * Raphael.rgb2hsb
     [ method ]
     **
     * Converts RGB values to HSB object.
     > Parameters
     - r (number) red
     - g (number) green
     - b (number) blue
     = (object) HSB object in format:
     o {
     o     h (number) hue
     o     s (number) saturation
     o     b (number) brightness
     o }
    \*/
    R.rgb2hsb = function (r, g, b) {
        b = prepareRGB(r, g, b);
        r = b[0];
        g = b[1];
        b = b[2];

        var H, S, V, C;
        V = mmax(r, g, b);
        C = V - mmin(r, g, b);
        H = (C == 0 ? null :
             V == r ? (g - b) / C :
             V == g ? (b - r) / C + 2 :
                      (r - g) / C + 4
            );
        H = ((H + 360) % 6) * 60 / 360;
        S = C == 0 ? 0 : C / V;
        return {h: H, s: S, b: V, toString: hsbtoString};
    };
    /*\
     * Raphael.rgb2hsl
     [ method ]
     **
     * Converts RGB values to HSL object.
     > Parameters
     - r (number) red
     - g (number) green
     - b (number) blue
     = (object) HSL object in format:
     o {
     o     h (number) hue
     o     s (number) saturation
     o     l (number) luminosity
     o }
    \*/
    R.rgb2hsl = function (r, g, b) {
        b = prepareRGB(r, g, b);
        r = b[0];
        g = b[1];
        b = b[2];

        var H, S, L, M, m, C;
        M = mmax(r, g, b);
        m = mmin(r, g, b);
        C = M - m;
        H = (C == 0 ? null :
             M == r ? (g - b) / C :
             M == g ? (b - r) / C + 2 :
                      (r - g) / C + 4);
        H = ((H + 360) % 6) * 60 / 360;
        L = (M + m) / 2;
        S = (C == 0 ? 0 :
             L < .5 ? C / (2 * L) :
                      C / (2 - 2 * L));
        return {h: H, s: S, l: L, toString: hsltoString};
    };
    R._path2string = function () {
        return this.join(",").replace(p2s, "$1");
    };
    function repush(array, item) {
        for (var i = 0, ii = array.length; i < ii; i++) if (array[i] === item) {
            return array.push(array.splice(i, 1)[0]);
        }
    }
    function cacher(f, scope, postprocessor) {
        function newf() {
            var arg = Array.prototype.slice.call(arguments, 0),
                args = arg.join("\u2400"),
                cache = newf.cache = newf.cache || {},
                count = newf.count = newf.count || [];
            if (cache[has](args)) {
                repush(count, args);
                return postprocessor ? postprocessor(cache[args]) : cache[args];
            }
            count.length >= 1e3 && delete cache[count.shift()];
            count.push(args);
            cache[args] = f[apply](scope, arg);
            return postprocessor ? postprocessor(cache[args]) : cache[args];
        }
        return newf;
    }

    var preload = R._preload = function (src, f) {
        var img = g.doc.createElement("img");
        img.style.cssText = "position:absolute;left:-9999em;top:-9999em";
        img.onload = function () {
            f.call(this);
            this.onload = null;
            g.doc.body.removeChild(this);
        };
        img.onerror = function () {
            g.doc.body.removeChild(this);
        };
        g.doc.body.appendChild(img);
        img.src = src;
    };

    function clrToString() {
        return this.hex;
    }

    /*\
     * Raphael.getRGB
     [ method ]
     **
     * Parses colour string as RGB object
     > Parameters
     - colour (string) colour string in one of formats:
     # <ul>
     #     <li>Colour name (“<code>red</code>”, “<code>green</code>”, “<code>cornflowerblue</code>”, etc)</li>
     #     <li>#••• — shortened HTML colour: (“<code>#000</code>”, “<code>#fc0</code>”, etc)</li>
     #     <li>#•••••• — full length HTML colour: (“<code>#000000</code>”, “<code>#bd2300</code>”)</li>
     #     <li>rgb(•••, •••, •••) — red, green and blue channels’ values: (“<code>rgb(200,&nbsp;100,&nbsp;0)</code>”)</li>
     #     <li>rgb(•••%, •••%, •••%) — same as above, but in %: (“<code>rgb(100%,&nbsp;175%,&nbsp;0%)</code>”)</li>
     #     <li>hsb(•••, •••, •••) — hue, saturation and brightness values: (“<code>hsb(0.5,&nbsp;0.25,&nbsp;1)</code>”)</li>
     #     <li>hsb(•••%, •••%, •••%) — same as above, but in %</li>
     #     <li>hsl(•••, •••, •••) — same as hsb</li>
     #     <li>hsl(•••%, •••%, •••%) — same as hsb</li>
     # </ul>
     = (object) RGB object in format:
     o {
     o     r (number) red,
     o     g (number) green,
     o     b (number) blue
     o     hex (string) color in HTML/CSS format: #••••••,
     o     error (boolean) true if string can’t be parsed
     o }
    \*/
    R.getRGB = cacher(function (colour) {
        if (!colour || !!((colour = Str(colour)).indexOf("-") + 1)) {
            return {r: -1, g: -1, b: -1, hex: "none", error: 1, toString: clrToString};
        }
        if (colour == "none") {
            return {r: -1, g: -1, b: -1, hex: "none", toString: clrToString};
        }
        !(hsrg[has](colour.toLowerCase().substring(0, 2)) || colour.charAt() == "#") && (colour = toHex(colour));
        var res,
            red,
            green,
            blue,
            opacity,
            t,
            values,
            rgb = colour.match(colourRegExp);
        if (rgb) {
            if (rgb[2]) {
                blue = toInt(rgb[2].substring(5), 16);
                green = toInt(rgb[2].substring(3, 5), 16);
                red = toInt(rgb[2].substring(1, 3), 16);
            }
            if (rgb[3]) {
                blue = toInt((t = rgb[3].charAt(3)) + t, 16);
                green = toInt((t = rgb[3].charAt(2)) + t, 16);
                red = toInt((t = rgb[3].charAt(1)) + t, 16);
            }
            if (rgb[4]) {
                values = rgb[4][split](commaSpaces);
                red = toFloat(values[0]);
                values[0].slice(-1) == "%" && (red *= 2.55);
                green = toFloat(values[1]);
                values[1].slice(-1) == "%" && (green *= 2.55);
                blue = toFloat(values[2]);
                values[2].slice(-1) == "%" && (blue *= 2.55);
                rgb[1].toLowerCase().slice(0, 4) == "rgba" && (opacity = toFloat(values[3]));
                values[3] && values[3].slice(-1) == "%" && (opacity /= 100);
            }
            if (rgb[5]) {
                values = rgb[5][split](commaSpaces);
                red = toFloat(values[0]);
                values[0].slice(-1) == "%" && (red *= 2.55);
                green = toFloat(values[1]);
                values[1].slice(-1) == "%" && (green *= 2.55);
                blue = toFloat(values[2]);
                values[2].slice(-1) == "%" && (blue *= 2.55);
                (values[0].slice(-3) == "deg" || values[0].slice(-1) == "\xb0") && (red /= 360);
                rgb[1].toLowerCase().slice(0, 4) == "hsba" && (opacity = toFloat(values[3]));
                values[3] && values[3].slice(-1) == "%" && (opacity /= 100);
                return R.hsb2rgb(red, green, blue, opacity);
            }
            if (rgb[6]) {
                values = rgb[6][split](commaSpaces);
                red = toFloat(values[0]);
                values[0].slice(-1) == "%" && (red *= 2.55);
                green = toFloat(values[1]);
                values[1].slice(-1) == "%" && (green *= 2.55);
                blue = toFloat(values[2]);
                values[2].slice(-1) == "%" && (blue *= 2.55);
                (values[0].slice(-3) == "deg" || values[0].slice(-1) == "\xb0") && (red /= 360);
                rgb[1].toLowerCase().slice(0, 4) == "hsla" && (opacity = toFloat(values[3]));
                values[3] && values[3].slice(-1) == "%" && (opacity /= 100);
                return R.hsl2rgb(red, green, blue, opacity);
            }
            rgb = {r: red, g: green, b: blue, toString: clrToString};
            rgb.hex = "#" + (16777216 | blue | (green << 8) | (red << 16)).toString(16).slice(1);
            R.is(opacity, "finite") && (rgb.opacity = opacity);
            return rgb;
        }
        return {r: -1, g: -1, b: -1, hex: "none", error: 1, toString: clrToString};
    }, R);
    /*\
     * Raphael.hsb
     [ method ]
     **
     * Converts HSB values to hex representation of the colour.
     > Parameters
     - h (number) hue
     - s (number) saturation
     - b (number) value or brightness
     = (string) hex representation of the colour.
    \*/
    R.hsb = cacher(function (h, s, b) {
        return R.hsb2rgb(h, s, b).hex;
    });
    /*\
     * Raphael.hsl
     [ method ]
     **
     * Converts HSL values to hex representation of the colour.
     > Parameters
     - h (number) hue
     - s (number) saturation
     - l (number) luminosity
     = (string) hex representation of the colour.
    \*/
    R.hsl = cacher(function (h, s, l) {
        return R.hsl2rgb(h, s, l).hex;
    });
    /*\
     * Raphael.rgb
     [ method ]
     **
     * Converts RGB values to hex representation of the colour.
     > Parameters
     - r (number) red
     - g (number) green
     - b (number) blue
     = (string) hex representation of the colour.
    \*/
    R.rgb = cacher(function (r, g, b) {
        return "#" + (16777216 | b | (g << 8) | (r << 16)).toString(16).slice(1);
    });
    /*\
     * Raphael.getColor
     [ method ]
     **
     * On each call returns next colour in the spectrum. To reset it back to red call @Raphael.getColor.reset
     > Parameters
     - value (number) #optional brightness, default is `0.75`
     = (string) hex representation of the colour.
    \*/
    R.getColor = function (value) {
        var start = this.getColor.start = this.getColor.start || {h: 0, s: 1, b: value || .75},
            rgb = this.hsb2rgb(start.h, start.s, start.b);
        start.h += .075;
        if (start.h > 1) {
            start.h = 0;
            start.s -= .2;
            start.s <= 0 && (this.getColor.start = {h: 0, s: 1, b: start.b});
        }
        return rgb.hex;
    };
    /*\
     * Raphael.getColor.reset
     [ method ]
     **
     * Resets spectrum position for @Raphael.getColor back to red.
    \*/
    R.getColor.reset = function () {
        delete this.start;
    };

    // http://schepers.cc/getting-to-the-point
    function catmullRom2bezier(crp, z) {
        var d = [];
        for (var i = 0, iLen = crp.length; iLen - 2 * !z > i; i += 2) {
            var p = [
                        {x: +crp[i - 2], y: +crp[i - 1]},
                        {x: +crp[i],     y: +crp[i + 1]},
                        {x: +crp[i + 2], y: +crp[i + 3]},
                        {x: +crp[i + 4], y: +crp[i + 5]}
                    ];
            if (z) {
                if (!i) {
                    p[0] = {x: +crp[iLen - 2], y: +crp[iLen - 1]};
                } else if (iLen - 4 == i) {
                    p[3] = {x: +crp[0], y: +crp[1]};
                } else if (iLen - 2 == i) {
                    p[2] = {x: +crp[0], y: +crp[1]};
                    p[3] = {x: +crp[2], y: +crp[3]};
                }
            } else {
                if (iLen - 4 == i) {
                    p[3] = p[2];
                } else if (!i) {
                    p[0] = {x: +crp[i], y: +crp[i + 1]};
                }
            }
            d.push(["C",
                  (-p[0].x + 6 * p[1].x + p[2].x) / 6,
                  (-p[0].y + 6 * p[1].y + p[2].y) / 6,
                  (p[1].x + 6 * p[2].x - p[3].x) / 6,
                  (p[1].y + 6*p[2].y - p[3].y) / 6,
                  p[2].x,
                  p[2].y
            ]);
        }

        return d;
    }
    /*\
     * Raphael.parsePathString
     [ method ]
     **
     * Utility method
     **
     * Parses given path string into an array of arrays of path segments.
     > Parameters
     - pathString (string|array) path string or array of segments (in the last case it will be returned straight away)
     = (array) array of segments.
    \*/
    R.parsePathString = function (pathString) {
        if (!pathString) {
            return null;
        }
        var pth = paths(pathString);
        if (pth.arr) {
            return pathClone(pth.arr);
        }

        var paramCounts = {a: 7, c: 6, h: 1, l: 2, m: 2, r: 4, q: 4, s: 4, t: 2, v: 1, z: 0},
            data = [];
        if (R.is(pathString, array) && R.is(pathString[0], array)) { // rough assumption
            data = pathClone(pathString);
        }
        if (!data.length) {
            Str(pathString).replace(pathCommand, function (a, b, c) {
                var params = [],
                    name = b.toLowerCase();
                c.replace(pathValues, function (a, b) {
                    b && params.push(+b);
                });
                if (name == "m" && params.length > 2) {
                    data.push([b][concat](params.splice(0, 2)));
                    name = "l";
                    b = b == "m" ? "l" : "L";
                }
                if (name == "r") {
                    data.push([b][concat](params));
                } else while (params.length >= paramCounts[name]) {
                    data.push([b][concat](params.splice(0, paramCounts[name])));
                    if (!paramCounts[name]) {
                        break;
                    }
                }
            });
        }
        data.toString = R._path2string;
        pth.arr = pathClone(data);
        return data;
    };
    /*\
     * Raphael.parseTransformString
     [ method ]
     **
     * Utility method
     **
     * Parses given path string into an array of transformations.
     > Parameters
     - TString (string|array) transform string or array of transformations (in the last case it will be returned straight away)
     = (array) array of transformations.
    \*/
    R.parseTransformString = cacher(function (TString) {
        if (!TString) {
            return null;
        }
        var paramCounts = {r: 3, s: 4, t: 2, m: 6},
            data = [];
        if (R.is(TString, array) && R.is(TString[0], array)) { // rough assumption
            data = pathClone(TString);
        }
        if (!data.length) {
            Str(TString).replace(tCommand, function (a, b, c) {
                var params = [],
                    name = lowerCase.call(b);
                c.replace(pathValues, function (a, b) {
                    b && params.push(+b);
                });
                data.push([b][concat](params));
            });
        }
        data.toString = R._path2string;
        return data;
    });
    // PATHS
    var paths = function (ps) {
        var p = paths.ps = paths.ps || {};
        if (p[ps]) {
            p[ps].sleep = 100;
        } else {
            p[ps] = {
                sleep: 100
            };
        }
        setTimeout(function () {
            for (var key in p) if (p[has](key) && key != ps) {
                p[key].sleep--;
                !p[key].sleep && delete p[key];
            }
        });
        return p[ps];
    };
    /*\
     * Raphael.findDotsAtSegment
     [ method ]
     **
     * Utility method
     **
     * Find dot coordinates on the given cubic bezier curve at the given t.
     > Parameters
     - p1x (number) x of the first point of the curve
     - p1y (number) y of the first point of the curve
     - c1x (number) x of the first anchor of the curve
     - c1y (number) y of the first anchor of the curve
     - c2x (number) x of the second anchor of the curve
     - c2y (number) y of the second anchor of the curve
     - p2x (number) x of the second point of the curve
     - p2y (number) y of the second point of the curve
     - t (number) position on the curve (0..1)
     = (object) point information in format:
     o {
     o     x: (number) x coordinate of the point
     o     y: (number) y coordinate of the point
     o     m: {
     o         x: (number) x coordinate of the left anchor
     o         y: (number) y coordinate of the left anchor
     o     }
     o     n: {
     o         x: (number) x coordinate of the right anchor
     o         y: (number) y coordinate of the right anchor
     o     }
     o     start: {
     o         x: (number) x coordinate of the start of the curve
     o         y: (number) y coordinate of the start of the curve
     o     }
     o     end: {
     o         x: (number) x coordinate of the end of the curve
     o         y: (number) y coordinate of the end of the curve
     o     }
     o     alpha: (number) angle of the curve derivative at the point
     o }
    \*/
    R.findDotsAtSegment = function (p1x, p1y, c1x, c1y, c2x, c2y, p2x, p2y, t) {
        var t1 = 1 - t,
            t13 = pow(t1, 3),
            t12 = pow(t1, 2),
            t2 = t * t,
            t3 = t2 * t,
            x = t13 * p1x + t12 * 3 * t * c1x + t1 * 3 * t * t * c2x + t3 * p2x,
            y = t13 * p1y + t12 * 3 * t * c1y + t1 * 3 * t * t * c2y + t3 * p2y,
            mx = p1x + 2 * t * (c1x - p1x) + t2 * (c2x - 2 * c1x + p1x),
            my = p1y + 2 * t * (c1y - p1y) + t2 * (c2y - 2 * c1y + p1y),
            nx = c1x + 2 * t * (c2x - c1x) + t2 * (p2x - 2 * c2x + c1x),
            ny = c1y + 2 * t * (c2y - c1y) + t2 * (p2y - 2 * c2y + c1y),
            ax = t1 * p1x + t * c1x,
            ay = t1 * p1y + t * c1y,
            cx = t1 * c2x + t * p2x,
            cy = t1 * c2y + t * p2y,
            alpha = (90 - math.atan2(mx - nx, my - ny) * 180 / PI);
        (mx > nx || my < ny) && (alpha += 180);
        return {
            x: x,
            y: y,
            m: {x: mx, y: my},
            n: {x: nx, y: ny},
            start: {x: ax, y: ay},
            end: {x: cx, y: cy},
            alpha: alpha
        };
    };
    /*\
     * Raphael.bezierBBox
     [ method ]
     **
     * Utility method
     **
     * Return bounding box of a given cubic bezier curve
     > Parameters
     - p1x (number) x of the first point of the curve
     - p1y (number) y of the first point of the curve
     - c1x (number) x of the first anchor of the curve
     - c1y (number) y of the first anchor of the curve
     - c2x (number) x of the second anchor of the curve
     - c2y (number) y of the second anchor of the curve
     - p2x (number) x of the second point of the curve
     - p2y (number) y of the second point of the curve
     * or
     - bez (array) array of six points for bezier curve
     = (object) point information in format:
     o {
     o     min: {
     o         x: (number) x coordinate of the left point
     o         y: (number) y coordinate of the top point
     o     }
     o     max: {
     o         x: (number) x coordinate of the right point
     o         y: (number) y coordinate of the bottom point
     o     }
     o }
    \*/
    R.bezierBBox = function (p1x, p1y, c1x, c1y, c2x, c2y, p2x, p2y) {
        if (!R.is(p1x, "array")) {
            p1x = [p1x, p1y, c1x, c1y, c2x, c2y, p2x, p2y];
        }
        var bbox = curveDim.apply(null, p1x);
        return {
            x: bbox.min.x,
            y: bbox.min.y,
            x2: bbox.max.x,
            y2: bbox.max.y,
            width: bbox.max.x - bbox.min.x,
            height: bbox.max.y - bbox.min.y
        };
    };
    /*\
     * Raphael.isPointInsideBBox
     [ method ]
     **
     * Utility method
     **
     * Returns `true` if given point is inside bounding boxes.
     > Parameters
     - bbox (string) bounding box
     - x (string) x coordinate of the point
     - y (string) y coordinate of the point
     = (boolean) `true` if point inside
    \*/
    R.isPointInsideBBox = function (bbox, x, y) {
        return x >= bbox.x && x <= bbox.x2 && y >= bbox.y && y <= bbox.y2;
    };
    /*\
     * Raphael.isBBoxIntersect
     [ method ]
     **
     * Utility method
     **
     * Returns `true` if two bounding boxes intersect
     > Parameters
     - bbox1 (string) first bounding box
     - bbox2 (string) second bounding box
     = (boolean) `true` if they intersect
    \*/
    R.isBBoxIntersect = function (bbox1, bbox2) {
        var i = R.isPointInsideBBox;
        return i(bbox2, bbox1.x, bbox1.y)
            || i(bbox2, bbox1.x2, bbox1.y)
            || i(bbox2, bbox1.x, bbox1.y2)
            || i(bbox2, bbox1.x2, bbox1.y2)
            || i(bbox1, bbox2.x, bbox2.y)
            || i(bbox1, bbox2.x2, bbox2.y)
            || i(bbox1, bbox2.x, bbox2.y2)
            || i(bbox1, bbox2.x2, bbox2.y2)
            || (bbox1.x < bbox2.x2 && bbox1.x > bbox2.x || bbox2.x < bbox1.x2 && bbox2.x > bbox1.x)
            && (bbox1.y < bbox2.y2 && bbox1.y > bbox2.y || bbox2.y < bbox1.y2 && bbox2.y > bbox1.y);
    };
    function base3(t, p1, p2, p3, p4) {
        var t1 = -3 * p1 + 9 * p2 - 9 * p3 + 3 * p4,
            t2 = t * t1 + 6 * p1 - 12 * p2 + 6 * p3;
        return t * t2 - 3 * p1 + 3 * p2;
    }
    function bezlen(x1, y1, x2, y2, x3, y3, x4, y4, z) {
        if (z == null) {
            z = 1;
        }
        z = z > 1 ? 1 : z < 0 ? 0 : z;
        var z2 = z / 2,
            n = 12,
            Tvalues = [-0.1252,0.1252,-0.3678,0.3678,-0.5873,0.5873,-0.7699,0.7699,-0.9041,0.9041,-0.9816,0.9816],
            Cvalues = [0.2491,0.2491,0.2335,0.2335,0.2032,0.2032,0.1601,0.1601,0.1069,0.1069,0.0472,0.0472],
            sum = 0;
        for (var i = 0; i < n; i++) {
            var ct = z2 * Tvalues[i] + z2,
                xbase = base3(ct, x1, x2, x3, x4),
                ybase = base3(ct, y1, y2, y3, y4),
                comb = xbase * xbase + ybase * ybase;
            sum += Cvalues[i] * math.sqrt(comb);
        }
        return z2 * sum;
    }
    function getTatLen(x1, y1, x2, y2, x3, y3, x4, y4, ll) {
        if (ll < 0 || bezlen(x1, y1, x2, y2, x3, y3, x4, y4) < ll) {
            return;
        }
        var t = 1,
            step = t / 2,
            t2 = t - step,
            l,
            e = .01;
        l = bezlen(x1, y1, x2, y2, x3, y3, x4, y4, t2);
        while (abs(l - ll) > e) {
            step /= 2;
            t2 += (l < ll ? 1 : -1) * step;
            l = bezlen(x1, y1, x2, y2, x3, y3, x4, y4, t2);
        }
        return t2;
    }
    function intersect(x1, y1, x2, y2, x3, y3, x4, y4) {
        if (
            mmax(x1, x2) < mmin(x3, x4) ||
            mmin(x1, x2) > mmax(x3, x4) ||
            mmax(y1, y2) < mmin(y3, y4) ||
            mmin(y1, y2) > mmax(y3, y4)
        ) {
            return;
        }
        var nx = (x1 * y2 - y1 * x2) * (x3 - x4) - (x1 - x2) * (x3 * y4 - y3 * x4),
            ny = (x1 * y2 - y1 * x2) * (y3 - y4) - (y1 - y2) * (x3 * y4 - y3 * x4),
            denominator = (x1 - x2) * (y3 - y4) - (y1 - y2) * (x3 - x4);

        if (!denominator) {
            return;
        }
        var px = nx / denominator,
            py = ny / denominator,
            px2 = +px.toFixed(2),
            py2 = +py.toFixed(2);
        if (
            px2 < +mmin(x1, x2).toFixed(2) ||
            px2 > +mmax(x1, x2).toFixed(2) ||
            px2 < +mmin(x3, x4).toFixed(2) ||
            px2 > +mmax(x3, x4).toFixed(2) ||
            py2 < +mmin(y1, y2).toFixed(2) ||
            py2 > +mmax(y1, y2).toFixed(2) ||
            py2 < +mmin(y3, y4).toFixed(2) ||
            py2 > +mmax(y3, y4).toFixed(2)
        ) {
            return;
        }
        return {x: px, y: py};
    }
    function inter(bez1, bez2) {
        return interHelper(bez1, bez2);
    }
    function interCount(bez1, bez2) {
        return interHelper(bez1, bez2, 1);
    }
    function interHelper(bez1, bez2, justCount) {
        var bbox1 = R.bezierBBox(bez1),
            bbox2 = R.bezierBBox(bez2);
        if (!R.isBBoxIntersect(bbox1, bbox2)) {
            return justCount ? 0 : [];
        }
        var l1 = bezlen.apply(0, bez1),
            l2 = bezlen.apply(0, bez2),
            n1 = mmax(~~(l1 / 5), 1),
            n2 = mmax(~~(l2 / 5), 1),
            dots1 = [],
            dots2 = [],
            xy = {},
            res = justCount ? 0 : [];
        for (var i = 0; i < n1 + 1; i++) {
            var p = R.findDotsAtSegment.apply(R, bez1.concat(i / n1));
            dots1.push({x: p.x, y: p.y, t: i / n1});
        }
        for (i = 0; i < n2 + 1; i++) {
            p = R.findDotsAtSegment.apply(R, bez2.concat(i / n2));
            dots2.push({x: p.x, y: p.y, t: i / n2});
        }
        for (i = 0; i < n1; i++) {
            for (var j = 0; j < n2; j++) {
                var di = dots1[i],
                    di1 = dots1[i + 1],
                    dj = dots2[j],
                    dj1 = dots2[j + 1],
                    ci = abs(di1.x - di.x) < .001 ? "y" : "x",
                    cj = abs(dj1.x - dj.x) < .001 ? "y" : "x",
                    is = intersect(di.x, di.y, di1.x, di1.y, dj.x, dj.y, dj1.x, dj1.y);
                if (is) {
                    if (xy[is.x.toFixed(4)] == is.y.toFixed(4)) {
                        continue;
                    }
                    xy[is.x.toFixed(4)] = is.y.toFixed(4);
                    var t1 = di.t + abs((is[ci] - di[ci]) / (di1[ci] - di[ci])) * (di1.t - di.t),
                        t2 = dj.t + abs((is[cj] - dj[cj]) / (dj1[cj] - dj[cj])) * (dj1.t - dj.t);
                    if (t1 >= 0 && t1 <= 1.001 && t2 >= 0 && t2 <= 1.001) {
                        if (justCount) {
                            res++;
                        } else {
                            res.push({
                                x: is.x,
                                y: is.y,
                                t1: mmin(t1, 1),
                                t2: mmin(t2, 1)
                            });
                        }
                    }
                }
            }
        }
        return res;
    }
    /*\
     * Raphael.pathIntersection
     [ method ]
     **
     * Utility method
     **
     * Finds intersections of two paths
     > Parameters
     - path1 (string) path string
     - path2 (string) path string
     = (array) dots of intersection
     o [
     o     {
     o         x: (number) x coordinate of the point
     o         y: (number) y coordinate of the point
     o         t1: (number) t value for segment of path1
     o         t2: (number) t value for segment of path2
     o         segment1: (number) order number for segment of path1
     o         segment2: (number) order number for segment of path2
     o         bez1: (array) eight coordinates representing beziér curve for the segment of path1
     o         bez2: (array) eight coordinates representing beziér curve for the segment of path2
     o     }
     o ]
    \*/
    R.pathIntersection = function (path1, path2) {
        return interPathHelper(path1, path2);
    };
    R.pathIntersectionNumber = function (path1, path2) {
        return interPathHelper(path1, path2, 1);
    };
    function interPathHelper(path1, path2, justCount) {
        path1 = R._path2curve(path1);
        path2 = R._path2curve(path2);
        var x1, y1, x2, y2, x1m, y1m, x2m, y2m, bez1, bez2,
            res = justCount ? 0 : [];
        for (var i = 0, ii = path1.length; i < ii; i++) {
            var pi = path1[i];
            if (pi[0] == "M") {
                x1 = x1m = pi[1];
                y1 = y1m = pi[2];
            } else {
                if (pi[0] == "C") {
                    bez1 = [x1, y1].concat(pi.slice(1));
                    x1 = bez1[6];
                    y1 = bez1[7];
                } else {
                    bez1 = [x1, y1, x1, y1, x1m, y1m, x1m, y1m];
                    x1 = x1m;
                    y1 = y1m;
                }
                for (var j = 0, jj = path2.length; j < jj; j++) {
                    var pj = path2[j];
                    if (pj[0] == "M") {
                        x2 = x2m = pj[1];
                        y2 = y2m = pj[2];
                    } else {
                        if (pj[0] == "C") {
                            bez2 = [x2, y2].concat(pj.slice(1));
                            x2 = bez2[6];
                            y2 = bez2[7];
                        } else {
                            bez2 = [x2, y2, x2, y2, x2m, y2m, x2m, y2m];
                            x2 = x2m;
                            y2 = y2m;
                        }
                        var intr = interHelper(bez1, bez2, justCount);
                        if (justCount) {
                            res += intr;
                        } else {
                            for (var k = 0, kk = intr.length; k < kk; k++) {
                                intr[k].segment1 = i;
                                intr[k].segment2 = j;
                                intr[k].bez1 = bez1;
                                intr[k].bez2 = bez2;
                            }
                            res = res.concat(intr);
                        }
                    }
                }
            }
        }
        return res;
    }
    /*\
     * Raphael.isPointInsidePath
     [ method ]
     **
     * Utility method
     **
     * Returns `true` if given point is inside a given closed path.
     > Parameters
     - path (string) path string
     - x (number) x of the point
     - y (number) y of the point
     = (boolean) true, if point is inside the path
    \*/
    R.isPointInsidePath = function (path, x, y) {
        var bbox = R.pathBBox(path);
        return R.isPointInsideBBox(bbox, x, y) &&
               interPathHelper(path, [["M", x, y], ["H", bbox.x2 + 10]], 1) % 2 == 1;
    };
    R._removedFactory = function (methodname) {
        return function () {
            eve("raphael.log", null, "Rapha\xebl: you are calling to method \u201c" + methodname + "\u201d of removed object", methodname);
        };
    };
    /*\
     * Raphael.pathBBox
     [ method ]
     **
     * Utility method
     **
     * Return bounding box of a given path
     > Parameters
     - path (string) path string
     = (object) bounding box
     o {
     o     x: (number) x coordinate of the left top point of the box
     o     y: (number) y coordinate of the left top point of the box
     o     x2: (number) x coordinate of the right bottom point of the box
     o     y2: (number) y coordinate of the right bottom point of the box
     o     width: (number) width of the box
     o     height: (number) height of the box
     o     cx: (number) x coordinate of the center of the box
     o     cy: (number) y coordinate of the center of the box
     o }
    \*/
    var pathDimensions = R.pathBBox = function (path) {
        var pth = paths(path);
        if (pth.bbox) {
            return clone(pth.bbox);
        }
        if (!path) {
            return {x: 0, y: 0, width: 0, height: 0, x2: 0, y2: 0};
        }
        path = path2curve(path);
        var x = 0,
            y = 0,
            X = [],
            Y = [],
            p;
        for (var i = 0, ii = path.length; i < ii; i++) {
            p = path[i];
            if (p[0] == "M") {
                x = p[1];
                y = p[2];
                X.push(x);
                Y.push(y);
            } else {
                var dim = curveDim(x, y, p[1], p[2], p[3], p[4], p[5], p[6]);
                X = X[concat](dim.min.x, dim.max.x);
                Y = Y[concat](dim.min.y, dim.max.y);
                x = p[5];
                y = p[6];
            }
        }
        var xmin = mmin[apply](0, X),
            ymin = mmin[apply](0, Y),
            xmax = mmax[apply](0, X),
            ymax = mmax[apply](0, Y),
            width = xmax - xmin,
            height = ymax - ymin,
                bb = {
                x: xmin,
                y: ymin,
                x2: xmax,
                y2: ymax,
                width: width,
                height: height,
                cx: xmin + width / 2,
                cy: ymin + height / 2
            };
        pth.bbox = clone(bb);
        return bb;
    },
        pathClone = function (pathArray) {
            var res = clone(pathArray);
            res.toString = R._path2string;
            return res;
        },
        pathToRelative = R._pathToRelative = function (pathArray) {
            var pth = paths(pathArray);
            if (pth.rel) {
                return pathClone(pth.rel);
            }
            if (!R.is(pathArray, array) || !R.is(pathArray && pathArray[0], array)) { // rough assumption
                pathArray = R.parsePathString(pathArray);
            }
            var res = [],
                x = 0,
                y = 0,
                mx = 0,
                my = 0,
                start = 0;
            if (pathArray[0][0] == "M") {
                x = pathArray[0][1];
                y = pathArray[0][2];
                mx = x;
                my = y;
                start++;
                res.push(["M", x, y]);
            }
            for (var i = start, ii = pathArray.length; i < ii; i++) {
                var r = res[i] = [],
                    pa = pathArray[i];
                if (pa[0] != lowerCase.call(pa[0])) {
                    r[0] = lowerCase.call(pa[0]);
                    switch (r[0]) {
                        case "a":
                            r[1] = pa[1];
                            r[2] = pa[2];
                            r[3] = pa[3];
                            r[4] = pa[4];
                            r[5] = pa[5];
                            r[6] = +(pa[6] - x).toFixed(3);
                            r[7] = +(pa[7] - y).toFixed(3);
                            break;
                        case "v":
                            r[1] = +(pa[1] - y).toFixed(3);
                            break;
                        case "m":
                            mx = pa[1];
                            my = pa[2];
                        default:
                            for (var j = 1, jj = pa.length; j < jj; j++) {
                                r[j] = +(pa[j] - ((j % 2) ? x : y)).toFixed(3);
                            }
                    }
                } else {
                    r = res[i] = [];
                    if (pa[0] == "m") {
                        mx = pa[1] + x;
                        my = pa[2] + y;
                    }
                    for (var k = 0, kk = pa.length; k < kk; k++) {
                        res[i][k] = pa[k];
                    }
                }
                var len = res[i].length;
                switch (res[i][0]) {
                    case "z":
                        x = mx;
                        y = my;
                        break;
                    case "h":
                        x += +res[i][len - 1];
                        break;
                    case "v":
                        y += +res[i][len - 1];
                        break;
                    default:
                        x += +res[i][len - 2];
                        y += +res[i][len - 1];
                }
            }
            res.toString = R._path2string;
            pth.rel = pathClone(res);
            return res;
        },
        pathToAbsolute = R._pathToAbsolute = function (pathArray) {
            var pth = paths(pathArray);
            if (pth.abs) {
                return pathClone(pth.abs);
            }
            if (!R.is(pathArray, array) || !R.is(pathArray && pathArray[0], array)) { // rough assumption
                pathArray = R.parsePathString(pathArray);
            }
            if (!pathArray || !pathArray.length) {
                return [["M", 0, 0]];
            }
            var res = [],
                x = 0,
                y = 0,
                mx = 0,
                my = 0,
                start = 0;
            if (pathArray[0][0] == "M") {
                x = +pathArray[0][1];
                y = +pathArray[0][2];
                mx = x;
                my = y;
                start++;
                res[0] = ["M", x, y];
            }
            var crz = pathArray.length == 3 && pathArray[0][0] == "M" && pathArray[1][0].toUpperCase() == "R" && pathArray[2][0].toUpperCase() == "Z";
            for (var r, pa, i = start, ii = pathArray.length; i < ii; i++) {
                res.push(r = []);
                pa = pathArray[i];
                if (pa[0] != upperCase.call(pa[0])) {
                    r[0] = upperCase.call(pa[0]);
                    switch (r[0]) {
                        case "A":
                            r[1] = pa[1];
                            r[2] = pa[2];
                            r[3] = pa[3];
                            r[4] = pa[4];
                            r[5] = pa[5];
                            r[6] = +(pa[6] + x);
                            r[7] = +(pa[7] + y);
                            break;
                        case "V":
                            r[1] = +pa[1] + y;
                            break;
                        case "H":
                            r[1] = +pa[1] + x;
                            break;
                        case "R":
                            var dots = [x, y][concat](pa.slice(1));
                            for (var j = 2, jj = dots.length; j < jj; j++) {
                                dots[j] = +dots[j] + x;
                                dots[++j] = +dots[j] + y;
                            }
                            res.pop();
                            res = res[concat](catmullRom2bezier(dots, crz));
                            break;
                        case "M":
                            mx = +pa[1] + x;
                            my = +pa[2] + y;
                        default:
                            for (j = 1, jj = pa.length; j < jj; j++) {
                                r[j] = +pa[j] + ((j % 2) ? x : y);
                            }
                    }
                } else if (pa[0] == "R") {
                    dots = [x, y][concat](pa.slice(1));
                    res.pop();
                    res = res[concat](catmullRom2bezier(dots, crz));
                    r = ["R"][concat](pa.slice(-2));
                } else {
                    for (var k = 0, kk = pa.length; k < kk; k++) {
                        r[k] = pa[k];
                    }
                }
                switch (r[0]) {
                    case "Z":
                        x = mx;
                        y = my;
                        break;
                    case "H":
                        x = r[1];
                        break;
                    case "V":
                        y = r[1];
                        break;
                    case "M":
                        mx = r[r.length - 2];
                        my = r[r.length - 1];
                    default:
                        x = r[r.length - 2];
                        y = r[r.length - 1];
                }
            }
            res.toString = R._path2string;
            pth.abs = pathClone(res);
            return res;
        },
        l2c = function (x1, y1, x2, y2) {
            return [x1, y1, x2, y2, x2, y2];
        },
        q2c = function (x1, y1, ax, ay, x2, y2) {
            var _13 = 1 / 3,
                _23 = 2 / 3;
            return [
                    _13 * x1 + _23 * ax,
                    _13 * y1 + _23 * ay,
                    _13 * x2 + _23 * ax,
                    _13 * y2 + _23 * ay,
                    x2,
                    y2
                ];
        },
        a2c = function (x1, y1, rx, ry, angle, large_arc_flag, sweep_flag, x2, y2, recursive) {
            // for more information of where this math came from visit:
            // http://www.w3.org/TR/SVG11/implnote.html#ArcImplementationNotes
            var _120 = PI * 120 / 180,
                rad = PI / 180 * (+angle || 0),
                res = [],
                xy,
                rotate = cacher(function (x, y, rad) {
                    var X = x * math.cos(rad) - y * math.sin(rad),
                        Y = x * math.sin(rad) + y * math.cos(rad);
                    return {x: X, y: Y};
                });
            if (!recursive) {
                xy = rotate(x1, y1, -rad);
                x1 = xy.x;
                y1 = xy.y;
                xy = rotate(x2, y2, -rad);
                x2 = xy.x;
                y2 = xy.y;
                var cos = math.cos(PI / 180 * angle),
                    sin = math.sin(PI / 180 * angle),
                    x = (x1 - x2) / 2,
                    y = (y1 - y2) / 2;
                var h = (x * x) / (rx * rx) + (y * y) / (ry * ry);
                if (h > 1) {
                    h = math.sqrt(h);
                    rx = h * rx;
                    ry = h * ry;
                }
                var rx2 = rx * rx,
                    ry2 = ry * ry,
                    k = (large_arc_flag == sweep_flag ? -1 : 1) *
                        math.sqrt(abs((rx2 * ry2 - rx2 * y * y - ry2 * x * x) / (rx2 * y * y + ry2 * x * x))),
                    cx = k * rx * y / ry + (x1 + x2) / 2,
                    cy = k * -ry * x / rx + (y1 + y2) / 2,
                    f1 = math.asin(((y1 - cy) / ry).toFixed(9)),
                    f2 = math.asin(((y2 - cy) / ry).toFixed(9));

                f1 = x1 < cx ? PI - f1 : f1;
                f2 = x2 < cx ? PI - f2 : f2;
                f1 < 0 && (f1 = PI * 2 + f1);
                f2 < 0 && (f2 = PI * 2 + f2);
                if (sweep_flag && f1 > f2) {
                    f1 = f1 - PI * 2;
                }
                if (!sweep_flag && f2 > f1) {
                    f2 = f2 - PI * 2;
                }
            } else {
                f1 = recursive[0];
                f2 = recursive[1];
                cx = recursive[2];
                cy = recursive[3];
            }
            var df = f2 - f1;
            if (abs(df) > _120) {
                var f2old = f2,
                    x2old = x2,
                    y2old = y2;
                f2 = f1 + _120 * (sweep_flag && f2 > f1 ? 1 : -1);
                x2 = cx + rx * math.cos(f2);
                y2 = cy + ry * math.sin(f2);
                res = a2c(x2, y2, rx, ry, angle, 0, sweep_flag, x2old, y2old, [f2, f2old, cx, cy]);
            }
            df = f2 - f1;
            var c1 = math.cos(f1),
                s1 = math.sin(f1),
                c2 = math.cos(f2),
                s2 = math.sin(f2),
                t = math.tan(df / 4),
                hx = 4 / 3 * rx * t,
                hy = 4 / 3 * ry * t,
                m1 = [x1, y1],
                m2 = [x1 + hx * s1, y1 - hy * c1],
                m3 = [x2 + hx * s2, y2 - hy * c2],
                m4 = [x2, y2];
            m2[0] = 2 * m1[0] - m2[0];
            m2[1] = 2 * m1[1] - m2[1];
            if (recursive) {
                return [m2, m3, m4][concat](res);
            } else {
                res = [m2, m3, m4][concat](res).join()[split](",");
                var newres = [];
                for (var i = 0, ii = res.length; i < ii; i++) {
                    newres[i] = i % 2 ? rotate(res[i - 1], res[i], rad).y : rotate(res[i], res[i + 1], rad).x;
                }
                return newres;
            }
        },
        findDotAtSegment = function (p1x, p1y, c1x, c1y, c2x, c2y, p2x, p2y, t) {
            var t1 = 1 - t;
            return {
                x: pow(t1, 3) * p1x + pow(t1, 2) * 3 * t * c1x + t1 * 3 * t * t * c2x + pow(t, 3) * p2x,
                y: pow(t1, 3) * p1y + pow(t1, 2) * 3 * t * c1y + t1 * 3 * t * t * c2y + pow(t, 3) * p2y
            };
        },
        curveDim = cacher(function (p1x, p1y, c1x, c1y, c2x, c2y, p2x, p2y) {
            var a = (c2x - 2 * c1x + p1x) - (p2x - 2 * c2x + c1x),
                b = 2 * (c1x - p1x) - 2 * (c2x - c1x),
                c = p1x - c1x,
                t1 = (-b + math.sqrt(b * b - 4 * a * c)) / 2 / a,
                t2 = (-b - math.sqrt(b * b - 4 * a * c)) / 2 / a,
                y = [p1y, p2y],
                x = [p1x, p2x],
                dot;
            abs(t1) > "1e12" && (t1 = .5);
            abs(t2) > "1e12" && (t2 = .5);
            if (t1 > 0 && t1 < 1) {
                dot = findDotAtSegment(p1x, p1y, c1x, c1y, c2x, c2y, p2x, p2y, t1);
                x.push(dot.x);
                y.push(dot.y);
            }
            if (t2 > 0 && t2 < 1) {
                dot = findDotAtSegment(p1x, p1y, c1x, c1y, c2x, c2y, p2x, p2y, t2);
                x.push(dot.x);
                y.push(dot.y);
            }
            a = (c2y - 2 * c1y + p1y) - (p2y - 2 * c2y + c1y);
            b = 2 * (c1y - p1y) - 2 * (c2y - c1y);
            c = p1y - c1y;
            t1 = (-b + math.sqrt(b * b - 4 * a * c)) / 2 / a;
            t2 = (-b - math.sqrt(b * b - 4 * a * c)) / 2 / a;
            abs(t1) > "1e12" && (t1 = .5);
            abs(t2) > "1e12" && (t2 = .5);
            if (t1 > 0 && t1 < 1) {
                dot = findDotAtSegment(p1x, p1y, c1x, c1y, c2x, c2y, p2x, p2y, t1);
                x.push(dot.x);
                y.push(dot.y);
            }
            if (t2 > 0 && t2 < 1) {
                dot = findDotAtSegment(p1x, p1y, c1x, c1y, c2x, c2y, p2x, p2y, t2);
                x.push(dot.x);
                y.push(dot.y);
            }
            return {
                min: {x: mmin[apply](0, x), y: mmin[apply](0, y)},
                max: {x: mmax[apply](0, x), y: mmax[apply](0, y)}
            };
        }),
        path2curve = R._path2curve = cacher(function (path, path2) {
            var pth = !path2 && paths(path);
            if (!path2 && pth.curve) {
                return pathClone(pth.curve);
            }
            var p = pathToAbsolute(path),
                p2 = path2 && pathToAbsolute(path2),
                attrs = {x: 0, y: 0, bx: 0, by: 0, X: 0, Y: 0, qx: null, qy: null},
                attrs2 = {x: 0, y: 0, bx: 0, by: 0, X: 0, Y: 0, qx: null, qy: null},
                processPath = function (path, d, pcom) {
                    var nx, ny, tq = {T:1, Q:1};
                    if (!path) {
                        return ["C", d.x, d.y, d.x, d.y, d.x, d.y];
                    }
                    !(path[0] in tq) && (d.qx = d.qy = null);
                    switch (path[0]) {
                        case "M":
                            d.X = path[1];
                            d.Y = path[2];
                            break;
                        case "A":
                            path = ["C"][concat](a2c[apply](0, [d.x, d.y][concat](path.slice(1))));
                            break;
                        case "S":
                            if (pcom == "C" || pcom == "S") { // In "S" case we have to take into account, if the previous command is C/S.
                                nx = d.x * 2 - d.bx;          // And reflect the previous
                                ny = d.y * 2 - d.by;          // command's control point relative to the current point.
                            }
                            else {                            // or some else or nothing
                                nx = d.x;
                                ny = d.y;
                            }
                            path = ["C", nx, ny][concat](path.slice(1));
                            break;
                        case "T":
                            if (pcom == "Q" || pcom == "T") { // In "T" case we have to take into account, if the previous command is Q/T.
                                d.qx = d.x * 2 - d.qx;        // And make a reflection similar
                                d.qy = d.y * 2 - d.qy;        // to case "S".
                            }
                            else {                            // or something else or nothing
                                d.qx = d.x;
                                d.qy = d.y;
                            }
                            path = ["C"][concat](q2c(d.x, d.y, d.qx, d.qy, path[1], path[2]));
                            break;
                        case "Q":
                            d.qx = path[1];
                            d.qy = path[2];
                            path = ["C"][concat](q2c(d.x, d.y, path[1], path[2], path[3], path[4]));
                            break;
                        case "L":
                            path = ["C"][concat](l2c(d.x, d.y, path[1], path[2]));
                            break;
                        case "H":
                            path = ["C"][concat](l2c(d.x, d.y, path[1], d.y));
                            break;
                        case "V":
                            path = ["C"][concat](l2c(d.x, d.y, d.x, path[1]));
                            break;
                        case "Z":
                            path = ["C"][concat](l2c(d.x, d.y, d.X, d.Y));
                            break;
                    }
                    return path;
                },
                fixArc = function (pp, i) {
                    if (pp[i].length > 7) {
                        pp[i].shift();
                        var pi = pp[i];
                        while (pi.length) {
                            pcoms1[i]="A"; // if created multiple C:s, their original seg is saved
                            p2 && (pcoms2[i]="A"); // the same as above
                            pp.splice(i++, 0, ["C"][concat](pi.splice(0, 6)));
                        }
                        pp.splice(i, 1);
                        ii = mmax(p.length, p2 && p2.length || 0);
                    }
                },
                fixM = function (path1, path2, a1, a2, i) {
                    if (path1 && path2 && path1[i][0] == "M" && path2[i][0] != "M") {
                        path2.splice(i, 0, ["M", a2.x, a2.y]);
                        a1.bx = 0;
                        a1.by = 0;
                        a1.x = path1[i][1];
                        a1.y = path1[i][2];
                        ii = mmax(p.length, p2 && p2.length || 0);
                    }
                },
                pcoms1 = [], // path commands of original path p
                pcoms2 = [], // path commands of original path p2
                pfirst = "", // temporary holder for original path command
                pcom = ""; // holder for previous path command of original path
            for (var i = 0, ii = mmax(p.length, p2 && p2.length || 0); i < ii; i++) {
                p[i] && (pfirst = p[i][0]); // save current path command

                if (pfirst != "C") // C is not saved yet, because it may be result of conversion
                {
                    pcoms1[i] = pfirst; // Save current path command
                    i && ( pcom = pcoms1[i-1]); // Get previous path command pcom
                }
                p[i] = processPath(p[i], attrs, pcom); // Previous path command is inputted to processPath

                if (pcoms1[i] != "A" && pfirst == "C") pcoms1[i] = "C"; // A is the only command
                // which may produce multiple C:s
                // so we have to make sure that C is also C in original path

                fixArc(p, i); // fixArc adds also the right amount of A:s to pcoms1

                if (p2) { // the same procedures is done to p2
                    p2[i] && (pfirst = p2[i][0]);
                    if (pfirst != "C")
                    {
                        pcoms2[i] = pfirst;
                        i && (pcom = pcoms2[i-1]);
                    }
                    p2[i] = processPath(p2[i], attrs2, pcom);

                    if (pcoms2[i]!="A" && pfirst=="C") pcoms2[i]="C";

                    fixArc(p2, i);
                }
                fixM(p, p2, attrs, attrs2, i);
                fixM(p2, p, attrs2, attrs, i);
                var seg = p[i],
                    seg2 = p2 && p2[i],
                    seglen = seg.length,
                    seg2len = p2 && seg2.length;
                attrs.x = seg[seglen - 2];
                attrs.y = seg[seglen - 1];
                attrs.bx = toFloat(seg[seglen - 4]) || attrs.x;
                attrs.by = toFloat(seg[seglen - 3]) || attrs.y;
                attrs2.bx = p2 && (toFloat(seg2[seg2len - 4]) || attrs2.x);
                attrs2.by = p2 && (toFloat(seg2[seg2len - 3]) || attrs2.y);
                attrs2.x = p2 && seg2[seg2len - 2];
                attrs2.y = p2 && seg2[seg2len - 1];
            }
            if (!p2) {
                pth.curve = pathClone(p);
            }
            return p2 ? [p, p2] : p;
        }, null, pathClone),
        parseDots = R._parseDots = cacher(function (gradient) {
            var dots = [];
            for (var i = 0, ii = gradient.length; i < ii; i++) {
                var dot = {},
                    par = gradient[i].match(/^([^:]*):?([\d\.]*)/);
                dot.color = R.getRGB(par[1]);
                if (dot.color.error) {
                    return null;
                }
                dot.color = dot.color.hex;
                par[2] && (dot.offset = par[2] + "%");
                dots.push(dot);
            }
            for (i = 1, ii = dots.length - 1; i < ii; i++) {
                if (!dots[i].offset) {
                    var start = toFloat(dots[i - 1].offset || 0),
                        end = 0;
                    for (var j = i + 1; j < ii; j++) {
                        if (dots[j].offset) {
                            end = dots[j].offset;
                            break;
                        }
                    }
                    if (!end) {
                        end = 100;
                        j = ii;
                    }
                    end = toFloat(end);
                    var d = (end - start) / (j - i + 1);
                    for (; i < j; i++) {
                        start += d;
                        dots[i].offset = start + "%";
                    }
                }
            }
            return dots;
        }),
        tear = R._tear = function (el, paper) {
            el == paper.top && (paper.top = el.prev);
            el == paper.bottom && (paper.bottom = el.next);
            el.next && (el.next.prev = el.prev);
            el.prev && (el.prev.next = el.next);
        },
        tofront = R._tofront = function (el, paper) {
            if (paper.top === el) {
                return;
            }
            tear(el, paper);
            el.next = null;
            el.prev = paper.top;
            paper.top.next = el;
            paper.top = el;
        },
        toback = R._toback = function (el, paper) {
            if (paper.bottom === el) {
                return;
            }
            tear(el, paper);
            el.next = paper.bottom;
            el.prev = null;
            paper.bottom.prev = el;
            paper.bottom = el;
        },
        insertafter = R._insertafter = function (el, el2, paper) {
            tear(el, paper);
            el2 == paper.top && (paper.top = el);
            el2.next && (el2.next.prev = el);
            el.next = el2.next;
            el.prev = el2;
            el2.next = el;
        },
        insertbefore = R._insertbefore = function (el, el2, paper) {
            tear(el, paper);
            el2 == paper.bottom && (paper.bottom = el);
            el2.prev && (el2.prev.next = el);
            el.prev = el2.prev;
            el2.prev = el;
            el.next = el2;
        },
        /*\
         * Raphael.toMatrix
         [ method ]
         **
         * Utility method
         **
         * Returns matrix of transformations applied to a given path
         > Parameters
         - path (string) path string
         - transform (string|array) transformation string
         = (object) @Matrix
        \*/
        toMatrix = R.toMatrix = function (path, transform) {
            var bb = pathDimensions(path),
                el = {
                    _: {
                        transform: E
                    },
                    getBBox: function () {
                        return bb;
                    }
                };
            extractTransform(el, transform);
            return el.matrix;
        },
        /*\
         * Raphael.transformPath
         [ method ]
         **
         * Utility method
         **
         * Returns path transformed by a given transformation
         > Parameters
         - path (string) path string
         - transform (string|array) transformation string
         = (string) path
        \*/
        transformPath = R.transformPath = function (path, transform) {
            return mapPath(path, toMatrix(path, transform));
        },
        extractTransform = R._extractTransform = function (el, tstr) {
            if (tstr == null) {
                return el._.transform;
            }
            tstr = Str(tstr).replace(/\.{3}|\u2026/g, el._.transform || E);
            var tdata = R.parseTransformString(tstr),
                deg = 0,
                dx = 0,
                dy = 0,
                sx = 1,
                sy = 1,
                _ = el._,
                m = new Matrix;
            _.transform = tdata || [];
            if (tdata) {
                for (var i = 0, ii = tdata.length; i < ii; i++) {
                    var t = tdata[i],
                        tlen = t.length,
                        command = Str(t[0]).toLowerCase(),
                        absolute = t[0] != command,
                        inver = absolute ? m.invert() : 0,
                        x1,
                        y1,
                        x2,
                        y2,
                        bb;
                    if (command == "t" && tlen == 3) {
                        if (absolute) {
                            x1 = inver.x(0, 0);
                            y1 = inver.y(0, 0);
                            x2 = inver.x(t[1], t[2]);
                            y2 = inver.y(t[1], t[2]);
                            m.translate(x2 - x1, y2 - y1);
                        } else {
                            m.translate(t[1], t[2]);
                        }
                    } else if (command == "r") {
                        if (tlen == 2) {
                            bb = bb || el.getBBox(1);
                            m.rotate(t[1], bb.x + bb.width / 2, bb.y + bb.height / 2);
                            deg += t[1];
                        } else if (tlen == 4) {
                            if (absolute) {
                                x2 = inver.x(t[2], t[3]);
                                y2 = inver.y(t[2], t[3]);
                                m.rotate(t[1], x2, y2);
                            } else {
                                m.rotate(t[1], t[2], t[3]);
                            }
                            deg += t[1];
                        }
                    } else if (command == "s") {
                        if (tlen == 2 || tlen == 3) {
                            bb = bb || el.getBBox(1);
                            m.scale(t[1], t[tlen - 1], bb.x + bb.width / 2, bb.y + bb.height / 2);
                            sx *= t[1];
                            sy *= t[tlen - 1];
                        } else if (tlen == 5) {
                            if (absolute) {
                                x2 = inver.x(t[3], t[4]);
                                y2 = inver.y(t[3], t[4]);
                                m.scale(t[1], t[2], x2, y2);
                            } else {
                                m.scale(t[1], t[2], t[3], t[4]);
                            }
                            sx *= t[1];
                            sy *= t[2];
                        }
                    } else if (command == "m" && tlen == 7) {
                        m.add(t[1], t[2], t[3], t[4], t[5], t[6]);
                    }
                    _.dirtyT = 1;
                    el.matrix = m;
                }
            }

            /*\
             * Element.matrix
             [ property (object) ]
             **
             * Keeps @Matrix object, which represents element transformation
            \*/
            el.matrix = m;

            _.sx = sx;
            _.sy = sy;
            _.deg = deg;
            _.dx = dx = m.e;
            _.dy = dy = m.f;

            if (sx == 1 && sy == 1 && !deg && _.bbox) {
                _.bbox.x += +dx;
                _.bbox.y += +dy;
            } else {
                _.dirtyT = 1;
            }
        },
        getEmpty = function (item) {
            var l = item[0];
            switch (l.toLowerCase()) {
                case "t": return [l, 0, 0];
                case "m": return [l, 1, 0, 0, 1, 0, 0];
                case "r": if (item.length == 4) {
                    return [l, 0, item[2], item[3]];
                } else {
                    return [l, 0];
                }
                case "s": if (item.length == 5) {
                    return [l, 1, 1, item[3], item[4]];
                } else if (item.length == 3) {
                    return [l, 1, 1];
                } else {
                    return [l, 1];
                }
            }
        },
        equaliseTransform = R._equaliseTransform = function (t1, t2) {
            t2 = Str(t2).replace(/\.{3}|\u2026/g, t1);
            t1 = R.parseTransformString(t1) || [];
            t2 = R.parseTransformString(t2) || [];
            var maxlength = mmax(t1.length, t2.length),
                from = [],
                to = [],
                i = 0, j, jj,
                tt1, tt2;
            for (; i < maxlength; i++) {
                tt1 = t1[i] || getEmpty(t2[i]);
                tt2 = t2[i] || getEmpty(tt1);
                if ((tt1[0] != tt2[0]) ||
                    (tt1[0].toLowerCase() == "r" && (tt1[2] != tt2[2] || tt1[3] != tt2[3])) ||
                    (tt1[0].toLowerCase() == "s" && (tt1[3] != tt2[3] || tt1[4] != tt2[4]))
                    ) {
                    return;
                }
                from[i] = [];
                to[i] = [];
                for (j = 0, jj = mmax(tt1.length, tt2.length); j < jj; j++) {
                    j in tt1 && (from[i][j] = tt1[j]);
                    j in tt2 && (to[i][j] = tt2[j]);
                }
            }
            return {
                from: from,
                to: to
            };
        };
    R._getContainer = function (x, y, w, h) {
        var container;
        container = h == null && !R.is(x, "object") ? g.doc.getElementById(x) : x;
        if (container == null) {
            return;
        }
        if (container.tagName) {
            if (y == null) {
                return {
                    container: container,
                    width: container.style.pixelWidth || container.offsetWidth,
                    height: container.style.pixelHeight || container.offsetHeight
                };
            } else {
                return {
                    container: container,
                    width: y,
                    height: w
                };
            }
        }
        return {
            container: 1,
            x: x,
            y: y,
            width: w,
            height: h
        };
    };
    /*\
     * Raphael.pathToRelative
     [ method ]
     **
     * Utility method
     **
     * Converts path to relative form
     > Parameters
     - pathString (string|array) path string or array of segments
     = (array) array of segments.
    \*/
    R.pathToRelative = pathToRelative;
    R._engine = {};
    /*\
     * Raphael.path2curve
     [ method ]
     **
     * Utility method
     **
     * Converts path to a new path where all segments are cubic bezier curves.
     > Parameters
     - pathString (string|array) path string or array of segments
     = (array) array of segments.
    \*/
    R.path2curve = path2curve;
    /*\
     * Raphael.matrix
     [ method ]
     **
     * Utility method
     **
     * Returns matrix based on given parameters.
     > Parameters
     - a (number)
     - b (number)
     - c (number)
     - d (number)
     - e (number)
     - f (number)
     = (object) @Matrix
    \*/
    R.matrix = function (a, b, c, d, e, f) {
        return new Matrix(a, b, c, d, e, f);
    };
    function Matrix(a, b, c, d, e, f) {
        if (a != null) {
            this.a = +a;
            this.b = +b;
            this.c = +c;
            this.d = +d;
            this.e = +e;
            this.f = +f;
        } else {
            this.a = 1;
            this.b = 0;
            this.c = 0;
            this.d = 1;
            this.e = 0;
            this.f = 0;
        }
    }
    (function (matrixproto) {
        /*\
         * Matrix.add
         [ method ]
         **
         * Adds given matrix to existing one.
         > Parameters
         - a (number)
         - b (number)
         - c (number)
         - d (number)
         - e (number)
         - f (number)
         or
         - matrix (object) @Matrix
        \*/
        matrixproto.add = function (a, b, c, d, e, f) {
            var out = [[], [], []],
                m = [[this.a, this.c, this.e], [this.b, this.d, this.f], [0, 0, 1]],
                matrix = [[a, c, e], [b, d, f], [0, 0, 1]],
                x, y, z, res;

            if (a && a instanceof Matrix) {
                matrix = [[a.a, a.c, a.e], [a.b, a.d, a.f], [0, 0, 1]];
            }

            for (x = 0; x < 3; x++) {
                for (y = 0; y < 3; y++) {
                    res = 0;
                    for (z = 0; z < 3; z++) {
                        res += m[x][z] * matrix[z][y];
                    }
                    out[x][y] = res;
                }
            }
            this.a = out[0][0];
            this.b = out[1][0];
            this.c = out[0][1];
            this.d = out[1][1];
            this.e = out[0][2];
            this.f = out[1][2];
        };
        /*\
         * Matrix.invert
         [ method ]
         **
         * Returns inverted version of the matrix
         = (object) @Matrix
        \*/
        matrixproto.invert = function () {
            var me = this,
                x = me.a * me.d - me.b * me.c;
            return new Matrix(me.d / x, -me.b / x, -me.c / x, me.a / x, (me.c * me.f - me.d * me.e) / x, (me.b * me.e - me.a * me.f) / x);
        };
        /*\
         * Matrix.clone
         [ method ]
         **
         * Returns copy of the matrix
         = (object) @Matrix
        \*/
        matrixproto.clone = function () {
            return new Matrix(this.a, this.b, this.c, this.d, this.e, this.f);
        };
        /*\
         * Matrix.translate
         [ method ]
         **
         * Translate the matrix
         > Parameters
         - x (number)
         - y (number)
        \*/
        matrixproto.translate = function (x, y) {
            this.add(1, 0, 0, 1, x, y);
        };
        /*\
         * Matrix.scale
         [ method ]
         **
         * Scales the matrix
         > Parameters
         - x (number)
         - y (number) #optional
         - cx (number) #optional
         - cy (number) #optional
        \*/
        matrixproto.scale = function (x, y, cx, cy) {
            y == null && (y = x);
            (cx || cy) && this.add(1, 0, 0, 1, cx, cy);
            this.add(x, 0, 0, y, 0, 0);
            (cx || cy) && this.add(1, 0, 0, 1, -cx, -cy);
        };
        /*\
         * Matrix.rotate
         [ method ]
         **
         * Rotates the matrix
         > Parameters
         - a (number)
         - x (number)
         - y (number)
        \*/
        matrixproto.rotate = function (a, x, y) {
            a = R.rad(a);
            x = x || 0;
            y = y || 0;
            var cos = +math.cos(a).toFixed(9),
                sin = +math.sin(a).toFixed(9);
            this.add(cos, sin, -sin, cos, x, y);
            this.add(1, 0, 0, 1, -x, -y);
        };
        /*\
         * Matrix.x
         [ method ]
         **
         * Return x coordinate for given point after transformation described by the matrix. See also @Matrix.y
         > Parameters
         - x (number)
         - y (number)
         = (number) x
        \*/
        matrixproto.x = function (x, y) {
            return x * this.a + y * this.c + this.e;
        };
        /*\
         * Matrix.y
         [ method ]
         **
         * Return y coordinate for given point after transformation described by the matrix. See also @Matrix.x
         > Parameters
         - x (number)
         - y (number)
         = (number) y
        \*/
        matrixproto.y = function (x, y) {
            return x * this.b + y * this.d + this.f;
        };
        matrixproto.get = function (i) {
            return +this[Str.fromCharCode(97 + i)].toFixed(4);
        };
        matrixproto.toString = function () {
            return R.svg ?
                "matrix(" + [this.get(0), this.get(1), this.get(2), this.get(3), this.get(4), this.get(5)].join() + ")" :
                [this.get(0), this.get(2), this.get(1), this.get(3), 0, 0].join();
        };
        matrixproto.toFilter = function () {
            return "progid:DXImageTransform.Microsoft.Matrix(M11=" + this.get(0) +
                ", M12=" + this.get(2) + ", M21=" + this.get(1) + ", M22=" + this.get(3) +
                ", Dx=" + this.get(4) + ", Dy=" + this.get(5) + ", sizingmethod='auto expand')";
        };
        matrixproto.offset = function () {
            return [this.e.toFixed(4), this.f.toFixed(4)];
        };
        function norm(a) {
            return a[0] * a[0] + a[1] * a[1];
        }
        function normalize(a) {
            var mag = math.sqrt(norm(a));
            a[0] && (a[0] /= mag);
            a[1] && (a[1] /= mag);
        }
        /*\
         * Matrix.split
         [ method ]
         **
         * Splits matrix into primitive transformations
         = (object) in format:
         o dx (number) translation by x
         o dy (number) translation by y
         o scalex (number) scale by x
         o scaley (number) scale by y
         o shear (number) shear
         o rotate (number) rotation in deg
         o isSimple (boolean) could it be represented via simple transformations
        \*/
        matrixproto.split = function () {
            var out = {};
            // translation
            out.dx = this.e;
            out.dy = this.f;

            // scale and shear
            var row = [[this.a, this.c], [this.b, this.d]];
            out.scalex = math.sqrt(norm(row[0]));
            normalize(row[0]);

            out.shear = row[0][0] * row[1][0] + row[0][1] * row[1][1];
            row[1] = [row[1][0] - row[0][0] * out.shear, row[1][1] - row[0][1] * out.shear];

            out.scaley = math.sqrt(norm(row[1]));
            normalize(row[1]);
            out.shear /= out.scaley;

            // rotation
            var sin = -row[0][1],
                cos = row[1][1];
            if (cos < 0) {
                out.rotate = R.deg(math.acos(cos));
                if (sin < 0) {
                    out.rotate = 360 - out.rotate;
                }
            } else {
                out.rotate = R.deg(math.asin(sin));
            }

            out.isSimple = !+out.shear.toFixed(9) && (out.scalex.toFixed(9) == out.scaley.toFixed(9) || !out.rotate);
            out.isSuperSimple = !+out.shear.toFixed(9) && out.scalex.toFixed(9) == out.scaley.toFixed(9) && !out.rotate;
            out.noRotation = !+out.shear.toFixed(9) && !out.rotate;
            return out;
        };
        /*\
         * Matrix.toTransformString
         [ method ]
         **
         * Return transform string that represents given matrix
         = (string) transform string
        \*/
        matrixproto.toTransformString = function (shorter) {
            var s = shorter || this[split]();
            if (s.isSimple) {
                s.scalex = +s.scalex.toFixed(4);
                s.scaley = +s.scaley.toFixed(4);
                s.rotate = +s.rotate.toFixed(4);
                return  (s.dx || s.dy ? "t" + [s.dx, s.dy] : E) +
                        (s.scalex != 1 || s.scaley != 1 ? "s" + [s.scalex, s.scaley, 0, 0] : E) +
                        (s.rotate ? "r" + [s.rotate, 0, 0] : E);
            } else {
                return "m" + [this.get(0), this.get(1), this.get(2), this.get(3), this.get(4), this.get(5)];
            }
        };
    })(Matrix.prototype);

    var preventDefault = function () {
        this.returnValue = false;
    },
    preventTouch = function () {
        return this.originalEvent.preventDefault();
    },
    stopPropagation = function () {
        this.cancelBubble = true;
    },
    stopTouch = function () {
        return this.originalEvent.stopPropagation();
    },
    getEventPosition = function (e) {
        var scrollY = g.doc.documentElement.scrollTop || g.doc.body.scrollTop,
            scrollX = g.doc.documentElement.scrollLeft || g.doc.body.scrollLeft;

        return {
            x: e.clientX + scrollX,
            y: e.clientY + scrollY
        };
    },
    addEvent = (function () {
        if (g.doc.addEventListener) {
            return function (obj, type, fn, element) {
                var f = function (e) {
                    var pos = getEventPosition(e);
                    return fn.call(element, e, pos.x, pos.y);
                };
                obj.addEventListener(type, f, false);

                if (supportsTouch && touchMap[type]) {
                    var _f = function (e) {
                        var pos = getEventPosition(e),
                            olde = e;

                        for (var i = 0, ii = e.targetTouches && e.targetTouches.length; i < ii; i++) {
                            if (e.targetTouches[i].target == obj) {
                                e = e.targetTouches[i];
                                e.originalEvent = olde;
                                e.preventDefault = preventTouch;
                                e.stopPropagation = stopTouch;
                                break;
                            }
                        }

                        return fn.call(element, e, pos.x, pos.y);
                    };
                    obj.addEventListener(touchMap[type], _f, false);
                }

                return function () {
                    obj.removeEventListener(type, f, false);

                    if (supportsTouch && touchMap[type])
                        obj.removeEventListener(touchMap[type], _f, false);

                    return true;
                };
            };
        } else if (g.doc.attachEvent) {
            return function (obj, type, fn, element) {
                var f = function (e) {
                    e = e || g.win.event;
                    var scrollY = g.doc.documentElement.scrollTop || g.doc.body.scrollTop,
                        scrollX = g.doc.documentElement.scrollLeft || g.doc.body.scrollLeft,
                        x = e.clientX + scrollX,
                        y = e.clientY + scrollY;
                    e.preventDefault = e.preventDefault || preventDefault;
                    e.stopPropagation = e.stopPropagation || stopPropagation;
                    return fn.call(element, e, x, y);
                };
                obj.attachEvent("on" + type, f);
                var detacher = function () {
                    obj.detachEvent("on" + type, f);
                    return true;
                };
                return detacher;
            };
        }
    })(),
    drag = [],
    dragMove = function (e) {
        var x = e.clientX,
            y = e.clientY,
            scrollY = g.doc.documentElement.scrollTop || g.doc.body.scrollTop,
            scrollX = g.doc.documentElement.scrollLeft || g.doc.body.scrollLeft,
            dragi,
            j = drag.length;
        while (j--) {
            dragi = drag[j];
            if (supportsTouch && e.touches) {
                var i = e.touches.length,
                    touch;
                while (i--) {
                    touch = e.touches[i];
                    if (touch.identifier == dragi.el._drag.id) {
                        x = touch.clientX;
                        y = touch.clientY;
                        (e.originalEvent ? e.originalEvent : e).preventDefault();
                        break;
                    }
                }
            } else {
                e.preventDefault();
            }
            var node = dragi.el.node,
                o,
                next = node.nextSibling,
                parent = node.parentNode,
                display = node.style.display;
            g.win.opera && parent.removeChild(node);
            node.style.display = "none";
            o = dragi.el.paper.getElementByPoint(x, y);
            node.style.display = display;
            g.win.opera && (next ? parent.insertBefore(node, next) : parent.appendChild(node));
            o && eve("raphael.drag.over." + dragi.el.id, dragi.el, o);
            x += scrollX;
            y += scrollY;
            eve("raphael.drag.move." + dragi.el.id, dragi.move_scope || dragi.el, x - dragi.el._drag.x, y - dragi.el._drag.y, x, y, e);
        }
    },
    dragUp = function (e) {
        R.unmousemove(dragMove).unmouseup(dragUp);
        var i = drag.length,
            dragi;
        while (i--) {
            dragi = drag[i];
            dragi.el._drag = {};
            eve("raphael.drag.end." + dragi.el.id, dragi.end_scope || dragi.start_scope || dragi.move_scope || dragi.el, e);
        }
        drag = [];
    },
    /*\
     * Raphael.el
     [ property (object) ]
     **
     * You can add your own method to elements. This is usefull when you want to hack default functionality or
     * want to wrap some common transformation or attributes in one method. In difference to canvas methods,
     * you can redefine element method at any time. Expending element methods wouldn’t affect set.
     > Usage
     | Raphael.el.red = function () {
     |     this.attr({fill: "#f00"});
     | };
     | // then use it
     | paper.circle(100, 100, 20).red();
    \*/
    elproto = R.el = {};
    /*\
     * Element.click
     [ method ]
     **
     * Adds event handler for click for the element.
     > Parameters
     - handler (function) handler for the event
     = (object) @Element
    \*/
    /*\
     * Element.unclick
     [ method ]
     **
     * Removes event handler for click for the element.
     > Parameters
     - handler (function) #optional handler for the event
     = (object) @Element
    \*/

    /*\
     * Element.dblclick
     [ method ]
     **
     * Adds event handler for double click for the element.
     > Parameters
     - handler (function) handler for the event
     = (object) @Element
    \*/
    /*\
     * Element.undblclick
     [ method ]
     **
     * Removes event handler for double click for the element.
     > Parameters
     - handler (function) #optional handler for the event
     = (object) @Element
    \*/

    /*\
     * Element.mousedown
     [ method ]
     **
     * Adds event handler for mousedown for the element.
     > Parameters
     - handler (function) handler for the event
     = (object) @Element
    \*/
    /*\
     * Element.unmousedown
     [ method ]
     **
     * Removes event handler for mousedown for the element.
     > Parameters
     - handler (function) #optional handler for the event
     = (object) @Element
    \*/

    /*\
     * Element.mousemove
     [ method ]
     **
     * Adds event handler for mousemove for the element.
     > Parameters
     - handler (function) handler for the event
     = (object) @Element
    \*/
    /*\
     * Element.unmousemove
     [ method ]
     **
     * Removes event handler for mousemove for the element.
     > Parameters
     - handler (function) #optional handler for the event
     = (object) @Element
    \*/

    /*\
     * Element.mouseout
     [ method ]
     **
     * Adds event handler for mouseout for the element.
     > Parameters
     - handler (function) handler for the event
     = (object) @Element
    \*/
    /*\
     * Element.unmouseout
     [ method ]
     **
     * Removes event handler for mouseout for the element.
     > Parameters
     - handler (function) #optional handler for the event
     = (object) @Element
    \*/

    /*\
     * Element.mouseover
     [ method ]
     **
     * Adds event handler for mouseover for the element.
     > Parameters
     - handler (function) handler for the event
     = (object) @Element
    \*/
    /*\
     * Element.unmouseover
     [ method ]
     **
     * Removes event handler for mouseover for the element.
     > Parameters
     - handler (function) #optional handler for the event
     = (object) @Element
    \*/

    /*\
     * Element.mouseup
     [ method ]
     **
     * Adds event handler for mouseup for the element.
     > Parameters
     - handler (function) handler for the event
     = (object) @Element
    \*/
    /*\
     * Element.unmouseup
     [ method ]
     **
     * Removes event handler for mouseup for the element.
     > Parameters
     - handler (function) #optional handler for the event
     = (object) @Element
    \*/

    /*\
     * Element.touchstart
     [ method ]
     **
     * Adds event handler for touchstart for the element.
     > Parameters
     - handler (function) handler for the event
     = (object) @Element
    \*/
    /*\
     * Element.untouchstart
     [ method ]
     **
     * Removes event handler for touchstart for the element.
     > Parameters
     - handler (function) #optional handler for the event
     = (object) @Element
    \*/

    /*\
     * Element.touchmove
     [ method ]
     **
     * Adds event handler for touchmove for the element.
     > Parameters
     - handler (function) handler for the event
     = (object) @Element
    \*/
    /*\
     * Element.untouchmove
     [ method ]
     **
     * Removes event handler for touchmove for the element.
     > Parameters
     - handler (function) #optional handler for the event
     = (object) @Element
    \*/

    /*\
     * Element.touchend
     [ method ]
     **
     * Adds event handler for touchend for the element.
     > Parameters
     - handler (function) handler for the event
     = (object) @Element
    \*/
    /*\
     * Element.untouchend
     [ method ]
     **
     * Removes event handler for touchend for the element.
     > Parameters
     - handler (function) #optional handler for the event
     = (object) @Element
    \*/

    /*\
     * Element.touchcancel
     [ method ]
     **
     * Adds event handler for touchcancel for the element.
     > Parameters
     - handler (function) handler for the event
     = (object) @Element
    \*/
    /*\
     * Element.untouchcancel
     [ method ]
     **
     * Removes event handler for touchcancel for the element.
     > Parameters
     - handler (function) #optional handler for the event
     = (object) @Element
    \*/
    for (var i = events.length; i--;) {
        (function (eventName) {
            R[eventName] = elproto[eventName] = function (fn, scope) {
                if (R.is(fn, "function")) {
                    this.events = this.events || [];
                    this.events.push({name: eventName, f: fn, unbind: addEvent(this.shape || this.node || g.doc, eventName, fn, scope || this)});
                }
                return this;
            };
            R["un" + eventName] = elproto["un" + eventName] = function (fn) {
                var events = this.events || [],
                    l = events.length;
                while (l--){
                    if (events[l].name == eventName && (R.is(fn, "undefined") || events[l].f == fn)) {
                        events[l].unbind();
                        events.splice(l, 1);
                        !events.length && delete this.events;
                    }
                }
                return this;
            };
        })(events[i]);
    }

    /*\
     * Element.data
     [ method ]
     **
     * Adds or retrieves given value asociated with given key.
     **
     * See also @Element.removeData
     > Parameters
     - key (string) key to store data
     - value (any) #optional value to store
     = (object) @Element
     * or, if value is not specified:
     = (any) value
     * or, if key and value are not specified:
     = (object) Key/value pairs for all the data associated with the element.
     > Usage
     | for (var i = 0, i < 5, i++) {
     |     paper.circle(10 + 15 * i, 10, 10)
     |          .attr({fill: "#000"})
     |          .data("i", i)
     |          .click(function () {
     |             alert(this.data("i"));
     |          });
     | }
    \*/
    elproto.data = function (key, value) {
        var data = eldata[this.id] = eldata[this.id] || {};
        if (arguments.length == 0) {
            return data;
        }
        if (arguments.length == 1) {
            if (R.is(key, "object")) {
                for (var i in key) if (key[has](i)) {
                    this.data(i, key[i]);
                }
                return this;
            }
            eve("raphael.data.get." + this.id, this, data[key], key);
            return data[key];
        }
        data[key] = value;
        eve("raphael.data.set." + this.id, this, value, key);
        return this;
    };
    /*\
     * Element.removeData
     [ method ]
     **
     * Removes value associated with an element by given key.
     * If key is not provided, removes all the data of the element.
     > Parameters
     - key (string) #optional key
     = (object) @Element
    \*/
    elproto.removeData = function (key) {
        if (key == null) {
            eldata[this.id] = {};
        } else {
            eldata[this.id] && delete eldata[this.id][key];
        }
        return this;
    };
     /*\
     * Element.getData
     [ method ]
     **
     * Retrieves the element data
     = (object) data
    \*/
    elproto.getData = function () {
        return clone(eldata[this.id] || {});
    };
    /*\
     * Element.hover
     [ method ]
     **
     * Adds event handlers for hover for the element.
     > Parameters
     - f_in (function) handler for hover in
     - f_out (function) handler for hover out
     - icontext (object) #optional context for hover in handler
     - ocontext (object) #optional context for hover out handler
     = (object) @Element
    \*/
    elproto.hover = function (f_in, f_out, scope_in, scope_out) {
        return this.mouseover(f_in, scope_in).mouseout(f_out, scope_out || scope_in);
    };
    /*\
     * Element.unhover
     [ method ]
     **
     * Removes event handlers for hover for the element.
     > Parameters
     - f_in (function) handler for hover in
     - f_out (function) handler for hover out
     = (object) @Element
    \*/
    elproto.unhover = function (f_in, f_out) {
        return this.unmouseover(f_in).unmouseout(f_out);
    };
    var draggable = [];
    /*\
     * Element.drag
     [ method ]
     **
     * Adds event handlers for drag of the element.
     > Parameters
     - onmove (function) handler for moving
     - onstart (function) handler for drag start
     - onend (function) handler for drag end
     - mcontext (object) #optional context for moving handler
     - scontext (object) #optional context for drag start handler
     - econtext (object) #optional context for drag end handler
     * Additionaly following `drag` events will be triggered: `drag.start.<id>` on start,
     * `drag.end.<id>` on end and `drag.move.<id>` on every move. When element will be dragged over another element
     * `drag.over.<id>` will be fired as well.
     *
     * Start event and start handler will be called in specified context or in context of the element with following parameters:
     o x (number) x position of the mouse
     o y (number) y position of the mouse
     o event (object) DOM event object
     * Move event and move handler will be called in specified context or in context of the element with following parameters:
     o dx (number) shift by x from the start point
     o dy (number) shift by y from the start point
     o x (number) x position of the mouse
     o y (number) y position of the mouse
     o event (object) DOM event object
     * End event and end handler will be called in specified context or in context of the element with following parameters:
     o event (object) DOM event object
     = (object) @Element
    \*/
    elproto.drag = function (onmove, onstart, onend, move_scope, start_scope, end_scope) {
        function start(e) {
            (e.originalEvent || e).preventDefault();
            var x = e.clientX,
                y = e.clientY,
                scrollY = g.doc.documentElement.scrollTop || g.doc.body.scrollTop,
                scrollX = g.doc.documentElement.scrollLeft || g.doc.body.scrollLeft;
            this._drag.id = e.identifier;
            if (supportsTouch && e.touches) {
                var i = e.touches.length, touch;
                while (i--) {
                    touch = e.touches[i];
                    this._drag.id = touch.identifier;
                    if (touch.identifier == this._drag.id) {
                        x = touch.clientX;
                        y = touch.clientY;
                        break;
                    }
                }
            }
            this._drag.x = x + scrollX;
            this._drag.y = y + scrollY;
            !drag.length && R.mousemove(dragMove).mouseup(dragUp);
            drag.push({el: this, move_scope: move_scope, start_scope: start_scope, end_scope: end_scope});
            onstart && eve.on("raphael.drag.start." + this.id, onstart);
            onmove && eve.on("raphael.drag.move." + this.id, onmove);
            onend && eve.on("raphael.drag.end." + this.id, onend);
            eve("raphael.drag.start." + this.id, start_scope || move_scope || this, /*[CC]*/ this._drag.x, this._drag.y /*[/CC]*/, e);
        }
        this._drag = {};
        draggable.push({el: this, start: start});
        this.mousedown(start);
        return this;
    };
    /*\
     * Element.onDragOver
     [ method ]
     **
     * Shortcut for assigning event handler for `drag.over.<id>` event, where id is id of the element (see @Element.id).
     > Parameters
     - f (function) handler for event, first argument would be the element you are dragging over
    \*/
    elproto.onDragOver = function (f) {
        f ? eve.on("raphael.drag.over." + this.id, f) : eve.unbind("raphael.drag.over." + this.id);
    };
    /*\
     * Element.undrag
     [ method ]
     **
     * Removes all drag event handlers from given element.
    \*/
    elproto.undrag = function () {
        var i = draggable.length;
        while (i--) if (draggable[i].el == this) {
            this.unmousedown(draggable[i].start);
            draggable.splice(i, 1);
            eve.unbind("raphael.drag.*." + this.id);
        }
        !draggable.length && R.unmousemove(dragMove).unmouseup(dragUp);
        drag = [];
    };
    /*\
     * Paper.circle
     [ method ]
     **
     * Draws a circle.
     **
     > Parameters
     **
     - x (number) x coordinate of the centre
     - y (number) y coordinate of the centre
     - r (number) radius
     = (object) Raphaël element object with type “circle”
     **
     > Usage
     | var c = paper.circle(50, 50, 40);
    \*/
    paperproto.circle = function (x, y, r) {
        var out = R._engine.circle(this, x || 0, y || 0, r || 0);
        this.__set__ && this.__set__.push(out);
        return out;
    };
    /*\
     * Paper.rect
     [ method ]
     *
     * Draws a rectangle.
     **
     > Parameters
     **
     - x (number) x coordinate of the top left corner
     - y (number) y coordinate of the top left corner
     - width (number) width
     - height (number) height
     - r (number) #optional radius for rounded corners, default is 0
     = (object) Raphaël element object with type “rect”
     **
     > Usage
     | // regular rectangle
     | var c = paper.rect(10, 10, 50, 50);
     | // rectangle with rounded corners
     | var c = paper.rect(40, 40, 50, 50, 10);
    \*/
    paperproto.rect = function (x, y, w, h, r) {
        var out = R._engine.rect(this, x || 0, y || 0, w || 0, h || 0, r || 0);
        this.__set__ && this.__set__.push(out);
        return out;
    };
    /*\
     * Paper.ellipse
     [ method ]
     **
     * Draws an ellipse.
     **
     > Parameters
     **
     - x (number) x coordinate of the centre
     - y (number) y coordinate of the centre
     - rx (number) horizontal radius
     - ry (number) vertical radius
     = (object) Raphaël element object with type “ellipse”
     **
     > Usage
     | var c = paper.ellipse(50, 50, 40, 20);
    \*/
    paperproto.ellipse = function (x, y, rx, ry) {
        var out = R._engine.ellipse(this, x || 0, y || 0, rx || 0, ry || 0);
        this.__set__ && this.__set__.push(out);
        return out;
    };
    /*\
     * Paper.path
     [ method ]
     **
     * Creates a path element by given path data string.
     > Parameters
     - pathString (string) #optional path string in SVG format.
     * Path string consists of one-letter commands, followed by comma seprarated arguments in numercal form. Example:
     | "M10,20L30,40"
     * Here we can see two commands: “M”, with arguments `(10, 20)` and “L” with arguments `(30, 40)`. Upper case letter mean command is absolute, lower case—relative.
     *
     # <p>Here is short list of commands available, for more details see <a href="http://www.w3.org/TR/SVG/paths.html#PathData" title="Details of a path's data attribute's format are described in the SVG specification.">SVG path string format</a>.</p>
     # <table><thead><tr><th>Command</th><th>Name</th><th>Parameters</th></tr></thead><tbody>
     # <tr><td>M</td><td>moveto</td><td>(x y)+</td></tr>
     # <tr><td>Z</td><td>closepath</td><td>(none)</td></tr>
     # <tr><td>L</td><td>lineto</td><td>(x y)+</td></tr>
     # <tr><td>H</td><td>horizontal lineto</td><td>x+</td></tr>
     # <tr><td>V</td><td>vertical lineto</td><td>y+</td></tr>
     # <tr><td>C</td><td>curveto</td><td>(x1 y1 x2 y2 x y)+</td></tr>
     # <tr><td>S</td><td>smooth curveto</td><td>(x2 y2 x y)+</td></tr>
     # <tr><td>Q</td><td>quadratic Bézier curveto</td><td>(x1 y1 x y)+</td></tr>
     # <tr><td>T</td><td>smooth quadratic Bézier curveto</td><td>(x y)+</td></tr>
     # <tr><td>A</td><td>elliptical arc</td><td>(rx ry x-axis-rotation large-arc-flag sweep-flag x y)+</td></tr>
     # <tr><td>R</td><td><a href="http://en.wikipedia.org/wiki/Catmull–Rom_spline#Catmull.E2.80.93Rom_spline">Catmull-Rom curveto</a>*</td><td>x1 y1 (x y)+</td></tr></tbody></table>
     * * “Catmull-Rom curveto” is a not standard SVG command and added in 2.0 to make life easier.
     * Note: there is a special case when path consist of just three commands: “M10,10R…z”. In this case path will smoothly connects to its beginning.
     > Usage
     | var c = paper.path("M10 10L90 90");
     | // draw a diagonal line:
     | // move to 10,10, line to 90,90
     * For example of path strings, check out these icons: http://raphaeljs.com/icons/
    \*/
    paperproto.path = function (pathString) {
        pathString && !R.is(pathString, string) && !R.is(pathString[0], array) && (pathString += E);
        var out = R._engine.path(R.format[apply](R, arguments), this);
        this.__set__ && this.__set__.push(out);
        return out;
    };
    /*\
     * Paper.image
     [ method ]
     **
     * Embeds an image into the surface.
     **
     > Parameters
     **
     - src (string) URI of the source image
     - x (number) x coordinate position
     - y (number) y coordinate position
     - width (number) width of the image
     - height (number) height of the image
     = (object) Raphaël element object with type “image”
     **
     > Usage
     | var c = paper.image("apple.png", 10, 10, 80, 80);
    \*/
    paperproto.image = function (src, x, y, w, h) {
        var out = R._engine.image(this, src || "about:blank", x || 0, y || 0, w || 0, h || 0);
        this.__set__ && this.__set__.push(out);
        return out;
    };
    /*\
     * Paper.text
     [ method ]
     **
     * Draws a text string. If you need line breaks, put “\n” in the string.
     **
     > Parameters
     **
     - x (number) x coordinate position
     - y (number) y coordinate position
     - text (string) The text string to draw
     = (object) Raphaël element object with type “text”
     **
     > Usage
     | var t = paper.text(50, 50, "Raphaël\nkicks\nbutt!");
    \*/
    paperproto.text = function (x, y, text) {
        var out = R._engine.text(this, x || 0, y || 0, Str(text));
        this.__set__ && this.__set__.push(out);
        return out;
    };
    /*\
     * Paper.set
     [ method ]
     **
     * Creates array-like object to keep and operate several elements at once.
     * Warning: it doesn’t create any elements for itself in the page, it just groups existing elements.
     * Sets act as pseudo elements — all methods available to an element can be used on a set.
     = (object) array-like object that represents set of elements
     **
     > Usage
     | var st = paper.set();
     | st.push(
     |     paper.circle(10, 10, 5),
     |     paper.circle(30, 10, 5)
     | );
     | st.attr({fill: "red"}); // changes the fill of both circles
    \*/
    paperproto.set = function (itemsArray) {
        !R.is(itemsArray, "array") && (itemsArray = Array.prototype.splice.call(arguments, 0, arguments.length));
        var out = new Set(itemsArray);
        this.__set__ && this.__set__.push(out);
        out["paper"] = this;
        out["type"] = "set";
        return out;
    };
    /*\
     * Paper.setStart
     [ method ]
     **
     * Creates @Paper.set. All elements that will be created after calling this method and before calling
     * @Paper.setFinish will be added to the set.
     **
     > Usage
     | paper.setStart();
     | paper.circle(10, 10, 5),
     | paper.circle(30, 10, 5)
     | var st = paper.setFinish();
     | st.attr({fill: "red"}); // changes the fill of both circles
    \*/
    paperproto.setStart = function (set) {
        this.__set__ = set || this.set();
    };
    /*\
     * Paper.setFinish
     [ method ]
     **
     * See @Paper.setStart. This method finishes catching and returns resulting set.
     **
     = (object) set
    \*/
    paperproto.setFinish = function (set) {
        var out = this.__set__;
        delete this.__set__;
        return out;
    };
    /*\
     * Paper.getSize
     [ method ]
     **
     * Obtains current paper actual size.
     **
     = (object)
     \*/
    paperproto.getSize = function () {
        var container = this.canvas.parentNode;
        return {
            width: container.offsetWidth,
            height: container.offsetHeight
                };
        };
    /*\
     * Paper.setSize
     [ method ]
     **
     * If you need to change dimensions of the canvas call this method
     **
     > Parameters
     **
     - width (number) new width of the canvas
     - height (number) new height of the canvas
    \*/
    paperproto.setSize = function (width, height) {
        return R._engine.setSize.call(this, width, height);
    };
    /*\
     * Paper.setViewBox
     [ method ]
     **
     * Sets the view box of the paper. Practically it gives you ability to zoom and pan whole paper surface by
     * specifying new boundaries.
     **
     > Parameters
     **
     - x (number) new x position, default is `0`
     - y (number) new y position, default is `0`
     - w (number) new width of the canvas
     - h (number) new height of the canvas
     - fit (boolean) `true` if you want graphics to fit into new boundary box
    \*/
    paperproto.setViewBox = function (x, y, w, h, fit) {
        return R._engine.setViewBox.call(this, x, y, w, h, fit);
    };
    /*\
     * Paper.top
     [ property ]
     **
     * Points to the topmost element on the paper
    \*/
    /*\
     * Paper.bottom
     [ property ]
     **
     * Points to the bottom element on the paper
    \*/
    paperproto.top = paperproto.bottom = null;
    /*\
     * Paper.raphael
     [ property ]
     **
     * Points to the @Raphael object/function
    \*/
    paperproto.raphael = R;
    var getOffset = function (elem) {
        var box = elem.getBoundingClientRect(),
            doc = elem.ownerDocument,
            body = doc.body,
            docElem = doc.documentElement,
            clientTop = docElem.clientTop || body.clientTop || 0, clientLeft = docElem.clientLeft || body.clientLeft || 0,
            top  = box.top  + (g.win.pageYOffset || docElem.scrollTop || body.scrollTop ) - clientTop,
            left = box.left + (g.win.pageXOffset || docElem.scrollLeft || body.scrollLeft) - clientLeft;
        return {
            y: top,
            x: left
        };
    };
    /*\
     * Paper.getElementByPoint
     [ method ]
     **
     * Returns you topmost element under given point.
     **
     = (object) Raphaël element object
     > Parameters
     **
     - x (number) x coordinate from the top left corner of the window
     - y (number) y coordinate from the top left corner of the window
     > Usage
     | paper.getElementByPoint(mouseX, mouseY).attr({stroke: "#f00"});
    \*/
    paperproto.getElementByPoint = function (x, y) {
        var paper = this,
            svg = paper.canvas,
            target = g.doc.elementFromPoint(x, y);
        if (g.win.opera && target.tagName == "svg") {
            var so = getOffset(svg),
                sr = svg.createSVGRect();
            sr.x = x - so.x;
            sr.y = y - so.y;
            sr.width = sr.height = 1;
            var hits = svg.getIntersectionList(sr, null);
            if (hits.length) {
                target = hits[hits.length - 1];
            }
        }
        if (!target) {
            return null;
        }
        while (target.parentNode && target != svg.parentNode && !target.raphael) {
            target = target.parentNode;
        }
        target == paper.canvas.parentNode && (target = svg);
        target = target && target.raphael ? paper.getById(target.raphaelid) : null;
        return target;
    };

    /*\
     * Paper.getElementsByBBox
     [ method ]
     **
     * Returns set of elements that have an intersecting bounding box
     **
     > Parameters
     **
     - bbox (object) bbox to check with
     = (object) @Set
     \*/
    paperproto.getElementsByBBox = function (bbox) {
        var set = this.set();
        this.forEach(function (el) {
            if (R.isBBoxIntersect(el.getBBox(), bbox)) {
                set.push(el);
            }
        });
        return set;
    };

    /*\
     * Paper.getById
     [ method ]
     **
     * Returns you element by its internal ID.
     **
     > Parameters
     **
     - id (number) id
     = (object) Raphaël element object
    \*/
    paperproto.getById = function (id) {
        var bot = this.bottom;
        while (bot) {
            if (bot.id == id) {
                return bot;
            }
            bot = bot.next;
        }
        return null;
    };
    /*\
     * Paper.forEach
     [ method ]
     **
     * Executes given function for each element on the paper
     *
     * If callback function returns `false` it will stop loop running.
     **
     > Parameters
     **
     - callback (function) function to run
     - thisArg (object) context object for the callback
     = (object) Paper object
     > Usage
     | paper.forEach(function (el) {
     |     el.attr({ stroke: "blue" });
     | });
    \*/
    paperproto.forEach = function (callback, thisArg) {
        var bot = this.bottom;
        while (bot) {
            if (callback.call(thisArg, bot) === false) {
                return this;
            }
            bot = bot.next;
        }
        return this;
    };
    /*\
     * Paper.getElementsByPoint
     [ method ]
     **
     * Returns set of elements that have common point inside
     **
     > Parameters
     **
     - x (number) x coordinate of the point
     - y (number) y coordinate of the point
     = (object) @Set
    \*/
    paperproto.getElementsByPoint = function (x, y) {
        var set = this.set();
        this.forEach(function (el) {
            if (el.isPointInside(x, y)) {
                set.push(el);
            }
        });
        return set;
    };
    function x_y() {
        return this.x + S + this.y;
    }
    function x_y_w_h() {
        return this.x + S + this.y + S + this.width + " \xd7 " + this.height;
    }
    /*\
     * Element.isPointInside
     [ method ]
     **
     * Determine if given point is inside this element’s shape
     **
     > Parameters
     **
     - x (number) x coordinate of the point
     - y (number) y coordinate of the point
     = (boolean) `true` if point inside the shape
    \*/
    elproto.isPointInside = function (x, y) {
        var rp = this.realPath = getPath[this.type](this);
        if (this.attr('transform') && this.attr('transform').length) {
            rp = R.transformPath(rp, this.attr('transform'));
        }
        return R.isPointInsidePath(rp, x, y);
    };
    /*\
     * Element.getBBox
     [ method ]
     **
     * Return bounding box for a given element
     **
     > Parameters
     **
     - isWithoutTransform (boolean) flag, `true` if you want to have bounding box before transformations. Default is `false`.
     = (object) Bounding box object:
     o {
     o     x: (number) top left corner x
     o     y: (number) top left corner y
     o     x2: (number) bottom right corner x
     o     y2: (number) bottom right corner y
     o     width: (number) width
     o     height: (number) height
     o }
    \*/
    elproto.getBBox = function (isWithoutTransform) {
        if (this.removed) {
            return {};
        }
        var _ = this._;
        if (isWithoutTransform) {
            if (_.dirty || !_.bboxwt) {
                this.realPath = getPath[this.type](this);
                _.bboxwt = pathDimensions(this.realPath);
                _.bboxwt.toString = x_y_w_h;
                _.dirty = 0;
            }
            return _.bboxwt;
        }
        if (_.dirty || _.dirtyT || !_.bbox) {
            if (_.dirty || !this.realPath) {
                _.bboxwt = 0;
                this.realPath = getPath[this.type](this);
            }
            _.bbox = pathDimensions(mapPath(this.realPath, this.matrix));
            _.bbox.toString = x_y_w_h;
            _.dirty = _.dirtyT = 0;
        }
        return _.bbox;
    };
    /*\
     * Element.clone
     [ method ]
     **
     = (object) clone of a given element
     **
    \*/
    elproto.clone = function () {
        if (this.removed) {
            return null;
        }
        var out = this.paper[this.type]().attr(this.attr());
        this.__set__ && this.__set__.push(out);
        return out;
    };
    /*\
     * Element.glow
     [ method ]
     **
     * Return set of elements that create glow-like effect around given element. See @Paper.set.
     *
     * Note: Glow is not connected to the element. If you change element attributes it won’t adjust itself.
     **
     > Parameters
     **
     - glow (object) #optional parameters object with all properties optional:
     o {
     o     width (number) size of the glow, default is `10`
     o     fill (boolean) will it be filled, default is `false`
     o     opacity (number) opacity, default is `0.5`
     o     offsetx (number) horizontal offset, default is `0`
     o     offsety (number) vertical offset, default is `0`
     o     color (string) glow colour, default is `black`
     o }
     = (object) @Paper.set of elements that represents glow
    \*/
    elproto.glow = function (glow) {
        if (this.type == "text") {
            return null;
        }
        glow = glow || {};
        var s = {
            width: (glow.width || 10) + (+this.attr("stroke-width") || 1),
            fill: glow.fill || false,
            opacity: glow.opacity || .5,
            offsetx: glow.offsetx || 0,
            offsety: glow.offsety || 0,
            color: glow.color || "#000"
        },
            c = s.width / 2,
            r = this.paper,
            out = r.set(),
            path = this.realPath || getPath[this.type](this);
        path = this.matrix ? mapPath(path, this.matrix) : path;
        for (var i = 1; i < c + 1; i++) {
            out.push(r.path(path).attr({
                stroke: s.color,
                fill: s.fill ? s.color : "none",
                "stroke-linejoin": "round",
                "stroke-linecap": "round",
                "stroke-width": +(s.width / c * i).toFixed(3),
                opacity: +(s.opacity / c).toFixed(3)
            }));
        }
        return out.insertBefore(this).translate(s.offsetx, s.offsety);
    };
    var curveslengths = {},
    getPointAtSegmentLength = function (p1x, p1y, c1x, c1y, c2x, c2y, p2x, p2y, length) {
        if (length == null) {
            return bezlen(p1x, p1y, c1x, c1y, c2x, c2y, p2x, p2y);
        } else {
            return R.findDotsAtSegment(p1x, p1y, c1x, c1y, c2x, c2y, p2x, p2y, getTatLen(p1x, p1y, c1x, c1y, c2x, c2y, p2x, p2y, length));
        }
    },
    getLengthFactory = function (istotal, subpath) {
        return function (path, length, onlystart) {
            path = path2curve(path);
            var x, y, p, l, sp = "", subpaths = {}, point,
                len = 0;
            for (var i = 0, ii = path.length; i < ii; i++) {
                p = path[i];
                if (p[0] == "M") {
                    x = +p[1];
                    y = +p[2];
                } else {
                    l = getPointAtSegmentLength(x, y, p[1], p[2], p[3], p[4], p[5], p[6]);
                    if (len + l > length) {
                        if (subpath && !subpaths.start) {
                            point = getPointAtSegmentLength(x, y, p[1], p[2], p[3], p[4], p[5], p[6], length - len);
                            sp += ["C" + point.start.x, point.start.y, point.m.x, point.m.y, point.x, point.y];
                            if (onlystart) {return sp;}
                            subpaths.start = sp;
                            sp = ["M" + point.x, point.y + "C" + point.n.x, point.n.y, point.end.x, point.end.y, p[5], p[6]].join();
                            len += l;
                            x = +p[5];
                            y = +p[6];
                            continue;
                        }
                        if (!istotal && !subpath) {
                            point = getPointAtSegmentLength(x, y, p[1], p[2], p[3], p[4], p[5], p[6], length - len);
                            return {x: point.x, y: point.y, alpha: point.alpha};
                        }
                    }
                    len += l;
                    x = +p[5];
                    y = +p[6];
                }
                sp += p.shift() + p;
            }
            subpaths.end = sp;
            point = istotal ? len : subpath ? subpaths : R.findDotsAtSegment(x, y, p[0], p[1], p[2], p[3], p[4], p[5], 1);
            point.alpha && (point = {x: point.x, y: point.y, alpha: point.alpha});
            return point;
        };
    };
    var getTotalLength = getLengthFactory(1),
        getPointAtLength = getLengthFactory(),
        getSubpathsAtLength = getLengthFactory(0, 1);
    /*\
     * Raphael.getTotalLength
     [ method ]
     **
     * Returns length of the given path in pixels.
     **
     > Parameters
     **
     - path (string) SVG path string.
     **
     = (number) length.
    \*/
    R.getTotalLength = getTotalLength;
    /*\
     * Raphael.getPointAtLength
     [ method ]
     **
     * Return coordinates of the point located at the given length on the given path.
     **
     > Parameters
     **
     - path (string) SVG path string
     - length (number)
     **
     = (object) representation of the point:
     o {
     o     x: (number) x coordinate
     o     y: (number) y coordinate
     o     alpha: (number) angle of derivative
     o }
    \*/
    R.getPointAtLength = getPointAtLength;
    /*\
     * Raphael.getSubpath
     [ method ]
     **
     * Return subpath of a given path from given length to given length.
     **
     > Parameters
     **
     - path (string) SVG path string
     - from (number) position of the start of the segment
     - to (number) position of the end of the segment
     **
     = (string) pathstring for the segment
    \*/
    R.getSubpath = function (path, from, to) {
        if (this.getTotalLength(path) - to < 1e-6) {
            return getSubpathsAtLength(path, from).end;
        }
        var a = getSubpathsAtLength(path, to, 1);
        return from ? getSubpathsAtLength(a, from).end : a;
    };
    /*\
     * Element.getTotalLength
     [ method ]
     **
     * Returns length of the path in pixels. Only works for element of “path” type.
     = (number) length.
    \*/
    elproto.getTotalLength = function () {
        var path = this.getPath();
        if (!path) {
            return;
        }

        if (this.node.getTotalLength) {
            return this.node.getTotalLength();
        }

        return getTotalLength(path);
    };
    /*\
     * Element.getPointAtLength
     [ method ]
     **
     * Return coordinates of the point located at the given length on the given path. Only works for element of “path” type.
     **
     > Parameters
     **
     - length (number)
     **
     = (object) representation of the point:
     o {
     o     x: (number) x coordinate
     o     y: (number) y coordinate
     o     alpha: (number) angle of derivative
     o }
    \*/
    elproto.getPointAtLength = function (length) {
        var path = this.getPath();
        if (!path) {
            return;
        }

        return getPointAtLength(path, length);
    };
    /*\
     * Element.getPath
     [ method ]
     **
     * Returns path of the element. Only works for elements of “path” type and simple elements like circle.
     = (object) path
     **
    \*/
    elproto.getPath = function () {
        var path,
            getPath = R._getPath[this.type];

        if (this.type == "text" || this.type == "set") {
            return;
        }

        if (getPath) {
            path = getPath(this);
        }

        return path;
    };
    /*\
     * Element.getSubpath
     [ method ]
     **
     * Return subpath of a given element from given length to given length. Only works for element of “path” type.
     **
     > Parameters
     **
     - from (number) position of the start of the segment
     - to (number) position of the end of the segment
     **
     = (string) pathstring for the segment
    \*/
    elproto.getSubpath = function (from, to) {
        var path = this.getPath();
        if (!path) {
            return;
        }

        return R.getSubpath(path, from, to);
    };
    /*\
     * Raphael.easing_formulas
     [ property ]
     **
     * Object that contains easing formulas for animation. You could extend it with your own. By default it has following list of easing:
     # <ul>
     #     <li>“linear”</li>
     #     <li>“&lt;” or “easeIn” or “ease-in”</li>
     #     <li>“>” or “easeOut” or “ease-out”</li>
     #     <li>“&lt;>” or “easeInOut” or “ease-in-out”</li>
     #     <li>“backIn” or “back-in”</li>
     #     <li>“backOut” or “back-out”</li>
     #     <li>“elastic”</li>
     #     <li>“bounce”</li>
     # </ul>
     # <p>See also <a href="http://raphaeljs.com/easing.html">Easing demo</a>.</p>
    \*/
    var ef = R.easing_formulas = {
        linear: function (n) {
            return n;
        },
        "<": function (n) {
            return pow(n, 1.7);
        },
        ">": function (n) {
            return pow(n, .48);
        },
        "<>": function (n) {
            var q = .48 - n / 1.04,
                Q = math.sqrt(.1734 + q * q),
                x = Q - q,
                X = pow(abs(x), 1 / 3) * (x < 0 ? -1 : 1),
                y = -Q - q,
                Y = pow(abs(y), 1 / 3) * (y < 0 ? -1 : 1),
                t = X + Y + .5;
            return (1 - t) * 3 * t * t + t * t * t;
        },
        backIn: function (n) {
            var s = 1.70158;
            return n * n * ((s + 1) * n - s);
        },
        backOut: function (n) {
            n = n - 1;
            var s = 1.70158;
            return n * n * ((s + 1) * n + s) + 1;
        },
        elastic: function (n) {
            if (n == !!n) {
                return n;
            }
            return pow(2, -10 * n) * math.sin((n - .075) * (2 * PI) / .3) + 1;
        },
        bounce: function (n) {
            var s = 7.5625,
                p = 2.75,
                l;
            if (n < (1 / p)) {
                l = s * n * n;
            } else {
                if (n < (2 / p)) {
                    n -= (1.5 / p);
                    l = s * n * n + .75;
                } else {
                    if (n < (2.5 / p)) {
                        n -= (2.25 / p);
                        l = s * n * n + .9375;
                    } else {
                        n -= (2.625 / p);
                        l = s * n * n + .984375;
                    }
                }
            }
            return l;
        }
    };
    ef.easeIn = ef["ease-in"] = ef["<"];
    ef.easeOut = ef["ease-out"] = ef[">"];
    ef.easeInOut = ef["ease-in-out"] = ef["<>"];
    ef["back-in"] = ef.backIn;
    ef["back-out"] = ef.backOut;

    var animationElements = [],
        requestAnimFrame = window.requestAnimationFrame       ||
                           window.webkitRequestAnimationFrame ||
                           window.mozRequestAnimationFrame    ||
                           window.oRequestAnimationFrame      ||
                           window.msRequestAnimationFrame     ||
                           function (callback) {
                               setTimeout(callback, 16);
                           },
        animation = function () {
            var Now = +new Date,
                l = 0;
            for (; l < animationElements.length; l++) {
                var e = animationElements[l];
                if (e.el.removed || e.paused) {
                    continue;
                }
                var time = Now - e.start,
                    ms = e.ms,
                    easing = e.easing,
                    from = e.from,
                    diff = e.diff,
                    to = e.to,
                    t = e.t,
                    that = e.el,
                    set = {},
                    now,
                    init = {},
                    key;
                if (e.initstatus) {
                    time = (e.initstatus * e.anim.top - e.prev) / (e.percent - e.prev) * ms;
                    e.status = e.initstatus;
                    delete e.initstatus;
                    e.stop && animationElements.splice(l--, 1);
                } else {
                    e.status = (e.prev + (e.percent - e.prev) * (time / ms)) / e.anim.top;
                }
                if (time < 0) {
                    continue;
                }
                if (time < ms) {
                    var pos = easing(time / ms);
                    for (var attr in from) if (from[has](attr)) {
                        switch (availableAnimAttrs[attr]) {
                            case nu:
                                now = +from[attr] + pos * ms * diff[attr];
                                break;
                            case "colour":
                                now = "rgb(" + [
                                    upto255(round(from[attr].r + pos * ms * diff[attr].r)),
                                    upto255(round(from[attr].g + pos * ms * diff[attr].g)),
                                    upto255(round(from[attr].b + pos * ms * diff[attr].b))
                                ].join(",") + ")";
                                break;
                            case "path":
                                now = [];
                                for (var i = 0, ii = from[attr].length; i < ii; i++) {
                                    now[i] = [from[attr][i][0]];
                                    for (var j = 1, jj = from[attr][i].length; j < jj; j++) {
                                        now[i][j] = +from[attr][i][j] + pos * ms * diff[attr][i][j];
                                    }
                                    now[i] = now[i].join(S);
                                }
                                now = now.join(S);
                                break;
                            case "transform":
                                if (diff[attr].real) {
                                    now = [];
                                    for (i = 0, ii = from[attr].length; i < ii; i++) {
                                        now[i] = [from[attr][i][0]];
                                        for (j = 1, jj = from[attr][i].length; j < jj; j++) {
                                            now[i][j] = from[attr][i][j] + pos * ms * diff[attr][i][j];
                                        }
                                    }
                                } else {
                                    var get = function (i) {
                                        return +from[attr][i] + pos * ms * diff[attr][i];
                                    };
                                    // now = [["r", get(2), 0, 0], ["t", get(3), get(4)], ["s", get(0), get(1), 0, 0]];
                                    now = [["m", get(0), get(1), get(2), get(3), get(4), get(5)]];
                                }
                                break;
                            case "csv":
                                if (attr == "clip-rect") {
                                    now = [];
                                    i = 4;
                                    while (i--) {
                                        now[i] = +from[attr][i] + pos * ms * diff[attr][i];
                                    }
                                }
                                break;
                            default:
                                var from2 = [][concat](from[attr]);
                                now = [];
                                i = that.paper.customAttributes[attr].length;
                                while (i--) {
                                    now[i] = +from2[i] + pos * ms * diff[attr][i];
                                }
                                break;
                        }
                        set[attr] = now;
                    }
                    that.attr(set);
                    (function (id, that, anim) {
                        setTimeout(function () {
                            eve("raphael.anim.frame." + id, that, anim);
                        });
                    })(that.id, that, e.anim);
                } else {
                    (function(f, el, a) {
                        setTimeout(function() {
                            eve("raphael.anim.frame." + el.id, el, a);
                            eve("raphael.anim.finish." + el.id, el, a);
                            R.is(f, "function") && f.call(el);
                        });
                    })(e.callback, that, e.anim);
                    that.attr(to);
                    animationElements.splice(l--, 1);
                    if (e.repeat > 1 && !e.next) {
                        for (key in to) if (to[has](key)) {
                            init[key] = e.totalOrigin[key];
                        }
                        e.el.attr(init);
                        runAnimation(e.anim, e.el, e.anim.percents[0], null, e.totalOrigin, e.repeat - 1);
                    }
                    if (e.next && !e.stop) {
                        runAnimation(e.anim, e.el, e.next, null, e.totalOrigin, e.repeat);
                    }
                }
            }
            animationElements.length && requestAnimFrame(animation);
        },
        upto255 = function (color) {
            return color > 255 ? 255 : color < 0 ? 0 : color;
        };
    /*\
     * Element.animateWith
     [ method ]
     **
     * Acts similar to @Element.animate, but ensure that given animation runs in sync with another given element.
     **
     > Parameters
     **
     - el (object) element to sync with
     - anim (object) animation to sync with
     - params (object) #optional final attributes for the element, see also @Element.attr
     - ms (number) #optional number of milliseconds for animation to run
     - easing (string) #optional easing type. Accept on of @Raphael.easing_formulas or CSS format: `cubic&#x2010;bezier(XX,&#160;XX,&#160;XX,&#160;XX)`
     - callback (function) #optional callback function. Will be called at the end of animation.
     * or
     - element (object) element to sync with
     - anim (object) animation to sync with
     - animation (object) #optional animation object, see @Raphael.animation
     **
     = (object) original element
    \*/
    elproto.animateWith = function (el, anim, params, ms, easing, callback) {
        var element = this;
        if (element.removed) {
            callback && callback.call(element);
            return element;
        }
        var a = params instanceof Animation ? params : R.animation(params, ms, easing, callback),
            x, y;
        runAnimation(a, element, a.percents[0], null, element.attr());
        for (var i = 0, ii = animationElements.length; i < ii; i++) {
            if (animationElements[i].anim == anim && animationElements[i].el == el) {
                animationElements[ii - 1].start = animationElements[i].start;
                break;
            }
        }
        return element;
        //
        //
        // var a = params ? R.animation(params, ms, easing, callback) : anim,
        //     status = element.status(anim);
        // return this.animate(a).status(a, status * anim.ms / a.ms);
    };
    function CubicBezierAtTime(t, p1x, p1y, p2x, p2y, duration) {
        var cx = 3 * p1x,
            bx = 3 * (p2x - p1x) - cx,
            ax = 1 - cx - bx,
            cy = 3 * p1y,
            by = 3 * (p2y - p1y) - cy,
            ay = 1 - cy - by;
        function sampleCurveX(t) {
            return ((ax * t + bx) * t + cx) * t;
        }
        function solve(x, epsilon) {
            var t = solveCurveX(x, epsilon);
            return ((ay * t + by) * t + cy) * t;
        }
        function solveCurveX(x, epsilon) {
            var t0, t1, t2, x2, d2, i;
            for(t2 = x, i = 0; i < 8; i++) {
                x2 = sampleCurveX(t2) - x;
                if (abs(x2) < epsilon) {
                    return t2;
                }
                d2 = (3 * ax * t2 + 2 * bx) * t2 + cx;
                if (abs(d2) < 1e-6) {
                    break;
                }
                t2 = t2 - x2 / d2;
            }
            t0 = 0;
            t1 = 1;
            t2 = x;
            if (t2 < t0) {
                return t0;
            }
            if (t2 > t1) {
                return t1;
            }
            while (t0 < t1) {
                x2 = sampleCurveX(t2);
                if (abs(x2 - x) < epsilon) {
                    return t2;
                }
                if (x > x2) {
                    t0 = t2;
                } else {
                    t1 = t2;
                }
                t2 = (t1 - t0) / 2 + t0;
            }
            return t2;
        }
        return solve(t, 1 / (200 * duration));
    }
    elproto.onAnimation = function (f) {
        f ? eve.on("raphael.anim.frame." + this.id, f) : eve.unbind("raphael.anim.frame." + this.id);
        return this;
    };
    function Animation(anim, ms) {
        var percents = [],
            newAnim = {};
        this.ms = ms;
        this.times = 1;
        if (anim) {
            for (var attr in anim) if (anim[has](attr)) {
                newAnim[toFloat(attr)] = anim[attr];
                percents.push(toFloat(attr));
            }
            percents.sort(sortByNumber);
        }
        this.anim = newAnim;
        this.top = percents[percents.length - 1];
        this.percents = percents;
    }
    /*\
     * Animation.delay
     [ method ]
     **
     * Creates a copy of existing animation object with given delay.
     **
     > Parameters
     **
     - delay (number) number of ms to pass between animation start and actual animation
     **
     = (object) new altered Animation object
     | var anim = Raphael.animation({cx: 10, cy: 20}, 2e3);
     | circle1.animate(anim); // run the given animation immediately
     | circle2.animate(anim.delay(500)); // run the given animation after 500 ms
    \*/
    Animation.prototype.delay = function (delay) {
        var a = new Animation(this.anim, this.ms);
        a.times = this.times;
        a.del = +delay || 0;
        return a;
    };
    /*\
     * Animation.repeat
     [ method ]
     **
     * Creates a copy of existing animation object with given repetition.
     **
     > Parameters
     **
     - repeat (number) number iterations of animation. For infinite animation pass `Infinity`
     **
     = (object) new altered Animation object
    \*/
    Animation.prototype.repeat = function (times) {
        var a = new Animation(this.anim, this.ms);
        a.del = this.del;
        a.times = math.floor(mmax(times, 0)) || 1;
        return a;
    };
    function runAnimation(anim, element, percent, status, totalOrigin, times) {
        percent = toFloat(percent);
        var params,
            isInAnim,
            isInAnimSet,
            percents = [],
            next,
            prev,
            timestamp,
            ms = anim.ms,
            from = {},
            to = {},
            diff = {};
        if (status) {
            for (i = 0, ii = animationElements.length; i < ii; i++) {
                var e = animationElements[i];
                if (e.el.id == element.id && e.anim == anim) {
                    if (e.percent != percent) {
                        animationElements.splice(i, 1);
                        isInAnimSet = 1;
                    } else {
                        isInAnim = e;
                    }
                    element.attr(e.totalOrigin);
                    break;
                }
            }
        } else {
            status = +to; // NaN
        }
        for (var i = 0, ii = anim.percents.length; i < ii; i++) {
            if (anim.percents[i] == percent || anim.percents[i] > status * anim.top) {
                percent = anim.percents[i];
                prev = anim.percents[i - 1] || 0;
                ms = ms / anim.top * (percent - prev);
                next = anim.percents[i + 1];
                params = anim.anim[percent];
                break;
            } else if (status) {
                element.attr(anim.anim[anim.percents[i]]);
            }
        }
        if (!params) {
            return;
        }
        if (!isInAnim) {
            for (var attr in params) if (params[has](attr)) {
                if (availableAnimAttrs[has](attr) || element.paper.customAttributes[has](attr)) {
                    from[attr] = element.attr(attr);
                    (from[attr] == null) && (from[attr] = availableAttrs[attr]);
                    to[attr] = params[attr];
                    switch (availableAnimAttrs[attr]) {
                        case nu:
                            diff[attr] = (to[attr] - from[attr]) / ms;
                            break;
                        case "colour":
                            from[attr] = R.getRGB(from[attr]);
                            var toColour = R.getRGB(to[attr]);
                            diff[attr] = {
                                r: (toColour.r - from[attr].r) / ms,
                                g: (toColour.g - from[attr].g) / ms,
                                b: (toColour.b - from[attr].b) / ms
                            };
                            break;
                        case "path":
                            var pathes = path2curve(from[attr], to[attr]),
                                toPath = pathes[1];
                            from[attr] = pathes[0];
                            diff[attr] = [];
                            for (i = 0, ii = from[attr].length; i < ii; i++) {
                                diff[attr][i] = [0];
                                for (var j = 1, jj = from[attr][i].length; j < jj; j++) {
                                    diff[attr][i][j] = (toPath[i][j] - from[attr][i][j]) / ms;
                                }
                            }
                            break;
                        case "transform":
                            var _ = element._,
                                eq = equaliseTransform(_[attr], to[attr]);
                            if (eq) {
                                from[attr] = eq.from;
                                to[attr] = eq.to;
                                diff[attr] = [];
                                diff[attr].real = true;
                                for (i = 0, ii = from[attr].length; i < ii; i++) {
                                    diff[attr][i] = [from[attr][i][0]];
                                    for (j = 1, jj = from[attr][i].length; j < jj; j++) {
                                        diff[attr][i][j] = (to[attr][i][j] - from[attr][i][j]) / ms;
                                    }
                                }
                            } else {
                                var m = (element.matrix || new Matrix),
                                    to2 = {
                                        _: {transform: _.transform},
                                        getBBox: function () {
                                            return element.getBBox(1);
                                        }
                                    };
                                from[attr] = [
                                    m.a,
                                    m.b,
                                    m.c,
                                    m.d,
                                    m.e,
                                    m.f
                                ];
                                extractTransform(to2, to[attr]);
                                to[attr] = to2._.transform;
                                diff[attr] = [
                                    (to2.matrix.a - m.a) / ms,
                                    (to2.matrix.b - m.b) / ms,
                                    (to2.matrix.c - m.c) / ms,
                                    (to2.matrix.d - m.d) / ms,
                                    (to2.matrix.e - m.e) / ms,
                                    (to2.matrix.f - m.f) / ms
                                ];
                                // from[attr] = [_.sx, _.sy, _.deg, _.dx, _.dy];
                                // var to2 = {_:{}, getBBox: function () { return element.getBBox(); }};
                                // extractTransform(to2, to[attr]);
                                // diff[attr] = [
                                //     (to2._.sx - _.sx) / ms,
                                //     (to2._.sy - _.sy) / ms,
                                //     (to2._.deg - _.deg) / ms,
                                //     (to2._.dx - _.dx) / ms,
                                //     (to2._.dy - _.dy) / ms
                                // ];
                            }
                            break;
                        case "csv":
                            var values = Str(params[attr])[split](separator),
                                from2 = Str(from[attr])[split](separator);
                            if (attr == "clip-rect") {
                                from[attr] = from2;
                                diff[attr] = [];
                                i = from2.length;
                                while (i--) {
                                    diff[attr][i] = (values[i] - from[attr][i]) / ms;
                                }
                            }
                            to[attr] = values;
                            break;
                        default:
                            values = [][concat](params[attr]);
                            from2 = [][concat](from[attr]);
                            diff[attr] = [];
                            i = element.paper.customAttributes[attr].length;
                            while (i--) {
                                diff[attr][i] = ((values[i] || 0) - (from2[i] || 0)) / ms;
                            }
                            break;
                    }
                }
            }
            var easing = params.easing,
                easyeasy = R.easing_formulas[easing];
            if (!easyeasy) {
                easyeasy = Str(easing).match(bezierrg);
                if (easyeasy && easyeasy.length == 5) {
                    var curve = easyeasy;
                    easyeasy = function (t) {
                        return CubicBezierAtTime(t, +curve[1], +curve[2], +curve[3], +curve[4], ms);
                    };
                } else {
                    easyeasy = pipe;
                }
            }
            timestamp = params.start || anim.start || +new Date;
            e = {
                anim: anim,
                percent: percent,
                timestamp: timestamp,
                start: timestamp + (anim.del || 0),
                status: 0,
                initstatus: status || 0,
                stop: false,
                ms: ms,
                easing: easyeasy,
                from: from,
                diff: diff,
                to: to,
                el: element,
                callback: params.callback,
                prev: prev,
                next: next,
                repeat: times || anim.times,
                origin: element.attr(),
                totalOrigin: totalOrigin
            };
            animationElements.push(e);
            if (status && !isInAnim && !isInAnimSet) {
                e.stop = true;
                e.start = new Date - ms * status;
                if (animationElements.length == 1) {
                    return animation();
                }
            }
            if (isInAnimSet) {
                e.start = new Date - e.ms * status;
            }
            animationElements.length == 1 && requestAnimFrame(animation);
        } else {
            isInAnim.initstatus = status;
            isInAnim.start = new Date - isInAnim.ms * status;
        }
        eve("raphael.anim.start." + element.id, element, anim);
    }
    /*\
     * Raphael.animation
     [ method ]
     **
     * Creates an animation object that can be passed to the @Element.animate or @Element.animateWith methods.
     * See also @Animation.delay and @Animation.repeat methods.
     **
     > Parameters
     **
     - params (object) final attributes for the element, see also @Element.attr
     - ms (number) number of milliseconds for animation to run
     - easing (string) #optional easing type. Accept one of @Raphael.easing_formulas or CSS format: `cubic&#x2010;bezier(XX,&#160;XX,&#160;XX,&#160;XX)`
     - callback (function) #optional callback function. Will be called at the end of animation.
     **
     = (object) @Animation
    \*/
    R.animation = function (params, ms, easing, callback) {
        if (params instanceof Animation) {
            return params;
        }
        if (R.is(easing, "function") || !easing) {
            callback = callback || easing || null;
            easing = null;
        }
        params = Object(params);
        ms = +ms || 0;
        var p = {},
            json,
            attr;
        for (attr in params) if (params[has](attr) && toFloat(attr) != attr && toFloat(attr) + "%" != attr) {
            json = true;
            p[attr] = params[attr];
        }
        if (!json) {
            // if percent-like syntax is used and end-of-all animation callback used
            if(callback){
                // find the last one
                var lastKey = 0;
                for(var i in params){
                    var percent = toInt(i);
                    if(params[has](i) && percent > lastKey){
                        lastKey = percent;
                    }
                }
                lastKey += '%';
                // if already defined callback in the last keyframe, skip
                !params[lastKey].callback && (params[lastKey].callback = callback);
            }
          return new Animation(params, ms);
        } else {
            easing && (p.easing = easing);
            callback && (p.callback = callback);
            return new Animation({100: p}, ms);
        }
    };
    /*\
     * Element.animate
     [ method ]
     **
     * Creates and starts animation for given element.
     **
     > Parameters
     **
     - params (object) final attributes for the element, see also @Element.attr
     - ms (number) number of milliseconds for animation to run
     - easing (string) #optional easing type. Accept one of @Raphael.easing_formulas or CSS format: `cubic&#x2010;bezier(XX,&#160;XX,&#160;XX,&#160;XX)`
     - callback (function) #optional callback function. Will be called at the end of animation.
     * or
     - animation (object) animation object, see @Raphael.animation
     **
     = (object) original element
    \*/
    elproto.animate = function (params, ms, easing, callback) {
        var element = this;
        if (element.removed) {
            callback && callback.call(element);
            return element;
        }
        var anim = params instanceof Animation ? params : R.animation(params, ms, easing, callback);
        runAnimation(anim, element, anim.percents[0], null, element.attr());
        return element;
    };
    /*\
     * Element.setTime
     [ method ]
     **
     * Sets the status of animation of the element in milliseconds. Similar to @Element.status method.
     **
     > Parameters
     **
     - anim (object) animation object
     - value (number) number of milliseconds from the beginning of the animation
     **
     = (object) original element if `value` is specified
     * Note, that during animation following events are triggered:
     *
     * On each animation frame event `anim.frame.<id>`, on start `anim.start.<id>` and on end `anim.finish.<id>`.
    \*/
    elproto.setTime = function (anim, value) {
        if (anim && value != null) {
            this.status(anim, mmin(value, anim.ms) / anim.ms);
        }
        return this;
    };
    /*\
     * Element.status
     [ method ]
     **
     * Gets or sets the status of animation of the element.
     **
     > Parameters
     **
     - anim (object) #optional animation object
     - value (number) #optional 0 – 1. If specified, method works like a setter and sets the status of a given animation to the value. This will cause animation to jump to the given position.
     **
     = (number) status
     * or
     = (array) status if `anim` is not specified. Array of objects in format:
     o {
     o     anim: (object) animation object
     o     status: (number) status
     o }
     * or
     = (object) original element if `value` is specified
    \*/
    elproto.status = function (anim, value) {
        var out = [],
            i = 0,
            len,
            e;
        if (value != null) {
            runAnimation(anim, this, -1, mmin(value, 1));
            return this;
        } else {
            len = animationElements.length;
            for (; i < len; i++) {
                e = animationElements[i];
                if (e.el.id == this.id && (!anim || e.anim == anim)) {
                    if (anim) {
                        return e.status;
                    }
                    out.push({
                        anim: e.anim,
                        status: e.status
                    });
                }
            }
            if (anim) {
                return 0;
            }
            return out;
        }
    };
    /*\
     * Element.pause
     [ method ]
     **
     * Stops animation of the element with ability to resume it later on.
     **
     > Parameters
     **
     - anim (object) #optional animation object
     **
     = (object) original element
    \*/
    elproto.pause = function (anim) {
        for (var i = 0; i < animationElements.length; i++) if (animationElements[i].el.id == this.id && (!anim || animationElements[i].anim == anim)) {
            if (eve("raphael.anim.pause." + this.id, this, animationElements[i].anim) !== false) {
                animationElements[i].paused = true;
            }
        }
        return this;
    };
    /*\
     * Element.resume
     [ method ]
     **
     * Resumes animation if it was paused with @Element.pause method.
     **
     > Parameters
     **
     - anim (object) #optional animation object
     **
     = (object) original element
    \*/
    elproto.resume = function (anim) {
        for (var i = 0; i < animationElements.length; i++) if (animationElements[i].el.id == this.id && (!anim || animationElements[i].anim == anim)) {
            var e = animationElements[i];
            if (eve("raphael.anim.resume." + this.id, this, e.anim) !== false) {
                delete e.paused;
                this.status(e.anim, e.status);
            }
        }
        return this;
    };
    /*\
     * Element.stop
     [ method ]
     **
     * Stops animation of the element.
     **
     > Parameters
     **
     - anim (object) #optional animation object
     **
     = (object) original element
    \*/
    elproto.stop = function (anim) {
        for (var i = 0; i < animationElements.length; i++) if (animationElements[i].el.id == this.id && (!anim || animationElements[i].anim == anim)) {
            if (eve("raphael.anim.stop." + this.id, this, animationElements[i].anim) !== false) {
                animationElements.splice(i--, 1);
            }
        }
        return this;
    };
    function stopAnimation(paper) {
        for (var i = 0; i < animationElements.length; i++) if (animationElements[i].el.paper == paper) {
            animationElements.splice(i--, 1);
        }
    }
    eve.on("raphael.remove", stopAnimation);
    eve.on("raphael.clear", stopAnimation);
    elproto.toString = function () {
        return "Rapha\xebl\u2019s object";
    };

    // Set
    var Set = function (items) {
        this.items = [];
        this.length = 0;
        this.type = "set";
        if (items) {
            for (var i = 0, ii = items.length; i < ii; i++) {
                if (items[i] && (items[i].constructor == elproto.constructor || items[i].constructor == Set)) {
                    this[this.items.length] = this.items[this.items.length] = items[i];
                    this.length++;
                }
            }
        }
    },
    setproto = Set.prototype;
    /*\
     * Set.push
     [ method ]
     **
     * Adds each argument to the current set.
     = (object) original element
    \*/
    setproto.push = function () {
        var item,
            len;
        for (var i = 0, ii = arguments.length; i < ii; i++) {
            item = arguments[i];
            if (item && (item.constructor == elproto.constructor || item.constructor == Set)) {
                len = this.items.length;
                this[len] = this.items[len] = item;
                this.length++;
            }
        }
        return this;
    };
    /*\
     * Set.pop
     [ method ]
     **
     * Removes last element and returns it.
     = (object) element
    \*/
    setproto.pop = function () {
        this.length && delete this[this.length--];
        return this.items.pop();
    };
    /*\
     * Set.forEach
     [ method ]
     **
     * Executes given function for each element in the set.
     *
     * If function returns `false` it will stop loop running.
     **
     > Parameters
     **
     - callback (function) function to run
     - thisArg (object) context object for the callback
     = (object) Set object
    \*/
    setproto.forEach = function (callback, thisArg) {
        for (var i = 0, ii = this.items.length; i < ii; i++) {
            if (callback.call(thisArg, this.items[i], i) === false) {
                return this;
            }
        }
        return this;
    };
    for (var method in elproto) if (elproto[has](method)) {
        setproto[method] = (function (methodname) {
            return function () {
                var arg = arguments;
                return this.forEach(function (el) {
                    el[methodname][apply](el, arg);
                });
            };
        })(method);
    }
    setproto.attr = function (name, value) {
        if (name && R.is(name, array) && R.is(name[0], "object")) {
            for (var j = 0, jj = name.length; j < jj; j++) {
                this.items[j].attr(name[j]);
            }
        } else {
            for (var i = 0, ii = this.items.length; i < ii; i++) {
                this.items[i].attr(name, value);
            }
        }
        return this;
    };
    /*\
     * Set.clear
     [ method ]
     **
     * Removes all elements from the set
    \*/
    setproto.clear = function () {
        while (this.length) {
            this.pop();
        }
    };
    /*\
     * Set.splice
     [ method ]
     **
     * Removes given element from the set
     **
     > Parameters
     **
     - index (number) position of the deletion
     - count (number) number of element to remove
     - insertion… (object) #optional elements to insert
     = (object) set elements that were deleted
    \*/
    setproto.splice = function (index, count, insertion) {
        index = index < 0 ? mmax(this.length + index, 0) : index;
        count = mmax(0, mmin(this.length - index, count));
        var tail = [],
            todel = [],
            args = [],
            i;
        for (i = 2; i < arguments.length; i++) {
            args.push(arguments[i]);
        }
        for (i = 0; i < count; i++) {
            todel.push(this[index + i]);
        }
        for (; i < this.length - index; i++) {
            tail.push(this[index + i]);
        }
        var arglen = args.length;
        for (i = 0; i < arglen + tail.length; i++) {
            this.items[index + i] = this[index + i] = i < arglen ? args[i] : tail[i - arglen];
        }
        i = this.items.length = this.length -= count - arglen;
        while (this[i]) {
            delete this[i++];
        }
        return new Set(todel);
    };
    /*\
     * Set.exclude
     [ method ]
     **
     * Removes given element from the set
     **
     > Parameters
     **
     - element (object) element to remove
     = (boolean) `true` if object was found & removed from the set
    \*/
    setproto.exclude = function (el) {
        for (var i = 0, ii = this.length; i < ii; i++) if (this[i] == el) {
            this.splice(i, 1);
            return true;
        }
    };
    setproto.animate = function (params, ms, easing, callback) {
        (R.is(easing, "function") || !easing) && (callback = easing || null);
        var len = this.items.length,
            i = len,
            item,
            set = this,
            collector;
        if (!len) {
            return this;
        }
        callback && (collector = function () {
            !--len && callback.call(set);
        });
        easing = R.is(easing, string) ? easing : collector;
        var anim = R.animation(params, ms, easing, collector);
        item = this.items[--i].animate(anim);
        while (i--) {
            this.items[i] && !this.items[i].removed && this.items[i].animateWith(item, anim, anim);
            (this.items[i] && !this.items[i].removed) || len--;
        }
        return this;
    };
    setproto.insertAfter = function (el) {
        var i = this.items.length;
        while (i--) {
            this.items[i].insertAfter(el);
        }
        return this;
    };
    setproto.getBBox = function () {
        var x = [],
            y = [],
            x2 = [],
            y2 = [];
        for (var i = this.items.length; i--;) if (!this.items[i].removed) {
            var box = this.items[i].getBBox();
            x.push(box.x);
            y.push(box.y);
            x2.push(box.x + box.width);
            y2.push(box.y + box.height);
        }
        x = mmin[apply](0, x);
        y = mmin[apply](0, y);
        x2 = mmax[apply](0, x2);
        y2 = mmax[apply](0, y2);
        return {
            x: x,
            y: y,
            x2: x2,
            y2: y2,
            width: x2 - x,
            height: y2 - y
        };
    };
    setproto.clone = function (s) {
        s = this.paper.set();
        for (var i = 0, ii = this.items.length; i < ii; i++) {
            s.push(this.items[i].clone());
        }
        return s;
    };
    setproto.toString = function () {
        return "Rapha\xebl\u2018s set";
    };

    setproto.glow = function(glowConfig) {
        var ret = this.paper.set();
        this.forEach(function(shape, index){
            var g = shape.glow(glowConfig);
            if(g != null){
                g.forEach(function(shape2, index2){
                    ret.push(shape2);
                });
            }
        });
        return ret;
    };


    /*\
     * Set.isPointInside
     [ method ]
     **
     * Determine if given point is inside this set’s elements
     **
     > Parameters
     **
     - x (number) x coordinate of the point
     - y (number) y coordinate of the point
     = (boolean) `true` if point is inside any of the set's elements
     \*/
    setproto.isPointInside = function (x, y) {
        var isPointInside = false;
        this.forEach(function (el) {
            if (el.isPointInside(x, y)) {
                isPointInside = true;
                return false; // stop loop
            }
        });
        return isPointInside;
    };

    /*\
     * Raphael.registerFont
     [ method ]
     **
     * Adds given font to the registered set of fonts for Raphaël. Should be used as an internal call from within Cufón’s font file.
     * Returns original parameter, so it could be used with chaining.
     # <a href="http://wiki.github.com/sorccu/cufon/about">More about Cufón and how to convert your font form TTF, OTF, etc to JavaScript file.</a>
     **
     > Parameters
     **
     - font (object) the font to register
     = (object) the font you passed in
     > Usage
     | Cufon.registerFont(Raphael.registerFont({…}));
    \*/
    R.registerFont = function (font) {
        if (!font.face) {
            return font;
        }
        this.fonts = this.fonts || {};
        var fontcopy = {
                w: font.w,
                face: {},
                glyphs: {}
            },
            family = font.face["font-family"];
        for (var prop in font.face) if (font.face[has](prop)) {
            fontcopy.face[prop] = font.face[prop];
        }
        if (this.fonts[family]) {
            this.fonts[family].push(fontcopy);
        } else {
            this.fonts[family] = [fontcopy];
        }
        if (!font.svg) {
            fontcopy.face["units-per-em"] = toInt(font.face["units-per-em"], 10);
            for (var glyph in font.glyphs) if (font.glyphs[has](glyph)) {
                var path = font.glyphs[glyph];
                fontcopy.glyphs[glyph] = {
                    w: path.w,
                    k: {},
                    d: path.d && "M" + path.d.replace(/[mlcxtrv]/g, function (command) {
                            return {l: "L", c: "C", x: "z", t: "m", r: "l", v: "c"}[command] || "M";
                        }) + "z"
                };
                if (path.k) {
                    for (var k in path.k) if (path[has](k)) {
                        fontcopy.glyphs[glyph].k[k] = path.k[k];
                    }
                }
            }
        }
        return font;
    };
    /*\
     * Paper.getFont
     [ method ]
     **
     * Finds font object in the registered fonts by given parameters. You could specify only one word from the font name, like “Myriad” for “Myriad Pro”.
     **
     > Parameters
     **
     - family (string) font family name or any word from it
     - weight (string) #optional font weight
     - style (string) #optional font style
     - stretch (string) #optional font stretch
     = (object) the font object
     > Usage
     | paper.print(100, 100, "Test string", paper.getFont("Times", 800), 30);
    \*/
    paperproto.getFont = function (family, weight, style, stretch) {
        stretch = stretch || "normal";
        style = style || "normal";
        weight = +weight || {normal: 400, bold: 700, lighter: 300, bolder: 800}[weight] || 400;
        if (!R.fonts) {
            return;
        }
        var font = R.fonts[family];
        if (!font) {
            var name = new RegExp("(^|\\s)" + family.replace(/[^\w\d\s+!~.:_-]/g, E) + "(\\s|$)", "i");
            for (var fontName in R.fonts) if (R.fonts[has](fontName)) {
                if (name.test(fontName)) {
                    font = R.fonts[fontName];
                    break;
                }
            }
        }
        var thefont;
        if (font) {
            for (var i = 0, ii = font.length; i < ii; i++) {
                thefont = font[i];
                if (thefont.face["font-weight"] == weight && (thefont.face["font-style"] == style || !thefont.face["font-style"]) && thefont.face["font-stretch"] == stretch) {
                    break;
                }
            }
        }
        return thefont;
    };
    /*\
     * Paper.print
     [ method ]
     **
     * Creates path that represent given text written using given font at given position with given size.
     * Result of the method is path element that contains whole text as a separate path.
     **
     > Parameters
     **
     - x (number) x position of the text
     - y (number) y position of the text
     - string (string) text to print
     - font (object) font object, see @Paper.getFont
     - size (number) #optional size of the font, default is `16`
     - origin (string) #optional could be `"baseline"` or `"middle"`, default is `"middle"`
     - letter_spacing (number) #optional number in range `-1..1`, default is `0`
     - line_spacing (number) #optional number in range `1..3`, default is `1`
     = (object) resulting path element, which consist of all letters
     > Usage
     | var txt = r.print(10, 50, "print", r.getFont("Museo"), 30).attr({fill: "#fff"});
    \*/
    paperproto.print = function (x, y, string, font, size, origin, letter_spacing, line_spacing) {
        origin = origin || "middle"; // baseline|middle
        letter_spacing = mmax(mmin(letter_spacing || 0, 1), -1);
        line_spacing = mmax(mmin(line_spacing || 1, 3), 1);
        var letters = Str(string)[split](E),
            shift = 0,
            notfirst = 0,
            path = E,
            scale;
        R.is(font, "string") && (font = this.getFont(font));
        if (font) {
            scale = (size || 16) / font.face["units-per-em"];
            var bb = font.face.bbox[split](separator),
                top = +bb[0],
                lineHeight = bb[3] - bb[1],
                shifty = 0,
                height = +bb[1] + (origin == "baseline" ? lineHeight + (+font.face.descent) : lineHeight / 2);
            for (var i = 0, ii = letters.length; i < ii; i++) {
                if (letters[i] == "\n") {
                    shift = 0;
                    curr = 0;
                    notfirst = 0;
                    shifty += lineHeight * line_spacing;
                } else {
                    var prev = notfirst && font.glyphs[letters[i - 1]] || {},
                        curr = font.glyphs[letters[i]];
                    shift += notfirst ? (prev.w || font.w) + (prev.k && prev.k[letters[i]] || 0) + (font.w * letter_spacing) : 0;
                    notfirst = 1;
                }
                if (curr && curr.d) {
                    path += R.transformPath(curr.d, ["t", shift * scale, shifty * scale, "s", scale, scale, top, height, "t", (x - top) / scale, (y - height) / scale]);
                }
            }
        }
        return this.path(path).attr({
            fill: "#000",
            stroke: "none"
        });
    };

    /*\
     * Paper.add
     [ method ]
     **
     * Imports elements in JSON array in format `{type: type, <attributes>}`
     **
     > Parameters
     **
     - json (array)
     = (object) resulting set of imported elements
     > Usage
     | paper.add([
     |     {
     |         type: "circle",
     |         cx: 10,
     |         cy: 10,
     |         r: 5
     |     },
     |     {
     |         type: "rect",
     |         x: 10,
     |         y: 10,
     |         width: 10,
     |         height: 10,
     |         fill: "#fc0"
     |     }
     | ]);
    \*/
    paperproto.add = function (json) {
        if (R.is(json, "array")) {
            var res = this.set(),
                i = 0,
                ii = json.length,
                j;
            for (; i < ii; i++) {
                j = json[i] || {};
                elements[has](j.type) && res.push(this[j.type]().attr(j));
            }
        }
        return res;
    };

    /*\
     * Raphael.format
     [ method ]
     **
     * Simple format function. Replaces construction of type “`{<number>}`” to the corresponding argument.
     **
     > Parameters
     **
     - token (string) string to format
     - … (string) rest of arguments will be treated as parameters for replacement
     = (string) formated string
     > Usage
     | var x = 10,
     |     y = 20,
     |     width = 40,
     |     height = 50;
     | // this will draw a rectangular shape equivalent to "M10,20h40v50h-40z"
     | paper.path(Raphael.format("M{0},{1}h{2}v{3}h{4}z", x, y, width, height, -width));
    \*/
    R.format = function (token, params) {
        var args = R.is(params, array) ? [0][concat](params) : arguments;
        token && R.is(token, string) && args.length - 1 && (token = token.replace(formatrg, function (str, i) {
            return args[++i] == null ? E : args[i];
        }));
        return token || E;
    };
    /*\
     * Raphael.fullfill
     [ method ]
     **
     * A little bit more advanced format function than @Raphael.format. Replaces construction of type “`{<name>}`” to the corresponding argument.
     **
     > Parameters
     **
     - token (string) string to format
     - json (object) object which properties will be used as a replacement
     = (string) formated string
     > Usage
     | // this will draw a rectangular shape equivalent to "M10,20h40v50h-40z"
     | paper.path(Raphael.fullfill("M{x},{y}h{dim.width}v{dim.height}h{dim['negative width']}z", {
     |     x: 10,
     |     y: 20,
     |     dim: {
     |         width: 40,
     |         height: 50,
     |         "negative width": -40
     |     }
     | }));
    \*/
    R.fullfill = (function () {
        var tokenRegex = /\{([^\}]+)\}/g,
            objNotationRegex = /(?:(?:^|\.)(.+?)(?=\[|\.|$|\()|\[('|")(.+?)\2\])(\(\))?/g, // matches .xxxxx or ["xxxxx"] to run over object properties
            replacer = function (all, key, obj) {
                var res = obj;
                key.replace(objNotationRegex, function (all, name, quote, quotedName, isFunc) {
                    name = name || quotedName;
                    if (res) {
                        if (name in res) {
                            res = res[name];
                        }
                        typeof res == "function" && isFunc && (res = res());
                    }
                });
                res = (res == null || res == obj ? all : res) + "";
                return res;
            };
        return function (str, obj) {
            return String(str).replace(tokenRegex, function (all, key) {
                return replacer(all, key, obj);
            });
        };
    })();
    /*\
     * Raphael.ninja
     [ method ]
     **
     * If you want to leave no trace of Raphaël (Well, Raphaël creates only one global variable `Raphael`, but anyway.) You can use `ninja` method.
     * Beware, that in this case plugins could stop working, because they are depending on global variable existance.
     **
     = (object) Raphael object
     > Usage
     | (function (local_raphael) {
     |     var paper = local_raphael(10, 10, 320, 200);
     |     …
     | })(Raphael.ninja());
    \*/
    R.ninja = function () {
        oldRaphael.was ? (g.win.Raphael = oldRaphael.is) : delete Raphael;
        return R;
    };
    /*\
     * Raphael.st
     [ property (object) ]
     **
     * You can add your own method to elements and sets. It is wise to add a set method for each element method
     * you added, so you will be able to call the same method on sets too.
     **
     * See also @Raphael.el.
     > Usage
     | Raphael.el.red = function () {
     |     this.attr({fill: "#f00"});
     | };
     | Raphael.st.red = function () {
     |     this.forEach(function (el) {
     |         el.red();
     |     });
     | };
     | // then use it
     | paper.set(paper.circle(100, 100, 20), paper.circle(110, 100, 20)).red();
    \*/
    R.st = setproto;

    eve.on("raphael.DOMload", function () {
        loaded = true;
    });

    // Firefox <3.6 fix: http://webreflection.blogspot.com/2009/11/195-chars-to-help-lazy-loading.html
    (function (doc, loaded, f) {
        if (doc.readyState == null && doc.addEventListener){
            doc.addEventListener(loaded, f = function () {
                doc.removeEventListener(loaded, f, false);
                doc.readyState = "complete";
            }, false);
            doc.readyState = "loading";
        }
        function isLoaded() {
            (/in/).test(doc.readyState) ? setTimeout(isLoaded, 9) : R.eve("raphael.DOMload");
        }
        isLoaded();
    })(document, "DOMContentLoaded");

// ┌─────────────────────────────────────────────────────────────────────┐ \\
// │ Raphaël - JavaScript Vector Library                                 │ \\
// ├─────────────────────────────────────────────────────────────────────┤ \\
// │ SVG Module                                                          │ \\
// ├─────────────────────────────────────────────────────────────────────┤ \\
// │ Copyright (c) 2008-2011 Dmitry Baranovskiy (http://raphaeljs.com)   │ \\
// │ Copyright (c) 2008-2011 Sencha Labs (http://sencha.com)             │ \\
// │ Licensed under the MIT (http://raphaeljs.com/license.html) license. │ \\
// └─────────────────────────────────────────────────────────────────────┘ \\

(function(){
    if (!R.svg) {
        return;
    }
    var has = "hasOwnProperty",
        Str = String,
        toFloat = parseFloat,
        toInt = parseInt,
        math = Math,
        mmax = math.max,
        abs = math.abs,
        pow = math.pow,
        separator = /[, ]+/,
        eve = R.eve,
        E = "",
        S = " ";
    var xlink = "http://www.w3.org/1999/xlink",
        markers = {
            block: "M5,0 0,2.5 5,5z",
            classic: "M5,0 0,2.5 5,5 3.5,3 3.5,2z",
            diamond: "M2.5,0 5,2.5 2.5,5 0,2.5z",
            open: "M6,1 1,3.5 6,6",
            oval: "M2.5,0A2.5,2.5,0,0,1,2.5,5 2.5,2.5,0,0,1,2.5,0z"
        },
        markerCounter = {};
    R.toString = function () {
        return  "Your browser supports SVG.\nYou are running Rapha\xebl " + this.version;
    };
    var $ = function (el, attr) {
        if (attr) {
            if (typeof el == "string") {
                el = $(el);
            }
            for (var key in attr) if (attr[has](key)) {
                if (key.substring(0, 6) == "xlink:") {
                    el.setAttributeNS(xlink, key.substring(6), Str(attr[key]));
                } else {
                    el.setAttribute(key, Str(attr[key]));
                }
            }
        } else {
            el = R._g.doc.createElementNS("http://www.w3.org/2000/svg", el);
            el.style && (el.style.webkitTapHighlightColor = "rgba(0,0,0,0)");
        }
        return el;
    },
    addGradientFill = function (element, gradient) {
        var type = "linear",
            id = element.id + gradient,
            fx = .5, fy = .5,
            o = element.node,
            SVG = element.paper,
            s = o.style,
            el = R._g.doc.getElementById(id);
        if (!el) {
            gradient = Str(gradient).replace(R._radial_gradient, function (all, _fx, _fy) {
                type = "radial";
                if (_fx && _fy) {
                    fx = toFloat(_fx);
                    fy = toFloat(_fy);
                    var dir = ((fy > .5) * 2 - 1);
                    pow(fx - .5, 2) + pow(fy - .5, 2) > .25 &&
                        (fy = math.sqrt(.25 - pow(fx - .5, 2)) * dir + .5) &&
                        fy != .5 &&
                        (fy = fy.toFixed(5) - 1e-5 * dir);
                }
                return E;
            });
            gradient = gradient.split(/\s*\-\s*/);
            if (type == "linear") {
                var angle = gradient.shift();
                angle = -toFloat(angle);
                if (isNaN(angle)) {
                    return null;
                }
                var vector = [0, 0, math.cos(R.rad(angle)), math.sin(R.rad(angle))],
                    max = 1 / (mmax(abs(vector[2]), abs(vector[3])) || 1);
                vector[2] *= max;
                vector[3] *= max;
                if (vector[2] < 0) {
                    vector[0] = -vector[2];
                    vector[2] = 0;
                }
                if (vector[3] < 0) {
                    vector[1] = -vector[3];
                    vector[3] = 0;
                }
            }
            var dots = R._parseDots(gradient);
            if (!dots) {
                return null;
            }
            id = id.replace(/[\(\)\s,\xb0#]/g, "_");

            if (element.gradient && id != element.gradient.id) {
                SVG.defs.removeChild(element.gradient);
                delete element.gradient;
            }

            if (!element.gradient) {
                el = $(type + "Gradient", {id: id});
                element.gradient = el;
                $(el, type == "radial" ? {
                    fx: fx,
                    fy: fy
                } : {
                    x1: vector[0],
                    y1: vector[1],
                    x2: vector[2],
                    y2: vector[3],
                    gradientTransform: element.matrix.invert()
                });
                SVG.defs.appendChild(el);
                for (var i = 0, ii = dots.length; i < ii; i++) {
                    el.appendChild($("stop", {
                        offset: dots[i].offset ? dots[i].offset : i ? "100%" : "0%",
                        "stop-color": dots[i].color || "#fff"
                    }));
                }
            }
        }
        $(o, {
            // [CC] Fixed differently in Raphael 2.2.0 (https://github.com/DmitryBaranovskiy/raphael/blob/master/history.md)
            fill: "url('" /* [CC] + document.location [/CC] */ + "#" + id + "')",
            opacity: 1,
            "fill-opacity": 1
        });
        s.fill = E;
        s.opacity = 1;
        s.fillOpacity = 1;
        return 1;
    },
    updatePosition = function (o) {
        var bbox = o.getBBox(1);
        $(o.pattern, {patternTransform: o.matrix.invert() + " translate(" + bbox.x + "," + bbox.y + ")"});
    },
    addArrow = function (o, value, isEnd) {
        if (o.type == "path") {
            var values = Str(value).toLowerCase().split("-"),
                p = o.paper,
                se = isEnd ? "end" : "start",
                node = o.node,
                attrs = o.attrs,
                stroke = attrs["stroke-width"],
                i = values.length,
                type = "classic",
                from,
                to,
                dx,
                refX,
                attr,
                w = 3,
                h = 3,
                t = 5;
            while (i--) {
                switch (values[i]) {
                    case "block":
                    case "classic":
                    case "oval":
                    case "diamond":
                    case "open":
                    case "none":
                        type = values[i];
                        break;
                    case "wide": h = 5; break;
                    case "narrow": h = 2; break;
                    case "long": w = 5; break;
                    case "short": w = 2; break;
                }
            }
            if (type == "open") {
                w += 2;
                h += 2;
                t += 2;
                dx = 1;
                refX = isEnd ? 4 : 1;
                attr = {
                    fill: "none",
                    stroke: attrs.stroke
                };
            } else {
                refX = dx = w / 2;
                attr = {
                    fill: attrs.stroke,
                    stroke: "none"
                };
            }
            if (o._.arrows) {
                if (isEnd) {
                    o._.arrows.endPath && markerCounter[o._.arrows.endPath]--;
                    o._.arrows.endMarker && markerCounter[o._.arrows.endMarker]--;
                } else {
                    o._.arrows.startPath && markerCounter[o._.arrows.startPath]--;
                    o._.arrows.startMarker && markerCounter[o._.arrows.startMarker]--;
                }
            } else {
                o._.arrows = {};
            }
            if (type != "none") {
                var pathId = "raphael-marker-" + type,
                    markerId = "raphael-marker-" + se + type + w + h + "-obj" + o.id;
                if (!R._g.doc.getElementById(pathId)) {
                    p.defs.appendChild($($("path"), {
                        "stroke-linecap": "round",
                        d: markers[type],
                        id: pathId
                    }));
                    markerCounter[pathId] = 1;
                } else {
                    markerCounter[pathId]++;
                }
                var marker = R._g.doc.getElementById(markerId),
                    use;
                if (!marker) {
                    marker = $($("marker"), {
                        id: markerId,
                        markerHeight: h,
                        markerWidth: w,
                        orient: "auto",
                        refX: refX,
                        refY: h / 2
                    });
                    use = $($("use"), {
                        "xlink:href": "#" + pathId,
                        transform: (isEnd ? "rotate(180 " + w / 2 + " " + h / 2 + ") " : E) + "scale(" + w / t + "," + h / t + ")",
                        "stroke-width": (1 / ((w / t + h / t) / 2)).toFixed(4)
                    });
                    marker.appendChild(use);
                    p.defs.appendChild(marker);
                    markerCounter[markerId] = 1;
                } else {
                    markerCounter[markerId]++;
                    use = marker.getElementsByTagName("use")[0];
                }
                $(use, attr);
                var delta = dx * (type != "diamond" && type != "oval");
                if (isEnd) {
                    from = o._.arrows.startdx * stroke || 0;
                    to = R.getTotalLength(attrs.path) - delta * stroke;
                } else {
                    from = delta * stroke;
                    to = R.getTotalLength(attrs.path) - (o._.arrows.enddx * stroke || 0);
                }
                attr = {};
                attr["marker-" + se] = "url(#" + markerId + ")";
                if (to || from) {
                    attr.d = R.getSubpath(attrs.path, from, to);
                }
                $(node, attr);
                o._.arrows[se + "Path"] = pathId;
                o._.arrows[se + "Marker"] = markerId;
                o._.arrows[se + "dx"] = delta;
                o._.arrows[se + "Type"] = type;
                o._.arrows[se + "String"] = value;
            } else {
                if (isEnd) {
                    from = o._.arrows.startdx * stroke || 0;
                    to = R.getTotalLength(attrs.path) - from;
                } else {
                    from = 0;
                    to = R.getTotalLength(attrs.path) - (o._.arrows.enddx * stroke || 0);
                }
                o._.arrows[se + "Path"] && $(node, {d: R.getSubpath(attrs.path, from, to)});
                delete o._.arrows[se + "Path"];
                delete o._.arrows[se + "Marker"];
                delete o._.arrows[se + "dx"];
                delete o._.arrows[se + "Type"];
                delete o._.arrows[se + "String"];
            }
            for (attr in markerCounter) if (markerCounter[has](attr) && !markerCounter[attr]) {
                var item = R._g.doc.getElementById(attr);
                item && item.parentNode.removeChild(item);
            }
        }
    },
    dasharray = {
        "-": [3, 1],
        ".": [1, 1],
        "-.": [3, 1, 1, 1],
        "-..": [3, 1, 1, 1, 1, 1],
        ". ": [1, 3],
        "- ": [4, 3],
        "--": [8, 3],
        "- .": [4, 3, 1, 3],
        "--.": [8, 3, 1, 3],
        "--..": [8, 3, 1, 3, 1, 3]
    },
    addDashes = function (o, value, params) {
        value = dasharray[Str(value).toLowerCase()];
        if (value) {
            var width = o.attrs["stroke-width"] || "1",
                butt = {round: width, square: width, butt: 0}[o.attrs["stroke-linecap"] || params["stroke-linecap"]] || 0,
                dashes = [],
                i = value.length;
            while (i--) {
                dashes[i] = value[i] * width + ((i % 2) ? 1 : -1) * butt;
            }
            $(o.node, {"stroke-dasharray": dashes.join(",")});
        }
        else {
          $(o.node, {"stroke-dasharray": "none"});
        }
    },
    setFillAndStroke = function (o, params) {
        var node = o.node,
            attrs = o.attrs,
            vis = node.style.visibility;
        node.style.visibility = "hidden";
        for (var att in params) {
            if (params[has](att)) {
                if (!R._availableAttrs[has](att)) {
                    continue;
                }
                var value = params[att];
                attrs[att] = value;
                switch (att) {
                    case "blur":
                        o.blur(value);
                        break;
                    case "title":
                        var title = node.getElementsByTagName("title");

                        // Use the existing <title>.
                        if (title.length && (title = title[0])) {
                          title.firstChild.nodeValue = value;
                        } else {
                          title = $("title");
                          var val = R._g.doc.createTextNode(value);
                          title.appendChild(val);
                          node.appendChild(title);
                        }
                        break;
                    case "href":
                    case "target":
                        var pn = node.parentNode;
                        if (pn.tagName.toLowerCase() != "a") {
                            var hl = $("a");
                            pn.insertBefore(hl, node);
                            hl.appendChild(node);
                            pn = hl;
                          // [KHS 20111006]
                          // The SVG standard way of handling titles/tooltips is to put them in
                          // a <title> child element rather than a title attribute. For IE9
                          // (and perhaps other modern browsers), we must add/update the <title>
                          // element as well as the title attribute.
                          if( att === "title") {
                            var titleText = document.createTextNode(value),
                                titleNode = $("title");
                            titleNode.appendChild( titleText);
                            pn.appendChild( titleNode);
                            didCreateTitleElt = true;
                            // [/KHS 20111006]
                          }
                        }
                        if (att == "target") {
                            pn.setAttributeNS(xlink, "show", value == "blank" ? "new" : value);
                        } else {
                            pn.setAttributeNS(xlink, att, value);
                        }
                        // [KCPT KHS 2011-10-06]
                        // In this path, we update an existing <title> element.
                        if( !didCreateTitleElt && (att === "title")) {
                          for( var child = pn.firstChild; child; child = child.nextSibling) {
                            if( child.tagName === "title") {
                              var oldTextChild = child.firstChild,
                                  newTextChild = document.createTextNode( value);
                              if( oldTextChild)
                                child.replaceChild( newTextChild, oldTextChild);
                              else
                                child.appendChild( newTextChild);
                            }
                          }
                        }
                        // [/KCPT KHS 2011-10-06]
                        break;
                    case "cursor":
                        node.style.cursor = value;
                        break;
                    case "transform":
                        o.transform(value);
                        break;
                    case "arrow-start":
                        addArrow(o, value);
                        break;
                    case "arrow-end":
                        addArrow(o, value, 1);
                        break;
                    case "clip-rect":
                        var rect = Str(value).split(separator);
                        if (rect.length == 4) {
                            o.clip && o.clip.parentNode.parentNode.removeChild(o.clip.parentNode);
                            var el = $("clipPath"),
                                rc = $("rect");
                            el.id = R.createUUID();
                            $(rc, {
                                x: rect[0],
                                y: rect[1],
                                width: rect[2],
                                height: rect[3]
                            });
                            el.appendChild(rc);
                            o.paper.defs.appendChild(el);
                            $(node, {"clip-path": "url(#" + el.id + ")"});
                            o.clip = rc;
                        }
                        if (!value) {
                            var path = node.getAttribute("clip-path");
                            if (path) {
                                var clip = R._g.doc.getElementById(path.replace(/(^url\(#|\)$)/g, E));
                                clip && clip.parentNode.removeChild(clip);
                                $(node, {"clip-path": E});
                                delete o.clip;
                            }
                        }
                    break;
                    case "path":
                        if (o.type == "path") {
                            $(node, {d: value ? attrs.path = R._pathToAbsolute(value) : "M0,0"});
                            o._.dirty = 1;
                            if (o._.arrows) {
                                "startString" in o._.arrows && addArrow(o, o._.arrows.startString);
                                "endString" in o._.arrows && addArrow(o, o._.arrows.endString, 1);
                            }
                        }
                        break;
                    case "width":
                        node.setAttribute(att, value);
                        o._.dirty = 1;
                        if (attrs.fx) {
                            att = "x";
                            value = attrs.x;
                        } else {
                            break;
                        }
                    case "x":
                        if (attrs.fx) {
                            value = -attrs.x - (attrs.width || 0);
                        }
                    case "rx":
                        if (att == "rx" && o.type == "rect") {
                            break;
                        }
                    case "cx":
                        node.setAttribute(att, value);
                        o.pattern && updatePosition(o);
                        o._.dirty = 1;
                        break;
                    case "height":
                        node.setAttribute(att, value);
                        o._.dirty = 1;
                        if (attrs.fy) {
                            att = "y";
                            value = attrs.y;
                        } else {
                            break;
                        }
                    case "y":
                        if (attrs.fy) {
                            value = -attrs.y - (attrs.height || 0);
                        }
                    case "ry":
                        if (att == "ry" && o.type == "rect") {
                            break;
                        }
                    case "cy":
                        node.setAttribute(att, value);
                        o.pattern && updatePosition(o);
                        o._.dirty = 1;
                        break;
                    case "r":
                        if (o.type == "rect") {
                            $(node, {rx: value, ry: value});
                        } else {
                            node.setAttribute(att, value);
                        }
                        o._.dirty = 1;
                        break;
                    case "src":
                        if (o.type == "image") {
                            node.setAttributeNS(xlink, "href", value);
                        }
                        break;
                    case "stroke-width":
                        if (o._.sx != 1 || o._.sy != 1) {
                            value /= mmax(abs(o._.sx), abs(o._.sy)) || 1;
                        }
                        node.setAttribute(att, value);
                        if (attrs["stroke-dasharray"]) {
                            addDashes(o, attrs["stroke-dasharray"], params);
                        }
                        if (o._.arrows) {
                            "startString" in o._.arrows && addArrow(o, o._.arrows.startString);
                            "endString" in o._.arrows && addArrow(o, o._.arrows.endString, 1);
                        }
                        break;
                    case "stroke-dasharray":
                        addDashes(o, value, params);
                        break;
                    case "fill":
                        var isURL = Str(value).match(R._ISURL);
                        if (isURL) {
                            el = $("pattern");
                            var ig = $("image");
                            el.id = R.createUUID();
                            $(el, {x: 0, y: 0, patternUnits: "userSpaceOnUse", height: 1, width: 1});
                            $(ig, {x: 0, y: 0, "xlink:href": isURL[1]});
                            el.appendChild(ig);

                            (function (el) {
                                R._preload(isURL[1], function () {
                                    var w = this.offsetWidth,
                                        h = this.offsetHeight;
                                    $(el, {width: w, height: h});
                                    $(ig, {width: w, height: h});
                                });
                            })(el);
                            o.paper.defs.appendChild(el);
                            $(node, {fill: "url(#" + el.id + ")"});
                            o.pattern = el;
                            o.pattern && updatePosition(o);
                            break;
                        }
                        var clr = R.getRGB(value);
                        if (!clr.error) {
                            delete params.gradient;
                            delete attrs.gradient;
                            !R.is(attrs.opacity, "undefined") &&
                                R.is(params.opacity, "undefined") &&
                                $(node, {opacity: attrs.opacity});
                            !R.is(attrs["fill-opacity"], "undefined") &&
                                R.is(params["fill-opacity"], "undefined") &&
                                $(node, {"fill-opacity": attrs["fill-opacity"]});
                        } else if ((o.type == "circle" || o.type == "ellipse" || Str(value).charAt() != "r") && addGradientFill(o, value)) {
                            if ("opacity" in attrs || "fill-opacity" in attrs) {
                                var gradient = R._g.doc.getElementById(node.getAttribute("fill").replace(/^url\(#|\)$/g, E));
                                if (gradient) {
                                    var stops = gradient.getElementsByTagName("stop");
                                    $(stops[stops.length - 1], {"stop-opacity": ("opacity" in attrs ? attrs.opacity : 1) * ("fill-opacity" in attrs ? attrs["fill-opacity"] : 1)});
                                }
                            }
                            attrs.gradient = value;
                            attrs.fill = "none";
                            break;
                        }
                        clr[has]("opacity") && $(node, {"fill-opacity": clr.opacity > 1 ? clr.opacity / 100 : clr.opacity});
                    case "stroke":
                        clr = R.getRGB(value);
                        node.setAttribute(att, clr.hex);
                        att == "stroke" && clr[has]("opacity") && $(node, {"stroke-opacity": clr.opacity > 1 ? clr.opacity / 100 : clr.opacity});
                        if (att == "stroke" && o._.arrows) {
                            "startString" in o._.arrows && addArrow(o, o._.arrows.startString);
                            "endString" in o._.arrows && addArrow(o, o._.arrows.endString, 1);
                        }
                        break;
                    case "gradient":
                        (o.type == "circle" || o.type == "ellipse" || Str(value).charAt() != "r") && addGradientFill(o, value);
                        break;
                    case "opacity":
                        if (attrs.gradient && !attrs[has]("stroke-opacity")) {
                            $(node, {"stroke-opacity": value > 1 ? value / 100 : value});
                        }
                        // fall
                    case "fill-opacity":
                        if (attrs.gradient) {
                            gradient = R._g.doc.getElementById(node.getAttribute("fill").replace(/^url\(#|\)$/g, E));
                            if (gradient) {
                                stops = gradient.getElementsByTagName("stop");
                                $(stops[stops.length - 1], {"stop-opacity": value});
                            }
                            break;
                        }
                    default:
                        att == "font-size" && (value = toInt(value, 10) + "px");
                        var cssrule = att.replace(/(\-.)/g, function (w) {
                            return w.substring(1).toUpperCase();
                        });
                        node.style[cssrule] = value;
                        o._.dirty = 1;
                        node.setAttribute(att, value);
                        break;
                }
            }
        }

        tuneText(o, params);
        node.style.visibility = vis;
    },
    leading = 1.2,
    tuneText = function (el, params) {
        if (el.type != "text" || !(params[has]("text") || params[has]("font") || params[has]("font-size") || params[has]("x") || params[has]("y"))) {
            return;
        }
        var a = el.attrs,
            node = el.node,
            fontSize = node.firstChild ? toInt(R._g.doc.defaultView.getComputedStyle(node.firstChild, E).getPropertyValue("font-size"), 10) : 10;
        // [CC] CODAP modification
        fontSize = isFinite( fontSize) ? fontSize : 10;
        // [/CC]

        if (params[has]("text")) {
            a.text = params.text;
            while (node.firstChild) {
                node.removeChild(node.firstChild);
            }
            var texts = Str(params.text).split("\n"),
                tspans = [],
                tspan;
            for (var i = 0, ii = texts.length; i < ii; i++) {
                tspan = $("tspan");
                i && $(tspan, {dy: fontSize * leading, x: a.x});
                tspan.appendChild(R._g.doc.createTextNode(texts[i]));
                node.appendChild(tspan);
                tspans[i] = tspan;
            }
        } else {
            tspans = node.getElementsByTagName("tspan");
            for (i = 0, ii = tspans.length; i < ii; i++) if (i) {
                $(tspans[i], {dy: fontSize * leading, x: a.x});
            } else {
                $(tspans[0], {dy: 0});
            }
        }
        $(node, {x: a.x, y: a.y});
        el._.dirty = 1;
        var bb = el._getBBox(),
            dif = a.y - (bb.y + bb.height / 2);
        dif && R.is(dif, "finite") && $(tspans[0], {dy: dif});
    },
    getRealNode = function (node) {
        if (node.parentNode && node.parentNode.tagName.toLowerCase() === "a") {
            return node.parentNode;
        } else {
            return node;
        }
    },
    Element = function (node, svg) {
        var X = 0,
            Y = 0;
        /*\
         * Element.node
         [ property (object) ]
         **
         * Gives you a reference to the DOM object, so you can assign event handlers or just mess around.
         **
         * Note: Don’t mess with it.
         > Usage
         | // draw a circle at coordinate 10,10 with radius of 10
         | var c = paper.circle(10, 10, 10);
         | c.node.onclick = function () {
         |     c.attr("fill", "red");
         | };
        \*/
        this[0] = this.node = node;
        /*\
         * Element.raphael
         [ property (object) ]
         **
         * Internal reference to @Raphael object. In case it is not available.
         > Usage
         | Raphael.el.red = function () {
         |     var hsb = this.paper.raphael.rgb2hsb(this.attr("fill"));
         |     hsb.h = 1;
         |     this.attr({fill: this.paper.raphael.hsb2rgb(hsb).hex});
         | }
        \*/
        node.raphael = true;
        /*\
         * Element.id
         [ property (number) ]
         **
         * Unique id of the element. Especially useful when you want to listen to events of the element,
         * because all events are fired in format `<module>.<action>.<id>`. Also useful for @Paper.getById method.
        \*/
        this.id = R._oid++;
        node.raphaelid = this.id;
        this.matrix = R.matrix();
        this.realPath = null;
        /*\
         * Element.paper
         [ property (object) ]
         **
         * Internal reference to “paper” where object drawn. Mainly for use in plugins and element extensions.
         > Usage
         | Raphael.el.cross = function () {
         |     this.attr({fill: "red"});
         |     this.paper.path("M10,10L50,50M50,10L10,50")
         |         .attr({stroke: "red"});
         | }
        \*/
        this.paper = svg;
        this.attrs = this.attrs || {};
        this._ = {
            transform: [],
            sx: 1,
            sy: 1,
            deg: 0,
            dx: 0,
            dy: 0,
            dirty: 1
        };
        !svg.bottom && (svg.bottom = this);
        /*\
         * Element.prev
         [ property (object) ]
         **
         * Reference to the previous element in the hierarchy.
        \*/
        this.prev = svg.top;
        svg.top && (svg.top.next = this);
        svg.top = this;
        /*\
         * Element.next
         [ property (object) ]
         **
         * Reference to the next element in the hierarchy.
        \*/
        this.next = null;
    },
    elproto = R.el;

    Element.prototype = elproto;
    elproto.constructor = Element;

    R._engine.path = function (pathString, SVG) {
        var el = $("path");
        SVG.canvas && SVG.canvas.appendChild(el);
        var p = new Element(el, SVG);
        p.type = "path";
        setFillAndStroke(p, {
            fill: "none",
            stroke: "#000",
            path: pathString
        });
        return p;
    };
    /*\
     * Element.rotate
     [ method ]
     **
     * Deprecated! Use @Element.transform instead.
     * Adds rotation by given angle around given point to the list of
     * transformations of the element.
     > Parameters
     - deg (number) angle in degrees
     - cx (number) #optional x coordinate of the centre of rotation
     - cy (number) #optional y coordinate of the centre of rotation
     * If cx & cy aren’t specified centre of the shape is used as a point of rotation.
     = (object) @Element
    \*/
    elproto.rotate = function (deg, cx, cy) {
        if (this.removed) {
            return this;
        }
        deg = Str(deg).split(separator);
        if (deg.length - 1) {
            cx = toFloat(deg[1]);
            cy = toFloat(deg[2]);
        }
        deg = toFloat(deg[0]);
        (cy == null) && (cx = cy);
        if (cx == null || cy == null) {
            var bbox = this.getBBox(1);
            cx = bbox.x + bbox.width / 2;
            cy = bbox.y + bbox.height / 2;
        }
        this.transform(this._.transform.concat([["r", deg, cx, cy]]));
        return this;
    };
    /*\
     * Element.scale
     [ method ]
     **
     * Deprecated! Use @Element.transform instead.
     * Adds scale by given amount relative to given point to the list of
     * transformations of the element.
     > Parameters
     - sx (number) horisontal scale amount
     - sy (number) vertical scale amount
     - cx (number) #optional x coordinate of the centre of scale
     - cy (number) #optional y coordinate of the centre of scale
     * If cx & cy aren’t specified centre of the shape is used instead.
     = (object) @Element
    \*/
    elproto.scale = function (sx, sy, cx, cy) {
        if (this.removed) {
            return this;
        }
        sx = Str(sx).split(separator);
        if (sx.length - 1) {
            sy = toFloat(sx[1]);
            cx = toFloat(sx[2]);
            cy = toFloat(sx[3]);
        }
        sx = toFloat(sx[0]);
        (sy == null) && (sy = sx);
        (cy == null) && (cx = cy);
        if (cx == null || cy == null) {
            var bbox = this.getBBox(1);
        }
        cx = cx == null ? bbox.x + bbox.width / 2 : cx;
        cy = cy == null ? bbox.y + bbox.height / 2 : cy;
        this.transform(this._.transform.concat([["s", sx, sy, cx, cy]]));
        return this;
    };
    /*\
     * Element.translate
     [ method ]
     **
     * Deprecated! Use @Element.transform instead.
     * Adds translation by given amount to the list of transformations of the element.
     > Parameters
     - dx (number) horisontal shift
     - dy (number) vertical shift
     = (object) @Element
    \*/
    elproto.translate = function (dx, dy) {
        if (this.removed) {
            return this;
        }
        dx = Str(dx).split(separator);
        if (dx.length - 1) {
            dy = toFloat(dx[1]);
        }
        dx = toFloat(dx[0]) || 0;
        dy = +dy || 0;
        this.transform(this._.transform.concat([["t", dx, dy]]));
        return this;
    };
    /*\
     * Element.transform
     [ method ]
     **
     * Adds transformation to the element which is separate to other attributes,
     * i.e. translation doesn’t change `x` or `y` of the rectange. The format
     * of transformation string is similar to the path string syntax:
     | "t100,100r30,100,100s2,2,100,100r45s1.5"
     * Each letter is a command. There are four commands: `t` is for translate, `r` is for rotate, `s` is for
     * scale and `m` is for matrix.
     *
     * There are also alternative “absolute” translation, rotation and scale: `T`, `R` and `S`. They will not take previous transformation into account. For example, `...T100,0` will always move element 100 px horisontally, while `...t100,0` could move it vertically if there is `r90` before. Just compare results of `r90t100,0` and `r90T100,0`.
     *
     * So, the example line above could be read like “translate by 100, 100; rotate 30° around 100, 100; scale twice around 100, 100;
     * rotate 45° around centre; scale 1.5 times relative to centre”. As you can see rotate and scale commands have origin
     * coordinates as optional parameters, the default is the centre point of the element.
     * Matrix accepts six parameters.
     > Usage
     | var el = paper.rect(10, 20, 300, 200);
     | // translate 100, 100, rotate 45°, translate -100, 0
     | el.transform("t100,100r45t-100,0");
     | // if you want you can append or prepend transformations
     | el.transform("...t50,50");
     | el.transform("s2...");
     | // or even wrap
     | el.transform("t50,50...t-50-50");
     | // to reset transformation call method with empty string
     | el.transform("");
     | // to get current value call it without parameters
     | console.log(el.transform());
     > Parameters
     - tstr (string) #optional transformation string
     * If tstr isn’t specified
     = (string) current transformation string
     * else
     = (object) @Element
    \*/
    elproto.transform = function (tstr) {
        var _ = this._;
        if (tstr == null) {
            return _.transform;
        }
        R._extractTransform(this, tstr);

        this.clip && $(this.clip, {transform: this.matrix.invert()});
        this.pattern && updatePosition(this);
        this.node && $(this.node, {transform: this.matrix});

        if (_.sx != 1 || _.sy != 1) {
            var sw = this.attrs[has]("stroke-width") ? this.attrs["stroke-width"] : 1;
            this.attr({"stroke-width": sw});
        }

        return this;
    };
    /*\
     * Element.hide
     [ method ]
     **
     * Makes element invisible. See @Element.show.
     = (object) @Element
    \*/
    elproto.hide = function () {
        if(!this.removed) this.node.style.display = "none";
        return this;
    };
    /*\
     * Element.show
     [ method ]
     **
     * Makes element visible. See @Element.hide.
     = (object) @Element
    \*/
    elproto.show = function () {
        if(!this.removed) this.node.style.display = "";
        return this;
    };
    /*\
     * Element.remove
     [ method ]
     **
     * Removes element from the paper.
    \*/
    elproto.remove = function () {
        var node = getRealNode(this.node);
        if (this.removed || !node.parentNode) {
            return;
        }
        var paper = this.paper;
        paper.__set__ && paper.__set__.exclude(this);
        eve.unbind("raphael.*.*." + this.id);
        if (this.gradient) {
            paper.defs.removeChild(this.gradient);
        }
        R._tear(this, paper);

        node.parentNode.removeChild(node);

        // Remove custom data for element
        this.removeData();

        for (var i in this) {
            this[i] = typeof this[i] == "function" ? R._removedFactory(i) : null;
        }
        this.removed = true;
    };
    elproto._getBBox = function () {
        if (this.node.style.display == "none") {
            this.show();
            var hide = true;
        }
        var canvasHidden = false,
            containerStyle;
        if (this.paper.canvas.parentElement) {
          containerStyle = this.paper.canvas.parentElement.style;
        } //IE10+ can't find parentElement
        else if (this.paper.canvas.parentNode) {
          containerStyle = this.paper.canvas.parentNode.style;
        }

        if(containerStyle && containerStyle.display == "none") {
          canvasHidden = true;
          containerStyle.display = "";
        }
        var bbox = {};
        try {
            bbox = this.node.getBBox();
        } catch(e) {
            // Firefox 3.0.x, 25.0.1 (probably more versions affected) play badly here - possible fix
            bbox = {
                x: this.node.clientLeft,
                y: this.node.clientTop,
                width: this.node.clientWidth,
                height: this.node.clientHeight
            }
        } finally {
            bbox = bbox || {};
            if(canvasHidden){
              containerStyle.display = "none";
            }
        }
        hide && this.hide();
        return bbox;
    };
    /*\
     * Element.attr
     [ method ]
     **
     * Sets the attributes of the element.
     > Parameters
     - attrName (string) attribute’s name
     - value (string) value
     * or
     - params (object) object of name/value pairs
     * or
     - attrName (string) attribute’s name
     * or
     - attrNames (array) in this case method returns array of current values for given attribute names
     = (object) @Element if attrsName & value or params are passed in.
     = (...) value of the attribute if only attrsName is passed in.
     = (array) array of values of the attribute if attrsNames is passed in.
     = (object) object of attributes if nothing is passed in.
     > Possible parameters
     # <p>Please refer to the <a href="http://www.w3.org/TR/SVG/" title="The W3C Recommendation for the SVG language describes these properties in detail.">SVG specification</a> for an explanation of these parameters.</p>
     o arrow-end (string) arrowhead on the end of the path. The format for string is `<type>[-<width>[-<length>]]`. Possible types: `classic`, `block`, `open`, `oval`, `diamond`, `none`, width: `wide`, `narrow`, `medium`, length: `long`, `short`, `midium`.
     o clip-rect (string) comma or space separated values: x, y, width and height
     o cursor (string) CSS type of the cursor
     o cx (number) the x-axis coordinate of the center of the circle, or ellipse
     o cy (number) the y-axis coordinate of the center of the circle, or ellipse
     o fill (string) colour, gradient or image
     o fill-opacity (number)
     o font (string)
     o font-family (string)
     o font-size (number) font size in pixels
     o font-weight (string)
     o height (number)
     o href (string) URL, if specified element behaves as hyperlink
     o opacity (number)
     o path (string) SVG path string format
     o r (number) radius of the circle, ellipse or rounded corner on the rect
     o rx (number) horisontal radius of the ellipse
     o ry (number) vertical radius of the ellipse
     o src (string) image URL, only works for @Element.image element
     o stroke (string) stroke colour
     o stroke-dasharray (string) [“”, “none”, “`-`”, “`.`”, “`-.`”, “`-..`”, “`. `”, “`- `”, “`--`”, “`- .`”, “`--.`”, “`--..`”]
     o stroke-linecap (string) [“`butt`”, “`square`”, “`round`”]
     o stroke-linejoin (string) [“`bevel`”, “`round`”, “`miter`”]
     o stroke-miterlimit (number)
     o stroke-opacity (number)
     o stroke-width (number) stroke width in pixels, default is '1'
     o target (string) used with href
     o text (string) contents of the text element. Use `\n` for multiline text
     o text-anchor (string) [“`start`”, “`middle`”, “`end`”], default is “`middle`”
     o title (string) will create tooltip with a given text
     o transform (string) see @Element.transform
     o width (number)
     o x (number)
     o y (number)
     > Gradients
     * Linear gradient format: “`‹angle›-‹colour›[-‹colour›[:‹offset›]]*-‹colour›`”, example: “`90-#fff-#000`” – 90°
     * gradient from white to black or “`0-#fff-#f00:20-#000`” – 0° gradient from white via red (at 20%) to black.
     *
     * radial gradient: “`r[(‹fx›, ‹fy›)]‹colour›[-‹colour›[:‹offset›]]*-‹colour›`”, example: “`r#fff-#000`” –
     * gradient from white to black or “`r(0.25, 0.75)#fff-#000`” – gradient from white to black with focus point
     * at 0.25, 0.75. Focus point coordinates are in 0..1 range. Radial gradients can only be applied to circles and ellipses.
     > Path String
     # <p>Please refer to <a href="http://www.w3.org/TR/SVG/paths.html#PathData" title="Details of a path’s data attribute’s format are described in the SVG specification.">SVG documentation regarding path string</a>. Raphaël fully supports it.</p>
     > Colour Parsing
     # <ul>
     #     <li>Colour name (“<code>red</code>”, “<code>green</code>”, “<code>cornflowerblue</code>”, etc)</li>
     #     <li>#••• — shortened HTML colour: (“<code>#000</code>”, “<code>#fc0</code>”, etc)</li>
     #     <li>#•••••• — full length HTML colour: (“<code>#000000</code>”, “<code>#bd2300</code>”)</li>
     #     <li>rgb(•••, •••, •••) — red, green and blue channels’ values: (“<code>rgb(200,&nbsp;100,&nbsp;0)</code>”)</li>
     #     <li>rgb(•••%, •••%, •••%) — same as above, but in %: (“<code>rgb(100%,&nbsp;175%,&nbsp;0%)</code>”)</li>
     #     <li>rgba(•••, •••, •••, •••) — red, green and blue channels’ values: (“<code>rgba(200,&nbsp;100,&nbsp;0, .5)</code>”)</li>
     #     <li>rgba(•••%, •••%, •••%, •••%) — same as above, but in %: (“<code>rgba(100%,&nbsp;175%,&nbsp;0%, 50%)</code>”)</li>
     #     <li>hsb(•••, •••, •••) — hue, saturation and brightness values: (“<code>hsb(0.5,&nbsp;0.25,&nbsp;1)</code>”)</li>
     #     <li>hsb(•••%, •••%, •••%) — same as above, but in %</li>
     #     <li>hsba(•••, •••, •••, •••) — same as above, but with opacity</li>
     #     <li>hsl(•••, •••, •••) — almost the same as hsb, see <a href="http://en.wikipedia.org/wiki/HSL_and_HSV" title="HSL and HSV - Wikipedia, the free encyclopedia">Wikipedia page</a></li>
     #     <li>hsl(•••%, •••%, •••%) — same as above, but in %</li>
     #     <li>hsla(•••, •••, •••, •••) — same as above, but with opacity</li>
     #     <li>Optionally for hsb and hsl you could specify hue as a degree: “<code>hsl(240deg,&nbsp;1,&nbsp;.5)</code>” or, if you want to go fancy, “<code>hsl(240°,&nbsp;1,&nbsp;.5)</code>”</li>
     # </ul>
    \*/
    elproto.attr = function (name, value) {
        if (this.removed) {
            return this;
        }
        if (name == null) {
            var res = {};
            for (var a in this.attrs) if (this.attrs[has](a)) {
                res[a] = this.attrs[a];
            }
            res.gradient && res.fill == "none" && (res.fill = res.gradient) && delete res.gradient;
            res.transform = this._.transform;
            return res;
        }
        if (value == null && R.is(name, "string")) {
            if (name == "fill" && this.attrs.fill == "none" && this.attrs.gradient) {
                return this.attrs.gradient;
            }
            if (name == "transform") {
                return this._.transform;
            }
            var names = name.split(separator),
                out = {};
            for (var i = 0, ii = names.length; i < ii; i++) {
                name = names[i];
                if (name in this.attrs) {
                    out[name] = this.attrs[name];
                } else if (R.is(this.paper.customAttributes[name], "function")) {
                    out[name] = this.paper.customAttributes[name].def;
                } else {
                    out[name] = R._availableAttrs[name];
                }
            }
            return ii - 1 ? out : out[names[0]];
        }
        if (value == null && R.is(name, "array")) {
            out = {};
            for (i = 0, ii = name.length; i < ii; i++) {
                out[name[i]] = this.attr(name[i]);
            }
            return out;
        }
        if (value != null) {
            var params = {};
            params[name] = value;
        } else if (name != null && R.is(name, "object")) {
            params = name;
        }
        for (var key in params) {
            eve("raphael.attr." + key + "." + this.id, this, params[key]);
        }
        for (key in this.paper.customAttributes) if (this.paper.customAttributes[has](key) && params[has](key) && R.is(this.paper.customAttributes[key], "function")) {
            var par = this.paper.customAttributes[key].apply(this, [].concat(params[key]));
            this.attrs[key] = params[key];
            for (var subkey in par) if (par[has](subkey)) {
                params[subkey] = par[subkey];
            }
        }
        setFillAndStroke(this, params);
        return this;
    };
    /*\
     * Element.toFront
     [ method ]
     **
     * Moves the element so it is the closest to the viewer’s eyes, on top of other elements.
     = (object) @Element
    \*/
    elproto.toFront = function () {
        if (this.removed) {
            return this;
        }
        var node = getRealNode(this.node);
        node.parentNode.appendChild(node);
        var svg = this.paper;
        svg.top != this && R._tofront(this, svg);
        return this;
    };
    /*\
     * Element.toBack
     [ method ]
     **
     * Moves the element so it is the furthest from the viewer’s eyes, behind other elements.
     = (object) @Element
    \*/
    elproto.toBack = function () {
        if (this.removed) {
            return this;
        }
        var node = getRealNode(this.node);
        var parentNode = node.parentNode;
        parentNode.insertBefore(node, parentNode.firstChild);
        R._toback(this, this.paper);
        var svg = this.paper;
        return this;
    };
    /*\
     * Element.insertAfter
     [ method ]
     **
     * Inserts current object after the given one.
     = (object) @Element
    \*/
    elproto.insertAfter = function (element) {
        if (this.removed || !element) {
            return this;
        }

        var node = getRealNode(this.node);
        var afterNode = getRealNode(element.node || element[element.length - 1].node);
        if (afterNode.nextSibling) {
            afterNode.parentNode.insertBefore(node, afterNode.nextSibling);
        } else {
            afterNode.parentNode.appendChild(node);
        }
        R._insertafter(this, element, this.paper);
        return this;
    };
    /*\
     * Element.insertBefore
     [ method ]
     **
     * Inserts current object before the given one.
     = (object) @Element
    \*/
    elproto.insertBefore = function (element) {
        if (this.removed || !element) {
            return this;
        }

        var node = getRealNode(this.node);
        var beforeNode = getRealNode(element.node || element[0].node);
        beforeNode.parentNode.insertBefore(node, beforeNode);
        R._insertbefore(this, element, this.paper);
        return this;
    };
    elproto.blur = function (size) {
        // Experimental. No Safari support. Use it on your own risk.
        var t = this;
        if (+size !== 0) {
            var fltr = $("filter"),
                blur = $("feGaussianBlur");
            t.attrs.blur = size;
            fltr.id = R.createUUID();
            $(blur, {stdDeviation: +size || 1.5});
            fltr.appendChild(blur);
            t.paper.defs.appendChild(fltr);
            t._blur = fltr;
            $(t.node, {filter: "url(#" + fltr.id + ")"});
        } else {
            if (t._blur) {
                t._blur.parentNode.removeChild(t._blur);
                delete t._blur;
                delete t.attrs.blur;
            }
            t.node.removeAttribute("filter");
        }
        return t;
    };
    R._engine.circle = function (svg, x, y, r) {
        var el = $("circle");
        svg.canvas && svg.canvas.appendChild(el);
        var res = new Element(el, svg);
        res.attrs = {cx: x, cy: y, r: r, fill: "none", stroke: "#000"};
        res.type = "circle";
        $(el, res.attrs);
        return res;
    };
    R._engine.rect = function (svg, x, y, w, h, r) {
        var el = $("rect");
        svg.canvas && svg.canvas.appendChild(el);
        var res = new Element(el, svg);
        res.attrs = {x: x, y: y, width: w, height: h, rx: r || 0, ry: r || 0, fill: "none", stroke: "#000"};
        res.type = "rect";
        $(el, res.attrs);
        return res;
    };
    R._engine.ellipse = function (svg, x, y, rx, ry) {
        var el = $("ellipse");
        svg.canvas && svg.canvas.appendChild(el);
        var res = new Element(el, svg);
        res.attrs = {cx: x, cy: y, rx: rx, ry: ry, fill: "none", stroke: "#000"};
        res.type = "ellipse";
        $(el, res.attrs);
        return res;
    };
    R._engine.image = function (svg, src, x, y, w, h) {
        var el = $("image");
        $(el, {x: x, y: y, width: w, height: h, preserveAspectRatio: "none"});
        el.setAttributeNS(xlink, "href", src);
        svg.canvas && svg.canvas.appendChild(el);
        var res = new Element(el, svg);
        res.attrs = {x: x, y: y, width: w, height: h, src: src};
        res.type = "image";
        return res;
    };
    R._engine.text = function (svg, x, y, text) {
        var el = $("text");
        svg.canvas && svg.canvas.appendChild(el);
        var res = new Element(el, svg);
        res.attrs = {
            x: x,
            y: y,
            "text-anchor": "middle",
            text: text,
            "font-family": R._availableAttrs["font-family"],
            "font-size": R._availableAttrs["font-size"],
            stroke: "none",
            fill: "#000"
        };
        res.type = "text";
        setFillAndStroke(res, res.attrs);
        return res;
    };
    R._engine.setSize = function (width, height) {
        this.width = width || this.width;
        this.height = height || this.height;
        this.canvas.setAttribute("width", this.width);
        this.canvas.setAttribute("height", this.height);
        if (this._viewBox) {
            this.setViewBox.apply(this, this._viewBox);
        }
        return this;
    };
    R._engine.create = function () {
        var con = R._getContainer.apply(0, arguments),
            container = con && con.container,
            x = con.x,
            y = con.y,
            width = con.width,
            height = con.height;
        if (!container) {
            throw new Error("SVG container not found.");
        }
        var cnvs = $("svg"),
            css = "overflow:hidden;",
            isFloating;
        x = x || 0;
        y = y || 0;
        width = width || 512;
        height = height || 342;
        $(cnvs, {
            height: height,
            version: 1.1,
            width: width,
            xmlns: "http://www.w3.org/2000/svg",
            "xmlns:xlink": "http://www.w3.org/1999/xlink"
        });
        if (container == 1) {
            cnvs.style.cssText = css + "position:absolute;left:" + x + "px;top:" + y + "px";
            R._g.doc.body.appendChild(cnvs);
            isFloating = 1;
        } else {
            cnvs.style.cssText = css + "position:relative";
            if (container.firstChild) {
                container.insertBefore(cnvs, container.firstChild);
            } else {
                container.appendChild(cnvs);
            }
        }
        container = new R._Paper;
        container.width = width;
        container.height = height;
        container.canvas = cnvs;
        container.clear();
        container._left = container._top = 0;
        isFloating && (container.renderfix = function () {});
        container.renderfix();
        return container;
    };
    R._engine.setViewBox = function (x, y, w, h, fit) {
        eve("raphael.setViewBox", this, this._viewBox, [x, y, w, h, fit]);
        var paperSize = this.getSize(),
            size = mmax(w / paperSize.width, h / paperSize.height),
            top = this.top,
            aspectRatio = fit ? "xMidYMid meet" : "xMinYMin",
            vb,
            sw;
        if (x == null) {
            if (this._vbSize) {
                size = 1;
            }
            delete this._vbSize;
            vb = "0 0 " + this.width + S + this.height;
        } else {
            this._vbSize = size;
            vb = x + S + y + S + w + S + h;
        }
        $(this.canvas, {
            viewBox: vb,
            preserveAspectRatio: aspectRatio
        });
        while (size && top) {
            sw = "stroke-width" in top.attrs ? top.attrs["stroke-width"] : 1;
            top.attr({"stroke-width": sw});
            top._.dirty = 1;
            top._.dirtyT = 1;
            top = top.prev;
        }
        this._viewBox = [x, y, w, h, !!fit];
        return this;
    };
    /*\
     * Paper.renderfix
     [ method ]
     **
     * Fixes the issue of Firefox and IE9 regarding subpixel rendering. If paper is dependant
     * on other elements after reflow it could shift half pixel which cause for lines to lost their crispness.
     * This method fixes the issue.
     **
       Special thanks to Mariusz Nowak (http://www.medikoo.com/) for this method.
    \*/
    R.prototype.renderfix = function () {
        var cnvs = this.canvas,
            s = cnvs.style,
            pos;
        try {
            pos = cnvs.getScreenCTM() || cnvs.createSVGMatrix();
        } catch (e) {
            pos = cnvs.createSVGMatrix();
        }
        var left = -pos.e % 1,
            top = -pos.f % 1;
        if (left || top) {
            if (left) {
                this._left = (this._left + left) % 1;
                s.left = this._left + "px";
            }
            if (top) {
                this._top = (this._top + top) % 1;
                s.top = this._top + "px";
            }
        }
    };
    /*\
     * Paper.clear
     [ method ]
     **
     * Clears the paper, i.e. removes all the elements.
    \*/
    R.prototype.clear = function () {
        R.eve("raphael.clear", this);
        var c = this.canvas;
        while (c.firstChild) {
            c.removeChild(c.firstChild);
        }
        this.bottom = this.top = null;
        (this.desc = $("desc")).appendChild(R._g.doc.createTextNode("Created with Rapha\xebl " + R.version));
        c.appendChild(this.desc);
        c.appendChild(this.defs = $("defs"));
    };
    /*\
     * Paper.remove
     [ method ]
     **
     * Removes the paper from the DOM.
    \*/
    R.prototype.remove = function () {
        eve("raphael.remove", this);
        this.canvas.parentNode && this.canvas.parentNode.removeChild(this.canvas);
        for (var i in this) {
            this[i] = typeof this[i] == "function" ? R._removedFactory(i) : null;
        }
    };
    var setproto = R.st;
    for (var method in elproto) if (elproto[has](method) && !setproto[has](method)) {
        setproto[method] = (function (methodname) {
            return function () {
                var arg = arguments;
                return this.forEach(function (el) {
                    el[methodname].apply(el, arg);
                });
            };
        })(method);
    }
})();

// ┌─────────────────────────────────────────────────────────────────────┐ \\
// │ Raphaël - JavaScript Vector Library                                 │ \\
// ├─────────────────────────────────────────────────────────────────────┤ \\
// │ VML Module                                                          │ \\
// ├─────────────────────────────────────────────────────────────────────┤ \\
// │ Copyright (c) 2008-2011 Dmitry Baranovskiy (http://raphaeljs.com)   │ \\
// │ Copyright (c) 2008-2011 Sencha Labs (http://sencha.com)             │ \\
// │ Licensed under the MIT (http://raphaeljs.com/license.html) license. │ \\
// └─────────────────────────────────────────────────────────────────────┘ \\

(function(){
    if (!R.vml) {
        return;
    }
    var has = "hasOwnProperty",
        Str = String,
        toFloat = parseFloat,
        math = Math,
        round = math.round,
        mmax = math.max,
        mmin = math.min,
        abs = math.abs,
        fillString = "fill",
        separator = /[, ]+/,
        eve = R.eve,
        ms = " progid:DXImageTransform.Microsoft",
        S = " ",
        E = "",
        map = {M: "m", L: "l", C: "c", Z: "x", m: "t", l: "r", c: "v", z: "x"},
        bites = /([clmz]),?([^clmz]*)/gi,
        blurregexp = / progid:\S+Blur\([^\)]+\)/g,
        val = /-?[^,\s-]+/g,
        cssDot = "position:absolute;left:0;top:0;width:1px;height:1px;behavior:url(#default#VML)",
        zoom = 21600,
        pathTypes = {path: 1, rect: 1, image: 1},
        ovalTypes = {circle: 1, ellipse: 1},
        path2vml = function (path) {
            var total =  /[ahqstv]/ig,
                command = R._pathToAbsolute;
            Str(path).match(total) && (command = R._path2curve);
            total = /[clmz]/g;
            if (command == R._pathToAbsolute && !Str(path).match(total)) {
                var res = Str(path).replace(bites, function (all, command, args) {
                    var vals = [],
                        isMove = command.toLowerCase() == "m",
                        res = map[command];
                    args.replace(val, function (value) {
                        if (isMove && vals.length == 2) {
                            res += vals + map[command == "m" ? "l" : "L"];
                            vals = [];
                        }
                        vals.push(round(value * zoom));
                    });
                    return res + vals;
                });
                return res;
            }
            var pa = command(path), p, r;
            res = [];
            for (var i = 0, ii = pa.length; i < ii; i++) {
                p = pa[i];
                r = pa[i][0].toLowerCase();
                r == "z" && (r = "x");
                for (var j = 1, jj = p.length; j < jj; j++) {
                    r += round(p[j] * zoom) + (j != jj - 1 ? "," : E);
                }
                res.push(r);
            }
            return res.join(S);
        },
        compensation = function (deg, dx, dy) {
            var m = R.matrix();
            m.rotate(-deg, .5, .5);
            return {
                dx: m.x(dx, dy),
                dy: m.y(dx, dy)
            };
        },
        setCoords = function (p, sx, sy, dx, dy, deg) {
            var _ = p._,
                m = p.matrix,
                fillpos = _.fillpos,
                o = p.node,
                s = o.style,
                y = 1,
                flip = "",
                dxdy,
                kx = zoom / sx,
                ky = zoom / sy;
            s.visibility = "hidden";
            if (!sx || !sy) {
                return;
            }
            o.coordsize = abs(kx) + S + abs(ky);
            s.rotation = deg * (sx * sy < 0 ? -1 : 1);
            if (deg) {
                var c = compensation(deg, dx, dy);
                dx = c.dx;
                dy = c.dy;
            }
            sx < 0 && (flip += "x");
            sy < 0 && (flip += " y") && (y = -1);
            s.flip = flip;
            o.coordorigin = (dx * -kx) + S + (dy * -ky);
            if (fillpos || _.fillsize) {
                var fill = o.getElementsByTagName(fillString);
                fill = fill && fill[0];
                o.removeChild(fill);
                if (fillpos) {
                    c = compensation(deg, m.x(fillpos[0], fillpos[1]), m.y(fillpos[0], fillpos[1]));
                    fill.position = c.dx * y + S + c.dy * y;
                }
                if (_.fillsize) {
                    fill.size = _.fillsize[0] * abs(sx) + S + _.fillsize[1] * abs(sy);
                }
                o.appendChild(fill);
            }
            s.visibility = "visible";
        };
    R.toString = function () {
        return  "Your browser doesn\u2019t support SVG. Falling down to VML.\nYou are running Rapha\xebl " + this.version;
    };
    var addArrow = function (o, value, isEnd) {
        var values = Str(value).toLowerCase().split("-"),
            se = isEnd ? "end" : "start",
            i = values.length,
            type = "classic",
            w = "medium",
            h = "medium";
        while (i--) {
            switch (values[i]) {
                case "block":
                case "classic":
                case "oval":
                case "diamond":
                case "open":
                case "none":
                    type = values[i];
                    break;
                case "wide":
                case "narrow": h = values[i]; break;
                case "long":
                case "short": w = values[i]; break;
            }
        }
        var stroke = o.node.getElementsByTagName("stroke")[0];
        stroke[se + "arrow"] = type;
        stroke[se + "arrowlength"] = w;
        stroke[se + "arrowwidth"] = h;
    },
    setFillAndStroke = function (o, params) {
        // o.paper.canvas.style.display = "none";
        o.attrs = o.attrs || {};
        var node = o.node,
            a = o.attrs,
            s = node.style,
            xy,
            newpath = pathTypes[o.type] && (params.x != a.x || params.y != a.y || params.width != a.width || params.height != a.height || params.cx != a.cx || params.cy != a.cy || params.rx != a.rx || params.ry != a.ry || params.r != a.r),
            isOval = ovalTypes[o.type] && (a.cx != params.cx || a.cy != params.cy || a.r != params.r || a.rx != params.rx || a.ry != params.ry),
            res = o;


        for (var par in params) if (params[has](par)) {
            a[par] = params[par];
        }
        if (newpath) {
            a.path = R._getPath[o.type](o);
            o._.dirty = 1;
        }
        params.href && (node.href = params.href);
        params.title && (node.title = params.title);
        params.target && (node.target = params.target);
        params.cursor && (s.cursor = params.cursor);
        "blur" in params && o.blur(params.blur);
        if (params.path && o.type == "path" || newpath) {
            node.path = path2vml(~Str(a.path).toLowerCase().indexOf("r") ? R._pathToAbsolute(a.path) : a.path);
            o._.dirty = 1;
            if (o.type == "image") {
                o._.fillpos = [a.x, a.y];
                o._.fillsize = [a.width, a.height];
                setCoords(o, 1, 1, 0, 0, 0);
            }
        }
        "transform" in params && o.transform(params.transform);
        if (isOval) {
            var cx = +a.cx,
                cy = +a.cy,
                rx = +a.rx || +a.r || 0,
                ry = +a.ry || +a.r || 0;
            node.path = R.format("ar{0},{1},{2},{3},{4},{1},{4},{1}x", round((cx - rx) * zoom), round((cy - ry) * zoom), round((cx + rx) * zoom), round((cy + ry) * zoom), round(cx * zoom));
            o._.dirty = 1;
        }
        if ("clip-rect" in params) {
            var rect = Str(params["clip-rect"]).split(separator);
            if (rect.length == 4) {
                rect[2] = +rect[2] + (+rect[0]);
                rect[3] = +rect[3] + (+rect[1]);
                var div = node.clipRect || R._g.doc.createElement("div"),
                    dstyle = div.style;
                dstyle.clip = R.format("rect({1}px {2}px {3}px {0}px)", rect);
                if (!node.clipRect) {
                    dstyle.position = "absolute";
                    dstyle.top = 0;
                    dstyle.left = 0;
                    dstyle.width = o.paper.width + "px";
                    dstyle.height = o.paper.height + "px";
                    node.parentNode.insertBefore(div, node);
                    div.appendChild(node);
                    node.clipRect = div;
                }
            }
            if (!params["clip-rect"]) {
                node.clipRect && (node.clipRect.style.clip = "auto");
            }
        }
        if (o.textpath) {
            var textpathStyle = o.textpath.style;
            params.font && (textpathStyle.font = params.font);
            params["font-family"] && (textpathStyle.fontFamily = '"' + params["font-family"].split(",")[0].replace(/^['"]+|['"]+$/g, E) + '"');
            params["font-size"] && (textpathStyle.fontSize = params["font-size"]);
            params["font-weight"] && (textpathStyle.fontWeight = params["font-weight"]);
            params["font-style"] && (textpathStyle.fontStyle = params["font-style"]);
        }
        if ("arrow-start" in params) {
            addArrow(res, params["arrow-start"]);
        }
        if ("arrow-end" in params) {
            addArrow(res, params["arrow-end"], 1);
        }
        if (params.opacity != null || 
            params["stroke-width"] != null ||
            params.fill != null ||
            params.src != null ||
            params.stroke != null ||
            params["stroke-width"] != null ||
            params["stroke-opacity"] != null ||
            params["fill-opacity"] != null ||
            params["stroke-dasharray"] != null ||
            params["stroke-miterlimit"] != null ||
            params["stroke-linejoin"] != null ||
            params["stroke-linecap"] != null) {
            var fill = node.getElementsByTagName(fillString),
                newfill = false;
            fill = fill && fill[0];
            !fill && (newfill = fill = createNode(fillString));
            if (o.type == "image" && params.src) {
                fill.src = params.src;
            }
            params.fill && (fill.on = true);
            if (fill.on == null || params.fill == "none" || params.fill === null) {
                fill.on = false;
            }
            if (fill.on && params.fill) {
                var isURL = Str(params.fill).match(R._ISURL);
                if (isURL) {
                    fill.parentNode == node && node.removeChild(fill);
                    fill.rotate = true;
                    fill.src = isURL[1];
                    fill.type = "tile";
                    var bbox = o.getBBox(1);
                    fill.position = bbox.x + S + bbox.y;
                    o._.fillpos = [bbox.x, bbox.y];

                    R._preload(isURL[1], function () {
                        o._.fillsize = [this.offsetWidth, this.offsetHeight];
                    });
                } else {
                    fill.color = R.getRGB(params.fill).hex;
                    fill.src = E;
                    fill.type = "solid";
                    if (R.getRGB(params.fill).error && (res.type in {circle: 1, ellipse: 1} || Str(params.fill).charAt() != "r") && addGradientFill(res, params.fill, fill)) {
                        a.fill = "none";
                        a.gradient = params.fill;
                        fill.rotate = false;
                    }
                }
            }
            if ("fill-opacity" in params || "opacity" in params) {
                var opacity = ((+a["fill-opacity"] + 1 || 2) - 1) * ((+a.opacity + 1 || 2) - 1) * ((+R.getRGB(params.fill).o + 1 || 2) - 1);
                opacity = mmin(mmax(opacity, 0), 1);
                fill.opacity = opacity;
                if (fill.src) {
                    fill.color = "none";
                }
            }
            node.appendChild(fill);
            var stroke = (node.getElementsByTagName("stroke") && node.getElementsByTagName("stroke")[0]),
            newstroke = false;
            !stroke && (newstroke = stroke = createNode("stroke"));
            if ((params.stroke && params.stroke != "none") ||
                params["stroke-width"] ||
                params["stroke-opacity"] != null ||
                params["stroke-dasharray"] ||
                params["stroke-miterlimit"] ||
                params["stroke-linejoin"] ||
                params["stroke-linecap"]) {
                stroke.on = true;
            }
            (params.stroke == "none" || params.stroke === null || stroke.on == null || params.stroke == 0 || params["stroke-width"] == 0) && (stroke.on = false);
            var strokeColor = R.getRGB(params.stroke);
            stroke.on && params.stroke && (stroke.color = strokeColor.hex);
            opacity = ((+a["stroke-opacity"] + 1 || 2) - 1) * ((+a.opacity + 1 || 2) - 1) * ((+strokeColor.o + 1 || 2) - 1);
            var width = (toFloat(params["stroke-width"]) || 1) * .75;
            opacity = mmin(mmax(opacity, 0), 1);
            params["stroke-width"] == null && (width = a["stroke-width"]);
            params["stroke-width"] && (stroke.weight = width);
            width && width < 1 && (opacity *= width) && (stroke.weight = 1);
            stroke.opacity = opacity;
        
            params["stroke-linejoin"] && (stroke.joinstyle = params["stroke-linejoin"] || "miter");
            stroke.miterlimit = params["stroke-miterlimit"] || 8;
            params["stroke-linecap"] && (stroke.endcap = params["stroke-linecap"] == "butt" ? "flat" : params["stroke-linecap"] == "square" ? "square" : "round");
            if ("stroke-dasharray" in params) {
                var dasharray = {
                    "-": "shortdash",
                    ".": "shortdot",
                    "-.": "shortdashdot",
                    "-..": "shortdashdotdot",
                    ". ": "dot",
                    "- ": "dash",
                    "--": "longdash",
                    "- .": "dashdot",
                    "--.": "longdashdot",
                    "--..": "longdashdotdot"
                };
                stroke.dashstyle = dasharray[has](params["stroke-dasharray"]) ? dasharray[params["stroke-dasharray"]] : E;
            }
            newstroke && node.appendChild(stroke);
        }
        if (res.type == "text") {
            res.paper.canvas.style.display = E;
            var span = res.paper.span,
                m = 100,
                fontSize = a.font && a.font.match(/\d+(?:\.\d*)?(?=px)/);
            s = span.style;
            a.font && (s.font = a.font);
            a["font-family"] && (s.fontFamily = a["font-family"]);
            a["font-weight"] && (s.fontWeight = a["font-weight"]);
            a["font-style"] && (s.fontStyle = a["font-style"]);
            fontSize = toFloat(a["font-size"] || fontSize && fontSize[0]) || 10;
            s.fontSize = fontSize * m + "px";
            res.textpath.string && (span.innerHTML = Str(res.textpath.string).replace(/</g, "&#60;").replace(/&/g, "&#38;").replace(/\n/g, "<br>"));
            var brect = span.getBoundingClientRect();
            res.W = a.w = (brect.right - brect.left) / m;
            res.H = a.h = (brect.bottom - brect.top) / m;
            // res.paper.canvas.style.display = "none";
            res.X = a.x;
            res.Y = a.y + res.H / 2;

            ("x" in params || "y" in params) && (res.path.v = R.format("m{0},{1}l{2},{1}", round(a.x * zoom), round(a.y * zoom), round(a.x * zoom) + 1));
            var dirtyattrs = ["x", "y", "text", "font", "font-family", "font-weight", "font-style", "font-size"];
            for (var d = 0, dd = dirtyattrs.length; d < dd; d++) if (dirtyattrs[d] in params) {
                res._.dirty = 1;
                break;
            }
        
            // text-anchor emulation
            switch (a["text-anchor"]) {
                case "start":
                    res.textpath.style["v-text-align"] = "left";
                    res.bbx = res.W / 2;
                break;
                case "end":
                    res.textpath.style["v-text-align"] = "right";
                    res.bbx = -res.W / 2;
                break;
                default:
                    res.textpath.style["v-text-align"] = "center";
                    res.bbx = 0;
                break;
            }
            res.textpath.style["v-text-kern"] = true;
        }
        // res.paper.canvas.style.display = E;
    },
    addGradientFill = function (o, gradient, fill) {
        o.attrs = o.attrs || {};
        var attrs = o.attrs,
            pow = Math.pow,
            opacity,
            oindex,
            type = "linear",
            fxfy = ".5 .5";
        o.attrs.gradient = gradient;
        gradient = Str(gradient).replace(R._radial_gradient, function (all, fx, fy) {
            type = "radial";
            if (fx && fy) {
                fx = toFloat(fx);
                fy = toFloat(fy);
                pow(fx - .5, 2) + pow(fy - .5, 2) > .25 && (fy = math.sqrt(.25 - pow(fx - .5, 2)) * ((fy > .5) * 2 - 1) + .5);
                fxfy = fx + S + fy;
            }
            return E;
        });
        gradient = gradient.split(/\s*\-\s*/);
        if (type == "linear") {
            var angle = gradient.shift();
            angle = -toFloat(angle);
            if (isNaN(angle)) {
                return null;
            }
        }
        var dots = R._parseDots(gradient);
        if (!dots) {
            return null;
        }
        o = o.shape || o.node;
        if (dots.length) {
            o.removeChild(fill);
            fill.on = true;
            fill.method = "none";
            fill.color = dots[0].color;
            fill.color2 = dots[dots.length - 1].color;
            var clrs = [];
            for (var i = 0, ii = dots.length; i < ii; i++) {
                dots[i].offset && clrs.push(dots[i].offset + S + dots[i].color);
            }
            fill.colors = clrs.length ? clrs.join() : "0% " + fill.color;
            if (type == "radial") {
                fill.type = "gradientTitle";
                fill.focus = "100%";
                fill.focussize = "0 0";
                fill.focusposition = fxfy;
                fill.angle = 0;
            } else {
                // fill.rotate= true;
                fill.type = "gradient";
                fill.angle = (270 - angle) % 360;
            }
            o.appendChild(fill);
        }
        return 1;
    },
    Element = function (node, vml) {
        this[0] = this.node = node;
        node.raphael = true;
        this.id = R._oid++;
        node.raphaelid = this.id;
        this.X = 0;
        this.Y = 0;
        this.attrs = {};
        this.paper = vml;
        this.matrix = R.matrix();
        this._ = {
            transform: [],
            sx: 1,
            sy: 1,
            dx: 0,
            dy: 0,
            deg: 0,
            dirty: 1,
            dirtyT: 1
        };
        !vml.bottom && (vml.bottom = this);
        this.prev = vml.top;
        vml.top && (vml.top.next = this);
        vml.top = this;
        this.next = null;
    };
    var elproto = R.el;

    Element.prototype = elproto;
    elproto.constructor = Element;
    elproto.transform = function (tstr) {
        if (tstr == null) {
            return this._.transform;
        }
        var vbs = this.paper._viewBoxShift,
            vbt = vbs ? "s" + [vbs.scale, vbs.scale] + "-1-1t" + [vbs.dx, vbs.dy] : E,
            oldt;
        if (vbs) {
            oldt = tstr = Str(tstr).replace(/\.{3}|\u2026/g, this._.transform || E);
        }
        R._extractTransform(this, vbt + tstr);
        var matrix = this.matrix.clone(),
            skew = this.skew,
            o = this.node,
            split,
            isGrad = ~Str(this.attrs.fill).indexOf("-"),
            isPatt = !Str(this.attrs.fill).indexOf("url(");
        matrix.translate(1, 1);
        if (isPatt || isGrad || this.type == "image") {
            skew.matrix = "1 0 0 1";
            skew.offset = "0 0";
            split = matrix.split();
            if ((isGrad && split.noRotation) || !split.isSimple) {
                o.style.filter = matrix.toFilter();
                var bb = this.getBBox(),
                    bbt = this.getBBox(1),
                    dx = bb.x - bbt.x,
                    dy = bb.y - bbt.y;
                o.coordorigin = (dx * -zoom) + S + (dy * -zoom);
                setCoords(this, 1, 1, dx, dy, 0);
            } else {
                o.style.filter = E;
                setCoords(this, split.scalex, split.scaley, split.dx, split.dy, split.rotate);
            }
        } else {
            o.style.filter = E;
            skew.matrix = Str(matrix);
            skew.offset = matrix.offset();
        }
        if (oldt !== null) { // empty string value is true as well
            this._.transform = oldt;
            R._extractTransform(this, oldt);
        }
        return this;
    };
    elproto.rotate = function (deg, cx, cy) {
        if (this.removed) {
            return this;
        }
        if (deg == null) {
            return;
        }
        deg = Str(deg).split(separator);
        if (deg.length - 1) {
            cx = toFloat(deg[1]);
            cy = toFloat(deg[2]);
        }
        deg = toFloat(deg[0]);
        (cy == null) && (cx = cy);
        if (cx == null || cy == null) {
            var bbox = this.getBBox(1);
            cx = bbox.x + bbox.width / 2;
            cy = bbox.y + bbox.height / 2;
        }
        this._.dirtyT = 1;
        this.transform(this._.transform.concat([["r", deg, cx, cy]]));
        return this;
    };
    elproto.translate = function (dx, dy) {
        if (this.removed) {
            return this;
        }
        dx = Str(dx).split(separator);
        if (dx.length - 1) {
            dy = toFloat(dx[1]);
        }
        dx = toFloat(dx[0]) || 0;
        dy = +dy || 0;
        if (this._.bbox) {
            this._.bbox.x += dx;
            this._.bbox.y += dy;
        }
        this.transform(this._.transform.concat([["t", dx, dy]]));
        return this;
    };
    elproto.scale = function (sx, sy, cx, cy) {
        if (this.removed) {
            return this;
        }
        sx = Str(sx).split(separator);
        if (sx.length - 1) {
            sy = toFloat(sx[1]);
            cx = toFloat(sx[2]);
            cy = toFloat(sx[3]);
            isNaN(cx) && (cx = null);
            isNaN(cy) && (cy = null);
        }
        sx = toFloat(sx[0]);
        (sy == null) && (sy = sx);
        (cy == null) && (cx = cy);
        if (cx == null || cy == null) {
            var bbox = this.getBBox(1);
        }
        cx = cx == null ? bbox.x + bbox.width / 2 : cx;
        cy = cy == null ? bbox.y + bbox.height / 2 : cy;
    
        this.transform(this._.transform.concat([["s", sx, sy, cx, cy]]));
        this._.dirtyT = 1;
        return this;
    };
    elproto.hide = function () {
        !this.removed && (this.node.style.display = "none");
        return this;
    };
    elproto.show = function () {
        !this.removed && (this.node.style.display = E);
        return this;
    };
    // Needed to fix the vml setViewBox issues
    elproto.auxGetBBox = R.el.getBBox;
    elproto.getBBox = function(){
      var b = this.auxGetBBox();
      if (this.paper && this.paper._viewBoxShift)
      {
        var c = {};
        var z = 1/this.paper._viewBoxShift.scale;
        c.x = b.x - this.paper._viewBoxShift.dx;
        c.x *= z;
        c.y = b.y - this.paper._viewBoxShift.dy;
        c.y *= z;
        c.width  = b.width  * z;
        c.height = b.height * z;
        c.x2 = c.x + c.width;
        c.y2 = c.y + c.height;
        return c;
      }
      return b;
    };
    elproto._getBBox = function () {
        if (this.removed) {
            return {};
        }
        return {
            x: this.X + (this.bbx || 0) - this.W / 2,
            y: this.Y - this.H,
            width: this.W,
            height: this.H
        };
    };
    elproto.remove = function () {
        if (this.removed || !this.node.parentNode) {
            return;
        }
        this.paper.__set__ && this.paper.__set__.exclude(this);
        R.eve.unbind("raphael.*.*." + this.id);
        R._tear(this, this.paper);
        this.node.parentNode.removeChild(this.node);
        this.shape && this.shape.parentNode.removeChild(this.shape);
        for (var i in this) {
            this[i] = typeof this[i] == "function" ? R._removedFactory(i) : null;
        }
        this.removed = true;
    };
    elproto.attr = function (name, value) {
        if (this.removed) {
            return this;
        }
        if (name == null) {
            var res = {};
            for (var a in this.attrs) if (this.attrs[has](a)) {
                res[a] = this.attrs[a];
            }
            res.gradient && res.fill == "none" && (res.fill = res.gradient) && delete res.gradient;
            res.transform = this._.transform;
            return res;
        }
        if (value == null && R.is(name, "string")) {
            if (name == fillString && this.attrs.fill == "none" && this.attrs.gradient) {
                return this.attrs.gradient;
            }
            var names = name.split(separator),
                out = {};
            for (var i = 0, ii = names.length; i < ii; i++) {
                name = names[i];
                if (name in this.attrs) {
                    out[name] = this.attrs[name];
                } else if (R.is(this.paper.customAttributes[name], "function")) {
                    out[name] = this.paper.customAttributes[name].def;
                } else {
                    out[name] = R._availableAttrs[name];
                }
            }
            return ii - 1 ? out : out[names[0]];
        }
        if (this.attrs && value == null && R.is(name, "array")) {
            out = {};
            for (i = 0, ii = name.length; i < ii; i++) {
                out[name[i]] = this.attr(name[i]);
            }
            return out;
        }
        var params;
        if (value != null) {
            params = {};
            params[name] = value;
        }
        value == null && R.is(name, "object") && (params = name);
        for (var key in params) {
            eve("raphael.attr." + key + "." + this.id, this, params[key]);
        }
        if (params) {
            for (key in this.paper.customAttributes) if (this.paper.customAttributes[has](key) && params[has](key) && R.is(this.paper.customAttributes[key], "function")) {
                var par = this.paper.customAttributes[key].apply(this, [].concat(params[key]));
                this.attrs[key] = params[key];
                for (var subkey in par) if (par[has](subkey)) {
                    params[subkey] = par[subkey];
                }
            }
            // this.paper.canvas.style.display = "none";
            if (params.text && this.type == "text") {
                this.textpath.string = params.text;
            }
            setFillAndStroke(this, params);
            // this.paper.canvas.style.display = E;
        }
        return this;
    };
    elproto.toFront = function () {
        !this.removed && this.node.parentNode.appendChild(this.node);
        this.paper && this.paper.top != this && R._tofront(this, this.paper);
        return this;
    };
    elproto.toBack = function () {
        if (this.removed) {
            return this;
        }
        if (this.node.parentNode.firstChild != this.node) {
            this.node.parentNode.insertBefore(this.node, this.node.parentNode.firstChild);
            R._toback(this, this.paper);
        }
        return this;
    };
    elproto.insertAfter = function (element) {
        if (this.removed) {
            return this;
        }
        if (element.constructor == R.st.constructor) {
            element = element[element.length - 1];
        }
        if (element.node.nextSibling) {
            element.node.parentNode.insertBefore(this.node, element.node.nextSibling);
        } else {
            element.node.parentNode.appendChild(this.node);
        }
        R._insertafter(this, element, this.paper);
        return this;
    };
    elproto.insertBefore = function (element) {
        if (this.removed) {
            return this;
        }
        if (element.constructor == R.st.constructor) {
            element = element[0];
        }
        element.node.parentNode.insertBefore(this.node, element.node);
        R._insertbefore(this, element, this.paper);
        return this;
    };
    elproto.blur = function (size) {
        var s = this.node.runtimeStyle,
            f = s.filter;
        f = f.replace(blurregexp, E);
        if (+size !== 0) {
            this.attrs.blur = size;
            s.filter = f + S + ms + ".Blur(pixelradius=" + (+size || 1.5) + ")";
            s.margin = R.format("-{0}px 0 0 -{0}px", round(+size || 1.5));
        } else {
            s.filter = f;
            s.margin = 0;
            delete this.attrs.blur;
        }
        return this;
    };

    R._engine.path = function (pathString, vml) {
        var el = createNode("shape");
        el.style.cssText = cssDot;
        el.coordsize = zoom + S + zoom;
        el.coordorigin = vml.coordorigin;
        var p = new Element(el, vml),
            attr = {fill: "none", stroke: "#000"};
        pathString && (attr.path = pathString);
        p.type = "path";
        p.path = [];
        p.Path = E;
        setFillAndStroke(p, attr);
        vml.canvas.appendChild(el);
        var skew = createNode("skew");
        skew.on = true;
        el.appendChild(skew);
        p.skew = skew;
        p.transform(E);
        return p;
    };
    R._engine.rect = function (vml, x, y, w, h, r) {
        var path = R._rectPath(x, y, w, h, r),
            res = vml.path(path),
            a = res.attrs;
        res.X = a.x = x;
        res.Y = a.y = y;
        res.W = a.width = w;
        res.H = a.height = h;
        a.r = r;
        a.path = path;
        res.type = "rect";
        return res;
    };
    R._engine.ellipse = function (vml, x, y, rx, ry) {
        var res = vml.path(),
            a = res.attrs;
        res.X = x - rx;
        res.Y = y - ry;
        res.W = rx * 2;
        res.H = ry * 2;
        res.type = "ellipse";
        setFillAndStroke(res, {
            cx: x,
            cy: y,
            rx: rx,
            ry: ry
        });
        return res;
    };
    R._engine.circle = function (vml, x, y, r) {
        var res = vml.path(),
            a = res.attrs;
        res.X = x - r;
        res.Y = y - r;
        res.W = res.H = r * 2;
        res.type = "circle";
        setFillAndStroke(res, {
            cx: x,
            cy: y,
            r: r
        });
        return res;
    };
    R._engine.image = function (vml, src, x, y, w, h) {
        var path = R._rectPath(x, y, w, h),
            res = vml.path(path).attr({stroke: "none"}),
            a = res.attrs,
            node = res.node,
            fill = node.getElementsByTagName(fillString)[0];
        a.src = src;
        res.X = a.x = x;
        res.Y = a.y = y;
        res.W = a.width = w;
        res.H = a.height = h;
        a.path = path;
        res.type = "image";
        fill.parentNode == node && node.removeChild(fill);
        fill.rotate = true;
        fill.src = src;
        fill.type = "tile";
        res._.fillpos = [x, y];
        res._.fillsize = [w, h];
        node.appendChild(fill);
        setCoords(res, 1, 1, 0, 0, 0);
        return res;
    };
    R._engine.text = function (vml, x, y, text) {
        var el = createNode("shape"),
            path = createNode("path"),
            o = createNode("textpath");
        x = x || 0;
        y = y || 0;
        text = text || "";
        path.v = R.format("m{0},{1}l{2},{1}", round(x * zoom), round(y * zoom), round(x * zoom) + 1);
        path.textpathok = true;
        o.string = Str(text);
        o.on = true;
        el.style.cssText = cssDot;
        el.coordsize = zoom + S + zoom;
        el.coordorigin = "0 0";
        var p = new Element(el, vml),
            attr = {
                fill: "#000",
                stroke: "none",
                font: R._availableAttrs.font,
                text: text
            };
        p.shape = el;
        p.path = path;
        p.textpath = o;
        p.type = "text";
        p.attrs.text = Str(text);
        p.attrs.x = x;
        p.attrs.y = y;
        p.attrs.w = 1;
        p.attrs.h = 1;
        setFillAndStroke(p, attr);
        el.appendChild(o);
        el.appendChild(path);
        vml.canvas.appendChild(el);
        var skew = createNode("skew");
        skew.on = true;
        el.appendChild(skew);
        p.skew = skew;
        p.transform(E);
        return p;
    };
    R._engine.setSize = function (width, height) {
        var cs = this.canvas.style;
        this.width = width;
        this.height = height;
        width == +width && (width += "px");
        height == +height && (height += "px");
        cs.width = width;
        cs.height = height;
        cs.clip = "rect(0 " + width + " " + height + " 0)";
        if (this._viewBox) {
            R._engine.setViewBox.apply(this, this._viewBox);
        }
        return this;
    };
    R._engine.setViewBox = function (x, y, w, h, fit) {
        R.eve("raphael.setViewBox", this, this._viewBox, [x, y, w, h, fit]);
        var paperSize = this.getSize(),
            width = paperSize.width,
            height = paperSize.height,
            H, W;
        if (fit) {
            H = height / h;
            W = width / w;
            if (w * H < width) {
                x -= (width - w * H) / 2 / H;
            }
            if (h * W < height) {
                y -= (height - h * W) / 2 / W;
            }
        }
        this._viewBox = [x, y, w, h, !!fit];
        this._viewBoxShift = {
            dx: -x,
            dy: -y,
            scale: paperSize
        };
        this.forEach(function (el) {
            el.transform("...");
        });
        return this;
    };
    var createNode;
    R._engine.initWin = function (win) {
            var doc = win.document;
            if (doc.styleSheets.length < 31) {
                doc.createStyleSheet().addRule(".rvml", "behavior:url(#default#VML)");
            } else {
                // no more room, add to the existing one
                // http://msdn.microsoft.com/en-us/library/ms531194%28VS.85%29.aspx
                doc.styleSheets[0].addRule(".rvml", "behavior:url(#default#VML)");
            }
            try {
                !doc.namespaces.rvml && doc.namespaces.add("rvml", "urn:schemas-microsoft-com:vml");
                createNode = function (tagName) {
                    return doc.createElement('<rvml:' + tagName + ' class="rvml">');
                };
            } catch (e) {
                createNode = function (tagName) {
                    return doc.createElement('<' + tagName + ' xmlns="urn:schemas-microsoft.com:vml" class="rvml">');
                };
            }
        };
    R._engine.initWin(R._g.win);
    R._engine.create = function () {
        var con = R._getContainer.apply(0, arguments),
            container = con.container,
            height = con.height,
            s,
            width = con.width,
            x = con.x,
            y = con.y;
        if (!container) {
            throw new Error("VML container not found.");
        }
        var res = new R._Paper,
            c = res.canvas = R._g.doc.createElement("div"),
            cs = c.style;
        x = x || 0;
        y = y || 0;
        width = width || 512;
        height = height || 342;
        res.width = width;
        res.height = height;
        width == +width && (width += "px");
        height == +height && (height += "px");
        res.coordsize = zoom * 1e3 + S + zoom * 1e3;
        res.coordorigin = "0 0";
        res.span = R._g.doc.createElement("span");
        res.span.style.cssText = "position:absolute;left:-9999em;top:-9999em;padding:0;margin:0;line-height:1;";
        c.appendChild(res.span);
        cs.cssText = R.format("top:0;left:0;width:{0};height:{1};display:inline-block;position:relative;clip:rect(0 {0} {1} 0);overflow:hidden", width, height);
        if (container == 1) {
            R._g.doc.body.appendChild(c);
            cs.left = x + "px";
            cs.top = y + "px";
            cs.position = "absolute";
        } else {
            if (container.firstChild) {
                container.insertBefore(c, container.firstChild);
            } else {
                container.appendChild(c);
            }
        }
        res.renderfix = function () {};
        return res;
    };
    R.prototype.clear = function () {
        R.eve("raphael.clear", this);
        this.canvas.innerHTML = E;
        this.span = R._g.doc.createElement("span");
        this.span.style.cssText = "position:absolute;left:-9999em;top:-9999em;padding:0;margin:0;line-height:1;display:inline;";
        this.canvas.appendChild(this.span);
        this.bottom = this.top = null;
    };
    R.prototype.remove = function () {
        R.eve("raphael.remove", this);
        this.canvas.parentNode.removeChild(this.canvas);
        for (var i in this) {
            this[i] = typeof this[i] == "function" ? R._removedFactory(i) : null;
        }
        return true;
    };

    var setproto = R.st;
    for (var method in elproto) if (elproto[has](method) && !setproto[has](method)) {
        setproto[method] = (function (methodname) {
            return function () {
                var arg = arguments;
                return this.forEach(function (el) {
                    el[methodname].apply(el, arg);
                });
            };
        })(method);
    }
})();

    // EXPOSE
    // SVG and VML are appended just before the EXPOSE line
    // Even with AMD, Raphael should be defined globally
    oldRaphael.was ? (g.win.Raphael = R) : (Raphael = R);

    if(typeof exports == "object"){
        module.exports = R;
    }
    return R;
}));

/* >>>>>>>>>> BEGIN source/utilities/layer_manager.js */
// ==========================================================================
//                                DG.LayerManager
// 
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/**
 * @class
 *
 * Holds onto a linked list of DG.RaphaelLayer whose order determines order of display of these layers by the paper
 *
 * @extends SC.Object
 */
DG.LayerManager = function( iPaper) {
  return  {
    /**
     * The first layer. If null, there are not yet any layers.
     * @property {DG.RaphaelLayer}
     */
    _firstLayer: null,

    /**
     * The last layer. If null, there are not yet any layers.
     * @property {DG.RaphaelLayer}
     */
    _lastLayer: null,

    /**
     * The paper shared by all layers
     * @property {Raphael Paper}
     */
    _paper: iPaper,

    /**
     * A new layer will be created on top of all previous layers. If iName is not null, the new layer will be
     * accessible as a named property.
     * Return null if an attempt is being made to create a layer with an already existing name.
     * Otherwise, return the newly created layer.
     * @param iName {String}
     * @param iAfterLayer {DG.RaphaelLayer}
     * @return {DG.LayerManager} to facilitate chained calls
     */
    addNamedLayer: function( iName, iAfterLayer) {
      DG.assert( !SC.empty( iName));

      if( this[iName]) {
        return this[iName];
      }

      var tLayer = DG.RaphaelLayer.create( { _paper: this._paper, name: iName } );
      this[ iName] = tLayer;

      if( iAfterLayer) {
        tLayer._prevLayer = iAfterLayer;
      }
      else if( this._lastLayer) {
        tLayer._prevLayer = this._lastLayer;
        this._lastLayer = tLayer;
      }
      else {  // Our very first layer
        this._firstLayer = this._lastLayer = tLayer;
      }
      return this;
    },

    /**
     *
     * @param iName {String}
     * @return {DG.RaphaelLayer}
     */
    getLayer: function( iName) {
      var tResult;
      this.forEach( function( iLayer) {
        if( iLayer.get('name') === iName)
          tResult = iLayer;
      });
      return tResult;
    },

    layerForElement: function( iElement) {
      var tFoundLayer;
      this.forEach( function( iLayer) {
        if( !tFoundLayer && iLayer.contains( iElement))
          tFoundLayer = iLayer;
      });
      return tFoundLayer;
    },

    forEach: function( iCallback) {
      var tLayer, tPrevLayer;
      for( tLayer = this._lastLayer; tLayer; tLayer = tPrevLayer) {
        tPrevLayer = tLayer._prevLayer;
        iCallback( tLayer);
      }
    },

    /**
     * Move the given element to iToLayer.
     * @param iElement {Raphael Element }
     * @param iFromLayer {DG.RaphaelLayer or String}
     * @param iToLayer {DG.RaphaelLayer or String}
     */
    moveElementFromTo: function( iElement, iFromLayer, iToLayer) {
      // this.testValidity();
      if( iFromLayer === iToLayer)
        return;
      if( typeof iFromLayer === 'string')
        iFromLayer = this[iFromLayer];
      if( typeof iToLayer === 'string')
        iToLayer = this[iToLayer];

      if( iFromLayer.contains( iElement)) {
        iFromLayer.prepareToMoveOrRemove( iElement);
        iToLayer.push( iElement);
      }
      // this.testValidity();
    },

    /**
     * We have to give layers a chance to update pointers to elements before calling remove
     * @param iElement {Raphael Element }
     */
    removeElement: function( iElement, iCallRemove) {
      iCallRemove = iCallRemove && iElement[0].constructor !== SVGCircleElement;
      this.forEach( function( iLayer) {
        iLayer.prepareToMoveOrRemove( iElement);
      });
      if( iCallRemove)
        iElement.remove();
      else {
        iElement.next = null;
        iElement.prev = null;
      }
      // this.testValidity();
    },

    setVisibility: function( iName, iVisibility, iAttrs) {
      if( this[iName]) {
        if( iVisibility)
          this[iName].show( iAttrs);
        else
          this[iName].hide();
      }
    },

    /**
     * The layer manager is valid
     *  - each layer is valid
     *  - no element appears more than once
     */
    testValidity: function() {
      

    }

  };
};

/* >>>>>>>>>> BEGIN source/views/raphael_base.js */
// ==========================================================================
//                          DG.RaphaelBaseView
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('libraries/raphael');
sc_require('utilities/layer_manager');

/** @class

    Use RaphaelBaseView when your rendering will be based on Raphael.

 @extends SC.View
 */
DG.RaphaelBaseView = SC.View.extend(DG.Destroyable,
    /** @scope DG.RaphaelBaseView.prototype */ {

      /**
       @property { Number }  Takes into account any borders the parent views may have
       */
      drawWidth: function () {
        return this.get('frame').width;
      }.property('frame'),

      /**
       @property { Number }  Takes into account any borders the parent views may have
       */
      drawHeight: function () {
        return this.get('frame').height;
      }.property('frame'),

      /**
       @property { R }  Raphael drawing environment
       */
      _paper: null,

      paper: function () {
        return this._paper;
      }.property('_paper'),

      /**
       * @property {DG.LayerManager }
       */
      _layerManager: null,

      layerManager: function () {
        // lazy instantiation because _paper must exist
        if (!this._layerManager) {
          this.initLayerManager();
        }
        return this._layerManager;
      }.property(),

      _plottedElementsMap: null,

      getPlottedElements: function( iIndex) {
        var tElements = this._plottedElementsMap && this._plottedElementsMap[iIndex];
        if( !tElements) {
          tElements = [];
          if( this._plottedElementsMap)
            this._plottedElementsMap[ iIndex] = tElements;
        }
        return tElements;
      },

      shiftPlottedElementsToEndOfMap: function( iIndex) {
        DG.assert(this._plottedElementsMap && this._plottedElementsMap[iIndex]);
        var tMapLength = this._plottedElementsMap.length,
            tElements = this._plottedElementsMap[iIndex];
        if( iIndex < tMapLength - 1) {
          this._plottedElementsMap.splice( iIndex, 1);
          this._plottedElementsMap.push( tElements);
        }
      },

      /**
       During createVisualization, stash elements in here that should be removed and regenerated
       each time drawing happens.
       @property { SC.Array of Raphael element }
       */
      _elementsToClear: null,

      _firstTimeToDraw: true,

      /**
       Initialize _elementsToClear
       */
      init: function () {
        arguments.callee.base.apply(this,arguments);
        this._elementsToClear = [];
        this._plottedElementsMap = [];
      },

      /**
       * signal that we're destroyed by nulling out _elementsToClear
       */
      destroy: function () {
        this._elementsToClear = null;
        this._paper = null;
        this._plottedElementsMap.length = 0;
        this._plottedElementsMap = null;

        arguments.callee.base.apply(this,arguments);
      },

      /**
       Called each time we have to regenerate or modify the visualization.
       Derived classes should call their sc_super so that _elementsToClear
       are removed.
       */
      createVisualization: function () {

        // If shouldDraw() returns false, no drawing occurs
        if (this.shouldDraw()) {

          // Perform any necessary pre-rendering tasks
          this.willDraw();

          // Perform any necessary rendering
          this.doDraw();

          // Perform any post-rendering tasks
          this.didDraw();
        }

        // TODO: This is a kluge that fixes a problem associated with Raphael 2.0 whereby the first time
        // a view is drawn, text is not drawn in the correct position or with the correct rotation.
        if (this._firstTimeToDraw) {
          this._firstTimeToDraw = false;
          this.invokeLater('displayDidChange', 1);
        }
      },

      /**
       Derived classes may override to perform their own render determination.
       If this function returns false, willDraw(), doDraw() and didDraw() are skipped.
       This base class implementation returns false if the view can't draw, so derived
       classes should make sure to return false if this base class returns false, e.g.
       return derivedClassShouldDraw() && arguments.callee.base.apply(this,arguments);
       @returns  {Boolean}   True if willDraw(), doDraw(), didDraw() can/should be called
       */
      shouldDraw: function shouldDraw() {
        // If we've been destroyed don't attempted to draw
        return !SC.none(this._elementsToClear);
      },

      /**
       Derived classes may override to perform their own pre-render preparation.
       If this function returns false, doDraw() and didDraw() are skipped.
       */
      willDraw: function willDraw() {
        // It can happen that _elementsToClear has gotten nulled out. Protect against that
        if (!this._elementsToClear)
          return;

        // Clear elements that get regenerated each time
        this._elementsToClear.forEach(function (iElement) {
          iElement.remove();
        });
        this._elementsToClear = [];
      },

      /**
       Derived classes override to do their drawing.
       */
      doDraw: function doDraw() {
      },

      /**
       Derived classes override to perform any end-of drawing tasks.
       */
      didDraw: function didDraw() {
        // It can happen that _elementsToClear has gotten nulled out. Protect against that
        if (!this._elementsToClear)
          return;

        // The elements to clear need to be in the background. We do it in reverse order
        // so that things drawn last will remain on top
        var tIndex, tLength = this._elementsToClear.length;
        for (tIndex = tLength - 1; tIndex >= 0; tIndex--)
          this._elementsToClear[tIndex].toBack();
      },

      /**
       * Change the size of our paper and recreate the visualization
       */
      updatePaper: function updatePaper() {
        if (this._paper) {
          var tDrawWidth = this.get('drawWidth'),
              tDrawHeight = this.get('drawHeight');

          if ((tDrawWidth <= 0) || (tDrawHeight <= 0))  // Can happen during removal of a view
            return;

          if ((this._paper.width !== tDrawWidth) ||
              (this._paper.height !== tDrawHeight)) {
            this._paper.setSize(tDrawWidth, tDrawHeight);
            this.notifyPropertyChange('paperSize');
            this.invokeLast(this.createVisualization);  // We're a different size, so everything is up for grabs
          }
        }
      }.observes('frame'),

      /**
       This is the root method you usually implement to draw into a view.  The
       basic idea here is to just push HTML strings into the context which will
       be converted to DOM elements by the browser.  This is usually much faster
       than manipulating the DOM yourself.

       Note that firstTime is YES only if render is being called on a new layer.
       This is the only time you want to render the HTML unless the HTML has
       changed.
       */
      render: function render(context, firstTime) {
        arguments.callee.base.apply(this,arguments);
        if (this._paper)
          this.createVisualization();
      },

      /**
       * Subclasses can override calling arguments.callee.base.apply(this,arguments) and then adding layers at will.
       */
      initLayerManager: function () {
        if (!this._layerManager && this._paper) {
          this._layerManager = new DG.LayerManager(this._paper);
        }
      },

      /**
       This is our opportunity to create the paper on which we'll draw.
       */
      didCreateLayer: function didCreateLayer() {
        /* jshint -W064 */  // Missing 'new' prefix when invoking a constructor. (W064)
        this._paper = Raphael(this.get('layer'),
            this.get('drawWidth'), this.get('drawHeight'));

        this.createVisualization();
      },

      // This is the default implementation, but it's helpful to be explicit here in the code in case we find
      // in the future we need modification
      touchStart: function (evt) {
        return NO; // Allows views up the hierarchy to respond. Particularly the component view
      },
      touchEnd: function (evt) {
        return YES; // We handled it
      },
      touchesDragged: function (evt, touches) {
        return YES; // Ours to deal with
      },
      /*  My commenting this out, we allow marquee select to work in plots
          captureTouch: function( touch) {
            return YES; // Don't let a sub view capture it
          },
      */
      // This is part of a hack to prevent both scroll view and raphael view from responding to touch
      touchPriority: YES
    });

/* >>>>>>>>>> BEGIN source/components/case_table/relation_divider_view.js */
// ==========================================================================
//                      DG.RelationDividerView
// 
//  A view for use with the DG.HierTableView which divides the individual
//  case tables in the hierarchical table view. The DG.RelationDividerView
//  provides feedback indicating the relationships between the parent cases
//  in the table to its left and the child cases in the table to its right.
//  The DG.RelationDividerView view may include curves, coloring, shading, etc.
//  
//  Author:   Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
/*global sc_static */

sc_require('components/case_table/case_table_drop_target');
sc_require('views/raphael_base');

// The width of the area between the left and right tables
DG.RDV_DIVIDER_WIDTH = 48;

/**
  The DG.RelationDividerView is the divider view between case tables in which relationship
  lines are drawn to indicate the parent-child relationships.
 */
DG.RelationDividerView = DG.CaseTableDropTarget.extend( (function() {

      // The width of the horizontal portion of the relationship curves
  var RDV_RELATION_LEFT_MARGIN = 12,
      RDV_RELATION_RIGHT_MARGIN = 4,
      
      // The color of the lines bounding the relationship regions
      RDV_RELATION_STROKE_COLOR = '#808080', // middle gray
      
      // The color of the shaded area of the relationship regions
      RDV_RELATION_FILL_COLOR = '#EEEEEE',   // pale gray
      
      // The expand/collapse icon images
      RDV_NO_ACTION_ICON_URL = '../../../../static/dg/de/cert/source/resources/slickgrid/images/no-action.png',
      RDV_EXPAND_ICON_URL = '../../../../static/dg/de/cert/source/resources/slickgrid/images/expand.gif',
      RDV_COLLAPSE_ICON_URL = '../../../../static/dg/de/cert/source/resources/slickgrid/images/collapse.gif',
      RDV_EXPAND_COLLAPSE_ICON_SIZE = { width: 9, height: 9 },
      
      kTouchMargin = 5;
  
  function getImageTouchZonePath( iImagePos, iImageSize) {
    var touchWidth = iImageSize.width + 2 * kTouchMargin,
        touchHeight = iImageSize.height + 2 * kTouchMargin,
        touchPathStr = 'M%@,%@ h%@ v%@ h%@ z'.
                          fmt( iImagePos.x - kTouchMargin,  // left
                               iImagePos.y - kTouchMargin,  // top
                               touchWidth,                  // across to right
                               touchHeight,                 // down
                               -touchWidth);                // across to left
    return touchPathStr;
  }
  
  return {  // return from closure

  layout: { width: DG.RDV_DIVIDER_WIDTH },

  /**
    Forwards to 'dividerView.leftTable'.
    @property {DG.CaseTableView}
   */
  leftTable: function( iKey, iValue) {
    if( iValue !== undefined) {
      this.setPath('headerView.leftTable', iValue);
      this.setPath('dividerView.leftTable', iValue);
      return this;
    }
    return this.getPath('dividerView.leftTable');
  }.property(),
  
  /**
    Forwards to 'dividerView.rightTable'.
    @property {DG.CaseTableView}
   */
  rightTable: function( iKey, iValue) {
    if( iValue !== undefined) {
      this.setPath('headerView.rightTable', iValue);
      this.setPath('dividerView.rightTable', iValue);
      return this;
    }
    return this.getPath('dividerView.rightTable');
  }.property(),

  /**
    Forwards to subviews.
   */
  displayDidChange: function() {
    arguments.callee.base.apply(this,arguments);

    var headerView = this.get('headerView'),
        dividerView = this.get('dividerView');
    if( headerView) headerView.displayDidChange();
    if( dividerView) dividerView.displayDidChange();
  }.observes('leftTable','rightTable'),
  
  childViews: [ 'headerView', 'dividerView', 'labelView' ],

  /** Shows the drop-target message when an attribute is dragged over. It needs to be added to the childViews array above. */
  labelView: SC.LabelView.extend({
    value: '',
    layout: {
      left: 2, right: 2, top: 2, bottom: 2
    }
  }),
  
  headerView: DG.RaphaelBaseView.extend({
    layout: { left: 0, top: 0, right: 0, height: 54 },
    
    render: function( iContext, iFirstTime) {
      arguments.callee.base.apply(this,arguments);
      iContext.resetClasses();
      iContext.addClass( ['slick-header','ui-state-default'], YES);
    },
    
    classNames: [],
    
    backgroundColor: '#E6E6E6',

    expandCollapseIcon: null,

    expandCollapseMap: {
      'collapse': RDV_COLLAPSE_ICON_URL,
      'expand': RDV_EXPAND_ICON_URL,
      'noAction': RDV_NO_ACTION_ICON_URL
    },

    doDraw: function() {
      function computeAction () {
        var dataModel = leftAdapter.get('model');
        var tableCollection = leftAdapter.get('collection');
        var rowCount = gridDataView.getLength();
        var ix;
        var myCase;
        var isCollapsed;
        var hasCollapsed = false;
        var action = 'noAction';

        DG.assert(dataModel, "No data model");
        DG.assert(tableCollection, 'No associated collection');

        for (ix = 0; ix < rowCount; ix += 1) {
          myCase = gridDataView.getItem(ix);
          isCollapsed = dataModel.isCollapsedNode(myCase);
          // if the case is not an ancestor case for this collection and has
          // children, then it is either expanded or collapsed
          if ((myCase.get('collection').get('id') === tableCollection.get('id')) &&
              (myCase.children.length > 0)) {
            if (!isCollapsed) {
              action = 'collapse';
              return action;
            } else {
              hasCollapsed = true;
            }
          }
        }
        if (hasCollapsed) {
          action = 'expand';
        }
        return action;
      }
      
      function expandCollapseAll( iEvent) {
        SC.run(function () {
          var action = computeAction();
          switch (action) {
            case 'collapse':
              table.expandCollapseAll( false);
              break;
            case 'expand':
              table.expandCollapseAll( true);
              break;
          }
        });
      }

      var table = this.get('leftTable'),
          leftAdapter = this.getPath('leftTable.gridAdapter'),
          gridDataView = leftAdapter && leftAdapter.get('gridDataView'),
          action = computeAction(),
          imageUrl = this.expandCollapseMap[action],
          imageTitle = (action === 'collapse')? "DG.CaseTable.dividerView.collapseAllTooltip".loc():
              (action === 'expand')? "DG.CaseTable.dividerView.expandAllTooltip".loc(): '',
          imagePos = { x: 3, y: 38 },
          imageSize = RDV_EXPAND_COLLAPSE_ICON_SIZE;

      this.action = action;

      if (SC.none(this.expandCollapseIcon)) {
        // The touch object is a transparent rectangle which is larger than the
        // expand/collapse icon which responds to touch. This makes it easier to
        // hit the expand/collapse icon on touch platforms.
        this._paper.path( getImageTouchZonePath( imagePos, imageSize))
            .attr({ fill: 'transparent', stroke: 'transparent' })
            .touchstart( function( iEvent) {
              SC.run( expandCollapseAll( iEvent));
            });
        this.expandCollapseIcon = this._paper.image( imageUrl,
            imagePos.x, imagePos.y,
            imageSize.width, imageSize.height)
            .click( function( iEvent) {
              SC.run( expandCollapseAll( iEvent));
            })
            .attr('title', imageTitle)
            .setClass(action);
      } else {
        this.expandCollapseIcon
            .attr({src: imageUrl, title: imageTitle, x: imagePos.x, y: imagePos.y})
            .setClass(action);
      }
    }
  }),

  dividerView: DG.RaphaelBaseView.extend({

    layout: { left: 0, top: 54, right: 0, bottom: 0 },
    
    backgroundColor: 'white',
    
    leftTable: null,
    
    rightTable: null,

    tableRefreshObserver: function() {
      this.notifyPropertyChange('tableDidRefresh');
    }.observes('*leftTable.gridAdapter.tableDidRefresh','*rightTable.gridAdapter.tableDidRefresh'),

    /**
     * This hash map maps parent case id to child group information.
     * @type {object}
     */
    _parentChildRelationsMap: null,
    
    displayProperties: ['tableDidRefresh'],

    doDraw: function() {
      var leftTable = this.get('leftTable'),
          leftAdapter = leftTable && leftTable.get('gridAdapter'),
          leftScrollTop = (leftTable && leftTable.getPath('scrollPos.scrollTop')) || 0,
          rightTable = this.get('rightTable'),
          rightAdapter = rightTable && rightTable.get('gridAdapter'),
          rightScrollTop = (rightTable && rightTable.getPath('scrollPos.scrollTop')) || 0,
          this_ = this;

      // We can get a request to draw before we are ready.
      if (!leftAdapter || !rightAdapter || SC.none(leftTable._slickGrid)) {
        //DG.log("DG.RelationDividerView.doDraw: BAILING! Missing adapter(s)");
        return;
      }

      // Lazy creation of the '_parentChildRelationsMap' property
      if (!this._parentChildRelationsMap) this._parentChildRelationsMap = [];

      /**
        Builds the SVG path string which renders from the specified Y coordinate
        on the left table (iStartY) to the specified Y coordinate on the right
        table (iEndY). The path consists of a short horizontal segment (width
        specified by RDV_RELATION_MARGINs) on each side and a Bezier curve 
        which connects them.
        @param    {Number}  iStartY   The Y coordinate on the left table where the path should start
        @param    {Number}  iEndY     The Y coordinate on the right table where the path should end
        @returns  {String}            The SVG path string
       */
      function buildPathStr( iStartY, iEndY) {
        
        // All we need is a horizontal line
        if( iStartY === iEndY)
          return 'M0,%@ h%@'.fmt( iStartY, DG.RDV_DIVIDER_WIDTH);
        
        // startPoint, endPoint, midPoint, controlPoint relate to the Bezier portion of the path
        var startPoint = { x: RDV_RELATION_LEFT_MARGIN, y: iStartY },
            endPoint = { x: DG.RDV_DIVIDER_WIDTH - RDV_RELATION_RIGHT_MARGIN, y: iEndY },
            midPoint = { x: (startPoint.x + endPoint.x) / 2, 
                         y: (startPoint.y + endPoint.y) / 2 },
            controlPoint = { x: midPoint.x, y: startPoint.y };
        return 'M0,%@ h%@ Q%@,%@ %@,%@ T%@,%@ h%@'.fmt(
                  // Start point
                  startPoint.y,
                  // Horizontal segment
                  RDV_RELATION_LEFT_MARGIN,
                  // Bezier control point
                  controlPoint.x, controlPoint.y,
                  // Midpoint of curve (endpoint of first Bezier curve)
                  midPoint.x, midPoint.y,
                  // Endpoint of second Bezier curve (assumes reflected control point)
                  endPoint.x, endPoint.y,
                  // Horizontal segment
                  RDV_RELATION_RIGHT_MARGIN);
      }

      /**
        Builds the SVG path string which defines the boundary of the area to be
        shaded when shading the area between a parent row in the left table and
        its child rows in the right table. The area is bounded on the top and
        bottom by the same Bezier curves used to draw the paths and on the left
        and right by the edge of the corresponding table.
        @param    {Number}  iStartY1  The Y coordinate on the left table where the path should start
        @param    {Number}  iEndY1    The Y coordinate on the right table where the path should end
        @param    {Number}  iStartY2  The Y coordinate on the left table where the path should start
        @param    {Number}  iEndY2    The Y coordinate on the right table where the path should end
        @returns  {String}            The SVG path string
       */
      function buildFillPathStr( iStartY1, iEndY1, iStartY2, iEndY2) {
            // startPoint, endPoint relate to the Bezier portion of the path
        var startPoint2 = { x: RDV_RELATION_LEFT_MARGIN, y: iStartY2 },
            endPoint2 = { x: DG.RDV_DIVIDER_WIDTH - RDV_RELATION_RIGHT_MARGIN, y: iEndY2 },
            midPoint2 = { x: (startPoint2.x + endPoint2.x) / 2, 
                          y: (startPoint2.y + endPoint2.y) / 2 },
            controlPoint2 = { x: midPoint2.x, y: endPoint2.y };
        return '%@ V%@ h%@ Q%@,%@ %@,%@ T%@,%@ h%@ Z'.fmt(
                  // Use existing function for the first section
                  buildPathStr( iStartY1, iEndY1),
                  // vertical line (V)
                  endPoint2.y,
                  // horizontal line (h)
                  - RDV_RELATION_RIGHT_MARGIN,
                  // Quadratic Bezier curve (Q)
                  controlPoint2.x, controlPoint2.y,
                  // Midpoint
                  midPoint2.x, midPoint2.y,
                  // Shorthand quadratic Bezier curve (T) (assumes reflected control point)
                  startPoint2.x, startPoint2.y,
                  // horizontal line (h)
                  - RDV_RELATION_LEFT_MARGIN);
                  // close path (Z)
      }

      /**
        Raphael event handler for the click on the expand/collapse icon.
        Sets the collapse/expand state internally and updates the SlickGrid DataView.
       */
      function expandCollapseClickHandler( iEvent) {
        var parentInfo = this.dgChildIDRange,
            isContained = (parentInfo && parentInfo.isContained),
            isCollapsed = (parentInfo && parentInfo.isCollapsed),
            parentID = this.dgParentID;
        parentInfo.isCollapsed = !isCollapsed;
        if( leftTable && !isContained) {
          DG.UndoHistory.execute(DG.Command.create({
            name: 'caseTable.expandCollapseOneCase',
            undoString: 'DG.Undo.caseTable.expandCollapseOneCase',
            redoString: 'DG.Redo.caseTable.expandCollapseOneCase',
            log: '%@ case %@'.loc(isCollapsed?'Expand':'Collapse', this.dgParentID),
            execute: function () {
              if(isCollapsed) {
                leftTable.expandCase( parentID);
              }
              else {
                leftTable.collapseCase( parentID);
              }
              rightTable.updateSelectedRows(true);
              rightTable.incrementProperty('expandCollapseCount');
            },
            undo: function () {
              if( isCollapsed)
                leftTable.collapseCase( parentID);
              else
                leftTable.expandCase( parentID);
              rightTable.updateSelectedRows(true);
              rightTable.incrementProperty('expandCollapseCount');
            },
            redo: function () {
              this.execute();
            }
          }));
        }
      }

      function determineImageURL(iChildIDRange) {
        return iChildIDRange.isContained
            ? RDV_NO_ACTION_ICON_URL
            : (iChildIDRange.isCollapsed
            ? RDV_EXPAND_ICON_URL
            : RDV_COLLAPSE_ICON_URL);
      }

      function getRowBounds(iLeftTable, iRightTable, iParentRow, topRightRow, bottomRightRow) {
        var leftRowBounds = iLeftTable.getRowBounds(iParentRow);
        var topRightRowBounds = iRightTable.getRowBounds(topRightRow);
        var bottomRightRowBounds = iRightTable.getRowBounds(bottomRightRow);
        var isTopLine = (iParentRow === 0) || (topRightRow === 0);
        if (leftRowBounds && topRightRowBounds && bottomRightRowBounds) {
          return {
            leftTop: leftRowBounds.top + (!isTopLine ? 1 : 0),
            leftBottom: leftRowBounds.bottom + 1,
            rightTop: topRightRowBounds.top + (!isTopLine ? 1 : 0),
            rightBottom: bottomRightRowBounds.bottom + 1
          };
        }
      }

      /**
       * Utility function which updates the path for the specified element if necessary
       * or hides it if it's no longer necessary.
       */
      function updatePathOrHide(iElement, iIsRequired, iPathStr) {
        if (iElement) {
          if (iIsRequired) {
            iElement.attr({path: iPathStr});
            iElement.show();
          } else {
            iElement.hide();
          }
        }
      }

      /**
       * Updates the parent-child lines. Creates new Raphael elements or updates
       * existing ones as necessary. Marks each object visited so that stale
       * objects can be removed.
       *
       * @param  iRelation {Object} Elements describing the relation between a parent
       *                       row and some number of children. This may consist
       *                       of a top line, an expand/collapse control, a touch
       *                       area, an area shape, and possibly a bottom line.
       * @param  iParentRow {number} Index of the parent row.
       * @param  iParentID  {number} The ID of the parent case
       * @param  iChildIDRange {{firstChildID: {number}, lastChildID: {number}, isCollapsed: {boolean}}}
       * The corresponding entry in the parentGroups map, which
       * should contain firstChildID and lastChildID properties.
       */
      function updateParentChildRelations(ix, iParentRow, iParentID, iChildIDRange) {
        var isRightCollapsed = iChildIDRange.isCollapsed || iChildIDRange.isContained;
        var topRightRow = rightAdapter.get('gridDataView').getRowById(
              isRightCollapsed ? iParentID : iChildIDRange.firstChildID);
        var bottomRightRow = rightAdapter.get('gridDataView').getRowById(
              isRightCollapsed ? iParentID : iChildIDRange.lastChildID);
        var rowBounds = getRowBounds(leftTable, rightTable, iParentRow,
              topRightRow, bottomRightRow);
        if (SC.none(rowBounds)) {
          return;
        }
        var isFillRequired = iParentRow % 2;
        var isBottomRequired = iChildIDRange.renderBottom;
        var imageUrl = determineImageURL(iChildIDRange);
        var imagePos = {x: 3, y: rowBounds.leftTop - leftScrollTop + 5};
        var imageSize = RDV_EXPAND_COLLAPSE_ICON_SIZE;
        var action = iChildIDRange.isContained? 'none': iChildIDRange.isCollapsed? 'expand': 'collapse';
        var imageTitle = (action === 'collapse')? "DG.CaseTable.dividerView.collapseGroupTooltip".loc():
            (action === 'expand')? "DG.CaseTable.dividerView.expandGroupTooltip".loc(): '';
        var touchPathStr = getImageTouchZonePath(imagePos, imageSize);
        var topPathStr = buildPathStr(rowBounds.leftTop - leftScrollTop,
              rowBounds.rightTop - rightScrollTop);
        var bottomPathStr = isBottomRequired? buildPathStr( rowBounds.leftBottom - leftScrollTop + 1,
            rowBounds.rightBottom - rightScrollTop + 1): '';
        var fillPathStr = isFillRequired ? buildFillPathStr(
              rowBounds.leftTop - leftScrollTop,
              rowBounds.rightTop - rightScrollTop,
              rowBounds.leftBottom - leftScrollTop + 1,
              rowBounds.rightBottom - rightScrollTop + 1) : '';

        var relation = this_._parentChildRelationsMap[ix];
        if (!relation) {
          relation = this_._parentChildRelationsMap[ix] = {};
          relation.top = this_._paper.path(topPathStr).attr(
              {stroke: RDV_RELATION_STROKE_COLOR});
          relation.bottom = this_._paper.path(bottomPathStr).attr(
              {stroke: RDV_RELATION_STROKE_COLOR});
          if (!isBottomRequired) {
            relation.bottom.hide();
          }
          relation.area = this_._paper.path(fillPathStr).attr(
                {fill: RDV_RELATION_FILL_COLOR, stroke: 'transparent'});
          if (!isFillRequired) relation.area.hide();
          // The touch object is a transparent rectangle which is larger than the
          // expand/collapse icon which responds to touch. This makes it easier to
          // hit the expand/collapse icon on touch platforms.
          if ((SC.browser.os === SC.OS.ios) || (SC.browser.os === SC.OS.android)) {
            relation.touch = this_._paper.path(touchPathStr)
                .attr({fill: 'transparent', stroke: 'transparent'})
                .touchstart(function (iEvent) {
                  SC.run(expandCollapseClickHandler.call(relation.icon,
                      iEvent));
                });
          }
          relation.icon = this_._paper
              .image(imageUrl, imagePos.x, imagePos.y, imageSize.width,
                  imageSize.height)
              .setClass(action)
              .click(function (iEvent) {
                SC.run(expandCollapseClickHandler.call(this, iEvent));
              }).attr('title', imageTitle);
        } else {
          updatePathOrHide(relation.top, true, topPathStr);
          updatePathOrHide(relation.bottom, isBottomRequired, bottomPathStr);
          updatePathOrHide(relation.area, isFillRequired, fillPathStr);
          updatePathOrHide(relation.touch, true, touchPathStr);
          relation.icon.attr({src: imageUrl, x: imagePos.x, y: imagePos.y, title: imageTitle})
              .setClass(action)
              .show();
        }
        relation.icon.dgParentID = iParentID;
        relation.icon.dgChildIDRange = iChildIDRange;
        return relation;
      }

      function hideRelationshipElements(ix) {
        var relation = this_._parentChildRelationsMap[ix];
        if (relation) {
          updatePathOrHide(relation.icon, false, '');
          updatePathOrHide(relation.top, false, '');
          updatePathOrHide(relation.bottom, false, '');
          updatePathOrHide(relation.area, false, '');
          updatePathOrHide(relation.touch, false, '');
        }
      }

      function updateRelationsLines() {
        if (!leftTable || !rightTable || leftTable.get('gridWidth') === 0 || rightTable.get('gridWidth') === 0) {
          //DG.log('DoDraw called on RelationDividerView, but tables not ready.');
          return;
        }
        var leftViewport = leftTable.get('gridViewport');
        var viewportCount = leftViewport.bottom - leftViewport.top;
        var leftDataView = leftAdapter.get('gridDataView');
        var rightDataView = rightAdapter.get('gridDataView');
        var rightProtoCase = rightAdapter.getProtoCase();
        var rightProtoCaseID = rightProtoCase && rightProtoCase.get('id');
        var rightProtoCaseIndex = rightDataView && rightDataView.getRowById(rightProtoCaseID);
        var protoCaseParentID = rightProtoCase && rightProtoCase.get('parentCaseID');
        var ix;
        var rowIx;
        var parentID;
        var parentCase;
        var nextParentCase;
        var lastParentCase;
        var childIDRange;
        var hasProtoCaseChild;
        var firstChildID;
        var firstChildIndex;
        var lastChildID;
        var lastChildIndex;

        DG.assert(leftViewport, 'leftViewport missing');
        DG.assert(leftDataView, 'leftDataView missing');

        for (ix = 0; ix < viewportCount; ++ix) {
          var parentItem = leftDataView.getItem(leftViewport.top + ix);
          if (parentItem && !parentItem._isProtoCase)
            lastParentCase = parentItem;
        }

        // for each visible row in the left-hand table compute the relationship
        // graphic
        for (ix = 0; ix < viewportCount; ix += 1) {
          rowIx = ix + leftViewport.top;
          parentCase = leftDataView.getItem(rowIx);
          nextParentCase = leftDataView.getItem(rowIx + 1);

          // if we found a parent case, compute the extent of its children and
          // its state, then make the appropriate graphics. Otherwise, hide
          // whatever elements may already be present.
          if (parentCase && parentCase.children[0]) {
            parentID = parentCase.get('id');
            hasProtoCaseChild = (protoCaseParentID === parentID) ||
                                  (!protoCaseParentID && (parentCase === lastParentCase));
            firstChildID = parentCase.children[0].get('id');
            firstChildIndex = rightDataView && rightDataView.getRowById(firstChildID);
            if (hasProtoCaseChild && (rightProtoCaseIndex < firstChildIndex)) {
              firstChildID = rightProtoCaseID;
            }
            lastChildID = parentCase.children[parentCase.children.length - 1].get('id');
            lastChildIndex = rightDataView && rightDataView.getRowById(lastChildID);
            if (hasProtoCaseChild && (rightProtoCaseIndex > lastChildIndex)) {
              lastChildID = rightProtoCaseID;
            }
            childIDRange = {
              firstChildID: firstChildID,
              lastChildID: lastChildID,
              isCollapsed: leftAdapter.model.isCollapsedNode(parentCase),
              isContained: (parentCase.get('collection').get('id') !==
                            leftAdapter.get('collection').get('id')),
              renderBottom: !nextParentCase || nextParentCase._isProtoCase
            };
            updateParentChildRelations(ix, rowIx, parentID, childIDRange);
          } else {
            hideRelationshipElements(ix);
          }
        }
        // if the viewport has shrunk, hide additional lines
        for (ix = viewportCount; ix < this_._parentChildRelationsMap.length; ix += 1) {
          hideRelationshipElements(ix);
        }
      }

      updateRelationsLines();
    }
  })

  };

}()));

/* >>>>>>>>>> BEGIN source/components/case_table/hier_table_view.js */
// ==========================================================================
//                        DG.HierTableView
//
//  A wrapper view for multiple DG.CaseTableViews.
//
//  Author:   Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/case_table/case_table_drop_target');
sc_require('components/case_table/case_table_view');
sc_require('components/case_table/relation_divider_view');

/** @class

  A HierTableView contains a multiple scrollable data grid views.

  The DG.HierTableView is the superview for the individual DG.CaseTableViews and the
  DG.RelationDividerViews that are used to divide them.
  Eventually, it will need to support an arbitrary number of collections, rather than
  being hard-coded at two as it is now.

  @extends SC.SplitView
*/
// eslint-disable-next-line no-redeclare
/*global YES:true, NO:true */

DG.HierTableView = SC.ScrollView.extend( (function() {
/** @scope DG.HierTableView.prototype */

  var /*kColumnHeaderBackgroundColor = '#E6E6E6',*/
    kMinTableWidth = 60;

  return {

    isVisibleChanged: function() {
      console.log('isVisibleChanged');
      // Headers may be in a bad state, refresh them
      if (this.get('isVisible')) {
        this.updateColumnInfo();
      }
    }.observes('isVisible'),

    /**
     * We scroll horizontally. Vertical scrolling is within case tables.
     */
    hasHorizontalScroller: YES,
    hasVerticalScroller: NO,
    horizontalOverlay: NO, // default YES
    //horizontalFade: YES, // default YES, applies if horizontalOverlay is true
    autohidesHorizontalScroller: YES, // default YES
    horizontalAlign: SC.ALIGN_LEFT, // default SC.ALIGN_CENTER

    classNames: 'dg-hier-table-view',

    /**
     The data context for which the table is displaying data.
     @property   {DG.DataContext}
     */
    dataContext: null,

    layout: { left: 0, top: 0, right: 0, bottom: 8 },

    /**
     * Whether the component is ready.
     *
     * The component size will not be adjusted until it is ready.
     * @type {boolean}
     */
    isReady: false,

    /**
     * Observes when the component's selection state changes. We need to
     * remove header menus when the component goes out of selection.
     */
    isSelectedDidChange: function () {
      if (!this.getPath('parentView.parentView.isSelected')) {
        // DG.log('Hiding Header Menus');
        this.contentView.hideHeaderMenus();
        this.resetActiveCell();
      }
      this.setPath('horizontalScrollerView.isVisible', false);
      this.invokeLater( function() {
        this.setPath('horizontalScrollerView.isVisible', true);
      }, 10);
    }.observes('parentView.parentView.isSelected'),

    resetActiveCell: function () {
      var childViews = this.get('childTableViews');
      childViews.forEach(function (view) {
        view.resetActiveCell();
      });

    },

    selectComponent: function () {
      var tComponentView = DG.ComponentView.findComponentViewParent(this);
      tComponentView.select();
    },

    init: function() {
      arguments.callee.base.apply(this,arguments);
      this.set('horizontalScrollerLayout', { left: 0, right: 18, top: 0, bottom: 0 });
    },

    /**
     * Adjustments needed to accommodate shared embedded mode CODAP
     * @override View.convertFrameToView
     **/
    convertFrameToView: function (frame/*, targetView*/) {
      var tOffset = $(this.containerLayer()).offset();
      return { x: tOffset.left - window.pageXOffset, y: tOffset.top - window.pageYOffset, width: frame.width, height: frame.height };
    },

    /**
     * Gives us a chance to add/remove classes to the component view in which I'm displayed.
     * For a hierarchical table view, the need is to give move the scroll bar up a bit so that
     * it is more accessible to the mouse.
     * @param iMyComponentView {DG.ComponentView}
     */
    adjustComponentViewClasses: function( iMyComponentView) {
      iMyComponentView.get('classNames').push('dg-case-table-component-view');
    },

    /**
     * This method is called by Sproutcore whenever the view is appended to
     * the document. In the case of component contents like this, this happens
     * whenever a component is selected or unselected. (It is removed from the
     * view and then reattached.
     *
     * The scroll positions of the case tables are not preserved through the
     * process of removal and reattachment. This confuses Slickgrid. So, we
     * scroll to the position that Sproutcore currently has.
     */
    didAppendToDocument: function () {
      var childViews = this.get('childTableViews');
      childViews.forEach(function (view) {
        view.refreshScroll();
      });
    },

    viewDidScrollHorizontally: function() {
      this.get('contentView').parentViewDidResizeOrScroll();
      // if in document...
      if (document.getElementById(this.get('layerId'))) {
        this.setPath('model.horizontalScrollOffset', this.get('horizontalScrollOffset'));
      }
    }.observes('horizontalScrollOffset'),

    modelDidScrollHorizontally: function() {
      var hso = this.getPath('model.horizontalScrollOffset');
      if (hso != null) {
        this.setIfChanged('horizontalScrollOffset', hso);
      }
    }.observes('model.horizontalScrollOffset'),

    isIndexHiddenDidChange: function () {
      this.updateColumnInfo();
    }.observes('.model.isIndexHidden'),

    /**
     * The content view is where "the action" is in this class. It contains a
     * SplitView that, in turn contains a hierarchical arrangement of case tables.
     */
    contentView: SC.SplitView.extend({
      layout: { left: 0, top: 0, right: 0, bottom: 0 },
      /**
       Lay out subtables left-to-right.
       @property
       */
      layoutDirection: SC.LAYOUT_HORIZONTAL,

      childViews: [],

      /**
       * Children are kept full size.
       * @override
       */
      shouldResizeChildrenToFit: NO,

      /**
       * @overload
       */
      parentViewDidResize: function (frame) {
        this.parentViewDidResizeOrScroll();
        return arguments.callee.base.apply(this,arguments);
      },

      parentViewDidResizeOrScroll: function() {
        var childTableViews = this.get('childTableViews');
        childTableViews.forEach(function(tableView) {
          tableView.ancestorViewDidResizeOrScroll();
        });
      },

      frameSize: function () {
        return this.get('frame').width;
      }.property(),

      frameSizeDidChange: function() {
        this.notifyPropertyChange('frameSize');
      }.observes('frame'),

      /**
       * Returns a view instance to be used as a divider between two other views,
       * or null if no divider should be used.
       *
       * The value of the 'splitDividerView' property will be instantiated. The default
       * value of this property is 'SC.SplitDividerView'. If the value is null or undefined,
       * null will be returned, and the SplitView will not automatically create dividers.
       *
       * You may override this method in a delegate.
       *
       * @param {SC.SplitView} splitView The split view that is hte parent of the
       * two views.
       * @param {SC.View} view1 The first view.
       * @param {SC.View} view2 The second view.
       * @returns {SC.View} The view instance to use as a divider.
       */
      splitViewDividerBetween: function(splitView, view1, view2){
        return DG.InertSplitDividerView.create();
      },

      /**
       An array of child table view object, one for each subtable.
       @property   {[DG.CaseTableView]}
       */
      childTableViews: function() {
        var childViews = this.get('childViews') || [],
            childTableViews = [];
        childViews.forEach( function( iChildView) {
          if( iChildView.kindOf( DG.CaseTableView))
            childTableViews.push( iChildView);
        });
        return childTableViews;
      }.property(),

      dividerViews: function () {
        var childViews = this.get('childViews') || [],
            dividerViews = [];
        childViews.forEach( function( iChildView) {
          if( iChildView.kindOf( DG.RelationDividerView))
            dividerViews.pushObject( iChildView); // Note: array.push is not SproutCore-friendly.
        });
        return dividerViews;
      }.property(),

      childTableLayoutDidChange: function( iNotifier) {
        this.hideHeaderMenus();
        this.displayDidChange();
      },

      /**
        Refreshes each of the individual table views.
       */
      refreshTables: function() {
        var childTableViews = this.get('childTableViews');
        childTableViews.forEach( function(tableView) { tableView.refresh(); });
      },

      /**
        Refreshes each of the individual table views.
       */
      refreshDividers: function() {
        var dividers = this.get('dividerViews');
        dividers.forEach(function (dividerView) { dividerView.displayDidChange(); });
      },

      /**
       Observer function called when the overall gridWidth of the parent table changes.
       Note that this is a content width notification, rather than a view size notification.
       @param    {DG.CaseTableView}    iNotifier -- the table view whose width changed
       */
      gridWidthDidChange: function( iNotifier) {

        var newMaxWidth = iNotifier.get('gridWidth');


        // Set the 'size' of the child table to its desired size
        iNotifier.set('size', newMaxWidth);
        this.scheduleTiling();

      },

      /**
       * Observer function called when the parent table is scrolled.
       *
       * Note that scroll handlers are triggered from jQuery event handlers,
       * and so must use SC.run() for SC updates to be triggered appropriately.
       *
       * The main job of this method is to manage propagation of scroll to the
       * left and to the right to maintain the rule that all parent cases of
       * a visible case should also be visible. We have gotten here from a
       * notification from a scroll event from slickgrid and any scrolling
       * of dependent tables will also produce scroll events, so we need to
       * avoid getting into feedback loops. We do this by keeping a propagation
       * count and, in each case table, a scroll event count. We increment the
       * propagation count and the event count for any case table that wasn't
       * scrolled from propagation. When a new notification arrives if its
       * table has a count less than the propagation count then it was a scroll
       * event from propagation and bypasses further propagation. If it has an event
       * count higher, it is a new event, so propagation should occur.
       *
       * @param iNotifier {DG.CaseTableView}
       */
      propagationCount: 0,
      tableDidScroll: function(iNotifier) {
        if (SC.none(iNotifier)) {
          return;
        }
        SC.run( function() {
          try {
            if (iNotifier._scrollEventCount < this.propagationCount) {
              //DG.log('tableDidScroll: %@ Ignoring. Propagation Count: %@/%@'.loc(
              //    iNotifier.get('collectionName'), this.propagationCount,
              //    iNotifier._scrollEventCount));
              iNotifier._scrollEventCount = this.propagationCount;
            } else {
              this.propagationCount++;
              iNotifier._scrollEventCount = this.propagationCount;

              //DG.log('tableDidScroll: %@ Propagating. Propagation Count: %@/%@'.loc(
                //    iNotifier.get('collectionName'), this.propagationCount,
                //        iNotifier._scrollEventCount));
                var leftTable = iNotifier.get('parentTable');
                var rightTable = iNotifier.get('childTable');
                var didScroll = true;
                while (leftTable) {
                  if (didScroll) {
                    didScroll = leftTable.scrollToAlignWithRight();
                    //if (didScroll) DG.log('tableDidScroll: %@ Propagated left: %@. (%@)'.loc(
                    //    iNotifier.get('collectionName'), leftTable.get('collectionName'), leftTable._scrollEventCount));
                  }
                  if (!didScroll) {
                    leftTable._scrollEventCount = this.propagationCount;
                  }
                  leftTable = leftTable.get('parentTable');
                }
                didScroll = true;
                while (rightTable) {
                  if (didScroll) {
                    didScroll = rightTable.scrollToAlignWithLeft();
                    //if (didScroll) DG.log('tableDidScroll: %@ Propagated right: %@. (%@)'.loc(
                    //    iNotifier.get('collectionName'), rightTable.get('collectionName'), rightTable._scrollEventCount));
                  }
                  if (!didScroll) {
                    rightTable._scrollEventCount = this.propagationCount;
                  }
                  rightTable = rightTable.get('childTable');
                }
            }
            this.get('dividerViews').forEach(function (dividerView) {
              if (dividerView.get('leftTable') === iNotifier || dividerView.get(
                      'rightTable') === iNotifier) {
                //DG.log('tableDidScroll reevaluating: %@ -> %@'.loc(dividerView.getPath('leftTable.collectionName'),
                //    dividerView.getPath('rightTable.collectionName')) );
                dividerView.displayDidChange();
                //} else {
                //DG.log('tableDidScroll omitting: %@ -> %@'.loc(dividerView.getPath('leftTable.collectionName'),
                //    dividerView.getPath('rightTable.collectionName'))
              }
            });
          } catch (ex) {
            DG.logWarn(ex);
          }
        }.bind( this));
      },

      /**
       Observer function called when the number of rows in the parent table changes.
       */
      rowCountDidChange: function(iNotifier) {
        if (!iNotifier) {
          return;
        }
        this.get('dividerViews').forEach(function (view) {
          if ((view.get('leftTable') === iNotifier) || (view.get('rightTable') === iNotifier)) {
            view.displayDidChange();
          }
        });
      },

      /**
       Observer function called when a row is expanded/collapsed.
       */
      tableDidExpandCollapse: function() {
        SC.run( function() {
          this.refreshDividers();
        }.bind( this));
      },

      hideHeaderMenus: function() {
        this.get('childTableViews').forEach(function (view) {
          view.hideHeaderMenu();
        });
      },

      model: SC.outlet('parentView.parentView.model')
    }),

    relationDividerView: DG.RelationDividerView.extend ( SC.SplitChild, {
      name: 'relationDividerView',
      minimumSize: DG.RDV_DIVIDER_WIDTH,
      maximumSize: DG.RDV_DIVIDER_WIDTH,
      size: DG.RDV_DIVIDER_WIDTH,
      autoResizeStyle: SC.FIXED_SIZE,
      compensatesForMovement: YES,
      allowsIndirectAdjustments: NO
    }),

    childTableView: DG.CaseTableView.extend ( SC.SplitChild, {
      name: 'childTableView',
      minimumSize: kMinTableWidth,
      autoResizeStyle: SC.RESIZE_AUTOMATIC,
      compensatesForMovement: YES
    }),

    leftDropTarget: null,

    makeRelationDividerView: function () {
      return this.relationDividerView.create({
        name: 'dividerTarget',
        dataContext: this.model.get('context')
      });
    },

    makeChildTableView: function () {
      return this.childTableView.create({});
    },

    /**
     * Removes the child table view and, if present, its divider.
     * @param {DG.CaseTableView} view
     */
    removeChildTableView: function (view) {
      var contentView = this.get('contentView');
      var viewIx = contentView.childViews.indexOf(view);
      var childCount = contentView.childViews.length;
      var dividerView;
      if (viewIx > 0) {
        dividerView = contentView.childViews[viewIx - 1];
      } else if (viewIx === 0 && childCount > 2) {
        dividerView = contentView.childViews[viewIx + 1];
      }
      if (dividerView) {
        contentView.removeChild(dividerView);
      }
      contentView.removeChild(view);
    },

    getChildTableViewForCollection: function(collectionID) {
      var childTableViews = this.get('childTableViews');
      return DG.ArrayUtils.firstMatch(childTableViews, function(tableView) {
                              return tableView.getPath('gridAdapter.collection.id') === collectionID;
                            });
    },

    /**
      An array of child table view object, one for each subtable.
      @property   {[DG.CaseTableView]}
     */
    childTableViews: function() {
      // delegate down
      var contentView = this.get('contentView');
      return contentView.childTableViews();
    }.property(),

    dividerViews: function () {
      // delegate down
      var contentView = this.get('contentView');
      return contentView.dividerViews();
    }.property(),

    /**
      Destruction method.
     */
    willDestroy: function() {
      var childViews = this.get('childTableViews');
      childViews.forEach( function( iView) {
                            if( iView && iView.willDestroy)
                              iView.willDestroy();
        iView.removeObserver('frameSize', this, 'contentWidthDidChange');
      });
    },

    /**
      Refreshes each of the individual table views.
     */
    refresh: function() {
      this.get('contentView').refreshTables();
    },

    /**
      Refreshes each of the individual table views.
     */
    refreshDividers: function() {
      this.get('contentView').refreshDividers();
    },

    mouseDown: function(ev) {
      // if not in a current edit, background clicks should complete any edit
      if (ev.target.tagName !== 'INPUT') {
        DG.globalEditorLock.commitCurrentEdit();
      }
      return NO;
    },

    touchStart: function( ev) {
      this.mouseDown(ev);
      arguments.callee.base.apply(this,arguments);
      return NO;
    },

    /**
     * @return {boolean}
     */
    isHorizontalScrollActive: function () {
      if (SC.none(this._lastContentWidth)) {
        this._lastContentWidth = this.getPath('contentView.frame.width');
      }
      return this.get('frame').width < this.get('_lastContentWidth');
    }.property(),

    _lastContentWidth: null,

    widenColumnsProportionally: function (newComponentWidth, currentComponentWidth) {
      var childTableViews = this.get('childTableViews') || [];
      var currentColumnWidths = childTableViews.reduce(function (subtotal, tableView) {
        var columnWidths = tableView.get('columnWidths') || {};
        return subtotal + Object.keys(columnWidths).reduce(function (tableSubtotal, key) {
          // if the key is numeric, it is an attribute id
          // we only want to sum the widths of attribute columns
          var width = isNaN(Number(key))? 0: columnWidths[key];
          return tableSubtotal + width;
        }, 0);
      }, 0);
      var factor = (currentColumnWidths + newComponentWidth - currentComponentWidth) / currentColumnWidths;
      childTableViews.forEach( function( iTableView) {
        iTableView.widenColumnsProportionally(factor);
      });
    },

    expandRightmostColumn: function (frameWidth, contentWidth) {
      var childTableViews = this.get('childTableViews');
      var lastTableView = childTableViews && childTableViews[childTableViews.length-1];
      if( lastTableView)
        lastTableView.resizeLastColumn(frameWidth - contentWidth);
    },

    /**
     * Width of the contained table set changed.
     */
    adjustContentWidth: function (changeAgent) {
      var tContentWidth = this.getPath('contentView.frame.width');
      var tFrameWidth = this.get('frame').width;
      var tPageWidth = window.innerWidth;
      var tMaxFrameWidth = Math.max(tPageWidth, tFrameWidth);
      var tComponentView = DG.ComponentView.findComponentViewParent(this);
      var tContentHasBeenSeen = this._lastContentWidth != null;
      var tIsAnimating = this.get('isComponentLayoutAnimating');
      var tLayout = tComponentView && tComponentView.get('layout');
      // console.log('HierTableView.adjustContentWidth: /changeAgent, ' +
      //     'tContentWidth, tFrameWidth, tPageWidth, this._lastContentWidth, tIsAnimating/' +
      //     [changeAgent, tContentWidth, tFrameWidth, tPageWidth, this._lastContentWidth, tIsAnimating].join());
      // console.trace();

      // If we have no component view parent we are not a part of the document, yet.
      // If we have no content width, then slickgrid has not rendered contents, yet.
      // If we have no frame width then the component may be beginning an animation
      // into existence.
      // If content width is the same as frame width, we have nothing to do.
      // If any of these, exit.
      if (SC.none(tComponentView) ||
          !tContentWidth ||
          !tFrameWidth ||
          tContentWidth === tFrameWidth ) {
        return;
      }

      // if frame width was adjusted to be larger than the content, we expand the rightmost column of rightmost
      // collection
      if ((tContentWidth > 0)
          && (tFrameWidth > 0)
          && Number(tFrameWidth) !== Number(tContentWidth)
          && changeAgent === 'frame'
          && tContentHasBeenSeen
          && !tIsAnimating
      ) {
        this.expandRightmostColumn(tFrameWidth, tContentWidth);
        tContentWidth = this.getPath('contentView.frame.width');
      }

      // if we are not scrolling then growth in content should expand frame,
      // but it should not expand it more than the width of the page
      if (tFrameWidth === this._lastContentWidth && changeAgent === "content") {
        var newWidth = Math.min(tContentWidth, tMaxFrameWidth);
        if (DG.KEEP_IN_BOUNDS_PREF) {
          tComponentView.configureViewBoundsLayout({height:tLayout.height,
            width:newWidth,
            x:tLayout.left,
            y:tLayout.top
          });
        } else {
          tComponentView.adjust('width', newWidth);
        }
      }
      // the content width should never be less than the component width
      else if (tContentWidth < tFrameWidth) {
        tComponentView.adjust('width', tContentWidth);
      }
      if (changeAgent === 'content') {
        this._lastContentWidth = tContentWidth;
      }
    },

    frameDidChange: function () {
      this.adjustContentWidth('frame');
    }.observes('frame'),

    contentWidthDidChange: function () {
      this.adjustContentWidth('content');
    },

    isComponentLayoutAnimating: function () {
      var tComponentView = DG.ComponentView.findComponentViewParent(this);
      return tComponentView && !!tComponentView._activeAnimations;
    }.property(),

    _wasAnimating: false,
    componentIsAnimatingDidChange: function () {
      var tComponentView = DG.ComponentView.findComponentViewParent(this);
      var viewState = tComponentView && tComponentView.get('viewState');
      var isAnimating = (viewState && viewState === SC.CoreView.ATTACHED_SHOWN_ANIMATING);
      if (this._wasAnimating !== isAnimating) {
        this.notifyPropertyChange('isComponentLayoutAnimating');
      }
      if (this._wasAnimating && !isAnimating) {
        this.adjustContentWidth('content');
        this.refresh();
      }
      this._wasAnimating = isAnimating;
    }.observes('parentView.parentView.viewState'),

    /**
      Observer function called when any of the child tables is changed.
     */
    _klugeAdjust: false,
    gridViewDidChange: function( iNotifier) {
      this.refreshDividers();

      // adjusting the width fixes initial redraw problems in Safari
      if( !this._klugeAdjust) {
        this._klugeAdjust = true;
        var tComponentView = DG.ComponentView.findComponentViewParent( this),
            tComponentFrame = tComponentView && tComponentView.get('frame'),
            tComponentWidth = tComponentFrame && tComponentFrame.width;
        if( tComponentWidth)
          tComponentView.adjust('width', tComponentWidth + 1);
      }
    },

    /**
      Attaches the specified set of DG.CaseTableAdapters to the individual child table views.
      @param  {[DG.CaseTableAdapter]} iAdapters
     */
    setCaseTableAdapters: function( iAdapters) {
      function setUpDividerView(parentTable, childTable, relationView) {
        if( relationView && parentTable && childTable) {
          relationView.beginPropertyChanges();
          relationView.set('leftTable', parentTable);
          relationView.set('rightTable', childTable);
          relationView.endPropertyChanges();
        }
      }
      var contentView = this.get('contentView');
      var childTableViews = this.get('childTableViews');
      var caseTablesInAdapterOrder = [];
      var childTableView;
      var lastChildTableView = null;
      var horizontalScrollOffset = this.getPath('model.horizontalScrollOffset');
      var x;

      // Remove all the contents of the view. We are going to recreate the order.
      while(!SC.none(x = contentView.get('childViews')[0])) {
        contentView.removeChild(x);
      }

      // find out which adapters are already mapped to views.
      iAdapters.forEach(function (adapter, ix) {
        caseTablesInAdapterOrder[ix] = childTableViews.findProperty('gridAdapter', adapter);
      });

      // now we are going to rebuild the view, left first...
      if (SC.none(this.leftDropTarget)) {
        this.leftDropTarget = DG.CaseTableDropTarget.create({
          name:'leftTarget',
          isTopLevel: true,
          dataContext: this.model.get('context')
        });
      }
      contentView.appendChild(this.leftDropTarget);

      // if not mapped to views create new views
      iAdapters.forEach(function (adapter, ix) {
        var divider;
        if (!caseTablesInAdapterOrder[ix]) {
          childTableView = this.makeChildTableView();
          childTableView.set('gridAdapter', adapter);
          caseTablesInAdapterOrder[ix] = childTableView;
        }
        if (ix > 0) {
          divider = this.makeRelationDividerView();
          setUpDividerView(caseTablesInAdapterOrder[ix-1], caseTablesInAdapterOrder[ix], divider);
          contentView.appendChild(divider);
        }
        if (ix + 1 === iAdapters.length) {
          // We mark the rightmost case table. While initializing we need to
          // ignore width adjustments until we have generated all the case tables.
          // after this, we try to avoid empty space to the right of the rightmost
          // table.
          caseTablesInAdapterOrder[ix].set('isRightmost', true);
        }
        contentView.appendChild(caseTablesInAdapterOrder[ix]);
        if (lastChildTableView) {
          lastChildTableView.set('childTable', caseTablesInAdapterOrder[ix]);
          caseTablesInAdapterOrder[ix].set('parentTable', lastChildTableView);
        } else {
          caseTablesInAdapterOrder[ix].set('parentTable', null);
        }
        lastChildTableView = caseTablesInAdapterOrder[ix];
        lastChildTableView.set('childTable', null);
      }.bind(this));
      this.updateSelectedRows();
      contentView.scheduleTiling();
      if (!contentView.hasObserverFor('frameSize', this, 'contentWidthDidChange')) {
        contentView.addObserver('frameSize', this, 'contentWidthDidChange');
      }
      // set the horizontal scroll to that saved in the model. We defer a render
      // cycle to let the slickgrid construction update the DOM
      this.invokeLater(function () {
        if (!SC.none(horizontalScrollOffset)) {
          this.set('horizontalScrollOffset', horizontalScrollOffset);
        }
      });

    },

    /**
      Refreshes the column header information for each subtable view.
     */
    updateColumnInfo: function() {
      var childTableViews = this.get('childTableViews') || [];
      childTableViews.forEach( function( iTableView) {
                                  iTableView.updateColumnInfo();
                              });
    },

    /**
      Refreshes the row data for each subtable view.
     */
    updateRowData: function() {
      this.refresh();
      this.refreshDividers();
    },

    /**
      Updates the row count for each subtable view.

      @param forceRedraw {Boolean} Whether to force a re-indexing of the rows
     */
    updateRowCount: function( forceRedraw) {
      var childTableViews = this.get('childTableViews') || [];
      childTableViews.forEach( function( iTableView) {
                                  iTableView.updateRowCount( forceRedraw);
                              });
    },

    /**
      Updates the set of selected rows for each subtable view.
     */
    updateSelectedRows: function() {
      var childTableViews = this.get('childTableViews') || [];
      childTableViews.forEach( function( iTableView) {
                                  iTableView.updateSelectedRows();
                              });
    },

    scrollSelectionToView: function (primaryCase) {
      var childTableViews = this.get('childTableViews') || [];
      childTableViews.forEach( function( iTableView) {
        iTableView.scrollSelectionToView(primaryCase);
      });
    },

    scrollToCaseByID: function (collectionClient, caseID) {
      if (SC.none(collectionClient)) {
        return;
      }
      DG.assert(collectionClient.constructor === DG.CollectionClient, 'Correct type');
      var view = this.findViewForCollection(collectionClient);
      if (view)
        view.scrollToCase(caseID);
    },

    findViewForCollection: function (iCollection) {
      var collectionID = iCollection.get('id');
      var childTableViews = this.get('childTableViews') || [];
      return childTableViews.find(function (childTableView) {
        var viewCollection = childTableView.getPath('gridAdapter.collection');
        return viewCollection.get('id') === collectionID;
      });
    },

    isFrameVisible: function (iFrame) {
      var thisFrame = this.get('frame');
      return ((thisFrame.x <= iFrame.x) && (thisFrame.y <= iFrame.y) &&
          (thisFrame.x + thisFrame.width >= iFrame.x + iFrame.width) &&
          (thisFrame.y + thisFrame.height >= iFrame.y + iFrame.height));
    },

    scrollHorizontallyToMakeVisible: function (iFrame) {
      var thisFrame = this.get('frame');
      var dLeft = thisFrame.x - iFrame.x;
      var dRight = iFrame.x + iFrame.width - (thisFrame.x + thisFrame.width);
      if (dLeft>=dRight) {
        this.scrollBy(dLeft+2, 0);
      } else {
        this.scrollBy(dRight+2, 0);
      }
    },

    /**
     * Scrolls a this view to place the given DOM Element in view.
     * @param iElement
     */
    scrollDOMElementHorizontallyToView: function(iElement) {
      var thisElement = this.layer();
      var left = 0, top = 0, width = iElement.offsetWidth,
          height = iElement.offsetHeight, frame;
      var el = iElement;
      while (el !== thisElement) {
        left += el.offsetLeft;
        top += el.offsetTop;
        el = el.parentElement;
      }
      frame = {x:left,y:top,width:width, height:height};
      if (!this.isFrameVisible(frame)) {
        this.scrollHorizontallyToMakeVisible(frame);
      } else {
        this.scrollBy(1,0);
      }
    }
  }; // end return from closure

}()));

/**
  @class DG.InertSplitDividerView

  An InertSplitDividerView is a variant of SC.SplitDividerView which
  doesn't allow the user to drag it and doesn't change the cursor,
  by not mixing in SC.SplitThumb.

  @extends SC.View, SC.SplitChild
  @author Kirk Swenson
*/
DG.InertSplitDividerView = SC.View.extend(SC.SplitChild,
{
  /** @scope SC.InertSplitDividerView.prototype */
  classNames: ['sc-split-divider-view'],

  // set to prevent SC.SplitView from automatically creating dividers
  // to sit between this divider and another view.
  isSplitDivider: YES,

  // NOTE: 'sc-fixed-size' is only hard-coded because SC.SplitView requires
  // this file, and SC.FIXED_SIZE is defined inside SC.SplitView.
  autoResizeStyle: 'sc-fixed-size',

  movesSibling: SC.MOVES_CHILD,

  size: SC.propertyFromRenderDelegate('dividerSize', 1),

  renderDelegateName: 'inertSplitDividerRenderDelegate'
});

/**
  The SC.BaseTheme.inertSplitDividerRenderDelegate is a variant of
  SC.BaseTheme.splitDividerRenderDelegate which minimizes its width
  so as to minimize its impact on mouse events, click events, etc.
  Without this adjustment, the divider intercepts all mouse events
  within five pixels to each side of the divider, which affects the
  ability to interact with scroll bars or other widgets along the
  edge of the subview.
*/
SC.BaseTheme.inertSplitDividerRenderDelegate = SC.RenderDelegate.create({
  className: 'dg-split-divider',
  dividerSize: 1,

  // We would like the divider size to be exactly one pixel,
  // but offsets any smaller than these seem to prevent it from
  // rendering at all, so we stick with this for now.
  splitPositionOffset: -5,
  splitSizeOffset: 5,

  render: function(dataSource, context) {
    this.addSizeClassName(dataSource, context);

    // the divider view itself is the grabber, but the visible line
    // may be inside of it.
    context.push("<div class='line'></div>");
  },

  update: function(dataSource, jquery) {
    this.updateSizeClassName(dataSource, jquery);
  }
});

// For legacy compatibility
DG.TableView = DG.HierTableView;

/* >>>>>>>>>> BEGIN source/components/case_table/insert_cases_dialog.js */
// ==========================================================================
//
//  Author:   kswenson
//
//  Copyright (c) 2017 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
sc_require('views/inspector/picker_title_view');
sc_require('views/inspector/picker_control_view');
/** @class

   Provides an editor view for examining and modifying case attribute properties.

 @extends SC.View
 */
DG.InsertCasesDialog = SC.PalettePane.extend( (function() // closure
    /** @scope DG.InsertCasesDialog.prototype */ {
    var kRowHeight = 20;
    var kControlHeight = kRowHeight - 2;
    var kTitleHeight = 26;
    var kControlWidth = 80;
    var kMargin = 10;
    var kLeading = 5;

    return {
      buttonIconClass: 'moonicon-icon-styles',  // So we can identify closure through click on button icon
      classNames: 'dg-insert-cases-dialog'.w(),
      layout: {width: 250, height: 100, centerX: 0, centerY: 0},
      isModal: true,
      caseTableView: null,  // provided by caller
      contentView: SC.View.extend(SC.FlowedLayout, {
        layoutDirection: SC.LAYOUT_VERTICAL,
        isResizable: false,
        isClosable: false,
        defaultFlowSpacing: {left: kMargin, right: kMargin, bottom: kLeading},
        canWrap: false,
        align: SC.ALIGN_TOP,
        layout: {right: 5},
        childViews: [ 'title', 'countCtl', 'beforeAfterCtl', 'applyOrCancelCtl' ],

        title: DG.PickerTitleView.extend({
          layout: {height: kTitleHeight},
          flowSpacing: {left: 0, right: 0, bottom: kLeading},
          title: 'DG.CaseTable.insertCasesDialog.title',
          localize: true,
        }),

        countCtl: DG.PickerControlView.design({
          layout: {height: kRowHeight},
          label: 'DG.CaseTable.insertCasesDialog.numCasesPrompt',
          localize: true,
          controlView: SC.TextFieldView.extend({
            layout: {
              centerY: 0,
              width: kControlWidth,
              height: kControlHeight
            },
            backgroundColor: 'white',
            didAppendToDocument: function() {
              this.becomeFirstResponder();
            }
          })
        }),

        beforeAfterCtl: DG.PickerControlView.design({
          layout: {height: kRowHeight},
          label: 'DG.CaseTable.insertCasesDialog.beforeAfter.prompt',
          localize: true,
          controlView: SC.RadioView.design({
            layout: {
              centerY: 0,
              width: 140,
              height: kControlHeight
            },
            items: [
              {
                title: 'DG.CaseTable.insertCasesDialog.beforeAfter.before'.loc(),
                value: 'before',
                enabled: YES
              },
              {
                title: 'DG.CaseTable.insertCasesDialog.beforeAfter.after'.loc(),
                value: 'after',
                enabled: YES
              }
            ],
            value: 'after',
            itemTitleKey: 'title',
            itemValueKey: 'value',
            itemIsEnabledKey: 'enabled',
            isEnabled: YES,
            layoutDirection: SC.LAYOUT_HORIZONTAL
          })
        }),

        applyOrCancelCtl: SC.View.design(SC.FlowedLayout, {
          layoutDirection: SC.LAYOUT_VERTICAL,
          defaultFlowSpacing: 5,
          align: SC.ALIGN_CENTER,
          layout: {
            width: kControlWidth,
            height: 24,
          },
          childViews: 'cancel apply'.w(),
          cancel: SC.ButtonView.design({
            layout: {  width: 90 },
            titleMinWidth: 0,
            title: 'DG.AttrFormView.cancelBtnTitle',  // "Cancel"
            target: null,
            action: 'close',
            toolTip: 'DG.AttrFormView.cancelBtnTooltip',  // "Dismiss the dialog without making any changes"
            localize: true,
            isCancel: true
          }),
          apply: SC.ButtonView.design({
            layout: { width: 90 },
            titleMinWidth: 0,
            title: 'DG.CaseTable.insertCasesDialog.applyBtnTitle', // "Insert Cases"
            target: null,
            action: 'insertCases',
            toolTip: 'DG.CaseTable.insertCasesDialog.applyBtnTooltip',
            localize: true,
            isDefault: true
          })
        })
      }),

      insertCases: function () {
        var caseTableView = this.get('caseTableView'),
            caseCount = Number(this.getPath('contentView.countCtl.controlView.value')),
            beforeAfter = this.getPath('contentView.beforeAfterCtl.controlView.value');
        if (!caseTableView || !caseCount || !(caseCount > 0)) return; // jshint ignore: line

        caseTableView.doInsertCases(caseCount, beforeAfter === 'after');
        this.close();
      },
      close: function () {
        DG.log('Closing Insert Cases Dialog');
        this.remove();
        this.destroy();
      },
      init: function () {
        arguments.callee.base.apply(this,arguments);
        var initialCaseCount = this.get('initialCaseCount') || 1;
        this.setPath('contentView.countCtl.controlView.value', initialCaseCount);
        this.setPath('contentView.applyOrCancelCtl.cancel.target', this);
        this.setPath('contentView.applyOrCancelCtl.apply.target', this);
      }
    };
  }())
);

/* >>>>>>>>>> BEGIN source/components/data_interactive/data_interactive_model.js */
// ==========================================================================
//  
//  Author:   jsandoe
//
//  Copyright (c) 2016 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
/** @class  DG.DataInteractiveModel - The model for a slider. Holds onto a global value.

 @extends SC.Object
 */
DG.DataInteractiveModel = SC.Object.extend(/** @scope DG.DataInteractiveModel.prototype */ {

  /**
   * @type {String}
   */
  name: null,

  /**
   * @type {String}
   */
  title: null,

  /**
   * @type {String}
   */
  version: null,

  /**
   * @type {{width:number,height:number}}
   */
  dimensions: null,

  /**
   * @type {boolean}
   */
  preventBringToFront: false,

  /**
   * @type {boolean}
   */
  preventDataContextReorg: false,

  /**
   * @type {boolean}
   */
  preventTopLevelReorg: false,

  /**
   * @type {boolean}
   */
  preventAttributeDeletion: false,

  /**
   * @type {boolean}
   */
  allowEmptyAttributeDeletion: false,

  /**
   * @type {boolean}
   */
  externalUndoAvailable: false,

  /**
   * @type {boolean}
   */
  standaloneUndoModeAvalable: false,

  /**
   * @type {boolean}
   */
  subscribeToDocuments: false,

  /**
   * @type {Object}
   */
  savedState: null,

  init: function () {
    arguments.callee.base.apply(this,arguments);
  }

});

/* >>>>>>>>>> BEGIN source/components/data_interactive/data_interactive_phone_handler.js */
// ==========================================================================
//                          DG.DataInteractivePhoneHandler
//
//  Copyright (c) 2016 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

// noinspection SpellCheckingInspection
function serializeItem(dataSet, item) {
  if (!item) {
    return;
  }
  var ret = {};
  var values = {};
  var baseCollectionID = dataSet.getPath('baseCollection.id');
  var attrs = dataSet.get('attrs');
  attrs.forEach(function (attr) {
    var value = item.getValue(attr.id, baseCollectionID);
    values[attr.name] = value != null ? value : "";
  });
  ret.values = values;
  ret.id = item.id;
  return ret;
}

/** @class
 *
 * The DataInteractivePhoneHandler handles inbound messages for the Data Interactive
 * API.
 *
 * @extends SC.Object
 */
DG.DataInteractivePhoneHandler = SC.Object.extend(
    /** @scope DG.DataInteractivePhoneHandler.prototype */ {

      /**
       * @type {DG.GameController}
       */
      controller: null,

      modelProps: ['version', 'dimensions',
                  'preventBringToFront', 'preventDataContextReorg', 'preventTopLevelReorg',
                  'preventAttributeDeletion', 'allowEmptyAttributeDeletion',
                  'respectEditableItemAttribute', 'subscribeToDocuments'],

      /**
       * We need to be able to set title.
       */
      view: function() {
        return this.getPath('controller.view');
      }.property(),

      // Not working in at least one circumstance having to do with interactiveFrame:update
      // idBinding: SC.Binding.oneWay('*controller.model.id'),
      id: function() {
        return this.getPath('controller.model.id');
      }.property(),

      /**
       * Handles communication over PostMessage interface.
       *
       * Set up by creator.
       *
       * @property {iframePhone.IframePhoneRpcEndpoint}
       */
      rpcEndpoint: null,

      /**
       * Whether activity has been detected on this channel.
       * @property {boolean}
       */
      connected: false,

      /**
       * Initiates a message to the Data Interactive Plugin from codap with
       * optional callback
       *
       * @param message {Object}
       * @param callback {Function} (optional)
       */
      sendMessage: function (message, callback) {
        this.rpcEndpoint.call(message, callback);
      },

      handlerMap: null,

      /**
       Initialization method
       */
      init: function () {
        arguments.callee.base.apply(this,arguments);

        this.handlerMap = {
          attribute: this.handleAttribute,
          attributeLocation: this.handleAttributeLocation,
          attributeList: this.handleAttributeList,
          'case': this.handleCase,
          allCases: this.handleAllCases,
          caseByIndex: this.handleCaseByIndexOrID,
          caseByID: this.handleCaseByIndexOrID,
          caseCount: this.handleCaseCount,
          caseSearch: this.handleCaseSearch,
          caseFormulaSearch: this.handleCaseFormulaSearch,
          collection: this.handleCollection,
          collectionList: this.handleCollectionList,
          component: this.handleComponent,
          componentList: this.handleComponentList,
          dataContext: this.handleDataContext,
          dataContextFromURL: this.handleDataContextFromURL,
          dataContextList: this.handleDataContextList,
          document: this.handleDocument,
          global: this.handleGlobal,
          globalList: this.handleGlobalList,
          configuration: this.handleConfiguration,
          configurationList: this.handleConfigurationList,
          item: this.handleItems,
          itemByID: this.handleItemByID,
          itemByCaseID: this.handleItemByCaseID,
          itemCount: this.handleItemCount,
          itemSearch: this.handleItemSearch,
          interactiveFrame: this.handleInteractiveFrame,
          logMessage: this.handleLogMessage,
          logMessageMonitor: this.handleLogMessageMonitor,
          selectionList: this.handleSelectionList,
          undoChangeNotice: this.handleUndoChangeNotice,
          formulaEngine: this.handleFormulaEngine,
        };
      },

      /**
       * Break loops
       */
      destroy: function () {
        if (this.rpcEndpoint) {
          this.rpcEndpoint.disconnect();
        }

        // filter out this instance from the log monitor list
        var self = this;
        var dataInteractiveLogMonitor = DG.currDocumentController().dataInteractiveLogMonitor;
        dataInteractiveLogMonitor.set("logMonitors", dataInteractiveLogMonitor.get("logMonitors").filter(function (logMonitor) {
          return logMonitor.iPhoneHandler !== self;
        }));

        return arguments.callee.base.apply(this,arguments);
      },


      /**
       * CODAP's request of DI state (for saving)
       * @param {function} callback
       */
      requestDataInteractiveState: function (callback) {
        this.sendMessage({
          action: 'get',
          resource: 'interactiveState'
        }, callback);
      },

      /**
       * A resource selector identifies a CODAP resource. It is either a group
       * resource or an individual resource. This routine parses a resource
       * selector into its component parts and builds an equivalent object.
       *
       *   * Base resources: [interactiveFrame, logMessage]
       *   * Doc resources: [dataContext, component, global]
       *   * DataContext resources: [collection, attributes]
       *   * Collection resources: [case]
       *
       *   Some examples of resource selectors:
       *    * "dataContext[DataCard]", or
       *    * "dataContext[DataCard2].collection[Measurements].attribute"
       *
       *   These would parse to objects, respectively:
       *    * {dataContext: 'DataCard', type: 'dataContext'}
       *    * {dataContext: 'DataCard2', collection: 'Measurements', attribute: null, type: 'attribute'}
       *
       * @param iResource {string}
       * @returns {{}}
       */
      parseResourceSelector: function (iResource) {
        // selects phrases like 'aaaa[bbbb]' or 'aaaa' in a larger context
        // var selectorRE = /(([\w]+)(?:\[\s*([#\w][^\]]*)\s*\])?)/g;
        var selectorRE = /(([\w]+)(?:\[\s*([^\]]+)\s*])?)/g;
        // selects complete strings matching the pattern 'aaaa[bbbb]' or 'aaaa'
        // var clauseRE =   /^([\w]+)(?:\[\s*([^\]][^\]]*)\s*\])?$/;
        var clauseRE =   /^([\w]+)(?:\[\s*([^\]]+)\s*])?$/;
        var result = {};
        var selectors = iResource.match(selectorRE);
        result.type = '';
        selectors.forEach(function (selector) {
          var resourceType, resourceName;
          var match = clauseRE.exec(selector);
          resourceType = match[1];
          resourceName = match[2];
          result[resourceType] = resourceName || "";
          result.type = resourceType;
        });

        return result;
      },

      /**
       *
       * @param {object} resourceSelector Return value from parseResourceSelector
       * @param {string} action           Action name: get, create, update, delete, notify
       * @returns {{interactiveFrame: DG.DataInteractivePhoneHandler}}
       */
      resolveResources: function (resourceSelector, action) {
        function resolveContext(selector, myContext) {
          var document = DG.currDocumentController();
          var context;

          if (SC.empty(selector)) {
            return;
          }
          if (selector === '#default') {
            context = myContext;
          } else {
            context = document.getContextByName(resourceSelector.dataContext) ||
                (!isNaN(resourceSelector.dataContext) &&
                    document.getContextByID(resourceSelector.dataContext)) || null;
          }
          return context;
        }

        var result = { interactiveFrame: this.get('controller')};
        var dataContext;
        var collection;
        var attrName, attrKey;
        var dataSet;

        if (['interactiveFrame',
              'logMessage',
              'logMessageMonitor',
              'dataContextList',
              'undoChangeNotice',
              'undoableActionPerformed',
              'component',
              'componentList',
              'document',
              'global',
              'globalList',
              'configuration',
              'configurationList',
              'formulaEngine'].indexOf(resourceSelector.type) < 0) {
          // if no data context provided, and we are not creating one, the
          // default data context is implied
          if (!(resourceSelector.dataContext) ) {
            if (action !== 'create' ||
                (resourceSelector.type !== 'dataContext' &&
                resourceSelector.type !== 'dataContextFromURL')) {
              resourceSelector.dataContext = '#default';
            }
            // set a flag in the result, so we can recognize this context as special.
            result.isDefaultDataContext = true;
          }
          result.dataContext = resolveContext(resourceSelector.dataContext,
              this.getPath('controller.context'));
        }

        dataContext = result.dataContext;

        if (resourceSelector.component) {
          result.component = DG.currDocumentController().getComponentByName(resourceSelector.component) ||
              (!isNaN(resourceSelector.component) &&
                  DG.currDocumentController().getComponentByID(resourceSelector.component));
        }

        if (resourceSelector.configuration) {
          result.configuration = {name: resourceSelector.configuration};
        }

        if (resourceSelector.global) {
          result.global = DG.globalsController.getGlobalValueByName(resourceSelector.global) ||
              DG.globalsController.getGlobalValueByID(resourceSelector.global);
        }

        if (resourceSelector.dataContextList != null) {
          result.dataContextList = DG.currDocumentController()
            .get('contexts')
            .map(function (context) {
              return {
                name: context.get('name'),
                guid: context.get('id'),
                title: context.get('title')
              };
            });
        }

        if (resourceSelector.collection) {
          result.collection = dataContext &&
              (dataContext.getCollectionByName(resourceSelector.collection) ||
              (!isNaN(resourceSelector.collection) &&
                  dataContext.getCollectionByID(resourceSelector.collection)));
        }

        collection = result.collection;

        if (resourceSelector.attribute || resourceSelector.attributeLocation) {
          attrKey = resourceSelector.attribute?'attribute':'attributeLocation';
          attrName = resourceSelector[attrKey];
          result[attrKey] = (
            (
              dataContext && (
                  dataContext.getAttributeByName(attrName) ||
                  dataContext.getAttributeByName(dataContext.canonicalizeName(attrName))
              )
            ) ||
            (
              !isNaN(attrName) &&
              collection && collection.getAttributeByID(attrName)
            )
          );
        }

        if (resourceSelector.caseByID) {
          result.caseByID = dataContext.getCaseByID(resourceSelector.caseByID);
        }

        if (resourceSelector.caseByIndex) {
          result.caseByIndex = collection && collection.getCaseAt(Number(resourceSelector.caseByIndex));
        }

        if (resourceSelector.caseSearch) {
          result.caseSearch = collection && collection.searchCases(resourceSelector.caseSearch);
        }

        if (resourceSelector.caseFormulaSearch) {
          result.caseFormulaSearch = collection && collection.searchCasesByFormula(resourceSelector.caseFormulaSearch);
        }

        if (resourceSelector.item) {
          dataSet = result.dataContext && result.dataContext.get('dataSet');
          result.item = dataSet && serializeItem(dataSet,
              dataSet.getDataItem(Number(resourceSelector.item)));
        }

        if (resourceSelector.itemByID) {
          dataSet = result.dataContext && result.dataContext.get('dataSet');
          result.itemByID = dataSet &&
              serializeItem(dataSet,dataSet.getDataItemByID(resourceSelector.itemByID));
        }

        if (resourceSelector.itemCount != null) {
          result.itemCount = result.dataContext && result.dataContext.get('itemCount');
        }

        if (resourceSelector.itemSearch) {
          dataSet = result.dataContext && result.dataContext.get('dataSet');
          result.itemSearch = dataSet && dataSet.getItemsBySearch(
              resourceSelector.itemSearch) ;
        }

        if (resourceSelector.itemByCaseID) {
          var myCase = result.dataContext && result.dataContext.getCaseByID(resourceSelector.itemByCaseID);
          dataSet = result.dataContext && result.dataContext.get('dataSet');
          result.itemByCaseID = dataSet && myCase && serializeItem(dataSet, myCase.get('item'));
        }

        DG.ObjectMap.forEach(resourceSelector, function (key, value) {
          // Make sure we got values for every non-terminal selector.
          if (SC.none(result[key]) && (key !== 'type') && (key !== resourceSelector.type)) {
            throw (new Error('Unable to resolve %@: %@'.loc(key, value)));
            //DG.log('Unable to resolve %@: %@'.loc(key, value));
          }
        });
        return result;
      },

      /**
       * Certain properties of the values object may need to be modified; e.g. attribute
       * names will need to conform to the conventions established by the API.
       * @param iDataContext {DG.DataContext}
       * @param iValues {Object}
       */
      validateValues: function(iDataContext, iValues) {
        if( SC.none( iValues))
          return;
        if( iValues.type === 'graph') {
          ['xAttributeName', 'yAttributeName', 'y2AttributeName', 'legendAttributeName'].forEach( function( iPropName) {
            if( !SC.none(iDataContext) && !SC.none( iValues[iPropName])) {
              iValues[ iPropName] = iDataContext.canonicalizeName( iValues[ iPropName] + ' ');
            }
          });
        }
        return iValues;
      },

      filterResultValues: function (resultValues) {
        var maxLevels = 10;
        function renameKeys (obj) {
          if (obj.guid != null) {
            obj.id = obj.guid;
          }
          return obj;
        }
        function visit(obj, level) {
          var k,v;
          if ((level < 0) ||
              (!obj) ||
              (typeof obj === 'string') ||
              (typeof obj === 'number') ||
              (typeof obj === 'boolean')) {
            return;
          }
          if (Array.isArray(obj))  {
            obj.forEach(function (o) {
              visit(o, level - 1);
            });
          } else if (typeof obj === 'object') {
            for (k in obj) {
              if (obj.hasOwnProperty(k)) {
                v = obj[k];
                visit(v, level - 1);
              }
            }
            renameKeys(obj);
          }
        }
        visit(resultValues, maxLevels);
      },
      handleOneCommand: function (iCmd) {
        var result = {success: false};
        try {
          // parse the resource name into constituent parts
          var selectorMap = iCmd.resource && this.parseResourceSelector(
              iCmd.resource);

          // resolve identified resources
          var resourceMap = this.resolveResources(selectorMap, iCmd.action);

          var action = iCmd.action;
          var type = selectorMap && selectorMap.type;
          var values = this.validateValues(resourceMap.dataContext,
              iCmd.values);
          var metadata = iCmd.meta;

          var handler = type && this.handlerMap[type];

          if (handler) {
            if (handler[action]) {
              // SC.run(function () {
              try {
                result = handler[action].call(this, resourceMap, values,
                    metadata) || {success: false};
                if (result.values) {
                  this.filterResultValues(result.values);
                }
              } catch (ex) {
                DG.logWarn(ex);
                result.values = {error: ex.toString()};
              }
              // }.bind(this));
            } else {
              result.values = {
                error: 'Unsupported action: %@/%@'.loc(action, type)
              };

            }
          } else {
            DG.logWarn("Unknown message type: " + type);
            result.values = {error: "Unknown message type: " + type};
          }
        } catch (ex) {
          DG.logWarn(ex);
          result.values = {error: ex.toString()};
        }
        return result;
      },
      /**
       * Respond to requests from a Data Interactive.
       *
       * Parses the request, instantiates any named resources, finds a handler
       * and invokes it.
       *
       * @param iMessage See documentation on the github wiki: TODO
       * @param iCallback
       */
      doCommand: function (iMessage, iCallback) {
        this.setIfChanged('connected', true);
        DG.log('Handle Request: ' + JSON.stringify(iMessage));
        var result = {success: false};
        SC.run(function () {

          if (!SC.none(iMessage)) {
            if (Array.isArray(iMessage)) {
              result = iMessage.map(function (cmd) {
                return this.handleOneCommand(cmd);
              }.bind(this));
            } else {
              result = this.handleOneCommand(iMessage);
            }
          }
        }.bind(this));
        try {
          DG.log('Returning response: ' + JSON.stringify(result));
          iCallback(result);
        } catch (ex) {
          DG.logWarn(ex);
          iCallback({success: false, values: {error: 'bad reply: ' + ex.toString()}});
        }
      },

      /**
       *     {{
       *      action: 'update'|'get'|'delete'
       *      what: {type: 'interactiveFrame'}
       *      values: { {title: {String}, version: {String}, dimensions: { width: {Number}, height: {Number} }}}
       *     }}
       * @return {object} Object should include status and values.
       */
      handleInteractiveFrame: {
        update: function (iResources, iValues) {
          var diModel = iResources.interactiveFrame.getPath('model.content');
          var diComponent = DG.currDocumentController().getComponentByID(this.get('id'));
          var diView = this.get('view');
          var title = iValues.title || iValues.name;
          var userSetTitle = iResources.interactiveFrame.getPath('model.userSetTitle');
          DG.assert(diModel, 'DataInteractiveModel  exists' );
          DG.assert(diModel.constructor === DG.DataInteractiveModel, 'model content is DataInteractiveModel');
          if (iValues) {
            if (!SC.none(title) && !userSetTitle) {
              diModel.set('title', title);
            }
            if (iValues.cannotClose != null) {
              diComponent.set('cannotClose', iValues.cannotClose);
            }
            if (iValues.isResizable != null) {
              diComponent.set('isResizable', iValues.isResizable);
            }

            var props = this.get('modelProps');
            props.forEach(function(prop) {
              if (iValues[prop] != null) {
                diModel.set(prop, iValues[prop]);
              }
            });
          }
          if (DG.STANDALONE_MODE && title && DG.isStandaloneComponent(title, diComponent.get('type'))) {
            DG.log('isStandalone component: ' + title);
            diView.makeStandalone();
            // if( DG.KEEP_IN_BOUNDS_PREF) {
            //
            // }
          }

          return {
            success: true
          };
        },

        get: function (iResources) {
          var diModel = iResources.interactiveFrame.getPath('model.content');
          var componentStorage = iResources.interactiveFrame.getPath('model.componentStorage');
          DG.assert(diModel, 'DataInteractiveModel  exists' );
          DG.assert(diModel.constructor === DG.DataInteractiveModel, 'model content is DataInteractiveModel');

          var tReturnValues = {};
          tReturnValues.id = this.get('id');
          tReturnValues.title = diModel.get('title');

          var props = this.get('modelProps');
          props.forEach(function(prop) {
            tReturnValues[prop] = diModel.get(prop);
          });

          // if embedded mode, set externalUndoAvailable, if standalone mode,
          // set standaloneUndoModeAvailable.
          tReturnValues.externalUndoAvailable = !DG.STANDALONE_MODE;
          tReturnValues.standaloneUndoModeAvailable = !!DG.STANDALONE_MODE;
          tReturnValues.run_remote_endpoint = DG.run_remote_endpoint || 'unknown';
          if (componentStorage) {
            DG.log('Sending data interactive, %@, state: %@'.loc(
                tReturnValues.title, JSON.stringify(componentStorage.savedGameState)));
            tReturnValues.savedState = componentStorage.savedGameState;
          }
          return {
            success: true,
            values: tReturnValues
          };
        },

        notify: function (iResources, iValues) {
          function parseDataURL(dataUri) {
            var typeToExtensionMap = {'image/png': 'png', 'image/gif': 'gif'};
            var dataUriRE = /^data:([^,]*),(.*$)/;
            var matches = dataUriRE.exec(dataUri);
            var mediaType, content, mimeType, extension;
            if (matches) {
              mediaType = matches[1];
              content = matches[2];
              mimeType = Object.keys(typeToExtensionMap).find(function (key) {
                return mediaType.startsWith(key);
              });
              if (mimeType) {
                extension = typeToExtensionMap[mimeType];
              }
            }
            return {
              mediaType: mediaType,
              content: content,
              mimeType: mimeType,
              extension: extension
            };
          }
          function handleRequest (request, props) {
            var kTimeout = 60000;// one minute
            var cursorMode = false;
            if (request === 'openGuideConfiguration') {
              DG.currDocumentController().configureGuide();
            }
            else if (request === 'indicateBusy') {
              cursorMode = (props.cursorMode && props.cursorMode !== 'false');
              DG.splash.showSplash(cursorMode, cursorMode?kTimeout:undefined);
            }
            else if (request === 'indicateIdle') {
              DG.splash.hideSplash();
            }
            return {success: true};
          }
          var result = {success: true};
          var imageData;
          if (iValues.dirty) {
            DG.dirtyCurrentDocument(this.controller, true);
          }
          if (iValues.image) {
            imageData = parseDataURL(iValues.image);
            if (imageData) {
              DG.exportFile(imageData.content, imageData.extension, imageData.mimeType);
            }
            else {
              result = {
                success: false,
                values: {
                  error: "Failed to parse image data uri: " + iValues.image.slice(0, 20)
                }
              };
            }
          }
          if (iValues.request) {
            result = handleRequest(iValues.request, iValues);
          }
          return result;
        },
        'delete': function (/*iResource*/) {
          DG.closeComponent(this.get('id'));
          return {success: true};
        }
      },

      /**
       * handles operations on dataContext.
       *
       * Notes:
       *
       *  * At this point only one data context for each data interactive is permitted.
       *  * Updates permit modification of top-level api properties only. That is
       *    to say, not collections. Use collection API.
       *
       * @param  iMessage {object}
       *     {{
       *      action: 'create'|'update'|'get'|'delete'
       *      what: {{type: 'context'}}
       *      values: {{name: {string}, title: {string}, description: {string}, collections: [{Object}] }}
       *     }}
       *
       */
      handleDataContext: {
        create: function (iResources, iValues) {
          var tFoundContext = DG.currDocumentController().getContextByName(iValues.name),
              status = true,
              context;
          if( tFoundContext) {
            context = tFoundContext;
          }
          else {
            var createSpec = DG.copy(iValues),
                resultValues = DG.clone(iValues);
            // we don't want to create the collections yet
            delete createSpec.collections;
            context = DG.currDocumentController().createNewDataContext(createSpec);
            if (iResources.isDefaultDataContext) {
              this.setPath('controller.context', context);
            }
            // create the collections
            if (resultValues.collections) {
              resultValues.collections.forEach(function (collectionSpec) {
                var collectionClient,
                    parentCollectionClient,
                    error = false;

                // map requested names to valid names
                if (collectionSpec.attrs) {
                  collectionSpec.attrs.forEach(function (attr) {
                    // original name and new name will be returned to client
                    attr.clientName = attr.name;
                    // We add a space as a kludge. For historical reasons, when creating
                    // attributes through other paths we interpret parens at the end
                    // of a name as the unit, so we strip it from the name. Plugins
                    // can set the unit in the request JSON. Adding a space will
                    // suppress the stripping of the parens. The space will be
                    // trimmed later.
                    attr.name = context.canonicalizeName(attr.name + ' ');
                  });
                }

                createSpec = DG.clone(collectionSpec);

                if (createSpec.parent) {
                  parentCollectionClient = context.getCollectionByName(createSpec.parent);

                  if (parentCollectionClient) {
                    createSpec.parent = parentCollectionClient.collection;
                  } else {
                    DG.log('Attempt to create collection "%@": Unknown parent: "%@"'
                        .loc(createSpec.name, createSpec.parent));
                    error = true;
                  }
                }
                if (!error) {
                  collectionClient = context.createCollection(createSpec);

                  // return id for created collection
                  collectionSpec.id = collectionClient && collectionClient.get('id');

                  if (collectionClient && collectionSpec.attrs) {
                    // return id for each created attribute
                    collectionSpec.attrs.forEach(function (attrSpec) {
                      var attr = collectionClient.getAttributeByName(attrSpec.name);
                      attrSpec.id = attr && attr.get('id');
                    });
                  }
                }
                status = status && !SC.none(collectionClient);
              });
            }
          }
          return {
            success: status,
            values: {
              name: context.get('name'),
              id: context.get('id'),
              title: context.get('title')
            }
          };
        },

        update: function (iResources, iValues) {
          return DG.appController.documentArchiver.updateDataContext(iResources, iValues);
        },

        get: function (iResources, iValues) {
          var context = iResources.dataContext;
          var values;
          if (context) {
            values = context.get('model').toArchive(true, true/*omit cases*/);
          }
          return {
            success: !SC.none(values),
            values: values
          };
        },

        'delete': function (iResources, iValues) {
          var context = iResources.dataContext;
          var documentController = DG.currDocumentController();
          if (context) {
            documentController.destroyDataContext(context.get('id'));
            return {
              success: true
            };
          } else {
            return {
              success: false,
              values: {
                error: 'Could not find dataContext'
              }
            };
          }
        },
        /**
         *
         * @param iResources
         * @param iValues {{
         *       request:'setAside'|'restoreSetasides',
         *       caseIDs: [number]
         *     }}
         * @return {{success: boolean, values: object}}
         */
        notify: function (iResources, iValues) {
          var context = iResources.dataContext;
          var request = iValues && iValues.request;
          var caseIDs = iValues && iValues.caseIDs;
          var success = true;
          var error;
          var changeResult;
          var cases;
          if (request === 'setAside') {
            if (!caseIDs) {
              success = false;
              error = 'Bad request';
            }
            else {
              cases = caseIDs.map(function (caseID){
                var myCase = context.getCaseByID(caseID);
                if (!myCase) {
                  DG.log('Attempt to set aside missing case: ' + caseID);
                }
                return myCase;
              }).filter(function (myCase) {return !!myCase;});
              changeResult = context.applyChange({
                operation: 'deleteCases',
                setAside: true,
                cases: cases,
                requester: this.get('id')
              });
              success = changeResult.success;
              if (!changeResult.success) {
                error = 'Request failed';
              }
            }
          }
          else if (request === 'restoreSetasides') {
            context.restoreSetAsideCases();
          }
          else {
            success = false;
            error = 'unknown request: ' + request;
          }
          return {success: success, values: {error: error}};
        }
      },

      /**
       * handles creation of a dataContext by reading in a URL.
       *
       * @param  iMessage {object}
       *     {{
       *      action: 'create'
       *      resource: 'dataContextFromURL'
       *      values: {URL: {string}}
       *     }}
       *
       */
      handleDataContextFromURL: {
        create: function (iResources, iValues) {
          var tURL;
          var status = true;
          if (iValues.URL) {
            tURL = iValues.URL;
            delete iValues.URL;
            DG.appController.importTextFromUrl( tURL, false /* Don't show case table */);
          }
          return {
            success: status
          };
        }
      },

      /**
       * handles list operations on dataContext.
       *
       * Notes:
       *
       *  * At this point only one data context for each data interactive is permitted.
       *  * Updates permit modification of top-level api properties only. That is
       *    to say, not collections. Use collection API.
       *
       * @param  iMessage {object}
       *     {{
       *      action: 'get'
       *      what: {{type: 'context'}}
       *      values: {{name: {string}, title: {string}, description: {string}, collections: [{Object}] }}
       *     }}
       *
       */
      handleDataContextList: {
        get: function (iResources) {
          var success = (iResources.dataContextList != null);
          return success ? { success: true, values: iResources.dataContextList } : { success: false };
        }
      },

      /**
       * handles operations on collections.
       *
       * Notes:
       *   * Parent collection must be created before the child collection.
       *   * Parent collection can have at most one child collection.
       *
       * @param  iMessage {object}
       *     {{
       *      action: 'create'|'update'|'get'|'delete'
       *      what: {{type: 'collection', context: {String}, collection: {String}}
       *      values: {{
       *        name: {string},
       *        title: {string},
       *        description: {string},
       *        parent: {string},
       *        attribute: [{Object}],
       *        labels: [{Object}] }}
       *     }}
       *
       */
      handleCollection: {
        get: function (iResources) {
          if (!iResources.collection) {
            return {success: false, values: {error: 'Collection not found'}};
          }
          var model = iResources.collection.get('collection');
          var values = model.toArchive(true/*excludeCases*/);
          return {
            success: true,
            values: values
          };
        },
        create: function (iResources, iValues) {
          return DG.appController.documentArchiver.createCollection(iResources, iValues, this.get('id'));
        },
        update: function (iResources, iValues) {
          if (!iResources.collection) {
            return {success: false, values: {error: 'Collection not found'}};
          }

          var context = iResources.dataContext;
          var change = {
            operation: 'updateCollection',
            collection: iResources.collection,
            properties: iValues,
            requester: this.get('id')
          };
          var changeResult = context.applyChange(change);
          var success = (changeResult && changeResult.success);
          return {
            success: success,
          };
        },
        'delete': function (iResources) {
          var resp = DG.appController.documentArchiver.deleteCollection(iResources, this.get('id'));
          if (resp && resp.collections && resp.collections.length) {
            return { success: true, values: {collections: [resp.collections[0].get('id')]}};
          }
          else {
            return {success: false, values: {error: 'Delete failed'}};
          }
        }
      },

      /**
       * handles operations on collection Lists.
       *
       * Notes:
       *   * List is in order of parentage, highest ancestor first, ultimate
       *     descendant last.
       *
       * @param  iMessage {object}
       *     {{
       *      action: 'get'
       *      what: {type: 'collection', context: {String}}
       *      }}
       * @return {object}
       *   {{
       *      success: {boolean}
       *      values: {
       *        name: {string},
       *        title: {string},
       *        guid: {number}
       *      }
       *     }}
       *
       */
      handleCollectionList: {
        get: function (iResources) {
          var context = iResources.dataContext;
          var values = context.get('collections').map(function (collection) {
            return {
              name: collection.get('name'),
              guid: collection.get('id'),
              title: collection.get('title')
            };
          });
          return {
            success: true,
            values: values
          };
        }
      },

      /**
       * handles operations on attributes.
       *
       * @param  iMessage {object}
       *     {{
       *        action: 'create'|'update'|'get'|'delete'
       *        what: {{type: 'attribute', context: {name}, collection: {string}, attribute: {string}}
       *        values: {[object]|object}
       *      }}
       *
       */
      handleAttribute: (function() {

      return {
        get: function (iResources) {
          var attribute = iResources.attribute;
          var values;
          if (!attribute) {
            return {success: false, values: {error: 'Attribute not found'}};
          }
          values = attribute.toArchive();
          return {
            success: true,
            values: values
          };
        },
        create: function (iResources, iValues, iMetadata) {
          // If we're not given any values, then abort. This is to avoid
          // spurious case table scrolling
          if( SC.isArray(iValues) && iValues.length === 0)
            return {success: true };
          return DG.appController.documentArchiver.createAttribute(iResources, iValues, iMetadata, this.get('id'));
        },
        update: function (iResources, iValues, iMetadata) {
          return DG.appController.documentArchiver.updateAttribute(iResources, iValues, iMetadata);
        },
        'delete': function (iResources, iValues, iMetadata) {
          var iDataContext = iResources.dataContext;
          var attr = iResources.attribute;
          var iAttrID = attr && attr.get('id');
          var tCollectionClient = iResources.collection;
          var response, change;
          if ((tCollectionClient.get('attrsController').get('length') === 1) &&
              (iDataContext.get('collections').length !== 1) &&
              (tCollectionClient.getAttributeByID(iAttrID))) {
            response = iDataContext.applyChange( {
              operation: 'deleteCollection', collection: tCollectionClient
            });
          } else {
            change = {
                operation: 'deleteAttributes',
                collection: tCollectionClient,
                attrs: [{id: iAttrID, attribute: attr}],
                requester: this.get('id')
              };
            if (iMetadata && iMetadata.dirtyDocument === false) {
              change.dirtyDocument = false;
            }
            response = iDataContext.applyChange( change);
          }
          iDataContext.set('flexibleGroupingChangeFlag', true);
          var success = !!(response && response.success);
          return {
            success: success,
          };
        }
      }; }()),

      handleAttributeLocation: {
        /*
         * Binds an attribute to a new collection in the data set. This
         * is equivalent to the data context attributeMove action.
         */
        update: function (iResources, iValues, iMetadata) {
          return DG.appController.documentArchiver.updateAttributeLocation(iResources, iValues, iMetadata);
        }
      },
      handleAttributeList: {
        get: function (iResources) {
          var collection = iResources.collection;
          var values = [];
          if (!collection) {
            return {success: false, values: {error: 'Collection not found'}};
          }

          collection.forEachAttribute(function (attr) {
            var value = {
              id: attr.get('id'),
              name: attr.get('name'),
              title: attr.get('title')
            };
            values.push(value);
          });
          return {
            success: true,
            values: values
          };
        }
      },
      handleAttributeSort: {
        update: function (iResources, iValues) {
          return DG.appController.documentArchiver.updateDataContext(iResources, iValues);
        }
      },
      handleCase: {
        create: function (iResources, iValues) {
          return DG.appController.documentArchiver.createCases(iResources, iValues, this.get('id'));
        },
        update: function (iResources, iValues) {
          var context = iResources.dataContext;
          var collection = iResources.collection;
          var result = {success: false};
          var cases = [];
          var values = [];

          iValues.forEach(function (entry) {
            var caseID = entry.id;
            var tCase = context.getCaseByID(caseID);
            if (tCase) {
              cases.push(tCase);
              values.push(entry.values);
            }
          });

          var changeResult;
          if (collection && cases.length) {
            changeResult = context.applyChange({
              operation: 'updateCases',
              collection: collection,
              cases: cases,
              values: values,
              requester: this.get('id')
            });
            result = changeResult;
          }
          return result;
        }
      },

      handleAllCases: {
        get: function (iResources) {
          var context = iResources.dataContext;
          var collection = iResources.collection;
          if (!context || !collection) {
            return {
              success: false
            };
          }

          var serializeCase = function (iCase) {
            var caseValues = {};
            collection.forEachAttribute(function (attr) {
              caseValues[attr.name] = iCase.getValue(attr.id);
            });
            return {
              'case': {
                id: iCase.id,
                parent: (iCase.parent && iCase.parent.id),
                children: iCase.children.map(function (child) {return child.id;}),
                values: caseValues
              },
              caseIndex: collection.getCaseIndexByID(iCase.get('id'))
            };
          }.bind(this);

          return {
            success: true,
            values: {
              collection: {
                name: collection.get('name'),
                id: collection.get('id')
              },
              cases: collection.get('casesController').map(serializeCase)
            }
          };
        },

        'delete': function (iResources) {
          var context = iResources.dataContext;
          var success = false;
          var changeResult, cases;
          if (context) {
            cases = context.get('allCases');
            changeResult = context.applyChange({
              operation: 'deleteCases',
              cases: cases,
              values: [],
              requester: this.get('id')
            });
            success = (changeResult && changeResult.success);
          }
          return {
            success: success
          };
        }
      },

      /**
       * Utility function to create a serializable representation of the case
       * for return to the data interactive
       * @param iCollection
       * @param iCase
       * @returns {{id: *, guid: *, parent: *, values: {}}}
       */
      makeSerializableCase: function (iCollection, iCase) {
        var values = {};
        iCollection.forEachAttribute(function (attr) {
          values[attr.name] = iCase.getValue(attr.id);
        });
        return  {
          id: iCase.id,
          parent: (iCase.parent && iCase.parent.id),
          collection: {
            name: iCollection.get('name'),
            id: iCollection.get('id')
          },
          values: values
        };
      },

      handleCaseByIndexOrID: {
        get: function (iResources) {
          function getCollectionClientFromCase(myCase, dataContext) {
            var collection = myCase.get('collection');
            var id = collection.get('id');
            return dataContext.getCollectionByID(id);
          }
          var dataContext = iResources.dataContext;
          var myCase = iResources.caseByIndex || iResources.caseByID;
          var collection, values;
          if (myCase) {
            collection = iResources.collection || getCollectionClientFromCase(myCase, dataContext);
            values = {
              'case': this.makeSerializableCase(collection, myCase),
              caseIndex: collection.getCaseIndexByID(myCase.get('id'))
            };
            values['case'].children = myCase.children.map(function (child) {return child.id;});
          }
          return {
            success: !SC.none(values),
            values: values
          };
        },
        notify: function (iResources, iValues) {
          if (!iResources.collection) {
            return {success: false, values: {error: 'Collection not found'}};
          }
          if (!(iResources.caseByID || iResources.caseByIndex)) {
            return {success: false, values: {error: 'Case not found'}};
          }

          var context = iResources.dataContext;
          var collection = iResources.collection;
          var theCase = iResources.caseByIndex || iResources.caseByID;
          var success = false;
          var changeResult;
          if (collection && theCase && iValues && iValues.caseOrder) {
            changeResult = context.applyChange({
              operation: 'moveCases',
              collection: collection,
              cases: [theCase],
              caseOrder: iValues.caseOrder,
              requester: this.get('id')
            });
            success = (changeResult && changeResult.success);
          }
          return {
            success: success
          };
        },
        update: function (iResources, iValues) {
          if (!iResources.collection) {
            return {success: false, values: {error: 'Collection not found'}};
          }
          if (!(iResources.caseByID || iResources.caseByIndex)) {
            return {success: false, values: {error: 'Case not found'}};
          }

          var context = iResources.dataContext;
          var collection = iResources.collection;
          var theCase = iResources.caseByIndex || iResources.caseByID;
          var success = false;
          var changeResult;
          if (collection && theCase && iValues && iValues.values) {
            changeResult = context.applyChange({
              operation: 'updateCases',
              collection: collection,
              cases: [theCase],
              values: [iValues.values],
              requester: this.get('id')
            });
            success = (changeResult && changeResult.success);
          }
          return {
            success: success
          };
        },
        'delete': function (iResources) {
          var context = iResources.dataContext;
          var collection = iResources.collection;
          var theCase = iResources.caseByIndex || iResources.caseByID;
          var success = false;
          var changeResult;
          if (collection && theCase) {
            changeResult = context.applyChange({
              operation: 'deleteCases',
              collection: collection,
              cases: [theCase],
              values: [],
              requester: this.get('id')
            });
            success = (changeResult && changeResult.success);
          }
          return {
            success: success
          };
        }
      },

      handleCaseCount: {
        get: function (iResources) {
          if (!iResources.collection) {
            return {success: false, values: {error: 'Collection not found'}};
          }

          var count = iResources.collection.casesController.length();
          return {
            success: true,
            values: count
          };
        }
      },

      handleCaseSearch: {
        get: function (iResources) {
          if (!iResources.collection) {
            return {success: false, values: {error: 'Collection not found'}};
          }
          var success = (iResources.caseSearch != null),
              cases = [];

          if (success) {
            cases = iResources.caseSearch.map(function (iCase) {
              return this.makeSerializableCase(iResources.collection, iCase);
            }.bind(this));
          }
          return {
            success: success,
            values: cases
          };
        }
      },
      handleCaseFormulaSearch: {
        get: function (iResources) {
          if (!iResources.collection) {
            return {success: false, values: {error: 'Collection not found'}};
          }
          var success = (iResources.caseFormulaSearch != null),
              cases = [];

          if (success) {
            cases = iResources.caseFormulaSearch.map(function (iCase) {
              return this.makeSerializableCase(iResources.collection, iCase);
            }.bind(this));
          }
          return {
            success: success,
            values: cases
          };
        }
      },

      handleItems: {
        get: function (iResources) {
          var success = (iResources.item != null),
              item;

          if (success) {
            item = iResources.item;
          }
          return {
            success: success,
            values: item
          };
        },

        create: function (iResources, iValues) {
          var context = iResources.dataContext;
          var result;
          if (context) {
            result = context.applyChange({
              operation: 'createItems',
              items: iValues,
              requester: this.get('id')
            });
            return result;
          }
          return {success: false};
        },
        'update': function (iResources, iValues) {
          var item = iResources.item;
          var context = iResources.dataContext;
          var createdCaseIDs, deletedCaseIDs, caseChanges;
          if (item != null) {
            caseChanges = context.applyChange({
              operation: 'updateItems',
              items: {id: item.id, values: iValues},
              requester: this.get('id')
            });
            if (caseChanges) {
              createdCaseIDs = caseChanges.createdCases?
                  caseChanges.createdCases.map(function (iCase) {return iCase.id; }):
                  [];
              deletedCaseIDs = caseChanges.deletedCases?
                  caseChanges.deletedCases.map(function (iCase) {return iCase.id; }):
                  [];
              return {
                success: true,
                values: {
                  createdCases: createdCaseIDs,
                  deletedCases: deletedCaseIDs
                }
              };
            }
          } else {
            // if no items, we expect an array of items for the "values" field
            return context.applyChange({
              operation: 'updateItems',
              items: iValues,
              requester: this.get('id')
            });
          }
        }

      },

      handleItemSearch: {
        get: function (iResources) {
          var dataContext = iResources.dataContext;
          var dataSet = dataContext && dataContext.get('dataSet');

          var success = (iResources.itemSearch != null),
              items = [];

          if (success) {
            items = iResources.itemSearch && iResources.itemSearch.map(function (item) {
              return serializeItem(dataSet, item);
            });
          }
          return {
            success: success,
            values: items
          };
        },
        'delete': function (iResources) {
          var items = iResources.itemSearch;
          var context = iResources.dataContext;
          var deletedItems;
          if (context && (items != null)) {
            context.applyChange({
              operation: 'deleteItems',
              items: items,
              requester: this.get('id')
            });
            deletedItems = context.deleteItems(items);
            if (deletedItems) {
              return {success: true, values: deletedItems && deletedItems.map(function (item) {return item.id;})};
            }
          }
          return {success: false};
        },
        notify: function (iResources, iValues) {
          var items = iResources.itemSearch;
          var context = iResources.dataContext;
          if (context && (items != null) && iValues.itemOrder) {
            context.applyChange({
              operation: 'moveItems',
              items: items,
              itemOrder: iValues.itemOrder,
              requester: this.get('id')
            });
            return {success: true};
          }
          return {success: false};
        }
      },

      handleItemByID:{
        get: function (iResources) {
          var success = (iResources.itemByID != null),
              item;

          if (success) {
            item = iResources.itemByID;
          }
          return {
            success: success,
            values: item
          };
        },

        'update': function (iResources, iValues) {
          var item = iResources.itemByID;
          // var itemID = item && item.id;
          // var newValues = item.values;
          var context = iResources.dataContext;
          var createdCaseIDs, deletedCaseIDs, caseChanges;
          if (item != null) {
            caseChanges = context.applyChange({
              operation: 'updateItems',
              items: {id: item.id, values: iValues},
              requester: this.get('id')
            });
            if (caseChanges) {
              createdCaseIDs = caseChanges.createdCases? caseChanges.createdCases.map(function (iCase) {return iCase.id; }): [];
              deletedCaseIDs = caseChanges.deletedCases? caseChanges.deletedCases.map(function (iCase) {return iCase.id; }): [];
              return {
                success: true,
                values: {
                  createdCases: createdCaseIDs,
                  deletedCases: deletedCaseIDs
                }
              };
            }
          } else {
            return { success: false, values: {error: "item not found"}};
          }
        },

        'delete': function (iResources) {
          var context = iResources.dataContext;
          var item = iResources.itemByID;
          var dataSet = context && context.get('dataSet');
          // DataContext/deleteItems expects actual SC.Items
          var scItem = dataSet && dataSet.getDataItemByID(item.id);
          var items = [scItem];
          var success = (scItem != null);
          var deletedItems;
          if (success) {
            context.applyChange({
              operation: 'deleteItems',
              items: items,
              requester: this.get('id')
            });
            deletedItems = context.deleteItems(items);
            if (deletedItems) {
              return {success: true, values: deletedItems && deletedItems.map(function (item) {return item.id;})};
            }
          } else {
            return {success: success};
          }
        }

      },
      handleItemByCaseID: {
        get: function (iResources) {
          var success = (iResources.itemByCaseID != null),
              items = [];

          if (success) {
            items = iResources.itemByCaseID;
          }
          return {
            success: success,
            values: items
          };
        },

        'update': function (iResources, iValues) {
          var item = iResources.itemByCaseID;
          // var itemID = item && item.id;
          // var newValues = item.values;
          var context = iResources.dataContext;
          var createdCaseIDs, deletedCaseIDs, caseChanges;
          if (item != null) {
            caseChanges = context.applyChange({
              operation: 'updateItems',
              items: {id: item.id, values: iValues},
              requester: this.get('id')
            });
            if (caseChanges) {
              createdCaseIDs = caseChanges.createdCases? caseChanges.createdCases.map(function (iCase) {return iCase.id; }): [];
              deletedCaseIDs = caseChanges.deletedCases? caseChanges.deletedCases.map(function (iCase) {return iCase.id; }): [];
              return {
                success: true,
                values: {
                  createdCases: createdCaseIDs,
                  deletedCases: deletedCaseIDs
                }
              };
            }
          } else {
            return { success: false, values: {error: "item not found"}};
          }
        },

        'delete': function (iResources) {
          var item = iResources.itemByCaseID;
          var items = [item];
          var context = iResources.dataContext;
          var success = (item != null);
          var deletedItems;
          if (success) {
            context.applyChange({
              operation: 'deleteItems',
              items: items,
              requester: this.get('id')
            });
            deletedItems = context.deleteItems(items);
            if (deletedItems) {
              return {success: true, values: deletedItems && deletedItems.map(function (item) {return item.id;})};
            }
          } else {
            return {success: success};
          }
        }
      },

      handleItemCount: {
        get: function (iResources) {
          var success = (iResources.itemCount != null);
          return success ? { success: true, values: iResources.itemCount } : { success: false };
        }
      },

      handleSelectionList: {
        /**
         * Returns an array containing ids of selected cases. If collection is
         * provided, will filter the list to members of the collection.
         * @param iResources
         * @returns {{success: boolean, values: *}}
         */
        get: function (iResources) {
          var context = iResources.dataContext;
          var collection = iResources.collection;
          var values = context && context.getSelectedCases().filter(function(iCase) {
            // if we specified a collection in the get, filter by it
            return (!collection || collection === iCase.collection);
          }).map(function (iCase) {
            var collectionID = iCase.getPath('collection.id');
            var collectionName = context.getCollectionByID(collectionID).get('name');
            return {
              collectionID: collectionID,
              collectionName: collectionName,
              caseID: iCase.get('id')
            };
          });
          if (!values) {
            return {success: false, values: {error: 'Unknown context.'}};
          }
          return {
            success: true,
            values: values
          };
        },
        /**
         * Creates a selection list in this context. The values provided will
         * replace the current selection list. Values are a array of case ids.
         * @param {object} iResources
         * @param {[number]} iValues
         * @returns {{success: boolean}}
         */
        create: function (iResources, iValues) {
          if (!iResources.dataContext) {
            return {success: false, values: {error: 'Unknown context.'}};
          }
          return this.doSelect(iResources, iValues, false);
        },
        /**
         * Updates a selection list in this context. The values provided will
         * amend the current selection list. Values are a array of case ids.
         * @param {object}iResources
         * @param {[number]} iValues
         * @returns {{success: boolean}}
         */
        update: function (iResources, iValues) {
          if (!iResources.dataContext) {
            return {success: false, values: {error: 'Unknown context.'}};
          }
          return this.doSelect(iResources, iValues, true);
        },
      },

      /**
       * Utility to initiate a select action in a data context.
       * @param {object} iResources
       * @param {[number]} iValues
       * @param {boolean} extend
       * @returns {{success: (*|boolean)}}
       */
      doSelect: function (iResources, iValues, extend) {
        var context = iResources.dataContext;
        var collection = iResources.collection;
        var cases;
        extend = extend && iValues.length !== 0;  // No cases indicates we're not extending selection but deselecting all
        if (collection) {
          cases = iValues.map(function (caseID) {
            return collection.getCaseByID(caseID);
          }).filter(function (iCase) {return !!iCase; });
        } else {
          cases = iValues.map(function (caseID) {
            return context.getCaseByID(caseID);
          }).filter(function (iCase) {return !!iCase; });
        }
          return context.applyChange({
            operation: 'selectCases',
            collection: collection,
            cases: cases,
            select: true,
            extend: extend,
            requester: this.get('id')
        });
      },

      handleComponent: (function () {
        // map CODAP Component types to DI-API component types
        var kTypeMap = {
          'DG.Calculator': 'calculator',
          'DG.TableView': 'caseTable',
          'DG.CaseCard': 'caseCard',
          'DG.GameView': 'game',
          'DG.GraphView': 'graph',
          'DG.GuideView': 'guideView',
          'DG.ImageComponentView': 'image',
          'DG.MapView': 'map',
          'DG.SliderView': 'slider',
          'DG.TextView': 'text',
          'DG.WebView': 'webView'
        };

        // map DI-API component types to CODAP Component types
        var kResourceMap = {
          'calculator': 'DG.Calculator',
          'caseTable': 'DG.TableView',
          'caseCard': 'DG.CaseCard',
          'game': 'DG.GameView',
          'graph': 'DG.GraphView',
          'guideView': 'DG.GuideView',
          'image': 'DG.ImageComponentView',
          'map': 'DG.MapView',
          'slider': 'DG.SliderView',
          'text': 'DG.TextView',
          'webView': 'DG.WebView'
        };

        var directMapping = function (key, value) {
          return {key: key, value: value};
        };

        var kComponentTypeDefaults = {
          slider: {
            dimensions: { width: 300, height: 98 }
          },
          caseTable: {
            dimensions: {width: 500, height: 200}
          },
          caseCard: {
            dimensions: {width: 200, height: 400}
          }
        };

        // correspondence of DI-API properties to ComponentStorage properties.
        //
        // Direct means a one-to-one mapping.
        var kComponentStorageProperties = {
          calculator: {
            name: directMapping,
            title: directMapping,
            cannotClose: directMapping
          },
          caseTable: {
            name: directMapping,
            title: directMapping,
            cannotClose: directMapping,
            horizontalScrollOffset: directMapping,
            isIndexHidden: directMapping
          },
          caseCard: {
            name: directMapping,
            title: directMapping,
            cannotClose: directMapping
          },
          game: {
            currentGameName: function (key, value) {
              return {key: 'name', value: value};
            },
            currentGameUrl: function (key, value) {
              return {key: 'URL', value: value};
            },
            name: function (key, value) {
              return {key: 'currentGameName', value: value};
            },
            title: directMapping,
            URL: function (key, value) {
              return {key: 'currentGameUrl', value: value};
            },
            cannotClose: directMapping,
            isVisible: directMapping
          },
          graph: {
            name: directMapping,
            title: directMapping,
            dataContext: function (key, value) {
              var v;
              if (value) {
                v = (typeof value === 'string') ? DG.currDocumentController().getContextByName(
                    value) : value.get('name');
              }
              return {
                key: key,
                value: v
              };
            },
            xAttributeName: directMapping,
            yAttributeName: directMapping,
            y2AttributeName: directMapping,
            legendAttributeName: directMapping,
            enableNumberToggle: directMapping,
            numberToggleLastMode: directMapping,
            cannotClose: directMapping
          },
          guideView: {
            name: directMapping,
            title: directMapping,
            cannotClose: directMapping,
            items: directMapping,
            currentItemIndex: directMapping,
            isVisible: directMapping
          },
          image: {
            name: directMapping,
            title: directMapping,
            URL: directMapping,
            cannotClose: directMapping
          },
          map: {
            name: directMapping,
            title: directMapping,
            // todo: need more information than key/value to resolve
            // todo: can the component constructor resolve?
            legendAttributeName: directMapping,
            // todo: is this necessary? Will the map constructor be attentive to this?
            dataContextName: function (key, value) {
              return {key: 'context', value: DG.currDocumentController().getContextByName(value)};
            },
            context: function (key, value) {
              return {key: 'dataContextName', value: value.get('name')};
            },
            cannotClose: directMapping,
            center: function (key, value) {
              return {key: 'newCenter', value: value};// two element array of [lat,long]
            },
            zoom: function (key, value) {
              return {key: 'newZoom', value: value};// positive number: 1 displays world higher numbers zoom IN
            }
          },
          slider: {
            animationDirection: directMapping,
            animationMode: directMapping,
            // todo: does slider construct global or is it expected to exist before?
            globalValueName: directMapping,
            lowerBound: directMapping,
            name: directMapping,
            title: directMapping,
            upperBound: directMapping,
            value: directMapping,
            cannotClose: directMapping
          },
          text: {
            name: directMapping,
            text: function (key, value) {
              return {key: 'apiText', value: value};
            },
            title: directMapping,
            cannotClose: directMapping
          },
          webView: {
            name: directMapping,
            title: directMapping,
            URL: directMapping,
            cannotClose: directMapping
          }
        };

        function remapProperties(from, to, componentType) {
          var mapping = kComponentStorageProperties[componentType];
          if (!mapping) {
            return;
          }
          Object.keys(from).forEach(function (key) {
            var mappingType = mapping[key];
            var m;
            if (typeof mappingType === 'function') {
              m = mappingType(key, from[key]);
              if (to.set) {
                to.set(m.key, m.value);
              } else {
                to[m.key] = m.value;
              }
            }
          });
        }

        function mapTableLinkPropertiesFromDI(iIn, iOut) {
          var document = DG.currDocumentController();
          var context = iIn.dataContext && document.getContextByName(iIn.dataContext);
          if (context) {
            DG.ArchiveUtils.addLink(iOut, 'context', context);
          }
        }

        return {
          create: function (iResource, iValues) {
            var doc = DG.currDocumentController();
            var type = iValues.type;
            var typeClass = type && kResourceMap[type];
            // apply defaults
            var tValues = Object.assign({}, kComponentTypeDefaults[type] || {}, iValues);
            // We are going to construct props. Props is structured like a
            // a component definition in a document
            var props = {
              componentStorage: {}
            };
            // var name = iValues.name || iValues.title;
            var success = true;
            var component, errorMessage,global;

            if (SC.none(typeClass)) {
              success = false;
              errorMessage = 'Unknown component type: ' + type;
            }

            // If we have a valid type ...
            if (success) {
              props.document = doc;
              props.type = typeClass;
              // the allowMoreThanOne=false restriction is historical. It prevented
              // proliferation of components when a document was repeatedly opened
              // we default to allowing any number. It is a DI's responsibility
              // to avoid proliferation.
              props.allowMoreThanOne = true;

              // construct the layout object
              props.layout = {};
              if (tValues.dimensions) {
                props.layout = Object.assign(props.layout, tValues.dimensions);
              }
              if (tValues.position) {
                if (typeof tValues.position === 'string') {
                  props.position = tValues.position;
                } else if (typeof tValues.position === 'object') {
                  props.layout = Object.assign(props.layout, tValues.position);
                }
              }

              // copy those properties that can be handled by simple remap
              remapProperties(tValues, props.componentStorage, type);

              var tableDataContext;
              if (tValues.type === 'caseTable' || tValues.type === 'caseCard') {
                mapTableLinkPropertiesFromDI(tValues, props.componentStorage);
                if (tValues.dataContext)
                  tableDataContext = DG.currDocumentController().getContextByName(tValues.dataContext);
              }
              // tables with data contexts
              if ((tValues.type === 'caseTable') && tableDataContext) {
                // component = DG.appController.showCaseDisplayFor(tableDataContext, props);
                component = doc.addCaseTable(
                    DG.mainPage.get('docView'), null,
                    Object.assign({position: 'top', dataContext: tableDataContext}, props));
                component.invokeLater(function () { component.showAndSelect(); });
              }
              if ((tValues.type === 'caseCard') && tableDataContext) {
                // component = DG.appController.showCaseDisplayFor(tableDataContext, props);
                component = doc.addCaseCard(
                    DG.mainPage.get('docView'), props.layout, tableDataContext);
                component.invokeLater(function () { component.showAndSelect(); });
              }
              // sliders with global values
              else if ((tValues.type === 'slider') && tValues.globalValueName) {
                global = DG.globalsController.getGlobalValueByName(tValues.globalValueName);
                if (global) {
                  DG.ArchiveUtils.addLink(props.componentStorage, "model", global);
                  component = DG.currDocumentController().createComponentAndView(DG.Component.createComponent(props), null, {initiatedViaCommand: true});
                  errorMessage = !component && 'Component creation failed';
                } else {
                  errorMessage = "Global not found: '%@'".loc(tValues.globalValueName);
                }
              }
              // all other components
              else {
                component = DG.currDocumentController().createComponentAndView(
                    DG.Component.createComponent(props), null, {initiatedViaCommand: true});
                errorMessage = !component && 'Component creation failed';
              }
            }

            if (success && component) {
              return {
                success: true,
                values: {
                  id: component.getPath('model.id'),
                  name: component.getPath('model.name'),
                  title: component.getPath('model.title'),
                  type: type
                }
              };
            } else {
              return {
                success: false,
                values: {
                  error: errorMessage || 'Unknown error'
                }
              };
            }
          },

          notify: function (iResources, iValues) {
            if (!iResources.component || iResources.component.get(
                'isDestroyed')) {
              return {success: false, values: {error: 'Component not found'}};
            }
            var component = iResources.component;
            var componentController = DG.currDocumentController().componentControllersMap[component.get('id')];
            var view = componentController && componentController.get('view');
            if (!view) {
              return {success: false, values: {error: 'Cannot find component view'}};
            }
            if (iValues.request) {
              if (iValues.request === 'select') {
                DG.InspectorPickerPane.close();
                view.select();
              } else if (iValues.request === 'autoScale') {
                if (componentController && componentController.rescaleFunction) {
                  componentController.rescaleFunction();
                }
                else if (componentController && componentController.resizeColumns) {
                  componentController.resizeColumns();
                }
                else {
                  return {success: false, values: {error: 'Component does not support rescale'}};
                }
              }
            }

            return {
              success: true
            };
          },

          update: function (iResources, iValues) {
            if (!iResources.component || iResources.component.get(
                'isDestroyed')) {
              return {success: false, values: {error: 'Component not found'}};
            }

            var component = iResources.component,
                componentType = component && component.get('type'),
                codapType = componentType && kTypeMap[componentType],
                componentContent = DG.Component.getContent(component), position,
                dimensions, remapped = {};

            if (!component) {
              return {success: false, values: {error: 'Cannot find component'}};
            }

            if (iValues.position) {
              position = iValues.position;
              component.set('position', position);
              delete iValues.position;
            }
            if (!SC.none(iValues.cannotClose)) {
              component.set('cannotClose', iValues.cannotClose);
              delete iValues.cannotClose;
            }
            if (!SC.none(iValues.isResizable)) {
              component.set('isResizable', iValues.isResizable);
              delete iValues.isResizable;
            }
            if (iValues.dimensions) {
              dimensions = iValues.dimensions;
              component.setPath('content.dimensions', dimensions);
              delete iValues.dimensions;
            }
            if (iValues.isVisible != null) {
              var view = DG.currDocumentController().componentControllersMap[component.get('id')].get('view');
              view.set('isVisible', iValues.isVisible);
              delete iValues.isVisible;
            }

            remapProperties(iValues, remapped, codapType);

            componentContent.beginPropertyChanges();
            Object.keys(remapped).forEach(function (key) {
              componentContent.set(key, remapped[key]);
            });
            componentContent.endPropertyChanges();

            return {
              success: true
            };
          },

          get: function (iResources) {
            function remapArchiveComponent(archive) {
              function extractObjectName(componentStorage, iKey) {
                var dataContextID = DG.ArchiveUtils.getLinkID(componentStorage, iKey);
                var dataContext = DG.store.find(dataContextID);
                return dataContext && dataContext.get('name');
              }
              var rtn = {};
              // DG.log('Get Component: ' + JSON.stringify(archive));
              var componentStorage = archive.componentStorage;
              var layout = archive.layout;


              rtn.type = kTypeMap[archive.type];
              if (layout) {
                if (layout.height || layout.width) {
                  rtn.dimensions = {
                    height: layout.height || 0,
                    width: layout.width || 0
                  };
                }
                if ((layout.left != null) || (layout.x != null)) {
                  rtn.position = {
                    left: layout.left || layout.x || 0,
                    top: layout.top || layout.y || 0
                  };
                }
              }
              if (componentStorage) {
                remapProperties(componentStorage, rtn, rtn.type);
              }
              switch (rtn.type) {
                case 'caseTable':
                  rtn.dataContext = extractObjectName(componentStorage, 'context');
                  break;
                case 'graph':
                  rtn.xAttributeName = extractObjectName( componentStorage, 'xAttr');
                  rtn.yAttributeName = extractObjectName( componentStorage, 'yAttr');
                  rtn.y2AttributeName = extractObjectName( componentStorage, 'y2Attr');
                  rtn.xLowerBound = componentStorage.xLowerBound;
                  rtn.xUpperBound = componentStorage.xUpperBound;
                  rtn.yLowerBound = componentStorage.yLowerBound;
                  rtn.yUpperBound = componentStorage.yUpperBound;
                  rtn.y2LowerBound = componentStorage.y2LowerBound;
                  rtn.y2UpperBound = componentStorage.y2UpperBound;
                  /* falls through */
                case 'map':
                  rtn.dataContext = extractObjectName(componentStorage, 'context');
                  rtn.legendAttributeName = extractObjectName( componentStorage, 'legendAttr');
                  rtn.center = extractObjectName('center');
                  rtn.zoom = extractObjectName('zoom');
                  break;
                default:
              }
              return rtn;
            }
            var component = iResources.component;
            var componentController = DG.currDocumentController()
                                          .getComponentControllerForModel(component);
            componentController && componentController.willSaveComponent();
            var archive = component && component.toArchive();
            var serialized = archive && remapArchiveComponent(archive);
            if (serialized) {
              return {
                success: true,
                values: serialized
              };
            } else {
              return {
                success: false,
                values: {
                  error: 'Could not serialize component.'
                }
              };
            }
          },

          'delete': function (iResource) {
            var component = iResource.component,
                componentID = component && component.get('id');
            if (componentID)
              DG.closeComponent(componentID);
            return {success: true};
          },
          'toDIType': function (iCODAPType) {
            return kTypeMap[iCODAPType];
          }
        };
      }()),

      handleComponentList: {
        get: function (iResources) {
          var document = DG.currDocumentController();

          var result = [];
          DG.ObjectMap.forEach(document.get('componentControllersMap'), function(id, componentController) {
            var component = componentController.get('model');
            result.push( {
              id: component.get('id'),
              name: component.get('name'),
              title: component.get('title'),
              type: this.handleComponent.toDIType(component.get('type'))
            });
          }.bind(this));
          return {
            success: true,
            values: result
          };
        }
      },

      handleDocument: {
        update: function (iResources, iDocObject) {

          return {
            success:DG.appController.documentArchiver.updateDocument( iDocObject)
          };
        },
        get: function() {
          if (DG.currDocumentController().notificationManager)
            DG.currDocumentController().notificationManager.sendDocumentToSubscribers();
        }
      },

      handleLogMessage: {
        notify: function (iResources, iValues) {
          DG.Debug.logUserWithTopic.apply(DG.Debug, [iValues.topic, iValues.formatStr].concat(iValues.replaceArgs));
          DG.dirtyCurrentDocument(this.controller, true);
          return {
            success: true
          };
        }
      },

      handleLogMessageMonitor: {
        register: function (iResource, iValues) {
          if (!iValues.topic && !iValues.topicPrefix && !iValues.formatStr && !iValues.formatPrefix && !iValues.message) {
            return {
              success: false,
              values: {
                error: 'At least one of the following values must be passed: topic, topicPrefix, formatStr, formatPrefix or message.'
              }
            };
          }

          var dataInteractiveLogMonitor = DG.currDocumentController().dataInteractiveLogMonitor;
          var logMonitor = SC.Object.create({
            iPhoneHandler: this,
            values: {
              id: dataInteractiveLogMonitor.get("nextLogMonitorId"),
              clientId: iValues.clientId, // optional client supplied id that it can use to denote monitor
              topic: iValues.topic,
              topicPrefix: iValues.topicPrefix,
              formatStr: iValues.formatStr,
              formatPrefix: iValues.formatPrefix,
              message: iValues.message
            }
          });
          dataInteractiveLogMonitor.get("logMonitors").pushObject(logMonitor);
          dataInteractiveLogMonitor.set("nextLogMonitorId", dataInteractiveLogMonitor.get("nextLogMonitorId") + 1);

          return {
            success: true,
            logMonitor: logMonitor.values
          };
        },

        unregister: function (iResource, iValues) {
          if (!iValues.id && !iValues.clientId) {
            return {
              success: false,
              values: {
                error: 'Missing monitor id or clientId in values'
              }
            };
          }
          var dataInteractiveLogMonitor = DG.currDocumentController().dataInteractiveLogMonitor;
          dataInteractiveLogMonitor.set("logMonitors", dataInteractiveLogMonitor.get("logMonitors").filter(function (logMonitor) {
            var logMonitorValues = logMonitor.values;
            if (iValues.id && (iValues.id !== logMonitorValues.id)) {
              return true;
            }
            return !!(iValues.clientId
                && (iValues.clientId !== logMonitorValues.clientId));

          }));

          return {
            success: true
          };
        },

      },

      handleUndoChangeNotice: {
        /**
         * The DataInteractive performed an undoable action
         *
         * We don't perform any action, because the external game has already performed the
         * action. We simply store this new command in the stack, and the undo/redo of this
         * command call undo/redo on the game.
         */
        notify: function (iResources, iValues) {
          var self = this;
          function handleUndoRedoCompleted (ret) {
            if (ret && ret.success === false) {
              // The Data Interactive was not able to successfully undo or redo an action
              DG.UndoHistory.showErrorAlert(true, {message: "Data Interactive error"});
            }
          }

          function registerUndoChangeNotice(logMessage, rpcEndpoint) {
            DG.UndoHistory.execute(DG.Command.create({
              name: 'interactive.undoableAction',
              undoString: 'DG.Undo.interactiveUndoableAction',
              redoString: 'DG.Redo.interactiveUndoableAction',
              log: 'Interactive action occurred: ' + logMessage,
              execute: function () {
              },
              undo: function () {
                // FIXME If the game component was removed and then re-added via an undo,
                // then calling undo or redo here will likely fail because the game's undo stack would
                // probably have been cleared.
                var message = {action: 'notify', resource: 'undoChangeNotice', values: {operation: "undoAction"}};
                self.sendMessage(message, handleUndoRedoCompleted);
              },
              redo: function () {
                var message = {action: 'notify', resource: 'undoChangeNotice', values: {operation: "redoAction"}};
                self.sendMessage(message, handleUndoRedoCompleted);
              }
            }));
            return true;
          }

          var logMessage = iValues && iValues.logMessage ? iValues.logMessage : "Unknown action";
          var success = true;

          switch (iValues.operation){
            case 'undoableActionPerformed':
              success = registerUndoChangeNotice(logMessage, this.get('rpcEndpoint'));
              break;
            case 'undoButtonPress':
              DG.UndoHistory.undo();
              break;

            case 'redoButtonPress':
              DG.UndoHistory.redo();
              break;
          }
          return {success: success, values: { canUndo: DG.UndoHistory.get('canUndo'),
                                              canRedo: DG.UndoHistory.get('canRedo') } };
        }
      },
      handleGlobal: {
        get: function (iResources) {
          var global = iResources.global;
          if (global) {
            return {
              success: true,
              values: {
                name: global.name,
                value: global.value,
                id: global.id
              }
            };
          } else {
            return {success: false, values: {error: 'Not found'}};
          }
        },
        update: function (iResources, iValues) {
          var global = iResources.global;
          var newValue = iValues.value;

          if (global && !SC.none(newValue)) {
            global.set('value', newValue);
            return {success: true};
          } else {
            return {success: false, values: {error: 'missing global or value'}};
          }
        },
        create: function (iResources, iValues) {
          var g = DG.globalsController.createGlobalValue(iValues);
          var result = SC.none(g)
                ?{error: 'error creating global value'}
                :{name: g.name, value: g.value, id: g.id};
          return {success: !SC.none(g), values: result};
        }
      },
      handleGlobalList: {
        get: function (iResources) {
          var names = DG.globalsController.getGlobalValueNames();
          var result = names.map(function (name) {
            var global = DG.globalsController.getGlobalValueByName(name);
            if (global) {
              return {
                name: global.name, value: global.value, id: global.id
              };
            }
            return null;
          }).filter(function(el) { return el; });
          return {success: true, values: result};
        }
      },
      handleConfiguration: {
        get: function (iResources) {
          var configuration = iResources.configuration;
          if (DG.get('publicConfigurationProperties').includes(configuration.name)) {
            return {
              success: true,
              values: {
                name: configuration.name,
                value: DG.get(configuration.name)
              }
            };
          } else {
            return {success: false, values: {error: 'Not found'}};
          }
        },
        update: function (iResources, iValues) {
          var configuration = iResources.configuration;
          var newValue = iValues.value;

          if (DG.get('publicConfigurationProperties').includes(configuration.name) && !SC.none(newValue)) {
            DG.set(configuration.name, newValue);
            return {success: true};
          } else {
            return {success: false, values: {error: 'not found or missing value'}};
          }
        }
      },
      handleConfigurationList: {
        get: function (iResources) {
          var properties = DG.get('publicConfigurationProperties');
          var result = properties.map(function (name) {
            var configParameterValue = DG[name]();
            return {
              name: name, value: configParameterValue
            };
          });
          return {success: true, values: result};
        }
      },
      handleFormulaEngine: {
        get: function() {
          return {
            success: true,
            values: DG.functionRegistry.get("categorizedFunctionInfo"),
          };
        },
        notify: function (_iResources, iValues) {
          var request = iValues.request;
          switch (request) {
            case "evalExpression":
              var source = iValues.source;
              try {
                return {
                  success: true,
                  values: iValues.records.map(function(record) {
                    var context = DG.FormulaContext.create({
                      vars: record,
                    });
                    var formula = DG.Formula.create({
                      source: source,
                      context: context,
                    });
                    return formula.evaluate();
                  }),
                };
              } catch (ex) {
                return {
                  success: false,
                  values: {
                    error: ex.toString(),
                  },
                };
              }
              // eslint-disable-next-line no-unreachable
              break;
            default:
              return {
                success: false,
                values: {
                  error: "Unsupported request type: " + request,
                },
              };
          }
        }
      },
      //get: function (iResources) {
      //  return {
      //    success: true,
      //  }
      //},
      //create: function (iResources, iValues) {
      //  return {
      //    success: true,
      //  }
      //},
      //update: function (iResources, iValues) {
      //  return {
      //    success: true,
      //  }
      //}
      //delete: function (iResources) {
      //  return {
      //    success: true,
      //  }
      //}
    });

/* >>>>>>>>>> BEGIN source/components/data_interactive/data_interactive_utils.js */
// ==========================================================================
//                          DG.DataInteractiveUtils
//
//  A collection of utilities for working with Data Interactives (plugins).
//
//  Copyright (c) 2017 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

DG.DataInteractiveUtils = {

  /**
   * Returns an archivable object containing properties for the specified attribute
   * @param iAttribute {DG.Attribute}
   * @return {Object}
   */
  getAttributeProperties: function(iAttribute, iProps) {
    var props = Object.assign({}, iAttribute && iAttribute.toArchive(), iProps);
    // clients expect 'id' rather than 'guid'
    if (iAttribute && iAttribute.get('id'))
      props.id = iAttribute.get('id');
    return props;
  },

  /**
   * Returns an array of archivable objects containing properties for the specified attributes
   * @param iAttributes {[DG.Attribute]}
   * @param iRequestSpecs {[Object]}
   * @return {Object}
   */
  mapAttributeProperties: function(iAttributes, iRequestSpecs) {
    return iAttributes && iAttributes.map(function(attr, index) {
            // append 'clientName' to returned properties
            var spec = iRequestSpecs && iRequestSpecs[index],
                clientName = spec && spec.clientName,
                addProps = clientName ? { clientName: clientName } : null;
            return DG.DataInteractiveUtils.getAttributeProperties(attr, addProps);
          });
  }

};


/* >>>>>>>>>> BEGIN source/components/data_interactive/notification_manager.js */
// ==========================================================================
//
//  Author:   jsandoe
//
//  Copyright (c) 2017 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
/**
 * @class  DG.Notification - Broadcasts notifications to Data Interactive
 * Plugins with active DI-API channels.
 *
 * @extends SC.Object
 */
DG.NotificationManager = SC.Object.extend(/** @scope DG.NotificationManager.prototype */
(function () {
  /**
   * Returns a list of active channels
   * @param document {DG.DocumentController}
   */
  function findActiveChannels (document) {
    var gameControllers = document.get('dataInteractives');
    var channels = gameControllers.filter(function (gameController) {
      return gameController.get('isUsingDataInteractiveChannel');
    }).map(function (gameController) {
      return gameController.get('activeChannel');
    });
    // If we have embeddedMode handlers return any active ones.
    if (DG.embeddedModePhoneHandlers) {
      DG.embeddedModePhoneHandlers.forEach(function (handler) {
        if (handler.get('isPhoneInUse')) {
          channels.push(handler);
        }
      });
    }
    return channels;
  }

  return {

    /**
     * Stashed as part of contextDataDidChange for later retrieval by observers such as maps
     * @property [Object]
     */
    mostRecentDataContextChanges: null,

    init: function () {
      arguments.callee.base.apply(this,arguments);
      this.invokeLater(function () {
        if (!this.isDestroyed) {
          // Because we're in an invokeLater, we might already have been destroyed
          var contexts = DG.currDocumentController().get('contexts');

          contexts.forEach(function (context) {
            this.guaranteeDataContextObserver(context);
          }.bind(this));
          DG.currDocumentController().addObserver('contextsLength', this, this.contextCountDidChange);
        }

      }, 200);
    },
    destroy: function () {
      var contexts = DG.currDocumentController().get('contexts');
      contexts.forEach(function (context) {
        this.removeDataContextObserver(context);
      }.bind(this));
      DG.currDocumentController().removeObserver('contextsLength', this, this.contextCountDidChange);
      arguments.callee.base.apply(this,arguments);
    },

    /**
     * Sends a notification to all active channels
     * @param message {Object} A serializable object.
     * @param callback {Function}
     */
    sendNotification: function (message, callback) {
      var activeChannels = findActiveChannels(DG.currDocumentController());
      activeChannels.forEach(function (channel) {
        if (channel.sendMessage) {
          channel.sendMessage(message, callback);
        }
      });
    },

    sendChannelNotification: function (gameController, message, callback) {
      var channel = gameController.get('activeChannel');
      if (channel) {
        if (channel.sendMessage) {
          channel.sendMessage(message, callback);
        }
      } else {
        DG.logWarn("NotificationManager.sendChannelNotification to unknown plugin");
      }
    },

    contextCountDidChange: function () {
      DG.log('contextCountDidChange');
      // re-add observers for all data contexts
      DG.currDocumentController().contexts.forEach(function (context){
        this.guaranteeDataContextObserver(context);
      }.bind(this));

      // send notification to DI
      this.sendNotification({
        action: 'notify',
        resource: 'documentChangeNotice',
        values: {
          operation: 'dataContextCountChanged'
        }
      }, function (response) {
        DG.log('Sent documentChangeNotice to Data Interactive');
        DG.log('Response: ' + JSON.stringify(response));
      });
    },

    guaranteeDataContextObserver: function (iDataContext) {
      if (!iDataContext.hasObserverFor('changeCount', this, this.contextDataDidChange)) {
        iDataContext.addObserver('changeCount', this, this.contextDataDidChange);
      }
    },

    removeDataContextObserver: function (iDataContext) {
      iDataContext.removeObserver('changeCount', this, this.contextDataDidChange);
    },

    /**
     * Called in response to data context change notices. We will filter out
     * changes that this object originated and those that were marked
     * unsuccessful. Then we will abstract the original change notice by
     * extracting what may be needed at a bare minimum for the DI to determine
     * their response to the notice.
     *
     * @param {@DG.DataContext} dataContext
     */
    contextDataDidChange: function (dataContext) {
      var dataContextName = dataContext.get('name');

      var originalChanges = dataContext.get('newChanges');

      var activeChannels = findActiveChannels(DG.currDocumentController());

      activeChannels.forEach(function (channel) {
        var changes = originalChanges.filter(function (iChange) {
          // filter out unsuccessful change attempts and those with
          // a requester that matches the channel handler.
          return ((iChange.result && iChange.result.success) &&
          (!iChange.requester || (iChange.requester !== channel.get('id'))));
        }.bind(channel)).map(function (iChange) {
          // fix up change objects by copying through certain result properties
          // and converting objects to their id.
          var result = {};
          DG.ObjectMap.forEach(iChange.result, function (k, v) {
            switch (k) {
              case 'success':
              case 'properties':
              case 'attrIDs':
              case 'caseID':
              case 'caseIDs':
              case 'itemID':
              case 'itemIDs':
                result[k] = v;
                break;
              case 'collection':
                result[k] = v.get('id');
                result.name = iChange.properties.name;
                result.attribute = (iChange.attributes && iChange.attributes.length > 0) ?
                    iChange.attributes[0].get('name') : null;
                break;
              case 'attrs':
                // return archivable attribute descriptors rather DG.Attributes
                result[k] = v && v.map(function(attr) {
                  return DG.DataInteractiveUtils.getAttributeProperties(attr);
                });
                break;
              default:
                DG.log('unhandled result property: ' + k );
            }
          });
          if (iChange.cases) {
            result.cases = [];
            result.extend = iChange.extend;
            (iChange.cases).forEach(function (iCase) {
              if( iCase._isProtoCase)
                return; // In rare situation got here and what follows causes exception
              var values = {};

              iCase.collection.attrs.forEach(function (attr) {
                values[attr.name] = iCase.getValue(attr.id);
              });

              result.cases.push({
                id: iCase.id,
                parent : iCase.parent && iCase.parent.id,
                context: {
                  id: iCase.collection.context.id,
                  name: iCase.collection.context.name
                },
                collection: {
                  id: iCase.collection.id,
                  name: iCase.collection.name,
                  parent: iCase.collection.parent ? {
                        id: iCase.collection.parent.id,
                        name: iCase.collection.parent.name
                      } : null
                },
                values: values
              });
            });
          }

          return {operation: iChange.operation, result: result};
        }); // end of map

        if (!changes || changes.length === 0) {
          return;
        }

        channel.sendMessage({
          action: 'notify',
          resource: 'dataContextChangeNotice[' + dataContextName + ']',
          values: changes
        }, function (response) {
          DG.log('Sent dataContextChangeNotice to Data Interactive for dataContext: '
              + dataContextName + ': ' + JSON.stringify(changes));
          DG.log('Response: ' + JSON.stringify(response));
        });
      });

      this.set('mostRecentDataContextChanges', originalChanges);
    },

    notifyLogMessageSubscribers: function (iValues) {
      // shortcut if no listeners are registered
      var logMonitors = DG.currDocumentController().dataInteractiveLogMonitor.get("logMonitors");
      if (logMonitors.length === 0) {
        return;
      }

      var values = {};
      Object.keys(iValues).forEach(function (key) {
        values[key] = iValues[key];
      });
      values.message = SC.String.fmt(iValues.formatStr, iValues.replaceArgs);

      logMonitors.forEach(function (logMonitor) {
        var logMonitorValues = logMonitor.values;
        logMonitorValues = SC.merge({
          topicMatches: logMonitorValues.topic && (logMonitorValues.topic === iValues.topic),
          topicPrefixMatches: logMonitorValues.topicPrefix && iValues.topic && (logMonitorValues.topicPrefix === iValues.topic.substr(0, logMonitorValues.topicPrefix.length)),
          formatStrMatches: logMonitorValues.formatStr && (logMonitorValues.formatStr === iValues.formatStr),
          formatPrefixMatches: logMonitorValues.formatPrefix && iValues.formatStr && (logMonitorValues.formatPrefix === iValues.formatStr.substr(0, logMonitorValues.formatPrefix.length)),
          messageMatches: logMonitorValues.message &&
            ((logMonitorValues.message === values.message)||
                (logMonitorValues.message === "*"))
        }, logMonitorValues);
        if (logMonitorValues.topicMatches || logMonitorValues.topicPrefixMatches ||
            logMonitorValues.formatStrMatches || logMonitorValues.formatPrefixMatches || logMonitorValues.messageMatches) {
          values.logMonitor = logMonitorValues;
          logMonitor.iPhoneHandler.sendMessage({
            action: "notify",
            resource: "logMessageNotice",
            values: values
          });
        }
      }.bind(this));
    },

    /**
     * Used when a plugin requests document state. We can't send it synchronously as a reply, so we call
     * this method to send it to all subscribers.
     */
    sendDocumentToSubscribers: function() {
      var activeChannels = findActiveChannels(DG.currDocumentController()),
          documentSubscribers;
      documentSubscribers = activeChannels.filter( function( iChannel) {
        return iChannel.getPath('controller.contentView.model.subscribeToDocuments');
      });
      if (documentSubscribers.length > 0) {
        DG.currDocumentController().captureCurrentDocumentState(true /* fullData */).then(function (value) {
          documentSubscribers.forEach( function( iSubscriber) {
            iSubscriber.sendMessage({
              action: 'notify',
              resource: 'document',
              values: {
                operation: 'newDocumentState',
                state: value
              }
            });
          });
        });
      }
    }
  };


})());

/* >>>>>>>>>> BEGIN source/components/game/game_controller.js */
// ==========================================================================
//                          DG.GameController
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/* globals iframePhone */
sc_require('controllers/component_controller');

/** @class
 *
 * The GameController manages a Component presumably containing a Data
 * Interactive.
 *
 * From CODAP's perspective a Data Interactive is a data source. It provides
 * data to an associated Data Context.
 *
 * It receives events from the interactive and acts upon them. Chiefly these
 * are events that create or update case data in collections managed by its
 * data context.
 *
 * @extends DG.ComponentController
*/
DG.GameController = DG.ComponentController.extend(
/** @scope DG.GameController.prototype */ {

      confirmCloseDescription: 'DG.GameController.confirmCloseDescription',

      shouldDestroyOnComponentDestroy: true,

      gameIsReady: true,  // Will be set to false at the point we discover we're
                          // going to have a default game loaded

      /**
       * Every game manages directly a default GameContext. A game context knows
       * basic information about the game and has collections and the namespace
       * for the game to store its data into.
       *
       * @property {DG.GameContext}
       */
      contextBinding: '.model.context',

      /**
       The total number of document-dirtying changes.
       @property   {Number}
       */
      changeCount: 0,

      /**
       The number of document-dirtying changes that have been saved.
       If this is less than the total change count, then the document is dirty.
       @property   {Number}
       */
      savedChangeCount: 0,

      /**
       Whether or not the document contains unsaved changes such that the user
       should be prompted to confirm when closing the document, for instance.
       @property   {Boolean}
       */
      hasUnsavedChanges: function() {
        return this.get('changeCount') > this.get('savedChangeCount');
      }.property(),

      /**
       Synchronize the saved change count with the full change count.
       This method should be called when a save occurs, for instance.
       */
      updateSavedChangeCount: function() {
        this.set('savedChangeCount', this.get('changeCount'));
      },

      /**
       * List of properties stored to/restored from component storage.
       */
      storedProperties: ['preventBringToFront', 'preventDataContextReorg', 'preventTopLevelReorg',
                          'preventAttributeDeletion', 'allowEmptyAttributeDeletion',
                          'respectEditableItemAttribute'],

      /**
       * If false, permit the data interactive to participate in normal component
       * selection, including coming to the front.
       * As of build ~0428 we allow data interactives to come to the front like any other component
       * @type {boolean}
       */
      preventBringToFront: function(key, value) {
        var path = 'model.content.preventBringToFront';
        if (value != null) this.setPath(path, value);
        return this.getPath(path);
      }.property(),

      /**
       * If true, prevent collection reorganization for this data interactive's
       * data context.
       * @type {boolean}
       */
      preventDataContextReorg: function(key, value) {
        var path = 'model.content.preventDataContextReorg';
        if (value != null) this.setPath(path, value);
        return this.getPath(path);
      }.property(),

      /**
       * If true, prevent collection reorganization for the top level of this
       * data interactive's data context.
       * @type {boolean}
       */
      preventTopLevelReorg: function(key, value) {
        var path = 'model.content.preventTopLevelReorg';
        if (value != null) this.setPath(path, value);
        return this.getPath(path);
      }.property(),

      /**
       * If true, prevent user deletion of attributes.
       * @type {boolean}
       */
      preventAttributeDeletion: function(key, value) {
        var path = 'model.content.preventAttributeDeletion';
        if (value != null) this.setPath(path, value);
        return this.getPath(path);
      }.property(),

      /**
       * If true, allow user deletion of attributes empty attributes
       * event when 'preventAttributeDeletion' property is set.
       * @type {boolean}
       */
      allowEmptyAttributeDeletion: function(key, value) {
        var path = 'model.content.allowEmptyAttributeDeletion';
        if (value != null) this.setPath(path, value);
        return this.getPath(path);
      }.property(),

      /**
       * If true, the case table should respect the item/case editable
       * indicated by the hidden '__editable__' attribute
       * @type {boolean}
       */
      respectEditableItemAttribute: function(key, value) {
        var path = 'model.content.respectEditableItemAttribute';
        if (value != null) this.setPath(path, value);
        return this.getPath(path);
      }.property(),

      init: function () {
        arguments.callee.base.apply(this,arguments);

        this._cmdQueue = [];

        this.gamePhoneHandler = DG.GamePhoneHandler.create({
          controller: this
        });
        this.dataInteractivePhoneHandler = DG.DataInteractivePhoneHandler.create({
          controller: this,
        });
        this.gamePhoneHandler.addObserver('connected', this, 'connectionDidChange');
        this.dataInteractivePhoneHandler.addObserver('connected', this, 'connectionDidChange');
      },

      /**
       * Break loops
       */
      destroy: function() {
        this.setPath('model.content', null);
        this.removeObserver('gamePhoneHandler.connected', this, 'connectionDidChange');
        this.removeObserver('dataInteractivePhoneHandler.connected', this, 'connectionDidChange');
        if (this.gamePhoneHandler) {
          this.gamePhoneHandler.destroy();
          this.gamePhoneHandler = null;
        }
        if (this.dataInteractivePhoneHandler) {
          this.dataInteractivePhoneHandler.destroy();
          this.dataInteractivePhoneHandler = null;
        }
        if (this.iframePhoneEndpoint) {
          this.iframePhoneEndpoint.disconnect();
        }
        arguments.callee.base.apply(this,arguments);
      },

      /**
       * The Parent Endpoint for the iFramePhone connection to the data interactive.
       * @property {ParentEndpoint}
       */
      iframePhoneEndpoint: null,

      /**
       * Handles the old-style 'game' API using async iframePhone post-messaging
       * @property {DG.GamePhoneHandler}
       */
      gamePhoneHandler: null,

      /**
       * Handles the new-style 'data interactive' API using async iframePhone post-messaging
       * Brought into existence in March, 2016
       * @property {DG.DataInteractivePhoneHandler}
       */
      dataInteractivePhoneHandler: null,

      /**
       * Return the phone handler that is connected. (Only one should be connected.)
       * @property { DG.DataInteractivePhoneHandler | DG.GamePhoneHandler }
       */
      activeChannel: function () {
        if (this.dataInteractivePhoneHandler.get('connected')) {
          return this.dataInteractivePhoneHandler;
        } else if (this.gamePhoneHandler.get('connected')) {
          return this.gamePhoneHandler;
        }
      }.property(),

      /**
       * @property {Boolean}
       */
      isUsingDataInteractiveChannel: function() {
        return this.get('activeChannel') === this.dataInteractivePhoneHandler;
      }.property('activeChannel'),

      connectionDidChange: function () {
        this.sendQueuedCommands();
        this.notifyPropertyChange('activeChannel');
      },

      setUpChannels: function (iFrame, iUrl) {
        var setupHandler = function (iHandler, iKey) {
          var wrapper = function (command, callback) {
            iHandler.set('isPhoneInUse', true);
            iHandler.doCommand(command, function (ret) {
              DG.doCommandResponseHandler(ret, callback);
            });
          };

          //First discontinue listening to old interactive.
          if (iHandler.rpcEndpoint) {
            iHandler.rpcEndpoint.disconnect();
          }

          // Global flag used to indicate whether calls to application should be made via phone, or not.
          iHandler.set('isPhoneInUse', false);

          iHandler.rpcEndpoint = new iframePhone.IframePhoneRpcEndpoint(wrapper.bind(this),
              iKey, iFrame, this.extractOrigin(iUrl), this.iframePhoneEndpoint);
          // Let games/interactives know that they are talking to CODAP, specifically (rather than any
          // old iframePhone supporting page) and can use its API.
          iHandler.rpcEndpoint.call({message: "codap-present"}, function (reply) {
            DG.log('Got codap-present reply on channel: "' + iKey + '": ' + JSON.stringify(reply));
            // success or failure, getting a reply indicates we are connected
          });
        }.bind( this);

        // We create a parent endpoint. The rpc endpoints will live within
        // the raw parent endpoint.
        this.iframePhoneEndpoint = new iframePhone.ParentEndpoint(iFrame,
            this.extractOrigin(iUrl), function () {DG.log('connected');});
        setupHandler(this.get('gamePhoneHandler'), 'codap-game');
        setupHandler(this.get('dataInteractivePhoneHandler'), 'data-interactive');
      },

      queueCommand: function(iCmd, iResponseHandler) {
        this._cmdQueue.push({ cmd: iCmd, responseHandler: iResponseHandler });
      },

      sendQueuedCommands: function() {
        var channel = this.get('activeChannel');
        if (channel) {
          while (this._cmdQueue.length) {
            var entry = this._cmdQueue.shift();
            channel.rpcEndpoint.call(entry.cmd, entry.responseHandler);
          }
        }
      },

      sendCommand: function(iCmd, iResponseHandler) {
        this.queueCommand(iCmd, iResponseHandler);
        this.sendQueuedCommands();
      },

      /**
       * If the URL is a web URL return the origin.
       *
       * The origin is scheme://domain_name.port
       */
      extractOrigin: function (url) {
        var re = /([^:]*:\/\/[^\/]*)/;
        if (/^http.*/i.test(url)) {
          return re.exec(url)[1];
        }
      },


      gameViewWillClose: function() {
      },

      /**
       * Saves the current state of the DataInteractive (if the DataInteractive supports this).
       *
       * This should be assumed to be asynchronous, as it will generally use iFramePhone,
       * although it's possible for it to return synchronously.
       *
       * @param {Function} callback     A function which will be called with a results object:
       * {success: bool, state: state}
       */
      saveGameState: function (callback) {
        var model, modelStorage, handler;
        // State can be stored in one of two places. Older, game API plugins
        // store state in their associated data context. There was a one-one
        // correspondence between a plugin and a data context assumed by
        // the Game API. Modern plugins have state stored in the model.
        if (this.get('isUsingDataInteractiveChannel')) {
          model = this.get('model');
          modelStorage = model && model.get('componentStorage');
          if (!modelStorage && model) {
            model.set('componentStorage', {});
          }
          handler = this.get('dataInteractivePhoneHandler');
          handler.requestDataInteractiveState(function(result) {
            // Documented property for plugin state is result.values
            // Some plugins use result.status for historical reasons.
            // We continue to support, for now.
            modelStorage.savedGameState = result && (result.values || result.state);
            callback(result);
          });
        } else {
          modelStorage = this.get('context');
          handler = this.get('gamePhoneHandler');
          handler.saveGameState(function (result) {
            if(modelStorage)
              modelStorage.savedGameState = result && result.state;
            callback(result);
          });
        }
      },

      /**
       *  Returns an object that should be stored with the document when the document is saved.
       *  @returns  {Object}  An object whose properties should be stored with the document.
       */
      createComponentStorage: function () {
        var tStorage = this.getPath('model.componentStorage');

        if (!SC.none(this.get('context'))) {
          // Save information about the current game
          tStorage.currentGameName = tStorage.currentGameName ||
              this.getPath('context.gameName') || this.getPath('context.name');
          tStorage.title = this.getPath('model.title');
          tStorage.currentGameUrl = tStorage.currentGameUrl || this.getPath('context.gameUrl');
          var storedProps = this.get('storedProperties');
          storedProps.forEach(function(prop) { tStorage[prop] = this.get(prop); }.bind(this));
        }

        var dataContext = this.get('context');

        if (dataContext && !this.getLinkID(tStorage, 'context')) {
          this.addLink(tStorage, 'context', dataContext);
        }

        // Save any user-created formulas from DG.FormulaObjects.
        // Currently, only formulas from the current game are saved.
        // Eventually, the formulas should be stored with the DG.GameContext
        // and they should be saved for any game in which formulas are defined.
        tStorage.currentGameFormulas = SC.clone(this.getPath('context.formulas'));

        return tStorage;
      },

      /**
       *  Restores the properties of the DG.GamePhoneHandler from the specified Object.
       *  @param  {Object}  iComponentStorage -- The object whose properties should be restored.
       *  @param  {String}  iDocumentID -- The ID of the document being restored.
       */
      restoreComponentStorage: function (iComponentStorage, iDocumentID) {
        arguments.callee.base.apply(this,arguments);
        var gameName = iComponentStorage.currentGameName || iComponentStorage.name,
            // 'di' URL param can override stored URL
            storedGameUrl = iComponentStorage && iComponentStorage.currentGameUrl,
            gameUrl = DG.finalGameUrl(storedGameUrl),
            contextID,
            dataContext;


        // We try to hook up the appropriate restored context.
        // Try to restore the data context for the current game.
        // First, see if it was written out with the document.
        // (Writing out the link began in build 0175.)
        contextID = this.getLinkID(iComponentStorage, 'context');
        dataContext = contextID && DG.currDocumentController().getContextByID(contextID);
        if (!dataContext) {
          // If it wasn't written out with the document, look for one
          // associated with a game of the correct name, or for the
          // first context as a last resort.
          DG.currDocumentController().contexts.forEach(function (iContext) {
            // Look for a context with matching game name.
            // Note that at the moment, 'gameName' is a computed
            // property which relies on the 'gameSpec' property
            // having been set, which is unlikely to have occurred
            // given that the gameSpec doesn't know about the context.
            // This could change down the road, however, so we leave it.
            if (!dataContext && iContext) {
              var contextGameName = iContext.get('gameName') || iContext.get('name');
              if (contextGameName === gameName) {
                dataContext = iContext;
              }
            }
          });
        }
        if (dataContext) {
          this.set('context', dataContext);
          this.setPath('context.gameName', gameName);
          this.setPath('context.gameUrl', gameUrl);
          var storedProps = this.get('storedProperties');
          storedProps.forEach(function(prop) { this.set(prop, iComponentStorage[prop]); }.bind(this));
        }

        // If there are user-created formulas to restore, set them in the
        // gameSpec.
        if (dataContext && iComponentStorage.currentGameFormulas)
          dataContext.set('formulas', iComponentStorage.currentGameFormulas);

        this.set('gameIsReady', true);
      },
      restoreGameState: function (iState) {
        this.gamePhoneHandler.restoreGameState(iState);
      }
    }) ;


/**
 * This entry point allows other parts of the code to send arbitrary notifications
 * to all DataInteractives currently running. The notification should be as defined
 * in https://github.com/concord-consortium/codap/wiki/CODAP-Data-Interactive-API#codap-initiated-actions.
 * If supported for the Game API (https://github.com/concord-consortium/codap/wiki/CODAP-Game-API-(Deprecated))
 * and the Data Interactive has connected through that channel, it will convert the
 * notification and issue it. Otherwise it will not send the command.
 *
 * No monitoring of the actual receipt of the notification is possible through
 * this method. It is possible that the notifications will be made and fail on the
 * DI side.
 *
 * @param iCmd       An object representing the command to be send
 * @return the number of DataInteractives that the event was issued to.
 */
DG.sendCommandToDI = function( iCmd) {
  function translateNotification(notification) {
    if (notification && notification.resource === 'undoChangeNotice') {
      return {operation: notification.values.operation};
    }
  }
  var controllers = DG.currDocumentController().get('dataInteractives');
  var gameNotification = null;
  controllers.forEach(function (controller) {
    var name = controller.getPath('view.title');
    var activeChannel = controller.get('activeChannel');
    var gamePhoneHandler = controller.get('gamePhoneHandler');
    function handleResponse(response) {
      //if (!response || !response.success) {
        //DG.log('Data Interactive Notification to %@ failed: %@'.loc(name, JSON.stringify(iCmd)));
      //}
    }
    if (activeChannel === gamePhoneHandler) {
      if (!gameNotification) {
        gameNotification = translateNotification(iCmd);
      }
      activeChannel.rpcEndpoint.call(gameNotification, handleResponse);
      DG.log('sendCommandToDI: sent game notification to %@: %@'.loc(name, JSON.stringify(gameNotification)));
    } else if (activeChannel) {
      activeChannel.rpcEndpoint.call(iCmd, handleResponse);
      DG.log('sendCommandToDI: sent notification to %@: %@'.loc(name, JSON.stringify(iCmd)));
    }
  });
};


/* >>>>>>>>>> BEGIN source/components/game/game_phone_handler.js */
// ==========================================================================
//                          DG.GamePhoneHandler
//
//  Copyright (c) 2016 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class
 *
 * The GamePhoneHandler manages a Component presumably containing a Data
 * Interactive.
 *
 * From CODAP's perspective a Data Interactive is a data source. It provides
 * data to an associated Data Context.
 *
 * It receives events from the interactive and acts upon them. Chiefly these
 * are events that create or update case data in collections managed by its
 * data context.
 *
 * @extends SC.Object
 */
DG.GamePhoneHandler = SC.Object.extend(
    /** @scope DG.GamePhoneHandler.prototype */ {

      /**
       Array of case IDs of currently open cases.
       @property {Array} of Number
       */
      openCaseIDs: null,

      /**
       * Handles communication over PostMessage interface.
       *
       * Set up by creator.
       *
       * @property {iframePhone.IframePhoneRpcEndpoint}
       */
      rpcEndpoint: null,

      /**
       * The game's controller.
       *
       * Set up by creator.
       *
       * @property {DG.GameController}
       */
      controller: null,

      /**
       * We need to be able to set version and title.
       */
      view: function() {
        return this.getPath('controller.view');
      }.property(),

      connected: false,

      /**
       * Every game manages exactly one GameContext. A game context knows
       * basic information about the game and has collections and the namespace
       * for the game to store its data into.
       *
       * @property {DG.GameContext}
       */
      contextBinding: '.controller.context',

      /**
       * Method for synchronous Data Interactive communication with a
       * data interactive (deprecated). Set by initGame.
       * This method is used for CODAP to initiate requests to
       * the Data Interactive.
       *
       * @property {Function}
       */
      doCommandFunc: null,

      /**
       * Name used for synchronous Data Interactive communication with a
       * Flash-based data interactive (deprecated). Set by initGame.
       * This name is used to identify an element with which to initiate requests to
       * the Data Interactive.
       *
       * @property {String}
       */
      gameEmbedID: null,

      /**
       Initialization method
       */
      init: function () {
        arguments.callee.base.apply(this,arguments);

        this.openCaseIDs = [];
      },

      /**
       * Break loops
       */
      destroy: function () {
        if (this.rpcEndpoint) {
          this.rpcEndpoint.disconnect();
        }
        arguments.callee.base.apply(this,arguments);
      },

      /**
       Returns the IDs of any currently open game cases, plus the child cases of those cases.
       @param iExcludeChildren {Boolean} optional parameter to not include child
       cases of open game cases.
       @returns  {Array} of Number   Array of open case IDs
       */
      getOpenCaseIDs: function (iExcludeChildren) {
        var tGameContext = this.get('context'),
            tOpenCaseIDs = [],
            tIncludeChildCases = !iExcludeChildren;

        // Adds the id of the specified case and all of its child cases to tOpenCaseIDs.
        function addCase(iCase) {
          tOpenCaseIDs.push(iCase.get('id'));

          if (tIncludeChildCases) {
            var childCases = iCase.get('children');
            childCases.forEach(function (iChildCase) {
              addCase(iChildCase);
            });
          }
        }

        // New Game API support -- Add open parent cases, child cases, and their values
        this.openCaseIDs.forEach(function (iCaseID) {
          var parentCase = tGameContext.getCaseByID(iCaseID);
          if (parentCase) addCase(parentCase);
        });

        // Old Game API support -- Add open parent cases, child cases, and their values
        DG.ObjectMap.forEach(this._openParentCases, function (iCollectionName, iOpenCase) {
          addCase(iOpenCase);
        });

        // Return the caseIDs to the caller
        return tOpenCaseIDs;
      },

      doCommand: function (iCmd, iCallback) {
        //DG.logWarn("DG.currGamePhoneHandler.doCommand is deprecated. Use DG.doCommand instead.");
        var result;
        SC.run(function () {
          result = this.dispatchCommand(iCmd, iCallback);
        }.bind(this));
        return result;
      },

      dispatchCommand: function (iCmd, iCallback) {
        var tCmdObj = null,
            tRet = {'success': false},
            tShouldDirtyDocument = true;

        this.setIfChanged('connected', true);

        // If it's a string, parse it as JSON
        if (SC.typeOf(iCmd) === SC.T_STRING) {
          // Catch any exceptions thrown by the parser
          try {
            tCmdObj = SC.json.decode(iCmd);
          }
          catch (e) {
            // TODO: Report invalid JSON back to caller
            DG.logWarn("Invalid JSON in doCommand(), reported from DG.GamePhoneHandler.dispatchCommand()");
            DG.log("JSON: " + iCmd);
          }
        }
        // If it's not a JSON-formatted string, assume it's a JavaScript cmd object
        else {
          tCmdObj = iCmd;
        }

      try {

        // Bail if we don't have a valid tCmdObj at this point
        if (!tCmdObj) return tRet;

        if (this.context && this.context.get('flexibleGroupingChangeFlag')
            && (['initGame',
              'createCollection',
              'openCase',
              'createCase',
              'createCases',
              'updateCases',
              'deleteCases'].indexOf(tCmdObj.action) >= 0)) {
          DG.log('User has reordered Data Context, "%@", further updates ' +
              'from data interactives prohibited.', this.context.get('name'));
          this.invokeLater(function () {
            this.showErrorAlert('DG.GamePhoneHandler.continuityError');
          }.bind(this));
          return tRet;
        }

        // Dispatch the action to the appropriate handler
        switch (tCmdObj.action) {

          /*
           * New API
           */
          case 'initGame':
            this.handleInitGame(tCmdObj.args, function () {
              var ret = {success: true};

              this.set('changeCount', 0);
              this.controller.updateSavedChangeCount();
              tShouldDirtyDocument = false;

              finishDispatchCommand.call(this);

              if (iCallback) {
                iCallback(ret);
              } else {
                return ret;
              }
            }.bind(this));
            return;

          case 'createComponent':
            // If we're in standalone mode, we allow more than one component of a type to be created
            tCmdObj.args.initiatedViaCommand = true;
            tRet = this.handleCreateComponent(tCmdObj.args, DG.STANDALONE_MODE);
            break;

          case 'createCollection':
            tRet = this.handleCreateCollection(tCmdObj.args);
            break;

          case 'openCase':
            tRet = this.handleOpenCase(tCmdObj.args);
            break;

          case 'updateCase':
            tRet = this.handleUpdateCase(tCmdObj.args);
            break;

          case 'closeCase':
            tRet = this.handleCloseCase(tCmdObj.args);
            break;

          case 'createCase':
            tRet = this.handleCreateCase(tCmdObj.args);
            break;

          case 'createCases':
            tRet = this.handleCreateCases(tCmdObj.args);
            break;

          case 'deleteCases':
            tRet = this.handleDeleteCases(tCmdObj.args);
            break;

          case 'deleteAllCaseData':
            tRet = this.handleDeleteAllCaseData(tCmdObj.args);
            break;

          case 'logAction':
            tRet = this.handleLogAction(tCmdObj.args);
            tShouldDirtyDocument = false;
            break;

          case 'reset':
            tRet = this.handleReset(tCmdObj.args);
            break;

          case 'undoableActionPerformed':
            tRet = this.handleUndoableAction(tCmdObj.args);
            break;

          case 'undo':
            tRet = DG.UndoHistory.undo();
            break;

          case 'redo':
            tRet = DG.UndoHistory.redo();
            break;

          /*
           * Old API
           */
          case 'requestAttributeValues':
            tRet = this.handleRequestAttributeValues(tCmdObj.args);
            tShouldDirtyDocument = false;
            SC.warn("Deprecated API Call: " + tCmdObj.action);
            break;

          default:
            tShouldDirtyDocument = false;
            SC.warn("Dispatch of unknown Data Interactive action(" + tCmdObj.action +
                "): ignoring");
            break;
        }
      } catch (ex) {
        DG.logWarn('DG.GameController.doCommand: Caught exception: ' + ex);
        //DG.logWarn('Original command: ' + (tCmdObj && JSON.stringify(tCmdObj)));
        tRet = tRet || {};
        tRet.success = false;
      }

        function finishDispatchCommand() {
          if (tShouldDirtyDocument) {
            this.incrementProperty('changeCount');
          }
        }

        finishDispatchCommand.call(this);

        if (iCallback) {
          //this.invokeLast(function() {
          iCallback(tRet);
          //});
          return tRet;
        }

        return tRet;
      },

      /**
       'initGame' handler
       @param {Object}   iArgs   See below for arguments
       @param {Function} callback  Callback, called when game is inited (this
       includes
       any game-state restoration)
       args: {
        name: "Name String",
        version: "Version String",
        dimensions: { width: _WIDTH_PIX_, height: _HEIGHT_PIX_ },
        contextType: 'DG.GameContext' | 'DG.DataContext', ...
        // Collections required to be ordered from grandparent-to-parent-to-child
        collections: [  // array of collections to create
          {
            name: "Collection1",
            attrs: [  // array of attributes to create/guarantee for this collection
              { name: "name string", type: 'numeric'|'nominal', [precision: _DECIMAL_PRECISION_] },
              ...
            ],
            labels: {
              singleCase: "singular name, e.g.: trial",
              pluralCase: "plural name, e.g.: trials",
              singleCaseWithArticle: "e.g.: a trial",
              setOfCases: "singular name, e.g.: game",
              setOfCasesWithArticle: "e.g.: a game"
            },
            defaults: {
              xAttr: "attribute name",
              yAttr: "attribute name",
              legendAttr: "attribute name",
              groupAttr: "attribute name"
            }
          },
          ...
        ]
      }
       */
      handleInitGame: function (iArgs, iCallback) {
        var finishInitGame = function () {
          SC.run(function () {
            // Ordinarily a component controller's model.content is the model that store's the
            // underlying state. But the model for a game controller (a Component) doesn't have
            // a natural content. So, as a workaround, we make ourselves its content so we can provide
            // a default title.
            this.set('defaultTitle', iArgs.name);
            this.setPath('model.content', this);

            // Once all the collections and attributes are created,
            // we're ready to play the game.
            this.set('gameIsReady', true);
            this.notifyPropertyChange('gameIsReady');

            if ((iArgs.log === undefined) || iArgs.log)
              DG.logUser("initGame: '%@', Collections: [%@]", tCurrentGameName,
                  tGameCollections.getEach('name').join(", "));
            this.updateLayout();
            if (iCallback) {
              iCallback();
            }
          }.bind(this));
        }.bind(this);

        //DG.log('InitGame: ' + JSON.stringify(iArgs));
        // The game-specified arguments form the core of the new DG.GameSpec.
        var tCurrentGameName = this.getPath('context.gameName'),
            tContextGameUrl = this.getPath('context.gameUrl'),
            tStoredGameUrl = this.getPath('model.componentStorage.currentGameUrl'),
            // 'di' URL param can override stored URL
            tCurrentGameUrl = tContextGameUrl || DG.finalGameUrl(tStoredGameUrl),
            tGameContext = this.get('context'),
            tGameCollections = [],
            tRestoredGameState,
            tRestoreCommand,
            tDoAppCommandFunc,
            tGameElement,
            tReturn = {success: true};

        if (SC.none(tGameContext)) {
          tGameContext = DG.currDocumentController().createNewDataContext({
            type: 'DG.GameContext'
          });
          this.set('context', tGameContext);
        }

        // Ask for the context after we've copied the arguments/properties,
        // so that if there's a 'contextType' it will be used.
        if (iArgs.name) {
          this.setPath('context.gameName', iArgs.name);
        }

        if (iArgs.version) {
          this.setPath('context.gameVersion', iArgs.version);
        }

        if (SC.empty(this.getPath('context.gameUrl'))) {
          this.setPath('context.gameUrl', tCurrentGameUrl);
        }

        if (iArgs.dimensions) {
          this.setPath('context.gameDimensions', {
            width: iArgs.dimensions.width, height: iArgs.dimensions.height
          });
        }

        if (!SC.none(iArgs.preventBringToFront)) {
          this.set('preventBringToFront', iArgs.preventBringToFront);
        }

        this.set('doCommandFunc', iArgs.doCommandFunc);
        this.set('gameEmbedID', iArgs.gameEmbedID);

        this.setPath('view.version',
            SC.none(this.context.gameVersion) ? '' : this.context.gameVersion);
        this.setPath('view.title',
            SC.none(this.context.gameName) ? '' : this.context.gameName);

        // Create/guarantee each collection and its required attributes
        if (iArgs.collections) {
          iArgs.collections.forEach(function (collectionArgs) {
            var result = this.handleCreateCollection(collectionArgs);
            tReturn.success = tReturn.success && result.success;
          }.bind(this));
        }

        // Notify that the collections have changed
        this.notifyPropertyChange('collections');

        // If we have restored game state for this game, we pass it to the game
        // at this point, before we've signalled that the game is ready. This way,
        // clients that respond to 'gameIsReady' won't have a chance to query the
        // game until it has finished restoring its state.
        tRestoredGameState = tGameContext && tGameContext.get('restoredGameState');
        tRestoreCommand = {
          operation: 'restoreState', args: {state: tRestoredGameState}
        };
        tDoAppCommandFunc = this.get('doCommandFunc');
        tGameElement = this.findCurrentGameElement(this.get('gameEmbedID'));

        if (tRestoredGameState) {
          if (tDoAppCommandFunc) {
            // for javascript games we can call the games 'doCommandFunc' directly
            tDoAppCommandFunc(tRestoreCommand);
          } else if (tGameElement && tGameElement.doCommandFunc) {
            // for flash games we must find the embedded swf object, then call its 'doCommandFunc'
            tGameElement.doCommandFunc(SC.json.encode(tRestoreCommand));
          } else if (this.get('isPhoneInUse')) {
            this.rpcEndpoint.call(tRestoreCommand, finishInitGame.bind(this));
            return tReturn;
          }
        }
        finishInitGame.call(this);
        return tReturn;
      },
      /**
       Create a component of the specified type.
       */
      handleCreateComponent: function (iArgs, iAllowMoreThanOne) {
        if (iAllowMoreThanOne)
          iArgs.allowMoreThanOne = true;
        // We use sendAction() here to avoid Lakosian issues
        return SC.RootResponder.responder.sendAction('createComponentAndView', null, this, null, iArgs);
      },

      /**
       * Find the current game element in DG, by searching the DOM
       *    Useful for callbacks to embedded flash .swf objects,
       *    which have functions made available by AS3's ExternalInterface.addCallback()
       * @param embeddedGameID the ID parameter of the game, e.g. set by ChainSaw.html for ChainSaw.swf
       * @return {} null or an element of an iFrame that has the given html ID.
       */
      findCurrentGameElement: function (embeddedGameID) {
        // games are dynamically embedded objects in iFrames
        var iFrames = document.getElementsByTagName("iframe"),
            gameElement = null;
        if (embeddedGameID) {
          var i, j; // find first iFrame with embedded element ID==embeddedGameID (expect 0 or 1 match)
          for (i = 0, j = iFrames.length; i < j && !gameElement; ++i) {
            try {
              gameElement = iFrames[i].contentWindow.document.getElementById(embeddedGameID);
            } catch (ex) {
              // errors may occur here because of same origin restrictions, we
              // expect that, so can ignore.
            }
          }
        }
        return gameElement;
      },

      notifyGameAboutExternalUndo: function () {
        if (this.get('gameIsReady') && DG.UndoHistory.get('enabled')) {
          if (DG.STANDALONE_MODE) {
            this.rpcEndpoint.call({operation: "standaloneUndoModeAvailable"});
          } else {
            this.rpcEndpoint.call({operation: "externalUndoAvailable"});
          }
        }
      }.observes('gameIsReady'),

      /**
       Returns the ID of the created case for passing to further 'openCase' or 'createCase' calls.
       @param {String} iAction   Command being executed (e.g. 'openCase',
       'createCase')
       @param {Object} iArgs     Arguments passed to the command
       @returns {Object}         { success: {Boolean}, [caseID: {Number}] }
       */
      doCreateCase: function (iAction, iArgs) {
        // TODO: Consolidate with doCreateCases() method below.
        var tGameContext = this.get('context'),
            collection = tGameContext.getCollectionByName(iArgs.collection),
            caseProperties = {},
            ret = {success: false};
        if (!SC.none(iArgs.parent))
          caseProperties.parent = iArgs.parent;

        if (!DG.assert(tGameContext, 'Missing game Context'))
          return ret;

        var change = {
          operation: 'createCase',
          properties: caseProperties,
          values: iArgs.values
        };
        if (collection)
          change.collection = collection;
        else  // We don't assert, because the data context will default to the child collection.
          DG.logWarn("DG.GamePhoneHandler.doCreateCase: Can't find collection '%@'", iArgs.collection);

        ret = tGameContext.applyChange(change);

        /*    Logging createCase generates too much logging, so turn it off, at least when it comes from
         a data interactive.
         if( ret.success && ((iArgs.log === undefined) || iArgs.log))
         DG.logUser("%@: %@ [%@]", iAction, iArgs.collection, iArgs.values.join(", "));
         */
        return ret;
      },

      /**
       Returns the ID of the created case for passing to further 'openCase' or 'createCase' calls.
       @param {String} iAction   Command being executed (e.g. 'openCase',
       'createCase')
       @param {Object} iArgs     Arguments passed to the command
       @returns {Object}         { success: {Boolean}, [caseID: {Number}] }
       */
      doCreateCases: function (iAction, iArgs) {
        var tGameContext = this.get('context'),
            collection = tGameContext.getCollectionByName(iArgs.collection),
            caseProperties = {},
            ret = {success: false};
        if (!SC.none(iArgs.parent))
          caseProperties.parent = iArgs.parent;

        if (!DG.assert(tGameContext, 'Missing game context'))
          return ret;

        var change = {
          operation: 'createCases',
          properties: caseProperties,
          values: iArgs.values
        };
        if (collection)
          change.collection = collection;
        else  // We don't assert, because the data context will default to the child collection.
          DG.logWarn("DG.GamePhoneHandler.doCreateCase: Can't find collection '%@'", iArgs.collection);

        ret = tGameContext.applyChange(change);

        if (ret.success && ((iArgs.log === undefined) || iArgs.log))
          DG.logUser("%@: %@ %@ cases created", iAction, iArgs.collection, iArgs.values.length);
        return ret;
      },

      /**
       * Deletes named cases.
     * @param {array} iCaseIDs
       * @returns {{success: boolean}}
       */
      doDeleteCases: function (iCaseIDs) {
        var tGameContext = this.get('context'),
            cases = [],
            change = {
              operation: 'deleteCases',
              cases: cases
            },
            ret;
        iCaseIDs.forEach(function (iCaseID) {
          var tCase = tGameContext.getCaseByID(iCaseID);
          if (tCase) {
            cases.push(tCase);
          }
        });
        ret = tGameContext.applyChange(change);
        if (SC.none(ret)) {
          DG.logWarn('UpdateCase failed to return a value');
          ret = {success: true};
        }

        return ret;
      },
      /**
       Update the values of an existing case.
       @param {String} iAction   Command being executed (e.g. 'openCase',
       'createCase')
       @param {Object} iArgs     Arguments passed to the command
       @returns {Object}         { success: {Boolean} }
       */
      doUpdateCase: function (iAction, iArgs) {
        var tGameContext = this.get('context'),
            collection = tGameContext.getCollectionByName(iArgs.collection),
            theCase = tGameContext.getCaseByID(iArgs.caseID),
            ret = {success: false};
        if (collection && theCase && iArgs.values) {
          var change = {
            operation: 'updateCases',
            collection: collection,
            cases: [theCase],
            values: [iArgs.values]
          };
          ret = tGameContext.applyChange(change);
          if (SC.none(ret)) {
            DG.logWarn('UpdateCase failed to return a value');
            ret = {success: true};
          }
        }
        if (iArgs.values && ((iArgs.log === undefined) || iArgs.log)) {
          DG.logUser("%@: %@ [%@]", iAction, collection.get('name'),
              iArgs.values ? iArgs.values.join(", ") : "");
        }
        return ret;
      },

      /**
       Create a new parent case, i.e. one that is expected to have child cases attached to it.
       Returns the ID of the created case for passing to further 'openCase' or 'createCase' calls.
       @param {Object} iArgs     Arguments passed to the 'openCase' command
       @returns {Object}         { success: {Boolean}, [caseID: {Number}] }
       */
      handleOpenCase: function (iArgs) {
        var tResult = this.doCreateCase('openCase', iArgs);
        if (tResult.success && !SC.none(tResult.caseID))
          this.openCaseIDs.pushObject(tResult.caseID);
        return tResult;
      },

      /**
       Update an open parent case with intermediate values.
       @param {Object} iArgs     Arguments passed to the 'updateCase' command
       @returns {Object}         { success: {Boolean} }
       */
      handleUpdateCase: function (iArgs) {
        return this.doUpdateCase('updateCase', iArgs);
      },

      /**
       Close an open parent case once the last of its child cases has been created.
       @param {Object} iArgs     Arguments passed to the 'closeCase' command
       @returns {Object}         { success: {Boolean} }
       */
      handleCloseCase: function (iArgs) {
        var tResult = this.doUpdateCase('closeCase', iArgs);
        if (!SC.none(iArgs.caseID))
          this.openCaseIDs.removeObject(iArgs.caseID);
        return tResult;
      },

      /**
       Create a leaf case, i.e. one which does not have any child cases.
       Returns the ID of the created case.
       @param {Object} iArgs     Arguments passed to the 'openCase' command
       @returns {Object}         { success: {Boolean}, [caseID: {Number}] }
       */
      handleCreateCase: function (iArgs) {
        return this.doCreateCase('createCase', iArgs);
      },

      /**
       Create a leaf case, i.e. one which does not have any child cases.
       Returns the ID of the created case.
       @param {Object} iArgs     Arguments passed to the 'openCase' command
       @returns {Object}         { success: {Boolean}, [caseID: {Number}] }
       */
      handleCreateCases: function (iArgs) {
        return this.doCreateCases('createCases', iArgs);
      },

      /**
       * Delete identified cases. If parent cases, delete children.
       * @param {Object} iArgs {caseIDs: [Number, ...]}
       */
      handleDeleteCases: function (iArgs) {
        return this.doDeleteCases(iArgs.caseIDs);
      },

      /**
       Delete all case data not associated with the current game case.
       @param {Object} iArgs     Arguments passed to the 'deleteAllCaseData'
       command
       @returns {Object}         { success: {Boolean}, [caseID: {Number}] }
       */
      handleDeleteAllCaseData: function (iArgs) {
        DG.logUser("deleteAllCaseData by Game");  // deleted via Game API, not via Delete Data button.
        var preserveAllGameCasesOption = iArgs && iArgs.preserveAllGames,
            preserveOpenEventCasesOption = iArgs && iArgs.preserveOpenEvents;
        return this.doDeleteAllCaseData(preserveAllGameCasesOption, !preserveOpenEventCasesOption);
      },


      /**
       Reset CODAP

       Remove the collections in the data context: they are to be redefined by the
       Data Interactive.
       */
      handleReset: function (iArgs) {
        // Destroy the collections: not just the cases within, but the attribute
        // definitions, too.
        this.doResetCollections();
      },

      /**
       The DataInteractive performed an undoable action

       We don't perform any action, because the external game has already performed the
       action. We simply store this new command in the stack, and the undo/redo of this
       command call undo/redo on the game.
       */
      handleUndoableAction: function (iArgs) {
        var logMessage = iArgs && iArgs.logMessage ? iArgs.logMessage : "Unknown action";
        var rpcEndpoint = this.get('rpcEndpoint');
        var handleUndoRedoCompleted = this.handleUndoRedoCompleted;
        DG.UndoHistory.execute(DG.Command.create({
          name: 'interactive.undoableAction',
          undoString: 'DG.Undo.interactiveUndoableAction',
          redoString: 'DG.Redo.interactiveUndoableAction',
          log: 'Interactive action occurred: ' + logMessage,
          execute: function () {
          },
          undo: function () {
            // FIXME If the game component was removed and then re-added via an undo,
            // then calling undo or redo here will likely fail because the game's undo stack would
            // probably have been cleared.
            rpcEndpoint.call({operation: "undoAction"}, handleUndoRedoCompleted);
          },
          redo: function () {
            rpcEndpoint.call({operation: "redoAction"}, handleUndoRedoCompleted);
          }
        }));
      },

      handleUndoRedoCompleted: function (ret) {
        if (ret && ret.success === false) {
          // The Data Interactive was not able to successfully undo or redo an action
          DG.UndoHistory.showErrorAlert(true, {message: "Data Interactive error"});
        }
      },

      /**
       * Reset all collections. Remove all case data and attributes.
       */
      doResetCollections: function () {
        var result,
            dataContext = this.get('context'),
            tChange = {
              operation: 'resetCollections'
            };
        if (dataContext)
          result = dataContext.applyChange(tChange);
        return result;
      },

      /**
       Delete all case data (except data linked to the currently open game case).
       Design for use by user (DG.AppController.deleteAllCaseData()) or by game (this.handleDeleteAllCaseData())
       @param preserveTopCasesOption {Boolean} (optional) prevent delete of all
       top level cases (delete child cases only)
       @param deleteOpenEventCases {Boolean} (optional) also delete open event
       cases, which by default are preserved.
       @returns {{success: boolean}}
       */
      doDeleteAllCaseData: function (preserveTopCasesOption, deleteOpenEventCases) {
        preserveTopCasesOption = preserveTopCasesOption || false;
        deleteOpenEventCases = deleteOpenEventCases || false;
        var dataContext = this.get('context'),
            tCaseIDsToPreserve = this.getOpenCaseIDs(deleteOpenEventCases), // don't delete the open cases (parent or child)
            tGameCollection = null,
            tDeletedCaseIDs = null;

        if (preserveTopCasesOption) {
          // add all top-level case IDs to tCaseIDsToPreserve, removing duplicates with getOpenCaseIDs() above.
          tGameCollection = dataContext && dataContext.getCollectionAtIndex(0); // get top-level collection
          if (tGameCollection) {
            tGameCollection.getCaseIDs().forEach(function (iID) {
              if (tCaseIDsToPreserve.indexOf(iID) === -1) {
                tCaseIDsToPreserve.push(iID);       // not a duplicate, so preserve this game case
              }
            });
          }
        }
        tDeletedCaseIDs = DG.store.destroyAllRecordsOfType(DG.Case, tCaseIDsToPreserve);

        var tChange = {
              operation: 'deleteCases',
              // signal that the action has already been completed
              isComplete: true,
              ids: tDeletedCaseIDs
            },
            result = {success: false};
        if (dataContext)
          result = dataContext.applyChange(tChange);
        return result;
      },

      /**
       Create a collection.
       Returns the ID of the created collection.
       @param {Object}       iCollectionArgs -- An object that specifies the properties of
       the collection
       {String}          iCollectionArgs.name -- Name of the new collection
       {Array of Object} iCollectionArgs.attrs -- Array of attribute specification objects
       @returns {Object}     { success: {Boolean}, collectionID: {Number} }
       */
      handleCreateCollection: function (iCollectionArgs) {
        //DG.log('CreateCollection: ' + JSON.stringify(iCollectionArgs));
        var tGameContext = this.get('context'),
            tCollectionProperties = {
              name: iCollectionArgs.name,
              caseName: iCollectionArgs.caseName,
              labels: iCollectionArgs.labels,
              defaults: iCollectionArgs.defaults,
              collapseChildren: iCollectionArgs.collapseChildren,
              areParentChildLinksConfigured: true
            },
            tGameCollections = tGameContext.get('collections'),
            tResult,
            tCollection;
        if (tGameCollections && tGameCollections.length > 0) {
          tCollectionProperties.parent = tGameCollections[tGameCollections.length - 1].get('id');
        }

        iCollectionArgs.attrs && iCollectionArgs.attrs.forEach(function (attr) {
          if (SC.none(attr.editable)) {
            attr.editable = false;
          }
        });

        tResult = tGameContext &&
            tGameContext.applyChange({
              operation: 'createCollection',
              properties: tCollectionProperties,
              attributes: iCollectionArgs.attrs
            });
        tCollection = tResult && tResult.success && tResult.collection;
        if (tCollection) {
          if ((iCollectionArgs.log === undefined) || iCollectionArgs.log)
            DG.logUser("newCollectionCreated: %@ with %@ attributes", iCollectionArgs.name, iCollectionArgs.attrs.length);
          return {success: true, collectionID: tCollection.get('id')};
        }
        else
          return {success: false};
      },

      /**
       Calls logUser with the specified arguments.
       Uses Function.apply to package the formatStr and replaceArgs for use by the logUser function.
       @param    {Object}    iArgs
       {String}    iArgs.formatStr -- the format string to use for the log statement
       instances of %@ will be replaced by replaceArgs
       {Array}     iArgs.replaceArgs -- Array of values used to replace %@ instances in formatStr
       */
      handleLogAction: function (iArgs) {
        // Must have formatStr to log anything.
        if (iArgs.formatStr) {
          // Combine the formatStr and replaceArgs into an array for Function.apply.
          var applyArgs = [iArgs.formatStr];
          if (iArgs.replaceArgs)
            applyArgs = applyArgs.concat(iArgs.replaceArgs);
          DG.logUser.apply(this, applyArgs);
          return {success: true};
        }
        return {success: false};
      },

      /**
       Get attribute values of the case, matching each of the supplied attribute names.
       Typically used to get values of formula attributes after doUpdateCase().

       If the case exists an array of values will be returned, with success==true.  Array
       values will be null if the matching attribute does not exist, or has a missing value.
       @param {Object} iArgs     Arguments { collection, caseID,
         attributeNames:[] }
       @returns {Object}         { success: {Boolean}, values: [] }
       */
      handleRequestAttributeValues: function (iArgs) {

        // get the case from the requested collection
        var tGameContext = this.get('context'),
            collection = tGameContext.getCollectionByName(iArgs.collection),
            theCase = tGameContext.getCaseByID(iArgs.caseID),
            ret = {success: false, values: []};

        if (collection && theCase && iArgs.attributeNames) {
          // get the attribute values matching each attribute name
          var attrIDs = collection.getAttributeIDs(),
              attrIndex,
              attrValue,
              i, j = iArgs.attributeNames.length;
          for (i = 0; i < j; ++i) {
            attrIndex = collection.getAttributeIndexByName(iArgs.attributeNames[i]);
            attrValue = null;
            if (attrIndex > 0 && attrIndex < attrIDs.length) {
              attrValue = theCase.getValue(attrIDs[attrIndex]);
            }
            ret.values.push(attrValue);
          }
          ret.success = true;
        }
        return ret;
      },

      /**
       [Old Game API] Creates a new collection with the specified attributes.
       This function is called directly by games using the old Game API.
       New games should use the New Game API 'initGame' command.
       @param  {String}  iCollectionName -- The name of the collection to create
       @param  {Array} of String  iAttributeNames -- The names of the attributes
       to create
       */
      newCollectionWithAttributes: function (iCollectionName, iAttributeNames) {
        DG.logUser("newCollectionCreated: %@ [%@]", iCollectionName, iAttributeNames.join(', '));

        var tGameContext = this.get('context'),
            aCollection = tGameContext && tGameContext.guaranteeCollection({
                  name: iCollectionName
                });
        if (aCollection) {
          iAttributeNames.forEach(function (iAttributeName) {
            aCollection.guaranteeAttribute({
              name: iAttributeName
            });
          });
        }

        // Weasels kluge -- Create the Games collection automatically
        if (iCollectionName === "Weasels")
          this.newCollectionWithAttributes("Games", ["game"]);

        // Notify that the collections have changed
        this.notifyPropertyChange('collections');

        this.set('gameIsReady', true);
      },

      _openGameName: '',
      _openParentCollectionName: '',
      _openParentCases: {},

      openParentCase: function (iGameName, iCollectionName, iParentCollectionName, iParentCase) {
        this._openGameName = iGameName;
        this._openParentCollectionName = iParentCollectionName;
        this._openParentCases[iCollectionName] = iParentCase;
      },

      closeParentCases: function () {
        this._openGameName = '';
        this._openParentCollectionName = '';
        this._openParentCases = {};
      },

      closeParentCase: function (iValues) {
        this.closeParentCases();
      },

      getParentCaseFor: function (iValues) {
        return this._openParentCases[Object.keys(this._openParentCases).pop()];
      },


      /**
       Saves the current state of the DataInteractive (if the DataInteractive supports this).

       This should be assumed to be asynchronous, as it will generally use iFramePhone,
       although it's possible for it to return synchronously.

       @param {Function} callback     A function which will be called with a results object:
       {success: bool, state: state}
       */
      saveGameState: function (callback) {
        var doAppCommandFunc = this.get('doCommandFunc'),
            saveCommand = {operation: "saveState"},
            tGameElement = this.findCurrentGameElement(this.get('gameEmbedID')),
            result;

        if (doAppCommandFunc) {
          // for JavaScript games we can call directly with Objects as arguments
          result = doAppCommandFunc(saveCommand);
          callback(result);
        } else if (tGameElement && tGameElement.doCommandFunc) {
          result = tGameElement.doCommandFunc(SC.json.encode(saveCommand));
          if (typeof result === 'string') {
            result = JSON.parse(result);
          }
          callback(result);
        } else if (this.get('isPhoneInUse')) {
          // async path
          this.rpcEndpoint.call(saveCommand, callback);
        } else {
          callback({success: false});
        }
      },

      restoreGameState: function (state) {
        var context = this.getPath('controller.context');
        if (context) {
          context.restoreFromStorage(state);
        }
      },

      gameViewWillClose: function () {
      },

      updateLayout: function () {
        if (DG.STANDALONE_MODE)
          return; // layout has been set to full document. Don't change it.
        var gameView = this.get('view'),
            gameSize = this.getPath('context.gameDimensions'),
            newWidth, newHeight;
        if (gameView && gameSize) {
          newWidth = gameSize.width + DG.ViewUtilities.horizontalPadding();
          newHeight = gameSize.height + DG.ViewUtilities.verticalPadding();
          gameView.adjust('width', newWidth);
          gameView.adjust('height', newHeight);
        }
      },

      /**
       Logs a user action with the specified action name and array of values.
       If no values are passed, the logged message is simply the iActionString.
       If values are specified, they are appended to the log message:
       logUserAction("doSomething") --> "doSomething"
       logUserAction("doSomething", ["John Doe", 37]) --> "doSomething: [John Doe, 37]"
       @param    {String}    iActionString -- The name of the action/command
       being logged
       @param    {Array}     iValues -- Additional values to be included in the
       log message
       */
      logUserAction: function (iActionString, iValues) {
        DG.logUser(iActionString + (iValues && iValues.length ? ": [" + iValues.join(", ") + "]" : ""));
      },

      showErrorAlert: function (msg) {
        DG.AlertPane.warn({
          localize: true,
          message: msg,
        });
      },

    });


/* >>>>>>>>>> BEGIN source/views/web_view.js */
// ==========================================================================
//                          DG.WebView
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class
 * Implements a view of a web page in an IFrame that presents a loading message
 * and an error message, if the load fails. In particular, if the load of a
 * page from another origin fails, the underlying message will be visible. We
 * won't be able to interrogate the IFrame, so the error message will be the
 * only indication the user has of the failure.
 * @extends SC.View
 */
DG.WebView = SC.View.extend(
/** @scope DG.WebView.prototype */ {
      classNames: ['dg-web-view'],
      childViews: DG.get('hideWebViewLoading') !== 'yes' ? ['loadingView', 'webView'] : ['webView'],

      isTextSelectable: YES,

      /**
       * The URL provided.
       * @type {String}
       */
      value: '',

      /**
       * The URL to load.
       *
       * We load protocol relative URLs to maximize the likelihood of success.
       * See: https://www.paulirish.com/2010/the-protocol-relative-url/
       *
       * @type {String)
       */
      _url: function () {
        return this.get('value').replace(/^https?:/, '');
      }.property('value'),

      /**
       * Whether we are loading.
       * @type {boolean}
       */
      isLoading: true,

      loadingMessage: function () {
        return this.isLoading ? 'DG.GameView.loading'.loc() : 'DG.GameView.loadError'.loc();
      }.property('isLoading'),

      /**
       * The purpose of this view is to provide a background to the WebView
       * while it is loading and, if it fails, provide an error message.
       * When the iframe loads, if it loads correctly, it will cover this view.
       */
      loadingView: SC.View.extend({
        childViews: ['urlLabel', 'messageLabel'],
        isLoadingBinding: '*parentView.isLoading',
        classNames: ['dg-web-view-backdrop'],
        classNameBindings: [
          'isLoading:dg-interactive-loading'
        ],
        urlLabel: SC.LabelView.extend({
          layout: { left: 10, right: 0, top: 0, height: 36 },
          valueBinding: '*parentView.parentView.value',
          classNames: ['dg-web-view-url']
        }),
        messageLabel: SC.LabelView.extend({
          layout: { left: 20, right: 20, top: 40, height: 40 },
          valueBinding: '*parentView.parentView.loadingMessage',
          classNames: ['dg-web-view-message']
        })
      }),

      webView: SC.WebView.extend({
        classNames: ['dg-web-view-frame'],

        value: function () {
          return this.getPath('parentView._url');
        }.property(),

        urlDidChange: function () {
          this.notifyPropertyChange('value');
        }.observes('*parentView.value'),

        /**
         * @override SC.WebView.iframeDidLoad
         */
        iframeDidLoad: function () {
          if (!SC.none(this.get('value'))) {
            this.setPath('parentView.isLoading', false);
          }
          arguments.callee.base.apply(this,arguments);
        }
      })
});

/* >>>>>>>>>> BEGIN source/components/game/game_view.js */
// ==========================================================================
//                          DG.GameView
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/game/game_controller');
sc_require('views/web_view');

/** @class
 *
 *  A container for a Data Interactive.
 *
 * @extends DG.WebView
 */

DG.GameView = DG.WebView.extend(
/** @scope DG.GameView.prototype */ {

      classNames: ['dg-game-view'],
      classNameBindings: ['connected:dg-interactive-connected'],

      /**
       * @property {DG.GameController}
       */
      controller: null,

      connected: null,

      didConnect: function () {
        this.set('connected', !SC.none(this.getPath('controller.activeChannel')));
      }.observes('.controller.activeChannel'),

      backgroundColor: 'white',

      destroy: function () {
        this.controller.gameViewWillClose();
        arguments.callee.base.apply(this,arguments);
      },

      webView: SC.WebView.extend({
        classNames: ['dg-web-view-frame'],

        // we modify the SC.WebView rendering to allow geolocation
        render: function(context, firstTime) {
          var src = this.get('value') || '',
              iframe;

          if (firstTime) {
            context.push('<iframe allow="geolocation; microphone; camera; bluetooth; clipboard-read; clipboard-write" src="' + src +
                '" style="position: absolute; width: 100%; height: 100%; border: 0; margin: 0; padding: 0;"></iframe>');
          }
          else if(src!==this._lastSrc) {
            iframe = this.$('iframe');
            // clear out the previous src, to force a reload
            iframe.attr('src', 'javascript:;');
            iframe.attr('src', src);
          }

          this._lastSrc = src;
        },


        // append language string to url as a query parameter
        value: function () {
          function parseUrl( url ) {
            var a = document.createElement('a');
            a.href = url;
            return a;
          }
          var url = this.getPath('parentView._url');
          var parsedUrl = parseUrl(url);
          var qp = parseUrl(url).search;
          var lang = DG.get('currentLanguage');
          var isBinaryDataURL = parsedUrl.protocol === 'data:';
          if (!isBinaryDataURL) {
            if (!qp || qp.length === 0) {
              qp = '?lang=' + lang;
            } else {
              qp += '&lang=' + lang;
            }
          }
          parsedUrl.search = qp;
          return parsedUrl.href;
        }.property(),

        controllerBinding: '*parentView.controller',

        _previousValue: null,

        // Setup iframePhone communication with the child iframe before it loads, so that connection
        // (iframe src will change when 'value' changes, but observers fire before bindings are synced)
        valueDidChange: function () {
          var tValue = this.get('value');
          var controller = this.parentView.get('controller');

          if (tValue !== this._previousValue) {
            controller.setUpChannels(this.$('iframe')[0], tValue);
          }

          this._previousValue = tValue;

        }.observes('value'),

        /**
         * @override SC.WebView.iframeDidLoad
         */
        iframeDidLoad: function () {
          if (!SC.none(this.value)) {
            this.setPath('parentView.isLoading', false);
          }
          var iframe = this.$('iframe')[0];
          if (this.value) {
            this.valueDidChange();
          }
          if (iframe && iframe.contentWindow) {
            // Allow the iframe to take over the entire screen (requested by InquirySpace)
            $(iframe).attr('allowfullscreen', true)
                .attr('webkitallowfullscreen', true)
                .attr('mozallowfullscreen', true);

          } else {
            DG.logWarn("DG.GameView:iframeDidLoad no contentWindow\n");
          }
          arguments.callee.base.apply(this,arguments);
        }

      })
});

/* >>>>>>>>>> BEGIN source/components/graph/adornments/plot_adornment.js */
// ==========================================================================
//                          DG.PlotAdornment
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class  The base class for plot adornments.

  @extends SC.Object
*/
DG.PlotAdornment = SC.Object.extend(
/** @scope DG.PlotAdornment.prototype */ 
{
  /**
    The model containing the data to display.
    @property { Depends on adornment }
  */
  model: null,

  /**
   * @property {DG.PlotBackgroundView}
  */
  paperSource: null,

  /**
   * @property( Raphael }
   */
  paper: function() {
    return this.getPath('paperSource.paper');
  }.property(),

  paperDidChange: function() {
    this.notifyPropertyChange('paper');
  }.observes('*paperSource.paper'),

  /**
    Provides x-coordinates
    @property { DG.AxisView }
  */
  xAxisView: function() {
    return this.getPath('paperSource.xAxisView');
  }.property('paperSource').cacheable(),

  xAxisViewDidChange: function() {
    this.notifyPropertyChange('xAxisView');
  }.observes('*paperSource.xAxisView'),

  /**
    Provides y-coordinates
    @property { DG.AxisView }
  */
  yAxisView: function() {
    return this.getPath('paperSource.yAxisView');
  }.property('paperSource').cacheable(),

  yAxisViewDidChange: function() {
    this.notifyPropertyChange('yAxisView');
  }.observes('*paperSource.yAxisView'),

  /**
    We need to know this view in order to transform from window to view coordinates.
    @property { SC.View }
  */
  parentView: null,

  /**
    These are the Raphael objects I draw, kept together for ease of showing and hiding.
    @property { SC.Array }
  */
  myElements: null,

  /**
   * The key into the layerManager to get the layer we use to display
   * @property { String }
   */
  layerName: null,

  /**
   * All my Raphael elements go in this layer
   * @property { DG.RaphaelLayer }
   */
  layer: function() {
    var tLayerManager = this.getPath('paperSource.layerManager');
    return (tLayerManager && this.layerName) ? tLayerManager[ this.layerName] :null;
  }.property('paperSource', 'layerName' ),

  /**
    Contains an array of elements, each of which corresponds to a pair of strings
    indicating a model property that should be observed and the handler that should
    be called when that property changes. Adding 'modelPropertiesToObserve' to the
    'concatenatedProperties' array allows the contents of the property from multiple
    levels of the 'class hierarchy' to be concatenated automatically taking advantage
    of a built-in SproutCore behavior. AddObserver/removeObserver will be called for 
    each of the ['PropertyName','ObserverMethod'] pairs as appropriate whenever the
    model changes.
    
    @property   {Array of [{String},{String}]}  Elements are ['PropertyName','ObserverMethod']
   */
  modelPropertiesToObserve: [ ['willDestroy', 'detachModel'],
    ['computingNeeded', 'updateToModel'],
    ['isVisible', 'updateVisibility'] ],
  concatenatedProperties: [ 'modelPropertiesToObserve' ],
  
  /**
    Initialization method
   */
  init: function() {
    arguments.callee.base.apply(this,arguments);

    this.myElements = [];
    // Trigger manually and then addObserver
    this.modelDidChange();
  },
  
  /**
    Detaches all model references in preparation for destruction of
    either the model or the adornment.
   */
  detachModel: function() {
    // Reset the model (triggering notification), then removeObserver
    this.set('model', null);
  },
  
  /**
    Destruction method
   */
  destroy: function() {
    this.detachModel();
    this.removeElements();
    arguments.callee.base.apply(this,arguments);
  },

  removeElements: function() {
    if( this.myElements) {
      var tLayerManager = this.getPath('paperSource.layerManager');
      this.myElements.forEach(function (iElement) {
        tLayerManager.removeElement(iElement);
        iElement.remove();
      });
      this.myElements = null;
    }
  },
  
  /**
    Observer method called when the adornment model changes.
    Guarantees that observers are added/removed for any relevant model properties.
    List ['Property','Handler'] pairs in 'modelPropertiesToObserve' property to
    have observers added/removed automatically.
   */
  _observedModel: null,
  modelDidChange: function() {
    // Get the concatenated list of model properties to observe
    var modelProps = this.get('modelPropertiesToObserve');

    // Detach from previous model
    if( this._observedModel) {
      if( modelProps) {
        // Remove observers for all listed properties
        modelProps.forEach( function( iModelProp) {
                              this._observedModel.removeObserver( iModelProp[0], this, iModelProp[1]);
                            }.bind( this));
      }
      this._observedModel = null;
    }
    
    // Attach to new model
    var model = this.get('model');
    if( model) {
      if( modelProps) {
        // Add observers for all listed properties
        modelProps.forEach( function( iModelProp) {
                              model.addObserver( iModelProp[0], this, iModelProp[1]);
                            }.bind( this));
      }
      this._observedModel = model;
    }
  }.observes('model'),

  showElements: function() {
    var tOpacity = this.get('opacity') || 1,
        tStrokeOpacity = this.get('strokeOpacity') || 1;
    this.myElements.forEach(function (iElement) {
      iElement.show();
      if (iElement.animatable) {
        iElement.stop();
        iElement.animate({'stroke-opacity': tStrokeOpacity, opacity: tOpacity},
            DG.PlotUtilities.kDefaultAnimationTime, '<>');
      }
    });
  },

  hideElements: function () {
    this.myElements.forEach(function (iElement) {
      if (iElement.animatable) {
        iElement.stop();
        iElement.animate({'stroke-opacity': 0, opacity: 0}, DG.PlotUtilities.kDefaultAnimationTime, '<>',
            function () {
              iElement.hide();
            });
      }
      else
        iElement.hide();
    });
  },

  /**
    My model's visibility has changed.
  */
  updateVisibility: function() {
    if( this.getPath('model.isVisible')) {
      this.updateToModel();
      this.showElements();
    }
    else if( !SC.none( this.myElements))
    {
      this.hideElements();
    }
  },

  updateToModel: function() {
    // Subclasses will override
  }

});


/* >>>>>>>>>> BEGIN source/components/graph/adornments/connecting_line_adornment.js */
// ==========================================================================
//                   DG.ConnectingLineAdornment
//
//  Connecting lines between points, intended for use between points on
//  a scatterplot.  Can easily be extended or repurposed for other
//  plot types.
//
//  Author:   Craig D. Miller
//
//  Copyright ©2012-13 Scientific Reasoning Research Institute,
//                  University of Massachusetts Amherst
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/adornments/plot_adornment');

/**
 * @class  Abstract base class for plot adornments that draw averages (mean, median) as symbols in the plot.
 * @extends DG.PlotAdornment
 */
DG.ConnectingLineAdornment = DG.PlotAdornment.extend(
    /** @scope DG.ConnectingLineAdornment.prototype */
    {
      /**
       * @property {Number}
       */
      unselectedLineWidth: 2,

      /**
       * @property {Number}
       */
      selectedLineWidth: 4,

      _dataTip: null,     // {DG.LineDataTip}
      dataTip: function () {
        if (!this._dataTip) {
          var tPlotView = this.get('parentView');
          DG.assert(tPlotView);
          this._dataTip = DG.LineDataTip.create({
            paperSource: this.get('paperSource'),
            plotView: tPlotView, layerName: DG.LayerNames.kDataTip
          });
        }
        return this._dataTip;
      }.property(),

      init: function () {
        arguments.callee.base.apply(this,arguments);
        this.myElements = [];
      },

      /** do we want the line(s) to be visible and up to date? Yes if our model 'isVisible' */
      wantVisible: function () {
        return this.getPath('model.isVisible');
      },

      /**
       * Tell our model that it is out of date.
       */
      invalidateModel: function () {
        var tModel = this.get('model');
        if (tModel) {
          tModel.setComputingNeeded();
        }
      },


      /**
       * Recompute our model if needed, then move symbols to location specified by model.
       * @param iAnimate {Boolean} [optional] if true then animate to new symbol location.
       */
      updateToModel: function (iAnimate) {
        var tModel = this.get('model');
        if (SC.none(tModel))
          return;

        // only recompute and update line if visible, this.updateVisibility() handles everything else
        if (tModel.get('isVisible')) {
          tModel.recomputeValueIfNeeded();
          this.updateLine(iAnimate);
        } else
          this.hideLines();
      },

      /**
       My model's visibility has changed.
       */
      updateVisibility: function () {
        this.updateToModel(true /*animate*/);
      },

      hideLines: function () {
        var tNumElements = this.myElements.length,
            tLayer = this.get('layer');
        for (var i = 0; i < tNumElements; i++) {
          this.myElements[i].animate({'stroke-opacity': 0}, DG.PlotUtilities.kDefaultAnimationTime, '<>',
              function () {
                tLayer.prepareToMoveOrRemove(this);
                this.remove();
              });
        }
        this.myElements.length = 0;
      },

      /**
       * Called when our entire layer is being hidden. Don't delete the elements. Just hide them.
       */
      hide: function () {
        this.get('myElements').forEach(function (iElement) {
          iElement.animate({'stroke-opacity': 0}, DG.PlotUtilities.kDefaultAnimationTime, '<>',
              function () {
                this.hide();
              });
        });
      },

      /**
       * Called when our entire layer is being shown after being hidden. Just show the elements.
       */
      show: function () {
        if (this.getPath('model.isVisible')) {
          this.get('myElements').forEach(function (iElement) {
            iElement.animate({'stroke-opacity': 1}, DG.PlotUtilities.kDefaultAnimationTime, '<>',
                function () {
                  this.show();
                });
          });
        }
      },

      /**
       * Create or update our lines, one for each parent present.
       * @param iAnimate {Boolean} [optional] if true then animate to new symbol location.
       */
      updateLine: function (iAnimate) {
        var tXAxisView = this.getPath('parentView.xAxisView'),
            tYAxisView = this.getPath('parentView.yAxisView');

        function getCoords(iX, iY) {
          return {
            x: tXAxisView.dataToCoordinate(iX),
            y: tYAxisView.dataToCoordinate(iY)
          };
        }

        if (tXAxisView && tYAxisView)
          this.doUpdateLine(iAnimate, getCoords);
      },

      /**
       * Create or update our lines, one for each parent present.
       * @param iAnimate {Boolean} [optional] if true then animate to new symbol location.
       */
      doUpdateLine: function (iAnimate, getCoordsFunc) {
        var kEmptyPath = 'M0,0',
            this_ = this,
            tCoordinatesKeyedByParentID = this.getPath('model.values'),
            kCount = 10,  // This is fixed so we get same colors no matter how many lines there are
            tPaper = this.get('paper'),
            tLayer = this.get('layer'),
            tNumLines = DG.ObjectMap.length(tCoordinatesKeyedByParentID),
            tLineNum = 0;

        if (!tPaper) {
          return;
        }
        if (!tCoordinatesKeyedByParentID)
          return; // Can happen in scatterplot that has multiple attributes

        DG.ObjectMap.forEach(tCoordinatesKeyedByParentID, function (iParentID, iCoordinatesObject) {
          var tCoordinates = iCoordinatesObject.coordinates,
              tNumValues = tCoordinates ? tCoordinates.length : 0,
              tPath = kEmptyPath, // use empty path if no points to connect
              tLineColor = iCoordinatesObject.color ?
                  (typeof iCoordinatesObject.color === 'string' ? iCoordinatesObject.color : iCoordinatesObject.color.colorString) :
                  DG.ColorUtilities.calcAttributeColorFromIndex(tLineNum % kCount, kCount),
              i,
              tLine;
          tLineColor = tLineColor.colorString || tLineColor;
          // create a new path, connecting each sorted data point
          for (i = 0; i < tNumValues; ++i) {
            var tCoords = getCoordsFunc(tCoordinates[i].x, tCoordinates[i].y);
            if (tCoords.x && tCoords.y) {
              if (tPath === kEmptyPath) {
                tPath = 'M%@,%@'.fmt(tCoords.x, tCoords.y); // move to first line
              } else {
                tPath += ' L%@,%@'.fmt(tCoords.x, tCoords.y); // draw to subsequent lines
              }
            }
          }
          DG.assert(tPath);

          tLine = this_.myElements[tLineNum];
          if (!tLine) {
            // create the line
            tLine = tPaper.path('')
                .attr({'stroke-opacity': 0, cursor: 'pointer'})
                .mousedown(function (iEvent) {
                  this_.get('model').selectParent(this.parentCaseID, iEvent.shiftKey);
                })
                .hover(
                    // over
                    function (iEvent) {
                      this_.showDataTip(iEvent, iParentID);
                    },
                    // out
                    function () {
                      this_.hideDataTip();
                    });
            this_.myElements.push(tLine);
            tLayer.push(tLine);
          }
          tLine.parentCaseID = iParentID;
          tLine.attr({path: tPath, stroke: tLineColor});
          if (iAnimate)
            tLine.animate({'stroke-opacity': 1}, DG.PlotUtilities.kDefaultAnimationTime, '<>');
          else
            tLine.attr({'stroke-opacity': 1});
          tLineNum++;
        });

        while (this.myElements.length > tNumLines) {
          var tLast = this.myElements.pop();
          tLayer.prepareToMoveOrRemove(tLast);
          tLast.remove();
        }
        this.updateSelection();
      },

      /**
       * If all cases for a given line are selected, we use a thick line, otherwise a thin line.
       */
      updateSelection: function () {
        if (!this.get('paper'))
          return;
        // TODO: Encapsulate access to selection in plotModel.
        var tArrayOfCoordinatesArrays = DG.ObjectMap.values(this.getPath('model.values')) || [], // In certain situations 'model.values' can be null
            tSelection = this.getPath('model.plotModel.selection');
        tArrayOfCoordinatesArrays.forEach(function (iObject, iLineNum) {
          var
              tCoordinates = iObject.coordinates,
              tNumValues = tCoordinates ? tCoordinates.length : 0,
              tAllSelected = true,
              tLine = this.myElements[iLineNum],
              i;
          if (tLine) {
            for (i = 0; i < tNumValues; ++i) {
              tAllSelected = tAllSelected && tSelection.indexOf(tCoordinates[i].theCase) >= 0;
              if (!tAllSelected)
                break;
            }
            tLine.attr({'stroke-width': (tAllSelected ? this.selectedLineWidth : this.unselectedLineWidth)});
          }
        }.bind(this));
      },

      showDataTip: function (iEvent, iParentID) {
        var tDataTip = this.get('dataTip');
        var tContext = this.getPath('model.plotModel.dataContext'),
            tParent = tContext && tContext.getCaseByID(iParentID),
            tGroupingAttribute = this.getPath('model.parentCollectionFirstAttribute');
        if (SC.none(tParent))
          return;

        var tGroupingAttributeName = tGroupingAttribute.get('name'),
            tGroupingValue = tParent.getValue(tGroupingAttribute.get('id')),
            tChildren = tParent.get('children').flatten(),
            tNumChildren = SC.isArray(tChildren) ? tChildren.get('length') : 0,
            tChildrenName = (tNumChildren > 0) ? tChildren[0].getPath('collection.name') : '';
        tDataTip.show(
            {
              groupingAttributeValue: tGroupingValue,
              groupingAttributeName: tGroupingAttributeName,
              numChildren: tNumChildren,
              childrenName: tChildrenName
            },
            {x: iEvent.offsetX - 5, y: iEvent.offsetY - 5});
      },

      hideDataTip: function () {
        this.get('dataTip').hide();
      }

    });



/* >>>>>>>>>> BEGIN source/components/graph/adornments/plot_adornment_model.js */
// ==========================================================================
//                        DG.PlotAdornmentModel
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/**
 * @class  DG.PlotAdornmentModel -- Base class for plot adornment models.
 * @extends SC.Object
 */

DG.PlotAdornmentModelNextID = 0;

DG.PlotAdornmentModel = SC.Object.extend(
/** @scope DG.PlotAdornmentModel.prototype */
{
  /**
    The plot model to which the adornment is attached; set on construction
    @type   {DG.PlotModel}
   */
  plotModel: null,
  
  /**
    The 'type' string by which this model is registered; set on construction
    @type   {string}
   */
  adornmentKey: null,

  /**
    True if the adornment should be displayed, false if it's hidden.
    @type   {Boolean}
   */
  isVisible: true,

  cases: function() {
    return this.get('enableMeasuresForSelection') ?
        this.getPath('plotModel.selection') :
        this.getPath('plotModel.cases');

  }.property(),
  
  /**
    Initialization method
   */
  init: function() {
    this.set('id', ++ DG.PlotAdornmentModelNextID);
  },

  /**
    Destruction method
   */
  destroy: function() {
    this.plotModel = null;
    this.notifyPropertyChange('willDestroy');
    arguments.callee.base.apply(this,arguments);
  },

  /**
   Private cache.
   @property { Boolean }
   */
  _needsComputing: true,

  /**
   * True if we need to compute new values to match new cells.
   * Note that this does not detect data changes where means need recomputing anyway.
   * @return { Boolean }
   */
  isComputingNeeded: function() {
    return this._needsComputing && this.isVisible;
  },

  /**
   * Note that our mean values are out of date, for lazy evaluation.
   * Dependencies, which will require a recompute
   *  - case-attribute-values added/deleted/changed for the primary and secondary axis attribute(s)
   *  - primary or secondary axis attributes changed (from one attribute to another)
   *  - axis models changed (must be up to date when we use them here)
   */
  setComputingNeeded: function() {
    this._needsComputing = true;
    if( this.isComputingNeeded())
      this.notifyPropertyChange('computingNeeded');
  },

  recomputeValueIfNeeded: function() {
    if( this.isComputingNeeded()) {
      this.recomputeValue();
    }
  },

  recomputeValue: function() {
    // Subclass will override
  },

  /**
   * Set by MultipleLsrlsModel.
   * @property {Boolean}
   */
  enableMeasuresForSelection: false,

  enableMeasuresForSelectionDidChange: function() {
    this.setComputingNeeded();
  }.observes('enableMeasuresForSelection'),

  /**
    Returns an object which contains properties that should be written
    out with the document for archiving purposes.
   */
  createStorage: function() {
    var tStorage = {};
    tStorage.isVisible = this.get('isVisible') || false;
    tStorage.enableMeasuresForSelection = this.get('enableMeasuresForSelection') || false;
    return tStorage;
  },

  /**
    Set the contents of the adornment model from the restored storage.
   */
  restoreStorage: function( iStorage) {
    if( iStorage)
      this.set('isVisible', iStorage.isVisible || false);
      this.set('enableMeasuresForSelection', iStorage.enableMeasuresForSelection || false);
  }

});

/**
 *  A registry which maps adornment keys (e.g. 'plottedValue') to a
 *  creation function for creating an instance of the adornment model.
 */
DG.PlotAdornmentModel.registry = {};
//DG.PlotAdornmentModel.registry['plottedValue'] = DG.PlottedFunctionModel.create;


/* >>>>>>>>>> BEGIN source/components/graph/adornments/connecting_line_model.js */
// ==========================================================================
//                        DG.ConnectingLineModel
//
//  Model for connecting lines between case icons in a scatterplot.
//  Points to connect are ordered by x-axis value by default, not case order.
//
//  Author:   Craig D. Miller
//
//  Copyright ©2012-13 Scientific Reasoning Research Institute,
//                  University of Massachusetts Amherst
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/adornments/plot_adornment_model');

/**
 * @class  The model for a plotted average (mean or median).
 * @extends SC.Object
*/
DG.ConnectingLineModel = DG.PlotAdornmentModel.extend(
/** @scope DG.ConnectingLineModel.prototype */
{
  /**
   * @private
   * @property{{key: caseID, coordinates: [{ x,y }]}} arrays of one point per non-missing value in the plot keyed
   * by parent case ID
   */
  _values: null,

  values: function( iKey, iValues) {
    if( iValues) {
      this._values = iValues;
    }
    else {
      this.recomputeValueIfNeeded();
    }
    return this._values;
  }.property(),

  parentCollectionFirstAttribute: null,

  /**
   * True if we need to compute new values to match new cells.
   * Note that this does not detect data changes where means need recomputing anyway.
   * @return { Boolean }
   */
  isComputingNeeded: function() {
    return this._needsComputing && this.isVisible;
  },

  /**
   * Note that our mean values are out of date, for lazy evaluation.
   * Dependencies, which will require a recompute
   *  - case-attribute-values added/deleted/changed for the primary and secondary axis attribute(s)
   *  - primary or secondary axis attributes changed (from one attribute to another)
   *  - axis models changed (must be up to date when we use them here)
   */
  setComputingNeeded: function() {
    this._needsComputing = true;
  },
  
  /**
    Use the bounds of the given axes to recompute slope and intercept.
  */
  recomputeValueIfNeeded: function() {
    if( this.isComputingNeeded())
      this.recomputeValue();
  },

  /**
   * Will be set by ScatterPlotView on creation of ConnectingLineAdornment
   * @property {Function}
   */
  getLineColorFunc: null,

  /**
    * Compute or re-compute the lines. Creates an array of objects, each having a color and
    * an array of world coordinate values to connect, which also determines the connection order.
    */
  recomputeValue: function() {
    var tCases = this.getPath('plotModel.cases'),
        tFirstCase = tCases.at(0),
        tXVarID = this.getPath( 'plotModel.xVarID'),
        tYKey = 'plotModel.' + (this.getPath('plotModel.verticalAxisIsY2') ? 'y2VarID' : 'yVarID'),
        tYVarID = this.getPath(tYKey),
        /* For maps, plotModel is pointing to a mapDataConfiguration whereas for graphs it's pointing to a Plot. */
        tLegendDesc = this.getPath('plotModel.dataConfiguration.legendAttributeDescription') ||
            this.getPath('plotModel.legendAttributeDescription');
    if( !( tXVarID && tYVarID )) {
      return; // too early to recompute, caller must try again later.
    }

    var getCategoryMap = function() {
      var tMap = null,
          tLegendIsCategorical = tLegendDesc && tLegendDesc.get('isCategorical');
      if( tLegendIsCategorical && tFirstCase) {
        var tCaseParentCollectionID = tFirstCase.getPath('parent.collection.id'),
            tLegendCollID = tLegendDesc.getPath( 'collectionClient.id');
        if( tCaseParentCollectionID === tLegendCollID)
            tMap = tLegendDesc.getPath('attribute.categoryMap');
      }
      return tMap;
    }.bind( this);

    var tParent = tFirstCase ? tFirstCase.getPath('parent.collection') : null,
        tParentAttributes = tParent ? tParent.get('attrs') : null,
        tFirstParentAttribute = tParentAttributes ? tParentAttributes[0] : null;
    this.set('parentCollectionFirstAttribute', tFirstParentAttribute);

    // create an array of points to connect for each parent collection
    var tValues = {},
        tCategoryMap = getCategoryMap(),
        tGetLineColorFunc = this.get('getLineColorFunc');
    tCases.forEach( function( iCase, iIndex ) {
      var tXVal = iCase.getForcedNumericValue( tXVarID),
          tYVal = iCase.getForcedNumericValue( tYVarID ),
          tParent = iCase.get('parent' ),
          tParentID = tParent ? tParent.get('id') : 'top';
      if (isFinite(tXVal) && isFinite(tYVal)) { // if both values exist (else skip missing points)
        if (!tValues[tParentID]) {
          tValues[tParentID] = {
            color: (tCategoryMap ? (tCategoryMap[iCase.getValue(tLegendDesc.getPath('attribute.id'))]) :
                (tGetLineColorFunc ? tGetLineColorFunc() : null)),
            coordinates: []
          };
        }
        tValues[ tParentID].coordinates.push( { x: tXVal, y: tYVal, theCase: iCase } );
      }
    });

    this._needsComputing = false;
    this.set( 'values', tValues); // we expect view to observe this change
  },

  /**
    Private cache.
    @property { Boolean }
  */
  _needsComputing: true,

  /**
   * Pass this along
   * @param iParentID {Number} of parent
   * @param iExtend {Boolean}
   */
  selectParent: function( iParentID, iExtend) {
    if(!DG.isFinite(iParentID))
      return; // no parent
    var tDataContext = this.getPath('plotModel.dataContext'),
        tParent = tDataContext.getCaseByID( iParentID),
        tParentCaseIndex = tParent.get('collection').getCaseIndexByID( iParentID) + 1,
        tChange = {
          operation: 'selectCases',
          collection: tParent.get('collection'),
          cases: [tParent],
          select: true,
          extend: iExtend
        };
    SC.run(function () {
      tDataContext.applyChange(tChange);
      if (tChange.select)
        DG.logUser("lineSelected: %@", tParentCaseIndex);
      else
        DG.logUser("lineDeselected: %@", tParentCaseIndex);
    }.bind(this));
  }

});

DG.PlotAdornmentModel.registry.connectingLine = DG.ConnectingLineModel;



/* >>>>>>>>>> BEGIN source/utilities/tool_tip.js */
// ==========================================================================
//                            DG.ToolTip
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class DG.ToolTip A simple adornment-like class that displays a string in a tooltip format.

  @extends SC.Object
*/
DG.ToolTip = SC.Object.extend(
/** @scope DG.ToolTip.prototype */
{
  /**
    Our gateway to attributes, values, and axes
    @property { DG.PlotView }
  */
  paperSource: null,

  destroy: function() {
    this.paperSource = null;
    arguments.callee.base.apply(this,arguments);
  },

  /**
    What we draw on.
    @property { Raphael }
  */
  paper: function() {
    return this.getPath('paperSource.paper');
  }.property('paperSource' ).cacheable(),

  /**
   * The key into the layerManager to get the layer we use to display
   * @property { String }
   */
  layerName: null,

  /**
   * The elements that make up the data tip get placed in this layer.
   * @property { DG.RaphaelLayer }
   */
  layer: function() {
    var tLayerManager = this.getPath('paperSource.layerManager');
    return (tLayerManager && this.layerName) ? tLayerManager[ this.layerName] :null;
  }.property('paperSource', 'layerName' ),

  /**
   * The text to display.
   * @property {String}
  */
  text: null,

  /**
    The original screen coordinates of the element from which the tip derives.
    @property { {x, y} }
  */
  tipOrigin: null,

  /**
   * If the element from which this tip derives is a circle, this is its radius
   */
  tipSourceRadius: null,

  tipIsEmpty: function() {
    return SC.empty(this.get('text'));
  }.property('text'),

  /**
    This is the element used for the text in the data tip
    @private
    @property { Raphael Element }
  */
  _tipTextElement: null,

  /**
   This is the element used for the rectangle backing the data tip
    @private
    @property { Raphael Element }
  */
  _tipRectElement: null,

  /**
   This is the element used for the data tip shadow
    @private
    @property { Raphael Element }
  */
  _tipShadowElement: null,

  updateTip: function() {
    if( this.get('tipIsEmpty'))
      return;

    var tPaper = this.get('paper' ),
        kRectXOffset = 10,
        kRectYOffset = 5,
        kShadowWidth = 2,
        tShadowXOffset,
        tShadowYOffset,
        kTextXOffset = 15,
        tTextYOffset,
        tX, tY, tRadius,
        tExtent,
        tRectWidth,
        tRectHeight;

    tRadius = this.tipSourceRadius ? this.tipSourceRadius : 0;
    tX = this.tipOrigin.x + tRadius;
    tY = this.tipOrigin.y + tRadius;
    this._tipTextElement.attr( { text: this.get('text') });
    tExtent = DG.RenderingUtilities.getExtentForTextElement( this._tipTextElement, 12);
    tRectWidth = tExtent.width + 10;
    tRectHeight = tExtent.height + 10;
    tTextYOffset = tRectHeight / 2 + 5;
    tShadowXOffset = kRectXOffset + tRectWidth + kShadowWidth;
    tShadowYOffset = kRectYOffset + kShadowWidth;

    // Adjust tX and tY so that the tip will be within the plotview
    if( tX + tShadowXOffset > tPaper.width)
      tX = Math.max(-kRectXOffset, tX - (tX + tShadowXOffset - tPaper.width));
    if( tY + tShadowYOffset + tRectHeight > tPaper.height)
      tY = Math.max(-kRectYOffset, tY - (tY + tShadowYOffset + tRectHeight - tPaper.height));
    // If the tip rectangle encompasses tipOrigin, move the tip rectangle up and to the left
    if( DG.ViewUtilities.ptInRect( this.tipOrigin,
            { x: tX, y: tY, width: tRectWidth + kShadowWidth + 5, height: tRectHeight + kShadowWidth + 5})) {
      tX = Math.max( 0, this.tipOrigin.x - tRadius - tRectWidth - kShadowWidth - kRectXOffset);
      tY = Math.max( 0, this.tipOrigin.y - tRadius - tRectHeight - kShadowWidth - kRectYOffset);
    }
    this._tipTextElement.attr({ x: tX + kTextXOffset, y: tY + tTextYOffset });

    this._tipShadowElement.attr( { 'path': 'M'+ (tX + tShadowXOffset) + ' ' + (tY + tShadowYOffset) +
                                    ' v' + tRectHeight + ' h-' + tRectWidth });
    this._tipRectElement.attr( { x: tX + kRectXOffset, y: tY + kRectYOffset,
                                width: tRectWidth, height: tRectHeight });
  },

  show: function() {
    if( this.get('tipIsEmpty'))
      return;

    var tPaper = this.get('paper' ),
        tLayer = this.get('layer');

    // Make sure only one data tip can be displayed at a time.
    this.hide();

    this._tipTextElement = tPaper.text( 0, 0, '')
                .attr({ 'text-anchor': 'start', 'opacity': 0 })
                .addClass( DG.PlotUtilities.kToolTipTextClassName);
    this._tipShadowElement = tPaper.path('')
                .attr('stroke-opacity', 0 )
                .addClass( DG.PlotUtilities.kToolTipShadowClassName);
    this._tipRectElement = tPaper.rect( 0, 0, 0, 0)
                .attr('opacity', 0 )
                .addClass( DG.PlotUtilities.kToolTipClassName);

    this.updateTip();

    tLayer.push( this._tipShadowElement);
    tLayer.push( this._tipRectElement);
    tLayer.push( this._tipTextElement);
    // TODO: Move constants below to DG.RenderingUtilities
    this._tipRectElement.animate({ 'opacity': 0.7 }, DG.PlotUtilities.kToolTipShowTime, '<>');
    this._tipTextElement.animate({ 'opacity': 1 }, DG.PlotUtilities.kToolTipShowTime, '<>');
    this._tipShadowElement.animate({ 'stroke-opacity': 0.7 }, DG.PlotUtilities.kToolTipShowTime, '<>');
  },

  hide: function() {
    var tLayer = this.get('layer');
    [ this._tipShadowElement, this._tipRectElement, this._tipTextElement ].forEach( function( iElement) {
      if( iElement) {
        tLayer.prepareToMoveOrRemove( iElement);
        iElement.remove();
      }
    });
  }

});

/* >>>>>>>>>> BEGIN source/components/graph/adornments/data_tip.js */
// ==========================================================================
//                            DG.DataTip
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('utilities/tool_tip');

/** @class DG.DataTip A simple adornment-like class that displays and updates a data tip that shows when the
 *    user hovers over a point.

  @extends DG.ToolTip
*/
DG.DataTip = DG.ToolTip.extend(
/** @scope DG.DataTip.prototype */ 
{
  /**
    Our gateway to attributes, values, and axes
    @property { DG.PlotView }
  */
  plotLayer: null,

  plotBinding: '.plotLayer.model',

  /**
   * The index of the case whose values are being displayed
   * @property { Integer }
   */
  caseIndex: null,

  /**
   * Override to call getDataTipText
   * @property {String}
   */
  text: function() {
    return this.getDataTipText();
  }.property(),

  init: function() {
    arguments.callee.base.apply(this,arguments);
    if(!this.get('paperSource'))
      this.set('paperSource', this.get('plotLayer'));
  },

  show: function( iX, iY, iR, iIndex) {
    this.set('caseIndex', iIndex);
    arguments.callee.base.apply(this,arguments);
  },

  getDataTipText: function() {
      return '';
  },

  handleChanges: function( iChanges) {
    // iChanges can be a single index or an array of indices
    var tChanges = (SC.typeOf( iChanges) === SC.T_NUMBER ? SC.IndexSet.create( iChanges) : iChanges);
    tChanges = tChanges || [];
    if( SC.none( this._myElements) || (this._myElements.length === 0) || !(tChanges.contains( this.get('caseIndex'))))
      return;

    this.updateTip();
  }

});

/* >>>>>>>>>> BEGIN source/components/graph/adornments/equation_view.js */
// ==========================================================================
//                          DG.EquationView
// 
//  A simple view for displaying an equation with formatting on top of a graph view.
//  There is one global instance.
//  
//  Author:   William Finzer
//
//  Copyright (c) 2021 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

    DG.EquationView displays text in a popup LabelView

 */
DG.EquationView = SC.LabelView.extend(
    /** @scope DG.EquationView.prototype */ {
      classNames: 'dg-equationview'.w(),

      transitionShow: SC.View.FADE_IN,
      transitionShowOptions: { duration: 1, timing: 'ease-in-out'},
      transitionHide: SC.View.FADE_OUT,
      transitionHideOptions: { duration: 1, timing: 'ease-in-out'},

      isEditable: false,

      localize: true,

      classNameBindings: ['highlighted:dg-equationview-opaque'],

      /**
       * Creator passes in these two functions to be called on mouseover and mouseout
       * @property {function}
       */
      highlight: null,
      /**
       * Creator passes in these two functions to be called on mouseover and mouseout
       * @property {function}
       */
      unhighlight: null,

      /**
       *
       * @param iViewLocation
       * @param iEquation {String} HTML
       */
      show: function (iViewLocation, iEquation) {
        if(!isFinite(iViewLocation.x) || !isFinite(iViewLocation.y))
          return; // Can happen during transitions
        this.get('layer').innerHTML = iEquation;

        SC.run(function () {
          this.adjust({left: iViewLocation.x, top: iViewLocation.y});
        }.bind(this));
      },

      didCreateLayer: function () {
        var this_ = this,
            tLayer = this.get('layer');
        tLayer.addEventListener('mouseover', this_.callHighlight.bind(this_));
        tLayer.addEventListener('mouseout', this_.callUnHighlight.bind(this_));
      },

      willDestroyLayer: function () {
        var this_ = this,
            tLayer = this.get('layer');
        tLayer.removeEventListener('mouseover', this_.callHighlight.bind(this_));
        tLayer.removeEventListener('mouseout', this_.callUnHighlight.bind(this_));
      },

      callHighlight: function () {
        this.highlight(this.get('index'));
      },

      callUnHighlight: function () {
        this.unhighlight(this.get('index'));
      },

      hide: function () {
        this.set('isVisible', false);
      }

    });

DG.EquationView.defaultHeight = 16;

/* >>>>>>>>>> BEGIN source/components/graph/adornments/line_data_tip.js */
// ==========================================================================
//                            DG.LineDataTip
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/adornments/data_tip');

/** @class DG.LineDataTip A simple adornment-like class that displays and updates a data tip that shows when the
 *    user hovers over a line.

  @extends DG.DataTip
*/
DG.LineDataTip = DG.DataTip.extend(
/** @scope DG.LineDataTip.prototype */ 
{
  /**
   * @property { {lineIndex: {Number}, parentName: {String}, numChildren: {Number}, childrenName: {String} }
   */
  info: null,

  /**
   * The returned string describes the line that the user is hovering over.
   * @return { String }
   */
  getDataTipText: function() {
    var tResult = '';
    if( this.info) {
      tResult = 'DG.DataTip.connectingLine'.loc( this.info.groupingAttributeName,
                                                this.info.groupingAttributeValue,
                                                this.info.numChildren,
                                                this.info.childrenName);
    }
    return tResult;
  },

  /**
   * Set up tip coordinates and info for generating text before passing control to base class
   * @param iInfo { {lineIndex: {Number}, parentName: {String}, numChildren: {Number}, childrenName: {String} }
   * @param iCoords
   */
  show: function( iInfo, iCoords) {
    this.info = {};
    this.tipOrigin = {};
    DG.ObjectMap.copy( this.info, iInfo);
    DG.ObjectMap.copy( this.tipOrigin, iCoords);

    arguments.callee.base.apply(this,arguments);
  }

});


/* >>>>>>>>>> BEGIN source/components/graph/adornments/line_label_mixin.js */
// ==========================================================================
//                        DG.LineLabelMixin
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class  Mixin class for line labels
 */
DG.LineLabelMixin =
    {
      /**
       @property { Raphael text element }
       */
      backgrndRect:null,
      textElement: null,

      /**
       Make the movable line. This only needs to be done once.
       Caller can optionally add the line element to this.myElements array.
       @return {Raphael element} the text element
       */
      createBackgroundRect: function() {
        this.backgrndRect = this.get('paper').rect(0, 0, 0, 0)
            .attr({ fill: 'white', 'stroke-width': 0, 'fill-opacity': 0.6 });
        return this.backgrndRect;
      },

      /**
       Make the text element that appears on hover
       Caller can optionally add the line element to this.myElements array.
       @return {Raphael element} the text element
       */
      createTextElement: function() {
        this.textElement = this.get('paper').text( 0, 0, '')
            .attr({ 'text-anchor': 'start', opacity: 1 });
        this.textElement.addClass('dg-graph-adornment');
        return this.textElement;
      },

      /**
       Compute the position of the text element
       */
      updateTextToModel: function( iFractionFromTop) {
        if( this.myElements === null)
          this.createElements();

        var kPadding = 5, // pixels
            tAxisView = this.get( 'valueAxisView'),
            tValue = this.get('value'),
            tValueCoord = (!SC.none( tValue) && isFinite(tValue)) ? tAxisView.dataToCoordinate( tValue) : -1000,
            tPaper = this.get('paper'),
            tValueString = this.get('valueString'),
            tTextElement = this.get('textElement'),
            tBackgrnd = this.get('backgrndRect'),
            tTextBox, tAlign,
            tTextAnchor = {},
            tBackgrndAnchor = {} ;

        tTextElement.attr( { text: tValueString } );
        tTextBox = tTextElement.getBBox();

        if( tAxisView.get('orientation') === DG.GraphTypes.EOrientation.kHorizontal) {
          tAlign = tTextElement.attr('text-anchor');
          tTextAnchor.y = iFractionFromTop * tPaper.height;
          tBackgrndAnchor.y = tTextAnchor.y - tTextBox.height / 2;

          // Don't change the alignment unless the current alignment no longer works
          switch( tAlign) {
            case 'start':
            case 'middle':
              tBackgrndAnchor.x = tValueCoord + 2;
              if( tTextBox.width + kPadding < tPaper.width - tValueCoord) {
                tTextAnchor.x = tValueCoord + kPadding;
              }
              else if( tTextBox.width + kPadding < tValueCoord) {
                tTextAnchor.x = tValueCoord - kPadding;
                tAlign = 'end';
              }
              else
                tTextAnchor.x = kPadding;
              break;
            case 'end':
              tBackgrndAnchor.x = tValueCoord - tTextBox.width - 2;
              if( tTextBox.width + kPadding < tValueCoord) {
                tTextAnchor.x = tValueCoord - kPadding;
              }
              else if ( tTextBox.width + kPadding < tPaper.width - tValueCoord) {
                tTextAnchor.x = tValueCoord + kPadding;
                tAlign = 'start';
              }
              else
                tTextAnchor.x = tPaper.width - kPadding;
              break;
          }
        }
        else {
          tTextAnchor.y = tValueCoord;
          tTextAnchor.x = tPaper.width / 2;
          tBackgrndAnchor.x = tTextAnchor.x - tTextBox.width / 2;
          tAlign = 'middle';
          if( tTextBox.height > tValueCoord) {
            tTextAnchor.y += tTextBox.height / 2 + 2;
            tBackgrndAnchor.y = tValueCoord + 2;
          }
          else {
            tTextAnchor.y -= tTextBox.height / 2 + 2;
            tBackgrndAnchor.y = tValueCoord - tTextBox.height - 2;
          }
        }

        tTextElement.attr( { x: tTextAnchor.x, y: tTextAnchor.y, 'text-anchor': tAlign });
        tBackgrnd.attr( { x: tBackgrndAnchor.x, y: tBackgrndAnchor.y, width: tTextBox.width, height: tTextBox.height });
      }

    };


/* >>>>>>>>>> BEGIN source/components/graph/adornments/twoD_line_adornment.js */
// ==========================================================================
//                      DG.TwoDLineAdornment
//
//  Author:   William Finzer
//
//  Copyright (c) 2016 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/*global pluralize:true*/

sc_require('components/graph/adornments/plot_adornment');

/** @class  Draws a line.

  @extends DG.PlotAdornment
*/
DG.TwoDLineAdornment = DG.PlotAdornment.extend(
/** @scope DG.TwoDLineAdornment.prototype */
    (function() {
      var kSumSquares = '<p style = "color:%@;">%@ = %@</p>', // sumOfResidualsSquared
          kSlopeInterceptXSingle = '<p style="color:%@;"><i>%@</i> = %@ <i>%@</i> %@ %@</p>', // color,y,slope,x,signInt,Int
          kSlopeInterceptXMultiple = '<p style="color:%@;"><i>%@</i> = %@ (<i>%@</i>) %@ %@</p>', // color,y,slope,x,signInt,Int
          kInfiniteSlope = '<p style = "color:%@;"><i>%@</i> = %@ %@</p>', // x,constant,unit
          kSlopeOnly = '<p style = "color:%@;">%@ = %@ %@</p>', // color, left side, numeric slope, slope unit
          kUnitsWrapper = '<span style = "color:gray;">%@</span>'; // units

  return {
    /**
     The line itself is a single line element
     @property { Raphael line element }
     */
    lineSeg: null,
    /**
     * element on top of lineSeg, transparent, thicker
     * @property { Raphael line element }
     */
    coverSeg: null,

    /**
     * @property {DG.EquationView}
     */
    equation: null,

    defaultColor: 'black',

    lineColor: function () {
      return this.get('defaultColor');
    }.property().cacheable(),

    equationColor: function () {
      return DG.color(DG.ColorUtilities.colorNameToHexColor(this.get('lineColor'))).darker(1).color;
    }.property().cacheable(),

    destroy: function () {
      if (this.equation) {
        this.get('paperSource').removeChildAndDestroy(this.equation);
        this.equation = null;
      }
      arguments.callee.base.apply(this,arguments);
    },

    /**
     Concatenated array of ['PropertyName','ObserverMethod'] pairs used for indicating
     which observers to add/remove from the model.

     @property   {Array of [{String},{String}]}  Elements are ['PropertyName','ObserverMethod']
     */
    modelPropertiesToObserve: [['slope', 'updateToModel'], ['intercept', 'updateToModel'],
      ['isInterceptLocked', 'updateToModel'],
      ['isVertical', 'updateToModel'], ['xIntercept', 'updateToModel'],
      ['sumSquaresResiduals', 'updateToModel'],
      ['equationCoords', 'updateToModel'],
      ['showConfidenceBands', 'updateToModel']],

    /**
     The returned string should have a reasonable number of significant digits for the
     circumstances.
     @property { String read only }
     */
    equationString: function () {
      var this_ = this;

      function equationForFiniteSlopeLine() {

        var handleDateTime = function () {
              var tLower = this_.getPath('xAxisView.model.lowerBound'),
                  tUpper = this_.getPath('xAxisView.model.upperBound'),
                  tRange = tUpper - tLower,
                  tSlopeMultiplier = 1;
              if (tRange < 120) {
                // leave in seconds
                tXVar = 'DG.ScatterPlotModel.secondsLabel'.loc();
              } else if (tRange < 60 * 60 * 2) { // 2 hours
                tSlopeMultiplier = 60; // per minute
                tXVar = 'DG.ScatterPlotModel.minutesLabel'.loc();

              } else if (tRange < 3600 * 24 * 2) { // 2 days
                tSlopeMultiplier = 3600; // per hour
                tXVar = 'DG.ScatterPlotModel.hoursLabel'.loc();
              } else if (tRange < 3600 * 24 * 365) { // 365 days
                tSlopeMultiplier = 3600 * 24; // per day
                tXVar = 'DG.ScatterPlotModel.daysLabel'.loc();
              } else {
                tSlopeMultiplier = 3600 * 24 * 365.25; // per year
                tXVar = 'DG.ScatterPlotModel.yearsLabel'.loc();
              }
              tXVar = kUnitsWrapper.loc(tXVar);
              tSlope *= tSlopeMultiplier;
              tSlopeString = tSlope.toPrecision(3) + " ";
              if (tSlopeString !== "0 ") {  // Implies intercept is meaningless because 0 of x-axis is arbitrary
                tInterceptString = tSign = "";
                tSlopeString += kUnitsWrapper.loc(this_.getPath('yAxisView.model.firstAttributeUnit')) + ' ';
              }
            },

            getSlopeUnit = function () {
              var tYUnit = this_.getPath('yAxisView.model.firstAttributeUnit'),
                  tXUnit = this_.getPath('xAxisView.model.firstAttributeUnit'),
                  tSlash = (tXUnit === '') ? '' : '/',
                  tSingularX;
              if (tXUnit.match(/((^[sS])|(\W[sS]))$/)) {
                tSingularX = tXUnit;
              } else {
                tSingularX = pluralize.singular(tXUnit);
              }
              tXUnit = SC.empty(tSingularX) ? tXUnit : tSingularX;
              return (tXUnit === '' && tYUnit === '') ? '' :
                  ' ' + tYUnit + tSlash + tXUnit + ')';
            },

            getInterceptUnitString = function () {
              var tYUnit = this_.getPath('yAxisView.model.firstAttributeUnit');
              return (tYUnit === '') ? '' : ' ' + kUnitsWrapper.loc(tYUnit);
            };

        var kSlopeInterceptForm = kSlopeInterceptXSingle,// y,slope,x,signInt,Int
            tIntercept = this_.getPath('model.intercept'),
            tSlope = this_.getPath('model.slope'),
            tDigits = DG.PlotUtilities.findNeededFractionDigits(
                tSlope, tIntercept,
                this_.get('xAxisView'), this_.get('yAxisView')),
            tIntNumFormat = DG.Format.number().group('').fractionDigits(0, tDigits.interceptDigits),
            tInterceptString = tIntNumFormat(tIntercept) + getInterceptUnitString(),
            tSlopeNumFormat = DG.Format.number().group('').fractionDigits(0, tDigits.slopeDigits),
            tSlopeUnit = getSlopeUnit(),
            tSlopeAsString = tSlopeNumFormat(tSlope),
            tFormattedSlopeUnit = kUnitsWrapper.loc(tSlopeUnit),
            tSlopeString = (SC.empty(tSlopeUnit) ? "" : "(") + tSlopeAsString + tFormattedSlopeUnit + " ",
            tSign = (tIntercept < 0) ? " " : " + ",
            tXIsDateTime = this_.getPath('xAxisView.isDateTime'),
            tYVar = this_.getPath('yAxisView.model.firstAttributeName'),
            tXVar = this_.getPath('xAxisView.model.firstAttributeName'),
            tEquationColor = this_.get('equationColor');
        if (tXIsDateTime) {
          handleDateTime();
          var tLeftSideString = 'DG.ScatterPlotModel.slopeOnly'.loc();
          return kSlopeOnly.loc(tEquationColor, tLeftSideString, tSlopeString, tXVar);
        }
        // When the intercept string is zero, don't display it (even if the numeric value is not zero).
        if (tIntNumFormat(tIntercept) === "0")
          tInterceptString = tSign = "";
        if (tSlopeAsString === "1" && SC.empty(tSlopeUnit))
          tSlopeString = "";
        if (tSlopeAsString === "0") {
          tSlopeString = '';
          tXVar = '';
          tSign = '';
        }
        if(tXVar.length > 1) {
          kSlopeInterceptForm = kSlopeInterceptXMultiple;
        }
        return kSlopeInterceptForm.loc(tEquationColor, tYVar, tSlopeString, tXVar, tSign, tInterceptString);
      }

      function equationForInfiniteSlopeLine() {
        var tDigits = DG.PlotUtilities.findFractionDigitsForAxis(this_.get('xAxisView')),
            tXIntercept = this_.getPath('model.xIntercept'),
            tXVar = this_.getPath('xAxisView.model.firstAttributeName'),
            tXUnit = this_.getPath('xAxisView.model.firstAttributeUnit'),
            tColor = this_.get('equationColor');
        return kInfiniteSlope.loc(tColor, tXVar,
            DG.Format.number().group('').fractionDigits(0, tDigits)(tXIntercept),
            kUnitsWrapper.loc(tXUnit));
      }

      if (this.getPath('model.isVertical'))
        return equationForInfiniteSlopeLine();
      else
        return equationForFiniteSlopeLine();

    }.property('model.intercept', 'model.slope', 'model.isVertical', 'model.xIntercept',
        'xAxisView.model.firstAttributeName', 'yAxisView.model.firstAttributeName').cacheable(),

    sumResidSquaredString: function () {
      var tResult = '';
      if (this.getPath('model.showSumSquares')) {
        var tSumSquares = this.getPath('model.sumSquaresResiduals'),
            tMaxDec = tSumSquares > 100 ? 0 : 3,
            tFormat = DG.Format.number().fractionDigits(0, tMaxDec),
            tSquaresString = SC.none(tSumSquares) ? '' : tFormat(tSumSquares),
            tLeftSideString = "DG.ScatterPlotModel.sumSquares".loc();
        tResult = kSumSquares.loc(this.get('equationColor'), tLeftSideString, tSquaresString);
      }
      return tResult;
    }.property(),

    createElements: function () {
      var this_ = this;
      if (this.myElements && (this.myElements.length > 0))
        return; // already created
      var tPaper = this.get('paper'),
          tDataTipLayer = this.getPath('paperSource.layerManager')[DG.LayerNames.kDataTip],
          tAdornmentLayer = this.getPath('paperSource.layerManager')[DG.LayerNames.kAdornments],
          tLineColor = this.get('lineColor'),
          tMouseStart, tOriginalCoordinates, tReturnPoint;

      this.lineSeg = tPaper.line(0, 0, 0, 0)
          .attr({stroke: tLineColor, 'stroke-opacity': 0});
      this.lineSeg.animatable = true;

      this.coverSeg = tPaper.line(0, 0, 0, 0)
          .attr({stroke: tLineColor, 'stroke-opacity': 0.001, 'stroke-width': 6})
          .hover(highlightElements, unHighlightElements);
      this.coverSeg.animatable = false;

      function highlightElements() {
        this_.lineSeg.attr('stroke-width', 2);
        this_.equation.set('highlighted', true);
      }

      function unHighlightElements() {
        this_.lineSeg.attr('stroke-width', 1);
        this_.equation.set('highlighted', false);
      }

      function beginDrag(event) {
        var tEqView = this;

        function getCurrentCoords() {
          var tFrame = tEqView.get('frame'),
              tXCenter = tFrame.x + tFrame.width / 2,
              tYCenter = tFrame.y + tFrame.height / 2;
          return {
            proportionCenterX: tXCenter / this_.get('paper').width,
            proportionCenterY: tYCenter / this_.get('paper').height
          };
        }

        tMouseStart = {x: event.clientX, y: event.clientY};
        tOriginalCoordinates = this_.getPath('model.equationCoords');
        tReturnPoint = SC.none(tOriginalCoordinates) ? getCurrentCoords() : tOriginalCoordinates;
        return YES;
      }

      function continueDrag(event) {
        var dX = (event.clientX - tMouseStart.x) / 2,
            dY = (event.clientY - tMouseStart.y) / 2,
            tPaper = this_.get('paper');
        this_.setPath('model.equationCoords', {
          proportionCenterX: tReturnPoint.proportionCenterX + dX / tPaper.width,
          proportionCenterY: tReturnPoint.proportionCenterY + dY / tPaper.height
        });
      }

      function endDrag(iEvent) {
        var tOriginal = tOriginalCoordinates,
            tNew;
        DG.UndoHistory.execute(DG.Command.create({
          name: "graph.repositionEquation",
          undoString: 'DG.Undo.graph.repositionEquation',
          redoString: 'DG.Redo.graph.repositionEquation',
          log: "Moved equation from %@ to %@".fmt(tOriginal, this.getPath('model.coordinates')),
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'reposition equation',
              type: 'DG.GraphView'
            }
          },
          execute: function () {
            tNew = this_.getPath('model.equationCoords');
          }.bind(this),
          undo: function () {
            this_.setPath('model.equationCoords', tOriginal);
          }.bind(this),
          redo: function () {
            this_.setPath('model.equationCoords', tNew);
          }.bind(this)
        }));
      }

      this.equation = DG.EquationView.create({
        highlight: highlightElements,
        unhighlight: unHighlightElements,
        mouseDown: beginDrag,
        mouseDragged: continueDrag,
        mouseUp: endDrag
      });
      this.get('paperSource').appendChild(this.equation);
      // Tune up the line rendering a bit
      this.lineSeg.node.setAttribute('shape-rendering', 'geometricPrecision');

      this.myElements = [this.lineSeg, this.coverSeg];
      tDataTipLayer.push(this.coverSeg);
      tAdornmentLayer.push(this.lineSeg);
    },

    positionEquationAndBackground: function () {
      var tModel = this.get('model');
      if (!tModel.get('isVisible')) // Only update if we're visible
        return;
      tModel.recomputeSlopeAndInterceptIfNeeded();
      var tSlope = tModel.get('slope'),
          tIntercept = tModel.get('intercept');
      this.showElements();
      if (this.myElements === null)
        this.createElements();
      var tXAxisView = this.get('xAxisView'),
          tYAxisView = this.get('yAxisView'),
          tYLowerBound = tYAxisView.getPath('model.lowerBound'),
          tYUpperBound = tYAxisView.getPath('model.upperBound'),
          // Form of tIntercepts is { pt1: { x, y }, pt2: { x, y }} in world coordinates
          tIntercepts = (tModel.get('isVertical')) ?
              {
                pt1: {x: tModel.get('xIntercept'), y: tYLowerBound},
                pt2: {x: tModel.get('xIntercept'), y: tYUpperBound}
              } :
              DG.PlotUtilities.lineToAxisIntercepts(
                  tSlope, tIntercept, tXAxisView.get('model'), tYAxisView.get('model'));

      function worldToScreen(iWorld) {
        return {
          x: tXAxisView.dataToCoordinate(iWorld.x),
          y: tYAxisView.dataToCoordinate(iWorld.y)
        };
      }

      function swapIntercepts() {
        var tSwap = tIntercepts.pt1;
        tIntercepts.pt1 = tIntercepts.pt2;
        tIntercepts.pt2 = tSwap;
      }

      function computeBestCoords() {
        var tTextAnchor = worldToScreen({
          x: (tIntercepts.pt1.x + tIntercepts.pt2.x) / 2,
          y: (tIntercepts.pt1.y + tIntercepts.pt2.y) / 2
        });
        return tTextAnchor;
      }

      function computeCoordsFromModel() {
        var tBoxCenterX = tEquationCoords.proportionCenterX * tPaperWidth,
            tBoxCenterY = tEquationCoords.proportionCenterY * tPaperHeight;
        return {x: tBoxCenterX - tTextWidth / 2, y: tBoxCenterY - tFrame.height / 2};
      }

      if (tIntercepts.pt2.x < tIntercepts.pt1.x)
        swapIntercepts();

      var kPadding = 3,
          tPaperWidth = this.get('paper').width,
          tPaperHeight = this.get('paper').height,
          tEquationCoords = this.getPath('model.equationCoords'),
          tScreen1 = worldToScreen(tIntercepts.pt1),
          tScreen2 = worldToScreen(tIntercepts.pt2),
          tFrame, tTextWidth;

      DG.RenderingUtilities.updateLine(this.lineSeg, tScreen1, tScreen2);
      DG.RenderingUtilities.updateLine(this.coverSeg, tScreen1, tScreen2);

      tFrame = this.getPath('equation.frame');
      tTextWidth = tFrame.width;
      tTextWidth += kPadding; // padding
      if (SC.none(tEquationCoords)) {
        tEquationCoords = computeBestCoords();
      } else {
        tEquationCoords = computeCoordsFromModel();
      }
      // this.equation.adjust({color: tEquationColor})
      this.equation.show(tEquationCoords, this.get('equationString'));

      // this.lineSeg.attr({ stroke: tLineColor });
    },

    updateVisibility: function () {
      arguments.callee.base.apply(this,arguments);
      if (this.equation) {
        if (this.getPath('model.isVisible')) {
          this.equation.set('isVisible', true);
        } else {
          this.equation.hide();
        }
      }
    },

    enableMeasuresForSelectionDidChange: function () {
      // Subclasses may override
    }

  };
}())
);


/* >>>>>>>>>> BEGIN source/components/graph/utilities/plot_utilities.js */
// ==========================================================================
//                            DG.PlotUtilities
//
//  DG.PlotUtilities is comprised of functions generally useful in plots.
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

DG.PlotUtilities = {

  // Constants for graphs
  kAxisColor: "#ccc",
  kEmptyPromptColor: '#999999',
  kRuleColor: '#ddd',   // graph background grid lines
  kRuleWidth: 1,
  kZeroLineColor: '#555',
  kZeroLineWidth: 1,
  kBinBorderLineColor: "rgba(115, 191, 202)",
  kBinBorderWidth: 1,
  kDefaultMovablePointColor: "yellow",
  kDefaultMovablePointRadius: 8,
  kDefaultMovableLineColor: "steelblue",
  kMovableLineHighlightColor: 'rgba(70, 30, 180, 0.2)',
  kMovableValueCapSize: 6,  // pixels on a side
  kDefaultLSRLColor: "green",
  kLineHighlightColor: "rgba(255, 0, 0, 0.3)",
  kPlotCellFill: 'rgba(128, 128, 128, 0)', // transparent
  kPlotCellStroke: '#eee',
  kStrokeDarkerFactor: 3,
  kPointRadiusLogBase: 2.0, // reduce point radius from max by log of (num. cases) base (LogBase).
  kPointRadiusMax: 10,
  kPointRadiusMin: 3,
  kPointRadiusSelectionAddend: 1,
  kDefaultPointColor: '#e6805b',
  kDefaultStrokeColor: 'white',
  kDefaultStrokeColorWithLegend: 'lightgrey',
  kDefaultPointOpacity: 0.85,
  kDefaultStrokeOpacity: 0.4,
  kDefaultStrokeOpacityWithLegend: 0.4,
  kDefaultStripWidth: 4,
  kMarqueeColor: "rgba(128, 128, 128, 0.3)",
  kDotClassName: 'dg-data-dot',
  kSelectedDotClassName: 'dg-data-dot-selected',
  kColoredDotClassName: 'dg-data-dot-colored',
  kSelectedColoredDotClassName: 'dg-data-dot-colored-selected',
  kDotClasses: ['dg-data-dot', 'dg-data-dot-selected', 'dg-data-dot-colored', 'dg-data-dot-colored-selected'],
  kToolTipClassName: 'dg-data-tip',
  kToolTipShadowClassName: 'dg-data-tip-shadow',
  kToolTipTextClassName: 'dg-data-tip-text',
  kStripClassName: 'dg-data-strip',
  kSelectedStripClassName: 'dg-data-strip-selected',
  kColoredStripClassName: 'dg-data-strip-colored',
  kSelectedColoredStripClassName: 'dg-data-strip-colored-selected',
  kLegendKey: 'legend-key',
  kLegendKeySelected: 'legend-key-selected',
  kLegendKeyName: 'legend-key-name',
  kMapColorRangeOffset: 0.0, // Offset proportion used to lower the apparent color min for map area coloring
  kDefaultAnimationTime: 1000,  // milliseconds
  kDataTipShowTime: 500, // milliseconds delay time before data tips appear
  kHighlightShowTime: 100, // milliseconds delay time before adornment highlighting appears
  kHighlightHideTime: 250, // milliseconds delay time before various tips/highlighting disappears
  kDataHoverTransform: 's1.5',  // scale 1.5 times on hover
  kDataCreateTransform: 's2',   // scale 2 times on create
  kBoxplotMaxWidth: 20,
  kMovableRegionOpacity: 0.3,
  kOther: '_other_', // Used as key to category map entry that stashes overflow of what doesn't fit on cell axis. Not likely to be an attribute value

  // Constants for maps
  kDefaultMapFillOpacity: '0.5',
  kDefaultMapStrokeColor: 'white',
  kDefaultMapStrokeOpacity: '0.6',
  kMapAreaNoLegendColor: '#FF3E00',
  kMapAreaNoLegendSelectedColor: '#1a7a93',
  kMapAreaNoLegendUnselectedOpacity: 0.5,
  kMapAreaNoLegendSelectedOpacity: 0.7,
  kMapAreaWithLegendSelectedOpacity: 0.9,
  kMapAreaWithLegendUnselectedOpacity: 0.9,
  kMapAreaNoLegendSelectedBorderColor: 'black',
  kMapAreaWithLegendUnselectedBorderColor: 'white',
  kMapAreaWithLegendSelectedBorderColor: 'red',
  kMapAreaSelectedBorderWeight: 3,
  kMapAreaUnselectedBorderWeight: 2,


  //  DG.PlotUtilities.lineToAxisIntercepts
  //
  //  Return the two points in logical coordinates where the line with the given
  //  iSlope and iIntercept intersects the rectangle defined by the upper and lower
  //  bounds of the two axes.
  //  The returned object has the form
  //    { pt1: { x, y }, pt2: { x, y }}
  lineToAxisIntercepts: function (iSlope, iIntercept, iXAxis, iYAxis) {

    function getLogicalBoundsRect() {
      return {
        left: iXAxis.get('lowerBound'),
        top: iYAxis.get('upperBound'),
        right: iXAxis.get('upperBound'),
        bottom: iYAxis.get('lowerBound')
      };
    }

    var tX1, tY1, tX2, tY2,
        tLogicalBounds = getLogicalBoundsRect();
    // Things can get hairy for nearly horizontal or nearly vertical lines.
    // This conditional takes care of that.
    if (Math.abs(iSlope) > 1) {
      tY1 = tLogicalBounds.bottom;
      tX1 = (tY1 - iIntercept) / iSlope;
      if (tX1 < tLogicalBounds.left) {
        tX1 = tLogicalBounds.left;
        tY1 = iSlope * tX1 + iIntercept;
      } else if (tX1 > tLogicalBounds.right) {
        tX1 = tLogicalBounds.right;
        tY1 = iSlope * tX1 + iIntercept;
      }

      tY2 = tLogicalBounds.top;
      tX2 = (tY2 - iIntercept) / iSlope;
      if (tX2 > tLogicalBounds.right) {
        tX2 = tLogicalBounds.right;
        tY2 = iSlope * tX2 + iIntercept;
      } else if (tX2 < tLogicalBounds.left) {
        tX2 = tLogicalBounds.left;
        tY2 = iSlope * tX2 + iIntercept;
      }
    } else {
      tX1 = tLogicalBounds.left;
      tY1 = iSlope * tX1 + iIntercept;
      if (tY1 < tLogicalBounds.bottom) {
        tY1 = tLogicalBounds.bottom;
        tX1 = (tY1 - iIntercept) / iSlope;
      } else if (tY1 > tLogicalBounds.top) {
        tY1 = tLogicalBounds.top;
        tX1 = (tY1 - iIntercept) / iSlope;
      }

      tX2 = tLogicalBounds.right;
      tY2 = iSlope * tX2 + iIntercept;
      if (tY2 > tLogicalBounds.top) {
        tY2 = tLogicalBounds.top;
        tX2 = (tY2 - iIntercept) / iSlope;
      } else if (tY2 < tLogicalBounds.bottom) {
        tY2 = tLogicalBounds.bottom;
        tX2 = (tY2 - iIntercept) / iSlope;
      }
    }

    // It is helpful to keep x1 < x2
    if (tX1 > tX2) {
      var tmp = tX1;
      tX1 = tX2;
      tX2 = tmp;

      tmp = tY1;
      tY1 = tY2;
      tY2 = tmp;
    }
    return {
      pt1: {x: tX1, y: tY1},
      pt2: {x: tX2, y: tY2}
    };
  },

  /**
   * Return a point in screen coordinates that is closest to the given point (scrn coords)
   * and on the line (in world coords).
   * @param iPt { x: <Number> y: <Number } in screen coords
   * @param iLine { slope: <Number> intercept: <Number> } in world coordinates
   * @param iXAxis { DG.CellLinearAxisView }
   * @param iYAxis { DG.CellLinearAxisView }
   * @return { x: <Number> y: <Number> } in screen coords
   */
  closestScreenPtGivenScreenPtAndWorldLine: function (iPt, iLine, iXAxis, iYAxis) {
    var tWorldX = iXAxis.coordinateToData(iPt.x),
        tWorldY = iYAxis.coordinateToData(iPt.y),
        tWorldResX = (iLine.slope === 0) ? tWorldX :
            (tWorldY - iLine.intercept + (tWorldX / iLine.slope)) /
            (iLine.slope + (1 / iLine.slope)),
        tWorldResY = iLine.slope * tWorldResX + iLine.intercept;
    return {
      x: iXAxis.dataToCoordinate(tWorldResX),
      y: iYAxis.dataToCoordinate(tWorldResY)
    };
  },

  //  DG.PlotUtilities.lineIntersectsPlotArea
  //
  // Does the line with the given slope and intercept intersect the
  // plot area defined by the two axes?
  // This algorithm does not work for lines with infinite slope. Caller must check.
  lineIntersectsPlotArea: function (iSlope, iIntercept, iXAxis, iYAxis) {
    DG.assert(isFinite(iSlope));
    var tXLowerBounds = iXAxis.get('lowerBound'),
        tXUpperBounds = iXAxis.get('upperBound'),
        tYLowerBounds = iYAxis.get('lowerBound'),
        tYUpperBounds = iYAxis.get('upperBound');

    // Try each border in turn
    return DG.MathUtilities.isInRange(iSlope * tXLowerBounds + iIntercept,
            tYLowerBounds, tYUpperBounds) ||
        DG.MathUtilities.isInRange(iSlope * tXUpperBounds + iIntercept,
            tYLowerBounds, tYUpperBounds) ||
        DG.MathUtilities.isInRange((tYLowerBounds - iIntercept) / iSlope,
            tXLowerBounds, tXUpperBounds) ||
        DG.MathUtilities.isInRange((tYUpperBounds - iIntercept) / iSlope,
            tXLowerBounds, tXUpperBounds);
  },

  /**
   *
   * @param iPt {x:{Number}, y:{Number}}
   * @param iXAxis
   * @param iYAxis
   * @return {Boolean}
   */
  isPointInPlotArea: function (iPt, iXAxis, iYAxis) {
    return DG.MathUtilities.isInRange(iPt.x, iXAxis.get('lowerBound'), iXAxis.get('upperBound')) &&
        DG.MathUtilities.isInRange(iPt.y, iYAxis.get('lowerBound'), iYAxis.get('upperBound'));
  },

  /**
   Return the number of fraction digits that should be displayed in the
   world value for an axis coordinate so that the position will be given
   to within one screen pixel.
   @param {DG.CellLinearAxisView}
   @return {Number}
   */
  findFractionDigitsForAxis: function (iAxisView) {
    if (!iAxisView)
      return null;

    var tMiddle = (iAxisView.get('pixelMin') + iAxisView.get('pixelMax')) / 2,
        tDelta = iAxisView.coordinateToData(tMiddle) -
            iAxisView.coordinateToData(tMiddle + 1),
        tLogDelta = Math.floor(Math.log(Math.abs(tDelta)) / Math.LN10);
    return Math.max(-tLogDelta, 0);
  },

  /**
   Return the number of fraction digits that will work reasonably well to describe a value
   belonging to a set with the given range.
   @param {min: {Number}, max: {Number}}
   @return {Number}
   */
  findFractionDigitsForRange: function (iRange) {
    return (iRange.max - iRange.min === 0) ? 2 :
        Math.max(-Math.floor(Math.log((iRange.max - iRange.min) / 1000) / Math.LN10), 0);
  },

  /**
   Return the number of fraction digits that should be displayed in the
   equation of a line so that it won't vary by more than a pixel from the
   actual line in the frame set by the two axes.
   This algorithm does not work for lines with infinite slope. Caller must check.
   @param {Number} The actual slope of the line
   @param {Number} Intercept of the line
   @param {DG.CellLinearAxisView}
   @param {DG.CellLinearAxisView}
   @return {{slopeDigits: {Number}, interceptDigits: {Number}}}
   */
  findNeededFractionDigits: function (iSlope, iIntercept, iXAxisView, iYAxisView) {
    var kMaxDigits = 12,  // Never try for more than this
        tXAxisModel = iXAxisView.get('model'),
        tYAxisModel = iYAxisView.get('model'),
        tCurrCoords, tTrialCoords,
        tGreatestDiff,
        tApproxIntercept, tApproxSlope,
        oInterceptDigits = 2,
        oSlopeDigits = (iSlope < 0.001 && iSlope !== 0) ? Math.abs(Math.floor(Math.log10(Math.abs(iSlope)))) + 1 : 3;

    function convertToScreen(iWorldPts) {
      iWorldPts.pt1.x = iXAxisView.dataToCoordinate(iWorldPts.pt1.x);
      iWorldPts.pt1.y = iYAxisView.dataToCoordinate(iWorldPts.pt1.y);
      iWorldPts.pt2.x = iXAxisView.dataToCoordinate(iWorldPts.pt2.x);
      iWorldPts.pt2.y = iYAxisView.dataToCoordinate(iWorldPts.pt2.y);
      return iWorldPts;
    }

    function greatestDiff() {
      var tDiff;
      tDiff = Math.max(Math.abs(tTrialCoords.pt1.x - tCurrCoords.pt1.x),
          Math.abs(tTrialCoords.pt1.y - tCurrCoords.pt1.y));
      tDiff = Math.max(tDiff, Math.abs(tTrialCoords.pt2.x - tCurrCoords.pt2.x));
      tDiff = Math.max(tDiff, Math.abs(tTrialCoords.pt2.y - tCurrCoords.pt2.y));
      return tDiff;
    }

    if (isNaN(iSlope) || isNaN(iIntercept) || SC.none(iSlope) || SC.none(iIntercept)) {
      return {slopeDigits: 0, interceptDigits: 0};
    }

    // { pt1: { x, y }, pt2: { x, y }}
    tCurrCoords = convertToScreen(DG.PlotUtilities.lineToAxisIntercepts(
        iSlope, iIntercept, tXAxisModel, tYAxisModel));

    do {  // Intercept
      // { { roundedValue: {Number}, decPlaces: {Number} }}
      tApproxIntercept = DG.MathUtilities.roundToSignificantDigits(
          iIntercept, oInterceptDigits);
      // Compute the approximated values
      tTrialCoords = convertToScreen(DG.PlotUtilities.lineToAxisIntercepts(
          iSlope, tApproxIntercept.roundedValue, tXAxisModel, tYAxisModel));
      tGreatestDiff = greatestDiff();
      if (tGreatestDiff > 1.0)
        oInterceptDigits += 1;
    } while ((tGreatestDiff > 1.0) && (oInterceptDigits < kMaxDigits));

    do {
      tApproxSlope = DG.MathUtilities.roundToSignificantDigits(
          iSlope, oSlopeDigits);
      tTrialCoords = convertToScreen(DG.PlotUtilities.lineToAxisIntercepts(
          tApproxSlope.roundedValue, iIntercept, tXAxisModel, tYAxisModel));
      tGreatestDiff = greatestDiff();
      if (tGreatestDiff > 1.0)
        oSlopeDigits += 1;
    } while ((tGreatestDiff > 1.0) && (oSlopeDigits < kMaxDigits));

    // So far we've computed the number of significant digits needed. But we need to return
    //  the number of fractional digits.
    if (Math.abs(iSlope) > 1)
      oSlopeDigits = Math.max(0, oSlopeDigits - Math.floor(Math.log(Math.abs(iSlope)) / Math.LN10) - 1);
    if (Math.abs(iIntercept) > 1)
      oInterceptDigits = Math.max(0, oInterceptDigits - Math.floor(Math.log(Math.abs(iIntercept)) / Math.LN10) - 1);

    return {slopeDigits: oSlopeDigits, interceptDigits: oInterceptDigits};
  },

  getFormattedNumericValue: function (iValue, iGetDigitsFunc) {
    var tDigits, tNumFormat,
        tResult = '';
    if (!SC.empty(iValue)) {
      tDigits = iGetDigitsFunc();
      if (SC.none(tDigits))  // Can happen for maps when there is no axis view
        tDigits = 2;
      tNumFormat = DG.Format.number().fractionDigits(0, tDigits);
      tNumFormat.group(''); // Don't separate with commas
      tResult = tNumFormat(iValue);
    }
    return tResult;
  },

  getFormattedCaseValue: function (iCase, iAttrDesc, iGetDigitsFunc, iAttrIndex) {
    iAttrIndex = !SC.none(iAttrIndex) ? iAttrIndex : 0;
    var tAttrs = iAttrDesc.get('attributes'),
        tAttr = SC.isArray(tAttrs) ? tAttrs[iAttrIndex] : null,
        tAttrID = tAttr ? tAttrs[iAttrIndex].get('id') : null,
        tType = iAttrDesc.get('attributeType'),
        tValue = iCase && !SC.none(tAttrID) && iCase.getValue(tAttrID),
        tRawAttrType = tAttr.get('type'),
        tDigits, tNumFormat;
    if (SC.empty(tValue)) return '';
    switch (tType) {
      case DG.Analysis.EAttributeType.eNumeric:
        tValue = iCase.getForcedNumericValue(tAttrID);
        tDigits = iGetDigitsFunc();
        if (SC.none(tDigits))  // Can happen for maps when there is no axis view
          tDigits = 2;
        if ((tRawAttrType === DG.Attribute.TYPE_NUMERIC) && DG.MathUtilities.notAYear(tValue)) {
          tValue = Intl.NumberFormat(DG.get('currentLanguage'),
              {maximumFractionDigits: tDigits}).format(tValue);
        } else {
          tNumFormat = DG.Format.number().fractionDigits(0, tDigits);
          tNumFormat.group(''); // Don't separate with commas
          tValue = tNumFormat(tValue);
        }
        break;
      case DG.Analysis.EAttributeType.eDateTime:
        tValue = DG.DateUtilities.formatDate(tValue);
        break;
      default:
        tValue = iCase.getStrValue(tAttrID);
    }
    return tValue;
  },

  doCreateCircleAnimation: function (iCircle) {
    //iCircle.attr( { 'fill-opacity': 0, 'stroke-opacity': 0 });
    //iCircle.animate({ 'fill-opacity': this.kDefaultPointOpacity, 'stroke-opacity': 1 },
    //  this.kDefaultAnimationTime, '<>');
//    iCircle.animate( {
//      "25%": { transform: this.kDataCreateTransform, easing: "<" },
//      "100%": { transform: "", easing: ">" }
//      }, this.kDefaultAnimationTime);
  },

  /**
   * Called when we wish to animate the removal of an element, especially one stashed in a layer.
   * Note that the animation depends on there being fill and/or stroke.
   * todo: Find a way to reinstate animation
   * @param iElement
   * @param iLayerManager
   */
  doHideRemoveAnimation: function (iElement, iLayerManager) {
    if (iElement) {
      iElement.attr({'fill-opacity': 0, opacity: 0});
      iElement.hide();
      // Remove event handlers
      if (iElement.events) {
        iElement.events.forEach(function (iHandler) {
          iHandler.unbind();
        });
        iElement.events.length = 0;
      }
      if (iLayerManager)
        iLayerManager.removeElement(this);
    }
  },

  /**
   * Modification of Raphael's setFillAndStroke, tuned to CODAP's situation of just working with circle and rect elements
   * @param o {Raphael Element}
   * @param params {Object}
   */
  setPlottedPointAttributes: function (o, params) {
    var node = o.node,
        attrs = o.attrs,
        R = Raphael,
        has = "hasOwnProperty";
    for (var att in params) {
      if (params[has](att)) {
        if (!R._availableAttrs[has](att)) {
          continue;
        }
        if (o.attr(att) === params[att]) {
          continue;
        }
        var value = params[att];
        attrs[att] = value;
        switch (att) {
          case "cursor":
            node.style.cursor = value;
            break;
          case "transform":
            o.transform(value);
            break;
          case "cx":
          case "cy":
          case "x":
          case "y":
          case "width":
          case "height":
            if (isFinite(value)) {
              node.setAttribute(att, value);
              o._.dirty = 1;
            }
            break;
          case "r":
            if (o.type == "rect") { // eslint-disable-line eqeqeq
              $(node, {rx: value, ry: value});
            } else {
              node.setAttribute(att, value);
            }
            o._.dirty = 1;
            break;
          case "stroke-width":
            node.setAttribute(att, value);
            break;
          case "fill":
            var clr = R.getRGB(value);
            if (!clr.error) {
              delete params.gradient;
              delete attrs.gradient;
              !R.is(attrs.opacity, "undefined") &&
              R.is(params.opacity, "undefined") &&
              $(node, {opacity: attrs.opacity});
              !R.is(attrs["fill-opacity"], "undefined") &&
              R.is(params["fill-opacity"], "undefined") &&
              $(node, {"fill-opacity": attrs["fill-opacity"]});
            }
            clr[has]("opacity") && $(node, {
              "fill-opacity": clr.opacity > 1 ?
                  clr.opacity / 100 : clr.opacity
            });
            // fall through
          case "stroke":
            clr = R.getRGB(value);
            node.setAttribute(att, clr.hex);
            att == "stroke" && clr[has]("opacity") &&   // eslint-disable-line eqeqeq
            $(node, {"stroke-opacity": clr.opacity > 1 ? clr.opacity / 100 : clr.opacity});
            break;
          case "opacity":
            if (attrs.gradient && !attrs[has]("stroke-opacity")) {
              $(node, {"stroke-opacity": value > 1 ? value / 100 : value});
            }
            // fall through
          default:
            att == "font-size" && (value = parseInt(value, 10) + "px"); // eslint-disable-line eqeqeq
            var cssrule = att.replace(/(\-.)/g, function (w) {
              return w.substring(1).toUpperCase();
            });
            node.style[cssrule] = value;
            o._.dirty = 1;
            node.setAttribute(att, value);
            break;
        }
      }
    }
  },

  mapAxisViewClassToAxisModelClass: function (iViewClass) {
    var tModelClass = DG.AxisModel;
    switch (iViewClass) {
      case DG.CellAxisView:
        tModelClass = DG.CellAxisModel;
        break;
      case DG.CellLinearAxisView:
      case DG.QualCellLinearAxisView:
        tModelClass = DG.CellLinearAxisModel;
        break;
      case DG.CountAxisView:
        tModelClass = DG.CountAxisModel;
        break;
      case DG.BinnedAxisView:
        tModelClass = DG.BinnedAxisModel;
        break;
      case DG.FormulaAxisView:
        tModelClass = DG.FormulaAxisModel;
        break;
    }
    return tModelClass;
  },

  /**Called when the user drags legend category keys
   * @param iIndex1 {Number}
   * @param iIndex2 {Number}
   */
  swapCategoriesByIndex: function (iAttributeDescription, iIndex1, iIndex2) {
    var tCategoryMap = iAttributeDescription.getPath('attribute.categoryMap'),
        tOrder = tCategoryMap.__order || [],
        tAttribute = iAttributeDescription.get('attribute');
    DG.assert(DG.ObjectMap.length(tCategoryMap) !== 0);
    var tSaved = tOrder[iIndex1];
    tOrder[iIndex1] = tOrder[iIndex2];
    tOrder[iIndex2] = tSaved;
    iAttributeDescription.setPath('attribute.categoryMap', tCategoryMap);
    tAttribute.notifyPropertyChange('categoryMap');
    iAttributeDescription.invalidateCaches();
  }

};

/* >>>>>>>>>> BEGIN source/components/graph/adornments/lsrl_adornment.js */
// ==========================================================================
//                      DG.LSRLAdornment
//
//  Author:   William Finzer
//
//  Copyright (c) 2016 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
/* global tinycolor */

sc_require('components/graph/adornments/twoD_line_adornment');
sc_require('components/graph/utilities/plot_utilities');

/** @class  Draws a least squares regression line.

  @extends DG.TwoDLineAdornment
*/
DG.LSRLAdornment = DG.TwoDLineAdornment.extend(
/** @scope DG.LSRLAdornment.prototype */ 
{
  defaultColor: DG.PlotUtilities.kDefaultLSRLColor,

  /**
   * This path is actually two curves, one above and one below the line.
   * At each value of x, the two y-values are the upper and lower bounds of the confidence interval
   * of the expected value of y.
   * @property { Raphael path element }
   */
  confidenceBandCurve: null,
  confidenceBandCurveCover: null,
  confidenceBandShading: null,

  lineColor: function() {

    var tLegendAttrDescription = this.getPath('model.plotModel.dataConfiguration.legendAttributeDescription');
    if(!tLegendAttrDescription || tLegendAttrDescription.isNull() || tLegendAttrDescription.get('isNumeric') ||
        tLegendAttrDescription.get('isColor')) {
      return arguments.callee.base.apply(this,arguments);
    }
    var tColor = DG.ColorUtilities.calcCaseColor(this.getPath( 'model.categoryName'),
                            tLegendAttrDescription);
    tColor = tColor.colorString || tColor;
    return tColor;
  }.property(),

  _infoTip: null,
  infoTip: function () {
    if (!this._infoTip) {
      var this_ = this;
      this._infoTip = DG.InfoTip.create({
        paperSource: function () {
          return this_.get('paperSource');
        }.property(),
      });
    }
    return this._infoTip;
  }.property(),

  equationString: function() {
    var tResult = arguments.callee.base.apply(this,arguments),
        kRSquared = '<p style = "color:%@;">r<sup>2</sup> = %@</p>',
        kSeSlope = '<p style = "color:%@;">&sigma;<sub style="vertical-align: sub">slope</sub> = %@</p>',
        kSeIntercept = '<p style = "color:%@;">&sigma;<sub style="vertical-align: sub">intercept</sub> = %@</p>';
    if( !this.getPath('model.isInterceptLocked')) {
      var tColor = this.get('equationColor'),
          tFormat = DG.Format.number().fractionDigits(0, 3),
          tRSquared = this.getPath('model.rSquared'),
          tRSquaredString = SC.none(tRSquared) ? '' : tFormat(tRSquared),
          tSeSlope = this.getPath('model.seSlope'),
          tSeSlopeString = SC.none(tSeSlope) ? '' : kSeSlope.loc(tColor, tFormat(tSeSlope)),
          tSeIntercept = this.getPath('model.seIntercept'),
          tSeInterceptString = SC.none(tSeIntercept) ? '' : kSeIntercept.loc(tColor, tFormat(tSeIntercept));

      tResult = tResult + kRSquared.loc(tColor, tRSquaredString) + tSeSlopeString + tSeInterceptString +
          this.get('sumResidSquaredString');
    }
    return tResult;
  }.property(),

  updateToModel: function() {
    this.positionEquationAndBackground();
  },

  createElements: function() {
    arguments.callee.base.apply(this,arguments);

    var this_ = this;

    function overScope(iEvent) {
      if(this_.getPath('model.showConfidenceBands')) {
        this_.get('infoTip').show({
          x: iEvent.offsetX - 5, y: iEvent.offsetY - 5,
          tipString: 'DG.ScatterPlotModel.LSRLCIBandInfo'.loc()
        });
      }
    }

    function outScope() {
      this_.get('infoTip').hide();
    }

    var tPaper = this.get('paper'),
       tDataTipLayer = this.getPath('paperSource.layerManager')[DG.LayerNames.kDataTip],
       tAdornmentLayer = this.getPath('paperSource.layerManager')[DG.LayerNames.kAdornments],
       tLayerForShading = this.getPath('paperSource.layerManager')[DG.LayerNames.kConnectingLines],
       tLineColor = this.get('lineColor'),
       tCurveColor = tinycolor(tLineColor).lighten(10).toHexString();
    this.confidenceBandCurve = tPaper.path( 'M,0,0')
                                     .attr({ stroke: tCurveColor, 'stroke-opacity': 0, 'stroke-dasharray': '- ' });
    this.confidenceBandCurve.animatable = true;
    this.confidenceBandCurveCover = tPaper.path( 'M,0,0')
                                .attr({ stroke: tLineColor, 'stroke-opacity': 0.001, 'stroke-width': 6 });
    this.confidenceBandCurveCover.animatable = false;
    this.confidenceBandShading = tPaper.path( 'M,0,0')
                                .attr({fill: tLineColor, 'stroke-width': 0, 'fill-opacity': 0 })
                                .hover(overScope, outScope);
    this.confidenceBandShading.animatable = true;

    this.myElements = this.myElements.concat([this.confidenceBandCurve, this.confidenceBandCurveCover,
      this.confidenceBandShading]);
    tDataTipLayer.push( this.confidenceBandCurveCover);
    tAdornmentLayer.push( this.confidenceBandCurve);
    tLayerForShading.push( this.confidenceBandShading);
  },

  positionEquationAndBackground: function() {
    arguments.callee.base.apply(this,arguments);
    var kAnimationTime = DG.PlotUtilities.kDefaultAnimationTime;
    if( !this.getPath('model.showConfidenceBands')) {
      this.confidenceBandCurve.animate({'stroke-opacity': 0 }, kAnimationTime, '<>');
      this.confidenceBandCurveCover.attr({path: 'M,0,0' });
      this.confidenceBandShading.animate({'fill-opacity': 0 }, kAnimationTime, '<>');
      return;
    }

    var tCount = this.getPath('model.count'),
       tContext = {
          count: tCount,
          sumSquaresX: this.getPath('model.xSumSquaredDeviations'),
          xMean: this.getPath('model.xMean'),
          slope: this.getPath('model.slope'),
          intercept: this.getPath('model.intercept'),
          mse: this.getPath('model.mse'),
          t: DG.MathUtilities.tAt0975ForDf(tCount - 2)
    };

    function confidenceValues(iX) {
      var tYHat = tContext.intercept + tContext.slope * iX,
          tStdErrorMeanEst = 1 / tContext.count + Math.pow(iX - tContext.xMean, 2) / tContext.sumSquaresX,
          tAddend = tContext.t * Math.sqrt(tContext.mse * tStdErrorMeanEst);
      return { lower: tYHat - tAddend, upper: tYHat + tAddend};
    }

    var tXAxisView = this.getPath('paperSource.xAxisView'),
       tYAxisView = this.getPath('paperSource.yAxisView'),
       tPixelMin = tXAxisView.get('pixelMin'),
       tPixelMax = tXAxisView.get('pixelMax'),
       tUpperPoints = [],
       tLowerPoints = [],
       tUpperPath = '',
       tLowerPath = '',
       tX, tYValues, tPixelX;
    for( tPixelX = tPixelMin; tPixelX <= tPixelMax; tPixelX+=10) {
      tX = tXAxisView.coordinateToData( tPixelX);
      tYValues = confidenceValues( tX);
      tUpperPoints.push( { left: tPixelX, top: tYAxisView.dataToCoordinate(tYValues.upper) });
      tLowerPoints.unshift( { left: tPixelX, top: tYAxisView.dataToCoordinate(tYValues.lower) });
    }
    if( tUpperPoints.length > 0) {
      // Accomplish spline interpolation
      tUpperPath = 'M' + tUpperPoints[0].left + ',' + tUpperPoints[0].top +
                   DG.SvgScene.curveBasis( tUpperPoints);
      tLowerPath = 'M' + tLowerPoints[0].left + ',' + tLowerPoints[0].top +
                   DG.SvgScene.curveBasis( tLowerPoints);
    }
    // The upper path starts at the left. The lower path starts at the right. We want to connect them
    // so that we get a region we can fill.
    var tCombinedPath = tUpperPath + tLowerPath.replace('M', 'L') + ' Z';
    this.confidenceBandCurve.attr({path: tUpperPath + tLowerPath });
    this.confidenceBandCurveCover.attr({path: tUpperPath + tLowerPath });
    this.confidenceBandShading.attr({path: tCombinedPath });
    this.confidenceBandShading.animate({'fill-opacity': 0.05 }, kAnimationTime, '<>');
  }

});


/* >>>>>>>>>> BEGIN source/components/graph/adornments/twoD_line_model.js */
// ==========================================================================
//                          DG.TwoDLineModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/adornments/plot_adornment_model');

/** @class  DG.TwoDLineModel - The model for a movable line.

  @extends DG.PlotAdornmentModel
*/
DG.TwoDLineModel = DG.PlotAdornmentModel.extend(
/** @scope DG.TwoDLineModel.prototype */ 
{
  /**
    The current slope of the line.
    @property { Number }
  */
  slope: null,

  /**
    The current intercept of the line.
    @property { Number }
  */
  intercept: null,

  /**
    True if the line is vertical
    @property { Boolean }
  */
  isVertical: false,

  /**
    If the line is vertical, it intersects the x-axis at this world value.
    @property { Number }
  */
  xIntercept: null,

  /**
   * Set by my plotModel when squares of residuals are showing
   */
  showSumSquares: false,

  /**
   * @property {Number}
   */
  sumSquaresResiduals: null,

  /**
   * Coordinates of the center of the equation rectangle as a proportion of the plot frame
   * @property {{proportionCenterX: {Number}, proportionCenterY: {Number}}}
   */
  equationCoords: null,

  /**
    Is the intercept locked at the origin?
    @property { Boolean }
  */
  isInterceptLocked: function( iKey, iLocked) {
    if( iLocked !== undefined) {
      this._interceptLocked = iLocked;
      this.setComputingNeeded();
      if( iLocked)
        this.set('intercept', 0);
    }
    return this._interceptLocked;
  }.property(),

  /**
    Use the bounds of the given axes to recompute slope and intercept.
  */
  toggleInterceptLocked: function() {
    this.set('isInterceptLocked', !this._interceptLocked);
  },

  /**
    Private cache.
    @property { Boolean }
  */
  _interceptLocked: null,

  /**
    Provide reasonable defaults.
  */
  init: function() {
    arguments.callee.base.apply(this,arguments);
    this.slope = 1;
    this.isVertical = false;
    this.xIntercept = null;
    this._interceptLocked = false;
    this._needsComputing = true;
  },

  /**
   Use the bounds of the given axes to recompute slope and intercept.
   */
  recomputeSlopeAndInterceptIfNeeded: function( iXAxis, iYAxis, iForSelection) {
    if( this.isComputingNeeded( iXAxis, iYAxis))
    {
      this.recomputeSlopeAndIntercept( iXAxis, iYAxis, iForSelection);
      this._needsComputing = false;
    }
  },

  /**
   * @return { [{x:{Number}, y: {Number} legend: {String|Number}}] } with properties specific to a given subclass
   * @param {Boolean}
   */
  getCoordinates: function() {
    var tValues = [],
        tCases = this.get('cases'),
        tXVarID = this.getPath('plotModel.xVarID'),
        tYVarID = this.getPath('plotModel.yVarID'),
        tlegendVarID = this.getPath('plotModel.legendVarID'),
        tLegendIsNumeric = this.getPath('plotModel.dataConfiguration.legendAttributeDescription.isNumeric');
    if( !SC.none(tCases)) {
      tCases.forEach(function (iCase) {
        var tXValue = iCase.getForcedNumericValue(tXVarID),
            tYValue = iCase.getForcedNumericValue(tYVarID),
            tLegendValue = tLegendIsNumeric ? null : iCase.getValue( tlegendVarID);
        if (isFinite(tXValue) && isFinite(tYValue)) {
          tValues.push({x: tXValue, y: tYValue, legend: tLegendValue});
        }
      });
    }
    return tValues;
  },

  createStorage: function() {
    var tStorage = arguments.callee.base.apply(this,arguments);
    DG.ObjectMap.copy( tStorage, {
      isInterceptLocked: this.get('isInterceptLocked'),
      equationCoords: this.get('equationCoords')
    });
    return tStorage;
  },

  /**
   * @param { Object } with properties specific to a given subclass
   */
  restoreStorage: function( iStorage) {
    arguments.callee.base.apply(this,arguments);
    if( iStorage) {
      this.set('isInterceptLocked', iStorage.isInterceptLocked);
      if( iStorage.equationCoords)
        this.set('equationCoords', iStorage.equationCoords);
    }
  }

});


/* >>>>>>>>>> BEGIN source/components/graph/adornments/lsrl_model.js */
// ==========================================================================
//                          DG.LSRLModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2016 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/adornments/twoD_line_model');

/** @class  DG.LSRLModel - The model for a least squares regression line.

 @extends DG.TwoDLineModel
 */
DG.LSRLModel = DG.TwoDLineModel.extend(
    /** @scope DG.TwoDLineModel.prototype */
    {
      /**
       * @property { Boolean }
       */
      showConfidenceBands: false,
      /**
       * @property {string}
       */
      categoryName: null,

      /**
       * @property {Number}
       */
      rSquared: null,

      /**
       * @property {Number}
       */
      sdResiduals: null,

      /**
       * @property {Number}
       */
      seSlope: null,

     /**
       * @property {Number}
       */
      seIntercept: null,

      getCoordinates: function() {
        var tCoordinates = arguments.callee.base.apply(this,arguments),
           tCategoryName = this.get('categoryName');
        return tCoordinates.filter( function( iCoords) {
          // '==' will provide equality when one is string and other is number
          // eslint-disable-next-line eqeqeq
          return SC.none( iCoords.legend) || tCategoryName == iCoords.legend ||  // jshint ignore:line
                 tCategoryName === '_main_';
        });
      },

      computeSumSquaresResiduals: function() {
        var tSumSquaresResiduals = 0,
            tSlope = this.get('slope'),
            tIntercept = this.get('intercept');
        this.getCoordinates().forEach(function (iCoordinates) {
          var tLineY = tIntercept + tSlope * iCoordinates.x,
              tResid = iCoordinates.y - tLineY;
          tSumSquaresResiduals += tResid * tResid;
        });
        this.setIfChanged('sumSquaresResiduals', tSumSquaresResiduals);
      },

      /**
       We compute the slope and intercept of the lsrl for the displayed points
       */
      recomputeSlopeAndIntercept: function () {
        var tInterceptIsLocked = this.get('isInterceptLocked'),
            tCoordinates = this.getCoordinates(),
            tSlopeIntercept, tSeSlope, tSeIntercept;
        tSlopeIntercept = DG.MathUtilities.leastSquaresLinearRegression( tCoordinates, tInterceptIsLocked);
        tSeSlope = this.get('showConfidenceBands') ? DG.MathUtilities.linRegrSESlopeAndIntercept( tCoordinates).seSlope
                                                   : null;
        tSeIntercept = this.get('showConfidenceBands')
                          ? DG.MathUtilities.linRegrSESlopeAndIntercept( tCoordinates).seIntercept : null;
        if( isNaN(tSlopeIntercept.slope) && isNaN( this.get('slope')) ||
            isNaN(tSlopeIntercept.intercept) && isNaN( this.get('intercept'))) {
          return; // not covered by setIfChanged
        }
        this.beginPropertyChanges();
          this.setIfChanged('count', tSlopeIntercept.count);
          this.setIfChanged('slope', tSlopeIntercept.slope);
          this.setIfChanged('intercept', tSlopeIntercept.intercept);
          this.setIfChanged('mse', tSlopeIntercept.mse);
          this.setIfChanged('xMean', tSlopeIntercept.xMean);
          this.setIfChanged('yMean', tSlopeIntercept.yMean);
          this.setIfChanged('xSumSquaredDeviations', tSlopeIntercept.xSumSquaredDeviations);
          this.setIfChanged('rSquared', tSlopeIntercept.rSquared);
          this.setIfChanged('seSlope', tSeSlope);
          this.setIfChanged('seIntercept', tSeIntercept);
          this.setIfChanged('isVertical', !isFinite(tSlopeIntercept.slope));
          this.setIfChanged('xIntercept', null);
          this.computeSumSquaresResiduals();
        this.endPropertyChanges();
      },

      createStorage: function() {
        var tStorage = arguments.callee.base.apply(this,arguments);
        tStorage.showConfidenceBands = this.showConfidenceBands;
        return tStorage;
      },

      /**
       * @param iStorage
       */
      restoreStorage: function( iStorage) {
        arguments.callee.base.apply(this,arguments);
        this.showConfidenceBands = iStorage.showConfidenceBands;
      }

    });


/* >>>>>>>>>> BEGIN source/components/graph/adornments/movable_line_adornment.js */
// ==========================================================================
//                      DG.MovableLineAdornment
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/adornments/twoD_line_adornment');
sc_require('components/graph/utilities/plot_utilities');

/** @class  Draws a movable line.

  @extends DG.TwoDLineAdornment
*/
DG.MovableLineAdornment = DG.TwoDLineAdornment.extend(
/** @scope DG.MovableLineAdornment.prototype */ 
{
  defaultColor: DG.PlotUtilities.kDefaultMovableLineColor,

  kLineSlideCur: DG.Browser.customCursorStr('../../../../static/dg/de/cert/resources/cursors/LineSlide.cur', 8, 8),
  kLineBotLeft: DG.Browser.customCursorStr('../../../../static/dg/de/cert/resources/cursors/LinePivotBotLeft.cur', 5, 12),
  kLineBotRight: DG.Browser.customCursorStr('../../../../static/dg/de/cert/resources/cursors/LinePivotBotRight.cur', 12, 12),
  kLineTopLeft: DG.Browser.customCursorStr('../../../../static/dg/de/cert/resources/cursors/LinePivotTopLeft.cur', 5, 5),
  kLineTopRight: DG.Browser.customCursorStr('../../../../static/dg/de/cert/resources/cursors/LinePivotTopRight.cur', 12, 5),

  kHandleSize: 12,

  /**
    We add three rectangular "handles" to indicate draggability
    @property { array of Raphael rectangle element }
  */
  hitHandles: null,

  /**
    The line is covered by three nearly transparent wider segments for hitting and hilighting
    @property { array of Raphael line element }
  */
  hitSegments: null,

  equationString: function() {
    var tResult = arguments.callee.base.apply(this,arguments);
    return tResult + this.get('sumResidSquaredString');
  }.property(),

  /**
    The line is defined by two pivot points
    @property { Point as in { x: <>, y: <> } } in world coordinates
  */
  pivot1: null,
  pivot2: null,

  /**
    Make the pieces of the movable line. This only needs to be done once.
  */
  createElements: function() {
    var this_ = this,
      tXAxisView = this.get('xAxisView'),
      tYAxisView = this.get('yAxisView'),
      tDragPoint, tLocked, tDragging = false;

    //=============Event handling functions===============
    function logDragResult() {
      var equation = this_.get('equationString');
      // Replace Unicode minus signs (used for display) with ASCII hyphens
      equation = equation.replace(/\u2212/g, "-");
      DG.logUser("dragMovableLine: '%@'", equation);
    }

    function overScope() {
      var tAttributes = { stroke: DG.PlotUtilities.kLineHighlightColor };
      this_.hitSegments.forEach(function(segment) {
        segment.stop();
        segment.animate(tAttributes, DG.PlotUtilities.kHighlightShowTime);
      });
    }

    function outScope() {
      var tAttributes = { stroke: DG.RenderingUtilities.kSeeThrough };
      if( !tDragging) {
        this_.hitSegments.forEach(function(segment) {
          segment.stop();
          segment.animate(tAttributes, DG.PlotUtilities.kHighlightHideTime);
        });
      }
    }

    function beginDrag( iWindowX, iWindowY) {
      var tLine = { slope: this_.getPath('model.slope'),
                    intercept: this_.getPath('model.intercept') };
      tDragPoint = DG.ViewUtilities.windowToViewCoordinates(
                    { x: iWindowX, y: iWindowY }, this_.parentView);
      if( this_.getPath('model.isVertical'))
        tDragPoint.x = tXAxisView.dataToCoordinate( this_.getPath('model.xIntercept'));
      else
        tDragPoint = DG.PlotUtilities.closestScreenPtGivenScreenPtAndWorldLine(
                              tDragPoint, tLine, tXAxisView, tYAxisView);
      tLocked = this_.getPath('model.isInterceptLocked');
      overScope();
      tDragging = true;
    }

    function continueTranslate( idX, idY) {
      this_.get('model').forceThroughPoint( {  x: tXAxisView.coordinateToData( tDragPoint.x + idX),
                          y: tYAxisView.coordinateToData( tDragPoint.y + idY) });
    }

    function endTranslate( idX, idY) {
      this_.pivot1 = this_.pivot2 = null;
      this_.updateToModel();  // needed to force re-computation of pivot points
      logDragResult();
      tDragging = false;
      outScope();
    }

    function beginRotation( iWindowX, iWindowY) {
      beginDrag( iWindowX, iWindowY);
    }

    function forceLineThroughPivots( iWorldDraggedPivot, iWorldStaticPivot, iScreenDraggedPivot, iScreenStaticPivot) {
      var kTolerance = 2;
      if( Math.abs(iScreenDraggedPivot.x - iScreenStaticPivot.x) < kTolerance) {
        // Snap to vertical
        iWorldDraggedPivot.x = iWorldStaticPivot.x;
      }
      else if( Math.abs(iScreenDraggedPivot.y - iScreenStaticPivot.y) < kTolerance) {
        // Snap to horizontal
        iWorldDraggedPivot.y = iWorldStaticPivot.y;
      }

      this_.get('model').forceThroughPoints( this_.pivot1, this_.pivot2);
    }

    function continueRotation1( idX, idY) {
      var tNewDragPt = { x: tDragPoint.x + idX, y: tDragPoint.y + idY },
          tStaticPivotPt = { x: tXAxisView.dataToCoordinate( this_.pivot2.x),
                            y: tYAxisView.dataToCoordinate( this_.pivot2.y) };
      this_.pivot1.x = tXAxisView.coordinateToData( tNewDragPt.x);
      this_.pivot1.y = tYAxisView.coordinateToData( tNewDragPt.y);
      if( tLocked)
        this_.get('model').forceThroughOriginAndPoint( this_.pivot1);
      else
        forceLineThroughPivots( this_.pivot1, this_.pivot2, tNewDragPt, tStaticPivotPt);
    }

    function continueRotation2( idX, idY) {
      var tNewDragPt = { x: tDragPoint.x + idX, y: tDragPoint.y + idY },
          tStaticPivotPt = { x: tXAxisView.dataToCoordinate( this_.pivot1.x),
                            y: tYAxisView.dataToCoordinate( this_.pivot1.y) };
      this_.pivot2.x = tXAxisView.coordinateToData( tNewDragPt.x);
      this_.pivot2.y = tYAxisView.coordinateToData( tNewDragPt.y);
      if( tLocked)
        this_.get('model').forceThroughOriginAndPoint( this_.pivot2);
      else
        forceLineThroughPivots( this_.pivot2, this_.pivot1, tNewDragPt, tStaticPivotPt);
    }

    function endRotation( idX, idY) {
      if( this_.pivot1.x > this_.pivot2.x) {
        var tSwap = this_.pivot1;
        this_.pivot1 = this_.pivot2;
        this_.pivot2 = tSwap;
      }
      logDragResult();
      tDragging = false;
      outScope();
    }

    //=============Main body of createElements===============

    if( this.myElements && (this.myElements.length > 0))
      return; // already created
    arguments.callee.base.apply(this,arguments); // Creates lineSeg, backgrndRect, and equation

    var tPaper = this.get('paper'),
        tDataTipLayer = this.getPath('paperSource.layerManager')[DG.LayerNames.kDataTip];

    this.hitHandles = [0, 1, 2].map(function(i) {
      return tPaper.rect(0, 0, this.kHandleSize, this.kHandleSize)
                    .addClass('dg-movable-line-handle')
                    .attr({ fill: '#FFF', 'fill-opacity': 1 });
    }.bind(this));

    // Hints (implemented as titles here) were good, but they cause layering problems that
    // prevent hitting the line if you are directly over lineSeg. Consider adding the hover
    // and drag routines to lineSeg.
    var dragContinue = [continueRotation1, continueTranslate, continueRotation2],
        dragBegin = [beginRotation, beginDrag, beginRotation],
        dragEnd = [endRotation, endTranslate, endRotation];
    this.hitSegments = [0, 1, 2].map(function(i) {
      return this.lineSeg.clone()
                  .attr({ 'stroke-width': 12,
                          stroke: DG.RenderingUtilities.kSeeThrough })
                  .hover(overScope, outScope)
                  .drag(dragContinue[i], dragBegin[i], dragEnd[i]);
    }.bind(this));

    this.hitHandles.concat(this.hitSegments).forEach( function( iElement) {
      this.myElements.push( iElement);
      tDataTipLayer.push( iElement);
    }.bind( this));
    return this.myElements;
  },

  /**
    Compute the positions of the pivots based on slope and intercept of the model.
   - The line has three segments when the intercept is not locked. Each segment has a different cursor, and one
   that changes based on line orientation.
   - When the intercept is locked, the has one or two segments, two if the origin is within the plot frame, one
   otherwise.
   - The intercept points and the breakpoints are used to define the segments. tIntercepts.pt1 is always to
   the left of tIntercepts.pt2. 
  */
  updateToModel: function() {
    if( !this.getPath('model.isVisible'))
        return;
    if( this.myElements === null)
      this.createElements();
    var tXAxisView = this.get( 'xAxisView'),
        tYAxisView = this.get( 'yAxisView'),
        tLayer = this.get('layer'),
        tModel = this.get('model'),
        tSlope = tModel.get('slope'),
        tLocked = tModel.get('isInterceptLocked'),
        tIntercept = tModel.get('intercept'),
        tXLowerBound = tXAxisView.getPath('model.lowerBound'),
        tXUpperBound = tXAxisView.getPath('model.upperBound'),
        tYLowerBound = tYAxisView.getPath('model.lowerBound'),
        tYUpperBound = tYAxisView.getPath('model.upperBound'),
        // Form of tIntercepts is { pt1: { x, y }, pt2: { x, y }} in world coordinates
        tIntercepts = (tModel.get('isVertical')) ?
                { pt1: { x: tModel.get('xIntercept'), y: tYLowerBound },
                  pt2: { x: tModel.get('xIntercept'), y: tYUpperBound }} :
                DG.PlotUtilities.lineToAxisIntercepts(
                  tSlope, tIntercept, tXAxisView.get('model'), tYAxisView.get('model') );

    function worldToScreen( iWorld) {
      return { x: tXAxisView.dataToCoordinate( iWorld.x),
               y: tYAxisView.dataToCoordinate( iWorld.y) };
    }

    function swapIntercepts() {
      var tSwap = tIntercepts.pt1;
      tIntercepts.pt1 = tIntercepts.pt2;
      tIntercepts.pt2 = tSwap;
    }

    if( tIntercepts.pt2.x < tIntercepts.pt1.x)
      swapIntercepts();

    var tBreakPt1, tBreakPt2;

    if( tLocked) {
      // The only break point is the origin, if it's visible.
      if( (tXLowerBound <= 0) && (tXUpperBound >= 0) && (tYLowerBound <= 0) && (tYUpperBound >= 0)) {
        tBreakPt1 = { x: 0, y: 0 };
        tBreakPt2 = tBreakPt1;
      }
      else if (tSlope >= 0) {
        if((tYUpperBound < 0) || (tXUpperBound < 0))
          tBreakPt1 = tBreakPt2 = tIntercepts.pt2;
        else
          tBreakPt1 = tBreakPt2 = tIntercepts.pt1;
      }
      else {  // tSlope < 0
        if((tYLowerBound > 0) || (tXUpperBound < 0))
          tBreakPt1 = tBreakPt2 = tIntercepts.pt2;
        else
          tBreakPt1 = tBreakPt2 = tIntercepts.pt1;
      }
    }
    else {
      tBreakPt1 = { x: tIntercepts.pt1.x + (3/8) * (tIntercepts.pt2.x - tIntercepts.pt1.x),
                    y: tIntercepts.pt1.y + (3/8) * (tIntercepts.pt2.y - tIntercepts.pt1.y) };
      tBreakPt2 = { x: tIntercepts.pt1.x + (5/8) * (tIntercepts.pt2.x - tIntercepts.pt1.x),
                    y: tIntercepts.pt1.y + (5/8) * (tIntercepts.pt2.y - tIntercepts.pt1.y) };
    }
    if( SC.none( this.pivot1) || !DG.MathUtilities.isInRange( this.pivot1.x, tXLowerBound, tXUpperBound) ||
                                  !DG.MathUtilities.isInRange( this.pivot1.y, tYLowerBound, tYUpperBound))
      this.pivot1 = tIntercepts.pt1;
    if( SC.none( this.pivot2) || !DG.MathUtilities.isInRange( this.pivot2.x, tXLowerBound, tXUpperBound) ||
                                      !DG.MathUtilities.isInRange( this.pivot2.y, tYLowerBound, tYUpperBound))
      this.pivot2 = tIntercepts.pt2;

    var pts = [tIntercepts.pt1, tBreakPt1, tBreakPt2, tIntercepts.pt2]
                .map(function(pt) { return worldToScreen(pt); });

    DG.RenderingUtilities.updateLine( this.lineSeg, pts[0], pts[3]);

    this.hitHandles.forEach(function(handle, i) {
      var xCenter = (pts[i].x + pts[i + 1].x) / 2,
          yCenter = (pts[i].y + pts[i + 1].y) / 2;
      tLayer.bringToFront(handle);
      handle.attr({x: xCenter - this.kHandleSize / 2, y: yCenter - this.kHandleSize / 2});
    }.bind(this));

    this.hitSegments.forEach(function(segment, i) {
      DG.RenderingUtilities.updateLine(segment, pts[i], pts[i + 1]);
    });

    var cursors = tSlope > 0
                    ? [this.kLineBotLeft, this.kLineSlideCur, this.kLineTopRight]
                    : [this.kLineTopLeft, this.kLineSlideCur, this.kLineBotRight];
    this.hitSegments.forEach(function(segment, i) {
      tLayer.bringToFront( segment);
      segment.attr({ cursor: cursors[i] });
    });

    this.positionEquationAndBackground();

  },

  /**
    My model's visibility has changed.
  */
  updateVisibility: function() {
    if( this.getPath('model.isVisible'))
      this.pivot1 = this.pivot2 = null;

    arguments.callee.base.apply(this,arguments);
  }

});


/* >>>>>>>>>> BEGIN source/components/graph/adornments/movable_line_model.js */
// ==========================================================================
//                          DG.MovableLineModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/adornments/twoD_line_model');

/** @class  DG.MovableLineModel - The model for a movable line.

  @extends DG.TwoDLineModel
*/
DG.MovableLineModel = DG.TwoDLineModel.extend(
/** @scope DG.TwoDLineModel.prototype */
{
  /**
    True if we need to compute a new slope and intercept to force within plot bounds
    @return { Boolean }
  */
  isComputingNeeded: function( iXAxis, iYAxis) {
    iXAxis = iXAxis || this.getPath('plotModel.xAxis');
    iYAxis = iYAxis || this.getPath('plotModel.yAxis');
    if( this._needsComputing)
      return true;
    if( this.isVertical) {
      this._needsComputing = (this.xIntercept < iXAxis.get('lowerBound')) ||
                              (this.xIntercept > iXAxis.get('upperBound'));
    }
    else {
      this._needsComputing = !DG.PlotUtilities.lineIntersectsPlotArea(
                  this.slope, this.intercept, iXAxis, iYAxis);
    }
    return this._needsComputing;
  },

  /**
   * If we are showing squares, we must recompute the sum of squares of residuals
   */
  slopeOrInterceptChanged: function() {
    var tSlope = this.get('slope'),
        tInter = this.get('intercept'),
        tSumSquares = 0;
    if( this.get('showSumSquares')) {
      if( this.get('isVertical'))
          tSumSquares = Infinity;
      else {
        this.getCoordinates().forEach(function (iCoordinates) {
          var tLineY = tInter + tSlope * iCoordinates.x,
              tResid = iCoordinates.y - tLineY;
          tSumSquares += tResid * tResid;
        });
      }
      this.set('sumSquaresResiduals', tSumSquares);
    }
  }.observes('slope', 'intercept', 'showSumSquares'),

  /**
    Use the bounds of the given axes to recompute slope and intercept.
  */
  recomputeSlopeAndIntercept: function( iXAxis, iYAxis) {
    iXAxis = iXAxis || this.getPath('plotModel.xAxis');
    iYAxis = iYAxis || this.getPath('plotModel.yAxis');
    var tLowerX = iXAxis.get('lowerBound'),
        tUpperX = iXAxis.get('upperBound'),
        tLowerY = iYAxis.get('lowerBound'),
        tUpperY = iYAxis.get('upperBound');
  
    // [wff 040817 ] Making the default a bit steeper so it's less likely to
    // look like it fits a typical set of points
    tUpperX = tLowerX + (tUpperX - tLowerX) / 2;

    if( !this.get('isInterceptLocked')) {
      this.beginPropertyChanges();
        this.set('slope', (tUpperY - tLowerY) / (tUpperX - tLowerX));
        this.set('intercept', tLowerY - this.slope * tLowerX);
        this.set('isVertical', false);
        this.set('xIntercept', null);
      this.endPropertyChanges();
    }
    else {
      this.forceThroughOriginAndPoint( { x: tUpperX, y: (tUpperY + tLowerY) /2 });
    }
    this._needsComputing = false;
  },

  /**
    Change the intercept but not the slope.
  */
  forceThroughPoint: function( iPoint) {
    if( this.isVertical) {
      this.set('xIntercept', iPoint.x);
    }
    else {
      var tSlope = this.get('slope'),
          tIntercept = iPoint.y - tSlope * iPoint.x;
      this.set('intercept', tIntercept);
    }
  },

  /**
   * Treat the situation in which the two points have the same x-coord as a special case.
   * If the intercept is locked, ignore the first point and force the line to go through the
   * second point and the origin.
  */
  forceThroughPoints: function( iPt1, iPt2) {
    if( iPt1.x === iPt2.x) {
      this.beginPropertyChanges();
        this.set('isVertical', true);
        this.set('xIntercept', iPt1.x);
        this.set('slope', null);
        this.set('intercept', null);
      this.endPropertyChanges();
    }
    else {
      var tSlope = (iPt2.y - iPt1.y) / (iPt2.x - iPt1.x);
      this.beginPropertyChanges();
        this.set('slope', tSlope);
        this.set('intercept', iPt1.y - tSlope * iPt1.x);
        this.set('isVertical', false);
        this.set('xIntercept', null);
      this.endPropertyChanges();
    }
  },

  /**
   * This routine is used when the intercept is locked.
  */
  forceThroughOriginAndPoint: function( iPt) {
    this.forceThroughPoints( iPt, { x: 0, y: 0 });
  },

  /**
   * @return { Object } with properties specific to a given subclass
   */
  createStorage: function() {
    var tStorage = arguments.callee.base.apply(this,arguments);
    DG.ObjectMap.copy( tStorage, {
      intercept: this.get('intercept'),
      slope: this.get('slope'),
      isVertical: this.get('isVertical'),
      xIntercept: this.get('xIntercept')
    });
    return tStorage;
  },

  /**
   * @param { Object } with properties specific to a given subclass
   */
  restoreStorage: function( iStorage) {
    arguments.callee.base.apply(this,arguments);
    this.set('intercept', iStorage.intercept);
    this.set('slope', iStorage.slope);
    this.set('isVertical', iStorage.isVertical);
    this.set('xIntercept', iStorage.xIntercept);
    this._needsComputing = false;
  }

});


/* >>>>>>>>>> BEGIN source/components/graph_map_common/layer_names.js */
// ==========================================================================
//                            DG.LayerNames
//
//  Author:   William Finzer
//
//  Copyright ©2014 Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/**
 * Define constants for layers used in a plot.
 */
DG.LayerNames = {
  kBackgroundImage: 'backgroundImage',
  kBackground: 'background',
  kGrid: 'grid',
  kIntervalShading: 'intervalShading',
  kClick: 'click',
  kGhost: 'ghost',
  kConnectingLines: 'connectingLines',
  kPoints: 'points',
  kSelectedPoints: 'selectedPoints',
  kAdornments: 'adornments',
  kDataTip: 'dataTip',
  kCoverRects: 'coverRects'
};

/* >>>>>>>>>> BEGIN source/components/graph/adornments/movable_point_adornment.js */
// ==========================================================================
//                      DG.MovablePointAdornment
//
//  Author:   William Finzer
//
//  Copyright (c) 2017 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/utilities/plot_utilities');
sc_require('components/graph_map_common/layer_names');

/** @class  Draws a movable point.

 @extends DG.PlotAdornment
 */
DG.MovablePointAdornment = DG.PlotAdornment.extend(
    /** @scope DG.MovablePointAdornment.prototype */
    {
      defaultColor: DG.PlotUtilities.kDefaultMovablePointColor,
      defaultRadius: DG.PlotUtilities.kDefaultMovablePointRadius,

      /**
       Concatenated array of ['PropertyName','ObserverMethod'] pairs used for indicating
       which observers to add/remove from the model.

       @property   {Array of [{String},{String}]}  Elements are ['PropertyName','ObserverMethod']
       */
      modelPropertiesToObserve: [['coordinates', 'updateToModel']],

      layerName: DG.LayerNames.kDataTip,

      opacity: 0.6,
      strokeOpacity: 0.8,

      /**
       The point itself is a single point element
       @property { Raphael point element }
       */
      point: null,

      /**
       The point has a shadow, offset down and to the right by 1 pixel
       @property { Raphael point element }
       */
      shadow: null,

      /**
       * Lazy instantiation.
       * @property {DG.PointDataTip }
       */
      dataTip: function() {
        if( !this._dataTip) {
          this._dataTip = DG.MovablePointDataTip.create( { plotLayer: this.get('paperSource'),
            layerName: DG.LayerNames.kDataTip, movablePoint: this.get('model') });
        }
        return this._dataTip;
      }.property(),

      /**
       * @property {Boolean} Indicates whether dragging is in progress
       */
      dragging: false,

      /**
       Make the pieces of the movable line. This only needs to be done once.
       */
      createElements: function () {
        var tXAxisView = this.get('xAxisView'),
            tYAxisView = this.get('yAxisView'),
            tOriginalCoordinates,
            tDragPoint;

        //=============Event handling functions===============
        var overScope = function () {
/*
              var tAttributes = {stroke: DG.PlotUtilities.kLineHighlightColor};
              this.point.stop();
              this.point.animate(tAttributes, DG.PlotUtilities.kHighlightShowTime);
*/

              this.get('dataTip').show( this.point.attr('cx'), this.point.attr('cy'), this.point.attr('r'));
            }.bind(this),

            outScope = function () {
/*
              var tAttributes = {stroke: DG.RenderingUtilities.kSeeThrough};
              if (!tDragging) {
                this.point.stop();
                this.point.animate(tAttributes, DG.PlotUtilities.kHighlightHideTime);
              }
*/
              this.get('dataTip').hide();
            }.bind(this),

            beginDrag = function (iWindowX, iWindowY) {
              tOriginalCoordinates = this.getPath('model.coordinates');
              tDragPoint = DG.ViewUtilities.windowToViewCoordinates(
                  {x: iWindowX, y: iWindowY}, this.parentView);
              overScope();
              this.set('dragging', true);
            }.bind(this),

            continueDrag = function (idX, idY) {
              this.setPath( 'model.coordinates', {  x: tXAxisView.coordinateToData( tDragPoint.x + idX),
                                  y: tYAxisView.coordinateToData( tDragPoint.y + idY) });
            }.bind(this),

            endDrag = function (idX, idY) {
              var tOriginal = tOriginalCoordinates,
                  tNew;
              DG.UndoHistory.execute(DG.Command.create({
                name: "graph.moveMovablePoint",
                undoString: 'DG.Undo.graph.moveMovablePoint',
                redoString: 'DG.Redo.graph.moveMovablePoint',
                log: "Moved movable point from %@ to %@".fmt( tOriginal, this.getPath('model.coordinates')),
                executeNotification: {
                  action: 'notify',
                  resource: 'component',
                  values: {
                    operation: 'drag movable point',
                    type: 'DG.GraphView'
                  }
                },
                execute: function() {
                  tNew = this.getPath('model.coordinates');
                }.bind( this),
                undo: function() {
                  this.setPath('model.coordinates', tOriginal);
                }.bind( this),
                redo: function() {
                  this.setPath('model.coordinates', tNew);
                }.bind( this)
              }));
              this.set('dragging', false);
              // outScope();
            }.bind(this);

        //=============Main body of createElements===============

        if (this.myElements && (this.myElements.length > 0))
          return; // already created

        var tLayer = this.get('layer'),
            tPaper = this.get('paper');

        this.point = tPaper.circle(0, 0, this.defaultRadius)
            .attr({fill: this.defaultColor, opacity: 0, stroke: 'black', 'stroke-opacity': 0, cursor: 'move'})
            .drag( continueDrag, beginDrag, endDrag)
            .hover( overScope, outScope);
        this.point.animatable = true;
        // Tune up the point rendering a bit
        this.point.node.setAttribute('shape-rendering', 'geometricPrecision');

        this.shadow = tPaper.circle(0, 0, this.defaultRadius)
            .attr({ 'stroke-width': 2, stroke: 'darkgray', 'stroke-opacity': 0});
        this.shadow.animatable = true;
        // Tune up the shadow rendering a bit
        this.shadow.node.setAttribute('shape-rendering', 'geometricPrecision');

        this.myElements = [ this.shadow, this.point ];
        this.myElements.forEach(function (iElement) {
          tLayer.push(iElement);
        });
        return this.myElements;
      },

      /**
       * Set coordinates based on model.
       * Decide whether to animate based on opacity.
       */
      updateToModel: function () {
        if (!this.getPath('model.isVisible'))
          return;
        if (this.myElements === null)
          this.createElements();
        var tXAxisView = this.get('xAxisView'),
            tYAxisView = this.get('yAxisView'),
            tModel = this.get('model'),
            tCoords = tModel.get('coordinates'),
            tScreenCoords = worldToScreen( tCoords),
            tPoint = this.get('point'),
            tShadow = this.get('shadow'),
            tLayer = this.get('layer');

        function worldToScreen(iWorld) {
          return {
            cx: tXAxisView.dataToCoordinate(iWorld.x),
            cy: tYAxisView.dataToCoordinate(iWorld.y)
          };
        }
        if( this.get('dragging') || tPoint.attr('opacity') === 0) {
          tPoint.attr(tScreenCoords);
          tShadow.attr({cx: tScreenCoords.cx + 1, cy: tScreenCoords.cy + 1});
        } else {
          tPoint.animate(tScreenCoords, DG.PlotUtilities.kDefaultAnimationTime, '<>');
          tShadow.animate({cx: tScreenCoords.cx + 1, cy: tScreenCoords.cy + 1},
              DG.PlotUtilities.kDefaultAnimationTime, '<>');
        }
        if( tPoint.attr('opacity') === 0) {
          tPoint.animate({opacity: this.opacity, 'stroke-opacity': this.strokeOpacity}, DG.PlotUtilities.kDefaultAnimationTime, '<>');
          tShadow.animate({ 'stroke-opacity': 0.8}, DG.PlotUtilities.kDefaultAnimationTime, '<>');
        }
        tLayer.bringToFront(tShadow);
        tLayer.bringToFront(tPoint);
      }

    });


/* >>>>>>>>>> BEGIN source/components/graph/adornments/movable_point_data_tip.js */
// ==========================================================================
//                            DG.MovablePointDataTip
//
//  Author:   William Finzer
//
//  Copyright (c) 2017 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/adornments/data_tip');

/** @class DG.MovablePointDataTip A simple adornment-like class that displays and updates a data tip that shows when the
 *    user hovers over a point.

 @extends DG.DataTip
 */
DG.MovablePointDataTip = DG.DataTip.extend(
    /** @scope DG.MovablePointDataTip.prototype */
    {
      movablePoint: null,

      coordinatesDidChange: function() {
        this.updateTip();
      }.observes('movablePoint.coordinates'),

      getDataTipText: function () {

        var tGraphModel = this.getPath('plotLayer.graphModel'),
            tCoordinates = this.getPath('movablePoint.coordinates'),

            getNameValuePair = function (iKey) {

              var digitsForAxis = function () {
                    return DG.PlotUtilities.findFractionDigitsForAxis(this.getPath('plotLayer.' + iKey + 'AxisView'));
                  }.bind(this),

                  tAttrDesc = tGraphModel.getPath('dataConfiguration.' + iKey + 'AttributeDescription'),
                  tAttr = tAttrDesc.get('attribute'),
                  tAttrID = tAttr ? tAttr.get('id') : null,
                  tIsDate = tAttrDesc.get('attributeType') === DG.Analysis.EAttributeType.eDateTime,
                  tName, tValue;
              if (!SC.none(tAttrID)) {
                tName = tAttr.get('name');
                tValue = tIsDate ? DG.DateUtilities.formatDate( tCoordinates[iKey]) :
                    DG.PlotUtilities.getFormattedNumericValue(tCoordinates[iKey], digitsForAxis);
                return tName + ': ' + tValue;
              }
              return null;
            }.bind( this),

            tTipText = '';

        if (!this.get('showOnlyLegendData')) {
          var tXPair = getNameValuePair('x'),
              tYPair = getNameValuePair('y');
          tTipText = SC.none(tXPair) ? '' : tXPair;
          if (!SC.none(tYPair)) {
            if (tTipText.length > 0)
              tTipText += '\n';
            tTipText += tYPair;
          }
        }
        return tTipText;
      },

      /**
       *  We set the tip origin and the case index before calling arguments.callee.base.apply(this,arguments)
       */
      show: function (iX, iY, iR, iIndex) {
        this.set('tipOrigin', {x: iX, y: iY});
        this.set('tipSourceRadius', iR);

        arguments.callee.base.apply(this,arguments);
      }

    });


/* >>>>>>>>>> BEGIN source/components/graph/adornments/movable_point_model.js */
// ==========================================================================
//                          DG.MovablePointModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2017 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class  DG.MovablePointModel - The model for a movable line.

  @extends DG.PlotAdornmentModel
*/
DG.MovablePointModel = DG.PlotAdornmentModel.extend(
/** @scope DG.TwoDLineModel.prototype */
{
  /**
   The current coordinates of the point in world coordinates.
   @property { { x: {Number}, y: { Number} }
   */
  coordinates: null,

  /**
    True if we need to compute a new slope and intercept to force within plot bounds
    @return { Boolean }
  */
  isComputingNeeded: function( iXAxis, iYAxis) {
    if( this._needsComputing)
      return true;

    this._needsComputing = !this.coordinates ||
        (this.coordinates.x < iXAxis.get('lowerBound')) ||
                            (this.coordinates.x > iXAxis.get('upperBound')) ||
        (this.coordinates.y < iYAxis.get('lowerBound')) ||
                            (this.coordinates.y > iYAxis.get('upperBound'));
    return this._needsComputing;
  },

  /**
    Use the bounds of the given axes to recompute default coordinates for the point.
  */
  recomputeCoordinates: function( iXAxis, iYAxis) {
    var tLowerX = iXAxis.get('lowerBound'),
        tUpperX = iXAxis.get('upperBound'),
        tLowerY = iYAxis.get('lowerBound'),
        tUpperY = iYAxis.get('upperBound');

    this.set('coordinates', {
      x: tUpperX - (tUpperX - tLowerX) / 3,
      y: tUpperY - (tUpperY - tLowerY) / 3
    });
  
    this._needsComputing = false;
  },

  /**
   Use the bounds of the given axes to recompute slope and intercept.
   */
  recomputePositionIfNeeded: function( iXAxis, iYAxis) {
    if( this.isComputingNeeded( iXAxis, iYAxis))
    {
      this.recomputeCoordinates( iXAxis, iYAxis);
    }
  },

  /**
   * @return { Object } with properties specific to a given subclass
   */
  createStorage: function() {
    var tStorage = arguments.callee.base.apply(this,arguments);
    DG.ObjectMap.copy( tStorage, {
      coordinates: this.get('coordinates')
    });
    return tStorage;
  },

  /**
   * @param { Object } with properties specific to a given subclass
   */
  restoreStorage: function( iStorage) {
    arguments.callee.base.apply(this,arguments);
    this.set('coordinates', iStorage.coordinates);
  }

});


/* >>>>>>>>>> BEGIN source/components/graph/adornments/value_axis_view_mixin.js */
// ==========================================================================
//                            DG.ValueAxisViewMixin
// 
//  A mixin designed to work with DG.PlotAdornments which respond to
//  notifications from a 'valueAxisView' property.
//  
//  Author:   Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

DG.ValueAxisViewMixin = {

  /**
    @property { DG.CellLinearAxisView }
  */
  valueAxisView: null,

  /**
    Private properties used with observer methods.
   */
  _observedAxisModel: null,
  _observedAxisView: null,
  
  /**
    Initialization method.
   */
  initMixin: function() {
    // Trigger manually to handle 'valueAxisView' passed in as create() argument
    this.axisViewDidChange();
    
    // Add observer to handle any subsequent changes
    this.addObserver('valueAxisView', this, 'axisViewDidChange');
  },
  
  /**
    Destruction method.
   */
  destroyMixin: function() {
    this.set('valueAxisView', null);
    this.removeObserver('valueAxisView', this, 'axisViewDidChange');
  },
  
  /**
    Observer method called when the axis model changes.
    Guarantees that the line is updated when the axis bounds change.
   */
  axisModelDidChange: function() {
    if( this._observedAxisModel) {
      this._observedAxisModel.removeObserver('lowerBound', this, 'updateToModel');
      this._observedAxisModel.removeObserver('upperBound', this, 'updateToModel');
      this._observedAxisModel = null;
    }
    
    var axisModel = this.getPath('valueAxisView.model');
    if( axisModel) {
      axisModel.addObserver('lowerBound', this, 'updateToModel');
      axisModel.addObserver('upperBound', this, 'updateToModel');
      this._observedAxisModel = axisModel;
    }
  },

  /**
    Observer method called when the axis view changes.
    Guarantees that the line is redrawn when the view bounds change.
   */
  axisViewDidChange: function() {
    if( this._observedAxisView) {
      this._observedAxisView.removeObserver('model', this, 'axisModelDidChange');
      this._observedAxisView.removeObserver('pixelMin', this, 'updateToModel');
      this._observedAxisView.removeObserver('pixelMax', this, 'updateToModel');
      this._observedAxisView = null;
    }
    
    // If the axis view has changed, the axis model probably has as well.
    this.axisModelDidChange();
    
    var axisView = this.get('valueAxisView');
    if( axisView) {
      axisView.addObserver('model', this, 'axisModelDidChange');
      axisView.addObserver('pixelMin', this, 'updateToModel');
      axisView.addObserver('pixelMax', this, 'updateToModel');
      this._observedAxisView = axisView;
    }
  },
  
  /**
    Observer method triggered when axis properties change.
   */
  updateToModel: function() {
  }

};

/* >>>>>>>>>> BEGIN source/components/graph/adornments/movable_value_adornment.js */
// ==========================================================================
//                      DG.MovableValueAdornment
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/adornments/plot_adornment');
sc_require('components/graph/adornments/line_label_mixin');
sc_require('components/graph/adornments/value_axis_view_mixin');

/** @class  Draws a movable line.
 *          Mixes in the DG.ValueAxisViewMixin for handling axis notifications that trigger updates.

  @extends DG.PlotAdornment
*/
DG.MovableValueAdornment = DG.PlotAdornment.extend( DG.LineLabelMixin, DG.ValueAxisViewMixin,
/** @scope DG.MovableValueAdornment.prototype */ 
{
  kLineSlideHCur: DG.Browser.customCursorStr('../../../../static/dg/de/cert/resources/cursors/LineSlideH.cur', 8, 8),
  kLineSlideVCur: DG.Browser.customCursorStr('../../../../static/dg/de/cert/resources/cursors/LineSlide.cur', 8, 8),

  /** The object has category names as keys the following as values: {
   *   lineSeg:{Raphael line element},  The movable value itself is a single line element
   *   coverSeg:{Raphael line element}, We cover the line segment with a wider segment for hit-testing and hilighting
   *   cap:{Raphael line element }
   * }
   * @property {Object}
   */
  valueElements: null,

  /**
   @property { DG.CellAxisView }
   */
  splitAxisView: function() {
    return this.getPath('parentView.secondaryAxisView');
  }.property(),

  orientation: function() {
    return this.getPath('valueAxisView.orientation');
  }.property(),
  orientationDidChange: function() {
    this.removeElements();
    this.updateToModel();
  }.observes('*valueAxisView.orientation'),

  /**
   * @param iCat {string}
   */
  screenCoord: function(iCat) {
    return this.get('valueAxisView').dataToCoordinate( this.get('model').getValueForCategory(iCat));
  },

  /**
    The returned string should have a reasonable number of significant digits for the
      circumstances.
    @param iCat {string}
    @return { String read only }
  */
  valueStringForCategory: function(iCat) {

    var dateTimeString = function() {
          var tAxisViewHelper = this.getPath('valueAxisView.axisViewHelper'),
              tResolution = tAxisViewHelper.getValueDisplayResolution(),
              tDateValue = new Date( tValue * 1000),
              tYear = tDateValue.getFullYear(),
              tMonthName = DG.monthName( tValue),
              tDay = tDateValue.getDate(),
              tHour = tDateValue.getHours()/*,
              tMinute = tDateValue.getMinutes(),
              tSecond = tDateValue.getSeconds()*/;
          switch( tResolution) {
            case 'year': return String(tYear);
            case 'month': return 'DG.MovableMonthYear'.loc( tMonthName, tYear);
            case 'day': return tDateValue.toLocaleDateString();
            case 'hour': return 'DG.MovableMonthDayHour'.loc( tMonthName, tDay, tHour);
            case 'second':
            case 'minute': return tDateValue.toLocaleTimeString();
          }

          return DG.DataUtilities.formatDate( tValue);
        }.bind( this),

        numericString = function() {
          var tDigits = DG.PlotUtilities.findFractionDigitsForAxis( this.get('valueAxisView')),
              tNumFormat = DG.Format.number().fractionDigits( 0, tDigits);
          if( tValue < 2500 )
            tNumFormat.group('');
          return tNumFormat( tValue);
        }.bind( this);

    var tValue = this.get('model').getValueForCategory(iCat);

    if( this.getPath('valueAxisView.isDateTime'))
      return dateTimeString();
    else
      return numericString();
  },
  valueStringDidChange: function() {
    this.notifyPropertyChange('valueString');
  }.observes('*model.valueChange', '*valueAxisView.model.firstAttributeName'),

  /**
    Concatenated array of ['PropertyName','ObserverMethod'] pairs used for indicating
    which observers to add/remove from the model.
    
    @property   {Array of [{String},{String}]}  Elements are ['PropertyName','ObserverMethod']
   */
  modelPropertiesToObserve: [ ['valueChange', 'updateToModel'],
                              ['removed', 'modelWasRemoved']],

  modelWasRemoved: function() {
    this.detachModel();
  },

  /**
    Make the movable line segments.
  */
  createElements: function() {
    var this_ = this,
        tPaper = this.get('paper'),
        tLayer = this.get('layer' ),
        tDragCoord,
        tOriginalValue;
  
    //=============Event handling functions===============
    function beginTranslate( iWindowX, iWindowY) {
      tOriginalValue = this_.get('model').getValueForCategory(this._key);
      var tDragPoint = DG.ViewUtilities.windowToViewCoordinates( 
                    { x: iWindowX, y: iWindowY }, this_.parentView);
      tDragCoord = (this_.get('orientation') === DG.GraphTypes.EOrientation.kHorizontal) ?
                        tDragPoint.x : tDragPoint.y;
    }
    
    function continueTranslate( idX, idY) {
      var tAxisView = this_.get('valueAxisView'),
          tDelta = (tAxisView.get('orientation') === DG.GraphTypes.EOrientation.kHorizontal) ? idX : idY,
          tValue = tAxisView.coordinateToData( tDragCoord + tDelta, true /* snapToTick */);
      this_.get('model').setValueForCategory( this._key, tValue);
    }
  
    function endTranslate( idX, idY) {
      var tOriginal = tOriginalValue,
          tCat = this._key,
          tModel = this_.get('model'),
          tNew;
      DG.logUser("dragMovableValue: '%@'", this_.valueStringForCategory(tCat));
      DG.UndoHistory.execute(DG.Command.create({
        name: "graph.moveMovableValue",
        undoString: 'DG.Undo.graph.moveMovableValue',
        redoString: 'DG.Redo.graph.removeMovableValue',
        log: "Moved movable value from %@ to %@".fmt( tOriginal, tModel.getValueForCategory(tCat)),
        executeNotification: {
          action: 'notify',
          resource: 'component',
          values: {
            operation: 'drag movable line',
            type: 'DG.GraphView'
          }
        },
        execute: function() {
          tNew = tModel.getValueForCategory(tCat);
        },
        undo: function() {
          tModel.setValueForCategory(tCat, tOriginal);
        },
        redo: function() {
          tModel.setValueForCategory(tCat, tNew);
        }
      }));
    }

    function overScope() {
      var tCoverSeg = this_.get('valueElements')[this._key].coverSeg,
          tAttributes = { stroke: DG.PlotUtilities.kMovableLineHighlightColor };
      tCoverSeg.stop();
      tCoverSeg.animate( tAttributes, DG.PlotUtilities.kHighlightShowTime);
    }

    function outScope() {
      var tCoverSeg = this_.get('valueElements')[this._key].coverSeg,
          tAttributes = { stroke: DG.RenderingUtilities.kSeeThrough };
      tCoverSeg.stop();
      tCoverSeg.animate( tAttributes, DG.PlotUtilities.kHighlightHideTime);
    }

    //=============Main body of createElements===============

    if( this.myElements && (this.myElements.length > 0))
      return; // already created
    if( !tPaper)
      return; // Not ready yet
    var tCapSize = DG.PlotUtilities.kMovableValueCapSize,
        tCur = (this.get('orientation') === DG.GraphTypes.EOrientation.kHorizontal) ?
                  this.kLineSlideHCur : this.kLineSlideVCur,
        tModelValues = this.getPath('model.values'),
        tValueElements = {};
    this.myElements = [];
    DG.ObjectMap.forEach( tModelValues, function( iKey, iValue) {
      var tLineSeg = tPaper.line( 0, 0, 0, 0)
              .attr({ 'stroke-opacity': 0 })
              .addClass('dg-graph-adornment-movable'),
          tCoverSeg = tPaper.line( 0, 0, 0, 0)
              .attr( { 'stroke-width': 6, stroke: DG.RenderingUtilities.kSeeThrough,
                cursor: tCur, title: "Drag the value" })
              .hover( overScope, outScope)
              .drag( continueTranslate, beginTranslate, endTranslate),
          tCap = tPaper.rect(-20, 0, tCapSize, tCapSize)
              .attr( { cursor: tCur, opacity: 0 })
              .drag( continueTranslate, beginTranslate, endTranslate)
              .addClass( 'dg-graph-adornment-movable'),
          tBackground = this_.createBackgroundRect(),
          tText = this_.createTextElement();
      tCoverSeg._key = tCap._key = tText._key = iKey;
      tLineSeg.animatable = true;
      tLineSeg.animate({ 'stroke-opacity': 1 }, DG.PlotUtilities.kDefaultAnimationTime, '<>');
      tText.animatable = true;
      tText.attr( {fill: DG.PlotUtilities.kDefaultMovableLineColor})
          .hover( overScope, outScope)
          .drag( continueTranslate, beginTranslate, endTranslate);
      tText.animate({ opacity: 1 }, DG.PlotUtilities.kDefaultAnimationTime, '<>');
      tCap.animatable = true;
      tCap.animate({ opacity: 1 }, DG.PlotUtilities.kDefaultAnimationTime, '<>');
      tValueElements[iKey] = {
        lineSeg: tLineSeg,
        coverSeg: tCoverSeg,
        cap: tCap,
        background: tBackground,
        text: tText
      };
      DG.ObjectMap.values(tValueElements[iKey]).forEach( function(iElement) {
        this_.myElements.push(iElement);
      });
    });
    this.myElements.forEach( function( iElement) {
      tLayer.push( iElement);
    });
    this.set('valueElements', tValueElements);
  },

  /**
    Compute the positions of the line segment and text element
  */
  updateToModel: function() {
    var getCellNames = function() {
          var tNames = this.getPath('model.plotModel.secondaryAxisModel.attributeDescription.cellNames');
          if (!tNames || tNames.length === 0)
            tNames = [DG.MovableValueModel.kSingleCellName];
          return tNames;
        }.bind(this),
    tCellNames = getCellNames(),
    tValueElements = this.get('valueElements');

    if( !this.myElements || tCellNames.some(function(iName) {
      return !tValueElements[iName];  // signifying it's out of date
    }) ||
        Object.keys(tValueElements).some( function( iKey) {
          return tCellNames.indexOf( iKey) < 0;
        })) {
      this.removeElements();
      this.createElements();
    }

    var this_ = this,
        tValueAxisView = this.get('valueAxisView'),
        tSplitAxisView = this.get('splitAxisView'),
        tCellExtent = tSplitAxisView && tSplitAxisView.get('fullCellWidth'),
        tPaper = this.get('paper'),
        tModelIsVisible = this.getPath('model.isVisible');
    if( !tValueAxisView || !tPaper || !tModelIsVisible || !tSplitAxisView) return;  // not ready yet or no need

    var tCapOffset = DG.PlotUtilities.kMovableValueCapSize / 2;
    DG.ObjectMap.forEach(this.get('valueElements'), function (iKey, iValueElement) {
      var tWorldCoord = this_.get('model').getValueForCategory(iKey),
          tScreenCoord = tValueAxisView && tValueAxisView.dataToCoordinate(tWorldCoord),
          tCellCoord = tSplitAxisView.cellNameToCoordinate(iKey),
          tPt1, tPt2, tTextAnchor, tTextBox, tTextXOffset = 0,
          tTextYOffset = 0,
          tBackgrndAnchor;
      if(!DG.isFinite(tCellCoord) || !DG.isFinite(tScreenCoord))
        return; // Can happen during transitions
      iValueElement.text.attr({text: this_.valueStringForCategory(iKey)});
      tTextBox = iValueElement.text.getBBox();

      if (tValueAxisView.get('orientation') === DG.GraphTypes.EOrientation.kHorizontal) {
        tPt1 = {x: tScreenCoord, y: tCellCoord + tCellExtent / 2};
        tPt2 = {x: tScreenCoord, y: tCellCoord - tCellExtent / 2 + DG.MovableValueAdornment.kLabelSpace / 2};
        tTextAnchor = 'middle';
        tTextYOffset = -4 * tCapOffset;
        tBackgrndAnchor = {x: tScreenCoord - tTextBox.width / 2, y: tPt2.y + tTextYOffset - tTextBox.height / 2};
      } else {
        tPt1 = {x: tCellCoord - tCellExtent / 2, y: tScreenCoord};
        tPt2 = {x: tCellCoord + tCellExtent / 2 - DG.MovableValueAdornment.kLabelSpace, y: tScreenCoord};
        tTextAnchor = 'start';
        tTextXOffset = 2 * tCapOffset;
        tBackgrndAnchor = {x: tPt2.x + tTextXOffset, y: tPt2.y - tTextBox.height / 2};
      }

      iValueElement.text.attr({
        x: tPt2.x + tTextXOffset, y: tPt2.y + tTextYOffset,
        'text-anchor': tTextAnchor
      });
      iValueElement.background.attr({
        x: tBackgrndAnchor.x,
        y: tBackgrndAnchor.y,
        width: tTextBox.width,
        height: tTextBox.height
      });

      DG.RenderingUtilities.updateLine(iValueElement.lineSeg, tPt1, tPt2);
      DG.RenderingUtilities.updateLine(iValueElement.coverSeg, tPt1, tPt2);
      iValueElement.cap.attr({x: tPt2.x - tCapOffset, y: tPt2.y - tCapOffset});
    });
  }

});

DG.MovableValueAdornment.kLabelSpace = 50;  // pixels


/* >>>>>>>>>> BEGIN source/components/graph/adornments/movable_value_model.js */
// ==========================================================================
//                      DG.MovableValueModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/adornments/plot_adornment_model');

/** @class  The model for a movable line.

  @extends SC.Object
*/
DG.MovableValueModel = DG.PlotAdornmentModel.extend(
/** @scope DG.MovableValueModel.prototype */ 
{
  /**
   * Each category keeps track of the current value. If no secondary attribute, category is 'main'
   * @property {Object} Keys are categories of secondary attribute with numbers as values
   */
  values: null,

  secondaryAxisAttributeDescription: function() {
    return this.getPath('plotModel.secondaryAxisModel.attributeDescription');
  }.property(),

  init: function() {
    arguments.callee.base.apply(this,arguments);
    this.createValuesObject();
  },

  createValuesObject: function() {
    var tCurrentValuesObject = this.get('values'),
        tValuesObject = {},
        tAttrDesc = this.get('secondaryAxisAttributeDescription'),
        tCellNames = tAttrDesc && tAttrDesc.get('cellNames');

    function valuesObjectIsValid() {
      var tTempCellNames = (!tCellNames || tCellNames.length === 0) ?
          [DG.MovableValueModel.kSingleCellName] : tCellNames;
      var tIsValid = tCurrentValuesObject && Object.keys(tCurrentValuesObject).every(function( iKey) {
        return tTempCellNames.indexOf(iKey) >= 0;
      });
      tIsValid = tIsValid && tTempCellNames.every( function( iName) {
        return tCurrentValuesObject.hasOwnProperty(iName);
      });
      return tIsValid;
    }

    if(valuesObjectIsValid())
      return; // because we've already got a valid one

    if( tCellNames.length === 0) {
      tValuesObject[DG.MovableValueModel.kSingleCellName] = null;
    }
    else {
      var tStartValue = tCurrentValuesObject && tCurrentValuesObject[DG.MovableValueModel.kSingleCellName];
      tCellNames.forEach(function (iName) {
        tValuesObject[iName] = tStartValue;
      });
    }
    this.set('values', tValuesObject);
    // this.recomputeValue( this.getPath('plotModel.primaryAxisModel'));
  },

  /**
   *
   * @param iCat {string}
   * @return {number} in world coordinates
   */
  getValueForCategory: function(iCat) {
    var tValuesObject = this.get('values');
    return tValuesObject[iCat];
  },

  /**
   *
   * @param iCat {string}
   * @param iValue {number}
   */
  setValueForCategory: function(iCat, iValue) {
    this.get('values')[iCat] = iValue;
    this.notifyPropertyChange('valueChange');
  },

  /**
    Go ahead and recomputeValue
  */
  handleChangedAxisAttribute: function( iAxis) {
    this.createValuesObject();
    this.recomputeValue(iAxis);
  },

  getAllValues: function() {
    return DG.ObjectMap.values( this.values);
  },

  setAllValues: function( iValue) {
    DG.ObjectMap.forEach(this.values, function (iKey) {
      this.values[iKey] = iValue;
    }.bind(this));
    this.notifyPropertyChange('valueChange');
    this._needsComputing = false;
  },

  /**
   * Use the bounds of the given axes to choose a value, but not one at the exact center.
   * The array of previous values can help in assigning values not identical to one already assigned
   * @param iAxis {DG.CellLinearAxisModel}
   * @param iPreviousValues {{category:number}}
   */
  recomputeValue: function( iAxis, iPreviousValues) {

    function inBounds(iNum) {
      return !SC.none( iNum) && iNum >= tLower && iNum <= tUpper;
    }

    var tLower = iAxis.get('lowerBound'),
        tUpper = iAxis.get('upperBound'),
        tChanged = false,
        tSavedValues = Object.assign({}, this.values);
    this.createValuesObject();  // no-op if already valid
    DG.ObjectMap.forEach(this.values, function(iKey, iValue) {
      if(iKey === DG.MovableValueModel.kSingleCellName && !tSavedValues.hasOwnProperty(iKey)) {
        iValue = tSavedValues[Object.keys(tSavedValues)[0]];
        this.values[iKey] = iValue;
      }
      var tSavedValue = tSavedValues[iKey];
      if( SC.none( iValue) && inBounds( tSavedValue)) {
        this.values[iKey] = tSavedValue;
      }
      else if( !inBounds( iValue)) {
        var tPreviousValue = iPreviousValues && iPreviousValues[iKey],
            tAnchor = SC.none(tPreviousValue) ? tLower : tPreviousValue;
        this.values[iKey] = tAnchor + (tUpper - tAnchor) / 3;
        tChanged = true;
      }
    }.bind(this));
    if( tChanged)
      this.notifyPropertyChange('valueChange');
    this._needsComputing = false;
  },

  createStorage: function() {
    var storage = arguments.callee.base.apply(this,arguments);
    if( this.get('isVisible'))
      storage.values = this.get('values');
    return storage;
  },
  
  restoreStorage: function( iStorage) {
    arguments.callee.base.apply(this,arguments);
    if( iStorage) {
      if (iStorage.values)
        this.set('values', iStorage.values);
      else if( iStorage.value) {
        var temp = {};
        temp[DG.MovableValueModel.kSingleCellName] = iStorage.value;
        this.set('values', temp);
      }
      this._needsComputing = false;
    }
    return this;
  }

});

DG.MovableValueModel.kSingleCellName = '_main';

DG.PlotAdornmentModel.registry.movableValue = DG.MovableValueModel;

/* >>>>>>>>>> BEGIN source/components/graph/adornments/multiple_lsrls_adornment.js */
// ==========================================================================
//                      DG.MultipleLSRLsAdornmentl
//
//  Author:   William Finzer
//
//  Copyright (c) 2017 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/adornments/plot_adornment');

/** @class  Holds onto an array of LSRLAdornment.

 @extends DG.PlotAdornment
 */
DG.MultipleLSRLsAdornment = DG.PlotAdornment.extend(
    /** @scope DG.MultipleLSRLsAdornmentl.prototype */
    {
      /**
       My array of adornments
       @property { [{DG.LSRLAdornment}] }
       */
      lsrlAdornments: null,

      init: function () {
        arguments.callee.base.apply(this,arguments);
        this.set('lsrlAdornments', []);
        this.updateToModel();
      },

      destroy: function () {
        this.lsrlAdornments.forEach(function (iAdorn) {
          iAdorn.destroy();
        });
        arguments.callee.base.apply(this,arguments);
      },

      /**
       Concatenated array of ['PropertyName','ObserverMethod'] pairs used for indicating
       which observers to add/remove from the model.

       @property   {Array of [{String},{String}]}  Elements are ['PropertyName','ObserverMethod']
       */
      modelPropertiesToObserve: [['lsrls', 'updateToModel'],
        ['isInterceptLocked', 'updateToModel'], ['showSumSquares', 'updateToModel'],
        ['showConfidenceBands', 'updateToModel']],

      /**
       Pass this down to my lsrlAdornments.
       And then deal with showing counts and percents
       */
      updateToModel: function () {
        this.get('model').recomputeSlopeAndInterceptIfNeeded();
        var tAdornments = this.get('lsrlAdornments');

        var adjustNumberOfAdornments = function () {
              var tLSRLs = this.getPath('model.lsrls');
              tAdornments.forEach( function( iAdornment, iIndex) {
                if( iIndex < tLSRLs.length) {
                  iAdornment.set('model', tLSRLs[iIndex]);
                }
                else {
                  iAdornment.set('model', null);  // Will later be removed from list of adornments
                }
              });
              while (tLSRLs.length > tAdornments.length) {
                var tNewAdorn = DG.LSRLAdornment.create({
                  parentView: this.get('parentView'),
                  model: tLSRLs[ tAdornments.length], paperSource: this.get('paperSource'),
                  layerName: DG.LayerNames.kAdornments });
                tNewAdorn.createElements();
                tAdornments.push(tNewAdorn);
              }
              while (tLSRLs.length < tAdornments.length) {
                var tIndex = tAdornments.findIndex(function (iAdorn) {
                  return SC.none(iAdorn.get('model'));
                });
                if (tIndex >= 0) {
                  var tAdorn = tAdornments[tIndex];
                  tAdornments.splice(tIndex, 1);
                  tAdorn.destroy();
                }
              }
            }.bind(this);

        // begin updateToModel
        adjustNumberOfAdornments();
        tAdornments.forEach(function (iAdornment) {
          iAdornment.updateToModel();
        });
      }

    });


/* >>>>>>>>>> BEGIN source/components/graph/adornments/multiple_lsrls_model.js */
// ==========================================================================
//                      DG.MultipleLSRLsModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2017 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/adornments/plot_adornment_model');

/** @class  The model for a set of LSRLAdornment.

 @extends SC.Object
 */
DG.MultipleLSRLsModel = DG.PlotAdornmentModel.extend(
   /** @scope DG.MultipleLSRLsModel.prototype */
   {
     /**
      The current value
      @property { [{DG.LSRLModel} ] }
      */
     lsrls: null,

     /**
      * @property { Boolean }
      */
     showSumSquares: false,

     /**
      * @property { Boolean }
      */
     isInterceptLocked: false,

     /** @property { Boolean } */
     showConfidenceBands: false,

     numLegendCells: function () {
       var tLegendDesc = this.getPath('plotModel.dataConfiguration.legendAttributeDescription'),
          tNumCells = (SC.none(tLegendDesc) || tLegendDesc.get('isNumeric')) ? 1 :
                      tLegendDesc.getPath('attributeStats.numberOfCells');
       return SC.none(tNumCells) ? 1 : Math.max(1, tNumCells);
     }.property(),

     /**
      Private cache.
      @property { Boolean }
      */
     _needsComputing: true,

     init: function () {
       arguments.callee.base.apply(this,arguments);
       this.lsrls = [];
       this.synchLSRLs();
     },

     destroy: function () {
       this.get('lsrls').forEach(function (iLSRL) {
         iLSRL.destroy();
       });
       this.lsrls = [];
       arguments.callee.base.apply(this,arguments);
     },

     /**
      * Keep my list of LSRLModels in synch
      */
     isVisibleChanged: function () {
       var tIsVisible = this.get('isVisible');
       this.synchLSRLs();
       this.get('lsrls').forEach(function (iLSRLModel) {
         iLSRLModel.set('isVisible', tIsVisible);
       });
     }.observes('isVisible'),

     toggleInterceptLocked: function () {
       this.toggleProperty('isInterceptLocked');
     },

     /**
      * Keep my list of LSRLModels in synch
      */
     isInterceptLockedChanged: function () {
       var tIsLocked = this.get('isInterceptLocked');
       this.get('lsrls').forEach(function (iLSRLModel) {
         iLSRLModel.set('isInterceptLocked', tIsLocked);
         iLSRLModel.setComputingNeeded();
       });
     }.observes('isInterceptLocked'),

     /**
      * Keep my list of LSRLModels in synch
      */
     showSumSquaresChanged: function () {
       var tShowing = this.get('showSumSquares');
       this.get('lsrls').forEach(function (iLSRLModel) {
         iLSRLModel.set('showSumSquares', tShowing);
       });
     }.observes('showSumSquares'),

     /**
      * Keep my list of LSRLModels in synch
      */
     showConfidenceBandsChanged: function () {
       var tShowing = this.get('showConfidenceBands');
       this.get('lsrls').forEach(function (iLSRLModel) {
         iLSRLModel.set('showConfidenceBands', tShowing);
       });
     }.observes('showConfidenceBands'),

     /**
      *  We do not set that our values need computing because these are only re-evaluated when
      *  the axis attribute changes.
      */
     setComputingNeeded: function () {
       this._needsComputing = true;
       this.get('lsrls').forEach(function (iLSRLModel) {
         iLSRLModel.setComputingNeeded();
       });
     }.observes('plotModel'),

     enableMeasuresForSelectionDidChange: function () {
       var tEnabled = this.get('enableMeasuresForSelection');
       this.get('lsrls').forEach(function (iLSRLModel) {
         iLSRLModel.set('enableMeasuresForSelection', tEnabled);
       });
     }.observes('enableMeasuresForSelection'),

     /**
      True if any of my values needs computing
      @return { Boolean }
      */
     isComputingNeeded: function (iAxis) {
       if (this._needsComputing)
         return true;
     },

     /**
      Pass this down to my lsrls.
      */
     recomputeSlopeAndInterceptIfNeeded: function (iXAxis, iYAxis) {
       if (this.isComputingNeeded()) {
         this._needsComputing = false;
         this.synchLSRLs();
         this.get('lsrls').forEach(function (iLSRL) {
           iLSRL.recomputeSlopeAndInterceptIfNeeded(iXAxis, iYAxis);
         });
       }
     },

     synchLSRLs: function() {
       var this_ = this,
          tLegendAttrDescription = this.getPath('plotModel.dataConfiguration.legendAttributeDescription'),
          tIsCategorical = tLegendAttrDescription.get('isCategorical'),
          tCellNames = tIsCategorical ?
                       tLegendAttrDescription.getPath('attributeStats.categoricalStats.cellNames') || [] : [],
          tLSRLs = this.get('lsrls');
       if(tCellNames.length > 0) {
         // Remove LSRLs for which there is no longer a cell name
         tLSRLs.filter(function(iLSRL) {
           return tCellNames.indexOf(iLSRL.get('categoryName')) < 0;
         }).forEach(function(eLSRL) {
           this_.removeLSRL(eLSRL);
         });
         // Add an LSRL for which a cell name exists but no corresponding LSRL
         tCellNames.filter(function(iName) {
           return tLSRLs.findIndex(function(iLSRL) {
             return iLSRL.get('categoryName') === iName;
           }) < 0;
         }).forEach(function(iName) {
           this_.addLSRLModel(iName);
         });
       } else {
         while (tLSRLs.length > 1) {
           tLSRLs.pop().destroy();
         }
         if(tLSRLs.length === 0)
           this.addLSRLModel('_main_');
       }
     },

     /**
      *
      * @param iCategoryName {string}
      * @return {DG.LSRLModel}
      */
     addLSRLModel: function (iCategoryName) {

       var tLSRLModel = DG.LSRLModel.create({
         plotModel: this.get('plotModel'),
         categoryName: iCategoryName,
         showSumSquares: this.get('showSumSquares'),
         showConfidenceBands: this.get('showConfidenceBands'),
         enableMeasuresForSelection: this.get('enableMeasuresForSelection'),
         isInterceptLocked: this.get('isInterceptLocked'),
         isVisible: this.get('isVisible')
       });
       tLSRLModel.set('isInterceptLocked', this.get('isInterceptLocked'));
       this.get('lsrls').push(tLSRLModel);
       this.setComputingNeeded();
       return tLSRLModel;
     },

     removeLSRL: function (iLSRL) {
       var tLsrls = this.get('lsrls'),
          tIndex = tLsrls.indexOf(iLSRL);
       tLsrls.splice(tIndex, 1);
       iLSRL.destroy();
     },

     createStorage: function () {
       var storage = arguments.callee.base.apply(this,arguments);
       storage.showSumSquares = this.showSumSquares;
       storage.isInterceptLocked = this.isInterceptLocked;
       storage.showConfidenceBands = this.showConfidenceBands;
       storage.lsrls = [];
       this.get('lsrls').forEach(function (iLSRL) {
         storage.lsrls.push(iLSRL.createStorage());
       });
       return storage;
     },

     restoreStorage: function (iStorage) {
       arguments.callee.base.apply(this,arguments);
       this.showSumSquares = iStorage.showSumSquares;
       this.isInterceptLocked = iStorage.isInterceptLocked;
       this.showConfidenceBands = iStorage.showConfidenceBands;
       this.get('lsrls').forEach(function (iLSRL) {
         iLSRL.set('showSumSquares', this.showSumSquares);
         iLSRL.set('isInterceptLocked', this.isInterceptLocked);
       }.bind(this));
       if (SC.isArray(iStorage.lsrls)) {
         this.get('lsrls').forEach(function (iLSRL, iIndex) {
           iLSRL.restoreStorage(iStorage.lsrls[iIndex]);
         });
       }
     }

   });
DG.PlotAdornmentModel.registry.multipleLSRLModels = DG.MultipleLSRLsModel;

/* >>>>>>>>>> BEGIN source/components/graph/adornments/multiple_movable_values_adornment.js */
// ==========================================================================
//                      DG.MultipleMovableValuesAdornment
//
//  Author:   William Finzer
//
//  Copyright (c) 2016 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/adornments/plot_adornment');

/** @class  Holds onto an array of MovableValueAdornment and takes charge of displaying alternating
 * shaded areas between them.

 @extends DG.PlotAdornment
 */
DG.MultipleMovableValuesAdornment = DG.PlotAdornment.extend(
    /** @scope DG.MultipleMovableValuesAdornment.prototype */
    {
      /**
       My array of adornments
       @property { [{DG.MovableValueAdornment}] }
       */
      valueAdornments: null,

      /**
       * @property {DG.Layer}
       */
      _shadingLayer: null,
      shadingLayer: function () {
        if (!this._shadingLayer && this.getPath('paperSource.layerManager')) {
          this._shadingLayer = this.getPath('paperSource.layerManager.' + DG.LayerNames.kIntervalShading);
        }
        return this._shadingLayer;
      }.property(),

      /** The object has category names as property names and an object of this form for values:
       * { category: { shadingRegions: {Element[]}, shadingCounts: {Element[]}}}
       * @property {Object}
       */
      shadingElementsObject: null,

      /**
       * @property {DG.CellLinearAxisView}
       */
      valueAxisView: null,

      /**
       @property { DG.CellAxisView }
       */
      splitAxisView: function() {
        return this.getPath('parentView.secondaryAxisView');
      }.property(),

      isShowingCountsOrPercents: function () {
        return this.getPath('model.isShowingCount') || this.getPath('model.isShowingPercent');
      }.property(),

      init: function () {
        arguments.callee.base.apply(this,arguments);
        this.set('valueAdornments', []);
        this.set('shadingElements', {});
      },

      destroy: function () {
        this.valueAdornments.forEach(function (iAdorn) {
          iAdorn.destroy();
        });
        arguments.callee.base.apply(this,arguments);
      },

      /**
       Concatenated array of ['PropertyName','ObserverMethod'] pairs used for indicating
       which observers to add/remove from the model.

       @property   {Array of [{String},{String}]}  Elements are ['PropertyName','ObserverMethod']
       */
      modelPropertiesToObserve: [['valueChange', 'updateToModel'],
        ['isShowingCount', 'updateToModel'], ['isShowingPercent', 'updateToModel'],
        ['valueModels', 'numberOfValuesChanged'], ['countPercentsObject', 'numberOfValuesChanged']],

      valueAxisViewDidChange: function() {
        var tNewView = this.get('valueAxisView');
        if( tNewView && this.valueAdornments) {
          this.valueAdornments.forEach(function( iAdorn) {
            iAdorn.set('valueAxisView', tNewView);
          });
        }
      }.observes('valueAxisView'),

      createElements: function () {
        var tMyElements = this.get('myElements'),
            tShadingElementsObject = {},
            tShadingLayer = this.get('shadingLayer'),
            tCountLayer = this.get('layer'),
            tNumValues = this.getPath('model.valueModels').length,
            tNumRegions = (tNumValues === 1) ? 0 : Math.ceil(tNumValues / 2),
            tNumCounts = tNumValues === 0 ? 0 : tNumValues + 1,
            tAnchor = this.getPath('valueAxisView.orientation') === DG.GraphTypes.EOrientation.kHorizontal ?
                'middle' : 'end';
        DG.ObjectMap.forEach(this.getPath('model.countPercentsObject'), function (iCat, iObj) {
          tShadingElementsObject[iCat] = { shadingRegions: [], shadingCounts: []};
          var tShadingRegions = tShadingElementsObject[iCat].shadingRegions;
          while (tShadingRegions.length < tNumRegions) {
            var tNewRegion = this.get('paper').rect(0, 0, 0, 0)
                .attr({'opacity': 0})
                .addClass('dg-movable-shaded');
            tShadingLayer.push(tNewRegion);
            tMyElements.push(tNewRegion);
            tShadingRegions.push(tNewRegion);
            tNewRegion.animate({'opacity': DG.PlotUtilities.kMovableRegionOpacity},
                DG.PlotUtilities.kDefaultAnimationTime, '<>');
          }
          var tCountElements = tShadingElementsObject[iCat].shadingCounts;
          while (tCountElements.length < tNumCounts) {
            var tNewText = this.get('paper').text(0, 0, '')
                .attr({'opacity': 0, 'text-anchor': tAnchor})
                .addClass('dg-graph-adornment');
            tCountLayer.push(tNewText);
            tMyElements.push(tNewText);
            tCountElements.push(tNewText);
            tNewText.animate({'opacity': 1}, DG.PlotUtilities.kDefaultAnimationTime, '<>');
          }
        }.bind(this));
        this.set('shadingElementsObject', tShadingElementsObject);
      },

      /**
       Pass this down to my valueAdornments.
       And then deal with showing counts and percents
       */
      updateToModel: function () {
        var tAdornments = this.get('valueAdornments'),
            tPaper = this.get('paper');
        if( !tPaper)
          return; //Not ready yet

        var getCellNames = function() {
              var tNames = this.getPath('model.plotModel.secondaryAxisModel.attributeDescription.cellNames');
              if (!tNames || tNames.length === 0)
                tNames = [DG.MovableValueModel.kSingleCellName];
              return tNames;
            }.bind(this),

            adjustNumberOfAdornments = function () {
              var tValues = this.getPath('model.valueModels');
              while (tValues.length > tAdornments.length) {
                var tNewAdorn = DG.MovableValueAdornment.create({
                  parentView: this.get('parentView'),
                  model: tValues[tAdornments.length],
                  paperSource: this.get('paperSource'),
                  layerName: this.get('layerName'),
                  valueAxisView: this.get('valueAxisView')
                });
                tNewAdorn.createElements();
                tAdornments.push(tNewAdorn);
              }
              while (tValues.length < tAdornments.length) {
                var tIndex = tAdornments.findIndex(function (iAdorn) {
                  return SC.none(iAdorn.get('model'));
                });
                if (tIndex >= 0) {
                  var tAdorn = tAdornments[tIndex];
                  tAdornments.splice(tIndex, 1);
                  tAdorn.destroy();
                }
              }
            }.bind(this),

            adjustShadedRegions = function () {
              if (tAdornments.length > 1) {
                tCellNames.forEach(function (iCat) {
                  var tScreenCoords = tAdornments.map(function (iAdorn) {
                    return iAdorn.screenCoord(iCat);
                  });
                  // Sort them so that shaded regions work properly
                  tScreenCoords.sort(function(a,b) { return a-b; });
                  // Update the shaded regions
                  var tX, tY, tWidth, tHeight;
                  tScreenCoords.forEach(function (iCoord, iIndex) {
                    if (iIndex % 2 === 0) {
                      var tLabelSpace = DG.MovableValueAdornment.kLabelSpace,
                          tRegion = this.shadingElementsObject[iCat].shadingRegions[iIndex / 2],
                          tCellCoord = tSplitAxisView && tSplitAxisView.cellNameToCoordinate(iCat);
                      if(!DG.isFinite(tCellCoord))
                        tCellCoord = tCellExtent / 2;
                      if (this.getPath('valueAxisView.orientation') === DG.GraphTypes.EOrientation.kHorizontal) {
                        var tRight = iIndex === tScreenCoords.length - 1 ? tPaper.width :
                            tScreenCoords[iIndex + 1];
                        tX = iCoord;
                        tY = tCellCoord - tCellExtent / 2 + tLabelSpace / 2;
                        tWidth = Math.abs(tRight - iCoord);
                        tHeight = Math.abs(tCellExtent - tLabelSpace / 2);
                      } else {
                        var tNextY = (iIndex === tScreenCoords.length - 1) ? 0 :
                            tScreenCoords[iIndex + 1];
                        tX = tCellCoord - tCellExtent / 2;
                        tY = iCoord;
                        tWidth = Math.abs(tCellExtent - tLabelSpace);
                        tHeight = Math.abs(tNextY - iCoord);
                      }
                      tRegion.attr({x: tX, y: tY, width: tWidth, height: tHeight});
                    }
                  }.bind(this));
                }.bind(this));
              }
            }.bind(this),

            adjustPercentsAndCounts = function () {

              function formatValueString(iCPObj) {
                var tCPString = '',
                    tPString = (tShowPercent && !SC.empty(iCPObj.percent)) ?
                        (tShowCount ? '(%@%)' : '%@%').fmt(Math.round(iCPObj.percent)) :
                        '';
                if (tShowCount && !tShowPercent) {
                  tCPString = iCPObj.count.toString();
                }
                else if (tShowPercent && !tShowCount) {
                  tCPString = tPString;
                }
                else if (tShowCount && tShowPercent) {
                  tCPString = '%@ %@'.fmt(iCPObj.count, tPString);
                }
                return tCPString;
              }

              var tAxisView = this.get('valueAxisView'),
                  tOrientation = tAxisView.get('orientation'),
                  tLabelSpace = tAdornments.length > 0 ? DG.MovableValueAdornment.kLabelSpace : 0,
                  tShowCount = this.getPath('model.isShowingCount'),
                  tShowPercent = this.getPath('model.isShowingPercent'),
                  tCountPercentsObject = this.getPath('model.countPercentsObject');
              DG.ObjectMap.forEach(tCountPercentsObject, function (iKey, iCountPercentsArray) {
                var tCountElements = this.shadingElementsObject[iKey].shadingCounts,
                    tCellCoord = tSplitAxisView.cellNameToCoordinate(iKey);
                if( !DG.isFinite(tCellCoord))
                  tCellCoord = tCellExtent / 2;
                iCountPercentsArray.forEach(function (iCountPercentObj, iIndex) {
                  var tLowerCoord = tAxisView.dataToCoordinate(iCountPercentObj.lower),
                      tUpperCoord = tAxisView.dataToCoordinate(iCountPercentObj.upper),
                      tY = tOrientation === DG.GraphTypes.EOrientation.kHorizontal ?
                          tCellCoord - tCellExtent / 2 + tLabelSpace / 2 + 12 :
                          (tLowerCoord + tUpperCoord) / 2,
                      tX = tOrientation === DG.GraphTypes.EOrientation.kHorizontal ?
                          (tLowerCoord + tUpperCoord) / 2 :
                          tCellCoord + tCellExtent / 2 - 5;
                  tCountElements[iIndex].attr({x: tX, y: tY, text: formatValueString(iCountPercentObj)});
                }.bind(this));
              }.bind(this));

            }.bind(this),

        hideShowPercentsAndCounts = function(iShow) {
          DG.ObjectMap.forEach(tCountPercentsObject, function (iKey, iCountPercentsArray) {
            var tCountElements = this.shadingElementsObject[iKey].shadingCounts;
            tCountElements.forEach( function( iElement) {
              if(iShow)
                iElement.show();
              else
                iElement.hide();
            });
          }.bind(this));
        }.bind(this);

        // begin updateToModel
        var tCellNames = getCellNames(),
            tSplitAxisView = this.get('splitAxisView'),
            tCellExtent = tSplitAxisView && tSplitAxisView.get('fullCellWidth'),
            tCountPercentsObject = this.getPath('model.countPercentsObject'),
            tShadingElementsObject = this.get('shadingElementsObject');
        this.get('model').recomputeValueIfNeeded();
        adjustNumberOfAdornments();
        tAdornments.forEach(function (iValueAdornment) {
          iValueAdornment.updateToModel();
        });
        if( this.get('myElements').length === 0 ||
            tCellNames.some(function(iName) {
              return !tShadingElementsObject[iName];  // signifying it's out of date
            }) ||
            Object.keys(tShadingElementsObject).some(function( iKey) {
              return tCellNames.indexOf(iKey) < 0;  // again, it's out of date
            })
        ) {
          this.removeElements();
          this.myElements = [];
          this.createElements();
        }

        adjustShadedRegions();
        if (this.get('isShowingCountsOrPercents')) {
          adjustPercentsAndCounts();
          hideShowPercentsAndCounts(true);
        }
        else
          hideShowPercentsAndCounts(false);
      },

      numberOfValuesChanged: function() {
        this.removeElements();  // Force recomputation from scratch
        this.myElements = [];
        this.updateToModel();
      }

    });


/* >>>>>>>>>> BEGIN source/components/graph/adornments/multiple_movable_values_model.js */
// ==========================================================================
//                      DG.MultipleMovableValuesModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2016 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/adornments/plot_adornment_model');

/** @class  The model for a set of movable valueModels plotted perpendicular to the primary axis.

 @extends SC.Object
 */
DG.MultipleMovableValuesModel = DG.PlotAdornmentModel.extend(
    /** @scope DG.MultipleMovableValuesModel.prototype */
    {
      /**
       An array of the movable value models
       @property { Object } Properties are category names, values are DG.MovableValueModel
       */
      valueModels: null,

      /**
       * @property {DG.CellLinearAxisModel}
       */
      axisModel: null,

      secondaryAxisAttributeDescription: function () {
        return this.getPath('plotModel.secondaryAxisModel.attributeDescription');
      }.property(),

      /**
       * @property {Boolean}
       */
      isShowingCount: false,

      /**
       * @property {Boolean}
       */
      isShowingPercent: false,

      /**
       * @property {{category: [{count: {Number}, percent: {Number}]}}
       */
      countPercentsObject: null,

      /**
       Private cache.
       @property { Boolean }
       */
      _needsComputing: true,

      init: function () {
        arguments.callee.base.apply(this,arguments);
        this.set('valueModels', []);
        this.set('countPercentsObject', {});
      },

      destroy: function () {
        this.beginPropertyChanges();
        while (this.valueModels.length > 0) {
          this.removeValue();
        }
        arguments.callee.base.apply(this,arguments);
      },

      /**
       *  We do not set that our valueModels need computing because these are only re-evaluated when
       *  the axis attribute changes.
       */
      setComputingNeeded: function () {
        this._needsComputing = true;
      }.observes('plotModel', 'isShowingCount', 'isShowingPercent'),

      /**
       True if any of my valueModels needs computing
       @return { Boolean }
       */
      isComputingNeeded: function (iAxis) {
        if (this._needsComputing)
          return true;
      },

      /**
       Pass this down to my valueModels.
       Also compute counts and percents for each region
       */
      recomputeValue: function (iAxis) {
        var tValueModels = this.get('valueModels'),
            tSplitAttributeDescription = this.getPath('secondaryAxisAttributeDescription'),
            tSplitVarID = tSplitAttributeDescription && tSplitAttributeDescription.getPath('attribute.id'),
            tNumericVarID = this.getPath('plotModel.primaryVarID'),
            tCases = this.get('cases'),
            tCountPercentsObject = this.get('countPercentsObject'),
            tCellNames = this.getPath('secondaryAxisAttributeDescription.cellNames'),
            tAssignedValues;
        DG.ObjectMap.forEach(tCountPercentsObject, function(iKey, iValue){
          delete tCountPercentsObject[iKey];
        });
        tValueModels.forEach( function(iValueModel) {
          iValueModel.recomputeValue(this.get('axisModel'), tAssignedValues);
          tAssignedValues = iValueModel.get('values');
        }.bind(this));
        if(!tCellNames || tCellNames.length === 0)
          tCellNames = [DG.MovableValueModel.kSingleCellName];
        if( tValueModels.length > 0) {
          tCellNames.forEach(function (iName) {
            var tEdges = [],
                tCountPercentsArray = [];
            tValueModels.forEach(function (iValueModel) {
              tEdges.push(iValueModel.getValueForCategory(iName));
            });
            tEdges.sort(function (a, b) {
              return b - a; // reverse sort
            });
            for (var tIndex = 0; tIndex <= tEdges.length; tIndex++)
              tCountPercentsArray.push({count: 0, percent: 0});
            var tTotalCount = 0;

            tCases.forEach(function (iCase) {
              var tNumericValue = iCase.getForcedNumericValue(tNumericVarID),
                  tCategoricalValue = tSplitVarID && iCase.getStrValue(tSplitVarID);
              if(SC.none(tCategoricalValue))
                tCategoricalValue = DG.MovableValueModel.kSingleCellName;
              if (isFinite(tNumericValue) && tCategoricalValue === iName) {
                var tBinIndex = tEdges.findIndex(function (iValue) {
                  return tNumericValue > iValue;
                });
                if (tBinIndex === -1)
                  tBinIndex = 0;
                else
                  tBinIndex = tEdges.length - tBinIndex;
                var tCPObj = tCountPercentsArray[tBinIndex];
                tCPObj.count++;
                tTotalCount++;
              }
            });
            tEdges.sort(function (a, b) {
              return a - b; // ascending sort
            });
            tCountPercentsArray.forEach(function (iCPObj, iIndex) {
              iCPObj.percent = tTotalCount === 0 ? '' : 100 * iCPObj.count / tTotalCount;
              iCPObj.lower = (iIndex === 0) ? iAxis.get('lowerBound') : tEdges[iIndex - 1];
              iCPObj.upper = (iIndex === tEdges.length) ? iAxis.get('upperBound') : tEdges[iIndex];
            });
            tCountPercentsObject[iName] = tCountPercentsArray;
          }.bind(this));
        }

        this._needsComputing = false;
      }.observes('axisModel.lowerBound', 'axisModel.upperBound'), // So that we'll recompute lower and upper when axis bounds change

      /**
       Use the bounds of the given axes to recompute slope and intercept.
       */
      recomputeValueIfNeeded: function (iAxis) {
        iAxis = iAxis || this.get('axisModel');
        if (this.isComputingNeeded(iAxis))
          this.recomputeValue(iAxis);
      },

      /**
       * Pass to my valueModels
       */
      handleChangedAxisAttribute: function () {
        this.get('valueModels').forEach(function (iValue) {
          iValue.handleChangedAxisAttribute(this.get('axisModel'));
        }.bind(this));
      },

      valueDidChange: function () {
        this.setComputingNeeded();
        this.notifyPropertyChange('valueChange');
      },

      /**
       *
       * @optional iStorage {Object}
       * @return {DG.MovableValueModel}
       */
      addValue: function (iStorage) {
        var this_ = this;

        function getAllValues() {
          var tAllValues = [];
          this_.get('valueModels').forEach(function (iAdorn) {
            tAllValues = tAllValues.concat(iAdorn.getAllValues());
          });
          return tAllValues;
        }

        var chooseGoodValue = function () {
          // Choose a value between lower and upper axis bounds not too close to an existing value
          var tAxis = this.get('axisModel'),
              tAxisLower = tAxis.get('lowerBound'),
              tLower = tAxisLower,
              tAxisUpper = tAxis.get('upperBound'),
              tUpper = tAxisUpper,
              tValues = getAllValues(),
              tMaxGap = 0,
              tIndex = 0;
          tValues.sort();
          while (tIndex <= tValues.length) {
            var tValue = (tIndex === tValues.length) ? tAxisUpper :
                Math.max(tAxisLower, Math.min(tAxisUpper, tValues[tIndex])),
                tPrevValue = (tIndex === 0) ? tAxisLower : tValues[tIndex - 1];
            if (tValue - tPrevValue > tMaxGap) {
              tMaxGap = tValue - tPrevValue;
              tLower = tPrevValue;
              tUpper = tValue;
            }
            tIndex++;
          }
          return tLower + (tUpper - tLower) / 3;
        }.bind(this);

        var tValue = DG.MovableValueModel.create({
          plotModel: this.get('plotModel')
        });
        if (iStorage) {
          tValue.restoreStorage(iStorage);
        } else {
          tValue.setAllValues(chooseGoodValue());
        }
        this.get('valueModels').push(tValue);
        tValue.addObserver('valueChange', this, 'valueDidChange');
        this.setComputingNeeded();
        this.notifyPropertyChange('valueModels');
        return tValue;
      },

      addThisValue: function (iValue) {
        this.get('valueModels').push(iValue);
        iValue.addObserver('valueChange', this, 'valueDidChange');
        this.setComputingNeeded();
        this.notifyPropertyChange('valueModels');
      },

      removeValue: function () {
        var tValues = this.get('valueModels');
        if (tValues && tValues.length > 0) {
          var tValue = tValues[tValues.length - 1];
          this.removeThisValue(tValue);
          return tValue;
        }
        return null;
      },

      /**
       * Called during undo of addValue
       * @param iValue {DG.MovableValueModel}
       */
      removeThisValue: function (iValue) {
        var tValues = this.get('valueModels'),
            tIndex = tValues.indexOf(iValue);
        DG.assert(tIndex >= 0);
        iValue.removeObserver('valueChange', this, 'valueDidChange');
        tValues.splice(tIndex, 1);
        this.recomputeValue(this.get('axisModel'));
        iValue.notifyPropertyChange('removed');
        this.setComputingNeeded();
        this.notifyPropertyChange('valueModels');
      },

      createStorage: function () {
        var storage = arguments.callee.base.apply(this,arguments);
        storage.isShowingCount = this.isShowingCount;
        storage.isShowingPercent = this.isShowingPercent;
        storage.valueModels = [];
        this.get('valueModels').forEach(function (iValue) {
          storage.valueModels.push(iValue.createStorage());
        });
        return storage;
      },

      restoreStorage: function (iStorage) {
        arguments.callee.base.apply(this,arguments);
        this.set('isShowingCount', iStorage.isShowingCount);
        this.set('isShowingPercent', iStorage.isShowingPercent);
        if (iStorage && iStorage.valueModels) {
          iStorage.valueModels.forEach(function (iValueStorage) {
            this.addValue(iValueStorage);
          }.bind(this));
        }
      }

    });
DG.PlotAdornmentModel.registry.multipleMovableValues = DG.MultipleMovableValuesModel;

/* >>>>>>>>>> BEGIN source/components/graph/adornments/plotted_average_adornment.js */
// ==========================================================================
//                   DG.PlottedAverageAdornment
//
//  Averages displayed as symbols in a dot plot.
//
//  Author:   Craig D. Miller
//
//  Copyright ©2012-13 Scientific Reasoning Research Institute,
//                  University of Massachusetts Amherst
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/adornments/plot_adornment');
sc_require('components/graph/adornments/line_label_mixin');

/**
 * @class  Abstract base class for plot adornments that draw averages (mean, median) as symbols in the plot.
 * @extends DG.PlotAdornment
 */
DG.PlottedAverageAdornment = DG.PlotAdornment.extend(
    /** @scope DG.PlottedAverageAdornment.prototype */
    {
      cellGap: 2, /** gap in pixels between one average line and the next */
      hoverWidth: 5, /** width of invisible 'cover' line that has popup text */
      hoverDelay: 10, /** very short (MS) delay before highlighting appears */
      symSize: 3, /** reference size, about 1/2 of width of symbols */
      symStrokeWidth: 1,
      bgStroke: 'black',
      bgFill: 'gray',
      bgStrokeWidth: 0.5,
      titlePrecision: 2, /** {Number} extra floating point precision of average value for this.titleString */
      titleFraction: 1 / 5, /** {Number} fraction-from-top for placement of average=123 text */

      shadingLayerName: '', /** Set on creation. This is layer where we stash backgrounds */
      /**
       * All my Raphael elements go in this layer
       * @property { DG.RaphaelLayer }
       */
      shadingLayer: function () {
        var tLayerManager = this.getPath('paperSource.layerManager');
        return (tLayerManager && this.layerName) ? tLayerManager[this.shadingLayerName] : null;
      }.property('paperSource', 'shadingLayerName'),

      /**
       * The number of average adornments displayed before me
       * Used to compute default equation position so as not to overlap with previous equations
       * @property offset {number}
       */
      offset: 0,

      /**
       * @property {Element[]}
       */
      lineCovers: null,

      /**
       * These display when user hovers over a symbol but are not part of the symbol
       * @property {Element[]}
       */
      hoverElements: null,

      /**
       Concatenated array of ['PropertyName','ObserverMethod'] pairs used for indicating
       which observers to add/remove from the model.

       @property   {Array of [{String},{String}]}  Elements are ['PropertyName','ObserverMethod']
       */
      // Disabled, needs redesign to avoid redundancy with DG.DotPlotView calls to updateToModel()
      //modelPropertiesToObserve: [ ['values', 'updateToModel'] ],

      init: function () {
        arguments.callee.base.apply(this,arguments);
        this.lineCovers = [];
        this.hoverElements = [];
      },

      /** do we want the average to be visible and up to date? Yes if our model 'isVisible' */
      wantVisible: function () {
        return this.getPath('model.isVisible');
      },

      /**
       * Recompute our model if needed, then move symbols to location specified by model.
       * @param iAnimate {Boolean} [optional] if true then animate to new symbol location.
       */
      updateToModel: function (iAnimate) {
        // We can get here indirectly in which case iAnimate is an object we should ignore
        if (iAnimate !== true)
          iAnimate = false;
        var tAverageModel = this.get('model');
        if (tAverageModel.get('isVisible')) {
          this.createEquationViews(); // No-op if they are already created
          if (!this.textElement) { // initialize the text element "average=", before updateSymbols()
            this.createTextElement();
            this.createBackgroundRect();
            this.textElement.attr('opacity', 1);  // We don't show this element until user hovers,
                                                  // at which point we need opacity to be 1
          }
          tAverageModel.recomputeValueIfNeeded();
          this.updateSymbols(iAnimate);
        }
        // If my plotView has a plottedNormalAdorn and gaussianFitEnabled, update it too
        var tPlottedNormalAdorn = this.getPath('parentView.parentView.plottedNormalAdorn');
        (DG.get('gaussianFitEnabled') && tPlottedNormalAdorn) && tPlottedNormalAdorn.doDraw();
      },

      // Subclasses will override if desired
      createEquationViews: function () {
      },

      // Subclasses may override
      updateEquation: function (i) {

      },

      /**
       * Show or hide the text element "average = 123.456"
       * Using DG.LineLabelMixin to position.
       * @param iShow {Boolean} Show or hide this text element?
       * @param iDisplayValue {Number} Value along numeric axis, for text display
       * @param iAxisValue {Number} Value along numeric axis, for positioning
       * @param iFractionFromTop {Number} used to position text on cross-axis
       * @param iElementID {Number} Rafael element id of the text, so we can find and update it on the fly.
       * @param iValue {Object} Has the statistics for the current cell
       */
      updateTextElement: function (iShow, iDisplayValue, iAxisValue, iFractionFromTop, iValue, iElementID) {
        DG.assert(this.textElement);
        if (iShow && DG.isFinite(iDisplayValue)) {
          // set up parameters used by DG.LineLabelMixin.updateTextToModel()
          this.value = iAxisValue; // for St.Dev., iAxisValue not equal to iDisplayValue
          this.valueAxisView = this.getPath('parentView.primaryAxisView');
          this.valueString = this.titleString(iDisplayValue, iValue);
          this.updateTextToModel(iFractionFromTop);
          this.textElement.show();
          this.backgrndRect.show();
          this.textShowingForID = iElementID;
        } else {
          // hide until next time
          //this.value = 0;
          this.valueString = '';
          this.textElement.hide();
          this.backgrndRect.hide();
          this.textShowingForID = undefined;
        }
      },

      /**
       * Create or update our myElements array of average symbols.
       * @param iAnimate {Boolean} [optional] if true then animate to new symbol location.
       */
      updateSymbols: function (iAnimate) {
        var tAdornment = this,
            tLayer = this.get('layer'),
            tShadingLayer = this.get('shadingLayer'),
            tPrimaryAxisView = this.getPath('parentView.primaryAxisView'),
            tSecondaryAxisView = this.getPath('parentView.secondaryAxisView'),
            tIsHorizontal = tPrimaryAxisView && (tPrimaryAxisView.get('orientation') === DG.GraphTypes.EOrientation.kHorizontal),
            tValuesArray = this.getPath('model.values'),
            tNumValues = tValuesArray && tValuesArray.length,
            tNumElements = this.myElements.length,
            tPaper = this.get('paper');
        if (!tSecondaryAxisView || !tNumValues)
          return; // Happens during transition after secondary attribute removed but before new axis created
        var tCellHeight = tAdornment.getPath('parentView.secondaryAxisView.fullCellWidth'),
            tFullHeight = tAdornment.getPath('parentView.secondaryAxisView.fullWidth'),
            p = {x: 0, y: 0, symSize: this.symSize, cellHeight: tCellHeight - this.cellGap,
              fullHeight: tFullHeight},
            tOffScreen = -3 * this.symSize; // negative view coordinate to move off screen to hide
        var tWorldCoord, tViewCoord, i, tSpread, tSpreadStart, tLowerWhisker, tUpperWhisker, tStat, tAmplitude;
        var tSymbol, tCover, tHoverElement, tBackground, kElemsPerCell = 4; // rafael elements

        function overScope() {
          tAdornment.highlightOne(this._valueIndex);
          if (!tAdornment.get('showMeasureLabels')) {
            tAdornment.updateTextElement(true, this.textStatValue, this.textAxisPosition, this.textCrossPosition,
                this.value, this.id);
          }
        }

        function outScope() {
          tAdornment.unHighlightOne(this._valueIndex);
          if (!tAdornment.get('showMeasureLabels')) {
            tAdornment.updateTextElement(false);
          }
        }

        // for each average value (one per cell on secondary axis), add *two* graphical elements
        // NOTE: alternatively, we might be able to create one group element that has both the symbol and cover as properties.
        for (i = 0; i < tNumValues; ++i) {

          // transform the computed average to view coordinates of symbol reference point
          tStat = tValuesArray[i][this.statisticKey]; // user-visible statistic value: number or undefined
          tWorldCoord = tValuesArray[i][this.centerKey]; // center value to plot: number or undefined
          tSpread = tValuesArray[i][this.spreadKey]; // spread value to plot: number or undefined;
          tSpreadStart = tValuesArray[i][this.spreadStartKey]; // world coord of lower end of spread
          tLowerWhisker = tValuesArray[i][this.lowerKey]; // end of lower whisker to plot: number or undefined;
          tUpperWhisker = tValuesArray[i][this.upperKey]; // end of upper whisker to plot: number or undefined;
          tAmplitude = tValuesArray[i][this.amplitudeKey]; // amplitude of gaussian fit curve for histogram
          tViewCoord = (isFinite(tWorldCoord) ? tPrimaryAxisView.dataToCoordinate(tWorldCoord) : tOffScreen);
          p.width = (isFinite(tSpread) ? Math.abs(tPrimaryAxisView.dataToCoordinate(tWorldCoord + tSpread) - tViewCoord) : 0);
          p.x = (tIsHorizontal ? tViewCoord : i * tCellHeight);
          p.y = (tIsHorizontal ? (tNumValues - i) * tCellHeight : tViewCoord);
          p.count = tValuesArray[i].count;
          p.center = tWorldCoord;
          p.spread = tSpread;
          p.spreadStart = (isFinite(tSpreadStart) ?
              tPrimaryAxisView.dataToCoordinate(tSpreadStart) : tOffScreen);
          p.lowerWhisker = (isFinite(tLowerWhisker) ?
              p.spreadStart - tPrimaryAxisView.dataToCoordinate(tLowerWhisker) : 0);
          p.upperWhisker = (isFinite(tUpperWhisker) ?
              (tIsHorizontal ? tPrimaryAxisView.dataToCoordinate(tUpperWhisker) - (p.spreadStart + p.width) :
                  -(p.spreadStart - p.width - tPrimaryAxisView.dataToCoordinate(tUpperWhisker))) : 0);
          p.amplitude = (isFinite(tAmplitude) ? tAmplitude : null);

          // create symbol and invisible cover line elements as needed (set constant attributes here)
          if (i * kElemsPerCell >= tNumElements) {
            tBackground = tPaper.path('M0,0')
                .attr({
                  stroke: this.bgStroke,
                  'stroke-width': this.bgStrokeWidth,
                  fill: this.bgFill,
                  'fill-opacity': 0.5
                });
            tSymbol = tPaper.path('M0,0')
                .attr({stroke: this.symStroke, 'stroke-width': this.symStrokeWidth, 'stroke-opacity': 0});
            tCover = tPaper.path('M0,0')
                .attr({'stroke-width': this.hoverWidth, stroke: DG.RenderingUtilities.kTransparent})
                .hover(overScope, outScope);
            tCover._valueIndex = i;
            this.lineCovers[i] = tCover;
            tHoverElement = tPaper.path('M0,0')
                .attr({stroke: this.symStroke, 'stroke-width': this.symStrokeWidth, 'stroke-opacity': 0});
            tHoverElement._valueIndex = i;
            this.hoverElements[i] = tHoverElement;
            tBackground.animatable = tSymbol.animatable = true;
            tBackground.animate({'stroke-opacity': 1}, DG.PlotUtilities.kDefaultAnimationTime, '<>');
            tSymbol.animate({'stroke-opacity': 1}, DG.PlotUtilities.kDefaultAnimationTime, '<>');
            this.myElements.push(tBackground);
            this.myElements.push(tSymbol);
            this.myElements.push(tCover);
            this.myElements.push(tHoverElement);
            tShadingLayer.push(tBackground);
            tLayer.push(tSymbol);
            tLayer.push(tCover);
            tLayer.push(tHoverElement);
          }

          // update elements (to current size/position)
          tBackground = this.myElements[i * kElemsPerCell];
          tSymbol = this.myElements[i * kElemsPerCell + 1];
          tCover = this.myElements[i * kElemsPerCell + 2];
          tHoverElement = this.myElements[i * kElemsPerCell + 3];
          if (iAnimate) {
            tBackground.animate({path: this.backgroundPath(p, tIsHorizontal)}, DG.PlotUtilities.kDefaultAnimationTime, '<>');
            tSymbol.animate({path: this.symbolPath(p, tIsHorizontal)}, DG.PlotUtilities.kDefaultAnimationTime, '<>',
                this.updateToModel.bind(this));
          } else {
            tBackground.attr({path: this.backgroundPath(p, tIsHorizontal)});
            tSymbol.attr({path: this.symbolPath(p, tIsHorizontal)});
          }
          tCover.attr('path', this.coverPath(p, tIsHorizontal));
          tHoverElement.attr('path', this.hoverElementPath(p, tIsHorizontal));

          // save the following values for updateTextElement() which is called during hover over the cover element
          tCover.textStatValue = tStat;
          tCover.textAxisPosition = this.getTextPositionOnAxis(tWorldCoord, tSpread);
          tCover.textCrossPosition = tIsHorizontal ?
              1 - ((1 / tNumValues) * (i + 1 - this.titleFraction)) :
              ((1 / tNumValues) * (i + this.titleFraction)); // text position in range [0-1] on cross axis
          tCover.value = tValuesArray[i];

          tSymbol.toFront(); // keep averages on top of cases
          tCover.toFront();  // keep cover on top of average symbol
          tHoverElement.toFront();  // So we can see it
          if (!this.get('showMeasureLabels')) {
            if (this.textElement) {
              this.backgrndRect.toFront();
              this.textElement.toFront();
            } // keep text in front of case circles

            // if mouse is now over an element with text showing, update the text now.
            if (this.textShowingForID === tCover.id) {
              this.updateTextElement(true, tCover.textStatValue, tCover.textAxisPosition, tCover.textCrossPosition,
                  tCover.id, tCover.value);
            }
          }

          this.updateEquation(i);
        }

        // remove extra symbols (if number of cells has shrunk)
        if (this.myElements.length > (kElemsPerCell * tNumValues)) {
          this.removeExtraSymbols(kElemsPerCell * tNumValues);
        }
        DG.assert(this.myElements.length === kElemsPerCell * tValuesArray.length);
      },

      /**
       * Remove extra symbols from the plot and the end of our 'myElements' array
       * @param iDesiredNumSymbols
       */
      removeExtraSymbols: function (iDesiredNumSymbols) {
        var tLayer = this.get('layer'),
            tShadingLayer = this.get('shadingLayer'),
            i, j, tElement;

        for (i = iDesiredNumSymbols, j = this.myElements.length; i < j; ++i) {
          tElement = this.myElements[i];
          tLayer.prepareToMoveOrRemove(tElement);
          tShadingLayer.prepareToMoveOrRemove(tElement);
          tElement.remove();
        }
        this.myElements.length = iDesiredNumSymbols;
      },

      /**
       * Create the path string for the average symbol; can be overridden
       * @param p {x,y,cellHeight} of reference point
       * @param iIsHorizontal {Boolean}
       * @return {String} M:move-to absolute: l:line-to relative: z:close path
       */
      symbolPath: function (p, iIsHorizontal) {
        if (iIsHorizontal) {
          return 'M%@,%@ v%@'.fmt(p.x, p.y, -(p.cellHeight));
        } else {
          return 'M%@,%@ h%@'.fmt(p.x, p.y, p.cellHeight);
        }
      },

      /**
       * Create the path string for the invisible popup cover region.
       * @param p {x,y,cellHeight} of reference point
       * @return {String} M:move-to absolute: v:vertical-line-to relative: h:horizontal-line-to
       */
      coverPath: function (p, iIsHorizontal) {
        if (iIsHorizontal) {
          return 'M%@,%@ v%@'.fmt(p.x, p.y, -(p.cellHeight));
        } else {
          return 'M%@,%@ h%@'.fmt(p.x, p.y, p.cellHeight);
        }
      },

      /**
       * Create the path string for element that will display on hover but is not part of the symbol.
       * @param p {x,y,cellHeight} of reference point
       * @return {String} M:move-to absolute: v:vertical-line-to relative: h:horizontal-line-to
       */
      hoverElementPath: function (p, iIsHorizontal) {
        return '';
      },

      /**
       * Create the path string for the background, for example gray reference lines on the St.Dev..
       * @param p {x,y,cellHeight} of reference point
       * @return {String} M:move-to absolute: v:vertical-line-to relative: h:horizontal-line-to
       */
      backgroundPath: function (p, iIsHorizontal) {
        return 'M0,0'; // default is to return an empty path
      },

      getValueString: function (axisValue, titleResource) {
        var tPrecision = DG.PlotUtilities.findFractionDigitsForAxis(this.getPath('parentView.primaryAxisView')),
           tNumFormat = DG.Format.number().fractionDigits(0, tPrecision).group('');
        return titleResource.loc(tNumFormat(axisValue));
      },

      /**
       * Return a string to be displayed to user to show numeric value with rounding and units
       * @param axisValue
       * @returns {{valueString:string, unitsString:string}}
       */
      valueAndUnitsStrings: function (axisValue, titleResource) {
        // convert resource to string with rounding, and insert axis value number
        if(!isFinite(axisValue))
          return {};
        var tUnits = this.getPath('parentView.primaryAxisView.model.firstAttributeUnit'),
           tValueString = this.getValueString(axisValue, titleResource);
        return {valueString: tValueString, unitsString: tUnits};
      },

      /**
       * @return {String} title string to show when hovering over average symbol/line
       */
      titleString: function (axisValue) {
        var tValueAndUnits = this.valueAndUnitsStrings(axisValue, this.titleResource);
        if (!tValueAndUnits.valueString)
          return '';
        if (this.get('showMeasureLabels')) {
          var tHTML = '<p style = "color:%@;">%@ %@</p>',
              tUnitsSpan = '<span style = "color:grey;">%@</span>'.loc(tValueAndUnits.unitsString);
          return tHTML.loc(this.symStroke, tValueAndUnits.valueString, tUnitsSpan);
        } else {
          return tValueAndUnits.valueString + ' ' + tValueAndUnits.unitsString;
        }
      }

    });

/**
 * @class  Base class for plotted average adornments that consist of a single line or area
 * @extends DG.PlottedAverageAdornment
 */
DG.PlottedSimpleAverageAdornment = DG.PlottedAverageAdornment.extend(DG.LineLabelMixin,
    /** @scope DG.PlottedSimpleAverageAdornment.prototype */
    (function () {

      return {

        init: function () {
          arguments.callee.base.apply(this,arguments);
          this.equationViews = [];
        },

        destroy: function () {
          this.destroyEquationViews();
          arguments.callee.base.apply(this,arguments);
        },

        showMeasureLabels: function () {
          return this.getPath('model.plotModel.showMeasureLabels') || SC.platform.touch;
        }.property(),

        showMeasuresLabelsDidChange: function () {
          if (this.get('showMeasureLabels')) {
            this.createEquationViews();
          } else {
            this.destroyEquationViews();
          }
          this.notifyPropertyChange('showMeasureLabels');
        }.observes('model.plotModel.showMeasureLabels'),

        /**
         * @property {DG.EquationView[]}
         */
        equationViews: null,

        destroyEquationViews: function () {
          if (this.get('equationViews')) {
            this.get('equationViews').forEach(function (iView) {
              iView.destroy();
            });
          }
          this.equationViews = [];
        },

        setEquationsVisibility: function (iIsVisible) {
          this.get('equationViews').forEach(function (iView) {
            iView.set('isVisible', iIsVisible);
          });
        },

        showElements: function () {
          arguments.callee.base.apply(this,arguments);
          this.setEquationsVisibility(true);
        },

        hideElements: function () {
          arguments.callee.base.apply(this,arguments);
          this.setEquationsVisibility(false);
        },

        /**
         * There will be one equation view for each of our values
         */
        createEquationViews: function () {
          var this_ = this,
              tEqViewIndex, tMouseStart, tOriginalCoordinates, tReturnPoint;

          function highlightElements(iIndex) {
            this_.highlightOne(iIndex);
          }

          function unHighlightElements(iIndex) {
            this_.unHighlightOne(iIndex);
          }

          function beginDrag(event) {
            var tEqView = this;

            function getCurrentCoords() {
              var tEqLayer = tEqView.get('layer');
              return {
                proportionX: tEqLayer.offsetLeft / this_.get('paper').width,
                proportionY: tEqLayer.offsetTop / this_.get('paper').height
              };
            }

            tEqViewIndex = tEqView.get('index');
            tMouseStart = {x: event.clientX, y: event.clientY};
            tOriginalCoordinates = this_.getPath('model.equationCoordsArray')[tEqViewIndex];
            tReturnPoint = SC.none(tOriginalCoordinates) ? getCurrentCoords() : tOriginalCoordinates;
            return YES;
          }

          function continueDrag(event) {
            var dX = (event.clientX - tMouseStart.x),
                dY = (event.clientY - tMouseStart.y),
                tPaper = this_.get('paper');
            if( dX !== 0 || dY !== 0) {
              var tCoordsArray = this_.getPath('model.equationCoordsArray'),
                  tCoords = {
                    proportionX: tReturnPoint.proportionX + dX / tPaper.width,
                    proportionY: tReturnPoint.proportionY + dY / tPaper.height
                  };
              tCoordsArray[tEqViewIndex] = tCoords;
              this_.updateEquation(tEqViewIndex);
            }
          }

          function endDrag(iEvent) {
            var tOriginal = tOriginalCoordinates,
                tNew;
            DG.UndoHistory.execute(DG.Command.create({
              name: "graph.repositionEquation",
              undoString: 'DG.Undo.graph.repositionEquation',
              redoString: 'DG.Redo.graph.repositionEquation',
              log: "Moved equation from %@ to %@".fmt(tOriginal, this.getPath('model.coordinates')),
              executeNotification: {
                action: 'notify',
                resource: 'component',
                values: {
                  operation: 'reposition equation',
                  type: 'DG.GraphView'
                }
              },
              execute: function () {
                tNew = this_.getPath('model.equationCoordsArray')[tEqViewIndex];
              }.bind(this),
              undo: function () {
                this_.getPath('model.equationCoordsArray')[tEqViewIndex] = tOriginal;
                this_.updateEquation(tEqViewIndex);
              }.bind(this),
              redo: function () {
                this_.getPath('model.equationCoordsArray')[tEqViewIndex] = tNew;
                this_.updateEquation(tEqViewIndex);
              }.bind(this)
            }));
          }

          if (this.get('showMeasureLabels')) {
            if (!this.equationViews)
              this.equationViews = [];
            var tValuesArray = this.getPath('model.values'),
                tNumValues = tValuesArray && tValuesArray.length;
            while (this.equationViews.length < tNumValues) {
              var tEquationView = DG.EquationView.create({
                index: this.equationViews.length,
                highlight: highlightElements,
                unhighlight: unHighlightElements,
                mouseDown: beginDrag,
                mouseDragged: continueDrag,
                mouseUp: endDrag
              });
              tEquationView.set('isVisible', false);
              this.get('paperSource').appendChild(tEquationView);
              this.equationViews.push(tEquationView);
            }
            while (this.equationViews.length > tNumValues) {
              this.equationViews.pop().destroy();
            }
            for (var index = 0; index < this.equationViews.length; index++) {
              this.updateEquation(index);
            }
          }
        },

        updateEquation: function (iIndex) {
          if (this.getPath('showMeasureLabels')) {
            var tIsHorizontal = this.getPath('parentView.primaryAxisView.orientation') ===
                                DG.GraphTypes.EOrientation.kHorizontal,
                tValuesArray = this.getPath('model.values'),
                tNumValues = tValuesArray && tValuesArray.length,
                tCenterWorld = tValuesArray[iIndex][this.centerKey],
                tStat = tValuesArray[iIndex][this.statisticKey],
                tTitleString = this.titleString(tStat, tValuesArray[iIndex]),
                tCellWidth = this.getPath('parentView.secondaryAxisView.fullCellWidth'),
                tPrimaryAxisView = this.getPath('parentView.primaryAxisView'),
                tEquationView = this.get('equationViews')[iIndex],
                tCoordsFromModel = this.getPath('model.equationCoordsArray')[iIndex],
                tPaper = this.get('paper'),
                tX, tY;
            if (!tEquationView)
              return; // Can happen during transitions
            tEquationView.show({x: 0, y: -100}, tTitleString);
            if (tCoordsFromModel) {
              var tEquationDiv = tEquationView.get('layer'),
                  tWidth = tEquationDiv.offsetWidth,
                  tHeight = tEquationDiv.offsetHeight;
              tX = tCoordsFromModel.proportionX * tPaper.width;
              tX = Math.min(Math.max(tX, -tWidth / 2), tPaper.width - tWidth / 2);
              tY = tCoordsFromModel.proportionY * tPaper.height;
              tY = Math.min(Math.max(tY, -tHeight / 2), tPaper.height - tHeight / 2);
              // Adjust the proportions in case we changed
              tCoordsFromModel.proportionX = tX / tPaper.width;
              tCoordsFromModel.proportionY = tY / tPaper.height;
            } else {
              var kOffscreen = -9,
                  tViewCoord = isFinite(tCenterWorld) ? tPrimaryAxisView.dataToCoordinate(tCenterWorld) : kOffscreen,
                  tSpreadWorld = tValuesArray[iIndex][this.spreadKey],
                  tSpreadCoord = isFinite(tSpreadWorld) ?
                      Math.abs(tPrimaryAxisView.dataToCoordinate(tSpreadWorld) - tPrimaryAxisView.dataToCoordinate(0)) : 0,
                  tLoc = this.getTextPositionOnAxis(tViewCoord, tSpreadCoord),
                  tOffset = this.get('offset') * DG.EquationView.defaultHeight;
              tX = tIsHorizontal ? tLoc : iIndex * tCellWidth;
              tY = tIsHorizontal ? tOffset + (tNumValues - iIndex - 1) * tCellWidth :
                  tOffset + (iIndex % 2) * DG.EquationView.defaultHeight;
            }
            tEquationView.set('isVisible', this.getPath('model.isVisible'));
            tEquationView.show({x: tX, y: tY}, tTitleString);
          }
        },

        offsetDidChange: function () {
          this.get('equationViews').forEach(function (iView, iIndex) {
            this.updateEquation(iIndex);
          }.bind(this));
        }.observes('offset'),

        highlightOne: function (iIndex) {
          var tCoverAttributes = {stroke: this.hoverColor},
              tHoverAttributes = {'stroke-opacity': 1},
              tCoverElement = this.lineCovers[iIndex],
              tHoverElement = this.hoverElements[iIndex];
          tCoverElement.stop();
          tCoverElement.animate(tCoverAttributes, this.hoverDelay);
          tHoverElement.stop();
          tHoverElement.animate(tHoverAttributes, this.hoverDelay);
          if (this.get('showMeasureLabels')) {
            this.get('equationViews')[iIndex].set('highlighted', true);
          }
        },

        unHighlightOne: function (iIndex) {
          var tCoverAttributes = {stroke: DG.RenderingUtilities.kTransparent},
              tHoverAttributes = {'stroke-opacity': 0},
              tCoverElement = this.lineCovers[iIndex],
              tHoverElement = this.hoverElements[iIndex];
          tCoverElement.stop();
          tCoverElement.animate(tCoverAttributes, DG.PlotUtilities.kHighlightHideTime);
          tHoverElement.stop();
          tHoverElement.animate(tHoverAttributes, DG.PlotUtilities.kHighlightHideTime);
          if (this.get('showMeasureLabels')) {
            this.get('equationViews')[iIndex].set('highlighted', false);
          }
        },

        /**
         * Get the desired axis position of the equation view, in display coordinates.
         * @param iCenterValue {Number}
         * @param iSpreadValue {Number}
         */
        getTextPositionOnAxis: function (iCenterValue, iSpreadValue) {
          var tOffset = 0,
              tAxisView = this.get('valueAxisView');
          if (tAxisView) {
            tOffset = Math.abs(tAxisView.coordinateToData(2) - tAxisView.coordinateToData(0));
          }
          return iCenterValue + tOffset; // default to text going to the right of the center line
        }

      };  // object returned closure
    }()) // function closure
);

/**
 * @class  Plots a computed value.
 * @extends DG.PlottedAverageAdornment
 */
DG.PlottedMeanAdornment = DG.PlottedSimpleAverageAdornment.extend(
    /** @scope DG.PlottedMeanAdornment.prototype */
    {
      statisticKey: 'mean', /** {String} key to relevant statistic in this.model.values[i][statistic] */
      centerKey: 'mean',
      titleResource: 'DG.PlottedAverageAdornment.meanValueTitle', /** {String} resource string for this.titleString() */
      //titleFraction: 0.3,   /** {Number} fraction-from-top for placement of average=123 text */
      hoverColor: "rgba(0, 0, 255, 0.3)", /** color of line when mouse over cover line */
      symStroke: '#00F',
      symStrokeWidth: 1.5

      /**
       * Create the path string for a Tinkerplots-like equilateral triangle at the given point on the axis line.
       * @param p {x,y,cellHeight} of reference point
       * @param iIsHorizontal {Boolean}
       * @return {String} M:move-to absolute: l:line-to relative: z:close path
       */
      /*symbolPath: function( p, iIsHorizontal ) {
        var triHeight = p.symSize*Math.sqrt(3),
            pathString = 'M%@,%@ l%@,%@ l%@,%@ z %@%@';
        if( iIsHorizontal ) {
          return pathString.fmt(
              p.x, (p.y - triHeight), // top of upward-pointing triangle
              (-p.symSize), triHeight, // lower left of triangle base
              (p.symSize*2), 0, // lower right of triangle base
              'V', // vertical line
              (p.y-p.cellHeight) // close path then move vertically to top of cell
            );
        } else {
          return pathString.fmt(
              (p.x+triHeight), p.y, // top of right-pointing triangle
              -triHeight, (-p.symSize), // top left of triangle base
              0, (p.symSize*2), // top right of triangle base
              'H', // horizontal line
              (p.x+p.cellHeight) // close path then move horizontally to top of cell
            );
        }
      }*/

    });


/**
 * @class  Plots a computed value.
 * @extends DG.PlottedSimpleAverageAdornment
 */
DG.PlottedMedianAdornment = DG.PlottedSimpleAverageAdornment.extend(
    /** @scope DG.PlottedMedianAdornment.prototype */
    {
      statisticKey: 'median',
      /** {String} key to relevant statistic in this.model.values[i][statisticKey] */
      centerKey: 'median',
      titleResource: 'DG.PlottedAverageAdornment.medianValueTitle',
      /** {String} resource string for this.titleString() */
      //titleFraction: 0.1,   /** {Number} fraction-from-top for placement of average=123 text */
      hoverColor: "rgba(193, 0, 32, 0.3)",
      /** color of line when mouse over cover line */
      symStroke: '#C10020',
      symStrokeWidth: 1.5

      /**
       * Create the path string for a TinkerPlots-like upside-down 'T' at the given point on the axis line.
       * @param p {x,y,cellHeight} of reference point
       * @param iIsHorizontal {Boolean}
       * @return {String} M:move-to absolute: l:line-to relative: z:close path
       */
      /*symbolPath: function( p, iIsHorizontal ) {
        if( iIsHorizontal ) {
          return 'M%@,%@ v%@ v%@ h%@ h%@'.fmt(
           p.x, p.y,
           -p.cellHeight, p.cellHeight,
           p.symSize, -2* p.symSize );
        } else {
          return 'M%@,%@ h%@ h%@ v%@ v%@'.fmt(
            p.x, p.y,
            p.cellHeight, -p.cellHeight,
            p.symSize, -2* p.symSize );
        }
      }
      */
    });


/**
 * @class  Plots a computed value.
 * @extends DG.PlottedSimpleAverageAdornment
 */
DG.PlottedDevAdornment = DG.PlottedSimpleAverageAdornment.extend(
    /** @scope DG.PlottedDevAdornment.prototype */
    {
      /**
       * Create the path string for the rectangular area covering the Standard Deviation.
       * @param p {x,y,cellHeight,width} of reference point in view coordinates
       * @param iIsHorizontal {Boolean}
       * @param iWidth {Number} width in pixels of spread
       * @return {String} M:move-to absolute: l:line-to relative: z:close path
       */
      symbolPath: function (p, iIsHorizontal) {
        if (iIsHorizontal) {
          // 2 lines
          return 'M%@,%@ v%@ M%@,%@ v%@'.fmt(
              p.x, p.y, -p.cellHeight, // vertical line up at -1 st.dev.
              p.x + 2 * p.width, p.y, -p.cellHeight); // vertical line up at +1 st.dev.
        } else {
          // 2 lines
          return 'M%@,%@ h%@ M%@,%@ h%@'.fmt(
              p.x, p.y, p.cellHeight, // vertical line up at -1 st.dev.
              p.x, p.y - 2 * p.width, p.cellHeight); // vertical line up at +1 st.dev.
        }
      },

      /**
       * Create the path string for the background, for example gray reference lines on the St.Dev..
       * @param p {x,y,cellHeight} of reference point
       * @return {String} M:move-to absolute: v:vertical-line-to relative: h:horizontal-line-to
       */
      backgroundPath: function (p, iIsHorizontal) {
        var x = p.x,
            y = p.y,
            w = p.width,
            h = p.cellHeight;
        if (iIsHorizontal) {
          return 'M%@,%@ v%@ h%@ v%@ z M%@,%@ v%@'.fmt(
              x, y, -h, 2 * w, h, // box from -1 to +1 s.d.
              x + w, y, -h); // vertical line up at mean
        } else {
          return 'M%@,%@ h%@ v%@ h%@ z M%@,%@ h%@'.fmt(
              x, y, h, -2 * w, -h, // box from mean to +1 s.d.
              x, y - w, h); // horizontal line right at -1 s.d.
        }
      },

      /**
       * Create the path string for the invisible popup cover region.
       * @param p {x,y,cellHeight,width} of reference point
       * @return {String} M:move-to absolute: v:vertical-line-to relative: h:horizontal-line-to
       */
      coverPath: function (p, iIsHorizontal) {
        return this.symbolPath(p, iIsHorizontal);
      },

      /**
       * Get the desired axis position of the pop-up text, in the attribute's coordinates.
       * @param iCenterValue
       * @param iSpreadValue
       */
      getTextPositionOnAxis: function (iCenterValue, iSpreadValue) {
        return iCenterValue + iSpreadValue; // text going to the right of the shading
      }

    });

/**
 * @class  Plots a computed deviation.
 * @extends DG.PlottedDevAdornment
 */
DG.PlottedStDevAdornment = DG.PlottedDevAdornment.extend(
    /** @scope DG.PlottedStDevAdornment.prototype */
    {
      bgFill: '#9980FF',
      bgStroke: '#9980FF',
      bgStrokeWidth: 0.5,
      symStrokeWidth: 1,
      symStroke: '#30F',
      statisticKey: 'stdev',
      /** {String} key to relevant statistic in this.model.values[i][statisticKey] */
      centerKey: 'centerMinus1Dev',
      /** {String} key to relevant center point in this.model.values[i][centerKey] */
      spreadKey: 'stdev',
      /** {String} key to relevant spread value in this.model.values[i][width] */
      titleResource: 'DG.PlottedAverageAdornment.stDevValueTitle',
      /** {String} resource string for this.titleString() */
      //titleFraction: 0.4,   /** {Number} fraction-from-top for placement of average=123 text */
      symHeight: 0.6,
      /** {Number} fractional distance from axis for symbol line  */
      hoverColor: "rgba(48, 0, 255, 0.3)", /** color of line when mouse over cover line */

    });

/**
 * @class  Plots a computed Inter-Quartile Range (IQR), between the first and third quartiles (Q1 and Q3).
 * @extends DG.PlottedSimpleAverageAdornment
 */
DG.PlottedStErrAdornment = DG.PlottedSimpleAverageAdornment.extend(
   /** @scope DG.PlottedStErrAdornment.prototype */
   {
     statisticKey: 'sterr', /** {String} key to relevant statistic in this.model.values[i][statisticKey] */
     centerKey: 'mean', /** {String} key to relevant center point in this.model.values[i][centerKey] */
     spreadKey: 'sterr', /** {String} key to relevant spread value in this.model.values[i][width] */
     titleResource: 'DG.PlottedAverageAdornment.stErrValueTitle', /** {String} resource string for this.titleString() */
     hoverColor: "rgba(246, 118, 142, 0.3)", /** color of line when mouse over cover line */
     bgStroke: '#FFb280',
     bgStrokeWidth: 0.5,
     bgFill: '#FFb280',
     symStroke: '#F6768E',
     offsetFromEdge: 10,
     tickLength: 6,
     modelPropertiesToObserve: [ ['numberOfStdErrs', 'updateToModel'] ],

     /**
      * Override so we can side effect plotted normal adornment
      * @param iAnimate {Boolean} [optional] if true then animate to new symbol location.
      */
     updateToModel: function (iAnimate) {
       arguments.callee.base.apply(this,arguments);
       // If my plotView has a plottedNormalAdorn and gaussianFitEnabled, update it too
       var tPlottedNormalAdorn = this.getPath('parentView.plottedNormalAdorn'),
           tIsHistogram = this.getPath('model.plotModel.dotsAreFused');
       DG.get('gaussianFitEnabled') === 'yes' && tPlottedNormalAdorn && tIsHistogram &&
          tPlottedNormalAdorn.updateToModel();
     },

     getValueString: function (stdErr, titleResource) {
       var tPrecision = DG.PlotUtilities.findFractionDigitsForAxis(this.getPath('parentView.primaryAxisView')),
          tNumFormat = DG.Format.number().fractionDigits(0, tPrecision).group(''),
          tNumStdErrs = this.getPath('model.numberOfStdErrs'),
          tNumStdErrsString = tNumStdErrs === 1 ? '' : String(tNumStdErrs);
       return this.get('showMeasureLabels')
              ? titleResource.loc(tNumStdErrsString, '<sub style="vertical-align: sub">', '</sub>',
                  tNumFormat(tNumStdErrs * stdErr))
              : titleResource.loc(tNumStdErrsString, '', '', tNumFormat(tNumStdErrs * stdErr));
     },

     /**
      * Create the path string for the line going from mean - stErr to mean + stErr with 5 pixel end bars.
      * @param p {x,y,width,cellHeight} of reference point, (.x,.y) is Q1, .width is IQR in pixels.
      * @return {String} M:move-to absolute: v:vertical-line-to relative: h:horizontal-line-to
      */
     symbolPath: function (p, iIsHorizontal) {
       var tHorizontalY = p.y - p.cellHeight + this.offsetFromEdge,
           tVerticalX = p.x + p.cellHeight - this.offsetFromEdge,
           tWidth = this.getPath('model.numberOfStdErrs') * p.width;
       if (iIsHorizontal) {
         return 'M%@,%@ h%@ M%@,%@ v%@ M%@,%@ v%@'.fmt(
            p.x - tWidth, tHorizontalY, 2 * tWidth,  // horizontal line segment
            p.x - tWidth, tHorizontalY - this.tickLength / 2, this.tickLength, // left tick
            p.x + tWidth, tHorizontalY - this.tickLength / 2, this.tickLength // right tick
         ); // vertical line up on mean + stErr
       } else {
         return 'M%@,%@ v%@ M%@,%@ h%@ M%@,%@ h%@'.fmt(
            tVerticalX, p.y + tWidth, - 2 * tWidth,  // vertical line segment
            tVerticalX - this.tickLength / 2, p.y + tWidth, this.tickLength, // upper tick
            tVerticalX - this.tickLength / 2, p.y - tWidth, this.tickLength); // lower tick
       }
     },

     /**
      * Create the path string for the invisible popup cover region.
      * @param p {x,y,width,cellHeight} of reference point, (.x,.y) is Q1, .width is IQR in pixels.
      * @return {String} M:move-to absolute: v:vertical-line-to relative: h:horizontal-line-to
      */
     coverPath: function (p, iIsHorizontal) {
       return this.symbolPath(p, iIsHorizontal);
     },

     /**
      * Create the path string for any element we want to show on hover but not to trigger a hover.
      * @param p {x,y,width,cellHeight} of reference point, (.x,.y) is Q1, .width is IQR in pixels.
      * @return {String} M:move-to absolute: v:vertical-line-to relative: h:horizontal-line-to
      */
     hoverElementPath: function (p, iIsHorizontal) {
       var tWidth = this.getPath('model.numberOfStdErrs') * p.width;
       if (iIsHorizontal) {
         return 'M%@,%@ v%@ M%@,%@ v%@'.fmt(
            p.x - tWidth, 0, p.fullHeight,  // vertical line segment to axis
            p.x + tWidth, 0, p.fullHeight // vertical line segment to axis
         ); // vertical line up on mean + stErr
       } else {
         return 'M%@,%@ h%@ M%@,%@ h%@'.fmt(
            0, p.y + tWidth, p.fullHeight,  // horizontal line segment to axis
            0, p.y - tWidth, p.fullHeight // horizontal line segment to axis
          );
       }
     },

     /**
      * Get the desired axis position of the pop-up text, in the attribute's coordinates.
      * @param iCenterValue
      * @param iSpreadValue
      */
     getTextPositionOnAxis: function (iCenterValue, iSpreadValue) {
       return iCenterValue + iSpreadValue; // text going to the right of the bar
     }
   });

/**
 * @class  Plots a computed deviation.
 * @extends DG.PlottedDevAdornment
 */
DG.PlottedMeanAbsDevAdornment = DG.PlottedDevAdornment.extend(
    /** @scope DG.PlottedMeanAbsDevAdornment.prototype */
    {
      bgFill: '#9ac6ff',
      bgStroke: '#5bbaff',
      bgStrokeWidth: 0.5,
      symStrokeWidth: 1,
      symStroke: '#00adff',
      statisticKey: 'mad', /** {String} key to relevant statistic in this.model.values[i][statisticKey] */
      centerKey: 'centerMinus1Dev', /** {String} key to relevant center point in this.model.values[i][centerKey] */
      spreadKey: 'mad', /** {String} key to relevant spread value in this.model.values[i][width] */
      titleResource: 'DG.PlottedAverageAdornment.madValueTitle', /** {String} resource string for this.titleString() */
      //titleFraction: 0.4,   /** {Number} fraction-from-top for placement of average=123 text */
      symHeight: 0.6, /** {Number} fractional distance from axis for symbol line  */
      hoverColor: "rgba(0, 173, 255, 0.3)", /** color of line when mouse over cover line */

    });

/**
 * @class  Plots a normal curve over the distribution.
 * For a dot plot view, the curve is based solely on the mean and standard deviation.
 * But for a histogram, the curve is a gaussian fit to the histogram.
 * @extends DG.PlottedSimpleAverageAdornment
 */
DG.PlottedNormalAdornment = DG.PlottedSimpleAverageAdornment.extend(
   /** @scope DG.PlottedNormalAdornment.prototype */
   {
     statisticKey: 'mean', /** {String} key to relevant statistic in this.model.values[i][statisticKey] */
     titleResource: 'DG.PlottedAverageAdornment.meanValueTitle', /** {String} resource string for this.titleString() */
     centerKey: 'mean', /** {String} key to relevant center point in this.model.values[i][centerKey] */
     spreadKey: 'stdev', /** {String} key to relevant spread value in this.model.values[i][width] */
     amplitudeKey: 'amplitude', /** {String} key to relevant amplitude value in this.model.values[i][amplitude] */
     hoverColor: "rgba(0, 125, 52,0.3)", /** color of line when mouse over cover line */
     bgStroke: '#FFb280',
     bgStrokeWidth: 0.5,
     // bgFill: '#FFb280',
     symStroke: '#007D34',
     symStrokeWidth: 1,
     offsetFromEdge: 10,

     /**
      * @returns {false|number} false if gaussian fit is not enabled, otherwise the number of standard errors
      */
     numStdErrors: function () {
       var tPlotModel = this.getPath('model.plotModel'),
           tStdErrorModel = tPlotModel.getAdornmentModel('plottedStErr'),
           tNumStdErrs = tStdErrorModel && tStdErrorModel.get('numberOfStdErrs');
       return DG.get('gaussianFitEnabled')==='yes' && tPlotModel.get('dotsAreFused') &&
              tStdErrorModel && tStdErrorModel.get('isVisible') && tNumStdErrs;
     },

     /**
      * @returns {false|number} false if gaussian fit is not enabled, otherwise the stadard error times the
      * number of standard errors
      */
     stdErrorValue: function (count, sd) {
       var tPlotModel = this.getPath('model.plotModel'),
           tStdErrorModel = tPlotModel.getAdornmentModel('plottedStErr'),
           tNumStdErrs = tStdErrorModel && tStdErrorModel.get('numberOfStdErrs'),
           tStdErrorValue = tNumStdErrs && tNumStdErrs * sd / Math.sqrt(count);
       return DG.get('gaussianFitEnabled')==='yes' && tPlotModel.get('dotsAreFused') &&
              tStdErrorModel && tStdErrorModel.get('isVisible') && tStdErrorValue;
     },

     /**
      * Create the path string for
      *   - the normal curve
      *   - the line from the peak to the axis
      *   - the line segment representing one standard deviation on each side of the mean
      * @param p {x,y,width,cellHeight} of reference point, (.x,.y)
      * @param iIsHorizontal {Boolean} true for horizontal orientation, false for vertical
      * @return {String} The path for the normal curve
      */
     symbolPath: function (p, iIsHorizontal) {

       function normal(x) {
         return DG.MathUtilities.normal(x, tAmplitude, tMu, tSigma);
       }

       function countToScreenCoordFromDotPlot (iCount) {
         var tStackCoord = (2 * tRadius - tOverlap) * iCount + 1;
         return iIsHorizontal ? p.y - tStackCoord : p.x + tStackCoord;
       }

         var sqrtTwoPi = Math.sqrt(2 * Math.PI),
          tParentPlotView = this.get('parentView'),
          tIsHistogram = this.getPath('model.plotModel.dotsAreFused'),
          tNumericAxisView = tParentPlotView.get('primaryAxisView'),
          tCountAxisView = tParentPlotView.get('secondaryAxisView'),
          tCountAxisFunc = tIsHistogram ? tCountAxisView.dataToCoordinate.bind(tCountAxisView)
                                        : countToScreenCoordFromDotPlot,
          tRadius = tParentPlotView.calcPointRadius(),
          tOverlap = tParentPlotView.get('overlap'),
          tBinWidth = tIsHistogram ? tParentPlotView.getPath('model.width')
                      : tParentPlotView.get('binWidthInWorldCoordinates'),
          tPixelMin = tNumericAxisView.get(iIsHorizontal ? 'pixelMin' : 'pixelMax'),
          tPixelMax = tNumericAxisView.get(iIsHorizontal ? 'pixelMax' : 'pixelMin'),
          tPath = '',
          tMeanSegment = '',
          tMeanSegmentPixelLength,
          tSDSegment = '',
          tSDSegmentPixelLength,
          tSESegment = '',
          tSESegmentPixelLength,
          tCount = p.count,
          tMu = p.center,
          tSigma = p.spread,
          tAmplitude = p.amplitude || (1 / (tSigma * sqrtTwoPi) * tCount * tBinWidth),
          tStdErrorValue = this.stdErrorValue( tCount, tSigma),
          tNumeric, tCountValue, tPixelCount,
          tPoints = [],
          kPixelGap = 1,
          tPixelNumeric, tPoint;
       for( tPixelNumeric = tPixelMin; tPixelNumeric <= tPixelMax; tPixelNumeric += kPixelGap) {
         tNumeric = tNumericAxisView.coordinateToData( tPixelNumeric);
         tCountValue = normal( tNumeric);
         if( DG.isFinite( tCountValue)) {
           tPixelCount = tCountAxisFunc( tCountValue);
           tPoint = iIsHorizontal ? {left: tPixelNumeric, top: tPixelCount} : {left: tPixelCount, top: tPixelNumeric};
           tPoints.push( tPoint);
         }
       }
       if( tPoints.length > 0) {
         // Accomplish spline interpolation
         tPath = 'M' + tPoints[0].left + ',' + tPoints[0].top + DG.SvgScene.curveBasis( tPoints);
       }
       tMeanSegmentPixelLength = tCountAxisFunc(normal(tMu)) - tCountAxisFunc(0);
       tMeanSegment = iIsHorizontal ? 'M%@,%@ v%@'.fmt( tNumericAxisView.dataToCoordinate(tMu),
          tCountAxisFunc(0), tMeanSegmentPixelLength) :
          'M%@,%@ h%@'.fmt( tCountAxisFunc(0), tNumericAxisView.dataToCoordinate(tMu),
             tMeanSegmentPixelLength);
       tSDSegmentPixelLength = tNumericAxisView.dataToCoordinate(tMu + tSigma) -
                               tNumericAxisView.dataToCoordinate(tMu - tSigma);
       tSDSegment = iIsHorizontal ? ' M%@,%@ h%@'.fmt( tNumericAxisView.dataToCoordinate(tMu - tSigma),
            tCountAxisFunc(normal(tMu - tSigma)), tSDSegmentPixelLength) :
            ' M%@,%@ v%@'.fmt( tCountAxisFunc(normal(tMu - tSigma)),
               tNumericAxisView.dataToCoordinate(tMu - tSigma), tSDSegmentPixelLength);
        if (tStdErrorValue) {
          tSESegmentPixelLength = tNumericAxisView.dataToCoordinate(tMu + tStdErrorValue) -
                                  tNumericAxisView.dataToCoordinate(tMu - tStdErrorValue);
          tSESegment = iIsHorizontal ? ' M%@,%@ h%@'.fmt( tNumericAxisView.dataToCoordinate(tMu - tStdErrorValue),
                tCountAxisFunc(normal(tMu - tStdErrorValue)), tSESegmentPixelLength) :
                ' M%@,%@ v%@'.fmt( tCountAxisFunc(normal(tMu - tStdErrorValue)),
                   tNumericAxisView.dataToCoordinate(tMu - tStdErrorValue), tSESegmentPixelLength);
        }
       return tPath + tMeanSegment + tSDSegment + tSESegment;
     },

     /**
      * Create the path string for the invisible popup cover region.
      * @param p {x,y,width,cellHeight} of reference point, (.x,.y) is Q1, .width is IQR in pixels.
      * @param iIsHorizontal {Boolean} true for horizontal orientation, false for vertical
      * @return {String} M:move-to absolute: v:vertical-line-to relative: h:horizontal-line-to
      */
     coverPath: function (p, iIsHorizontal) {
       return this.symbolPath(p, iIsHorizontal);
     },

     /**
      * Return a string to be displayed to user to show numeric value with rounding and units
      * @returns {{valueString:string, unitsString:string}}
      * @param count
      * @param stdDev
      * @param numStdErrors
      * @param titleResource
      */
     standardErrorAndUnitsStrings: function (count, stdDev, numStdErrors, titleResource, useSubscript) {
       var tNumStdErrorsString = numStdErrors === 1 ? '' : String(numStdErrors),
           tStdError = stdDev / Math.sqrt(count),
           tUnits = this.getPath('parentView.primaryAxisView.model.firstAttributeUnit'),
           tPrecision = DG.PlotUtilities.findFractionDigitsForAxis(this.getPath('parentView.primaryAxisView')),
           tNumFormat = DG.Format.number().fractionDigits(0, tPrecision).group(''),
           tStdErrorsFormatted = tNumFormat(numStdErrors * tStdError),
           tValueString = useSubscript
              ? titleResource.loc(tNumStdErrorsString, '<sub style="vertical-align: sub">', '</sub>', tStdErrorsFormatted)
              : titleResource.loc(tNumStdErrorsString, '', '', tStdErrorsFormatted);
       return {valueString: tValueString, unitsString: tUnits};
     },

     /**
      * @return {String} title string to show when hovering over curve
      */
     titleString: function (mean, valueObject) {
       var kGaussianFitEnabled = DG.get('gaussianFitEnabled')==='yes',
          tIsHistogram = this.getPath('model.plotModel.dotsAreFused'),
          tShowMeasureLabels = this.get('showMeasureLabels'),
          tPrefix = kGaussianFitEnabled && tIsHistogram ? "DG.Inspector.graphPlottedGaussianFit".loc() : "",
          tStdev = typeof valueObject === 'object' ? valueObject.stdev : valueObject,
          tMeanValueAndUnits = this.valueAndUnitsStrings(mean, this.titleResource),
          tStdevValueAndUnits = this.valueAndUnitsStrings(tStdev,
              'DG.PlottedAverageAdornment.stDevValueTitle'),
          tStdErrValue = this.stdErrorValue(valueObject.count, valueObject.stdev);
      var tStdErrValueAndUnits = tStdErrValue
                                 ? this.standardErrorAndUnitsStrings(valueObject.count, valueObject.stdev,
                                    this.numStdErrors(), 'DG.PlottedAverageAdornment.stErrValueTitle',
                                    tShowMeasureLabels)
                                 : { valueString: '', unitsString: ''};
       if (!tMeanValueAndUnits.valueString)
         return '';
       if (tShowMeasureLabels) {
         tPrefix = '<p style="text-decoration-line: underline">' + tPrefix + '</p>';
         var tHTML = '<div style = "color:%@;">%@</div>',
            tUnitsSpan = '<span style = "color:grey;">%@</span>'.loc(tMeanValueAndUnits.unitsString),
            tMeanHtmlString = '<p>%@ %@</p>'.loc(tMeanValueAndUnits.valueString, tUnitsSpan),
            tSDHtmlString = '<p>%@ %@</p>'.loc(tStdevValueAndUnits.valueString, tUnitsSpan),
            tStdErrHtmlString = tStdErrValue
                                ? ('<p>%@ %@</p>'.loc(tStdErrValueAndUnits.valueString, tUnitsSpan))
                                : '';
         return tHTML.loc(this.symStroke, tPrefix + tMeanHtmlString + tSDHtmlString + tStdErrHtmlString, tUnitsSpan);
       } else {
         if (kGaussianFitEnabled)
            tPrefix = tPrefix + ': ';
         return tPrefix + tMeanValueAndUnits.valueString + ' ' + tMeanValueAndUnits.unitsString + ', ' +
                tStdevValueAndUnits.valueString + ' ' + tStdevValueAndUnits.unitsString +
                (tStdErrValue ? ', ' + tStdErrValueAndUnits.valueString + ' ' +
                tStdErrValueAndUnits.unitsString : '');
       }
     },

     /**
      * Get the desired axis position of the pop-up text, in the attribute's coordinates.
      * @param iCenterValue
      * @param iSpreadValue
      */
     getTextPositionOnAxis: function (iCenterValue, iSpreadValue) {
       return iCenterValue + iSpreadValue; // text going to the right of the bar
     }
   });



/* >>>>>>>>>> BEGIN source/components/graph/adornments/plotted_average_model.js */
// ==========================================================================
//                            DG.PlottedAverageModel
// 
//  Model for averages displayed as symbols in a dot plot.
//  The primary axis should be numeric, and the secondary axis one or
//  more cells (one mean per cell).
//  
//  Author:   Craig D. Miller
//
//  Copyright ©2013 Scientific Reasoning Research Institute,
//                  University of Massachusetts Amherst
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/adornments/plot_adornment_model');

/**
 * @class  The model for a plotted average (mean or median).
 * @extends SC.Object
*/
DG.PlottedAverageModel = DG.PlotAdornmentModel.extend(
/** @scope DG.PlottedAverageModel.prototype */
{
  _values: null,       // [{ mean|median }], one element per cell on secondary axis

  values: function( iKey, iValue) {
    if( iValue) {
      this._values = iValue;
    }
    if( !this._values) {
      this.recomputeValue();
    }
    return this._values;
  }.property(),

  enableMeasuresForSelection: false,
  precision: 0,       // decimal precision of attribute being averaged

});

/**
 * @class  The model for a plotted average (mean or median).
 * @extends SC.Object
*/
DG.PlottedSimpleAverageModel = DG.PlottedAverageModel.extend(
/** @scope DG.PlottedAverageModel.prototype */
{
  /**
   * Coordinates of the center of the equation rectangle as a proportion of the plot frame
   * @property {{proportionCenterX: {Number}, proportionCenterY: {Number}}[]}
   */
  equationCoordsArray: null,
  
  init: function() {
    arguments.callee.base.apply(this,arguments);
    this.equationCoordsArray = [];
  },

  createStorage: function() {
    var tStorage = arguments.callee.base.apply(this,arguments);
    DG.ObjectMap.copy( tStorage, {
      equationCoordsArray: this.get('equationCoordsArray')
    });
    return tStorage;
  },

  /**
   * @param { Object } with properties specific to a given subclass
   */
  restoreStorage: function( iStorage) {
    arguments.callee.base.apply(this,arguments);
    if( iStorage) {
      if( iStorage.equationCoordsArray)
        this.set('equationCoordsArray', iStorage.equationCoordsArray);
    }
  }
  
});



    DG.PlottedMeanStDevModel = DG.PlottedSimpleAverageModel.extend(
/** @scope DG.PlottedMeanStDevModel.prototype */
{
  /**
   * Compute or re-compute the sums, counts, and means of each cell.
   * returns null or an array of values, one for each cell
   */
  computeSumCountMeanStdDev: function(includeMAD) {

    var tCases = this.get('cases'),
        tNumericVarID = this.getPath( 'plotModel.primaryVarID'),
        tNumericAxisModel = this.getPath('plotModel.primaryAxisModel'),
        tCategoricalVarID = this.getPath( 'plotModel.secondaryVarID'),
        tCategoricalAxisModel = this.getPath('plotModel.secondaryAxisModel');
    if( !( tCategoricalAxisModel && tNumericAxisModel )) {
      return null; // too early to recompute, caller must try again later.
    }

    var tNumCells = tCategoricalAxisModel.get('numberOfCells');
    var tValues = []; // new values to compute and save
    var i,j;

    // initialize the values
    for( i=0, j=tNumCells; i<j; ++i ) {
      tValues.push({ sum:0, sumOfSquares:0, count:0, mean:undefined, stdev:undefined, sterr:undefined, numericValues: [] });
    }

    // compute count and sum of cases in each cell, excluding missing values
    // take care to handle null VarIDs and null case values correctly
    tCases.forEach( function( iCase, iIndex ) {
      var tNumericValue = iCase.getNumValue( tNumericVarID),
          tCellValue = iCase.getStrValue( tCategoricalVarID),
          tCellNumber = tCategoricalAxisModel.cellNameToCellNumber( tCellValue);
      if( tCellNumber!=null && DG.MathUtilities.isInIntegerRange( tCellNumber, 0, tValues.length )) { // if Cell Number not missing
        var iValue = tValues[tCellNumber];
        if( isFinite( tNumericValue )) { // if numeric value not missing
          iValue.sum += tNumericValue;
          iValue.sumOfSquares +=( tNumericValue * tNumericValue );
          iValue.count += 1;
          if( includeMAD) {
            iValue.numericValues.push( tNumericValue);
          }
          //iValue.cellValue = tCellValue;
        }
      }
    });

    // compute mean of cases in each cell
    tValues.forEach( function( iValue ) { // TO-DO remove this.
      if( iValue.count > 0 ) {
        iValue.mean = iValue.sum / iValue.count;
        iValue.stdev = Math.sqrt(( iValue.sumOfSquares -
                                   ( iValue.mean * iValue.mean ) * iValue.count) /
                                 (iValue.count - 1));
        if( includeMAD) {
          iValue.mad = iValue.numericValues.reduce( function( iMad, iNumValue) {
            return iMad + Math.abs( iValue.mean - iNumValue);
          }, 0) / iValue.count;
          delete iValue.numericValues;
        }
      }
    });

    return tValues;
  }
});

DG.PlottedMeanModel = DG.PlottedMeanStDevModel.extend(
/** @scope DG.PlottedMeanModel.prototype */
{
  /**
   * Compute or re-compute the mean(s).
   */
  recomputeValue: function() {
    var tValues = this.computeSumCountMeanStdDev();

    if( tValues ) {
      var tNumericAxisModel = this.getPath('plotModel.primaryAxisModel');
      this.set( 'precision', tNumericAxisModel.getPath('attributeDescription.attribute.precision'));
      this.set( 'values', tValues ); // we expect view to observe this change
      this._needsComputing = false;
    }
  }
});
DG.PlotAdornmentModel.registry.plottedMean = DG.PlottedMeanModel;

DG.PlottedStDevModel = DG.PlottedMeanStDevModel.extend(
/** @scope DG.PlottedStDevModel.prototype */
{
  /**
   * Compute or re-compute the standard deviation(s).
   */
  recomputeValue: function() {
    var tValues = this.computeSumCountMeanStdDev();
    if( !tValues)
      return;

    // compute st.dev. of cases in each cell
    tValues.forEach( function( iValue ) {
      if( iValue.count > 1 ) {
        iValue.centerMinus1Dev = iValue.mean - iValue.stdev;
      }
    });
    var tNumericAxisModel = this.getPath('plotModel.primaryAxisModel');
    this.set( 'precision', tNumericAxisModel.getPath('attributeDescription.attribute.precision'));
    this.set( 'values', tValues ); // we expect view to observe this change
    this._needsComputing = false;
  }
});
DG.PlotAdornmentModel.registry.plottedStDev = DG.PlottedStDevModel;

DG.PlottedStErrModel = DG.PlottedMeanStDevModel.extend(
/** @scope DG.PlottedStErrModel.prototype */
{
  numberOfStdErrs: 1,

  /**
   * Compute or re-compute the standard deviation(s).
   */
  recomputeValue: function() {
    var tValues = this.computeSumCountMeanStdDev();
    if( !tValues)
      return;

    // compute st.dev. of cases in each cell
    tValues.forEach( function( iValue ) {
      if( iValue.count > 1 ) {
        iValue.sterr = iValue.stdev / Math.sqrt( iValue.count );
        iValue.centerMinus1Dev = iValue.mean - iValue.sterr;
      }
    });
    var tNumericAxisModel = this.getPath('plotModel.primaryAxisModel');
    this.set( 'precision', tNumericAxisModel.getPath('attributeDescription.attribute.precision'));
    this.set( 'values', tValues ); // we expect view to observe this change
    this._needsComputing = false;
  },

  /**
   * @return { Object }
   */
  createStorage: function () {
    var storage = arguments.callee.base.apply(this,arguments);

    storage.numberOfStdErrs = this.get('numberOfStdErrs');

    return storage;
  },

  /**
   * @param { Object }
   */
  restoreStorage: function (iStorage) {
    arguments.callee.base.apply(this,arguments);
    this.set('numberOfStdErrs', iStorage.numberOfStdErrs || 1);
  }

});
DG.PlotAdornmentModel.registry.plottedStErr = DG.PlottedStErrModel;

DG.PlottedNormalModel = DG.PlottedMeanStDevModel.extend(
   /** @scope DG.PlottedNormalModel.prototype */
   {
     addGaussianFitToValues: function(iValue) {
       var sqrtTwoPi = Math.sqrt(2 * Math.PI),
         tPlotModel = this.get('plotModel'),
         tBarWidth = tPlotModel.get('width'),
         tBars = tPlotModel.get('bars'),
         tPointsToFit = tBars.map( function( iBar) {
            return { x: iBar.lowerEdgeWorld + tBarWidth/2, y: iBar.count };
          }),
          tMean = iValue.mean,
          tSigma = iValue.stdev,
          tCount = iValue.count,
          tAmp = (1 / (tSigma * sqrtTwoPi)) * tCount * tBarWidth,
          tFittedParameters = DG.MathUtilities.fitGaussianGradientDescent( tPointsToFit, tAmp, tMean, tSigma);
       iValue.mean = tFittedParameters.mu;
       iValue.stdev = tFittedParameters.sigma;
       iValue.amplitude = tAmp;
     },

     /**
      * Compute or re-compute the mean(s) and stdDev(s).
      * When we are plotting on a dot plot, we compute mean and stdDev from the data in each cell.
      * But when we are plotting on a histogram, we first find the counts for each bin and then do a
      * least squares fit to the normal distribution to find the mean and stdDev to use for drawing
      * the normal curve. (Note that this "gaussian fit" produces a different mean and stdDev than
      * the mean and stdDev of the data.)
      */
     recomputeValue: function() {
       var kGaussianFitEnabled = DG.get('gaussianFitEnabled')==='yes',
          tPlotModel = this.get('plotModel'),
          tValues = this.computeSumCountMeanStdDev();
          if(tValues && tPlotModel.get('dotsAreFused') && kGaussianFitEnabled) {
            this.addGaussianFitToValues(tValues[0]);
          }

       if( tValues ) {
         this.set( 'values', tValues ); // we expect view to observe this change
         this._needsComputing = false;
       }
     }
   });
DG.PlotAdornmentModel.registry.plottedNormal = DG.PlottedNormalModel;

DG.PlottedMadModel = DG.PlottedMeanStDevModel.extend(
    /** @scope DG.PlottedMadModel.prototype */
    {
      /**
       * Compute or re-compute the mean(s).
       */
      recomputeValue: function() {
        var tValues = this.computeSumCountMeanStdDev( true /* include MAD */);
        if( !tValues)
          return;

        tValues.forEach( function( iValue ) {
          iValue.centerMinus1Dev = iValue.mean - iValue.mad;
        });
        var tNumericAxisModel = this.getPath('plotModel.primaryAxisModel');
        this.set( 'precision', tNumericAxisModel.getPath('attributeDescription.attribute.precision'));
        this.set( 'values', tValues ); // we expect view to observe this change
        this._needsComputing = false;
      }
    });
DG.PlotAdornmentModel.registry.plottedMad = DG.PlottedMadModel;

DG.PlottedQuantileModel = DG.PlottedSimpleAverageModel.extend(
/** @scope DG.PlottedMedianModel.prototype */
{
  /**
   * Compute quantile(s) for cases in each cell.
   * Note: array of '.vals' is sorted ascending, which helps make further quantile computations more efficient.
   * returns null or an array of values, one for each cell.
   */
  collectCellValsAndMedian: function() {

    var tCases = this.get('cases'),
        tNumericVarID = this.getPath( 'plotModel.primaryVarID'),
        tCategoricalVarID = this.getPath( 'plotModel.secondaryVarID'),
        tCategoricalAxisModel = this.getPath('plotModel.secondaryAxisModel');
    if( ! tCategoricalAxisModel ) {
      //DG.log("DG.PlottedMedianModel.recomputeValue() ignored, no plotModel.secondaryAxisModel yet");
      return; // too early to recompute, caller must try again later.
    }
    var tNumCells = tCategoricalAxisModel.get('numberOfCells'),
        tValues = [], // new values to compute and save
        i,j;

    // initialize the values
    for( i=0, j=tNumCells; i<j; ++i ) {
      tValues.push({ vals: [], cases: [], median: undefined });
    }

    // collect array of numeric cases in each cell, excluding missing/non-numeric/non-finite values
    // take care to handle null VarIDs and null case values correctly
    tCases.forEach( function( iCase, iIndex ) {
      var tNumericValue = iCase.getNumValue( tNumericVarID),
          tCellValue = iCase.getStrValue( tCategoricalVarID),
          tCellNumber = tCategoricalAxisModel.cellNameToCellNumber( tCellValue);
      if( tCellNumber!= null && DG.MathUtilities.isInIntegerRange( tCellNumber, 0, tValues.length )) { // if Cell Number not missing
        var iValue = tValues[tCellNumber];
        if( isFinite( tNumericValue )) { // if numeric value not missing
          iValue.vals.push( tNumericValue );
          iValue.cases.push( iCase);
        }
      }
    });

    // compute median of cases in each cell
    tValues.forEach( function( iValue ) {
      if( iValue.vals.length > 0 ) { // TO_DO remove this.
        iValue.median = DG.MathUtilities.medianOfNumericArray( iValue.vals ); // also sorts .vals array
      }
    });
    return tValues;
  }
});

DG.PlottedMedianModel = DG.PlottedQuantileModel.extend(
/** @scope DG.PlottedMedianModel.prototype */
{
  /**
   * Compute or re-compute the median(s).
   */
  recomputeValue: function() {
    var tValues = this.collectCellValsAndMedian();

    if( tValues) {
      this.set('values', tValues); // we expect view to observe this change
      this._needsComputing = false;
      //DG.log("DG.PlottedMedianModel.recomputeValue() done");
    }
  }
});
DG.PlotAdornmentModel.registry.plottedMedian = DG.PlottedMedianModel;

DG.PlottedIQRModel = DG.PlottedQuantileModel.extend(
/** @scope DG.PlottedMedianModel.prototype */
{
  /**
   * Compute or re-compute the Median, Q1, Q3, IQR for each cell.
   */
  recomputeValue: function() {
    var tValues = this.collectCellValsAndMedian();
    if( !tValues)
      return;

    // also compute IQR
    tValues.forEach( function( iValue ) {
      if( iValue.vals.length > 0 ) {
        iValue.Q1 = DG.MathUtilities.quantileOfSortedArray( iValue.vals, 0.25 );
        iValue.Q3 = DG.MathUtilities.quantileOfSortedArray( iValue.vals, 0.75 );
        iValue.IQR = (iValue.Q3 - iValue.Q1);
      }
    });

    this.set( 'values', tValues ); // we expect view to observe this change
    this._needsComputing = false;
    //DG.log("DG.PlottedIQRModel.recomputeValue() done");
  }
});
DG.PlotAdornmentModel.registry.plottedIQR = DG.PlottedIQRModel;

DG.PlottedBoxPlotModel = DG.PlottedIQRModel.extend(
/** @scope DG.PlottedBoxPlotModel.prototype */
{
  showOutliers: false,  // If true, then we draw a "modified" boxplot
  showICI: false,  // If true, then we draw an informal confidence interval

  /**
   * Compute or re-compute the Median, Q1, Q3, lowerWhisker, upperWhisker for each cell.
   * My base class will have computed everything except the lower and upper whisker.
   *    A whisker extends at most 1.5 times the IQR beyond the appropriate percentile, but
   *    stops at the closest value that doesn't exceed it.
   */
  recomputeValue: function() {
    this.beginPropertyChanges();  // Postpone notification until after we compute whisker ends

    arguments.callee.base.apply(this,arguments);

    var tValues = this.get('values'),
        tShowOutliers = this.get('showOutliers'),
        tShowICI = this.get('showICI');
    if( tValues) {

      tValues.forEach(function (iValue) {
        iValue.upperOutliers = [];
        iValue.lowerOutliers = [];
        if (iValue.vals.length > 0) {
          if( tShowOutliers) {
            var tMaxWhiskerLength = 1.5 * iValue.IQR,
                tWhiskerCandidate, tIndex;
            tWhiskerCandidate = iValue.Q1 - tMaxWhiskerLength;
            tIndex = 0;
            while (iValue.vals[tIndex] < tWhiskerCandidate) {
              iValue.lowerOutliers.push(iValue.vals[tIndex]);
              tIndex++;
            }
            iValue.lowerWhisker = iValue.vals[tIndex];

            tWhiskerCandidate = iValue.Q3 + tMaxWhiskerLength;
            tIndex = iValue.vals.length - 1;
            while (iValue.vals[tIndex] > tWhiskerCandidate) {
              iValue.upperOutliers.push(iValue.vals[tIndex]);
              tIndex--;
            }
            iValue.upperWhisker = iValue.vals[tIndex];
          }
          else {
            iValue.lowerWhisker = iValue.vals[0];
            iValue.upperWhisker = iValue.vals[iValue.vals.length - 1];
          }
          iValue.ICI = tShowICI ? iValue.IQR / Math.sqrt(iValue.vals.length) : undefined;
        }
      });
    }

    this.endPropertyChanges();
  },
  /**
   Returns an object which contains properties that should be written
   out with the document for archiving purposes.
   */
  createStorage: function() {
    var tStorage = arguments.callee.base.apply(this,arguments);
    tStorage.showOutliers = this.get('showOutliers') || false;
    tStorage.showICI = this.get('showICI') || false;
    return tStorage;
  },

  /**
   Set the contents of the adornment model from the restored storage.
   */
  restoreStorage: function( iStorage) {
    arguments.callee.base.apply(this,arguments);
    if( iStorage) {
      this.set('showOutliers', iStorage.showOutliers || false);
      this.set('showICI', iStorage.showICI || false);
    }
  }

});
DG.PlotAdornmentModel.registry.plottedBoxPlot = DG.PlottedBoxPlotModel;

/* >>>>>>>>>> BEGIN source/components/graph/adornments/plotted_box_plot_adornment.js */
// ==========================================================================
//                   DG.PlottedBoxPlotAdornment
//
//  Averages displayed as symbols in a dot plot.
//
//  Author:   William Finzer
//
//  Copyright (c) 2016 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/adornments/plotted_average_adornment');

DG.PlottedBoxPlotLogString = '';  // global to avoid duplicate log strings.

/**
 * @class  Plots a box plot showing whiskers, Q1, Q3, and median.
 * @extends DG.PlottedAverageAdornment
 */
DG.PlottedBoxPlotAdornment = DG.PlottedAverageAdornment.extend(
    /** @scope DG.PlottedBoxPlotAdornment.prototype */
    (function () {

      var BoxPlotSymbol = SC.Object.extend({
        boxSymbol: null,
        lowerWhiskerCover: null,
        Q1Cover: null,
        lowerRect: null,
        medianCover: null,
        upperRect: null,
        Q3Cover: null,
        upperWhiskerCover: null,
        outliers: null,
        outlierCovers: null,
        ici: null,
        iciCover: null,
        iciHoverElement: null,

        init: function () {
          arguments.callee.base.apply(this,arguments);
          this.outliers = [];
          this.outlierCovers = [];
        },

        /**
         *
         * @param iDest {[] || DG.RaphaelLayer }
         */
        pushElements: function (iDest) {
          DG.ObjectMap.forEach(this, function (iKey, iValue) {
            if (iValue.paper) // Test for it being a Raphael Element
              iDest.push(iValue);
          });
          this.outliers.forEach(function (iElement) {
            iDest.push(iElement);
          });
          this.outlierCovers.forEach(function (iElement) {
            iDest.push(iElement);
          });
          this.ici && iDest.push(this.ici);
          this.iciCover && iDest.push(this.iciCover);
          this.iciHoverElement && iDest.push(this.iciHoverElement);
        },

        removeFromArrayAndLayer: function (iArray, iLayer) {

          function removeElement( iElement) {
            if( iElement) {
              iLayer.prepareToMoveOrRemove(iElement);
              iElement.remove();
              iArray.splice(iArray.indexOf(iElement), 1);
            }
          }

          DG.ObjectMap.forEach(this, function (iKey, iValue) {
            if (iValue.paper) // Test for it being a Raphael Element
            {
              removeElement(iValue);
            }
          });
          this.outliers.forEach(function (iElement) {
            removeElement(iElement);
          });
          this.outlierCovers.forEach(function (iElement) {
            removeElement(iElement);
          });
          removeElement( this.ici);
          removeElement( this.iciCover);
          removeElement( this.iciHoverElement);
        }
      });

      return {
        hoverColor: "rgba(255, 48, 0, 0.3)", /** color of line when mouse over cover line */
        bgStroke: '#FFb280',
        bgStrokeWidth: 0.5,
        bgFill: '#FFb280',
        symStroke: '#F30',
        symStrokeWidth: 1,
        iciStroke: '#30F',
        iciStrokeWidth: 2,
        iciHoverElementStrokeWidth: 1,

        modelPropertiesToObserve: [ ['showOutliers', 'updateVisibility'] ],

        /**
         * @property {[BoxPlotSymbol]}
         */
        boxPlotSymbols: null,

        init: function () {
          arguments.callee.base.apply(this,arguments);
          this.boxPlotSymbols = [];
        },

        _infoTip: null,
        infoTip: function () {
          if (!this._infoTip) {
            var this_ = this;
            this._infoTip = DG.InfoTip.create({
              paperSource: function () {
                return this_.get('paperSource');
              }.property(),
            });
          }
          return this._infoTip;
        }.property(),

        /**
         * Recompute our model if needed, then move symbols to location specified by model.
         * @param iAnimate {Boolean} [optional] if true then animate to new symbol location.
         */
        updateToModel: function( iAnimate ) {
          // We can get here indirectly in which case iAnimate is an object we should ignore
          if (iAnimate !== true)
            iAnimate = false;
          var tModel = this.get('model');

          if( tModel && tModel.get('isVisible')) {
            tModel.recomputeValueIfNeeded();
            this.updateSymbols( iAnimate );
          }
        },

        /**
         * Show or hide the text element "average = 123.456"
         * Using DG.LineLabelMixin to position.
         * @param iShow {Boolean} Show or hide this text element?
         * @param iDisplayValue {Number} Value along numeric axis, for text display
         * @param iAxisValue {Number} Value along numeric axis, for positioning
         * @param iFractionFromTop {Number} used to position text on cross-axis
         * @param iElementID {Number} Rafael element id of the text, so we can find and update it on the fly.
         * @param iValue {Object} Has the statistics for the current cell
         */
        updateTextElement: function( iShow, iDisplayValue, iAxisValue, iFractionFromTop, iValue, iElementID ) {
          DG.assert( this.textElement );
          if( iShow && DG.isFinite( iDisplayValue ) ) {
            // set up parameters used by DG.LineLabelMixin.updateTextToModel()
            this.value = iAxisValue; // for St.Dev., iAxisValue not equal to iDisplayValue
            this.valueAxisView = this.getPath('parentView.primaryAxisView');
            this.valueString = this.titleString( iDisplayValue, iValue );
            this.updateTextToModel( iFractionFromTop );
            this.textElement.show();
            this.backgrndRect.show();
            this.textShowingForID = iElementID;
          } else {
            // hide until next time
            //this.value = 0;
            this.valueString = '';
            this.valueAxisView = null;
            this.textElement.hide();
            this.backgrndRect.hide();
            this.textShowingForID = undefined;
          }
        },

        /**
         * Create a user log of the the hover over the average line, but remove duplicates
         * @param logString
         */
        updateHoverLog: function( logString ) {
          if( logString !== DG.PlottedBoxPlotLogString ) { // not 2 of the same log strings in a row
            DG.PlottedBoxPlotLogString = logString;        // save for next comparison
            DG.logUser("%@: %@", "hoverOverGraphLine", DG.PlottedBoxPlotLogString );
          }
        },

        /**
         * Create or update our myElements array of average symbols.
         * @param iAnimate {Boolean} [optional] if true then animate showing/hiding of box plot.
         */
        updateSymbols: function (iAnimate) {
          // We can get here indirectly in which case iAnimate is an object we should ignore
          if (iAnimate && iAnimate !== true)
            iAnimate = false;
          var this_ = this,
              kAnimationTime = DG.PlotUtilities.kDefaultAnimationTime,
              tLayer = this.get('layer'),
              tPrimaryAxisView = this.getPath('parentView.primaryAxisView'),
              tSecondaryAxisView = this.getPath('parentView.secondaryAxisView'),
              tIsHorizontal = tPrimaryAxisView && (tPrimaryAxisView.get('orientation') === DG.GraphTypes.EOrientation.kHorizontal),
              tValuesArray = this.getPath('model.values'),
              tNumValues = tValuesArray && tValuesArray.length,
              tPaper = this.get('paper');
          if (!tSecondaryAxisView || !tNumValues || !tPaper)
            return; // Happens during transition after secondary attribute removed but before new axis created
          var formatValue = function( iValue) {
            var tDigits = DG.PlotUtilities.findFractionDigitsForAxis(tPrimaryAxisView),
               tNumFormat = DG.Format.number().fractionDigits(0, tDigits);
               tNumFormat.group(''); // Don't separate with commas
               return tNumFormat(iValue);
             };

          var tFullHeight = tSecondaryAxisView.get('fullWidth'),
              tCellHeight = (tNumValues ? tSecondaryAxisView.get('fullCellWidth') : 0),
              tSpec = {x: 0, y: 0, symSize: this.symSize, cellHeight: tCellHeight - this.cellGap,
                              fullHeight: tFullHeight},
              tOffScreen = -3 * this.symSize, // negative view coordinate to move off-screen to hide
              tBoxWidth = Math.min(tCellHeight / 3, DG.PlotUtilities.kBoxplotMaxWidth);

          function overScope() {
            var tAttributes = {stroke: this_.hoverColor};
            this.stop();
            this.animate(tAttributes, this_.hoverDelay, '<>');
            var tBBox = this.getBBox();
            this_.get('infoTip').show({
              x: tBBox.x, y: tBBox.y - 2,
              tipString: this.info.tipString, tipValue: formatValue(this.info.tipValue)
            });
            if( this.info.tipString.indexOf('ICI') >= 0) {  // ICI has a special hover element
              var tICIHover = this_.boxPlotSymbols[this.index].iciHoverElement;
              tICIHover.stop();
              tICIHover.animate({ 'stroke-opacity': 1 }, this_.hoverDelay, '<>');
            }
          }

          function outScope() {
            var tAttributes = {stroke: DG.RenderingUtilities.kTransparent};
            this.stop();
            this.animate(tAttributes, DG.PlotUtilities.kHighlightHideTime, '<>');
            this_.get('infoTip').hide();
            if( this.info.tipString.indexOf('ICI') >= 0) {  // ICI has a special hover element
              var tICIHover = this_.boxPlotSymbols[this.index].iciHoverElement;
              tICIHover.stop();
              tICIHover.animate({ 'stroke-opacity': 0 }, DG.PlotUtilities.kHighlightHideTime, '<>');
            }
          }

          function select() {
            var tNumericVarID = this_.getPath('model.plotModel.primaryVarID'),
                tLower = this.info.range.lower,
                tUpper = this.info.range.upper,
                tCases = this.info.range.cases,
                tSelection = [],
                tChange = {
                  operation: 'selectCases',
                  collection: this_.getPath('model.plotModel.collectionClient'),
                  cases: tSelection,
                  select: true,
                  extend: false
                };
            tCases.forEach(function (iCase) {
              var tValue = iCase.getForcedNumericValue(tNumericVarID);
              if (tValue >= tLower && tValue <= tUpper)
                tSelection.push(iCase);
            });
            this_.getPath('model.plotModel.dataContext').applyChange(tChange);
          }

          /**
           * A boxplot consists of
           *  - the outline of the plot
           *  - a rectangle for each quartile inside the box with a pointer hover cursor and a mousedown action
           *  - a cover segment for each whisker with pointer hover cursor and showing endpoint values, mousedown selects
           *  - a cover segment for the median with pointer hover cursor and showing median value
           *  - a cover segment for Q1 and Q3 with pointer hover cursor and showing appropriate values
           * @type {function(this:DG.PlottedBoxPlotAdornment)}
           */
          var updateOneBoxPlot = function (iIndex) {

            /**
             * Create the path string for the box plot. It is centered in the cell and 1/3 of the cellHeight in width
             * @param p {x,y,width,lowerWhisker,upperWhisker,cellHeight} of reference point, (.x,.y) is Q1,
             *        the two whiskers are lengths in pixels .width is IQR in pixels.
             * @return {String} M:move-to absolute: v:vertical-line-to relative: h:horizontal-line-to
             */
            var getSymbolPath = function () {
              return tIsHorizontal ?
                    // Start at the lower whisker, line to Q1. Draw the box. Draw the median line. Draw the upper whisker.
                    'M%@,%@ h%@ M%@,%@ v%@ h%@ v%@ h%@ z M%@,%@ v%@ M%@,%@ h%@'.fmt(
                        tSpec.Q1 - tSpec.lowerWhisker, tYCenter, tSpec.lowerWhisker,
                        tSpec.Q1, tYCenter,
                        -tBoxWidth / 2, tSpec.width, tBoxWidth, -tSpec.width,
                        tSpec.x, tYCenter - tBoxWidth / 2, tBoxWidth,
                        tSpec.Q1 + tSpec.width, tYCenter, tSpec.upperWhisker) :
                    'M%@,%@ v%@ M%@,%@ h%@ v%@ h%@ v%@ z M%@,%@ h%@ M%@,%@ v%@'.fmt(
                        tXCenter, tSpec.Q1 - tSpec.lowerWhisker, tSpec.lowerWhisker,
                        tXCenter, tSpec.Q1,
                        -tBoxWidth / 2, -tSpec.width, tBoxWidth, tSpec.width,
                        tXCenter - tBoxWidth / 2, tSpec.y, tBoxWidth,
                        tXCenter, tSpec.Q1 - tSpec.width, tSpec.upperWhisker);
                },

                getLowerRect = function () {
                  return tIsHorizontal ?
                      {
                        x: tSpec.Q1, y: tSpec.y - tSpec.cellHeight / 2 - tBoxWidth / 2,
                        width: tSpec.x - tSpec.Q1, height: tBoxWidth
                      } :
                      {
                        x: tSpec.x + tSpec.cellHeight / 2 - tBoxWidth / 2, y: tSpec.y,
                        width: tBoxWidth, height: tSpec.Q1 - tSpec.y
                      };
                },

                getUpperRect = function () {
                  return tIsHorizontal ?
                      {
                        x: tSpec.x, y: tSpec.y - tSpec.cellHeight / 2 - tBoxWidth / 2,
                        width: tSpec.Q3 - tSpec.x, height: tBoxWidth
                      } :
                      {
                        x: tSpec.x + tSpec.cellHeight / 2 - tBoxWidth / 2, y: tSpec.Q3,
                        width: tBoxWidth, height: tSpec.y - tSpec.Q3
                      };
                },

                getLowerWhisker = function () {
                  return tIsHorizontal ?
                    'M%@,%@ h%@'.fmt( tSpec.Q1 - tSpec.lowerWhisker, tYCenter, tSpec.lowerWhisker) :
                    'M%@,%@ v%@'.fmt( tXCenter, tSpec.Q1 - tSpec.lowerWhisker, tSpec.lowerWhisker);
                },

                getUpperWhisker = function () {
                  return tIsHorizontal ?
                    // Start at Q3, line to upperWhisker.
                    'M%@,%@ h%@'.fmt( tSpec.Q3, tYCenter, tSpec.upperWhisker) :
                    'M%@,%@ v%@'.fmt( tXCenter, tSpec.Q3, tSpec.upperWhisker);
                },

                getIci = function () {
                 return tIsHorizontal ?
                        'M%@,%@ h%@'.fmt( tSpec.iciLower, tYCenter, tSpec.iciUpper - tSpec.iciLower) :
                        'M%@,%@ v%@'.fmt( tXCenter, tSpec.iciLower, tSpec.iciUpper - tSpec.iciLower);
               },

                getIciHoverPath = function () {
                 return tIsHorizontal ?
                        'M%@,%@ v%@ M%@,%@ v%@'
                           .fmt( tSpec.iciLower, 0, tSpec.fullHeight,
                              tSpec.iciUpper, 0, tSpec.fullHeight) :
                        'M%@,%@ h%@ M%@,%@ h%@'
                           .fmt( 0, tSpec.iciLower, tSpec.fullHeight,
                              0, tSpec.iciUpper, tSpec.fullHeight);
               },

                getCrossCover = function (iHKey, iVKey) {
                  return tIsHorizontal ?
                    // Move to the position for horizontal drawing and then make a line across the boxplot width
                    'M%@,%@ v%@'.fmt( tSpec[iHKey], tYCenter - tBoxWidth / 2, tBoxWidth) :
                    'M%@,%@ h%@'.fmt( tXCenter - tBoxWidth / 2, tSpec[iVKey], tBoxWidth);
                },

                outlierSymbol = function (iIndex) {
                  var tD = tBoxWidth / 3,
                      tCoord = tSpec.outliers[ iIndex],
                      tX = tIsHorizontal ? tCoord : tXCenter,
                      tY = tIsHorizontal ? tYCenter: tCoord;
                  return 'M%@,%@ h%@ M%@,%@ v%@'.fmt(
                      tX - tD / 2, tY, tD, tX, tY - tD / 2, tD);
                },

                createBoxPlotSymbol = function() {
                  var tSymbol = BoxPlotSymbol.create();
                  this.boxPlotSymbols.push(tSymbol);
                  tSymbol.boxSymbol = tPaper.path('M0,0')
                      .attr({stroke: this.symStroke, 'stroke-width': this.symStrokeWidth, 'stroke-opacity': 0});
                  tSymbol.lowerRect = tPaper.rect(0, 0, 0, 0)
                      .attr({
                        stroke: this.bgStroke,
                        'stroke-width': this.bgStrokeWidth,
                        fill: this.bgFill,
                        'fill-opacity': 0.5,
                        cursor: "pointer"
                      })
                      .mousedown(select);
                  tSymbol.upperRect = tSymbol.lowerRect.clone()
                      .mousedown(select);
                  tSymbol.lowerWhiskerCover = tPaper.path('M0,0')
                      .attr({
                        'stroke-width': this.hoverWidth, stroke: DG.RenderingUtilities.kTransparent,
                        cursor: "pointer"
                      })
                      .hover(overScope, outScope)
                      .mousedown(select);
                  tSymbol.upperWhiskerCover = tSymbol.lowerWhiskerCover.clone()
                      .hover(overScope, outScope)
                      .mousedown(select);
                  tSymbol.medianCover = tSymbol.lowerWhiskerCover.clone()
                      .hover(overScope, outScope);
                  tSymbol.Q1Cover = tSymbol.lowerWhiskerCover.clone()
                      .hover(overScope, outScope);
                  tSymbol.Q3Cover = tSymbol.lowerWhiskerCover.clone()
                      .hover(overScope, outScope);
                  tSymbol.ici = tPaper.path(getIci())
                     .attr({stroke: this.iciStroke, 'stroke-width': this.iciStrokeWidth, 'stroke-opacity': 0});
                  tSymbol.iciCover = tPaper.path(getIci())
                     .attr({'stroke-width': this.hoverWidth, stroke: DG.RenderingUtilities.kTransparent,})
                     .hover(overScope, outScope);
                  tSymbol.iciCover.index = iIndex;
                  tSymbol.iciHoverElement = tPaper.path(getIciHoverPath())
                     .attr({'stroke-width': this.iciHoverElementStrokeWidth, stroke: this.iciStroke, 'stroke-opacity': 0});

                  tSymbol.lowerRect.animatable =
                      tSymbol.upperRect.animatable =
                          tSymbol.boxSymbol.animatable =
                             tSymbol.ici.animatable = true;
                  tSymbol.lowerRect.animate({'stroke-opacity': 1}, kAnimationTime, '<>');
                  tSymbol.upperRect.animate({'stroke-opacity': 1}, kAnimationTime, '<>');
                  tSymbol.boxSymbol.animate({'stroke-opacity': 1}, kAnimationTime, '<>');
                  tSymbol.ici.animate({'stroke-opacity': 1}, kAnimationTime, '<>');
                  tSymbol.pushElements(this.myElements);
                  tSymbol.pushElements(tLayer);
                }.bind( this),

                configureBoxPlotSymbol = function ( iSymbol) {
                  var iciStrokeOpacity = this.getPath('model.showICI') ? 1 : 0;
                  iSymbol.lowerRect.info = {range: {lower: tQ1, upper: tMedian, cases: tCases}};
                  iSymbol.upperRect.info = {range: {lower: tMedian, upper: tQ3, cases: tCases}};
                  iSymbol.lowerWhiskerCover.info = {
                    tipString: 'lower = %@', tipValue: tLowerWhisker,
                    range: {lower: tLowerWhisker, upper: tQ1, cases: tCases}
                  };
                  iSymbol.upperWhiskerCover.info = {
                    tipString: 'upper = %@', tipValue: tUpperWhisker,
                    range: {lower: tQ3, upper: tUpperWhisker, cases: tCases}
                  };
                  iSymbol.medianCover.info = {tipString: 'median = %@', tipValue: tMedian};
                  iSymbol.Q1Cover.info = {tipString: 'Q1 = %@', tipValue: tQ1};
                  iSymbol.Q3Cover.info = {tipString: 'Q3 = %@', tipValue: tQ3};
                  if (iAnimate) {
                    iSymbol.boxSymbol.animate({path: getSymbolPath()}, kAnimationTime, '<>');
                    iSymbol.lowerRect.animate(getLowerRect(), kAnimationTime, '<>');
                    iSymbol.upperRect.animate(getUpperRect(), kAnimationTime, '<>');
                    iSymbol.ici.animate({ 'stroke-opacity': iciStrokeOpacity }, kAnimationTime, '<>');
                  } else {
                    iSymbol.boxSymbol.attr({path: getSymbolPath()});
                    iSymbol.lowerRect.attr(getLowerRect());
                    iSymbol.upperRect.attr(getUpperRect());
                    iSymbol.ici.attr({ 'stroke-opacity': iciStrokeOpacity });
                  }
                  iSymbol.lowerWhiskerCover.attr('path', getLowerWhisker());
                  iSymbol.upperWhiskerCover.attr('path', getUpperWhisker());
                  iSymbol.medianCover.attr('path', getCrossCover('x', 'y'));
                  iSymbol.Q1Cover.attr('path', getCrossCover('Q1', 'Q1'));
                  iSymbol.Q3Cover.attr('path', getCrossCover('Q3', 'Q3'));
                  iSymbol.ici.attr('path', getIci());
                  iSymbol.iciCover.attr('path', getIci());
                  iSymbol.iciHoverElement.attr('path', getIciHoverPath());

                  iSymbol.iciCover.info = {
                    tipString: 'ICI: [%@, %@]'.fmt(formatValue(tMedian - tIci),
                       formatValue(tMedian + tIci))
                  };

                  // Since the number of outliers is variable, we have get the right number
                  var tSym, tSymCover;
                  while( iSymbol.outliers.length < tSpec.outliers.length) {
                    tSym = tPaper.path('M0,0')
                        .attr({stroke: this.symStroke, 'stroke-width': this.symStrokeWidth, 'stroke-opacity': 1});
                    tSymCover = tPaper.path('M0,0')
                        .attr({
                          'stroke-width': this.hoverWidth, stroke: DG.RenderingUtilities.kTransparent,
                          cursor: "pointer"
                        })
                        .hover(overScope, outScope)
                        .mousedown(select);
                    tSym.animatable = true;
                    this.myElements.push( tSym);
                    tLayer.push( tSym);
                    iSymbol.outliers.push( tSym);
                    this.myElements.push( tSymCover);
                    tLayer.push( tSymCover);
                    iSymbol.outlierCovers.push( tSymCover);
                  }
                  while( iSymbol.outliers.length > tSpec.outliers.length) {
                    tSym = iSymbol.outliers.pop();
                    tLayer.prepareToMoveOrRemove(tSym);
                    tSym.remove();
                    this.myElements.splice(this.myElements.indexOf(tSym), 1);
                    tSymCover = iSymbol.outlierCovers.pop();
                    tLayer.prepareToMoveOrRemove(tSymCover);
                    tSymCover.remove();
                    this.myElements.splice(this.myElements.indexOf(tSymCover), 1);
                  }

                  iSymbol.outliers.forEach( function( iOutlier, iOutlierIndex) {
                    var tNumLower = tValuesArray[iIndex].lowerOutliers.length,
                        tWorldValue =  (iOutlierIndex < tNumLower) ?
                                        tValuesArray[iIndex].lowerOutliers[ iOutlierIndex] :
                                        tValuesArray[iIndex].upperOutliers[ iOutlierIndex - tNumLower],
                        tCover = iSymbol.outlierCovers[ iOutlierIndex],
                        tPath = outlierSymbol( iOutlierIndex);
                    iOutlier.attr({ path: tPath });
                    tCover.attr({ path: tPath });
                    tCover.info = {
                      tipString: '%@', tipValue: tWorldValue,
                      range: {lower: tWorldValue, upper: tWorldValue, cases: tCases }
                    };
                  });

                  iSymbol.boxSymbol.toFront();
                  iSymbol.ici.toFront();
                  iSymbol.lowerWhiskerCover.toFront();
                  iSymbol.upperWhiskerCover.toFront();
                  iSymbol.medianCover.toFront();
                  iSymbol.Q1Cover.toFront();
                  iSymbol.Q3Cover.toFront();
                  iSymbol.iciCover.toFront();
                  iSymbol.iciHoverElement.toFront();
                }.bind( this);

            // Begin updateOneBoxPlot
            var tCases = tValuesArray[iIndex].cases,
                tMedian = tValuesArray[iIndex].median,
                tQ1 = tValuesArray[iIndex].Q1,
                tQ3 = tValuesArray[iIndex].Q3,
                tLowerWhisker = tValuesArray[iIndex].lowerWhisker,
                tUpperWhisker = tValuesArray[iIndex].upperWhisker,
                tIci = tValuesArray[iIndex].ICI,
                tMedianCoord = ( isFinite(tMedian) ? tPrimaryAxisView.dataToCoordinate(tMedian) : tOffScreen ),
                tQ1Coord = ( isFinite(tQ1) ? tPrimaryAxisView.dataToCoordinate(tQ1) : tOffScreen ),
                tQ3Coord = ( isFinite(tQ3) ? tPrimaryAxisView.dataToCoordinate(tQ3) : tOffScreen );
            tSpec.width = ( isFinite(tQ3Coord - tQ1Coord) ? Math.abs(tQ3Coord - tQ1Coord) : 0 );
            tSpec.x = ( tIsHorizontal ? tMedianCoord : iIndex * tCellHeight );
            tSpec.y = ( tIsHorizontal ? (tNumValues - iIndex) * tCellHeight : tMedianCoord );
            tSpec.Q1 = tQ1Coord;
            tSpec.Q3 = tQ3Coord;
            tSpec.lowerWhisker = ( isFinite(tLowerWhisker) ?
            tSpec.Q1 - tPrimaryAxisView.dataToCoordinate(tLowerWhisker) : 0);
            tSpec.upperWhisker = ( isFinite(tUpperWhisker) ?
                (tIsHorizontal ? tPrimaryAxisView.dataToCoordinate(tUpperWhisker) - (tSpec.Q1 + tSpec.width) :
                    -(tSpec.Q1 - tSpec.width - tPrimaryAxisView.dataToCoordinate(tUpperWhisker))) : 0);
            tSpec.iciLower = ( isFinite(tIci) ? tPrimaryAxisView.dataToCoordinate(tMedian - tIci) : tOffScreen );
            tSpec.iciUpper = ( isFinite(tIci) ? tPrimaryAxisView.dataToCoordinate(tMedian + tIci) : tOffScreen );
            tSpec.outliers = [];
            tValuesArray[iIndex].lowerOutliers.forEach(function (iOutlier) {
              tSpec.outliers.push(tPrimaryAxisView.dataToCoordinate(iOutlier));
            });
            tValuesArray[iIndex].upperOutliers.forEach(function (iOutlier) {
              tSpec.outliers.push(tPrimaryAxisView.dataToCoordinate(iOutlier));
            });
            var tXCenter = tSpec.x + tSpec.cellHeight / 2,
                tYCenter = tSpec.y - tSpec.cellHeight / 2;

            // create and update the boxplot elements
            if (iIndex >= this.boxPlotSymbols.length) {
              createBoxPlotSymbol();
            }

            // update elements (to current size/position)
            configureBoxPlotSymbol( this.boxPlotSymbols[iIndex]);

          }.bind(this);

          // Begin updateSymbols
          for (var i = 0; i < tNumValues; ++i) {
            updateOneBoxPlot(i);
          }
          while (this.boxPlotSymbols.length > tNumValues) {
            this.boxPlotSymbols.pop().removeFromArrayAndLayer(this.myElements, tLayer);
          }
        }
      };  // object returned closure
    }()) // function closure
);
/* >>>>>>>>>> BEGIN source/components/graph/adornments/plotted_count_adornment.js */
// ==========================================================================
//                   DG.PlottedCountAdornment
//
//  Counts/Percents displayed as text in each cell of a plot.
//
//  Author:   Craig D. Miller
//
//  Copyright ©2012-13 Scientific Reasoning Research Institute,
//                  University of Massachusetts Amherst
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/adornments/plot_adornment');
sc_require('components/graph/adornments/value_axis_view_mixin');

/**
 * @class  Abstract base class for plot adornments that draw averages (mean, median) as symbols in the plot.
 *          Mixes in the DG.ValueAxisViewMixin for handling axis notifications that trigger updates.
 * @extends DG.PlotAdornment
 */
DG.PlottedCountAdornment = DG.PlotAdornment.extend( DG.ValueAxisViewMixin,
/** @scope DG.PlottedCountAdornment.prototype */
{
  marginX: 2,
  marginY: 2,
  textColor: '#315B7D',
  numCellsOnX: 1,
  numCellsOnY: 1,
  numCellsOnSecondary: 1,
  numCellsOnPrimary: 1,
  xIsPrimaryAxis: true,

  /**
    Concatenated array of ['PropertyName','ObserverMethod'] pairs used for indicating
    which observers to add/remove from the model.
    
    @property   {Array of [{String},{String}]}  Elements are ['PropertyName','ObserverMethod']
   */
  modelPropertiesToObserve: [ ['values', 'updateToModel'],
                              ['isShowingCount', 'updateSymbols'],
                              ['isShowingPercent', 'updateSymbols'],
                              ['percentKind', 'updateToModel']],

  /** do we want the average to be visible and up to date? Yes if our model 'isVisible' */
  wantVisible: function() {
    return this.getPath('model.isVisible');
  },

  /**
   * Recompute our model if needed, then move symbols to location specified by model.
   * @param iAnimate {Boolean} [optional] if true then animate to new symbol location.
   */
  updateToModel: function( iAnimate ) {
    if( typeof iAnimate === 'object')
        iAnimate = false; // because we get here through notification, which passes an object
    var tCountModel = this.get('model');

    // only recompute and update symbols if visible, this.updateVisibility() handles everything else
    if( tCountModel && tCountModel.get('isVisible')) {
      tCountModel.recomputeValueIfNeeded();
      this.updateSymbols( iAnimate );
    }
  },

  /**
   * Create or update our myElements array of average symbols.
   * @param iAnimate {Boolean} [optional] if true then animate to new symbol location.
   */
  updateSymbols: function( iAnimate ) {
    var this_ = this;

    function formatValueString( iValue) {
      var tForSelectionOnly = this_.getPath('model.enableMeasuresForSelection'),
          tFormatString,
          tValueString = '',
          tCountValue = tForSelectionOnly ? iValue.selectedCount: iValue.count,
          tPercValue = DG.MathUtilities.roundToSignificantDigits(iValue.percent, 2).roundedValue; // 2 significant digits
      if( tShowCount && !tShowPercent) {
        tFormatString = tForSelectionOnly ? 'DG.PlottedCount.withSelection' : 'DG.PlottedCount.withoutSelection';
        tValueString = tFormatString.loc (tCountValue.toString());
      }
      else if( tShowPercent && !tShowCount) {
        tFormatString = tForSelectionOnly ? 'DG.PlottedPercent.withSelection' : 'DG.PlottedPercent.withoutSelection';
        tValueString = tFormatString.loc( tPercValue);
      }
      else if( tShowCount && tShowPercent) {
        tFormatString = tForSelectionOnly ? 'DG.PlottedCountPercent.withSelection' : 'DG.PlottedCountPercent.withoutSelection';
        tValueString = tForSelectionOnly ?
            tFormatString.loc( tCountValue, iValue.count, tPercValue) :
            tFormatString.loc( tCountValue, tPercValue);
      }
      return tValueString;
    }

    function findLongestValueString() {
      var tMaxString = '';
      tValuesArray.forEach( function( iValue) {
        var tTestString = formatValueString( iValue);
        if( tTestString.length > tMaxString.length)
          tMaxString = tTestString;
      });
      return tMaxString;
    }

    var tModel = this.get('model'),
        tIsVisible = tModel.get('isVisible'),
        tShowCount = tModel.get('isShowingCount'),
        tShowPercent = tModel.get('isShowingPercent');
    if( !tIsVisible || (!tShowCount && !tShowPercent))
      return; // We have nothing to to update

    var tValuesArray = tModel.get('values'),
        tNumValues = tValuesArray.length,
        tNumElements = this.myElements.length;

    this.updateNumCells();
    if( tNumValues !==( this.numCellsOnX * this.numCellsOnY ) || tNumValues === 0) {
      // TODO: find the places where this happens and fix (Chainsaw: thickness vs. ?)
      // zero length array indicates that the model was not able to compute values and aborted; we should also,
      // until model is complete again.
      if( tNumValues > 0 )
        DG.logWarn("DG.PlottedCountAdornment.updateSymbols has mismatch of %@ values and %@ cells", tNumValues,
            ( this.numCellsOnX * this.numCellsOnY ));
      this.removeExtraSymbols( 0 );
      return;
    }
    var tPaper = this.get('paper'),
        tLayer = this.get('layer' ),
        tCellHeight = this.getPath('yAxisView.fullCellWidth'),
        tCellWidth = this.getPath('xAxisView.fullCellWidth'),
        tFontSize = 12,
        tLongest = findLongestValueString(),
        tTempElement = tPaper.text(-100, 0, tLongest)
            .attr( {'font-size': tFontSize })
            .addClass('dg-graph-adornment-count'),
        tExtent = DG.RenderingUtilities.getExtentForTextElement( tTempElement, 11),
        tYOffset = tExtent.height,

        tAttrs, tTextElem, tIsNewElement, i;
    while( tExtent.width > tCellWidth) {
      tFontSize--;
      tTempElement.attr( {'font-size': tFontSize });
      tExtent = DG.RenderingUtilities.getExtentForTextElement( tTempElement, 11);
    }
    tTempElement.remove();

    // for each count value (one per cell of plot), add/update a text element
    for( i=0; i<tNumValues; ++i ) {
      var tValue = tValuesArray[i],
          tIndexPrimary = tValue.primaryCell,
          tIndexSecondary = tValue.secondaryCell,
          tIndexX=( this.xIsPrimaryAxis ? tIndexPrimary : tIndexSecondary ),
          tIndexY=( this.xIsPrimaryAxis ? tIndexSecondary : tIndexPrimary ),
          tCountFromTop = this.numCellsOnY - tIndexY - 1;
      tIsNewElement = ( i >= tNumElements );
      tAttrs = { // position in upper-right of cell, with margin
          x: ((tIndexX+1)*tCellWidth) - this.marginX,
          y: this.marginY + tYOffset/3 + (tCountFromTop*tCellHeight ),
          'font-size': tFontSize,
          text: formatValueString( tValue)
      };

      if (tIsNewElement) {   // create text element
        tTextElem = tPaper.text(tAttrs.x, tAttrs.y, tAttrs.text);
        tTextElem.attr({'text-anchor': 'end', fill: this.textColor});
        tTextElem.addClass('dg-graph-adornment-count');
        this.myElements.push(tTextElem);
        tLayer.push(tTextElem);
      } else {                // update text element
        tTextElem = this.myElements[i];
        tTextElem.attr(tAttrs);
      }
      if (iAnimate) {
        tTextElem.attr({opacity: 0})
            .animate({opacity: 1}, DG.PlotUtilities.kDefaultAnimationTime, '<>');
      }
    }

    // remove extra symbols (if number of cells has shrunk)
    if( tNumValues < this.myElements.length ) {
      this.removeExtraSymbols( tNumValues );
    }
    DG.assert( this.myElements.length === tValuesArray.length );
  },

  /**
   * Remove extra symbols from the plot and the end of our 'myElements' array
   * @param iDesiredNumSymbols
   */
  removeExtraSymbols: function( iDesiredNumSymbols ) {
    var tLayer = this.get('layer' ),
        i, j, tElement;
    for( i=iDesiredNumSymbols, j=this.myElements.length; i<j; ++i ) {
      tElement = this.myElements[i];
      tLayer.prepareToMoveOrRemove( tElement);
      tElement.remove(); // remove from paper
      tElement = null;   // remove from array
    }
    this.myElements.length = iDesiredNumSymbols;
  },

  /**
   * Get the title shown when hovering over the count text
   * @param iCount {Number}
   * @param iPercent {Number}
   * @return {String}
   */
  getTitle: function( iCount, iPercent ) {
    // TODO: use getCaseCountString: function( iCollection, iCount) ?
    var tCasesString = ( iCount === 1 ? 'DG.DataContext.singleCaseName'.loc() : 'DG.DataContext.pluralCaseName'.loc() );
    return 'DG.PlottedCountAdornment.title'.loc( iCount, tCasesString, iPercent.toFixed(0));
  },

  /**
   * Update the number of cells on X and Y, for *all* plot types,
   * including those that use primary/secondary axis designation, instead
   * of X and Y.
   */
  updateNumCells: function() {
    var tPlot = this.getPath('model.plotModel'),
        tXAxis = tPlot.get('xAxis'),
        tYAxis = tPlot.get('yAxis'),
        tSecondaryAxis = tPlot.get('secondaryAxisModel'),
        tPrimaryAxis = tPlot.get('primaryAxisModel');

    this.xIsPrimaryAxis = tSecondaryAxis === tYAxis;
    this.numCellsOnX = tXAxis.get('numberOfCells') || 1;
    this.numCellsOnY = tYAxis.get('numberOfCells') || 1;
    this.numCellsOnSecondary = tSecondaryAxis ? tSecondaryAxis.get('numberOfCells') : 1;
    this.numCellsOnPrimary = tPrimaryAxis ? tPrimaryAxis.get('numberOfCells') : 1;
  }

});

/* >>>>>>>>>> BEGIN source/components/graph/data_model/analysis.js */
// ==========================================================================
//                            DG.Analysis
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

  Provides some types and constants for use in analysis objects

*/
DG.Analysis = {

  /**
   * Enumeration of possible types for attributes.
   */
  EAttributeType: {
        eNone: 0,
        eNumeric: 1,
        eCategorical: 2,
        eDateTime: 3,
        eBoundary: 4,
        eColor: 5
  },

  /**
   * Enumeration of possible roles for attributes.
   */
  EAnalysisRole: {
        eInvalid: -1,
        eNone: 0,
        ePrimaryNumeric: 1,
        eSecondaryNumeric: 2,
        ePrimaryCategorical: 3,
        eSecondaryCategorical: 4,
        eLegendNumeric: 5,
        eLegendCategorical: 6,
        eVerticalSplit: 7,      // for attribute in place DG.GraphTypes.EPlace.eTopSplit
        eHorizontalSplit: 8     // for attribute in place DG.GraphTypes.EPlace.eRightSplit
  },

  EPercentKind: {
    eCell: 0,
    eRow: 1,
    eColumn: 2
  },

  EBreakdownType: {
    eCount: 0,
    ePercent: 1
  },

/**
   * Constant to indicate a null attribute. It's inconvenient to use null because in a property
      function you can't distinguish between a desire to set it to null and a value of null.
   */
  kNullAttribute: null,

  forceColorToCategorical: function( iType) {
    return (iType === this.EAttributeType.eColor) ? this.EAttributeType.eCategorical : iType;
  }

};


/* >>>>>>>>>> BEGIN source/components/graph/adornments/plotted_count_model.js */
// ==========================================================================
//                          DG.PlottedCountModel
//
//  Model for counts and percentages displayed as text in plots
//  of the graph.  Plot is divided into cells according to categorical
//  axis bins.  In the future this count can also be divided by user-specified
//  divider lines like TinkerPlots.
//
//  Author:   Craig D. Miller
//
//  Copyright ©2012-13 Scientific Reasoning Research Institute,
//                  University of Massachusetts Amherst
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/adornments/plot_adornment_model');
sc_require('components/graph/data_model/analysis');

/**
 * @class  The model for a plotted count and/or percent.
 * @extends SC.Object
 */
DG.PlottedCountModel = DG.PlotAdornmentModel.extend(
    /** @scope DG.PlottedCountModel.prototype */
    (function () {

      return {

        values: null,       // [{ count|percent }], one element per cell
        //precision: 0,     // decimal precision of percent being displayed
        plotModel: null,    // {DG.PlotModel}

        isVisible: false, // opposite of base class

        _isShowingCount: false,

        destroy: function() {
          this.plotModel = null;  // break reference loop
          arguments.callee.base.apply(this,arguments);
        },

        /**
         * @property {Boolean}
         */
        isShowingCount: function (iKey, iValue) {
          if (!SC.none(iValue) && iValue !== this._isShowingCount) {
            this._isShowingCount = iValue;
            this.set('isVisible', this._isShowingCount || this._isShowingPercent);
          }
          return this._isShowingCount;
        }.property(),

        _isShowingPercent: false,
        /**
         * @property {Boolean}
         */
        isShowingPercent: function (iKey, iValue) {
          if (!SC.none(iValue) && iValue !== this._isShowingPercent) {
            this._isShowingPercent = iValue;
            this.set('isVisible', this._isShowingCount || this._isShowingPercent);
          }
          return this._isShowingPercent;
        }.property(),

        enableMeasuresForSelection: false,

        /**
         * @property {ePercentKind}
         */
        _percentKind: null,
        percentKind: function(iKey, iValue) {
          if( !SC.none( iValue)) {
            this._percentKind = iValue;
            this._needsComputing = true;
          }
          if( SC.none( this._percentKind))
              this._percentKind = DG.Analysis.EPercentKind.eRow;
          return this._percentKind;
        }.property(),

        /** compute counts */
        recomputeValue: function () {

          function computeCellPercents() {
            var tTotalCount = 0;
            if( !tForSelection) {
              tValueArray.forEach(function (iCell) {
                tTotalCount += iCell.count;
              });
            }
            tValueArray.forEach(function (iCell) {
              var tCellCount = tForSelection ? iCell.selectedCount : iCell.count;
              tTotalCount = tForSelection ? iCell.count : tTotalCount;
              if (tTotalCount > 0 && tCellCount > 0) {
                iCell.percent = 100 * tCellCount / tTotalCount;
              } else {
                iCell.percent = 0; // if 0 cases then 0%
              }
            });
          }

          function computeRowPercents() {
            var tRowCounts = [];
            for( var i = 0; i < tNumOnSecondary; i++) {
              tRowCounts[ i] = 0;
            }
            tValueArray.forEach(function (iCell, iIndex) {
              var tRow = iIndex % tNumOnSecondary;
              tRowCounts[ tRow] += iCell.count;
            });
            tValueArray.forEach(function (iCell, iIndex) {
              var tCellCount = tForSelection ? iCell.selectedCount : iCell.count,
                  tRow = iIndex % tNumOnSecondary,
                  tRowCount = tRowCounts[ tRow];
              if( tForSelection)
                iCell.count = tRowCount;  // So we'll see the right denominator in display
              if (tRowCount > 0 && tCellCount > 0) {
                iCell.percent = 100 * tCellCount / tRowCount;
              } else {
                iCell.percent = 0; // if 0 cases then 0%
              }
            });
          }

          function computeColumnPercents() {
            var tColumnCounts = [];
            for( var i = 0; i < tNumOnPrimary; i++) {
              tColumnCounts[ i] = 0;
            }
            tValueArray.forEach(function (iCell, iIndex) {
              var tColumn = Math.floor( iIndex / tNumOnSecondary);
              tColumnCounts[ tColumn] += iCell.count;
            });
            tValueArray.forEach(function (iCell, iIndex) {
              var tCellCount = tForSelection ? iCell.selectedCount : iCell.count,
                  tColumn = Math.floor( iIndex / tNumOnSecondary),
                  tColumnCount = tColumnCounts[ tColumn];
              if( tForSelection)
                iCell.count = tColumnCount;  // So we'll see the right denominator in display
              if (tColumnCount > 0 && tCellCount > 0) {
                iCell.percent = 100 * tCellCount / tColumnCount;
              } else {
                iCell.percent = 0; // if 0 cases then 0%
              }
            });
          }

          var tNumOnPrimary = this.getPath('plotModel.primaryAxisModel.numberOfCells'),
              tNumOnSecondary = this.getPath('plotModel.secondaryAxisModel.numberOfCells'),
              tPercentKind = (tNumOnPrimary > 1 && tNumOnSecondary > 1) ? this.get('percentKind') :
                  DG.Analysis.EPercentKind.eCell,
              tIsRotated = this.getPath('plotModel.primaryAxisPlace') === DG.GraphTypes.EPlace.eY,
              tForSelection = this.get('enableMeasuresForSelection');
          // Take this opportunity to turn off showing percent if there is only one cell
          if( this.get('isShowingPercent') && (tNumOnPrimary * tNumOnSecondary === 1) &&
              !tForSelection) {
            this.set('isShowingPercent', false);
          }
          if( tIsRotated) {
            if( tPercentKind === DG.Analysis.EPercentKind.eColumn)
              tPercentKind = DG.Analysis.EPercentKind.eRow;
            else if(tPercentKind === DG.Analysis.EPercentKind.eRow)
              tPercentKind = DG.Analysis.EPercentKind.eColumn;
          }

          // get non-missing case count in each cell, and cell index, from plot models
          DG.assert(this.plotModel && this.plotModel.getCellCaseCounts);
          var tValueArray = this.plotModel.getCellCaseCounts( tForSelection);
          switch( tPercentKind) {
            case DG.Analysis.EPercentKind.eCell:
              computeCellPercents();
              break;
            case DG.Analysis.EPercentKind.eRow:
              computeRowPercents();
              break;
            case DG.Analysis.EPercentKind.eColumn:
              computeColumnPercents();
              break;
          }

          this.set('values', tValueArray); // we expect view to observe this change
          this._needsComputing = false;
        },

        /**
         Private cache.
         @property { Boolean }
         */
        _needsComputing: true,

        /**
         Returns an object which contains properties that should be written
         out with the document for archiving purposes.
         */
        createStorage: function () {
          var tStorage = arguments.callee.base.apply(this,arguments);
          tStorage.isShowingCount = this.get('isShowingCount') || false;
          tStorage.isShowingPercent = this.get('isShowingPercent') || false;
          tStorage.percentKind = SC.none(this.get('percentKind')) ? undefined : this.get('percentKind');
          return tStorage;
        },

        /**
         Set the contents of the adornment model from the restored storage.
         */
        restoreStorage: function (iStorage) {
          this.set('isShowingCount', SC.none( iStorage.isShowingCount) ? iStorage.isVisible : iStorage.isShowingCount);
          this.set('isShowingPercent', iStorage.isShowingPercent || false);
          this.set('percentKind', SC.none(iStorage.isShowingPercent) ? DG.Analysis.EPercentKind.eRow :
              iStorage.percentKind);
          arguments.callee.base.apply(this,arguments);
        }

      };
    }()));

DG.PlotAdornmentModel.registry.plottedCount = DG.PlottedCountModel;

/* >>>>>>>>>> BEGIN source/components/graph/adornments/plotted_formula_edit_context.js */
// ==========================================================================
//                      DG.PlottedFormulaEditContext
//
//  Author:   Kirk Swenson
//
//  Copyright (c) 2017 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

DG.PlottedFormulaEditContext = SC.Object.extend({

  plottedFormula: null,

  expressionBinding: '.plottedFormula.expression',

  formulaView: null,

  formulaDialog: null,

  createFormulaView: function(iOptions) {
    var formulaContext = this,
        formulaLabel = iOptions.formulaPrompt.loc(),
        formulaView = DG.FormulaTextEditView.create({
                        // SC defers to INPUT elements on mobile Safari in ignoreTouchHandle().
                        // In this case, we want SC to dispatch the touch normally.
                        classNames: ['dg-wants-sc-touch'],
                        layout: { height: 20 },
                        borderStyle: SC.BORDER_BEZEL,
                        isVisible: false,
                        isEditable: false,
                        value: formulaContext.getPath('plottedFormula.expression'),
                        leftAccessoryView: SC.LabelView.create({
                          layout: { left: 0, width:45, height:20, centerY: 0 },
                          value: formulaLabel ? "\xA0" + formulaLabel : "",
                          backgroundColor: 'gray'
                        }),
                        desiredExtent: 20,
                        mouseDown: function(evt) {
                          formulaContext.openFormulaEditorDialog();
                        },
                        touchStart: function(evt) {
                          this.mouseDown();
                        }
                      });
    this.set('formulaView', formulaView);
    this.set('clientOptions', iOptions ? DG.copy(iOptions) : {});
/*  We can get here as the document is opened which is a bug. And actually
    it's better to have the user click in the place where the formula goes anyway.
    if( SC.empty( this.getPath('plottedFormula.expression'))) {
      this.openFormulaEditorDialog();
    }
*/
    return formulaView;
  },

  openFormulaEditorDialog: function() {
    var formulaContext = this,
        dataContext = this.getPath('plottedFormula.plotModel.dataContext'),
        result = DG.AttributeFormulaView.buildOperandsMenuAndCompletionData(dataContext),
        clientOptions = this.get('clientOptions'),
        options = Object.assign({
                    applyTarget: formulaContext,
                    applyAction: 'applyNewFormula',
                    attrNamePrompt: 'DG.PlottedFormula.defaultNamePrompt'.loc(),
                    attrNameValue: "",
                    attrNameIsEnabled: false,
                    formulaValue: formulaContext.get('expression'),
                    formulaCompletions: result.completionData,
                    formulaOperands: result.operandsMenu
                  }, clientOptions),
        formulaDialog = DG.CreateAttributeFormulaView(options);
    this.set('formulaDialog', formulaDialog);
    return formulaDialog;
  },

  createEditCommand: function(newFormula) {
    var clientOptions = this.get('clientOptions'),
        originalFormula = this.get('expression');

    var setFormula = function setFormula(formula) {
      this.set('expression', formula);
      this.setPath('formulaView.value', formula);
    }.bind(this);

    return DG.Command.create({
      name: clientOptions.commandName,
      undoString: clientOptions.undoString,
      redoString: clientOptions.redoString,
      log: clientOptions.logMessage &&
            clientOptions.logMessage.fmt(originalFormula, newFormula),
      executeNotification: {
        action: 'notify',
        resource: 'component',
        values: {
          operation: 'edit plot formula',
          type: 'DG.GraphView'
        }
      },
      execute: function() {
        setFormula(newFormula);
      },
      undo: function() {
        setFormula(originalFormula);
      },
      redo: function() {
        setFormula(newFormula);
      }
    });
  },

  applyNewFormula: function() {
    var cmd = this.createEditCommand(this.getPath('formulaDialog.formula'));
    DG.UndoHistory.execute(cmd);

    var dialog = this.get('formulaDialog');
    if (dialog) {
      dialog.close();
      this.set('formulaDialog', null);
    }
  }
});

DG.PlottedFormulaEditContext.formulaEditContexts = {};

DG.PlottedFormulaEditContext.hasFormulaEditContextFor = function(iPlottedFormula) {
  return iPlottedFormula &&
      !SC.none(DG.PlottedFormulaEditContext.formulaEditContexts[iPlottedFormula.get('id')]);
};

DG.PlottedFormulaEditContext.getFormulaEditContext = function(iPlottedFormula) {
  var adornmentID = iPlottedFormula.get('id');
  if (!DG.PlottedFormulaEditContext.formulaEditContexts[adornmentID]) {
    DG.PlottedFormulaEditContext.formulaEditContexts[adornmentID] =
      DG.PlottedFormulaEditContext.create({ plottedFormula: iPlottedFormula });
  }
  return DG.PlottedFormulaEditContext.formulaEditContexts[adornmentID];
};

DG.PlottedFormulaEditContext.destroyFormulaEditContext = function( iID) {
  var tContext = DG.PlottedFormulaEditContext.formulaEditContexts[iID];
  if( tContext) {
    tContext.destroy();
    delete DG.PlottedFormulaEditContext.formulaEditContexts[iID];
  }
};
/* >>>>>>>>>> BEGIN source/components/graph/adornments/plotted_function_adornment.js */
// ==========================================================================
//                    DG.PlottedFunctionAdornment
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/adornments/plot_adornment');

/** @class  Plots a function.

  @extends DG.PlotAdornment
*/
DG.PlottedFunctionAdornment = DG.PlotAdornment.extend(
/** @scope DG.PlottedFunctionAdornment.prototype */
{

  /**
    Concatenated array of ['PropertyName','ObserverMethod'] pairs used for indicating
    which observers to add/remove from the model.

    @property   {Array of [{String},{String}]}  Elements are ['PropertyName','ObserverMethod']
   */
  modelPropertiesToObserve: [ ['expression', 'updateToModel'], ['dependentChange', 'updateToModel'] ],

  /**
    The function is drawn by specifying a path for a path element.
    @property { Raphael line element }
  */
  curve: null,

  /**

  */
  createElements: function() {
    if( this.myElements && (this.myElements.length > 0))
      return; // already created
    if( !this.get('paper'))
      return; // Not ready yet
    this.curve = this.get('paper').path('').attr( { stroke: 'red' });
    this.curve.animatable = true;
    this.myElements.push( this.curve);
    this.get('layer' ).push( this.curve);
  },

  /**
    Compute the path for the current equation given by my model.
    We're using a fixed grid scheme at the moment, but should rewrite this to use an adaptive
    algorithm such as the one described at: <http://yacas.sourceforge.net/Algochapter4.html>.
  */
  updateToModel: function() {
    if(!this.getPath('model.isVisible') || !this.get('paper'))
      return;

    this.createElements();
    var tXAxisView = this.get('xAxisView'),
        tYAxisView = this.get('yAxisView'),
        tPixelMin = tXAxisView.get('pixelMin'),
        tPixelMax = tXAxisView.get('pixelMax'),
        kPixelGap = 1,  // pixels between path points
        tPixelX,
        tModel = this.get('model'),
        tPath = '',
        tX, tY, tPixelY,
        tPoints = [];

    // begin updateToModel body
    if( tModel) {
      // Wrap the loop in a try/catch block so exceptions will exit the loop.
      try {
        for( tPixelX = tPixelMin; tPixelX <= tPixelMax; tPixelX += kPixelGap) {
          tX = tXAxisView.coordinateToData( tPixelX);
          // Note: If an exception is thrown on evaluate(), we exit the loop
          tY = tModel.evaluate({ x: tX });
          if( DG.isFinite( tY)) {
            tPixelY = tYAxisView.dataToCoordinate( tY);
            tPoints.push( {top: tPixelY, left: tPixelX});
          }
        }
      }
      catch(err) {
        // Extract error information to provide feedback to user.
      }
      if( tPoints.length > 0) {
        // Accomplish spline interpolation
        tPath = 'M' + tPoints[0].left + ',' + tPoints[0].top + DG.SvgScene.curveBasis( tPoints);
      }
    }
    this.curve.attr( { path: tPath });
  }

});

DG.PlottedFunctionAdornment.createFormulaEditView = function(iPlottedFunction) {
  var formulaEditContext = DG.PlottedFormulaEditContext.getFormulaEditContext(iPlottedFunction);
  return formulaEditContext.createFormulaView({
                              attrNamePrompt: 'DG.PlottedFunction.namePrompt',
                              formulaPrompt: 'DG.PlottedFunction.formulaPrompt',
                              formulaHint: 'DG.PlottedFunction.formulaHint',
                              commandName: 'graph.editPlottedFunction',
                              undoString: 'DG.Undo.graph.changePlotFunction',
                              redoString: 'DG.Redo.graph.changePlotFunction',
                              logMessage: 'Change plotted function: "%@1" to "%@2"'
                            });
};


/* >>>>>>>>>> BEGIN source/utilities/object_map.js */
// ==========================================================================
//                            DG.ObjectMap
// 
//  A collection of utilities for manipulating objects as associative arrays
//  or maps.
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

DG.ObjectMap = {

  /**
    Returns the number of properties the object has.
    Returns 0 for undefined or null objects.
    
    @param {Object} iObject   The object whose properties should be counted
    @returns {Number}       The object's property count
   */
  length: function( iObject) {
    return Object.keys( iObject || {}).length;
  },

  /**
    Returns an array of strings representing the property names of the object.
    The order of the returned elements is not specified by the standard.
    Returns an empty array for undefined or null objects.
    
    @param {Object} iObject   The object whose properties names should be returned
    @returns {Array of String}  Array of property name strings
   */
  keys: function( iObject) {
    return Object.keys( iObject || {});
  },
  
  /**
    Returns an array of values representing the property values of the object.
    The order of the returned elements is not specified by the standard.
    Returns an empty array for undefined or null objects.
    
    @param {Object} iObject   The object whose properties names should be returned
    @returns {Array of values}  Array of property values
   */
  values: function( iObject) {
    var tValues = [];
    DG.ObjectMap.forEach( iObject, function( iKey, iValue) { tValues.push( iValue); } );
    return tValues;
  },
  
  /**
    Copies the properties of iSrcObject into ioDstObject. This is a shallow copy which
    overwrites any properties of ioDstObject with the corresponding properties of iSrcObject.
    Note: See SC.clone(), SC.copy(), and SC.mixin() for alternative implementations with
    different implementations than this.
    
    @param {Object} ioDstObject   The object to copy properties into
    @param {Object} iSrcObject    The object to copy properties from
   */
  copy: function( ioDstObject, iSrcObject) {
    DG.ObjectMap.forEach( iSrcObject, function( iKey, iValue) { ioDstObject[iKey] = iValue; });
  },
  
  /**
    Copies some of the properties of iSrcObject into ioDstObject. iFilterFunc determines
    which properties should be copied, returning true for those that should be copied,
    false otherwise. This is a shallow copy which overwrites any properties of ioDstObject 
    with the corresponding properties of iSrcObject.
    
    @param {Object} ioDstObject   The object to copy properties into
    @param {Object} iSrcObject    The object to copy properties from
    @param {Function} iFilterFunc(iKey,iValue)  Returns true for properties to copy
   */
  copySome: function( ioDstObject, iSrcObject, iFilterFunc) {
    DG.ObjectMap.forEach( iSrcObject,
                          function( iKey, iValue) {
                            if( iFilterFunc( iKey, iValue))
                              ioDstObject[iKey] = iValue;
                          });
  },
  
  /**
    Applies the specified function to each property of the specified object.
    The order in which the properties are visited is not specified by the standard.
    
    The function passed to forEach should have the following signature:
    
    function( iKey, iValue)
    
    @param {Object}   iObject   The object whose properties should be iterated
    @param {Function} iFunction The function to be called for each entry
   */
  forEach: function( iObject, iFunction) {
    if( !iObject) return;
    for( var tKey in iObject) {
      if( iObject.hasOwnProperty( tKey))
        iFunction( tKey, iObject[ tKey]);
    }
  },
  
  /**
    Returns the name/key of the "first" property of the specified object.
    Since the order in which the elements are visited is not specified by the standard,
    which element will be returned as the "first" element is not guaranteed.
    It is likely, however, that for a given object, every call to this function will
    return the same key. This function is useful for clients that need access to some
    element of the map, but aren't particular about which element they get.
    Returns undefined for undefined or null objects.
    
    @param {Object} iObject   The object whose properties names should be returned
    @returns {String}       Property name/key or undefined
   */
  firstKey: function( iObject) {
    return DG.ObjectMap.findKey( iObject, function( iKey, iValue) { return true; });
  },
  
  /**
    Returns the name/key of the "first" property of the specified object that matches
    the specified criterion. The match criterion can be specified as a string, in which
    case the property name is matched, or more commonly as a function, which is applied
    to the elements of the object until the function returns true for one of them,
    at which point that element's name/key is returned.
    If no matching property is found, the function returns undefined.
    The order in which properties are visited is not specified by the standard.
    
    The match function should have the signature:
    Boolean matchFunc( iKey, iValue) { ... }
    where iKey is the key/name of the property and iValue is its value.

    @param {Object}             iObject   The object whose properties names should be returned
    @param {String | Function}  iMatch String to match against the property names OR
                    Function to apply until the first match is found
    @returns {String}       Property name/key of first match or undefined
   */
  findKey: function( iObject, iMatch) {
    if( !iObject || !iMatch) return undefined;
    
    // iMatch can be a key name to match or a match function
    var tKeyName, tFunction = iMatch;
    if( SC.typeOf( iMatch) !== SC.T_FUNCTION) {
      tKeyName = String( iMatch);
      tFunction = function( iKey, iValue) {
              return iKey === tKeyName;
            };
    }
    for( var tKey in iObject) {
      if( iObject.hasOwnProperty( tKey) && tFunction( tKey, iObject[ tKey]))
        return tKey;
    }
    return undefined;
  },
  
  /**
    Returns the name/key of the "first" property of the specified object whose value
    matches the specified value. The comparison is performed with ===. For more
    elaborate comparisons, use the findKey() method with an appropriate function.
    The order in which properties are visited is not specified by the standard.
    
    @param {Object} iObject   The object whose properties names should be returned
    @param {      iValue}   Value to match against the property values
    @returns {String}       Property name/key of first match or undefined
   */
  findValue: function( iObject, iValue) {
    var tValue = iValue;
    return DG.ObjectMap.findKey( iObject, function( iKey, iValue) { return iValue === tValue; });
  },
  
  /**
    Inserts the specified key:value pair into the specified object's map/property list.
    
    @param {Object} iObject   The object whose properties names should be returned
    @param {Object} iKey    The key/name of the property to be inserted
    @param {Object} iValue    The value of the property to be inserted
   */
  insert: function( iObject, iKey, iValue) {
    iObject[ iKey] = iValue;
  },
  
  /**
    Removes the property with the specified key/name from the specified object's map/property list.
    
    @param {Object} iObject   The object whose properties names should be returned
    @param {Object} iKey    The key/name of the property to be removed
    @returns            The value of the property removed
   */
  remove: function( iObject, iKey) {
    var tValue = iKey ? iObject[ iKey] : undefined;
    delete iObject[ iKey];
    return tValue;
  },

  /**
   * Assigns each 'own' property of iObj2 to iObj1.
   *
   * @param iObj1 {*}
   * @param iObj2 {*}
   * @returns {*}
   */
  join: function( iObj1, iObj2) {
    DG.ObjectMap.forEach( iObj2, function( iKey, iValue) {
      iObj1[ iKey] = iValue;
    });
    return iObj1;
  }

};

/* >>>>>>>>>> BEGIN source/formula/function_registry.js */
// ==========================================================================
//  Author:   Kirk Swenson
//
//  Copyright (c) 2016 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('utilities/object_map');

/*
 * For full localization, we will need to allow localization of function names.
 * In preparation for that eventuality, localized function string resources
 * contain a displayName field. Until the code is prepared to actually use
 * the displayName field appropriately, however, this flag prevents its use.
 */
DG.useFunctionDisplayNames = false;

/** @class DG.FunctionRegistry
 *
 * A registry of the functions available in CODAP.
 */

DG.FunctionRegistry = SC.Object.extend((function() // closure
/** @scope DG.FunctionRegistry.prototype */ {

      // queue of function modules ready to be processed
  var fnModuleQueue = [],
      // map of category names -> { map of function names -> function info objects }
      fnInfoMap = {},
      // array of uncategorized function names
      fnNamesArray = [],
      // flag indicating whether function names are currently sorted
      fnNamesSorted = true,
      // localized strings to be loaded from resources
      fnStringsMap = null,
      // simple functions
      fns = {},
      // aggregate functions
      aggFns = {};

  /**
    Adds the names of the functions in iModule to the fnNames property,
    for use in creating the function popup menu. The properties of the
    iModule object are assumed to be functions, and the names are taken
    from the names of the properties. This will need some adjustment when
    localization is taken into account.
    @param  {Object}  iModule -- Properties are functions
   */
  function processFnModule(iModule) {
    DG.ObjectMap.forEach(iModule, function(iName, iProps) {
      // add it to the categorized map
      var rawCategory = iProps.category || 'DG.Formula.FuncCategoryOther',
          category = rawCategory.loc(),
          fnStrings = (fnStringsMap && fnStringsMap[iName]) || {},
          // for historical reasons, aggregate functions specify arguments
          // differently than non-aggregate functions.
          minArgs = iProps.requiredArgs ? iProps.requiredArgs.min : iProps.minArgs,
          maxArgs = iProps.requiredArgs ? iProps.requiredArgs.max : iProps.maxArgs;
      // if the number of arguments are specified in the function strings documentation,
      // then use that number rather than the function's own maxArgs. This allows the
      // documentation for functions with arbitrary number of arguments (e.g. concat())
      // to control the number of arguments to display.
      if (fnStrings.args && fnStrings.args.length)
        maxArgs = fnStrings.args.length;
      if (!fnInfoMap[category]) fnInfoMap[category] = {};
      var fnInfo = {
            name: iName,
            displayName: DG.useFunctionDisplayNames ? (fnStrings.displayName || iName) : iName,
            category: category,
            description: fnStrings.description,
            minArgs: minArgs,
            maxArgs: maxArgs,
            args: fnStrings.args,
            examples: fnStrings.examples
          };
      if (fnInfo.args) {
        // specify required/optional arguments
        fnInfo.args = fnInfo.args.map(function(arg, index) {
                        if (arg && (index < minArgs))
                          arg.required = true;
                        return arg;
                      });
      }
      fnInfoMap[category][iName] = fnInfo;

      // add it to the uncategorized array
      fnNamesArray.push(iName);
      // mark it as needing to be sorted
      fnNamesSorted = false;
    });
  }

  /**
    Process the objects in the fnModuleQueue to map function names.
    Create a sorted array of categories from the function names.
   */
  function prepareFunctionInfo() {

    // called after loading the localizable function strings
    function processFunctionInfo() {
      if (fnModuleQueue.length) {
        fnModuleQueue.forEach(function(iModule) {
                                processFnModule(iModule);
                              });
        fnModuleQueue = [];
      }

      if (!fnNamesSorted) {
        fnNamesArray.sort();
        fnNamesSorted = true;
      }
    }

    /*
     * Process the localizable function strings.
     */
    if (!fnStringsMap) {
      $.ajax({
        url: '../../../../static/dg/de/cert/resources/json/function_strings.json',
        dataType: 'text'
      })
      .done(function(text) {
        try {
          // We allow comments in function strings documentation,
          // so we remove them before parsing.
          var json = window.stripJsonComments(text);
          fnStringsMap = JSON.parse(json);
        }
        catch(e) {
          // function strings parse errors are logged, but we can continue
          DG.log("%@: %@", e.name, e.message);
          fnStringsMap = {};
        }
      })
      .fail(function(jqxhr, textStatus, error) {
        // log errors loading the function strings
        DG.log("Error loading 'function-strings.json': '%@'", error);
        fnStringsMap = {};
      })
      .always(function() {
        // we always process the function info, with or without the function strings
        processFunctionInfo();
      });
    }
  }

  return {
    /**
      Returns the function names map, which maps category strings to
      arrays of function names for use in building menus, browsers, etc.
      @type {object}
     */
    categorizedFunctionInfo: function() {
      prepareFunctionInfo();
      return fnInfoMap;
    }.property(),

    /**
      Returns a flat array of function names.
      @type {string[]}
     */
    namesArray: function() {
      prepareFunctionInfo();
      return fnNamesArray;
    }.property(),

    /**
      Returns a flat array of function names with parentheses added.
      @type {string[]}
     */
    namesWithParentheses: function() {
      var fns = this.get('namesArray');
      return fns.map(function(iName) {
                      return iName + "()";
                    });
    }.property(),

    /**
      Returns the internal non-aggregate function objects map (currently
      still required by DG.FormulaContext for compiled evaluation).
      @returns  {object}  map of function names to function objects
     */
    functions: function() {
      return fns;
    }.property(),

    /**
      Register the specified functions.
      @param    {object}  iFunctions - map of function name to aggregate function objects
     */
    registerFunctions: function(iFunctions) {
      fnModuleQueue.push(iFunctions);
      DG.ObjectMap.copy(fns, iFunctions);
    },

    /**
      Register the specified aggregate functions.
      @param    {object}  iFunctions - map of function name to aggregate function objects
     */
    registerAggregates: function(iFunctions) {
      fnModuleQueue.push(iFunctions);
      DG.ObjectMap.copy(aggFns, iFunctions);
    },

    /**
      Return the function object for the specified function name.
      @param    {string}  iFnName - the name of the function
      @returns  {object}  the requested function object
     */
    getFunction: function(iFnName) {
      return iFnName && fns[iFnName];
    },

    /**
      Return whether the specified function name corresponds to
      an aggregate function.
      @param    {string}  iFnName - the name of the function
      @returns  {boolean} whether the function is an aggregate function
     */
    isAggregate: function(iFnName) {
      return iFnName && (aggFns[iFnName] != null);
    },

    /**
      Returns the aggregate function object for the specified
      function name.
      @param    {string}  iFnName - the name of the function
      @returns  {object}  the requested function object
     */
    getAggregate: function(iFnName) {
      return iFnName && aggFns[iFnName];
    }

  };
})());

/**
  Singleton instance
 */
DG.functionRegistry = DG.FunctionRegistry.create();

$(function() {
  // process the functions once the document is loaded
  DG.functionRegistry.get('namesArray');
});

/* >>>>>>>>>> BEGIN source/formula/formula_context.js */
// ==========================================================================
//                          DG.FormulaContext
//
//  Author:   Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('formula/function_registry');

/** @class DG.FormulaContext

  DG.FormulaContext objects support DG.Formula objects by providing identifier
  binding and evaluation, function binding and evaluation, etc.

  @extends SC.Object
*/
DG.FormulaContext = SC.Object.extend( (function() {

  /**
    Utility function for check argument count.
    @param    {String}    iName -- The name of the function
    @param    {Array}     iArgs -- The arguments to the function
    @param    {Object}    iFnProps -- An object which contains argument specs for
                            multiple functions, e.g. iArgsSpecs[iName] is the
                            specification for the 'iName' function. The specification
                            is an object with 'minArgs' and 'maxArgs' properties.
   */
  function checkArgs( iName, iArgs, iFnProps) {
    var fArgs = iFnProps && iFnProps[iName];
    if( fArgs && (iArgs.length < fArgs.minArgs))
      throw new DG.FuncArgsError( iName, fArgs);
  }

  return {

  /**
    During compilation, a stack of function contexts indicating the functions
    being processed, e.g. in the expression mean(count(round(x))), when x is
    compiled there are three function contexts on the stack.
    @type {object[]}
   */
  _functionContextStack: null,

  /**
    Initialization function
   */
  init: function() {
    this._functionContextStack = [];

    // need access to functions locally for compiled evaluation
    this._fns = DG.functionRegistry.get('functions');
  },

  /**
    Adds a function context to the top of stack
    @param  {object}  iFunctionContext
   */
  beginFunctionContext: function(iFunctionContext) {
    this._functionContextStack.push(iFunctionContext);
  },

  /**
    Pops a function context from the top of the stack
    @param  {object}  iFunctionContext
   */
  endFunctionContext: function(iFunctionContext) {
    var endName = iFunctionContext && iFunctionContext.name,
        stackSize = this._functionContextStack.length,
        topName = stackSize ? this._functionContextStack[stackSize - 1].name : '';
    if (endName === topName)
      -- this._functionContextStack.length;
    else
      DG.logError("Error: DG.FormulaContext.endFunctionContext -- attempt to end incorrect function context");
  },

  /**
    Returns an array of aggregate function indices representing the aggregate
    functions that are on the _functionContextStack at the moment.
    @returns {number[]}
   */
  getAggregateFunctionIndices: function() {
    return [];
  },

    /**
     * Determine whether the given case should be included in any evaluation. Default is to return true.
     * Subclasses such as DG.PlottedFunctionContext will evaluate based on the cases currently showing.
     *
     * @param  {Object}              iEvalContext -- { _case_: , _id_: }
     * @return {boolean}
     */
  filterCase: function (iEvalContext) {
    return true;
  },

  /**
    Called when a dependency is identified during compilation.
    @param {object}   iDependency
    @param {object}   .dependentSpec - the specs of the node that is dependant
    @param {string}     .type - the type of the node that is dependant
    @param {string}     .id - the id of the node that is dependant
    @param {string}     .name - the name of the node that is dependant
                        defaults to the ownerSpec of the current context
    @param {object}   .independentSpec - the specs of the node being depended upon
    @param {string}     .type - the type of the node being depended upon
    @param {string}     .id - the id of the node being depended upon
    @param {string}     .name - the name of the node being depended upon
    @param {number[]} .aggFnIndices - array of aggregate function indices
                          defaults to the aggregate functions on the stack
                          at compile time when the variable is bound
    @param {object}   .dependentContext - the formula context for the dependent node
   */
  registerDependency: function(iDependency) {
  },

  invalidateNamespace: function() {
    this.notifyPropertyChange('namespaceChange');
  },

  /**
    Invalidation function for use with the dependency manager.
    Called by the dependency manager when invalidating nodes as a result
    of tracked dependencies.
    @param {object}     ioResult
    @param {object}     iDependent
    @param {object}     iDependency
    @param {DG.Case[]}  iCases - array of cases affected
                                 if no cases specified, all cases are affected
    @param {boolean}    iForceAggregate - treat the dependency as an aggregate dependency
   */
  invalidateDependent: function(ioResult, iDependent, iDependency, iCases, iForceAggregate) {
  },

  /**
    Returns true if the specified function name refers to an aggregate function.
    Derived classes may override as appropriate.
   */
  isAggregate: function(iName) {
    return false;
  },

  /**
    Clear any cached bindings for this formula. Called before compiling.
    Derived classes may override as appropriate.
   */
  clearCaches: function() {
  },

  /**
    Called when the formula is about to be recompiled to clear any cached data.
    Derived classes may override as appropriate.
   */
  willCompile: function() {
    this.clearCaches();
  },

  /**
    Called when the formula has been recompiled to clear any stale dependencies.
    Derived classes may override as appropriate.
   */
  didCompile: function() {
  },

  /**
    Called when the formula has been recompiled to clear any stale dependencies.
    Derived classes may override as appropriate.
   */
  completeCompile: function() {
  },

  /**
    Called when dependents change to clear function caches.
    Derived classes may override as appropriate.
   */
  invalidateFunctions: function(iFunctionIndices) {
  },

  /**
    Compiles a variable reference into the JavaScript code for accessing
    the appropriate value. For the base FormulaContext, this means
    binding to global constants such as 'pi' and 'e'.
    @param    {String}    iName -- The variable name to be bound
    @returns  {String}    The JavaScript code for accessing the value
    @throws   {VarReferenceError} Base class throws VarReferenceError for
                                  variable names that are not recognized.
   */
  compileVariable: function( iName) {
    switch( iName) {
    case 'pi':
    case 'π':
      return 'Math.PI';
    case 'e':
      return 'Math.E';
    default:
      var eVars = this.get('eVars');
      if( eVars && (eVars[iName] !== undefined))
        return 'e.' + iName;

      var vars = this.get('vars');
      if( vars && (vars[iName] !== undefined))
        return 'c.vars["' + iName + '"]';
    }
    this.registerDependency({ independentSpec: {
                                type: DG.DEP_TYPE_UNDEFINED,
                                id: iName,
                                name: iName
                            }});
    return '(function(){throw new DG.VarReferenceError(\'' + iName + '\');})()';
  },

  /**
    Direct evaluation of the variable without an intervening compilation.
    For the base FormulaContext, this means binding to global constants such as 'pi' and 'e'.
    @param    {String}    iName -- The variable name to be bound
    @returns  {Object}    Return value can be a Number, String, Boolean, error object, etc.
    @throws   {DG.VarReferenceError}  Throws VarReferenceError for variable
                                      names that are not recognized.
   */
  evaluateVariable: function( iName, iEvalContext) {
    switch( iName) {
    case 'pi':
    case 'π':
      return Math.PI;
    case 'e':
      return Math.E;
    default:
      var eValue = iEvalContext && iEvalContext[ iName];
      if( eValue !== undefined)
        return eValue;
      var vars = this.get('vars');
      if( vars && (vars[iName] !== undefined))
        return vars[iName];
    }
    throw new DG.VarReferenceError( iName);
  },

  /**
    Returns true if this context's formula contains aggregate functions, false otherwise.
    @property {Boolean}
   */
  hasAggregates: false,

  /**
    Compiles a function reference into the JavaScript code for evaluating
    the appropriate function. For the base FormulaContext, this means
    binding to global functions such as ln(), log(), round(), etc. as well
    as the standard JavaScript Math functions (sin(), cos(), atan()), etc.
    @param    {String}    iName -- The name of the function to be called.
    @param    {String[]}  iArgs -- array of arguments to the function
    @param    {Number[]}  iAggFnIndices -- array of aggregate function indices
                            indicating the aggregate function call stack, which
                            determines the aggregates that must be invalidated
                            when a dependent changes.
    @returns  {String}    The JavaScript code for calling the specified function
    @throws   {DG.FuncReferenceError} Throws DG.FuncReferenceError for function
                                      names that are not recognized.
   */
  compileFunction: function( iName, iArgs, iAggFnIndices) {

    var checkArgsAndRandom = function(iFn, iArgs) {
      var isRandom = iFn && iFn.isRandom;
      // validate arguments
      checkArgs(iName, iArgs, iFn);
      if (isRandom) {
        // register the 'random' dependency for invalidation
        this.registerDependency({ independentSpec: {
                                    type: DG.DEP_TYPE_SPECIAL,
                                    id: 'random',
                                    name: 'random'
                                  },
                                  aggFnIndices: iAggFnIndices
                                });
      }
    }.bind(this);

    // Functions provided by built-in '_fns' property of context
    var _fn = this._fns && this._fns[iName];
    if (_fn) {
      checkArgsAndRandom(_fn, iArgs);
      return 'c._fns.' + iName + '.evalFn(' + iArgs + ')';
    }

    // Functions provided by client-provided 'fns' property of context
    // Currently only used in unit tests. If continued support is
    // desired should refactor to work with DG.FunctionRegistry.
    var fns = this.get('fns');
    if( fns && typeof fns[iName] === 'function') {
      //checkArgsAndRandom( iName, iArgs, this.get('fnsProps'));
      return 'c.fns.' + iName + '(' + iArgs + ')';
    }

    return '(function(){throw new DG.FuncReferenceError(\'' + iName + '\');})()';
  },

  /**
    Evaluates a function reference directly without compilation. For the base
    FormulaContext, this means binding to global functions such as ln(), log(),
    round(), etc. as well as the standard JavaScript Math functions (sin(), cos(),
    atan(), etc.).
    @param    {String}    iName -- The name of the function to be called.
    @param    {Array}     iArgs -- the arguments to the function
    @returns  {String}    The JavaScript code for calling the specified function
    @throws   {DG.FuncReferenceError} Throws DG.FuncReferenceError for function
                                      names that are not recognized.
   */
  evaluateFunction: function( iName, iArgs) {

    // Functions provided by built-in '_fns' property of context
    var _fn = DG.functionRegistry.getFunction(iName);
    if (_fn) {
      checkArgs(iName, iArgs, this._fns);
      return _fn.evalFn.apply(this._fns, iArgs);
    }

    // Functions provided by client-provided 'fns' property of context
    // Currently only used in unit tests. If continued support is
    // desired should refactor to work with DG.FunctionRegistry.
    var fns = this.get('fns');
    if( fns && typeof fns[iName] === 'function') {
      checkArgs( iName, iArgs, this.get('fnsProps'));
      return fns[iName].apply( fns, iArgs);
    }

    throw new DG.FuncReferenceError( iName);
  }

  }; // end of closure return statement

}()));

/**
  Returns an evaluable JavaScript function that returns the value
  of the specified expression. The function created is of the form:
    function( c, e) { return iExpression };
  where c is the formula context/compile context and e is the evaluation context.
  @returns  {Function}  The evaluable function
 */
DG.FormulaContext.createContextFunction = function( iExpression) {
  /* jslint evil:true */  // allow use of the Function constructor
  return new Function('c', 'e', 'return ' + iExpression);
};

/* >>>>>>>>>> BEGIN source/formula/global_formula_context.js */
// ==========================================================================
//                      DG.GlobalFormulaContext
//  
//  Author:   Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('formula/formula_context');

/** @class DG.GlobalFormulaContext

  DG.FormulaContext objects support DG.Formula objects by providing identifier
  binding and evaluation, function binding and evaluation, etc.
  The DG.GlobalFormulaContext class adds binding to global (slider) values.

  @extends DG.FormulaContext
*/
DG.GlobalFormulaContext = DG.FormulaContext.extend({

  /**
    Compiles a variable reference into the JavaScript code for accessing
    the appropriate value. For the PlottedFunctionContext, this means
    binding to 'x' and any global values (e.g. sliders).
    @param    {String}    iName -- The variable name to be bound
    @returns  {String}    The JavaScript code for accessing the value
    @throws   {VarReferenceError} Base class throws VarReferenceError for
                                  variable names that are not recognized.
   */
  compileVariable: function( iName) {
  
    // Check for a match with any global variables (e.g. sliders)
    var globalValue = DG.globalsController.getGlobalValueByName( iName);
    if( globalValue) {
      // register the dependency for tracking/invalidation purposes
      this.registerDependency({ independentSpec: {
                                  type: DG.DEP_TYPE_GLOBAL,
                                  id: globalValue.get('id'),
                                  name: iName }
                              });

      // Having identified the global value to be referenced, we attach
      // a function that can access the appropriate value, making use of
      // JavaScript variable scoping to make sure that the new function has
      // access to the local variable named 'global'. We attach this function
      // to a map of referenced global variables in the context named 'g'.
      // (This is code that is generated by the app for the express purpose
      // of machine consumption, so we use terse variable names for simplicity.)
      // The generated JavaScript code then executes the function dereferenced
      // from the context with code that looks something like 'return c.g["v1"]'.
      if( !this.g) this.g = {};
      this.g[iName] = function() {
                        return globalValue.get('value');
                      };
      return 'c.g["' + iName + '"]()';
    }

    // If we don't match any variables we're in charge of,
    // let the base class have a crack at it.
    return arguments.callee.base.apply(this,arguments);
  },
  
  /**
    Direct evaluation of the expression without an intervening compilation.
    This is unlikely to be used for plotted funtions where the expression is
    generally evaluated enough times to make compilation to JavaScript
    worthwhile, but we support it for consistency and completeness.
    @param    {String}    iName -- The variable name to be bound
    @returns  {Number}            The value of the specified variable or global
    @throws   {VarReferenceError} Base class throws VarReferenceError for
                                  variable names that are not recognized.
   */
  evaluateVariable: function( iName, iEvalContext) {

    // Check for a match with any global variables (e.g. sliders)
    var globalValue = DG.globalsController.findGlobalByName( iName);
    if( globalValue) {
      this.g[ iName] = true;  // add entry in map for dependency tracking
      return globalValue.get('value');
    }

    // If we don't match any variables we're in charge of,
    // let the base class have a crack at it.
    return arguments.callee.base.apply(this,arguments);
  }
  
 });


/* >>>>>>>>>> BEGIN source/formula/collection_formula_context.js */
// ==========================================================================
//                      DG.CollectionFormulaContext
//
//  Author:   Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('formula/global_formula_context');

/** @class DG.CollectionFormulaContext

  Derived class of DG.FormulaContext which supports references to collection
  attributes as well as global variables (through its DG.GlobalFormulaContext
  base class).

  @extends DG.GlobalFormulaContext
*/
DG.CollectionFormulaContext = DG.GlobalFormulaContext.extend((function() {

  return {

  /**
    Constant used when registering dependencies to indicate that all functions are affected.
    @type {String}
   */
  ALL_FUNCTIONS: '__ALL__',

  /**
    Properties of the formula owner for use by the dependency manager.
    Generally passed in by the client on construction.
    @type {object}
    @type {string}  .type - the type of the owner
    @type {string}  .id - the ID of the owner
    @type {string}  .name - the name of the owner
   */
  ownerSpec: null,

  /**
    The collection for which this CollectionFormulaContext provides bindings.
    Generally passed in by the client on construction.
    @property {DG.CollectionRecord}
   */
  collection: null,

  /**
    Cache of attribute functions which are referenced by the formula.
    @property {Object}  Map from attribute name {String} to ID {Number}
   */
  attrFns: null,

  /**
    Attribute reference counts for each collection.
    Needs to be tracked per aggregate function instance rather than per context.
    @property {Map of CollectionID:AttrReferenceCount pairs}
   */
  collectionAttrRefCounts: null,

  /**
    Cache of information for each aggregate function instance.
    @property {Array of Object}
   */
  aggFnInstances: null,

  /**
    Count of aggregate function instances assigned.
    Used to make sure that instance indices are assigned uniquely.
    @property {Number}
   */
  aggFnCount: 0,

  /**
    Provides access to the DependencyMgr for the data context.
    @property {DG.DependencyMgr}
   */
  dependencyMgr: function() {
    return this.getPath('collection.context.dependencyMgr');
  }.property(),

  /**
    Initialization method.
   */
  init: function() {
    arguments.callee.base.apply(this,arguments);

    // register formula-owning nodes on creation
    this.get('dependencyMgr').registerNode(this.get('ownerSpec'));

    // Initializes the caches
    this.clearCaches();
  },

  destroy: function() {
    this.get('dependencyMgr').removeNode(this.get('ownerSpec'));

    arguments.callee.base.apply(this,arguments);
  },

  /**
    Called when the parse/compilation changes.
    Clearing the caches prevents them from affecting the new compilation.
   */
  clearCaches: function() {
    this.attrFns = {};
    this.collectionAttrRefCounts = {};
    this.aggFnInstances = [];
    this.aggFnCount = 0;
  }.observes('collection'),

  /**
    Returns the case index for the give case ID.
    @param    {Number}    iCase -- The case being evaluated or its ID
    @returns  {Number}    The index of the case with the specified ID
   */
  getCaseIndex: function( iCase) {
    var caseID, collection;
    if (typeof iCase === 'object') {
      caseID = iCase.id;
      collection = iCase.collection;
    } else {
      caseID = iCase;
      collection = this.collection;
    }
    var map = collection && collection.caseIDToGroupedIndexMap;
    return map && (map[ caseID] + 1); // 1-based index
  },

  /**
    Returns the value of the specified attribute for the specified case.
    @param    {DG.Case}   iCase -- The case from which the value is to be retrieved
    @param    {Number}    iAttrID -- The ID of the attribute whose value is to be retrieved
    @returns  {Object}    Return value can be a Number, String, Boolean, error object, etc.
   */
  getAttrValue: function( iCase, iAttrID) {
    var tValue = iCase && iAttrID && iCase.getTypedValue( iAttrID);
    // Propagate errors via exceptions
    if( tValue instanceof Error) throw tValue;
    return tValue;
  },

  /**
    Returns the attribute in the data context/data set with the specified name.
    @param    {String}    iName -- The name of the attribute to find
    @returns  {DG.AttributeModel}
   */
  getAttributeByName: function( iName) {
    // check the current collection first
    var collection = this.get('collection'),
        attr = collection && collection.getAttributeByName(iName);
    if (attr) return attr;

    // if not in the current collection, check all collections
    var attrs = this.getPath('collection.context.dataSet.attrs'),
        attrCount = attrs && attrs.length,
        i;
    for (i = 0; i < attrCount; ++i) {
      attr = attrs[i];
      if (attr.get('name') === iName) {
        return attr;
      }
    }
    return null;
  },

  /**
    Returns the collection in which the specified attribute resides.
    @param    {DG.AttributeModel} -- the attribute to find
    @returns  {DG.CollectionModel}
   */
  getCollectionForAttribute: function( iAttribute) {
    // check the current collection first
    if (iAttribute.getPath('collection.id') === this.getPath('collection.id'))
      return this.get('collection');

    // if not in the current collection, check all collections
    var collections = this.getPath('collection.context.collections'),
        key = DG.ObjectMap.findKey(collections, function(iKey, iCollection) {
                return iCollection.getAttributeByName(iAttribute.get('name'));
              });
    return key && collections[key];
  },

  /**
    Returns an array of aggregate function indices representing the aggregate
    functions that are on the _functionContextStack at the moment.
    @returns {number[]}
   */
  getAggregateFunctionIndices: function() {
    var i, fnContext,
        fnContextLength = this._functionContextStack.length,
        aggFnIndices = [];
    for (i = 0; i < fnContextLength; ++i) {
      fnContext = this._functionContextStack[i];
      if (fnContext.isAggregate && (fnContext.aggFnIndex != null)) {
        aggFnIndices.push(fnContext.aggFnIndex);
      }
    }
    return aggFnIndices;
  },

  /**
    Called when the formula is about to be recompiled to clear any cached data.
   */
  willCompile: function() {
    arguments.callee.base.apply(this,arguments);

    // clear dependencies so they can be pruned after compilation
    this.get('dependencyMgr')._clearDependencies(this.get('ownerSpec'));
  },

  /**
    Called when the formula has been recompiled to clear any stale dependencies.
    Derived classes may override as appropriate.
   */
  completeCompile: function() {
    arguments.callee.base.apply(this,arguments);

    // prune (remove) prior dependencies that are no longer extant
    this.get('dependencyMgr')._pruneDependencies(this.get('ownerSpec'));
  },

  /**
    Called when a dependency is identified during compilation.
    @param {object}   iDependency
    @param {object}   .dependentSpec - the specs of the node that is dependant
    @param {string}     .type - the type of the node that is dependant
    @param {string}     .id - the id of the node that is dependant
    @param {string}     .name - the name of the node that is dependant
    @param {object}   .independentSpec - the specs of the node being depended upon
    @param {string}     .type - the type of the node being depended upon
    @param {string}     .id - the id of the node being depended upon
    @param {string}     .name - the name of the node being depended upon
    @param {number[]} .aggFnIndices - array of aggregate function indices
    @param {object}   .dependentContext - the formula context for the dependent node
   */
  registerDependency: function(iDependency) {
    var dependency = SC.clone(iDependency);
    if (!dependency.dependentSpec)
      dependency.dependentSpec = this.get('ownerSpec');
    DG.assert(dependency.independentSpec);
    if (!dependency.aggFnIndices) {
      dependency.aggFnIndices = this.getAggregateFunctionIndices();
    }
    else if (dependency.aggFnIndices === this.ALL_FUNCTIONS) {
      dependency.aggFnIndices = [];
      for (var i = 0; i < this.aggFnInstances.length; ++i) {
        dependency.aggFnIndices.push(i);
      }
    }
    if (!dependency.dependentContext)
      dependency.dependentContext = this;
    this.get('dependencyMgr').registerDependency(dependency);
  },

  /**
    Invalidation function for use with the dependency manager.
    Called by the dependency manager when invalidating nodes as a result
    of tracked dependencies.
    @param {object}     ioResult
    @param {object}     iDependent
    @param {object}     iDependency
    @param {DG.Case[]}  iCases - array of cases affected
                                 if no cases specified, all cases are affected
    @param {boolean}    iForceAggregate - treat the dependency as an aggregate dependency
   */
  invalidateDependent: function(ioResult, iDependent, iDependency, iCases, iForceAggregate) {
    var attributeID = iDependent && iDependent.id,
        attribute = attributeID && DG.Attribute.getAttributeByID(attributeID);

    // invalidate specific cases when there's a simple dependency
    if (attribute && !iForceAggregate && iDependency.simpleDependency) {
      attribute.invalidateCases(iCases);
      ioResult.simpleDependencies.push(iDependent);
    }
    // Invalidate all cases when there's an aggregate dependency
    // or if we're forcing all dependencies to be treated as aggregate.
    // The latter happens when we're processing simple dependencies among
    // aggregate function arguments.
    if (attribute && (iForceAggregate || iDependency.aggFnIndices.length)) {
      attribute.invalidateCases(null, iDependency.aggFnIndices);
      ioResult.aggregateDependencies.push(iDependent);
    }

    // If we're invalidating a lookup...() function as a result of an invalidation
    // cascade in the source context, start an invalidation cascade locally.
    var dependencyMgr = this.get('dependencyMgr');
    if (iDependency.srcDependencyMgr && (dependencyMgr !== iDependency.srcDependencyMgr)) {
      dependencyMgr.invalidateDependentsOf([iDependent]);
    }
  },

  /**
    Compiles a variable reference into the JavaScript code for accessing
    the appropriate value. For the CollectionFormulaContext, this means
    binding to 'caseIndex' and any collection attributes by name.
    @param    {String}    iName -- The variable name to be bound
    @returns  {String}    The JavaScript code for accessing the value
    @throws   {VarReferenceError} Base class throws VarReferenceError for
                                  variable names that are not recognized.
   */
  compileVariable: function( iName, iAggFnIndices) {
    // Client is responsible for putting '_id_' into the evaluation context.
    // This context's getCaseIndex() method provides the implementation,
    // which requires the caseIDToIndexMap, which is built on demand.
    if( iName === 'caseIndex') {
      // register the 'caseIndex' dependency for invalidation
      this.registerDependency({ independentSpec: {
                                  type: DG.DEP_TYPE_SPECIAL,
                                  id: 'caseIndex',
                                  name: 'caseIndex'
                                },
                                aggFnIndices: iAggFnIndices
                              });
      return 'c.getCaseIndex(e._case_)';
    }

    var attribute = this.getAttributeByName(iName),
        formulaCollection = this.get('collection'),
        collection = attribute && this.getCollectionForAttribute(attribute),
        collectionID = collection && collection.get('id');

    function isValidAttrReference() {
      // allow child attr references inside aggregate functions
      if (iAggFnIndices && iAggFnIndices.length) return true;
      if (collection && collection.isDescendantOf(formulaCollection))
        return false;
      // not one of our child collections, must be okay
      return true;
    }

    if( attribute) {
      // register the dependency for tracking/invalidation purposes
      this.registerDependency({ independentSpec: {
                                  type: DG.DEP_TYPE_ATTRIBUTE,
                                  id: attribute.get('id'),
                                  name: iName
                                },
                                aggFnIndices: iAggFnIndices
                              });

      // Having identified the attribute to be referenced, we attach a
      // function that can access the appropriate value, making use of
      // JavaScript variable scoping to make sure that the new function has
      // access to the local variable named 'attributeID'. We attach this
      // function to a map of referenced attributes in the context named 'attrFns'.
      // (This is code that is generated by the app for the express purpose
      // of machine consumption, so we use terse variable names for simplicity.)
      // The generated JavaScript code then executes the function dereferenced
      // from the context with code that looks something like
      // 'c.attrFns["attrName"](e)', where the case is passed in at
      // evaluation time.
      // Client is responsible for putting '_case_' into evaluation context.
      var attributeID = attribute.get('id');
      this.attrFns[ iName] = isValidAttrReference()
                              ? function(iEvalContext) {
                                  var tCase = iEvalContext._caseMap_
                                                ? iEvalContext._caseMap_[collectionID]
                                                : iEvalContext._case_,
                                      tValue = tCase && tCase.getTypedValue(attributeID);
                                  // Propagate error values immediately
                                  if( tValue instanceof Error) throw tValue;
                                  return tValue;
                                }
                              : function(iEvalContext) {
                                  throw new DG.HierReferenceError(iName);
                                };

      // Track the number of attribute references for each collection
      // This needs to be tracked per aggregate function instance so
      // that mean(weight)/mean(game) behaves appropriately.
      collectionID = collection.get('id');
      var refCount = this.collectionAttrRefCounts[ collectionID] || 0;
      this.collectionAttrRefCounts[ collectionID]  = refCount + 1;

      // The function built above captures the attribute ID at compile time,
      // but it must be evaluated multiple times for different cases. Thus,
      // the function takes a case reference, which the client is required
      // to have placed into the evaluation context.
      return 'c.attrFns["' + iName + '"](e)';
    }
    return arguments.callee.base.apply(this,arguments);
  },

  /**
    Direct evaluation of the expression without an intervening compilation.
    This is unlikely to be used for case attribute formulas, where the formula
    is generally evaluated enough times to make compilation to JavaScript
    worthwhile, but we support it for consistency and completeness.
    @param    {String}    iName -- The variable name to be bound
    @returns  {Object}    Return value can be a Number, String, Boolean, error object, etc.
    @throws   {VarReferenceError} Base class throws VarReferenceError for
                                  variable names that are not recognized.
   */
  evaluateVariable: function( iName, iEvalContext) {
    // Client is responsible for putting '_id_' into the evaluation context.
    // This context's getCaseIndex() method provides the implementation,
    // which requires the caseIDToIndexMap, which is built on demand.
    if( iName === 'caseIndex') return this.getCaseIndex( iEvalContext._id_);

    // Client is responsible for putting '_case_' into evaluation context.
    // This context's getAttrValue() method provides the implementation.
    var collection = this.get('collection'),
        attribute = collection && collection.getAttributeByName( iName),
        attributeID = attribute && attribute.get('id');
    if( attributeID) return this.getAttrValue( iEvalContext._case_, attributeID);

    return arguments.callee.base.apply(this,arguments);
  },

  /**
    Returns the collection whose cases should be iterated when evaluating
    a particular aggregate function instance; depends on the arguments of
    the aggregate functions involved. Currently computed formula-wide, but
    ultimately needs to be computed separately for each aggregate function
    depending on its arguments.
    @returns  {DG.CollectionClient}   The whose cases should be iterated
   */
  getCollectionToIterate: function() {
    var collections = this.getPath('collection.context.dataSet.collectionOrder'),
        collectionCount = collections.length,
        i, collection, collectionID;
    // loop from child collection to parent collections
    for (i = collectionCount - 1; i >= 0; --i) {
      collection = collections[i];
      collectionID = collection.get('id');
      if (this.collectionAttrRefCounts[collectionID])
        return collection;
    }
    return this.get('collection');
  },

  /**
    Returns true if this context's formula contains aggregate functions, false otherwise.
    @property {Boolean}
   */
  hasAggregates: function() {
    return this.aggFnCount > 0;
  }.property('aggFnCount'),

  /**
    Returns true if the specified function name refers to an aggregate function.
   */
  isAggregate: function( iName) {
    return DG.functionRegistry.isAggregate(iName);
  },

  /**
    Builds the array of argument expressions.
   */
  marshalArguments: function( iAggregateFn, iEvalContext, iInstance) {
    var i, argCount = iInstance.args.length,
        reqArgs = iAggregateFn.get('requiredArgs'),
        aggFnArgCount = Math.min(argCount, reqArgs.max),
        argCountWithFilter = aggFnArgCount + 1;
    iInstance.argFns = [];
    for( i = 0; i < aggFnArgCount; ++i) {
      iInstance.argFns.push( DG.FormulaContext.createContextFunction( iInstance.args[i]));
    }

    // if an extra argument was specified, assume it's a filter argument
    if (argCount >= argCountWithFilter)
      iInstance.filterFn = DG.FormulaContext.createContextFunction( iInstance.args[argCountWithFilter-1]);
  },

  validateArguments: function( iAggregateFn, iEvalContext, iInstance) {
    // Make sure we have a valid number of arguments
    var reqArgs = iAggregateFn.get('requiredArgs'),
        maxArgsWithFilter = reqArgs.max + 1,
        providedArgCount = iInstance.args.length,
        marshaledArgCount = iInstance.argFns.length;
    if( (marshaledArgCount < reqArgs.min) || (providedArgCount > maxArgsWithFilter))
      throw new DG.FuncArgsError( iInstance.name, { min: reqArgs.min, max: maxArgsWithFilter });
  },

  /**
    Evaluates the specified aggregate function (specified by internal index).
    Marshals the function arguments into evaluable form and dispatches to
    the appropriate aggregate function.

    @param    {Number}          iAggFnIndex -- The internal instance index.
    @returns  {Number|String|?} The result of the aggregate function evaluation
   */
  evalAggregate: function( iEvalContext, iAggFnIndex) {

    var instance = this.aggFnInstances[ iAggFnIndex];

    var aggregateFn = DG.functionRegistry.getAggregate(instance.name),
        result = aggregateFn && aggregateFn.queryCache( this, iEvalContext, instance);

    // Return the cached result if there is one
    if( result !== undefined)
      return result;

    // Marshal the arguments into individually callable functions.
    this.marshalArguments(aggregateFn, iEvalContext, instance);

    // Make sure we have a valid number of arguments
    this.validateArguments(aggregateFn, iEvalContext, instance);

    // Invoke the aggregate function with context and instance arguments
    result = aggregateFn.evaluate( this, iEvalContext, instance);

    return result;
  },

  /**
    Override base class function to include the aggregate function index
    in the function context so that individual aggregate function dependencies
    can be tracked.
    @param  {Object}  iFunctionContext - the function context for the current function
   */
  beginFunctionContext: function(iFunctionContext) {
    if (iFunctionContext.isAggregate) {
      iFunctionContext.aggFnIndex = this.aggFnCount;
    }
    arguments.callee.base.apply(this,arguments);
  },

  /**
    Invalidate the caches for the aggregate functions that correspond to the
    specified indices. This is called during while traversing the dependency
    graph when aggregate function dependents are encountered.
    @param  {Number[]}  iFunctionIndices - array of aggregate function indices
   */
  invalidateFunctions: function(iFunctionIndices) {
    if (iFunctionIndices) {
      iFunctionIndices.forEach(function(iAggFnIndex) {
        var instance = this.aggFnInstances && this.aggFnInstances[ iAggFnIndex];
        if (instance) {
          instance.caches = {};
          instance.results = {};
        }
      }.bind(this));
    }
  },

  /**
    Compiles a function reference into the JavaScript code for evaluating
    the appropriate function. For the base FormulaContext, this means
    binding to global functions such as ln(), log(), round(), etc. as well
    as the standard JavaScript Math functions (sin(), cos(), atan()), etc.
    This CollectionFormulaContext adds support for aggregate functions that
    compute over the attributes and cases of the collection.

    @param    {String}    iName -- The name of the function to be called.
    @param    {String[]}  iArgs -- array of arguments to the function
    @param    {Number[]}  iAggFnIndices -- array of aggregate function indices
                            indicating the aggregate function call stack, which
                            determines the aggregates that must be invalidated
                            when a dependent changes.
    @returns  {String}    The JavaScript code for calling the specified function
    @throws   {DG.FuncReferenceError} Throws DG.FuncReferenceError for function
                                      names that are not recognized.
   */
  compileFunction: function( iName, iArgs, iAggFnIndices) {

    // If this is an aggregate function reference, dispatch it as such.
    if( this.isAggregate( iName)) {

      // Some functions (e.g. count()) have an implicit dependency on 'caseIndex'
      var _fn = DG.functionRegistry.getAggregate(iName);
      if (_fn && _fn.isCaseIndexDependent(iArgs)) {
        // register the 'caseIndex' dependency for invalidation
        this.registerDependency({ independentSpec: {
                                    type: DG.DEP_TYPE_SPECIAL,
                                    id: 'caseIndex',
                                    name: 'caseIndex'
                                  },
                                  aggFnIndices: iAggFnIndices
                                });
      }

      // Internal aggregate function instances are identified by auto-generated index.
      // This way, mean(x)/mean(y) results in two separate instances.
      var aggFnIndex = this.aggFnCount++;

      // We push the name and arguments into the instance rather than marshaling
      // them into JavaScript text for the JavaScript interpreter.
      this.aggFnInstances.push({ index: aggFnIndex, name: iName, args: iArgs,
                                  aggFnIndices: iAggFnIndices });

      // The JavaScript code simply passes in the instance index.
      // At evaluation-time, evalAggregate() can extract the contents of the instance.
      return 'c.evalAggregate(e,' + aggFnIndex + ')';
    }

    // base class handles non-aggregate functions
    return arguments.callee.base.apply(this,arguments);
  }

  }; // end of closure return statement

}()));

/* >>>>>>>>>> BEGIN source/components/graph/adornments/plotted_function_model.js */
// ==========================================================================
//                      DG.PlottedFunctionModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('formula/collection_formula_context');
sc_require('components/graph/adornments/plot_adornment_model');

/** @class  The formula context used by the PlottedFunctionModel

 @extends DG.GlobalFormulaContext
 */
DG.PlottedFunctionContext = DG.CollectionFormulaContext.extend((function () {

  return {

    /**
     Set on construction: ['plottedValue' | 'plottedFunction']
     @type {string}
     */
    adornmentKey: null,

    /**
     Set on construction
     @type {DG.PlotModel}
     */
    plotModel: null,

    /**
     Utility function for identifying the name of the primary attribute.
     @returns  {String}  the name of the variable on the primary axis
     */
    primaryVarName: function () {
      var xVarID = this.getPath('plotModel.primaryVarID') || this.getPath('plotModel.xVarID'),
          xVarAttr = xVarID && DG.Attribute.getAttributeByID(xVarID),
          xVarName = xVarAttr && xVarAttr.get('name');
      return !SC.empty(xVarName) ? xVarName : null;
    }.property('plotModel'),

    /**
     Utility function for identifying the name of the X-axis attribute.
     @param    {String}    iName -- The name of the identifier being matched
     @returns  {Boolean}   True if the identifier matches the name of the
     x-axis attribute, false otherwise.
     */
    isPrimaryVarName: function (iName) {
      if (SC.empty(iName)) return false;
      if (iName === this.get('primaryVarName')) return true;
      if ((iName === 'x') && (this.get('adornmentKey') === 'plottedFunction')) return true;
      return false;
    }.property('primaryVarName'),

    /**
     Utility function for identifying the ID of the secondary/split attribute.
     @returns  {String}  the ID of the variable on the secondary axis
     */
    groupVarID: function () {
      // for plotted values/functions, we always want to override the default
      // grouping by collection; therefore, if we don't have a split attribute
      // we specify a non-falsy 'groupVarID' which will prevent the default
      // grouping but won't actually generate values that would split into groups.
      return this.getPath('plotModel.secondaryVarID') || -1;
    }.property('plotModel'),

    /**
     * Return true if the given case is currently among those being plotted.
     *
     * @param  {Object}              iEvalContext -- { _case_: , _id_: }
     * @return {boolean}
     */
    filterCase: function (iEvalContext) {
      var tResult = arguments.callee.base.apply(this,arguments),
          tCases = this.getPath('plotModel.enableMeasuresForSelection') ?
              this.getPath('plotModel.selection') : this.getPath('plotModel.cases');
      return tResult && tCases.indexOf(iEvalContext._case_) >= 0;
    },

    /**
     Compiles a variable reference into the JavaScript code for accessing
     the appropriate value. For the PlottedFunctionContext, this means
     binding to 'x' and any global values (e.g. sliders).
     @param    {String}    iName -- The variable name to be bound
     @returns  {String}    The JavaScript code for accessing the value
     @throws   {VarReferenceError} Base class throws VarReferenceError for
     variable names that are not recognized.
     */
    compileVariable: function (iName) {

      // Plotted functions can always refer to 'x' or the name of the attribute
      // on the x-axis, either of which correspond to the value of the x-axis
      // for the point being evaluated. For compilation purposes, we assume
      // that the value is passed in by the client as part
      // of the evaluation context.
      if (this.isPrimaryVarName(iName)) {
        if (this.get('adornmentKey') === 'plottedValue') {
          // let base class handle it by attribute name
          // cf. http://sproutcore-gyan.blogspot.com/2010/03/modify-argument-value-before-calling.html
          iName = this.get('primaryVarName');
        }
        else {
          return 'e.x';
        }
      }

      // If we don't match any variables we're in charge of,
      // let the base class have a crack at it.
      return arguments.callee.base.apply(this,arguments);
    },

    /**
     Called when the formula has been recompiled to clear any stale dependencies.
     Derived classes may override as appropriate.
     */
    didCompile: function () {
      arguments.callee.base.apply(this,arguments);

      // register the 'plot' dependency for invalidation
      var plotModel = this.get('plotModel'),
          // TODO: use a more robust ID
          plotID = DG.Debug.scObjectID(plotModel);
      this.registerDependency({
        independentSpec: {
          type: DG.DEP_TYPE_PLOT,
          id: plotID,
          name: 'plot-' + plotID
        },
        aggFnIndices: this.ALL_FUNCTIONS
      });
    },

    /**
     Direct evaluation of the expression without an intervening compilation.
     This is unlikely to be used for plotted funtions where the expression is
     generally evaluated enough times to make compilation to JavaScript
     worthwhile, but we support it for consistency and completeness.
     @param    {String}    iName -- The variable name to be bound
     @returns  {Number}            The value of the specified variable or global
     @throws   {VarReferenceError} Base class throws VarReferenceError for
     variable names that are not recognized.
     */
    evaluateVariable: function (iName, iEvalContext) {

      // Plotted functions can always refer to 'x' or the name of the attribute
      // on the x-axis, either of which correspond to the value of the x-axis
      // for the point being evaluated. For compilation purposes, we assume
      // that the value is passed in by the client as part
      // of the evaluation context.
      if (this.isPrimaryVarName(iName)) {
        if (this.get('adornmentKey') === 'plottedValue') {
          // let base class handle it by attribute name
          // cf. http://sproutcore-gyan.blogspot.com/2010/03/modify-argument-value-before-calling.html
          iName = this.get('primaryVarName');
        }
        else {
          return iEvalContext.x;
        }
      }

      // If we don't match any variables we're in charge of,
      // let the base class have a crack at it.
      return arguments.callee.base.apply(this,arguments);
    },

    /**
     Builds the array of argument expressions.
     */
    marshalArguments: function (iAggregateFn, iEvalContext, iInstance) {
      arguments.callee.base.apply(this,arguments);

      var reqArgs = iAggregateFn.get('requiredArgs'),
          argCount = iInstance.args.length;
      // if not enough arguments were specified, make a reference to the primary
      // univariate variable available, since some functions will use it
      if ((argCount < reqArgs.min) && (this.get('adornmentKey') === 'plottedValue')) {
        var uniVarName = this.get('primaryVarName'),
            uniVarExpr = uniVarName
                && this.compileVariable(uniVarName, iInstance.aggFnIndices);
        if (uniVarExpr)
          iInstance.argFns.unshift(DG.FormulaContext.createContextFunction(uniVarExpr));
      }
    },

    /**
     Called by the DependencyMgr to invalidate dependent nodes.
     @param {object}     ioResult
     @param {object}     iDependent
     @param {object}     iDependency
     @param {DG.Case[]}  iCases - array of cases affected
     if no cases specified, all cases are affected
     @param {boolean}    iForceAggregate - treat the dependency as an aggregate dependency
     */
    invalidateDependent: function (ioResult, iDependent, iDependency, iCases, iForceAggregate) {
      // invalidate affected aggregate functions
      if (iDependency.aggFnIndices)
        this.invalidateFunctions(iDependency.aggFnIndices);
      // Note that there is a redundancy between this notification, which indicates when
      // any dependent has changed, and the DG.GlobalFormulaContext sending of the same
      // notification when a global value changes. Ultimately, the GlobalFormulaContext
      // mechanism should be disabled, but we leave that for another day.
      this.notifyPropertyChange('dependentChange');
    }

  }; // return from function closure
}())); // function closure


/** @class  The model for a plotted function.

 @extends DG.PlotAdornmentModel
 */
DG.PlottedFunctionModel = DG.PlotAdornmentModel.extend(
    /** @scope DG.PlottedFunctionModel.prototype */
    {
      /**
       The algebraic expression to plot.
       @property {DG.Formula}
       */
      _expression: null,

      /**
       Computed property: Returns the source string for the expression.
       Intended to be used with .get('expression')/.set('expression') to
       get or set the string representation for the formula expression.

       For get('expression'):
       @returns  {String}    the formula string used for the expression

       For set('expression'):
       @param    {String}    iKey -- Passed by SproutCore (generall 'expression')
       @param    {String}    iValue -- The formula string to use for the expression
       @returns  {Object}    this -- so that methods can be chained
       */
      expression: function (iKey, iValue) {
        if (iValue !== undefined) {
          var tSiblings = this.get('siblingPlottedFunctions');
          if( tSiblings)
            tSiblings.forEach( function( iPlottedFunctionModel) {
              iPlottedFunctionModel.set('expression', iValue);
            });
          if (SC.empty(iValue))
            this._expression = null;
          else {
            if (SC.none(this._expression)) {
              this.createDGFormula(iValue);
            }
            else
              this._expression.set('source', iValue);
          }
          return this;  // for chaining
        }
        return (this._expression && this._expression.get('source')) || '';
      }.property(),

      /**
       * In the context of split plots, one plotted function drives the equations of all others
       * @property {[DG.PlottedFunctionModel]}
     */
      siblingPlottedFunctions: null,

      /**
       Destruction function.
       */
      destroy: function () {
        if (this._expression)
          this.destroyDGFormula();
        DG.PlottedFormulaEditContext.destroyFormulaEditContext( this.get('id'));
        arguments.callee.base.apply(this,arguments);
      },

      /**
       Utility function for creating the DG.Formula.
       */
      createDGFormula: function (iSource) {
        var adornmentKey = this.get('adornmentKey'),
            id = this.get('id'),
            owner = {type: adornmentKey, id: id, name: adornmentKey + id},
            context = DG.PlottedFunctionContext
                .create({
                  ownerSpec: owner,
                  adornmentKey: adornmentKey,
                  plotModel: this.get('plotModel'),
                  collection: this.get('primaryCollection')
                });
        this._expression = DG.Formula.create({context: context, source: iSource});
        this._expression.addObserver('dependentChange', this, 'dependentDidChange');
      },

      /**
       Utility function for destroying the DG.Formula.
       */
      destroyDGFormula: function () {
        this._expression.removeObserver('dependentChange', this, 'dependentDidChange');
        this._expression.destroy();
        this._expression = null;
      },

      /**
       Utility function to return the collection represented by the attribute on the
       "primary" axis (X for scatter plots, could be X or Y for univariate plots)
       */
      primaryCollection: function () {
        var attrID = this.getPath('plotModel.primaryVarID') || this.getPath('plotModel.xVarID'),
            attribute = attrID && DG.Attribute.getAttributeByID(attrID),
            collection = attribute && attribute.get('collection');
        return collection;
      }.property('plotModel'),

      /**
       Utility function to return the split axis, i.e. the categorical attribute
       on the secondary axis, if any.
       */
      splitAxisModel: function () {
        if (!this.getPath('plotModel.yAxis.isNumeric'))
          return this.getPath('plotModel.yAxis');
        if (!this.getPath('plotModel.xAxis.isNumeric'))
          return this.getPath('plotModel.xAxis');
        return null;
      }.property('plotModel'),

      /**
       Observer function called when the formula indicates that
       a dependent has changed. This method merely propagates the
       notification to clients.
       */
      dependentDidChange: function (iNotifier, iKey) {
        this.notifyPropertyChange(iKey);
      },

      /**
       Observer function which invalidates the intermediate compile results
       for the formula when global value names are added, removed, or changed.
       These changes can affect the bindings of the formula, so a recompilation
       is required when they occur.
       */
      globalNamesDidChange: function () {
        // Name changes require recompilation
        this.invalidateExpression();
      }.observes('DG.globalsController.globalNameChanges'),

      /**
       Recompilation will force us to pay attention to changed cases
       */
      enableMeasuresForSelectionDidChange: function () {
        // Requires recompilation
        this.invalidateExpression();
      }.observes('enableMeasuresForSelection'),

      /**
       Invalidate the expression so it gets recompiled/evaluated.
       */
      invalidateExpression: function () {
        if (this._expression)
          this._expression.invalidate();
      },

      /**
       Evaluates the plotted function at the specified x value.
       @param    {Object}            The set of values available to the expression the expression
       @returns  {Number|undefined}  The evaluated result
       */
      evaluate: function (iEvalContext) {
        if (!this._expression) return;

        // Note that this will propagate any exceptions thrown.
        return this._expression.evaluate(iEvalContext);
      },

      /**
       * @return { Object }
       */
      createStorage: function () {
        var storage = arguments.callee.base.apply(this,arguments);

        storage.adornmentKey = this.get('adornmentKey');
        storage.expression = this.get('expression');

        return storage;
      },

      /**
       * @param { Object }
       */
      restoreStorage: function (iStorage) {
        arguments.callee.base.apply(this,arguments);
        this.set('adornmentKey', iStorage.adornmentKey);
        this.set('expression', iStorage.expression);
      }

    });

DG.PlotAdornmentModel.registry.plottedValue = DG.PlottedFunctionModel;
DG.PlotAdornmentModel.registry.plottedFunction = DG.PlottedFunctionModel;

/* >>>>>>>>>> BEGIN source/components/graph/adornments/plotted_value_adornment.js */
// ==========================================================================
//                      DG.PlottedValueAdornment
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/adornments/plot_adornment');
sc_require('components/graph/adornments/line_label_mixin');

/** @class  Plots a computed value.

  @extends DG.PlotAdornment
*/
DG.PlottedValueAdornment = DG.PlotAdornment.extend( DG.LineLabelMixin,
/** @scope DG.PlottedValueAdornment.prototype */
{
  statisticsKey: 'plottedValue',
  lastHoverValue: null,

  /**
    @property { DG.CellLinearAxisView }
  */
  valueAxisView: function() {
    return this.getPath('parentView.primaryAxisView');
  }.property(),

  /**
    @property { DG.CellAxisView }
  */
  splitAxisView: function() {
    return this.getPath('parentView.secondaryAxisView');
  }.property(),

  valueTextElement: null,

  /**
    The value is drawn as a line segement.
    @property [{Object}]
  */
  valueSegments: null,

  /**
    @property { Number }
  */
  values: function() {
    var splitAxisModel = this.get('splitAxisModel'),
        values = [];
    if (splitAxisModel && splitAxisModel.forEachCellDo) {
      splitAxisModel.forEachCellDo(function(iIndex, iName) {
        values.push(this.getValueToPlot(iName));
      }.bind(this));
    }
    else {
      values.push(this.getValueToPlot());
    }
    return values;
  }.property(),

  /**
    The returned string should have a reasonable number of significant digits for the
      circumstances.
    @property { String read only }
  */
  valueStrings: function() {
    var tValues = this.get('values');

    if( tValues instanceof Error)
      return tValues.message;

    var tDigits = DG.PlotUtilities.findFractionDigitsForAxis( this.get('valueAxisView')),
        tNumFormat = DG.Format.number().fractionDigits( 0, tDigits);
    return tValues.map(function(iValue) {
      if( iValue < 2500)
        tNumFormat.group('');
      else
        tNumFormat.group( ',');
      return DG.isFinite(iValue) ? tNumFormat(iValue) : (iValue != null ? iValue.toString() : null);
    });
  }.property('values'),

  /**
    Concatenated array of ['PropertyName','ObserverMethod'] pairs used for indicating
    which observers to add/remove from the model.

    @property   {Array of [{String},{String}]}  Elements are ['PropertyName','ObserverMethod']
   */
  modelPropertiesToObserve: [ ['expression', 'updateToModel'], ['dependentChange', 'updateToModel'] ],

  splitAxisModel: function() {
    return this.getPath('model.splitAxisModel');
  }.property(),

  init: function() {
    arguments.callee.base.apply(this,arguments);

    this.valueSegments = [];
    this.myElements = [];
  },

  /**
   * valueSegments will contain an array of { valueSegment, background, textElement }
  */
  createElements: function( iNumCells) {
    var this_ = this;
    if( this.valueSegments.length === iNumCells)
      return; // already the right number

    function createSegment() {
      var tSegment = tPaper.path('')
          .addClass('dg-plotted-value');
      return tSegment;
    }

    function createTextElement() {
      var tText = tPaper.text( 0, 0, '')
          .attr({ 'text-anchor': 'start', opacity: 1 })
          .hide()
          .addClass('dg-graph-adornment');
      return tText;
    }

    function createBackground() {
      var tBackgrnd = tPaper.path('')
          .addClass('dg-plotted-value-background');
      return tBackgrnd;
    }

    function createCover( iCellNum) {
      var tHoverWidth = 5;        /** width of invisible 'cover' line that has popup text */

      function overScope() {
        var tHoverColor = "rgba(0, 255, 0, 0.2)",
            tHoverDelay = 10,
            tAttributes = { stroke: tHoverColor },
            tValueElement = this_.valueTextElement,
            tValueText = this_.get('valueStrings')[ iCellNum],
            tSegmentBox = this.getBBox();
        this.stop();
        this.animate( tAttributes, tHoverDelay );

        tValueElement.attr('text', tValueText);
        if( tSegmentBox.y === tSegmentBox.y2) { // horizontal segment
          tValueElement.attr( { x: tSegmentBox.x2 - 5, y: tSegmentBox.y - 6, 'text-anchor': 'end'});
        }
        else {
          tValueElement.attr( { x: tSegmentBox.x + 3, y: tSegmentBox.y + 6, 'text-anchor': 'start'});
        }
        tValueElement.show();

        // Log this hover provided it wasn't the last hover
        if( tValueText !== this_.lastHoverValue) {
          this_.updateHoverLog( this_.statisticsKey+"=" + tValueText );
          this_.lastHoverValue = tValueText;
        }
      }

      function outScope() {
        var tAttributes = { stroke: DG.RenderingUtilities.kTransparent };
        this.stop();
        this.animate( tAttributes, DG.PlotUtilities.kHighlightHideTime );
        this_.valueTextElement.hide();
      }

      var tCover = tPaper.path('M0,0')
          .attr({ 'stroke-width':tHoverWidth, stroke:DG.RenderingUtilities.kTransparent })
          .hover( overScope, outScope);
      return tCover;
    }

    var tLayerManager = this.getPath('paperSource.layerManager'),
        tLayer = this.get('layer'),
        tPaper = this.get('paper'),
        tValueSegments = this.get('valueSegments');
    if( !this.valueTextElement) {
      this.valueTextElement = createTextElement();
    }
    while( tValueSegments.length < iNumCells) {
      var tValueSegment = {
        background: createBackground(),
        valueSegment: createSegment(),
        cover: createCover(tValueSegments.length)
      };
      tValueSegments.push( tValueSegment);
      DG.ObjectMap.forEach( tValueSegment, function( iKey, iElement) {
        this.myElements.push( iElement);
        tLayer.push( iElement);
      }.bind(this));
    }

    while( tValueSegments.length > iNumCells) {
      var tSegmentToRemove = tValueSegments.pop();
      DG.ObjectMap.forEach( tSegmentToRemove, function( iKey, iElement) {
        tLayerManager.removeElement( iElement, true /* callRemove */);
        iElement.remove();
      });
    }
  },

  /**

  */
  updateToModel: function() {
    if (this.getPath('model.isVisible')) {

      var tSplitAxisModel = this.get('splitAxisModel'), // categorical axis if any
          tNumCells = tSplitAxisModel ? tSplitAxisModel.get('numberOfCells') : 1,
          tValueAxisView = this.get('valueAxisView'),
          tSplitAxisView = this.get('splitAxisView');

      if (!(tValueAxisView && tSplitAxisView))
        return;   // happens when the plot is going awayu

      this.createElements(tNumCells);  // if needed

      var tCellWidth = tSplitAxisView.get('fullCellWidth'),
          tPaper = this.get('paper'),
          tPlottedValues = this.get('values');
      for (var tIndex = 0; tIndex < tNumCells; tIndex++) {
        var tPlottedValue = tPlottedValues && tPlottedValues[tIndex],
            tValueSegment = this.get('valueSegments')[tIndex].valueSegment,
            tBackground = this.get('valueSegments')[tIndex].background,
            tCover = this.get('valueSegments')[tIndex].cover,
            tCoord, tPt1, tPt2;

        if (DG.isFinite(tPlottedValue)) {
          tCoord = tValueAxisView.dataToCoordinate(tPlottedValue);
          if (tValueAxisView.get('orientation') === DG.GraphTypes.EOrientation.kHorizontal) {
            tPt1 = {x: tCoord, y: tPaper.height - tIndex * tCellWidth};
            tPt2 = {x: tCoord, y: tPaper.height - (tIndex + 1) * tCellWidth};
          }
          else {
            tPt1 = {x: tIndex * tCellWidth, y: tCoord};
            tPt2 = {x: (tIndex + 1) * tCellWidth, y: tCoord};
          }
          DG.RenderingUtilities.updateLine(tValueSegment, tPt1, tPt2);
          DG.RenderingUtilities.updateLine(tCover, tPt1, tPt2);
          DG.RenderingUtilities.updateLine(tBackground, tPt1, tPt2);
        }
        else {
          tValueSegment.attr({path: ''});
          tCover.attr({path: ''});
          tBackground.attr({path: ''});
        }
      }
    }
  }.observes('DG.globalsController.globalNameChanges'),

  valueAxisAttrDidChange: function() {
    var tModel = this.get('model');
    if( tModel) {
      this.get('model').invalidateExpression();
    }
  }.observes('*valueAxisView.model.firstAttributeName'),

  /**

  */
  getValueToPlot: function(iGroup) {
    var model = this.get('model'),
        evalContext = iGroup ? { _groupID_: iGroup } : {},
        tPlottedValue = NaN;

    try {
      if( model)
        tPlottedValue = model.evaluate(evalContext);
    }
    catch(e) {
      // Propagate errors to return value
      tPlottedValue = e;
    }

    return tPlottedValue;
  },

  /**
   * Create a user log of the the hover over the average line, but remove duplicates
   * @param logString
   */
  updateHoverLog: function( logString ) {
    DG.logUser("%@: %@", "hoverOverPlottedValue", logString );
  }

});

DG.PlottedValueAdornment.createFormulaEditView = function(iPlottedValue) {
  var formulaEditContext = DG.PlottedFormulaEditContext.getFormulaEditContext(iPlottedValue);
  return formulaEditContext.createFormulaView({
                              attrNamePrompt: 'DG.PlottedValue.namePrompt',
                              formulaPrompt: 'DG.PlottedValue.formulaPrompt',
                              formulaHint: 'DG.PlottedValue.formulaHint',
                              commandName: 'graph.editPlottedValue',
                              undoString: 'DG.Undo.graph.changePlotValue',
                              redoString: 'DG.Redo.graph.changePlotValue',
                              logMessage: 'Change plotted value: "%@1" to "%@2"'
                            });
};

/* >>>>>>>>>> BEGIN source/components/graph/adornments/point_data_tip.js */
// ==========================================================================
//                            DG.PointDataTip
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/adornments/data_tip');

/** @class DG.PointDataTip A simple adornment-like class that displays and updates a data tip that shows when the
 *    user hovers over a point.

 @extends DG.DataTip
 */
DG.PointDataTip = DG.DataTip.extend(
    /** @scope DG.PointDataTip.prototype */
    {
      /**
       * The index of the case whose values are being displayed
       * @property { Integer }
       */
      caseIndex: null,

      /**
       * If true, we only show the value of the legend attribute, if any
       * @property{Boolean}
       */
      showOnlyLegendData: false,

      getDataTipText: function () {

        var this_ = this,
            tPlot = this.getPath('plotLayer.model'),  // Use of plotBinding doesn't work the first time
            tCases = tPlot && tPlot.get('cases'),
            tCase = tCases ? tCases.unorderedAt(this.get('caseIndex')) : null;

        function getNameValuePair(iKey) {
          var digitsForLegend = function() {
            return DG.PlotUtilities.findFractionDigitsForRange(tAttrDesc.getPath('attributeStats.minMax'));
            },
          digitsForAxis = function() {
            return DG.PlotUtilities.findFractionDigitsForAxis(this_.getPath('plotLayer.' + iKey + 'AxisView'));
            };

          var tAttrDesc = tPlot.getPath('dataConfiguration.' + iKey + 'AttributeDescription'),
              tAttributes = tAttrDesc && tAttrDesc.get('attributes'),
              tPlotIndex = this_.getPath('plotLayer.plotIndex');
          if(!tAttrDesc)
            return null;
          // If there are more than 1 attribute, we'll end up using the plot index to pull out the right one
          // This only works because we only allow multiple attributes on the y-place.
          tPlotIndex = (tPlotIndex < tAttributes.length) ? tPlotIndex : 0;
          var tAttr = tAttributes[tPlotIndex],
              tType = (typeof(tAttr) === 'object') ? tAttr.get('type') : null,
              tAttrID = (typeof(tAttr) === 'object') ? tAttr.get('id') : null,
              tDigitsFunc = (iKey === 'legend') ? digitsForLegend : digitsForAxis,
                  tName, tValue;
          if (!SC.none(tAttrID) && tType !== 'qualitative') {
            tName = tAttr.get('name');
            tValue = DG.PlotUtilities.getFormattedCaseValue( tCase, tAttrDesc, tDigitsFunc, tPlotIndex);
            return tName + ': ' + tValue;
          }
          return null;
        }

        function appendPair( iPair) {
          // Only append if not already present
          if (!SC.none(iPair) && tTipText.indexOf(iPair) < 0) {
            if (tTipText.length > 0)
              tTipText += '\n';
            tTipText += iPair;
          }
        }

        if (SC.none(tCase))
          return '';

        var tLegendPair = getNameValuePair('legend'),
            tCaptionPair = getNameValuePair('caption'),
            tTipText = '';

        if( !this.get('showOnlyLegendData')) {
          var tXPair = getNameValuePair('x'),
              tYKey = this.getPath('plotLayer.isUsingY2') ? 'y2' : 'y',
              tYPair = getNameValuePair(tYKey);
          appendPair( tXPair);
          appendPair( tYPair);
        }
        appendPair( tCaptionPair);
        appendPair( tLegendPair);
        return tTipText;
      },

      /**
       *  We set the tip origin and the case index before calling arguments.callee.base.apply(this,arguments)
       */
      show: function (iX, iY, iR, iIndex) {
        this.set('tipOrigin', {x: iX, y: iY});
        this.set('tipSourceRadius', iR );
        this.set('caseIndex', iIndex);

        arguments.callee.base.apply(this,arguments);
      },

//  hide: function() {
//    var tLayer = this.get('layer');
//    if( tLayer)
//      tLayer.clear();
//  },
//
      handleChanges: function (iChanges) {
        // iChanges can be a single index or an array of indices
        var tChanges = (SC.typeOf(iChanges) === SC.T_NUMBER ? SC.IndexSet.create(iChanges) : iChanges);
        tChanges = tChanges || [];
        if (!tChanges.contains(this.get('caseIndex')))
          return;

        this.updateTip();
      }

    });


/* >>>>>>>>>> BEGIN source/components/graph/axes/axis_coordinator.js */
// ==========================================================================
//                          DG.AxisCoordinator
//
//  Author:   William Finzer
//
//  Copyright (c) 2019 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class  When a graph is split, this object keeps numeric axis scales in synch.

  @extends SC.Object
*/
DG.AxisCoordinator = SC.Object.extend(
/** @scope DG.AxisCoordinator.prototype */ 
{
  /**
   * Owned by the graph model.
   * @property {[DG.AxisModel] }
   */
  xAxisArray: null,

  /**
   * Owned by the graph model.
   * @property {[DG.AxisModel] }
   */
  yAxisArray: null,

  /**
   * Owned by the graph model.
   * @property {[DG.AxisModel] }
   */
  y2AxisArray: null,

  _handlingChange: false,

  init: function() {
    this.xAxisArray = [];
    this.yAxisArray = [];
    this.y2AxisArray = [];
  },

  destroy: function() {

    this.xAxisArray.forEach( this.removeAxisObservers);
    this.yAxisArray.forEach( this.removeAxisObservers);
    this.yAxisArray.forEach( this.removeAxisObservers);

    this.xAxisArray = [];
    this.yAxisArray = [];
    this.y2AxisArray = [];
  },

  removeAxisObservers: function( iAxis) {
    if( iAxis) {
      iAxis.removeObserver( 'lowerBound', this, this.boundChanged);
      iAxis.removeObserver( 'upperBound', this, this.boundChanged);
    }
  },

  setAxis: function( iKey, iIndex, iAxis) {
    var tAxisArray = this.get(iKey + 'AxisArray');
    this.removeAxisObservers( tAxisArray[iIndex]);
    iAxis.addObserver( 'lowerBound', this, this.boundChanged, iKey);
    iAxis.addObserver( 'upperBound', this, this.boundChanged, iKey);
    tAxisArray[iIndex] = iAxis;
  },

  boundChanged: function( iAxis, iKey, iValue, iAxisKey) {
    if( this._handlingChange)
      return;

    var tArray = this.get( iAxisKey + 'AxisArray'),
        tValue = iAxis.get( iKey);
    this._handlingChange = true;
    tArray.forEach( function( oneAxis) {
      if( iAxis !== oneAxis)
        oneAxis.set( iKey, tValue);
    });
    this._handlingChange = false;
  }

});


/* >>>>>>>>>> BEGIN source/components/graph/utilities/graph_drop_target.js */
// ==========================================================================
//                          DG.GraphDropTarget
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class  Mixin to define behavior of graph subviews on drag

*/
DG.GraphDropTarget =
{
  kDropFrameClass: 'dg-graph-drop-frame',

  /**
   * Return the key to a localizable string to be displayed when the target has no current attribute
   */
  blankDropHint: '',

  // SC.DropTarget protocol
  isDropTarget: true,

  /**
   Graph controller observes this property to detect that a drag has taken place.
   @property{{collection:{DG.CollectionRecord}, attribute:{DG.Attribute}, text:{String},
   axisOrientation:{String} }}
   */
  dragData:null,

  getDataConfiguration: function() {
    return this.get('dataConfiguration') || this.getPath('model.dataConfiguration') ||
        this.getPath('graphModel.dataConfiguration');
  },

  /**
   * Override SC.View for CODAP drop targets.
   * [CODAP fix] When the CODAP div is not at (0, 0) and when the page is scrolled,
   * the default Sproutcore mechanism for computing position does not give the desired
   * frame origin. This comes up when CODAP is used in embedded mode as in the ZiSci project.
   * Our fix is to use the jQuery 'offset' method to determine the offset regardless of positioning
   * and scrolling of CODAP div.
   *
   * Note that we are forgoing computation of possible scaling, which Sproutcore does do.
   * @override View.convertFrameToView
   */
  convertFrameToView: function (frame, targetView) {
    var tOffset = $(this.containerLayer()).offset();
    return { x: tOffset.left - window.pageXOffset, y: tOffset.top - window.pageYOffset, width: frame.width, height: frame.height };
  },

  computeDragOperations: function( iDrag) {
    if( this.isValidAttribute( iDrag))
      return SC.DRAG_LINK;
    else
      return SC.DRAG_NONE;
  },

  dragEntered: function( iDragObject, iEvent) {
    this.borderFrame.addClass('dg-graph-drop-frame-fill');
    this.showDropHint( {x: iEvent.clientX, y: iEvent.clientY});
  },

  dragExited: function( iDragObject, iEvent) {
    this.borderFrame.removeClass('dg-graph-drop-frame-fill');
    this.hideDropHint();
  },

  acceptDragOperation: function() {
    return YES;
  },

  isValidAttributeForPlotSplit: function( iDrag) {
    var tDragAttr = iDrag.data.attribute,
        tCurrAtt = this.get('plottedAttribute'),
        tDataConfiguration = this.getDataConfiguration(),
        tDragAttrIsNominal = tDataConfiguration.attributeIsNominal(tDragAttr),
        tConfigurationHasAtLeastOneAttribute = tDataConfiguration &&
            tDataConfiguration.hasAtLeastOneAttributeAssigned(),
        tValidForPlotSplit = tDragAttrIsNominal && tConfigurationHasAtLeastOneAttribute &&
            tDragAttr !== tCurrAtt;
    return tValidForPlotSplit;
  },

  isValidAttribute: function( iDrag) {
    var tDragAttr = iDrag.data.attribute,
        tCurrAttr = this.get('plottedAttribute');
    return SC.none( tCurrAttr) || (tCurrAttr !== tDragAttr);
  },

  /**
   * Draw an orange frame to show we're a drop target.
   * Set the dropHintString for later display on dragEntered
   * @param iDrag {Object}
   */
  dragStarted: function( iDrag) {
    var tPaper = this.get('paper' );
    if (!tPaper) return;

    var kWidth = 3,
        tFrame,
        tDraggedName = iDrag.data.attribute.get('name'),
        tAttrName = this.getPath('plottedAttribute.name'),
        tOrientation = this.get('orientation'),
        tDataConfiguration = this.getDataConfiguration(),
        tDropHint;

    function isEmpty( iString) {
      return SC.empty( iString) || iString === 'undefined';
    }

    if( this.isValidAttribute( iDrag)) {
      if (tOrientation === DG.GraphTypes.EOrientation.kVertical2) {
        this.set('isVisible', true);
        var tParentView = this.get('parentView');
        if (tParentView)
          tParentView.makeSubviewFrontmost(this);
      }
      if(tDataConfiguration.attributeIsNominal(iDrag.data.attribute) && tOrientation !== DG.GraphTypes.EOrientation.kNone) {
        if(tOrientation === DG.GraphTypes.EOrientation.kVertical || tOrientation === DG.GraphTypes.EOrientation.kVertical2)
          tDropHint = 'DG.GraphView.layoutPlotsVertically'.loc(tDraggedName);
        else tDropHint = 'DG.GraphView.layoutPlotsSideBySide'.loc(tDraggedName);
      }
      else {
        tDropHint = (isEmpty(tAttrName) ? this.get('blankDropHint').loc(tDraggedName) :
            'DG.GraphView.replaceAttribute'.loc(tAttrName, tDraggedName));
      }

      tFrame = {
        x: kWidth, y: kWidth,
        width: tPaper.width - 2 * kWidth,
        height: tPaper.height - 2 * kWidth
      };

      if (this.get('isVertical')) {
        tFrame.y += 18 + 2 * kWidth;
        tFrame.height -= 18 + 2 * kWidth;
      }

      if (SC.none(this.borderFrame)) {
        this.borderFrame = tPaper.path('')
            .addClass(this.kDropFrameClass);
      }
      this.borderFrame.attr({path: DG.RenderingUtilities.pathForFrame(tFrame)})
          .show();

      this.set('dropHintString', tDropHint);
    }
  },

  dragEnded: function() {
    if( this.borderFrame)
      this.borderFrame.hide();
  },

  /**
  @property{Raphael element}
  */
  borderFrame: null,

  /**
   * @property {String} - Display when dragged attribute is over this target
   */
  dropHintString: null,

  isVertical: function() {
    var tOrientation = this.get('orientation');
    return tOrientation &&
        [DG.GraphTypes.EOrientation.kVertical, DG.GraphTypes.EOrientation.kVertical2, DG.GraphTypes.EOrientation.kRight].indexOf( tOrientation) >= 0;
  }.property(),

  showDropHint: function( iWindowLoc) {
    if( SC.empty( this.dropHintString))
      return;
    iWindowLoc.y +=10;  // Get below the mouse
    DG.mainPage.getPath('mainPane.tipView').show(iWindowLoc, this.dropHintString);
  },

  hideDropHint: function() {
    DG.mainPage.getPath('mainPane.tipView').hide();
  },

  /**
   Attempt to assign the given attribute to this axis.
   @param {SC.Drag} 'data' property contains 'collection', 'attribute', 'text' properties
   @param {SC.DRAG_LINK}
     */
  performDragOperation:function ( iDragObject, iDragOp ) {
    this.hideDropHint();
    this.set( 'dragData', iDragObject.data );
    return SC.DRAG_LINK;
  },

  /**
   * These methods -- externalDragDidChange, dataDragEntered, dataDragHovered,
   * dataDragDropped, and dataDragExited -- support drags initiated outside
   * the page, specifically drags from plugins.
   */
  _externalDragObject: function () {
    var data = DG.mainPage.getPath('mainPane.dragAttributeData');
    if (data) {
      return {
        data: data
      };
    }
  }.property(),
  externalDragDidChange: function () {
    var tDrag = this.get('_externalDragObject');
    if (!tDrag) {
      return;
    }
    if (DG.mainPage.getPath('mainPane._isDraggingAttr')) {
      this.dragStarted(tDrag);
    } else {
      this.dragEnded();
    }
  }.observes('DG.mainPage.mainPane._isDraggingAttr'),

  dataDragEntered: function (iEvent) {
    var externalDragObject = this.get('_externalDragObject');
    if (externalDragObject && this.isValidAttribute(externalDragObject)) {
      this.dragEntered(externalDragObject, iEvent);
      iEvent.preventDefault();
    }
  },
  dataDragHovered: function (iEvent) {
    var externalDragObject = this.get('_externalDragObject');
    if (externalDragObject && this.isValidAttribute(externalDragObject)) {
      iEvent.dataTransfer.dropEffect = 'copy';
      iEvent.preventDefault();
      iEvent.stopPropagation();
    } else {
      return false;
    }
  },
  dataDragDropped: function(iEvent) {
    var externalDragObject = this.get('_externalDragObject');
    var data;
    if (externalDragObject && this.isValidAttribute(externalDragObject)) {
      data = DG.mainPage.getPath('mainPane.dragAttributeData');
      this.hideDropHint();
      this.set('dragData', data);
      iEvent.preventDefault();
    } else {
      return false;
    }
  },
  dataDragExited: function (iEvent) {
    var externalDragObject = this.get('_externalDragObject');
    if (externalDragObject && this.isValidAttribute(externalDragObject)) {
      this.dragExited(externalDragObject, iEvent);
      iEvent.preventDefault();
    }
  }
};


/* >>>>>>>>>> BEGIN source/utilities/rendering_utilities.js */
// ==========================================================================
//                          DG.RenderingUtilities
//
//  A collection of utilities for working with svg
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('libraries/raphael');

DG.RenderingUtilities = {

  /* jshint -W064 */  // Missing 'new' prefix when invoking a constructor. (W064)
  _blankCanvas: Raphael(-500, 0, 500, 500),
  /* jshint +W064 */
  
  kTransparent: "rgba(255, 255, 255, 0)",
  kSeeThrough: "rgba(255, 255, 255, 0.001)",  // Still receives mouse events
  kCaptionFontHeight: 20,
  kDefaultFontHeight: 12,

  /**
  Use getBBox unless this fails, in which case use an estimate based on the given default height.
    @param {Raphael element} must be text
    @return {Point as in {width, height} } in pixels
  */
  getExtentForTextElement: function( iTextElement, iDefaultHeight, iWithoutTransform) {
    var tTextBox = iTextElement.getBBox( iWithoutTransform),
    // Browsers can fill with zeroes or NaNs if they can't do measurement. Because NaN is "falsy" the following works
    tTextHeight = (tTextBox && tTextBox.height) || iDefaultHeight,
    tTextWidth = tTextBox ?tTextBox.width : 0;
    // Sometimes tTextHeight and tTextWidth come out 0. Draw offscreen.
    if( !tTextWidth) {
      var tExtent = this.textExtent(iTextElement.attr('text'), iTextElement.attr('font-family'),
                                    iTextElement.attr('font-size'));
      tTextWidth = tExtent.x;
      tTextHeight = tExtent.y;
    }
    return { width: tTextWidth, height: tTextHeight };
  },

  /**
  How many pixels long will the text be when rendered on the given canvas?
   Note: The result is an estimate based on the assumption that the average character width
          is 6 pixels and height is 9 pixels. Attempts to actually get a computation of extent that
          makes use of the canvas have failed.
        We ignore the canvas for now because we haven't been able to figure out how to get a reliable
        text extent using it.
    @param {R} a Raphael canvas
    @param {String} the string to be rendered
    @return {Point as in {x, y} } length of the string in pixels
  */
  textExtentOnCanvas: function( iCanvas, iText, iFontFamily, iFontSize) {
    var tText = iCanvas.text( -500, -5000, iText)
            .attr({'font-family': iFontFamily, 'font-size': iFontSize}),
      tBox = tText.getBBox(),
      tExtent = { x: tBox.width, y: tBox.height };
    tText.remove();
    return tExtent;
  },

  /**
  How many pixels long will the text be when rendered on the _blankCanvas?
   @param {String} the string to be rendered
    @return {Point as in {x, y} } length of the string in pixels
  */
  textExtent: function( iText, iFontFamily, iFontSize) {
    return this.textExtentOnCanvas( this._blankCanvas, iText, iFontFamily, iFontSize);
  },

  /**
   * Fit the given text element within the given space and, if the whole string does not fit, append ellipsis
   * @param iTextElement {Raphael Element}
   * @param iDesiredExtent {Number} space in pixels
   */
  elideToFit: function( iTextElement, iDesiredExtent) {
    var tStringToFit = iTextElement.attr('text'),
        tNumChars = tStringToFit.length,
        tExtra = 0,
        tCounter = 0,
        tWidth;
    do {
      tWidth = this.getExtentForTextElement(iTextElement, DG.RenderingUtilities.kDefaultFontHeight, true).width;
      if (tWidth > iDesiredExtent) {
        var tNewNumChars = Math.floor((iDesiredExtent / tWidth) * tNumChars) - tExtra;
        tStringToFit = iTextElement.attr('text').substring(0, tNewNumChars) + '…';
        tNumChars = tStringToFit.length;
        tExtra++;
      }
      iTextElement.attr('text', tStringToFit);
      tCounter++; // Prevent unexpected failure to exit
    }
    while ( tWidth > iDesiredExtent && tCounter < 10);
  },

  /**
    @param {element} a Raphael line
    @param {Point} start
    @param {Point} stop
  */
  updateLine: function( iLine, iStart, iStop) {
//    iLine.attr( { x1: iStart.x, y1: iStart.y, x2: iStop.x, y2: iStop.y });
    iLine.attr( { path: "M" + iStart.x + " " + iStart.y + " L" +
                  iStop.x + " " + iStop.y });
  },

  /**
    // Return a string that defines a path for the given rectangle.
    @param {{ x:{Number}, y:{Number}, width:{Number}, height:{Number}}}
    @return {String} SVG path string
  */
  pathForFrame: function( iFrame) {
    return 'M' + iFrame.x + ' ' + iFrame.y + 
        ' L' + (iFrame.x + iFrame.width) + ' ' + iFrame.y + 
        ' L' + (iFrame.x + iFrame.width) + ' ' + (iFrame.y + iFrame.height) +
        ' L' + iFrame.x + ' ' + (iFrame.y + iFrame.height) + 
        ' L' + iFrame.x + ' ' + iFrame.y;
  },

  /**
   *
   * @param iElement {Element}
   * @param iRotation {Number}
   * @param iCenterX {Number}
   * @param iCenterY {Number}
   */
  rotateText: function( iElement, iRotation, iCenterX, iCenterY) {
    // 'rotate' is deprecated in Raphael 2.0 and is additive rather than specifying
    if( Raphael.version < "2.0")
      iElement.rotate( iRotation, iCenterX, iCenterY);
    else  { // transform is new to Raphael 2.0
      var tTransform = 'r%@,%@,%@'.fmt( iRotation, iCenterX, iCenterY);
      iElement.attr( {transform: tTransform });
    }
  },

  testPaperValidity: function( iPaper) {
    this.printPaper( iPaper);
    var map = {},
        bot = iPaper.bottom;
    while (bot) {
      if( map[bot.id]) {
        console.log('Paper is not valid. Element %@ appears twice'.fmt( bot.id));
        return false;
      }
      if( bot.prev && bot.prev.next !== bot) {
        console.log('Paper is not valid. Prev of %@ not pointing to %@'.fmt( bot.id, bot.id));
        return false;
      }
      if( bot.next && bot.next.prev !== bot) {
        console.log('Paper is not valid. Next of %@ not pointing to %@'.fmt( bot.id, bot.id));
        return false;
      }
      map[bot.id] = true;
      bot = bot.next;
    }
    return true;
  },

  svgElementClass: function( iElement) {
    var tClass;
    if( iElement[0]) {
      switch (iElement[0].constructor) {
        case SVGImageElement:
          tClass = 'I';
          break;
        case SVGRectElement:
          tClass = 'R';
          break;
        case SVGPathElement:
          tClass = 'P';
          break;
        case SVGCircleElement:
          tClass = 'C';
          break;
        default:
          tClass = '?';
      }
    }
    return tClass;
  },

  printPaper: function( iPaper) {
    var tPrintout = 'Paper-> ',
        tElement = iPaper.bottom,
        tMap = {},
        tEnd = false;
    while( tElement && !tEnd) {
      tEnd = tMap[tElement.id];
      if( !tEnd) {
        tMap[ tElement.id] = true;
        tPrintout += tElement.id + ': ' + this.svgElementClass( tElement) + ', ';
        tElement = tElement.next;
      }
      else {
        tPrintout += 'FAILED - repetition of ' + tElement.id;
      }
    }
    console.log( tPrintout);
  }

};

/* >>>>>>>>>> BEGIN source/components/graph/axes/axis_label_view.js */
// ==========================================================================
//                              DG.AxisLabelView
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/utilities/graph_drop_target');
sc_require('views/raphael_base');
sc_require('utilities/rendering_utilities');

/** @class  DG.AxisLabelView - Displays attribute name(s) on left or bottom of graph.
 *          Particularly important when a plot has been split so there are multiple independent axes there.


 @extends DG.RaphaelBaseView
 */
DG.AxisLabelView = DG.RaphaelBaseView.extend(DG.GraphDropTarget,
    /** @scope DG.AxisLabelView.prototype */
    (function () {
      return {

        classNames: 'dg-axis-view'.w(),

        orientation: null,

        /**
         * @property {DG.Attribute}
         */
        plottedAttribute: null,

        blankDropHint: 'DG.GraphView.addToEmptyPlace',

        desiredExtent: DG.RenderingUtilities.kCaptionFontHeight,

        init: function() {
          arguments.callee.base.apply(this,arguments);

          // Add a classname for use in QA automation
          var tClassName;
          switch( this.get('orientation')) {
            case DG.GraphTypes.EOrientation.kHorizontal:
              tClassName = 'dg-h-axis';
              break;
            case DG.GraphTypes.EOrientation.kVertical:
              tClassName = 'dg-v-axis';
              break;
            case DG.GraphTypes.EOrientation.kVertical2:
              tClassName = 'dg-v2-axis';
              break;
          }
          this.get('classNames').push( tClassName);

        }

      };
    }()));


/* >>>>>>>>>> BEGIN source/components/graph/axes/axis_model.js */
// ==========================================================================
//                          DG.AxisModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class  The model for a graph axis.

  @extends SC.Object
*/
DG.AxisModel = SC.Object.extend(
/** @scope DG.AxisModel.prototype */ 
{
  /**
    Describes the physical location of the axis in the graph. One of: x, y, or legend.
    @property { DG.AttributePlacementDescription }
  */
  attributeDescription: null,

  /**
   * @property{DG.PlotDataConfiguration}
   */
  dataConfiguration: null,

  /**
   * @property {Boolean}
   */
  scaleCanAnimate: true,

  /**
   * Passed by GraphModel so that the point color on the label for a scatterplot's first attribute
   * will correspond to that set by the user for its points.
   * @property {function}
   */
  getPointColor: null,

  /**
   * Override if desired
   * @param iPlotModel {DG.PlotModel}
   */
  setLinkToPlotIfDesired: function( iPlotModel) {

  },

  /**
    The array of strings that will be used to label the axis.
    @property { Array of String }
    Note: This should be cacheable, but I couldn't make it work.
  */
  labels: function() {
    var tDesc = this.get('attributeDescription'),
        tLabels = [];
    if( tDesc) {
      tDesc.get('attributes' ).forEach( function( iAttribute) {
        if( iAttribute !== DG.Analysis.kNullAttribute) {
          var tName = iAttribute.get('name' ),
              tUnit = iAttribute.get('unit' ),
              tThisLabel = tName + (!SC.empty( tUnit) ? ' (' + tUnit + ')' : '');
          tLabels.push( tThisLabel);
        }
      });
    }
    return tLabels;
  }.property(),
  labelsDidChange: function() {
    this.notifyPropertyChange('labels');
  }.observes('*attributeDescription.attribute'),

  /**
   * Some property of the attribute with the given ID has changed, typically its name or unit
   * @param iAttrID {Number}
   */
  handleUpdateAttribute: function( iAttrID) {
    this.labelsDidChange();
  },

  /**
    The string to use as a tooltip.
    @property { String }
  */
  labelDescription: function() {
    return this.getPath('attributeDescription.attribute.description') || '';
  }.property()/*.cacheable()*/,
  labelDescriptionDidChange: function() {
    this.notifyPropertyChange('labelDescription');
  }.observes('*attributeDescription.attribute'),

  /**
   *
   * @param iIndex
   * @return {String}
   */
  getLabelDescription: function( iIndex) {
    var tAttributes = this.getPath('attributeDescription.attributes');
    return (tAttributes && iIndex < tAttributes.length) ? tAttributes[ iIndex].get('description') : '';
  },

  firstAttribute: function() {
    var tAttributes = this.getPath( 'attributeDescription.attributes' );
    if( SC.isArray( tAttributes ) && (tAttributes.length > 0) ) {
      return tAttributes[ 0];
    }
  }.property(),

  firstAttributeName: function() {
    var tAttr = this.get('firstAttribute');
    return tAttr ? tAttr.get( 'name' ) : '';
  }.property(),
  firstAttributeNameDidChange: function() {
    this.notifyPropertyChange('firstAttributeName');
  }.observes('*attributeDescription.attribute', '*attributeDescription.attributes'),

  firstAttributeUnit: function() {
    var tUnit = '',
        tAttr = this.get('firstAttribute');
    if( tAttr)
      tUnit = tAttr.get( 'unit' );
    return tUnit || '';
  }.property(),

  /**
  One by default. Subclasses will likely override.
    @property {Number}
  */
  numberOfCells: function() {
    return 1;
  }.property().cacheable(),

  valueToCellNumber: function() {
    return 0; // The default
  },

  /**
      @protected
    @property { DG.GraphAnimator }
  */
  axisAnimator: null,

  /**
    @return{Number} always return 0
  */
  cellNameToCellNumber: function( iCellName) {
    return 0;
  },
  
  /**
  Must be overriden by subclasses
    @property {null}
  */
  isNumeric: null,

  noAttributes: function() {
    return this.getPath('attributeDescription.noAttributes');
  }.property(),

  /**
  Default implementation does nothing

    @param {Number} iLower - desired world coordinate lower bound
    @param {Number} iUpper - desired world coordinate upper bound
  */
  setLowerAndUpperBounds: function() {
  },

  /**
   * If I have an animation, end it.
   */
  stopAnimation: function() {
    var tAnimator = this.get('axisAnimator');
    if( !SC.none( tAnimator ) ) {
      tAnimator.endAnimation();
    }
  }

});


/* >>>>>>>>>> BEGIN source/components/graph/axes/axis_multi_target.js */
// ==========================================================================
//                            DG.AxisMultiTarget
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/*
 * Under certain circumstances when user is dragging an attribute, this view displays a drop target
 * that allows the user to add more than one attribute to an axis.
 */

sc_require('components/graph/utilities/graph_drop_target');
sc_require('views/raphael_base');

/** @class  DG.AxisMultiTarget - A drop area for adding multiple attributes to a graph

 @extends DG.RaphaelBaseView, DG.GraphDropTarget
 */
DG.AxisMultiTarget = DG.RaphaelBaseView.extend( DG.GraphDropTarget,
  /** @scope DG.AxisMultiTarget.prototype */
  {

    classNameBindings: ['dragIsInside:dg-graph-drop-multi-background'],

    dragIsInside: false,

    dataConfiguration: null,

    /**
     We're adding attributes to this description
     @property { DG.AttributeDescription }
     */
    attributeDescription:null,

    /**
     We're adding attributes to this description
     @property { DG.AttributeDescription }
     */
    otherAttributeDescription:null,

    /**
     * @property {DG.Attribute}
     */
    plottedAttribute:function () {
      return this.getPath('attributeDescription.attribute');
    }.property(),

    /**
     * @property {DG.Attribute}
     */
    otherPlottedAttribute:function () {
      return this.getPath('otherAttributeDescription.attribute');
    }.property(),

    /**
     @property{Raphael element}
     */
    plusArea:null,

    /**
     * @property { width: {Number} height: {Number}}
     */
    desiredExtent:function () {
      return { width:this.getPath('parentView.layout.width') || 24, height:24 };
    }.property(),

    dragEntered:function ( iDragObject, iEvent ) {
      this.plusArea.addClass( 'dg-graph-drop-plus-fill' );
      this.set('dragIsInside', true);
      this.showDropHint({x: iEvent.clientX, y: iEvent.clientY});
    },

    dragExited:function ( iDragObject, iEvent ) {
      this.plusArea.removeClass( 'dg-graph-drop-plus-fill' );
      this.set('dragIsInside', false);
      this.hideDropHint();
    },

    /**
     * For adding a numeric attribute to the y-axis:
     * A dragged attribute is valid for such a drop if there is already at least one attribute
     * and the dragged attribute is not one of them.
     * If the dragged attribute is not nominal there must also be an attribute on the
     * 'other' axis since we only support multiple numeric attributes for scatter plots for now.
     * @param iDrag
     * @return {Boolean}
     */
    isValidAttribute: function( iDrag) {
      return this.isValidAttributeForScatterplot( iDrag) || this.isValidAttributeForPlotSplit( iDrag);
    },

    isValidAttributeForPlotSplit: function( iDrag) {
      return (iDrag.data.attribute !== this.getPath('dataConfiguration.topAttributeDescription.attribute')) &&
          DG.GraphDropTarget.isValidAttributeForPlotSplit.call(this, iDrag);
    },

    /**
     * @override
     * @param iDrag
     * @return {boolean|*}
     */
    isValidAttributeForScatterplot: function( iDrag) {
      var tDragAttr = iDrag.data.attribute,
          tDragAttrIsNominal = this.getDataConfiguration().attributeIsNominal(tDragAttr),
          tCurrAttr = this.get('plottedAttribute'),
          tXDescription = this.getPath('dataConfiguration.xAttributeDescription'),
          tCurrXAttr = tXDescription ? tXDescription.get('attribute') : DG.Analysis.kNullAttribute,
          tY1Description = this.getPath('dataConfiguration.yAttributeDescription'),
          tY1Attr = tY1Description ? tY1Description.get('attribute') : DG.Analysis.kNullAttribute,
          tValidForScatterplot = (tCurrXAttr !== DG.Analysis.kNullAttribute) &&
              (tY1Attr !== DG.Analysis.kNullAttribute) &&
              (tY1Attr !== tDragAttr) &&
              (tCurrAttr !== tDragAttr) &&
              tXDescription.get('isNumeric') &&
              tY1Description.get('isNumeric') &&
              !tDragAttrIsNominal;
      return tValidForScatterplot;
    },

    // Draw an orange frame to show we're a drop target.
    dragStarted:function ( iDrag ) {
      var kPadding = 3,
          kPlusWidth = 24,
          tIsValidForScatterplot = this.isValidAttributeForScatterplot( iDrag),
          tIsValidForPlotSplit = this.isValidAttributeForPlotSplit( iDrag);

      function pathForPlus() {
        return 'M-6,-18 h6 v6 h6 v6 h-6 v6 h-6 v-6 h-6 v-6 h6 v-6Z';
      }

      if( tIsValidForScatterplot || tIsValidForPlotSplit ) {
        this.set('isVisible', true);
        var tParentView = this.get('parentView');
        if( tParentView)
            tParentView.makeSubviewFrontmost( this);

        var tX = kPlusWidth / 2 + kPadding,
          tY = tX + 2 * kPadding;
        if( SC.none( this.plusArea ) ) {
          this.plusArea = this._paper.path( pathForPlus() )
            .addClass( this.kDropFrameClass );
        }
        this.plusArea.transform( '' )
          .transform( 'T' + tX + ',' + tY )
          .show();

        var tDraggedName = iDrag.data.attribute.get( 'name' ),
            tString = tIsValidForScatterplot ?
                'DG.GraphView.addAttribute'.loc( tDraggedName ) :
                'DG.GraphView.layoutPlotsSideBySide'.loc( tDraggedName);
        this.set( 'dropHintString', tString );
      }
    },

    dragEnded:function () {
      if( this.plusArea )
        this.plusArea.hide();
      this.set('isVisible', false);
    }

  } );


/* >>>>>>>>>> BEGIN source/components/graph/axes/axis_view.js */
// ==========================================================================
//                              DG.AxisView
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/utilities/graph_drop_target');
sc_require('views/raphael_base');

/** @class  DG.AxisView - The base class view for a graph axis.

 On creation, pass in the orientation, as in
 DG.AxisView.create( { orientation: DG.GraphTypes.EOrientation.kVertical })

 @extends DG.RaphaelBaseView
 */
DG.AxisView = DG.RaphaelBaseView.extend(DG.GraphDropTarget,
    /** @scope DG.AxisView.prototype */ (function () {
      return {
        displayProperties: ['suppressLabel',
          'model.attributeDescription.attribute',
          'model.attributeDescription.attributeStats.categoricalStats.numberOfCells',
          'model.attributeDescription.attributeStats.cellMap',
          'otherYAttributeDescription.attribute'],
        classNames: 'dg-axis-view'.w(),

        /**
         The model on which this view is based.
         @property { DG.AxisModel }
         */
        model: null,

        /**
         Either 'vertical' or 'horizontal' or 'vertical2'
         @property { String }
         */
        orientation: null,

        /**
         * When this set, we use its paper rather than our own for rendering our label.
         * @property {DG.RaphaelBaseView}
         */
        paperSourceForLabel: null,

        paperForLabel: function() {
          if( this.get('paperSourceForLabel'))
            return this.getPath('paperSourceForLabel.paper');
          else return this.get('paper');
        }.property('paperSourceForLabel'),

        /**
         * In some situations we don't want to show the label; e.g. split right or split top
         * we only show the label on one of the axes.
         * @property {Boolean}
         */
        suppressLabel: false,

        /**
         * Most axis views allow bin lines. But a BinnedAxisView does not.
         * @property {Boolean}
         */
        allowCellBoundaries: true,

        /**
         * @property {DG.Attribute}
         */
        plottedAttribute: function () {
          return this.getPath('model.attributeDescription.attribute');
        }.property(),
        plottedAttributeDidChange: function() {
          // If make use of an AxisLabelView, let it know the new plottedAttribute so it can
          // highlight correctly in a drag of an attribute
          if( this.get('paperSourceForLabel'))
            this.setPath( 'paperSourceForLabel.plottedAttribute', this.get('plottedAttribute'));
        }.observes('model.attributeDescription.attribute'),

        xAttributeDescription: null,  // Used by vertical2 axis to test if drag attribute is valid
        otherYAttributeDescription: null,  // Used by vertical2 axis to test if drag attribute is valid

        blankDropHint: 'DG.GraphView.addToEmptyPlace',

        _hiddenDragView: null,

        /**
         For Raphael 1.5.2 we could always return the height, but this changed with Raphael 2.0 when
         the BBox started depending on rotation.
         @property { Number }
         */
        desiredExtent: function () {
          if( this.get('paperSourceForLabel'))
            return 0; // it will be laid out independently of us

          var tLabelExtent = this.get('labelExtent'),
              tDimension;
          switch (this.get('orientation')) {
            case DG.GraphTypes.EOrientation.kHorizontal:
            case DG.GraphTypes.EOrientation.kTop:
              tDimension = 'y';
              break;
            case DG.GraphTypes.EOrientation.kVertical:
            case DG.GraphTypes.EOrientation.kVertical2:
            case DG.GraphTypes.EOrientation.kRight:
              tDimension = 'x';
              break;
          }
          return tLabelExtent[ tDimension];
        }.property('labelNode', 'paperSourceForLabel'),

        /**
         * When we are the "other" axis, our partner needs to know how much to offset pixelMin
         * @property {Number}
         */
        pixelMinOffset: function() {
          var tPaperSourceForLabel = this.get('paperSourceForLabel');
          return tPaperSourceForLabel ? tPaperSourceForLabel.get('desiredExtent') : 0;
        }.property('paperSourceForLabel'),

        /**
         @property{Number}
         */
        axisLineCoordinate: function() {
          var tCoord;
          switch( this.get('orientation')) {
            case DG.GraphTypes.EOrientation.kVertical:
              tCoord = this.get('drawWidth');
              break;
            case DG.GraphTypes.EOrientation.kVertical2:
            case DG.GraphTypes.EOrientation.kHorizontal:
            case DG.GraphTypes.EOrientation.kRight:
              tCoord = 0;
              break;
            case DG.GraphTypes.EOrientation.kTop:
              tCoord = this.get('drawHeight');
              break;
          }
          return tCoord;
        }.property('drawWidth', 'drawHeight'),

        /**
         * Return whether both my model and my otherAxisView's model have no attributes assigned
         * @return{Boolean}
         */
        noAttributesOnEitherAxis: function() {
          var tDataConfiguration = this.getPath('model.dataConfiguration');
          return tDataConfiguration && tDataConfiguration.noAttributesFor(['x', 'y']);
        },

        /**
         Coordinate of my minimum value (Y: bottom end, X: left end)
         @property { Number }
         */
        pixelMin: function() {
          var tResult = 0;
          if( this.get('isVertical')) {
            tResult = this.get('drawHeight');
          }
          return tResult;
        }.property(),
        pixelMinDidChange: function() {
          this.notifyPropertyChange('pixelMin');
        }.observes('drawHeight'),

        /**
         Coordinate of my maximum value (Y: top end, X: right end)
         @property { Number }
         */
        pixelMax: function() {
          return this.get('isVertical') ? 0 :
              this.get('drawWidth');
        }.property('drawWidth'),

        /**
         Return the extent of the label
         @property {Point as in { x, y }}
         */
        labelExtent: function () {
          var kMinHeight = DG.RenderingUtilities.kCaptionFontHeight,
              tLabelNode = this.get('labelNode'),
              tExtent = { x: kMinHeight, y: kMinHeight};
          if (!SC.none(tLabelNode)) {
            var tBox = tLabelNode.extent();
            tExtent = { x: isNaN(tBox.width) ? kMinHeight : Math.max(kMinHeight, tBox.width),
              y: isNaN(tBox.height) ? kMinHeight : Math.max(kMinHeight, Math.ceil(tBox.height / 2) * 2) };
          }
          return tExtent;
        }.property('labelNode').cacheable(),

        /**
         Subclasses must override
         @return { Boolean }
         */
        isNumeric: null,

        /**
         The Raphael element used to display the label.
         @property {Array of LabelNode}
         */
        labelNodes: function () {
          var this_ = this,
              tChangeHappened = false,
              tLabelCount = 0,
              tRotation = this.get('isVertical') ? -90 : 0,
              tOtherYAttributes = this.getPath('otherYAttributeDescription.attributes'),
              tOtherYCount = SC.isArray(tOtherYAttributes) ? tOtherYAttributes.length : 0,
              tBaseLabelIndex = (this.get('orientation') === DG.GraphTypes.EOrientation.kVertical2) ? tOtherYCount : 0,
              tNoAttributesOnThisAxis = this.getPath('model.noAttributes'),
              tNoAttributesOnEitherAxis = this.noAttributesOnEitherAxis(),
              tLabels, tNumAttributes, tNode, tAttributes, tAttribute;
          if (SC.none(this.get('paperForLabel')) || (this._labelNodes == null))
            return [];

          if( (this.constructor === DG.AxisView) && (tNoAttributesOnEitherAxis ||
              (tNoAttributesOnThisAxis && DG.ComponentView.isComponentViewForViewSelected( this)))) {
            tLabels = ['DG.AxisView.emptyGraphCue'.loc()];
            tNumAttributes = 0;
          }
          else {
            tLabels = this.getPath('model.labels');
            tNumAttributes = tBaseLabelIndex + tLabels.length +
                ((this.get('orientation') === DG.GraphTypes.EOrientation.kVertical) ? tOtherYCount : 0);
          }
          tLabels.forEach(function (iLabel, iIndex) {
            if (tLabelCount >= this_._labelNodes.length) {
              tNode = DG.LabelNode.create({
                paper: this_.get('paperForLabel'),
                rotation: tRotation,
                colorIndex: tBaseLabelIndex + iIndex,
                numColors: tNumAttributes,
                getPointColor: iIndex === 0 ? this_.getPath('model.getPointColor') : null,
                priorNode: (tLabelCount > 0) ? tLabels[ tLabelCount - 1] : null });
              tAttributes = this_.getPath('model.attributeDescription.attributes');
              tAttribute = (SC.isArray(tAttributes)) ? tAttributes[iIndex] : null;
              if( tAttribute) {
                tNode.setDragLabelHandler(DG.DragLabelHandler.create({
                  labelNode: tNode,
                  labelView: this_._hiddenDragView,
                  viewToAddTo: this_,
                  attributeDescription: this_.getPath('model.attributeDescription'),
                  attributeName: tAttribute.get('name'),
                  dataContext: this_.getPath('model.dataConfiguration.dataContext')
                }));
              }
              this_._labelNodes.push(tNode);
              tChangeHappened = true;
            }
            else {
              tNode = this_._labelNodes[ tLabelCount];
              tNode.beginPropertyChanges();
                tNode.setIfChanged('colorIndex', tBaseLabelIndex + iIndex);
                tNode.setIfChanged('numColors', tNumAttributes);
                if( iIndex === 0 && tNumAttributes > 1)
                  tNode.numColorsChanged(); // in case the base color has changed
              tNode.endPropertyChanges();
            }

            tChangeHappened = (iLabel !== tNode.get('text'));
            tNode.setIfChanged('text', iLabel);

            tLabelCount++;
          });

          while (this._labelNodes.length > tLabelCount) {
            this._labelNodes.pop().remove();
            tChangeHappened = true;
          }

          if (tChangeHappened)
            this.notifyPropertyChange('labelNode', this._labelNodes);

          return this._labelNodes;
        }.property(),

        labelNodesDidChange: function() {
          this.notifyPropertyChange('labelNodes');
          this.get('labelNodes'); // Should cause new text to be set in each label node.
        }.observes('*model.labels'),

        /**
         The Raphael element used to display the label.
         @property {Raphael element}
         */
        labelNode: function () {
          var tNodes = this.get('labelNodes');
          return (tNodes.length > 0) ? tNodes[0] : null;
        }.property('labelNodes'),

        /**
         * @private
         * @property {[DG.LabelNode]}
         */
        _labelNodes: null,

        init: function () {
          arguments.callee.base.apply(this,arguments);
          this._labelNodes = [];
          // Add a classname for use in QA automation
          var tClassName;
          switch( this.get('orientation')) {
            case DG.GraphTypes.EOrientation.kVertical2:
              tClassName = 'dg-v2-axis';
              break;
          }
          this.get('classNames').push( tClassName);
          this._hiddenDragView = SC.LabelView.create({
            classNames: 'dg-drag-label'.w(),
            layout: {width: 100, height: 20, top: -50, left: 0},
            value: ''
          });
          this.appendChild( this._hiddenDragView);
          // A plain axis view will need to redraw each time the component becomes selected/unselected
          if( this.constructor === DG.AxisView)
            DG.mainPage.docView.addObserver('selectedChildView', this, this.doDraw);
        },

        /**
         * Remove observer and nodes
         */
        destroy: function() {
          if( this.constructor === DG.AxisView)
            DG.mainPage.docView.removeObserver('selectedChildView', this, this.doDraw);
          this.get('labelNodes').forEach( function( iNode) {
            iNode.remove();
            iNode.destroy();
          });
          this._labelNodes = null;
          arguments.callee.base.apply(this,arguments);
        },

        /**
         * The label consists of one clickable text node for each attribute assigned to the axis.
         * These are separated by colons.
         * Note that only y-axes of scatterplots are equipped to handle multiple attributes.
         */
        renderLabel: function () {
          if( this.get('suppressLabel')) {
            this.suppressLabelChanged();  // Guarantee that it's hidden
            return;
          }

          var tNodes = this.get('labelNodes'),
              tPaperForLabel = this.get('paperForLabel'),
              tDrawWidth = tPaperForLabel ? tPaperForLabel.width: 0,
              tDrawHeight = tPaperForLabel ? tPaperForLabel.height : 0,
              tIsVertical = this.get('isVertical'),
              tOrientation = this.get('orientation'),
              tTotalLength = 0,
              tLayout = tNodes.map(function (iNode) {
                var tExtent = iNode.extent();
                // We do this next test because of a peculiarity of restoring a graph component that is
                //  minimized. The label gets a chance to position itself during the initial render while
                //  the component is minimized but doesn't get another chance during maximization.
                if( !tIsVertical && tExtent.height === 0)
                  tExtent.height = tDrawHeight;
                tTotalLength += tIsVertical ? tExtent.height : tExtent.width;
                return { node: iNode, extent: tExtent };
              }),
              tPosition = tIsVertical ? ((tDrawHeight + tTotalLength) / 2) : ((tDrawWidth - tTotalLength) / 2);
          // It seems redundant to go through this every time we display, but we've had trouble getting the descriptions
          //  to be set consistently.
          tNodes.forEach(function( iNode, iIndex) {
            var tDescription = this.get('model').getLabelDescription(iIndex) +
                '—' + 'DG.AxisView.labelTooltip'.loc(('DG.AxisView.' + this.orientation).loc());
            iNode._textElement.attr('title', tDescription);
          }.bind(this));

          tLayout.forEach(function (iLayout) {
            var tNode = iLayout.node,
                tLabelExtent = { x: iLayout.extent.width, y: iLayout.extent.height },
                tLoc = { }; // The center of the node

            switch( tOrientation) {
              case DG.GraphTypes.EOrientation.kVertical:
              case DG.GraphTypes.EOrientation.kVertical2:
              case DG.GraphTypes.EOrientation.kRight:
                tLoc.x = tLabelExtent.x / 4 + 4;
                tLoc.y = tPosition - tLabelExtent.y / 2;
                tPosition -= tLabelExtent.y + 4;
                if (tOrientation === DG.GraphTypes.EOrientation.kVertical2 ||
                    tOrientation === DG.GraphTypes.EOrientation.kRight)
                  tLoc.x = tDrawWidth - tLabelExtent.x / 2 - 2;
                break;
              case DG.GraphTypes.EOrientation.kHorizontal:
              case DG.GraphTypes.EOrientation.kTop:
                tLoc.x = tPosition + tLabelExtent.x / 2;
                tLoc.y = tDrawHeight - tLabelExtent.y / 2 - 2;
                tPosition += tLabelExtent.x + 4;
                if( tOrientation === DG.GraphTypes.EOrientation.kTop)
                  tLoc.y = tLabelExtent.y / 3;
                break;
            }
            tNode.set('loc', tLoc);
          });
        },

        suppressLabelChanged: function() {
          var tLabelNodes = this._labelNodes,
              tSuppress = this.get('suppressLabel');
          if (tLabelNodes) {
            tLabelNodes.forEach(function (iNode) {
              if( tSuppress)
                iNode.hide();
              else
                iNode.show();
            });
          }
          if( !tSuppress)
            this.renderLabel();
        }.observes('suppressLabel'),

        /**
         This is the main backbone of the axis.
         @return {Raphael element}
         */
        renderAxisLine: function() {
          var tCoord = this.get('axisLineCoordinate'),
              tPixelMin = this.get('pixelMin'),
              tPixelMax = this.get('pixelMax'),
              tStart, tStop;
          switch( this.get('orientation')) {
            case DG.GraphTypes.EOrientation.kVertical:
              tStart = { x: tCoord - 1, y: tPixelMin };
              tStop = { x: tCoord - 1, y: tPixelMax };
              break;
            case DG.GraphTypes.EOrientation.kHorizontal:
              tStart = { x: tPixelMin, y: tCoord + 1 };
              tStop = { x: tPixelMax, y: tCoord + 1 };
              break;
            case DG.GraphTypes.EOrientation.kVertical2:
            case DG.GraphTypes.EOrientation.kRight:
              tStart = { x: tCoord + 1, y: tPixelMin };
              tStop = { x: tCoord + 1, y: tPixelMax };
              break;
            case DG.GraphTypes.EOrientation.kTop:
              tStart = { x: tPixelMin, y: tCoord - 1 };
              tStop = { x: tPixelMax, y: tCoord - 1 };
              break;
          }
          return this.get('paper').line( tStart.x, tStart.y, tStop.x, tStop.y)
              .attr( { stroke: DG.PlotUtilities.kAxisColor,
                strokeWidth: 2 });
        },

        /**
         Graph controller observes this property to detect that a drag has taken place.
         @property{{
          context:{DG.DataContext},
          collection:{DG.CollectionRecord},
          attribute:{DG.Attribute},
          text:{String},
          axisOrientation:{String} }}
         */
        dragData: null,

        /**
         Attempt to assign the given attribute to this axis.
         @param {SC.Drag} 'data' property contains 'collection', 'attribute', 'text' properties
         @param {SC.DRAG_LINK}
         */
        performDragOperation: function (iDragObject, iDragOp) {
          this.hideDropHint();
          this.set('dragData', iDragObject.data);
          return SC.DRAG_LINK;
        },

        /**
         * Override so that y2 can hide if it has no attribute
         */
        dragEnded: function() {
          if( (this.get('orientation') === DG.GraphTypes.EOrientation.kVertical2) && (this.constructor === DG.AxisView)) {
            this.set('isVisible', false);
          }
          DG.GraphDropTarget.dragEnded.apply(this, arguments);
        },

        numberOfCells: function () {
          return this.getPath('model.numberOfCells');
        }.property(),

        numberOfCellsChanged: function() {
          this.notifyPropertyChange('numberOfCells');
        }.observes('*model.numberOfCells'),

        fullWidth: function () {
          return Math.abs(this.get('pixelMax') - this.get('pixelMin'));
        }.property('pixelMax', 'pixelMin'),

        /**
         The total distance in pixels between one cell and the next without any "slop" at the ends.
         @property {Number} in pixels
         */
        fullCellWidth: function () {
          return this.get('fullWidth') / this.get('numberOfCells');
        }.property('numberOfCells', 'pixelMax', 'pixelMin'),

        /**
         The width to be used when actually drawing into a cell because it takes into account
         the need for space between cells and space on both ends.
         @property {Number} in pixels
         */
        cellWidth: function () {
          var tNumCells = this.get('numberOfCells'),
              tPixelMin = this.get('pixelMin'),
              tPixelMax = this.get('pixelMax'),
              kShrinkFactor = 0.9,
          // Here's where we make a bit of space at the ends of the axis.
              tUpperBounds = tNumCells + 0.5,
              tLowerBounds = 0,
              tAxisRange = tUpperBounds - tLowerBounds,
              tHalfWidth = Math.abs((tPixelMax - tPixelMin) / tAxisRange);

          return tHalfWidth * kShrinkFactor;
        }.property('numberOfCells', 'pixelMax', 'pixelMin'),

        /**
         Note that for vertical axis, the zeroth cell is at the top.
         @return {Number} coordinate of the given cell.
         */
        cellToCoordinate: function (iCellNum) {
          var tNumCells = this.get('numberOfCells'),
              tPixelWidth = Math.abs( this.get('pixelMax') - this.get('pixelMin')),
              tDistanceToCell = (iCellNum + 0.5) / tNumCells * tPixelWidth,
              tCoordinate;
          switch (this.get('orientation')) {
            case DG.GraphTypes.EOrientation.kHorizontal:
            case DG.GraphTypes.EOrientation.kTop:
              tCoordinate = this.get('pixelMin') + tDistanceToCell;
              break;
            case DG.GraphTypes.EOrientation.kVertical:
            case DG.GraphTypes.EOrientation.kVertical2:
            case DG.GraphTypes.EOrientation.kRight:
              tCoordinate = this.get('pixelMin') - tDistanceToCell;
              break;
          }

          return tCoordinate;
        },

        /**
         @return {Number} coordinate of the cell with the given name.
         */
        cellNameToCoordinate: function (iCellName) {
          return this.cellToCoordinate(this.model.cellNameToCellNumber(iCellName));
        },

        /**
         Default implementation does nothing.
         @param {Function} to be called for each tick
         */
        forEachTickDo: function () {
        },

        doDraw: function() {
          this.renderLabel();
        },

        /**
         Default implementation expects a number between 0 and 1 and returns a number between pixelMin and pixelMax.
         @param{Number} Expected to be between 0 and 1.
         @return {Number}
         */
        dataToCoordinate: function (iData) {
          var
              tPixelMin = this.get('pixelMin'),
              tPixelMax = this.get('pixelMax');
          return tPixelMin + iData * (tPixelMax - tPixelMin);
        },

        /**
         Default implementation expects a number between 0 and 1 and returns a number between pixelMin and pixelMax.
         @param{Number} Expected to be between pixelMin and pixelMax.
         @return {Number} Typically between 0 and 1.
         */
        coordinateToData: function (iCoord) {
          var
              tPixelMin = this.get('pixelMin'),
              tPixelMax = this.get('pixelMax');
          return (iCoord - tPixelMin) / (tPixelMax - tPixelMin);
        },

        isValidAttribute: function (iDrag) {
          switch (this.get('orientation')) {
            case DG.GraphTypes.EOrientation.kVertical2:
              return this.isValidAttributeForScatterplot( iDrag) ||
                  this.isValidAttributeForPlotSplit( iDrag);
            case DG.GraphTypes.EOrientation.kTop:
            case DG.GraphTypes.EOrientation.kRight:
              return this.isValidAttributeForPlotSplit( iDrag);
            default:
              return DG.GraphDropTarget.isValidAttribute.call(this, iDrag);
          }
        },

        /**
         * Only called for a y2 axis view
         * @param iDrag
         * @return {boolean|*}
         */
        isValidAttributeForScatterplot: function( iDrag) {
          var tDragAttr = iDrag.data.attribute,
              tDataConfiguration = this.getDataConfiguration(),
              tDragAttrIsNominal = tDataConfiguration.attributeIsNominal(tDragAttr),
              tCurrAttr = this.getPath('model.attributeDescription.attribute'),
              tXAttrDescription = this.get('xAttributeDescription'),
              tXAttr = tXAttrDescription && tXAttrDescription.get('attribute'),
              tXIsNumeric = tXAttrDescription && tXAttrDescription.get('isNumeric'),
              tOtherYAttr = this.getPath('otherYAttributeDescription.attribute'),
              tValidForScatterplot = (tXAttr !== DG.Analysis.kNullAttribute && tXIsNumeric) &&
                  (tCurrAttr !== tDragAttr) &&
                  !tDragAttrIsNominal &&
                  tOtherYAttr && !tDataConfiguration.attributeIsNominal( tOtherYAttr);
          return tValidForScatterplot;
        }
      };
    }()));


/* >>>>>>>>>> BEGIN source/components/graph/axes/axis_view_helper.js */
// ==========================================================================
//                              DG.AxisViewHelper
//
//  Author:   William Finzer
//
//  Copyright (c) 2016 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class  DG.AxisViewHelper - Base class for helpers that draw ticks on cell linear axes
 *
 * @extends SC.Object
 */
DG.AxisViewHelper = SC.Object.extend(
    /** @scope DG.AxisViewHelper.prototype */ (function () {
      return {
        kAxisGap: 1,
        kTickLength: 4,

        /**
         * @property {DG.CellLinearAxisView}
         */
        axisView: null,

        destroy: function() {
          arguments.callee.base.apply(this,arguments);
          this.axisView = null;
        },

        paper: function() {
          return this.getPath('axisView.paper');
        }.property(),
        paperDidChange: function() {
          this.notifyPropertyChange('paper');
        }.observes('axisView.paper'),

        elementsToClear: function() {
          return this.axisView._elementsToClear;
        }.property('axisView'),

        orientation: function() {
          return this.getPath('axisView.orientation');
        }.property(),
        orientationDidChange: function() {
          this.notifyPropertyChange('orientation');
        }.observes('axisView.orientation'),

        lowerBound: function() {
          return this.getPath('axisView.model.lowerBound');
        }.property(),
        lowerBoundDidChange: function() {
          this.notifyPropertyChange('lowerBound');
        }.observes('axisView.model.lowerBound'),

        upperBound: function() {
          return this.getPath('axisView.model.upperBound');
        }.property(),
        upperBoundDidChange: function() {
          this.notifyPropertyChange('upperBound');
        }.observes('axisView.model.upperBound'),

        axisLineCoordinate: function() {
          return this.getPath('axisView.axisLineCoordinate');
        }.property(),
        axisLineCoordinateDidChange: function() {
          this.notifyPropertyChange('axisLineCoordinate');
        }.observes('axisView.axisLineCoordinate'),

        tickGap: function() {
          return this.getPath('axisView.model.tickGap');
        }.property(),
        tickGapDidChange: function() {
          this.notifyPropertyChange('tickGap');
        }.observes('axisView.model.tickGap'),

        pixelMin: function() {
          return this.getPath('axisView.pixelMin');
        }.property(),
        pixelMinDidChange: function() {
          this.notifyPropertyChange('pixelMin');
        }.observes('axisView.pixelMin'),

        pixelMax: function() {
          return this.getPath('axisView.pixelMax');
        }.property(),
        pixelMaxDidChange: function() {
          this.notifyPropertyChange('pixelMax');
        }.observes('axisView.pixelMax'),

        isVertical: function() {
          return this.getPath('axisView.isVertical');
        }.property(),
        isVerticalDidChange: function() {
          this.notifyPropertyChange('isVertical');
        }.observes('axisView.isVertical'),

        fullCellWidth: function() {
          return this.getPath('axisView.fullCellWidth');
        }.property(),
        fullCellWidthDidChange: function() {
          this.notifyPropertyChange('fullCellWidth');
        }.observes('axisView.fullCellWidth'),

        maxNumberExtent: function(iKey, iValue) {
          if( !SC.none( iValue)) {
            this.setPath('axisView.maxNumberExtent', iValue);
          }
          return this.getPath('axisView.maxNumberExtent');
        }.property(),
        maxNumberExtentDidChange: function() {
          this.notifyPropertyChange('maxNumberExtent');
        }.observes('axisView.maxNumberExtent'),

        /**
         * @property Cache of information about this axis
         */
        info: function() {
          var tInfo = {
            lowerBound: this.get('lowerBound'),
            upperBound: this.get('upperBound'),
            range: null,
            cellWidth: this.get('fullCellWidth'),
            pixelMax: this.get('pixelMax')
          };
          tInfo.range = tInfo.upperBound - tInfo.lowerBound;
          return tInfo;
        }.property().cacheable(),
        infoDidChange: function() {
          this.notifyPropertyChange('info');
        }.observes('*axisView.model.lowerBound', '*axisView.model.upperBound',
            'axisView.fullCellWidth', 'axisView.pixelMax'),

        /**
         Given the value to plot and its cell number, give the coordinate along this axis.
         @return {Number}
         */
        cellDataToCoordinate: function( iCell, iData) {
          return this.cellDataToCoordinateUsingCache( iCell, iData, this.get('info'));
        },

        /**
         Given the value to plot return the coordinate along this axis.
         @return {Number}
         */
        dataToCoordinate: function( iData) {
          return this.cellDataToCoordinate( 0, iData);
        },

        /**
         Given a coordinate, return the result of the linear transformation
         to data value
         @param iCoord {Number} in screen coordinates
         @param iSnapToTick {boolean} if true, and return value is close to a tick, return the tick value
         @return {Number} in world coordinates.
         */
        coordinateToData: function( iCoord, iSnapToTick) {
          return this.coordinateToDataGivenCell( 0, /*this.whichCell( iCoord)*/ iCoord, iSnapToTick);
        },

        /**
         Given the value to plot and its cell number, give the coordinate along this axis.
         @return {Number}
         */
        cellDataToCoordinateUsingCache: function( iCell, iData, iCache) {
          if (!isFinite( iData))
            return null;

          var tCoordinate = SC.empty( iData) ? null : (iData - iCache.lowerBound) * iCache.cellWidth / iCache.range;
          if(!SC.none(tCoordinate))
            switch( this.get('orientation')) {
              case DG.GraphTypes.EOrientation.kVertical:
              case DG.GraphTypes.EOrientation.kVertical2:
                tCoordinate = iCache.pixelMax + (iCell + 1) * iCache.cellWidth - tCoordinate;
                break;

              case DG.GraphTypes.EOrientation.kHorizontal:
                tCoordinate = iCell * iCache.cellWidth + tCoordinate;
                break;
            }

          return tCoordinate;
        },

        /**
         Given a coordinate, return the result of the linear transformation
         to data value. The value will be relative to the given cell; i.e., if
         the user has dragged outside of that cell, the returned value is as though
         that cell continued on in both directions.
         * @param iCell {number}
         * @param iCoord {number}
         * @param iSnapToTick {boolean} if true, and return value is close to a tick, return the tick value
         * @return {Number} in world coordinates
         */
        coordinateToDataGivenCell: function( iCell, iCoord, iSnapToTick) {
          var tData = 0,
              tCellWidth = this.get('fullCellWidth'),
              tLowerBound, tUpperBound, tPixelMin, tPixelMax, tPixelDistance, tPixelsPerWorldUnit;
          if (tCellWidth !== 0) {
            tLowerBound = this.get('lowerBound');
            tUpperBound = this.get('upperBound');
/*
       TBool tReverseScale = ((ds_CCellLinearAxis*) mAxisP)->IsScaleReversed();
       TBool tLogScale = ((ds_CCellLinearAxis*) mAxisP)->IsScaleLogarithmic();
*/

            if( this.get('isVertical')) {
              tPixelMin = this.get('pixelMax') + tCellWidth * (iCell + 1);
              tPixelMax = tPixelMin - tCellWidth;
              iCoord += this.get('pixelMax'); // offset by the top of the axis
            } else {
              tPixelMin = this.get('pixelMin') + tCellWidth * iCell;
              tPixelMax = tPixelMin + tCellWidth;
              iCoord += this.get('pixelMin'); // offset by the left of the axis
        }
            tPixelDistance = iCoord - tPixelMin;
            tPixelsPerWorldUnit = ( tPixelMax - tPixelMin) / (tUpperBound - tLowerBound);
            tData = tLowerBound + tPixelDistance / tPixelsPerWorldUnit;
/*
       TDouble tLogLinearParam( ((ds_CCellLinearAxis*) mAxisP)->
                       GetLogLinearTransitionParam()); // 0 => linear; 1 => log
            tPixelDistance is the number of pixels from the relevant axis boundary to the given coordinate
       TLength tPixelDistance( tReverseScale ? (pixelMax - iCoord) : (iCoord - pixelMin));
            For a vertical scale, tPixelDistance is negative, but tCellWidth is positive. That won't work for a
            log scale so we have to change the sign.
       if( tLogScale && (mOrientation === ds_kVertical))
         tPixelDistance *= -1;
       tData = ((tLogLinearParam === 0) ? 0 :
               tLogLinearParam * tLowerBounds *
                 pow( 10, log10( tUpperBounds / tLowerBounds) * tPixelDistance / tCellWidth))
           +
           ((tLogLinearParam === 1) ? 0 :
               (1 - tLogLinearParam) * (tLowerBounds + tPixelDistance * (tUpperBound - tLowerBound)
                             / ( tPixelMax - tPixelMin)));
*/
            if( iSnapToTick) {
              var kSnapPixelThreshold = 2,
                  tTickGap = this.get('tickGap'),
                  tNearestTickValue = Math.round(tData / tTickGap) * tTickGap;
              if (Math.abs(tNearestTickValue - tData) * tPixelsPerWorldUnit < kSnapPixelThreshold) {
                tData = tNearestTickValue;
              }

            }
          }

          return tData;
        }


      };
    }()));


/* >>>>>>>>>> BEGIN source/components/graph/axes/binned_axis_model.js */
// ==========================================================================
//                          DG.BinnedAxisModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2019 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/axes/axis_model');

/** @class  DG.BinnedAxisModel - The model for a graph axis that has numeric bins.

 @extends SC.Object
 */
DG.BinnedAxisModel = DG.AxisModel.extend(
    /** @scope DG.BinnedAxisModel.prototype */
    {
      /**
       * Needed?
       @property {Boolean}
       */
      isNumeric: true,

      /**
       * It's somewhat unusual for an axis to refer to a PlotModel but since the binning depends on the cases and
       * their values, and these depend also on the secondary axis attribute, it seems best to rely on the PlotModel
       * that has easy access to the plottable cases.
       * @property {DG.BinnedPlotModel}
       */
      binnedPlotModel: null,

      setLinkToPlotIfDesired: function( iPlotModel) {
        this.set('binnedPlotModel', iPlotModel);
      },

      init: function() {
        arguments.callee.base.apply(this,arguments);
      },

      destroy: function() {
        this.binnedPlotModel = null;  // break cycle
        arguments.callee.base.apply(this,arguments);
      },

      lowerBound: function() {
        return this.getPath('binnedPlotModel.leastBinEdge');
      }.property(),

      upperBound: function() {
        return this.getPath('binnedPlotModel.maxBinEdge');
      }.property(),

      /**
       Determined by asking my plot model
       Note: Unlike a CellLinearAxis we always accommodate _all_ the valid numeric values.
       @property{Number} >= 1
       */
      numberOfBins: function () {
        return this.getPath('binnedPlotModel.totalNumberOfBins');
      }.property(),

      valueToCellNumber: function( iValue) {
        var tBinnedPlotModel = this.get('binnedPlotModel');
        if( tBinnedPlotModel)
          return tBinnedPlotModel.valueToBinNumber( iValue);
        else return 0;
      },

      /**
       * Provide this so PlottedCountModel will be happy
       */
      numberOfCells: function() {
        return this.get('numberOfBins');
      }.property(),

      /**
       * @return {[{ label: {String}, title: {String} }]}
       */
      binLabels: function () {
        var tLabels = [],
            tLabelTemplate = '[%@, %@)',
            tTitleTemplate = "DG.BinnedPlotModel.binLabelTip";
        this.forEachBinDo(function (iBinNum, iLeft, iRight) {
          tLabels.push({
            label: tLabelTemplate.fmt(iLeft, iRight),
            title: tTitleTemplate.loc(iLeft, iRight)
          });
        });
        return tLabels;
      }.property(),
      binLabelsDidChange: function() {
        this.notifyPropertyChange('binLabels');
      }.observes('binnedPlotModel.totalNumberOfBins', 'binnedPlotModel.alignment', 'binnedPlotModel.width'),

      /**
       * Pass responsibility to binnedPlotModel.
       * @param iFunc {Function}
       */
      forEachBinDo: function( iFunc) {
        this.get('binnedPlotModel').forEachBinDo( iFunc);
      }

    });


/* >>>>>>>>>> BEGIN source/components/graph/axes/binned_axis_view.js */
// ==========================================================================
//                            DG.BinnedAxisView
//
//  Author:   William Finzer
//
//  Copyright (c) 2019 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/axes/axis_view');

/** @class  DG.BinnedAxisView - The view for a graph axis that displays numeric bins.

 @extends DG.AxisView
 */
DG.BinnedAxisView = DG.AxisView.extend( (function() {
  var kTickLength = 4,
      kAxisGap = 2;

  return {
    /** @scope DG.BinnedAxisView.prototype */

    /**
     Number of pixels required from the axis line to the edge of the graph view
     @property { Number }
     */
    desiredExtent: function() {
      var kWidthFudge = 5;
      return arguments.callee.base.apply(this,arguments) + kTickLength + kAxisGap + kWidthFudge + this.get('maxLabelExtent');
    }.property('maxLabelExtent'),

    /**
     * When we are the "other" axis, our partner needs to know how much to offset pixelMin.
     * For me, it's the same as desiredExtent
     * @property {Number}
     */
    pixelMinOffset: function() {
      return this.get('desiredExtent');
    }.property('desiredExtent'),

    /**
     It's not clear whether this is a numeric axis or not
     @property { Boolean }
     */
    isNumeric: true,

    /**
     * @property {Boolean}
     */
    centering: true,

    /**
     @property {Number} Each time we draw the axis, we set this property to the maximum width
     of the label strings. Note that this will change depending not only on the length of the
     strings but on the rotation of the labels.
     */
    maxLabelExtent: 0,

    allowCellBoundaries: false,

    numberOfBins: function() {
      return this.getPath('model.binnedPlotModel.totalNumberOfBins');
    }.property(),
    numberOfBinsDidChange: function() {
      this.notifyPropertyChange( 'numberOfBins');
      this.displayDidChange();
    }.observes('model.binnedPlotModel.totalNumberOfBins'),

    /**
     * @return { Number} in pixels
     */
    binWidth: function() {
      var tNumBins = this.get('numberOfBins');

      return Math.abs(this.get('pixelMax') - this.get('pixelMin')) / tNumBins;
    }.property('numberOfBins'),

    labelSpecs: null,

    /**
     *
     * @param iBinNum {Number}
     * @return {Number} screen coordinate of center of bin
     */
    binToCoordinate: function( iBinNum) {
      var tOffset = (iBinNum + 0.5) * this.get('binWidth');
      if (this.get('orientation') === DG.GraphTypes.EOrientation.kVertical)
        tOffset = -tOffset;
      return this.get('pixelMin') + tOffset;
    },

    /**
     *
     * @param iWorldValue
     * @return {Number} in screen coordinates
     */
    dataToCoordinate: function( iWorldValue) {
      return this.binToCoordinate( Math.floor( (iWorldValue - this.getPath( 'model.binnedPlotModel.alignment')) /
        this.getPath('model.binnedPlotModel.width')));
    },

    binnedPlotModelWidthOrAlignmentDidChange: function() {
      this.displayDidChange();
    }.observes('model.binnedPlotModel.width', 'model.binnedPlotModel.alignment'),

    /**
     Since I'm a leaf class I implement doDraw.
     */
    doDraw: function doDraw() {

      // We can get stuck if we have height or width of zero
      var tFrame = this.get('frame');
      if( !tFrame || (tFrame.height === 0 || tFrame.width === 0))
        return;

      var this_ = this,
          kHorizontalOrientations = [DG.GraphTypes.EOrientation.kHorizontal, DG.GraphTypes.EOrientation.kTop],
          tModel = this.get('model'),
          tNumBins = tModel.get('numberOfBins'),
          tBaseline = this_.get('axisLineCoordinate'),
          tOrientation = this.get('orientation'),
          tIsHorizontal = kHorizontalOrientations.indexOf( tOrientation) >= 0,
          tRotation = tIsHorizontal ? 0 : -90, // default to parallel to axis
          tMaxHeight = DG.RenderingUtilities.kDefaultFontHeight,  // So there will be a default extent
          tCentering = this.get('centering'),
          tTickOffset = tCentering ? 0 : this.get('binWidth') / 2,
          tAnchor = tCentering ? 'middle' : 'start',
          tMaxWidth = tMaxHeight,
          tLabels = this.getPath('model.binLabels'),
          tLabelSpecs = this.get('labelSpecs') || [],
          tCollision = false,
          kCollisionPadding = 5,
          tPrevLabelEnd;

      function measureOneBin( iBinLabelAndTitle, iBinNum) {
        var tCoord = this_.binToCoordinate(iBinNum);
        if( !isFinite( tCoord)) {
          return;
        }
        var tTextElement;
        if( !tLabelSpecs[iBinNum]) {
          tTextElement = this_.get('paper').text(0, 0, iBinLabelAndTitle.label)
              .addClass('dg-axis-tick-label')
              .addClass('dg-binned-axis-label');
        }
        else {
          tTextElement = tLabelSpecs[ iBinNum].element;
          tTextElement.attr('text', iBinLabelAndTitle.label);
        }
        tTextElement.attr('title', iBinLabelAndTitle.title);
        var tTextExtent = DG.RenderingUtilities.getExtentForTextElement(
                          tTextElement, DG.RenderingUtilities.kDefaultFontHeight, true /* compute with no transform */);

        tTextElement.binNum = iBinNum;
        tLabelSpecs[iBinNum] = { element: tTextElement, coord: tCoord,
                      height: tTextExtent.height, width: tTextExtent.width };

        tMaxHeight = Math.max( tMaxHeight, tTextExtent.height);
        tMaxWidth = Math.max( tMaxWidth, tTextExtent.width);
        if(SC.none( tPrevLabelEnd)) {
          tCollision = tTextExtent.width > this_.get('binWidth');
          tPrevLabelEnd = tIsHorizontal ? tCoord + tTextExtent.width / 2 : tCoord - tTextExtent.width / 2;
        }
        else if( tIsHorizontal) {
          tCollision = tCollision || (tCoord - tTextExtent.width / 2 < tPrevLabelEnd + kCollisionPadding);
          tPrevLabelEnd = (tCoord + tTextExtent.width / 2);
        }
        else {  // vertical
          tCollision = tCollision || (tCoord + tTextExtent.width / 2 > tPrevLabelEnd - kCollisionPadding);
          tPrevLabelEnd = (tCoord - tTextExtent.width / 2);
        }
      } // measureOneBin

      // iLabelSpec has form { element: {Raphael element}, coord: {Number}, height: {Number}, width: {Number} }
      function drawOneCell( iLabelSpec, iIndex) {
        var tCoord = iLabelSpec.coord,
            tLabelX, tLabelY;
        switch( this_.get('orientation')) {
          case DG.GraphTypes.EOrientation.kVertical:
            this_._elementsToClear.push(
              this_.get('paper').line( tBaseline, tCoord + tTickOffset, tBaseline - kTickLength, tCoord + tTickOffset)
                .attr( { stroke: DG.PlotUtilities.kAxisColor }));
            tLabelX = tBaseline - kTickLength - kAxisGap - iLabelSpec.height / 3;
            tLabelY = tCoord + tTickOffset - ((iIndex === 0 && !tCentering) ? iLabelSpec.height / 2 : 0);
            if( tRotation === 0) {
              tAnchor = 'end';
              if( iLabelSpec.width > tLabelX && tLabelX > 10) {
                DG.RenderingUtilities.elideToFit( iLabelSpec.element, tLabelX);
              }
            }
            break;

          case DG.GraphTypes.EOrientation.kHorizontal:
            this_._elementsToClear.push(
              this_.get('paper').line( tCoord - tTickOffset, tBaseline, tCoord - tTickOffset, tBaseline + kTickLength)
                .attr( { stroke: DG.PlotUtilities.kAxisColor }));
            tLabelX = tCoord - tTickOffset + 1;
            tLabelY = tBaseline + kTickLength + kAxisGap + iLabelSpec.height / 3;
            if( tRotation === -90) {
              tAnchor = 'end';
              if( iIndex === 0 && !tCentering)
                tLabelX += iLabelSpec.height / 3;
              if( iLabelSpec.width > tFrame.height - tLabelY && tFrame.height - tLabelY > 10)
                DG.RenderingUtilities.elideToFit( iLabelSpec.element, tFrame.height - tLabelY);
            }
            break;
        }
        iLabelSpec.element.attr( { x: tLabelX, y: tLabelY, 'text-anchor': tAnchor });
        DG.RenderingUtilities.rotateText( iLabelSpec.element, tRotation, tLabelX, tLabelY);
      } // drawOneCell

      //==========Main body of doDraw==================
      this._elementsToClear.push( this.renderAxisLine());

      tLabels.forEach( measureOneBin);
      while( tLabelSpecs.length > tNumBins) {
        var tSpec = tLabelSpecs.pop();
        tSpec.element.remove();
      }
      if( tCollision) // labels must be perpendicular to axis
        tRotation = tIsHorizontal ? -90 : 0;
      tLabelSpecs.forEach( drawOneCell);

      this.set('labelSpecs', tLabelSpecs);

      this.renderLabel();
      // By changing maxLabelExtent we can trigger notification that causes the graph to re-layout
      // axes and plot if needed.
      var tNewExtent;
      switch (tOrientation) {
        case DG.GraphTypes.EOrientation.kHorizontal:
          tNewExtent = (tRotation === 0) ? tMaxHeight : tMaxWidth;
          break;
        case DG.GraphTypes.EOrientation.kVertical:
          tNewExtent = (tRotation === 0) ? tMaxWidth : tMaxHeight;
          break;
      }
      this.setIfChanged('maxLabelExtent', tNewExtent);
    }

  };
}())
);


/* >>>>>>>>>> BEGIN source/components/graph/axes/cell_axis_model.js */
// ==========================================================================
//                          DG.CellAxisModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/axes/axis_model');

/** @class  DG.CellAxisModel - The model for a graph axis.

  @extends SC.Object
*/
DG.CellAxisModel = DG.AxisModel.extend(
/** @scope DG.CellAxisModel.prototype */ 
{
  /**
    Determined by asking attributeStats
    @property{Number} >= 1
  */
  numberOfCells: function() {
    return Math.max( 1, this.getPath('attributeDescription.attributeStats.numberOfCells'));
  }.property(),

  cellNames: function() {
    var tNames = [],
        tAttribute = this.getPath('attributeDescription.attribute');
    if( tAttribute) {
      tAttribute.forEachCategory( function( iCategory) {
        tNames.push( iCategory);
      });
    }
    return tNames;
  }.property(),

  numberOfCellsDidChange: function() {
    this.notifyPropertyChange('numberOfCells');
  }.observes('*attributeDescription.attributeStats.numberOfCells'),

  numberOfCategoriesLimitDidChange: function() {
    this.notifyPropertyChange('numberOfCategoriesLimit');
  }.observes('*attributeDescription.attributeStats.number_of_categories_limit'),

  /**
    Iterates through cells to find name with maximum length
    @property{Number}
  */
  maxCellNameLength: function() {
    var tMaxLength = 0;
    this.forEachCellDo( function( iIndex, iName) {
      tMaxLength = Math.max( tMaxLength, iName.length);
    });
    return tMaxLength;
  }.property()/*.cacheable()*/,
  maxCellNameLengthDidChange: function() {
    this.notifyPropertyChange('maxCellNameLength');
  }.observes('*attributeDescription.attributeStats.cellMap'),

  /**
    @property {Boolean}
  */
  isNumeric: false,

  /**
    @return{Number} corresponding to given name
  */
  cellNameToCellNumber: function( iCellName) {
    var stats = this.getPath('attributeDescription.attributeStats');
    return stats ? stats.cellNameToCellNumber( iCellName) : 0;
  },

  /**
   * For a cell axis, not all the underlying categories need be displayed; e.g. if a given
   * category has no points, it will not appear.
   * Use this routine to compute the underlying index in the cellMap from the displayed index.
   * @param {Number} iDisplayedIndex
   * @return {Number}
   */
  displayedCellIndexToUnderlyingIndex: function( iDisplayedIndex) {
    var tCellMap = this.getPath('attributeDescription.attributeStats.cellMap'),
        tAttribute = this.getPath('attributeDescription.attribute'),
        tCellIndex = 0,
        tResult = iDisplayedIndex;
    if( DG.ObjectMap.length(tCellMap) > 0) {
      tAttribute.forEachCategory(function (iName, iColor, iIndex) {
        var tValues = tCellMap[iName],
            tNumUses = tValues ? tValues.cases.length : 0;
        if (tNumUses > 0) {
          if( tCellIndex === iDisplayedIndex)
            tResult = iIndex;
          tCellIndex++;
        }
      });
    }
    return tResult;
  },
  
  /**
   * For a cell axis, not all the underlying categories need be display; e.g. if a given
   * category has no points, it will not appear.
   * Use this routine to compute the displayed index on the axis from the underlying index.
   * @param {Number} iUnderlyingIndex
   * @return {Number}
   */
  underlyingIndexToDisplayedIndex: function( iUnderlyingIndex) {
    var tCellMap = this.getPath('attributeDescription.attributeStats.cellMap'),
        tAttribute = this.getPath('attributeDescription.attribute'),
        tDisplayedIndex = 0,
        tResult = iUnderlyingIndex;
    if( DG.ObjectMap.length(tCellMap) > 0) {
      tAttribute.forEachCategory(function (iName, iColor, iIndex) {
        if( iIndex === iUnderlyingIndex)
          tResult = tDisplayedIndex;
        var tValues = tCellMap[iName],
            tNumUses = tValues ? tValues.cases.length : 0;
        if (tNumUses > 0) {
          tDisplayedIndex++;
        }
      });
    }
    return tResult;
  },

  /**
    Go through each of the cells passing the given function, whose signature
      is ( iCellIndex, iName, iNumUses, iNumSelected )
  */
  forEachCellDo: function( iCellFunc) {
    var tCellMap = this.getPath('attributeDescription.attributeStats.cellMap'),
        tAttribute = this.getPath('attributeDescription.attribute'),
        tCellIndex = 0;
    if( DG.ObjectMap.length(tCellMap) === 0)
      iCellFunc( 0, '', 0, 0);  // There is always at least one cell
    else {
      tAttribute.forEachCategory(function (iName, iColor, iIndex) {
        var tValues = tCellMap[iName],
            tNumUses = tValues ? tValues.cases.length : 0,
            tNumSelected = 0;
        if (tNumUses > 0) {
          iCellFunc(tCellIndex++, iName, tNumUses, tNumSelected);
        }
      });
      if( tCellMap[DG.PlotUtilities.kOther])
        iCellFunc(tCellIndex++, "DG.CellAxis.other".loc(), tCellMap[DG.PlotUtilities.kOther].cases.length);
    }
  }
  
});


/* >>>>>>>>>> BEGIN source/components/graph/axes/cell_axis_view.js */
// ==========================================================================
//                            DG.CellAxisView
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/axes/axis_view');

/** @class  DG.CellAxisView - The view for a graph axis that displays cells.

 @extends DG.AxisView
 */
DG.CellAxisView = DG.AxisView.extend( (function() {
  var kTickLength = 4,
      kAxisGap = 2;

  return {
    /** @scope DG.CellAxisView.prototype */

    displayProperties: ['centering'],

    /**
     Number of pixels required from the axis line to the edge of the graph view
     @property { Number }
     */
    desiredExtent: function() {
      var tExtent = arguments.callee.base.apply(this,arguments),
          kWidthFudge = 5;
      if( !this.get('isNumeric')) { // Not yet handling numeric axis broken up by cells
        tExtent += kTickLength + kAxisGap + kWidthFudge + this.get('maxLabelExtent');
      }
      return tExtent;
    }.property('maxLabelExtent'),

    /**
     * When we are the "other" axis, our partner needs to know how much to offset pixelMin.
     * For me, it's the same as desiredExtent
     * @property {Number}
     */
    pixelMinOffset: function() {
      return this.get('desiredExtent');
    }.property('desiredExtent'),

    /**
     I'm not supposed to work with numbers.
     @property { Boolean }
     */
    isNumeric: false,

    /**
     * @property {Boolean}
     */
    centering: false,

    /**
     * @property { Object { cellBeingDragged: {Integer}, position: {Number}}}
     */
    dragInfo: null,

    /**
     @property {Number} Each time we draw the axis, we set this property to the maximum width
     of the label strings. Note that this will change depending not only on the length of the
     strings but on the rotation of the labels.
     */
    maxLabelExtent: 0,

    /**
     The convention is that, unlike continuous axes, for a
     vertical axis, the low numbers are at the top.
     @param {Number} in screen coordinates
     @return {Number} the cell number corresponding to the given screen coordinate
     */
    whichCell: function( iCoord) {
      var tNumCells = this.getPath('model.numberOfCells'),
          tCell = 0;
      if( tNumCells > 1) {
        var tPixelMin = this.get('pixelMin'),
            tPixelMax = this.get('pixelMax');
        // In order to do the computation, we have to adjust for the coordinates of the ends
        // of the axes, knowing the thePixel is in plot view coordinates, not axis view coordinates.
        if( this.get('isVertical')) {
          iCoord = Math.min( Math.max( tPixelMax + 1, iCoord), tPixelMin - 1);
          tCell = Math.floor( (tPixelMin - iCoord) * tNumCells / ( tPixelMin - tPixelMax));
        }
        else {  // horizontal
          iCoord = Math.max( Math.min( tPixelMax - tPixelMin - 1, iCoord), 1.0);
          tCell = Math.floor( iCoord * tNumCells / ( tPixelMax - tPixelMin));
        }

        //      KCP_ASSERT( (tCell >= 0) && (tCell < tNumCells));
      }
      return tCell;
    },

    /**
     Override base class to account for drag in progress
     @return {Number} coordinate of the given cell.
     */
    cellToCoordinate: function (iCellNum, iIgnoreDragging) {
      var tDragInfo = this.get('dragInfo');
      if( !iIgnoreDragging && tDragInfo && tDragInfo.draggingInProgress && iCellNum === tDragInfo.cellBeingDragged) {
        return tDragInfo.position;
      }
      else {
        return arguments.callee.base.apply(this,arguments);
      }
    },

    /**
     Since I'm a leaf class I implement doDraw.
     */
    doDraw: function doDraw() {

      // We can get stuck if we have height or width of zero
      var tFrame = this.get('frame');
      if( !tFrame || (tFrame.height === 0 || tFrame.width === 0))
        return;

      var this_ = this,
          kHorizontalOrientations = [DG.GraphTypes.EOrientation.kHorizontal, DG.GraphTypes.EOrientation.kTop],
          tModel = this.get('model'),
          tNumCells = tModel.get('numberOfCells'),
          tBaseline = this_.get('axisLineCoordinate'),
          tOrientation = this.get('orientation'),
          tIsHorizontal = kHorizontalOrientations.indexOf( tOrientation) >= 0,
          tRotation = tIsHorizontal ? 0 : -90, // default to parallel to axis
          tCursorClass = tIsHorizontal ? 'dg-axis-cell-label-x' : 'dg-axis-cell-label-y',
          tMaxHeight = DG.RenderingUtilities.kDefaultFontHeight,  // So there will be a default extent
          tCentering = this.get('centering'),
          tTickOffset = tCentering ? 0 : this.get('fullCellWidth') / 2,
          tAnchor = tCentering ? 'middle' : 'start',
          tMaxWidth = tMaxHeight,
          tLabelSpecs = this.get('labelSpecs') || [],
          tCollision = false,
          tPrevLabelEnd,
          tDragStartCoord, tCellBeingDragged, tOriginalCellIndex, tStartingCellnames; // eslint-disable-line no-unused-vars

      var beginDrag = function ( iWindowX, iWindowY) {
            tStartingCellnames = this_.getPath('model.cellNames');
            tOriginalCellIndex = tCellBeingDragged = this.cellNum;
            tDragStartCoord = DG.ViewUtilities.windowToViewCoordinates({x: iWindowX, y: iWindowY}, this_);
            tDragStartCoord = tIsHorizontal ? tDragStartCoord.x : tDragStartCoord.y;
          },
          doDrag = function (iDeltaX, iDeltaY, iWindowX, iWindowY) {
            var tModel = this_.get('model'),
                tCurrentCoord = tDragStartCoord + (tIsHorizontal ? iDeltaX : iDeltaY),
                tCategoryInCurrentCell = this_.whichCell( tCurrentCoord);
            // Todo Touch is currently returning NaN for window coordinates. Fix this
            if( isNaN(tCurrentCoord))
                return;
            SC.run(function() {
              if( tCategoryInCurrentCell !== tCellBeingDragged) {
                tCellBeingDragged = tModel.underlyingIndexToDisplayedIndex(
                    swapCategories(tModel.get('attributeDescription'),
                        tModel.displayedCellIndexToUnderlyingIndex(tCategoryInCurrentCell),
                        tModel.displayedCellIndexToUnderlyingIndex(tCellBeingDragged)));
              }
              this_.set('dragInfo', {
                cellBeingDragged: tCellBeingDragged, position: tCurrentCoord,
                draggingInProgress: true
              });
              this_.displayDidChange();
              this_.propertyDidChange('categoriesDragged');
            });
          },
          endDrag = function ( iEvent) {
            SC.run(function() {
              this_.set('dragInfo', null);
              this_.displayDidChange();
              this_.propertyDidChange('categoriesDragged');
              this_.updateLayerIfNeeded();
            });
            if( tOriginalCellIndex !== tCellBeingDragged) {
              var tCat1 = tStartingCellnames[tOriginalCellIndex],
                  tCat2 = tStartingCellnames[tCellBeingDragged];
              DG.UndoHistory.execute(DG.Command.create({
                name: 'swapCategories',
                undoString: 'DG.Undo.graph.swapCategories',
                redoString: 'DG.Redo.graph.swapCategories',
                log: 'Moved category %@ into position of %@'.fmt(tCat1, tCat2),
                _initialCell: tOriginalCellIndex,
                _finalCell: tCellBeingDragged,
                _axisModel: this_.get('model'),
                executeNotification: {
                  action: 'notify',
                  resource: 'component',
                  values: {
                    operation: 'swap categories',
                    type: 'DG.GraphView'
                  }
                },
                execute: function () {
                },
                undo: function () {
                  swapCategories( this._axisModel.get('attributeDescription'),
                      this._initialCell, this._finalCell);
                  var temp = this._initialCell;
                  this._initialCell = this._finalCell;
                  this._finalCell = temp;
                },
                redo: function () {
                  this.undo();
                }
              }));
            }
          },
          swapCategories = function( iAttributeDescription, iCat1, iCat2) {
            var tSign = Math.sign(iCat1 - iCat2),
                tCellToSwap = iCat2 + tSign;
            // Insist on pairwise swaps until we get one beyond iCat1
            while (tCellToSwap !== iCat1 + tSign) {
              DG.PlotUtilities.swapCategoriesByIndex(iAttributeDescription, iCat2, tCellToSwap);
              tCellToSwap += tSign;
              iCat2 += tSign;
            }
            return iCat2;
          };

      function setLimitToNumCellsToDraw() {
        var tDrawingSpace = Math.abs(this_.get('pixelMax') - this_.get('pixelMin')),
            tLimit = Math.floor(tDrawingSpace / DG.RenderingUtilities.kDefaultFontHeight);
        this_.setPathIfChanged('model.attributeDescription.number_of_categories_limit', tLimit);
      }

      function measureOneCell( iCellNum, iCellName) {
        var tCoord = this_.cellToCoordinate(iCellNum);
        if( !isFinite( tCoord)) {
          return;
        }
        var tTextElement;
        if( !tLabelSpecs[iCellNum]) {
          tTextElement = this_.get('paper').text(0, 0, iCellName)
              .addClass('dg-axis-tick-label')
              .addClass(tCursorClass)
              .drag(doDrag, beginDrag, endDrag);
        }
        else {
          tTextElement = tLabelSpecs[ iCellNum].element;
          tTextElement.attr('text', iCellName);
        }
        var tTextExtent = DG.RenderingUtilities.getExtentForTextElement(
                          tTextElement, DG.RenderingUtilities.kDefaultFontHeight, true /* compute with no transform */);

        tTextElement.cellNum = iCellNum;
        tLabelSpecs[iCellNum] = { element: tTextElement, coord: tCoord,
                      height: tTextExtent.height, width: tTextExtent.width };

        tMaxHeight = Math.max( tMaxHeight, tTextExtent.height);
        tMaxWidth = Math.max( tMaxWidth, tTextExtent.width);
        if(SC.none( tPrevLabelEnd)) {
          tCollision = tTextExtent.width > this_.get('fullCellWidth');
          tPrevLabelEnd = tIsHorizontal ? tCoord + tTextExtent.width / 2 : tCoord - tTextExtent.width / 2;
        }
        else if( tIsHorizontal) {
          tCollision = tCollision || (tCoord - tTextExtent.width / 2 < tPrevLabelEnd);
          tPrevLabelEnd = (tCoord + tTextExtent.width / 2);
        }
        else {  // vertical
          tCollision = tCollision || (tCoord + tTextExtent.width / 2 > tPrevLabelEnd);
          tPrevLabelEnd = (tCoord - tTextExtent.width / 2);
        }
      } // measureOneCell

      // iLabelSpec has form { element: {Raphael element}, coord: {Number}, height: {Number}, width: {Number} }
      function drawOneCell( iLabelSpec, iIndex) {
        var tCoord = iLabelSpec.coord,
            // tTextHeight = iLabelSpec.height,
            tLabelX, tLabelY;
        switch( this_.get('orientation')) {
          case DG.GraphTypes.EOrientation.kVertical:
          case DG.GraphTypes.EOrientation.kVertical2:
            this_._elementsToClear.push(
              this_.get('paper').line( tBaseline, tCoord + tTickOffset, tBaseline - kTickLength, tCoord + tTickOffset)
                .attr( { stroke: DG.PlotUtilities.kAxisColor }));
            tLabelX = tBaseline - kTickLength - kAxisGap - iLabelSpec.height / 3;
            tLabelY = tCoord + tTickOffset - ((iIndex === 0 && !tCentering) ? iLabelSpec.height / 2 : 0);
            if( tRotation === 0) {
              tAnchor = 'end';
              if( iLabelSpec.width > tLabelX && tLabelX > 10) {
                DG.RenderingUtilities.elideToFit( iLabelSpec.element, tLabelX);
              }
            }
            break;

          case DG.GraphTypes.EOrientation.kHorizontal:
            this_._elementsToClear.push(
              this_.get('paper').line( tCoord - tTickOffset, tBaseline, tCoord - tTickOffset, tBaseline + kTickLength)
                .attr( { stroke: DG.PlotUtilities.kAxisColor }));
            tLabelX = tCoord - tTickOffset + 1;
            tLabelY = tBaseline + kTickLength + kAxisGap + iLabelSpec.height / 3;
            if( tRotation === -90) {
              tAnchor = 'end';
              if( iIndex === 0 && !tCentering)
                tLabelX += iLabelSpec.height / 3;
              if( iLabelSpec.width > tFrame.height - tLabelY && tFrame.height - tLabelY > 10)
                DG.RenderingUtilities.elideToFit( iLabelSpec.element, tFrame.height - tLabelY);
            }
            break;
          case DG.GraphTypes.EOrientation.kTop:
            this_._elementsToClear.push(
                this_.get('paper').line( tCoord - tTickOffset, tBaseline, tCoord - tTickOffset, tBaseline - kTickLength)
                    .attr( { stroke: DG.PlotUtilities.kAxisColor }));
            tLabelX = tCoord - tTickOffset + 1;
            tLabelY = tBaseline - kTickLength - kAxisGap - iLabelSpec.height / 3;
            if( tRotation === -90) {
              var tAxisLabelHeight = this_.get('labelExtent').y;
              tAnchor = 'start';
              if( iIndex === 0)
                tLabelX += iLabelSpec.height / 3;
              if( iLabelSpec.width > tLabelY - tAxisLabelHeight && tLabelY - tAxisLabelHeight > 10)
                DG.RenderingUtilities.elideToFit( iLabelSpec.element, tLabelY - tAxisLabelHeight);
            }
            break;
          case DG.GraphTypes.EOrientation.kRight:
            this_._elementsToClear.push(
                this_.get('paper').line( tBaseline, tCoord + tTickOffset, tBaseline + kTickLength, tCoord + tTickOffset)
                    .attr( { stroke: DG.PlotUtilities.kAxisColor }));
            tLabelX = tBaseline + kTickLength + kAxisGap + iLabelSpec.height / 3;
            tLabelY = tCoord + tTickOffset;
            if( tRotation === 0) {
              var tAxisLabelWidth = this_.get('labelExtent').x;
              tAnchor = 'start';
              if( iLabelSpec.width > tFrame.width - tLabelX - tAxisLabelWidth) {
                DG.RenderingUtilities.elideToFit(iLabelSpec.element, tFrame.width - tLabelX- tAxisLabelWidth);
              }
            }
            break;
        }
        iLabelSpec.element.attr( { x: tLabelX, y: tLabelY, 'text-anchor': tAnchor });
        DG.RenderingUtilities.rotateText( iLabelSpec.element, tRotation, tLabelX, tLabelY);
      } // drawOneCell

      //==========Main body of doDraw==================
      setLimitToNumCellsToDraw();

      // Special case for short labels
      if( this.getPath('model.maxCellNameLength') <= 3)
        tRotation = 0;

      this._elementsToClear.push( this.renderAxisLine());

      tModel.forEachCellDo( measureOneCell);
      while( tLabelSpecs.length > tNumCells) {
        var tSpec = tLabelSpecs.pop();
        tSpec.element.remove();
      }
      if( tCollision) // labels must be perpendicular to axis
        tRotation = tIsHorizontal ? -90 : 0;
      tLabelSpecs.forEach( drawOneCell);

      this.set('labelSpecs', tLabelSpecs);

      this.renderLabel();
      // By changing maxLabelExtent we can trigger notification that causes the graph to re-layout
      // axes and plot if needed.
      var tNewExtent;
      switch (tOrientation) {
        case DG.GraphTypes.EOrientation.kHorizontal:
        case DG.GraphTypes.EOrientation.kTop:
          tNewExtent = (tRotation === 0) ? tMaxHeight : tMaxWidth;
          break;
        case DG.GraphTypes.EOrientation.kVertical:
        case DG.GraphTypes.EOrientation.kVertical2:
        case DG.GraphTypes.EOrientation.kRight:
          tNewExtent = (tRotation === 0) ? tMaxWidth : tMaxHeight;
          break;
      }
      this.setIfChanged('maxLabelExtent', tNewExtent);
    }

  };
}())
);


/* >>>>>>>>>> BEGIN source/components/graph/axes/cell_linear_axis_model.js */
// ==========================================================================
//                        DG.CellLinearAxisModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/axes/cell_axis_model');

/** @class  DG.CellLinearAxisModel - The model for a graph axis.

  @extends DG.CellAxisModel
*/
DG.CellLinearAxisModel = DG.CellAxisModel.extend(
/** @scope DG.CellLinearAxisModel.prototype */
{
  /**
    The gap between tick marks in world coordinates.
    @property { Number }
  */
  tickGap: null,

  /**
    The lower bound of the axis in world coordinates.
    @property { Number }
  */
  __lowerBound: null,
  lowerBound: function( iKey, iValue) {
    if( !SC.none( iKey) && !SC.none( iValue))
        this.__lowerBound = iValue;
    return this.__lowerBound;
  }.property(),

  /**
    The upper bound of the axis in world coordinates.
    @property { Number }
  */
  __upperBound: null,
  upperBound: function( iKey, iValue) {
    if( !SC.none( iKey) && !SC.none( iValue))
      this.__upperBound = iValue;
    return this.__upperBound;
  }.property(),

  /**
   * Prefer a zero lower bound for axis when supported by data.
   * @property { boolean }
   */
  preferZeroLowerBound: false,

  /**
   * Draw a grid line at zero.
   * @property { boolean }
   */
  drawZeroLine: false,

  /**
    Should the zero be locked at one end of the axis?
    @property { boolean }
  */
  lockZero: function( iKey, iLockZero) {
    if( iLockZero !== undefined) {
      this.beginPropertyChanges();
      this.set('_lockZero', iLockZero);
      if( iLockZero)
        this.set( 'lowerBound', 0);
      else
        this.setDataMinAndMax( this._lowerBound, this._upperBound);
      this.endPropertyChanges();
    }
    return this._lockZero;
  }.property( '_lockZero').cacheable(),

  /**
    Should decimal tick values be suppressed (as for a frequency axis)?
    @property { boolean }
  */
  displayOnlyIntegers: false,

  /**
    @property {Boolean}
  */
  isNumeric: true,

  /**
   * @property {Boolean}
   */
  scaleCanAnimate: true,

  /**
    The actual lower bounds from which the apparent lower bounds is computed.
      @private
    @property { Number }
  */
  _lowerBound: null,

  /**
    The actual upper bounds from which the apparent upper bounds is computed.
      @private
    @property { Number }
  */
  _upperBound: null,

  init: function() {
    arguments.callee.base.apply(this,arguments);
    this.attributeDescriptionDidChange();
  },

  attributeDescriptionDidChange: function() {
    var tAttrDesc = this.get('attributeDescription');
    if( tAttrDesc && Number(tAttrDesc.getPath('attribute.precision')) === 0)
      this.set('displayOnlyIntegers', true);
  }.observes('attributeDescription'),

  /**
    Override (for now) because superclass will compute it wrong!
    @property{Number} >= 1
  */
  numberOfCells: function() {
    return 1;
  }.property(),

   /**
      @private
    @property { boolean }
  */
  _lockZero: false,

  /**
  We set lower and upper bounds without notifying until after the change
  is complete. Since clients rely on notification from the operands, we
  cause either or both of them to notify as necessary.
  We keep the tickGap in synch with the bounds because this routine is called
  during animation and the tickGap needs to change as the bounds change.

    @param {Number} iLower - desired world coordinate lower bound
    @param {Number} iUpper - desired world coordinate upper bound
  */
  setLowerAndUpperBounds: function( iLower, iUpper, iWithAnimation) {
    iWithAnimation = iWithAnimation || false;
    if( iWithAnimation) {
      if( SC.none( this.axisAnimator))
        this.axisAnimator = DG.GraphAnimator.create();
      this.axisAnimator
          .set('axisInfoArray', [{ axis: this, newBounds: {lower: iLower, upper: iUpper} }])
          .animate();
    }
    else {
      this.beginPropertyChanges();
      // Change to private variables so they don't get out of synch.
      this._lowerBound = iLower;
      this._upperBound = iUpper;
      this.setIfChanged('lowerBound', iLower);
      this.setIfChanged('upperBound', iUpper);
      this.setIfChanged('tickGap', this._computeTickGap(iLower, iUpper));
      this.endPropertyChanges();
    }
  },

  /**
    Translate the bounds of the axis by the given delta
    @param {Number} iDelta - The amount by which the bounds will be translated
  */
  translate: function( iDelta) {
    if( (iDelta === 0) || this._lockZero)
      return; // Can't translate when zero is locked.
    this.beginPropertyChanges();
    this._lowerBound += iDelta;
    this._upperBound += iDelta;
    this._setBoundsFromInternalBounds();
    this.endPropertyChanges();
  },

  /**
    Translate the bounds of the axis by the given delta
    @param {Number} iFixedValue - Will remain constant
    @param {Number} iFactor - The dilation amount
    @return {{lower: {Number}, upper: {Number}}}
  */
  computeBoundsForDilation: function( iFixedValue, iFactor) {
    var tNewLower = (!this._lockZero || (this._lowerBound !== 0)) ?
                      iFixedValue + (this._lowerBound - iFixedValue) * iFactor :
                      this._lowerBound,
        tNewUpper = (!this._lockZero || (this._upperBound !== 0)) ?
                      iFixedValue + (this._upperBound - iFixedValue) * iFactor :
                      this._upperBound;
    return {lower: tNewLower, upper: tNewUpper};
  },

  /**
    Dilate the axes by the given ratio leaving fixedValue constant.
    @param {Number} iFixedValue - Will remain constant
    @param {Number} iFactor - The dilation amount
    @param {Boolean} Should the dilation be accomplished with animation. Default is false.
  */
  dilate: function( iFixedValue, iFactor, iWithAnimation) {
    var tNewBounds = this.computeBoundsForDilation( iFixedValue, iFactor);
    iWithAnimation = iWithAnimation || false;
    if( iWithAnimation) {
      if( SC.none( this.axisAnimator))
        this.axisAnimator = DG.GraphAnimator.create();
      this.axisAnimator
          .set('axisInfoArray', [{ axis: this, newBounds: tNewBounds }])
          .animate();
    }
    else {
      this._lowerBound = tNewBounds.lower;
      this._upperBound = tNewBounds.upper;

      if( this._setBoundsFromInternalBounds()) {
        this.beginPropertyChanges();
        this._resetTickGap( this.get('lowerBound'), this.get('upperBound'));
        this._handleAxisChange();
        this.endPropertyChanges();
      }
    }
  },

  /**
    My data range has changed. Recompute a reasonable _lowerBound and
    _upperBound.

    If iAllowRangeToShrink is false, we will keep the current bounds if they
    are wide enough to encompass the new dataMin and dataMax.

    @param {Number} iDataMin - the data provide this value
    @param {Number} iDataMax - the data provide this value
    @param {boolean} iAllowRangeToShrink - If true, we can shrink the current bounds
  */
  setDataMinAndMax: function( iDataMin, iDataMax, iAllowRangeToShrink) {
    // If we're not allowed to shrink, don't let null iDataMin or iDataMax force us to do anything
    if( !iAllowRangeToShrink && (SC.none( iDataMin) || SC.none( iDataMax)))
      return;

    // If we're not allowed to shrink and the current bounds will handle the given min and max, we can bail
    if( !iAllowRangeToShrink &&
        (iDataMin >= this.get('lowerBound')) && (iDataMax <= this.get('upperBound')))
      return;

    this._resetScale(iDataMin, iDataMax);

    // There are special conditions having to do with multiples that require us
    // to call both _setBoundsFromInternalBounds and _resetTickGap. If either
    // returns true, then we have _handleAxisChange.
    var tSetBoundsResult = this._setBoundsFromInternalBounds(),
        tResetTickGapResult = this._resetTickGap( this.get('lowerBound'),
                                                  this.get('upperBound'));
    if ( tSetBoundsResult || tResetTickGapResult)
      this._handleAxisChange();
  },

  /**
  Recompute lowerBound, upperBound and tickGap for each subaxis

    @param {Number} iDataMin - the data provide this value
    @param {Number} iDataMax - the data provide this value
    @protected
  */
  _resetScale: function( iDataMin, iDataMax) {
    var tNewParams = this._computeBoundsAndTickGap( iDataMin, iDataMax);
    this.set('tickGap', tNewParams.gap);
    this._lowerBound = tNewParams.lower;
    this._upperBound = tNewParams.upper;
  },

  /**
  Recompute lowerBound, upperBound and tickGap for each subaxis

    @param {Number} iDataMin - the data provide this value
    @param {Number} iDataMax - the data provide this value
    @return { {lower: {Number}, upper: {Number}, gap: {Number}} }
    @protected
  */
  _computeBoundsAndTickGap: function( iDataMin, iDataMax) {
    var kFactor = 2.5,
        tType = this.getPath('attributeDescription.attributeType'),
        tDefaultConstants = defaultsForType( tType),
        tTickGap;

    function defaultsForType( iType) {
      switch( iType) {
        case DG.Analysis.EAttributeType.eDateTime:
          return {
            min: Date.now() / 1000 - 10 * 24 * 60 * 60,
            max: Date.now() / 1000,
            addend: 5 * 24 * 60 * 60
          };
        case DG.Analysis.EAttributeType.eNumeric:
          /* falls through */
        default:
          return {
            min: 0,
            max: 10,
            addend: 5
          };
      }
    }

    // We can get in here with dataMax < iDataMin if there are no values.
    // should not rely on min/max being real or +/- inf.
    if ( !DG.isFinite( iDataMax) || !DG.isFinite( iDataMin) || (iDataMax < iDataMin)) {
      // If the attribute description has defaults, we use them. Otherwise arbitrarily set range from 0..10
      var tDefaultMin = this.getPath('attributeDescription.attribute.defaultMin' ),
          tDefaultMax = this.getPath('attributeDescription.attribute.defaultMax' );
      iDataMin = SC.none( tDefaultMin) ? tDefaultConstants.min : tDefaultMin;
      iDataMax = SC.none( tDefaultMax) ? tDefaultConstants.max : tDefaultMax;
    }
    else if( (iDataMin === iDataMax) && (iDataMin === 0)){
      iDataMin = -10;
      iDataMax = 10;
    }
    else if( (iDataMin === iDataMax) && (Math.floor(iDataMin) === iDataMin)) {
      // Place the value in the middle of a scale that extends a fixed amount in each direction
      iDataMax += tDefaultConstants.addend;
      iDataMin -= tDefaultConstants.addend;
    }
    else if( iDataMin === iDataMax) {
      switch( tType) {
        case DG.Analysis.EAttributeType.eNumeric:
          // Place the value in the middle of a scale that extends 10% of the value in each direction
          iDataMax = iDataMin + 0.1 * Math.abs( iDataMin);
          iDataMin = iDataMin - 0.1 * Math.abs( iDataMin);
          break;
        case DG.Analysis.EAttributeType.eDateTime:
          // Place the value in the middle of a scale that extends a fixed amount in each direction
          iDataMax += tDefaultConstants.addend;
          iDataMin -= tDefaultConstants.addend;
          break;
      }
    }
    else if( tType === DG.Analysis.EAttributeType.eNumeric) { // Here we can snap to zero
      if( (iDataMin > 0) && (iDataMax > 0) && (iDataMin <= iDataMax / kFactor))
        iDataMin = 0;
      else if( (iDataMin < 0) && (iDataMax < 0) && (iDataMax >= iDataMin / kFactor))
        iDataMax = 0;
    }
    tTickGap = this._computeTickGap( iDataMin, iDataMax);
    return { lower: this._findLow( iDataMin, tTickGap),
              upper: this._findHigh( iDataMax, tTickGap),
              gap: tTickGap };
  },

  /**
    @param {Number} iDataMin - the data provide this value
    @param {Number} iDataMax - the data provide this value
    @return {Number} the new tickGap
    @protected
  */
  _computeTickGap: function( iDataMin, iDataMax) {
    var tRange = (iDataMin >= iDataMax) ? Math.abs( iDataMin) : iDataMax - iDataMin,
        tTickGap = this._goodTickValue( tRange / 5);
    // If we're set to only show integers, we have to make sure
    // that tickGap is at least one.
    if (this.displayOnlyIntegers && (tTickGap < 1))
      tTickGap = 1;

    return tTickGap;
  },

  /**
    @param {Number} iDataMin - the data provide this value
    @param {Number} iDataMax - the data provide this value
    @return {boolean} true if new tickgap is different than pre-existing one
    @protected
  */
  _resetTickGap: function( iDataMin, iDataMax) {
    var tOldTickGap = this.tickGap,
        tNewTickGap = this._computeTickGap( iDataMin, iDataMax);

    this.set('tickGap', tNewTickGap);

    return tOldTickGap !== tNewTickGap;
  },

  /**
  Use the internal bounds to set the apparent bounds. If either bound
  is "close" to zero, snap it to zero.

  Don't use this algorithm if there is a transformation in place
  because a transformation typically has trouble with zero.

    @return {boolean} True if either apparent bounds changes, false otherwise.
    @private
  */
  _setBoundsFromInternalBounds: function() {
    var kGrabFraction = 0.05,
        tSavedLower = this.get('lowerBound'),
        tSavedUpper = this.get('upperBound'),
        tGrabRange = (this._upperBound - this._lowerBound) * kGrabFraction;

    this.beginPropertyChanges();
    if ((this.get( 'lockZero') || ((this._lowerBound > 0) && (this._lowerBound - tGrabRange < 0))))
      this.set( 'lowerBound', 0);
    else
      this.set( 'lowerBound', this._lowerBound);

    if ((this._upperBound < 0)  && (this._upperBound + tGrabRange > 0))
      this.set( 'upperBound', 0);
    else
      this.set( 'upperBound', this._upperBound);
    this.endPropertyChanges();

    return (tSavedLower !== this.get('lowerBound')) ||
        (tSavedUpper !== this.get('upperBound'));
},

  /**
  A change in my model can trigger a change in how I handle leading or
  trailing zeroes.

    @private
  */
  _handleAxisChange: function() {
    // Do nothing until we're ready to deal with leading or trailing zeroes
  },

  /**
    @param {Number} iDataMin - the data provide this value
    @param {Number} iTickGap - the gap between ticks
    @return {Number} a reasonable value for the lower bounds
  */
  _findLow: function( iDataMin, iTickGap) {
    if ((iDataMin >= 0) && this.get('preferZeroLowerBound'))
      return 0;
    if( iTickGap !== 0)
      return (Math.floor( iDataMin / iTickGap) - 0.5) * iTickGap;
    else
      return iDataMin - 1;
  },

  /**
    @param {Number} iDataMax - the data provide this value
    @param {Number} iTickGap - the gap between ticks
    @return {Number} a reasonable value for the uppax bounds
  */
  _findHigh: function( iDataMax, iTickGap) {
    if( iTickGap !== 0)
      return (Math.floor( iDataMax / iTickGap) + 1.5) * iTickGap;
    else
      return iDataMax + 1;
  },

  /**
    Computes a good major tick value from a trial value. It will be the next
      lowest value of the form 1, 2, 5, 10, ...
    @param {Number} iTrial - a suggested tick value
  */
  _goodTickValue: function( iTrial) {
    return DG.MathUtilities.goodTickValue( iTrial);
  }

});

/* >>>>>>>>>> BEGIN source/components/graph/axes/cell_linear_axis_view.js */
// ==========================================================================
//                          DG.CellLinearAxisView
// 
//  A view of a linear axis possibly broken into cells.
//  
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/axes/cell_axis_view');

/** @class

  An axis with a numeric scale, possible broken into cells.

  @extends DG.CellAxisView
*/
DG.CellLinearAxisView = DG.CellAxisView.extend(
/** @scope DG.CellLinearAxisView.prototype */ (function() {
  var kAxisGap = 1,
      kTickLength = 4;

  return {

    displayProperties: 'model.lowerBound model.upperBound model.tickGap'.w(),

    /**
     * @property { DG.NumericAxisViewHelper or DG.DateTimeAxisViewHelper}
     */
    _axisViewHelper: null,
    axisViewHelper: function() {
      var tNewHelperClass = (this.get('isDateTime')) ?
          DG.DateTimeAxisViewHelper : DG.NumericAxisViewHelper;
      if( !this._axisViewHelper || tNewHelperClass !== this._axisViewHelper.constructor) {
        if(this._axisViewHelper)
          this._axisViewHelper.destroy();
        this._axisViewHelper = tNewHelperClass.create( {
          axisView: this
        });
      }
      return this._axisViewHelper;
    }.property('isDateTime'),

    attributeDidChange: function() {
      this._axisViewHelper = null;
    }.observes('model.attributeDescription.attribute'),

    /**
    I work with numbers.
      @return { Boolean }
    */
    isNumeric: true,

    isDateTime: function() {
      return this.getPath('model.attributeDescription.attributeType') ===
          DG.Analysis.EAttributeType.eDateTime;
    }.property(),
    attributeTypeChanged: function() {
      this.notifyPropertyChange('isDateTime');
    }.observes('model.attributeDescription.attributeType'),

    /**
      @property {Number} The coordinate at which the zero line should be drawn. Null if zero
        is not within axis bounds.
    */
    zeroPixel: function() {
      if( (0 >= this.getPath('model.lowerBound')) && (0 <= this.getPath('model.upperBound')))
        return this.dataToCoordinate( 0);
      else
        return null;
    }.property().cacheable(),
    zeroPixelDidChange: function() {
      this.notifyPropertyChange('zeroPixel');
    }.observes('*model.lowerBound', '*model.upperBound', 'pixelMin', 'pixelMax'),

    /**
      @property {Number} Each time we draw the axis, we set this property to the maximum width
        of the number label strings
    */
    maxNumberExtent: 0,

    /**
    coordToString
      @param {Number} location on axis
      @return {String}  Formatted version of world coordinate with decimals appropriate to axis
    */
    coordToString: function( iPixelValue) {
      var tData = this.coordinateToData( iPixelValue),
        tTickGap = this.getPath('model.tickGap'),
        tFracDigits = (tTickGap < 1) ? 1 + Math.ceil( Math.abs( Math.log( tTickGap) / Math.LN10)) : 0,
        tFormat;
      if( (tFracDigits === 0) && (tTickGap < 10))
        tFracDigits++;
      tFormat = DG.Format.number().group("").fractionDigits( 0, tFracDigits);
      return tFormat( tData);
    },

    /**
    We force display which will call createVisualization
    */
    prepareVisualization: function() {
      this.displayDidChange();
    },

    /**
    Called each time we have to regenerate or modify the visualization
    */
    doDraw: function doDraw() {
      var this_ = this,
          tOrientation = this.get('orientation');

      function setupEventHandling() {
        var tFrame = this_.get('frame'),
            tClickHandling = false,
            tLockZero = this_.getPath('model.lockZero');

        // Event handlers
        function beginDrag() {
          this_._dragPanel.show();
          this_._isDragging = true;
          DG.logUser("dragStart: { lower: %@, upper: %@ }",
            this_.getPath('model.lowerBound'), this_.getPath('model.upperBound'));
        }

        function endDrag() {
          this_._dragPanel.hide();
          this_._isDragging = false;
          var newLowerBound = this_.getPath('model.lowerBound'),
              newUpperBound = this_.getPath('model.upperBound'),
              oldLowerBound = this_._lowerBoundAtDragStart,
              oldUpperBound = this_._upperBoundAtDragStart,
              wasDilate = (newLowerBound === oldLowerBound || newUpperBound === oldUpperBound),
              tGraphView = this_.get('parentView'),
              tAxisKey, tGraphModelId;
          if      (tOrientation === DG.GraphTypes.EOrientation.kHorizontal) { tAxisKey = 'xAxisView'; }
          else if (tOrientation === DG.GraphTypes.EOrientation.kVertical)   { tAxisKey = 'yAxisView'; }
          else                                    { tAxisKey = 'y2AxisView'; }

          DG.ObjectMap.forEach(DG.currDocumentController().componentControllersMap, function(id, controller) {
            if (controller.get('graphView') === tGraphView) {
              tGraphModelId = id;
            }
          });

          DG.UndoHistory.execute(DG.Command.create({
            name: (wasDilate ? 'graph.axis.dilate' : 'graph.axis.drag'),
            undoString: (wasDilate ? 'DG.Undo.axisDilate' : 'DG.Undo.axisDrag'),
            redoString: (wasDilate ? 'DG.Redo.axisDilate' : 'DG.Redo.axisDrag'),
            log: "dragEnd: { lower: %@, upper: %@ }".fmt(newLowerBound, newUpperBound),
            _componentId: tGraphModelId,
            _controller: function() {
              return DG.currDocumentController().componentControllersMap[this._componentId];
            },
            _model: function() {
              return this._controller().getPath(tAxisKey+'.model');
            },
            executeNotification: {
              action: 'notify',
              resource: 'component',
              values: {
                operation: 'change axis bounds',
                newBounds: { lower: newLowerBound, upper: newUpperBound },
                type: 'DG.GraphView'
              }
            },
            execute: function() { },
            undo: function() {
              this._model().setLowerAndUpperBounds(oldLowerBound, oldUpperBound, true /* animate */ );
            },
            redo: function() {
              this._model().setLowerAndUpperBounds(newLowerBound, newUpperBound, true /* animate */ );
            }
          }));
        }

        function beginTranslate( iWindowX, iWindowY) {
          if( !tClickHandling) {
            beginDrag();
            this_._lowerBoundAtDragStart = this_.getPath('model.lowerBound');
            this_._upperBoundAtDragStart = this_.getPath('model.upperBound');
          }
        }

        function doTranslate( idX, idY) {
          SC.run(function () {
            if (!tClickHandling && this_._isDragging) {
              //DG.SoundUtilities.drag();
              var tDelta = this_.get('isVertical') ? idY : idX,
                  tHelper = this_.get('axisViewHelper'),
                  tLowerBound = this_.getPath('model.lowerBound'),
                  tCurrentDelta = tHelper.coordinateToDataGivenCell(0, 0) -
                      tHelper.coordinateToDataGivenCell(0, tDelta),
                  tIncDelta = tCurrentDelta - (tLowerBound - this_._lowerBoundAtDragStart);
                this_.get('model').translate(tIncDelta);
            }
          });
        }

        // We are dragging in the lower portion of the axis. The upper bound will remain fixed
        function beginLowerDilate( iWindowX, iWindowY) {
          if( !tClickHandling) {
            var tPoint = DG.ViewUtilities.windowToViewCoordinates(
                          { x: iWindowX, y: iWindowY }, this_);
            this_._dilationAnchorCoord =
                    this_.get( 'isVertical') ? tPoint.y : tPoint.x;
            this_._lowerBoundAtDragStart = this_.getPath('model.lowerBound');
            this_._upperBoundAtDragStart = this_.getPath('model.upperBound');
            beginDrag();
          }
        }

        function doLowerDilate( idX, idY) {
          SC.run(function() {
            if (!tClickHandling && this_._isDragging) {
              //DG.SoundUtilities.drag();
              var tLowerAtStart = this_.get('_lowerBoundAtDragStart'),
                  tUpper = this_.getPath('model.upperBound'),
                  tCurrDelta = this_.get('isVertical') ? idY : idX,
                  tFixed = this_.get('pixelMax'),
                  tDelta = tFixed - this_._dilationAnchorCoord,
                  tFactor = tDelta / (tDelta - tCurrDelta);
              if ((tFactor > 0) && (tFactor < 10)) {
                this_.setPath('model._lowerBound', tLowerAtStart);
                this_.get('model').dilate(tUpper, tFactor);
              }
            }
          });
        }

        // We are dragging in the lower portion of the axis. The upper bound will remain fixed
        function beginUpperDilate( iWindowX, iWindowY) {
          if( !tClickHandling) {
            var tPoint = DG.ViewUtilities.windowToViewCoordinates(
                          { x: iWindowX, y: iWindowY }, this_);
            this_._dilationAnchorCoord =
                    this_.get( 'isVertical') ? tPoint.y : tPoint.x;
            this_._upperBoundAtDragStart = this_.getPath('model.upperBound');
            this_._lowerBoundAtDragStart = this_.getPath('model.lowerBound');
            beginDrag();
          }
        }

        function doUpperDilate( idX, idY) {
          SC.run(function() {
            if( !tClickHandling && this_._isDragging) {
              //DG.SoundUtilities.drag();
              var tUpperAtStart = this_.get('_upperBoundAtDragStart'),
                  tLower = this_.getPath('model.lowerBound'),
                  tCurrDelta = this_.get('isVertical') ? idY : idX,
                  tFixed = this_.get('pixelMin'),
                  tDelta = tFixed - this_._dilationAnchorCoord,
                  tFactor = tDelta / (tDelta - tCurrDelta);
              if ((tFactor > 0) && (tFactor < 10)) {
                this_.setPath('model._upperBound', tUpperAtStart);
                this_.get('model').dilate(tLower, tFactor);
              }
            }
          });
        }

        function setRect( iElement, iX, iY, iWidth, iHeight) {
          iElement.attr( { x: iX, y: iY, width: iWidth, height: iHeight });
        }

        function handleMouseDown( iEvent) {
          tClickHandling = iEvent.altKey;
        }

        function handleMouseMove( iEvent) {
          var tZoomDirection;
          if( iEvent.altKey) {
            var magnifyPlusCursorUrl = '../../../../static/dg/de/cert/resources/cursors/MagnifyPlus.cur',
                magnifyMinusCursorUrl = '../../../../static/dg/de/cert/resources/cursors/MagnifyMinus.cur',
                cursorUrl = iEvent.shiftKey ? magnifyMinusCursorUrl : magnifyPlusCursorUrl;
            tZoomDirection = iEvent.shiftKey ? "out" : "in";
            this.attr( { cursor:DG.Browser.customCursorStr( cursorUrl, 8, 8),
                  title: "Click to zoom " + tZoomDirection });
          }
          else
            this.attr( { cursor: this.defaultCursor, title: this.defaultTitle });
        }

        function handleMouseUp( iEvent) {
          var tFactor, tViewPoint, tFixedCoord;
          if( iEvent.altKey) {
            tFactor = iEvent.shiftKey ? 2 : 0.5;
            tViewPoint = DG.ViewUtilities.windowToViewCoordinates(
              { x: iEvent.clientX, y: iEvent.clientY }, this_);
            tFixedCoord =  this_.get('isVertical') ? tViewPoint.y : tViewPoint.x;
            this_.get('model').dilate( this_.coordinateToData(tFixedCoord), tFactor,
                          true /* with animation */);
            tClickHandling = false;
          }
        }

        // ============body of setupEventHandling===========
        if( SC.none( this_._midPanel)) {
          this_._midPanel = this_.get('paper').rect(0, 0, 0, 0)
                    .attr({ stroke: DG.RenderingUtilities.kTransparent,
                            fill: DG.RenderingUtilities.kSeeThrough });
          this_._lowerPanel = this_._midPanel.clone();
          this_._upperPanel = this_._midPanel.clone();
          this_._dragPanel = this_._midPanel.clone();
          // It doesn't work to assign mousedown, mouseup, and mousemove to _midPanel
          // and then clone. The handlers don't get cloned. :-(
          if( !tLockZero) {
            this_._midPanel.defaultTitle = 'DG.CellLinearAxisView.midPanelTooltip'.loc(); // "Drag to translate axis scale"
            this_._midPanel.attr({title: this_._midPanel.defaultTitle});
            this_._midPanel.mousedown(handleMouseDown);
            this_._midPanel.mouseup(handleMouseUp);
            this_._midPanel.drag(doTranslate, beginTranslate, endDrag);
            this_._midPanel.mousemove(handleMouseMove);

            this_._lowerPanel.defaultTitle = 'DG.CellLinearAxisView.lowerPanelTooltip'.loc(); // "Drag to change axis lower bound"
            this_._lowerPanel.attr({title: this_._lowerPanel.defaultTitle});
            this_._lowerPanel.mousedown(handleMouseDown);
            this_._lowerPanel.mouseup(handleMouseUp);
            this_._lowerPanel.drag(doLowerDilate, beginLowerDilate, endDrag);
            this_._lowerPanel.mousemove(handleMouseMove);
          }

          this_._upperPanel.defaultTitle = 'DG.CellLinearAxisView.upperPanelTooltip'.loc(); // "Drag to change axis upper bound";
          this_._upperPanel.attr( { title: this_._upperPanel.defaultTitle });
          this_._upperPanel.mousedown( handleMouseDown);
          this_._upperPanel.mouseup( handleMouseUp);
          this_._upperPanel.drag( doUpperDilate, beginUpperDilate, endDrag);
          this_._upperPanel.mousemove( handleMouseMove);

          // Note that the name of this cursor canNOT be "ClosedHand" or in Safari
          // you will get a black closed hand no matter what is in the file.
          this_._dragPanel.attr( { cursor: DG.Browser.customCursorStr('../../../../static/dg/de/cert/resources/cursors/ClosedHandXY.cur', 8, 8) });
        }
        switch( this_.get('orientation')) {
          case DG.GraphTypes.EOrientation.kVertical:
          case DG.GraphTypes.EOrientation.kVertical2:
            if( !tLockZero) {
              setRect(this_._lowerPanel, 0, (5 / 8) * tFrame.height, tFrame.width, (3 / 8) * tFrame.height);
              this_._lowerPanel.defaultCursor = DG.Browser.customCursorStr('../../../../static/dg/de/cert/resources/cursors/DownDilate.cur', 8, 8);
              this_._lowerPanel.attr({cursor: this_._lowerPanel.defaultCursor});
              setRect(this_._midPanel, 0, (3 / 8) * tFrame.height, tFrame.width, (3 / 8) * tFrame.height);
              this_._midPanel.defaultCursor = DG.Browser.customCursorStr('../../../../static/dg/de/cert/resources/cursors/TranslateY.cur', 8, 8);
              this_._midPanel.attr({cursor: this_._midPanel.defaultCursor});
            }
            setRect(this_._upperPanel, 0, 0, tFrame.width, (tLockZero ? 1 : (3 / 8)) * tFrame.height);
            this_._upperPanel.defaultCursor = DG.Browser.customCursorStr('../../../../static/dg/de/cert/resources/cursors/UpDilate.cur', 8, 8);
            this_._upperPanel.attr({ cursor: this_._upperPanel.defaultCursor });
            setRect(this_._dragPanel, 0, 0, tFrame.width, tFrame.height);
            break;
          case DG.GraphTypes.EOrientation.kHorizontal:
            if( !tLockZero) {
              setRect(this_._lowerPanel, 0, 0, (3 / 8) * tFrame.width, tFrame.height);
              this_._lowerPanel.defaultCursor = DG.Browser.customCursorStr('../../../../static/dg/de/cert/resources/cursors/LeftDilate.cur', 8, 8);
              this_._lowerPanel.attr({cursor: this_._lowerPanel.defaultCursor});
              setRect(this_._midPanel, (3 / 8) * tFrame.width, 0, (3 / 8) * tFrame.width, tFrame.height);
              this_._midPanel.defaultCursor = DG.Browser.customCursorStr('../../../../static/dg/de/cert/resources/cursors/TranslateX.cur', 8, 8);
              this_._midPanel.attr({cursor: this_._midPanel.defaultCursor});
            }
            setRect(this_._upperPanel, (tLockZero ? 0 : (5 / 8) * tFrame.width), 0,
                (tLockZero ? 1 : (3 / 8)) * tFrame.width, tFrame.height);
            this_._upperPanel.defaultCursor = DG.Browser.customCursorStr('../../../../static/dg/de/cert/resources/cursors/RightDilate.cur', 8, 8);
            this_._upperPanel.attr({ cursor: this_._upperPanel.defaultCursor });
            setRect(this_._dragPanel, 0, 0,
                tFrame.width, tFrame.height);
            break;
        }
        if( !this_._isDragging)
            this_._dragPanel.hide();
      }

      // ===============Main body of doDraw===============

      this._elementsToClear.push( this.renderAxisLine());
      this.get('axisViewHelper').drawTicks();
      setupEventHandling();
      this.renderLabel();
    },

    /**
     Given the value to plot return the coordinate along this axis.
     @return {Number}
     */
    dataToCoordinate: function( iData) {
      return this.get('axisViewHelper').dataToCoordinate( iData);
    },

    /**
    Given a coordinate, return the result of the linear transformation
    to data value
     @param iCoord {number}
     @param iSnapToTick {boolean} if true, and return value is close to a tick, return the tick value
     @return {Number} in world coordinates.
    */
    coordinateToData: function( iCoord, iSnapToTick) {
      return this.get('axisViewHelper').coordinateToData( iCoord, iSnapToTick);
    },

    /**
     * Called typically be a ValueAnimator to get the amount to increment a value displayed along the axis
     * @property {Number}
     */
    increment: function() {
      return this.coordinateToData(1) - this.coordinateToData(0);
    }.property('frame').cacheable(),

    incrementDidChange: function() {
      this.notifyPropertyChange('increment');
    }.observes('*model.lowerBound', '*model.upperBound'),

    /**
    Return the maximum length of the label strings plus a bit extra.
      @property {Number} of pixels
    */
    desiredExtent: function() {
      var tExtent = arguments.callee.base.apply(this,arguments) + kAxisGap + kTickLength + this.get('maxNumberExtent');
      return tExtent;
    }.property('maxNumberExtent'),

    /**
    Call the given function once for each tick with arguments
        iWorldCoordinateOfTick, iScreenCoordinateOfTick
      @param {Function} to be called for each tick
    */
    forEachTickDo: function( iDoF) {
      this.get('axisViewHelper').forEachTickDo( iDoF);
    },

    _isDragging: false,
    _lowerBoundAtDragStart: null,
    _upperBoundAtDragStart: null,
    _dilationAnchorCoord: null,
    _dragPanel: null,
    _lowerPanel: null,
    _midPanel: null,
    _upperPanel: null
  };

}())
);


/* >>>>>>>>>> BEGIN source/components/graph/axes/count_axis_model.js */
// ==========================================================================
//                        DG.CountAxisModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2018 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/axes/cell_axis_model');

/** @class  DG.CountAxisModel - The model for a graph axis.

  @extends DG.CellLinearAxisModel
*/
DG.CountAxisModel = DG.CellLinearAxisModel.extend(
/** @scope DG.CountAxisModel.prototype */ 
{
  /**
    Should decimal tick values be suppressed (as for a frequency axis)?
    @property { boolean }
  */
  displayOnlyIntegers: true,

  /**
   * Determines whether we display count or percent
   * @property {DG.Analysis.EBreakdownType}
   */
  scaleType: DG.Analysis.EBreakdownType.eCount,

   /**
      @private
    @property { boolean }
  */
  _lockZero: true,

  init: function() {
    arguments.callee.base.apply(this,arguments);
    this.set('attributeDescription',
        DG.AttributePlacementDescription.create());  // because we observe it even though we don't use it
  },

  /**
   Override
   */
  labels: function() {
    switch( this.get('scaleType')) {
      case DG.Analysis.EBreakdownType.eCount:
        return ["DG.CountAxisView.countLabel".loc()];
      case DG.Analysis.EBreakdownType.ePercent:
        return ["DG.CountAxisView.percentLabel".loc()];
      default:
        return [];
    }
  }.property('scaleType'),

  /**
   *
   * @return {String}
   */
  getLabelDescription: function( /*iIndex*/) {
    switch( this.get('scaleType')) {
      case DG.Analysis.EBreakdownType.eCount:
        return "DG.CountAxisView.countLabelDescription".loc();
      case DG.Analysis.EBreakdownType.ePercent:
        return "DG.CountAxisView.percentLabelDescription".loc();
      default:
        return '';
    }
  },

  /**
   * Override until we can handle cells on numeric axis
   * @param iName
   * @return {number}
   */
  cellNameToCellNumber: function( iName) {
    return 0;
  }

 });


/* >>>>>>>>>> BEGIN source/components/graph/axes/count_axis_view.js */
// ==========================================================================
//                          DG.CountAxisView
// 
//  A view of a linear axis possibly broken into cells.
//  
//  Author:   William Finzer
//
//  Copyright (c) 2017 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/axes/cell_linear_axis_view');

/** @class

  An axis with a numeric scale, possible broken into cells.

  @extends DG.CellLinearAxisView
*/
DG.CountAxisView = DG.CellLinearAxisView.extend(
/** @scope DG.CountAxisView.prototype */ (function() {

  return {

    /**
     * @property { DG.NumericAxisViewHelper or DG.DateTimeAxisViewHelper}
     */
    _axisViewHelper: null,
    axisViewHelper: function() {
      if( !this._axisViewHelper) {
        var tHelperClass = DG.NumericAxisViewHelper;
        this._axisViewHelper = tHelperClass.create( {
          axisView: this
        });
      }
      return this._axisViewHelper;
    }.property()

  };

}())
);


/* >>>>>>>>>> BEGIN source/utilities/date_utilities.js */
// ==========================================================================
//                            DG.DateUtilities
//
//  Author:   William Finzer
//
//  Copyright (c) 2017 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================


/**
    @namespace Date value utility functions
*/
DG.DateUtilities = {
  // DateTime levels
   EDateTimeLevel: {
    eSecond: 0,
    eMinute: 1,
    eHour: 2,
    eDay: 3,
    eMonth: 4,
    eYear: 5
  },
  kSecond: 1000,
  kMinute: (1000) * 60,
  kHour: ((1000) * 60) * 60,
  kDay: (((1000) * 60) * 60) * 24,
  kMonth: ((((1000) * 60) * 60) * 24) * 30,
  kYear: ((((1000) * 60) * 60) * 24) * 365

};

/**
 * 1. Compute the outermost date-time level that changes from the
 * minimum to the maximum date.
 * 2. The inner level is one smaller than this unless the difference of
 * the min and max outer levels is greater than some arbitrary minimum,
 * in which case the inner is the same as the outer.
 *
 * @param iMinDate { Number } milliseconds
 * @param iMaxDate { Number } milliseconds
 * @return {{outerLevel: EDateTimeLevel, innerLevel: EDateTimeLevel, increment: {Number}}
 */
DG.DateUtilities.determineLevels = function(iMinDate, iMaxDate) {
  var tDateDiff = iMaxDate - iMinDate,
      tIncrement = 1, // Will only be something else if inner level is year
      tOuterLevel, tInnerLevel;

  if (tDateDiff < 3 * this.kMinute) {
    tOuterLevel = this.EDateTimeLevel.eDay;
    tInnerLevel = this.EDateTimeLevel.eSecond;
  }
  else if (tDateDiff < 3 * this.kHour) {
    tOuterLevel = this.EDateTimeLevel.eDay;
    tInnerLevel = this.EDateTimeLevel.eMinute;
  }
  else if (tDateDiff < 3 * this.kDay) {
    tOuterLevel = this.EDateTimeLevel.eDay;
    tInnerLevel = this.EDateTimeLevel.eHour;
  }
  else if (tDateDiff < 3 * this.kMonth) {
    tOuterLevel = this.EDateTimeLevel.eMonth;
    tInnerLevel = this.EDateTimeLevel.eDay;
  }
  else if (tDateDiff < 3 * this.kYear) {
    tOuterLevel = this.EDateTimeLevel.eYear;
    tInnerLevel = this.EDateTimeLevel.eMonth;
  }
  else {
    tOuterLevel = this.EDateTimeLevel.eYear;
    tInnerLevel = this.EDateTimeLevel.eYear;
    tIncrement = Math.max( 1, DG.MathUtilities.goodTickValue( tDateDiff / (this.kYear * 5)));
  }
  return {
    increment: tIncrement,
    outerLevel: tOuterLevel,
    innerLevel: tInnerLevel
  };
};

DG.DateUtilities.mapLevelToPrecision = function( iLevel) {
  var tPrecision = DG.Attribute.DATE_PRECISION_NONE;
  switch (iLevel) {
    case this.EDateTimeLevel.eSecond:
      tPrecision = DG.Attribute.DATE_PRECISION_SECOND;
      break;
    case this.EDateTimeLevel.eMinute:
      tPrecision = DG.Attribute.DATE_PRECISION_MINUTE;
      break;
    case this.EDateTimeLevel.eHour:
      tPrecision = DG.Attribute.DATE_PRECISION_HOUR;
      break;
    case this.EDateTimeLevel.eDay:
      tPrecision = DG.Attribute.DATE_PRECISION_DAY;
      break;
    case this.EDateTimeLevel.eMonth:
      tPrecision = DG.Attribute.DATE_PRECISION_MONTH;
      break;
    case this.EDateTimeLevel.eYear:
      tPrecision = DG.Attribute.DATE_PRECISION_YEAR;
      break;
  }
  return tPrecision;
};

/**
  Returns true if the specified value should be treated as epoch
  seconds when provided as the only argument to the date() function,
  false if the value should be treated as a year.
  date(2000) should be treated as a year, but date(12345) should not.
 */
DG.DateUtilities.defaultToEpochSecs = function(iValue) {
  return Math.abs(iValue) >= 5000;
};

/**
  Returns a DG date object constructed from its arguments.
  Currently this is a JavaScript Date object, but could be
  replaced with another (e.g. moment.js) object at some point.
 */
DG.DateUtilities.createDate = function(/* iArgs */) {
  var args = [Date].concat(Array.prototype.slice.call(arguments)),
      date;

  if (args.length === 2 && typeof args[1] === 'string' && isNaN(args[1])) {
    return DG.DateUtilities.dateParser.parseDate(args[1], true);
  }

  if ((args.length === 2)) {  // We have either seconds since 1970 or a year
    if (DG.DateUtilities.defaultToEpochSecs(args[1]))
      args[1] = Number(args[1]) * 1000;// convert from seconds to milliseconds
    else {  // We have a value < 5000.
      args[2] = 0;  // This will force the constructor to treat args[1] as a year
    }
  }
  // Call Date constructor with specified arguments
  // cf. http://stackoverflow.com/a/8843181
  /* jshint -W058 */
  date = new (Function.bind.apply(Date, args))();

  if (isNaN(date)) {
    date = null;
  }

  // replace default numeric conversion (milliseconds) with our own (seconds)
  if (date) {
    date.valueOf = function() { return Date.prototype.valueOf.apply(this) / 1000; };
  }

  return date;
};
DG.createDate = DG.DateUtilities.createDate;

/**
  Returns true if the specified value is a DG date object.
 */
DG.DateUtilities.isDate = function(iValue) {
  return iValue instanceof Date;
};
DG.isDate = DG.DateUtilities.isDate;

DG._isDateRegex = null;

/**
 * Returns true if the specified value is a string that can be converted to a
 * valid date.
 * If iLoose is true, applies a looser definition of date. For example, a four
 * digit number is interpreted as a year.
 */
DG.DateUtilities.isDateString = function(iValue, iLoose) {
  return DG.DateUtilities.dateParser.isDateString(iValue, iLoose);
};
DG.isDateString = DG.DateUtilities.isDateString;

/**
 * Default formatting for Date objects.
 * @param date {Date | number }
 * @param precision {number}
 * @param useShortFormat {boolean} default is false
 * @return {string}
 */

DG.DateUtilities.formatDate = function(x, precision, useShortFormat) {
  var formatPrecisions = {
    'year': {year: 'numeric'},
    'month': {year: 'numeric', month: 'numeric'},
    'day': {year: 'numeric', month: 'numeric', day: 'numeric'},
    'hour': {year: 'numeric', month: 'numeric', day: 'numeric', hour: 'numeric'},
    'minute': {year: 'numeric', month: 'numeric', day: 'numeric', hour: 'numeric', minute: 'numeric'},
    'second': {year: 'numeric', month: 'numeric', day: 'numeric', hour: 'numeric', minute: 'numeric', second: 'numeric'},
    'millisecond': {year: 'numeric', month: 'numeric', day: 'numeric', hour: 'numeric', minute: 'numeric', second: 'numeric', fractionalSecondDigits: 3}
  };

  var precisionFormat = formatPrecisions[precision] || formatPrecisions.minute;

  if (!(x && (DG.isDate(x) || DG.isDateString(x) || DG.MathUtilities.isNumeric(x)))) return;

  if ( DG.MathUtilities.isNumeric(x)) {
    x = new Date(x*1000);
  } else if (DG.isDateString(x)) {
    x = new Date(x);
  }

  var locale = DG.get('currentLanguage');
  return new Intl.DateTimeFormat(locale, precisionFormat).format(x);
};
DG.formatDate = DG.DateUtilities.formatDate;

/**
  Default formatting for Date objects.
  Uses toLocaleDateString() for default date formatting.
  Optionally uses toLocaleTimeString() for default time formatting.
 */
DG.DateUtilities.monthName = function(x) {
  if (!(x && (DG.isDate(x) || DG.isDateString(x) || DG.MathUtilities.isNumeric(x)))) return "";
  var date;
  if (DG.isDate(x))
    date = x;
  else
    date = DG.createDate(x);
  var monthNames = [
        'DG.Formula.DateLongMonthJanuary',
        'DG.Formula.DateLongMonthFebruary',
        'DG.Formula.DateLongMonthMarch',
        'DG.Formula.DateLongMonthApril',
        'DG.Formula.DateLongMonthMay',
        'DG.Formula.DateLongMonthJune',
        'DG.Formula.DateLongMonthJuly',
        'DG.Formula.DateLongMonthAugust',
        'DG.Formula.DateLongMonthSeptember',
        'DG.Formula.DateLongMonthOctober',
        'DG.Formula.DateLongMonthNovember',
        'DG.Formula.DateLongMonthDecember'
      ],
      monthName = monthNames[date.getMonth()];
  return monthName && monthName.loc();
};
DG.monthName = DG.DateUtilities.monthName;

/**
 * parseDate - Parses dates in a uniform manner across browser
 *
 * Has two modes: strict (default) and loose
 *
 * In strict mode recognizes year, month or year, month, day iso calendar date
 * or date/time strings (not just year) and local dates and date/time strings.
 * In loose mode recognizes all iso calendar dates and iso date-time strings and
 * a variety of date and date/time formats.
 *
 * Recognized in strict mode or loose mode, en/US locale:
 *   * 2019-05
 *   * 2019-05-25
 *   * 2019-05-25 10:04Z
 *   * 2019-05-25T10:04Z
 *   * 2019-05-25T10:04:03+01:00
 *   * 2019-05-25T10:04:03.123+01:00
 *   * 5/25/2019
 *   * 5/25/2019 10:04
 *   * 5/25/2019 10:04am
 *   * 5/25/2019 10:04:32.123 AM
 *
 * Recognized in loose mode
 *   * 2019
 *   * 2019.05.25
 *   * 25 Oct 2019
 *   * Oct 25, 2019
 *   * Oct. 25, 2019
 *   * October 25, 2019
 * Not recognized as dates
 *   * relative dates (e.g. today, tomorrow, next week)
 *   * anniversary dates (e.g. June 5)
 *   * out of range dates (e.g. June 32, 2019)
 */
DG.DateUtilities.dateParser = (function () {
  var timePart = '(\\d\\d?)(?::(\\d\\d?)(?::(\\d\\d)(?:\\.(\\d+))?)?)?';
  var monthsFull = [
    'DG.Formula.DateLongMonthJanuary',
    'DG.Formula.DateLongMonthFebruary',
    'DG.Formula.DateLongMonthMarch',
    'DG.Formula.DateLongMonthApril',
    'DG.Formula.DateLongMonthMay',
    'DG.Formula.DateLongMonthJune',
    'DG.Formula.DateLongMonthJuly',
    'DG.Formula.DateLongMonthAugust',
    'DG.Formula.DateLongMonthSeptember',
    'DG.Formula.DateLongMonthOctober',
    'DG.Formula.DateLongMonthNovember',
    'DG.Formula.DateLongMonthDecember'
  ].map(function (m) {return m.loc().toLowerCase(); });

  var monthsAbbr = [
    'DG.Formula.DateShortMonthJanuary',
    'DG.Formula.DateShortMonthFebruary',
    'DG.Formula.DateShortMonthMarch',
    'DG.Formula.DateShortMonthApril',
    'DG.Formula.DateShortMonthMay',
    'DG.Formula.DateShortMonthJune',
    'DG.Formula.DateShortMonthJuly',
    'DG.Formula.DateShortMonthAugust',
    'DG.Formula.DateShortMonthSeptember',
    'DG.Formula.DateShortMonthOctober',
    'DG.Formula.DateShortMonthNovember',
    'DG.Formula.DateShortMonthDecember'
  ].map(function(m) {return m.loc().toLowerCase();});

  var daysOfWeek = [
    "DG.Formula.DateLongDaySunday",
    "DG.Formula.DateLongDayMonday",
    "DG.Formula.DateLongDayTuesday",
    "DG.Formula.DateLongDayWednesday",
    "DG.Formula.DateLongDayThursday",
    "DG.Formula.DateLongDayFriday",
    "DG.Formula.DateLongDaySaturday",
  ].map( function (dow) {return dow.loc().toLowerCase();});

  var daysOfWeekAbbr = [
    "DG.Formula.DateShortDaySunday",
    "DG.Formula.DateShortDayMonday",
    "DG.Formula.DateShortDayTuesday",
    "DG.Formula.DateShortDayWednesday",
    "DG.Formula.DateShortDayThursday",
    "DG.Formula.DateShortDayFriday",
    "DG.Formula.DateShortDaySaturday",
  ].map( function (dow) {return dow.loc().toLowerCase();});

  var monthsProperAbbrRE = monthsAbbr.map(function (str) {return str + '\\.';});
  var monthsProperAbbr = monthsAbbr.map(function (str) {return str + '.';});
  // var ordinals='0th,1st,2nd,3rd,4th,5th,6th,7th,8th,9th';
  var monthsArray = monthsAbbr.concat(monthsProperAbbr, monthsFull);
  var monthsArrayRE = monthsAbbr.concat(monthsProperAbbrRE, monthsFull);
  var daysOfWeekArray = daysOfWeek.concat(daysOfWeekAbbr);

  // yyyy-MM-dd hh:mm:ss.SSSZ
  var isoDateTimeRE = /^(\d{4})-([01]\d)(?:-([0-3]\d)(?:[T ]([0-2]\d)(?::([0-5]\d)(?::([0-5]\d)(?:[.,](\d+))?)?)?(Z|(?:[+-]\d\d:?\d\d?)| ?[a-zA-Z]{1,4}T)?)?)?$/;
  var isoDateTimeGroupMap = {year:1, month:2, day:3, hour:4, min:5, sec: 6, subsec: 7, timezone: 8};

  // MM/dd/yyyy hh:mm:ss.SSS PM
  var localDateTimeRE = /^([01]?\d)\/([0-3]?\d)\/(\d{4}|\d{2})(?:,? (\d\d?)(?::(\d\d?)(?::(\d\d)(?:\.(\d+))?)?)?(?: ?(am|pm|AM|PM))?)?$/;
  var localDateTimeGroupMap = {year:3, month:1, day:2, hour:4, min:5, sec: 6, subsec: 7, ampm: 8, timezone: 9};

  // dd MMM, yyyy or MMM, yyyy
  var  dateVar1 = new RegExp('^(\\d\\d?) (' + monthsArrayRE.join('|') + '),? (\\d{4})(?: ' + timePart + '(?: (am|pm))?)?$', 'i');
  var dateVar1GroupMap = {year:3, month:2, day:1, hour:4, min:5, sec: 6, subsec: 7, ampm: 8};

  // yyyy-mm-dd, yyyy.mm.dd, yyyy/mm/dd
  // Require all three parts
  var dateVar2 = new RegExp('^(\\d{4})[./-](\\d\\d?)[./-](\\d\\d?)(?: ' + timePart + '(?: (am|pm|AM|PM))?)?$');
  var dateVar2GroupMap = {year:1, month:2, day:3, hour:4, min:5, sec: 6, subsec: 7, ampm: 8};

  // MMM dd, yyyy or MMM yyyy
  var dateVar3 = new RegExp('^(?:(?:' + daysOfWeekArray.join('|') + '),? )?(' + monthsArrayRE.join('|') + ')(?: (\\d\\d?),)? (\\d{4})(?: ' + timePart + '(?: (am|pm))?)?$', 'i');
  var dateVar3GroupMap = {year:3, month:1, day:2, hour:4, min:5, sec: 6, subsec: 7, ampm: 8};

  // 'hh:mm:ss AM/PM on dd/MM/yyyy'
  var dateVar4 = /(\d\d?):(\d\d)(?::(\d\d))? (AM|PM) on (\d\d?)\/(\d\d?)\/(\d{4})/;
  var dateVar4GroupMap = {year:5, month: 6, day: 7, hour: 1, min: 2, sec: 3, ampm: 4};

  // unix dates: Tue Jul  9 18:16:04 PDT 2019
  var unixDate = new RegExp('^(?:(?:' + daysOfWeekAbbr.join('|') + ') )?(' + monthsAbbr.join('|') + ') ([ \\d]\\d) ([ \\d]\\d):(\\d\\d):(\\d\\d) ([A-Z]{3}) (\\d{4})$', 'i');
  var unixDateGroupMap = {year: 7, month: 1, day: 2, hour: 3, min: 4, sec:5, timezone: 6};

  // new Date().toString(), most browsers
  var browserDate = new RegExp('^(?:' + daysOfWeekAbbr.join('|') + ') (' + monthsAbbr.join('|') + ') (\\d\\d?),? (\\d{4})(?: ' + timePart + ' (GMT(?:[+-]\\d{4})?(?: \\([\\w ]+\\))?))', 'i');
  var browserDateGroupMap = {year:3, month:1, day:2, hour:4, min:5, sec: 6, subsec: 7, timezone: 8};

  var utcDate = new RegExp('^(?:' + daysOfWeekAbbr.join('|') + '),? (\\d\\d?) (' + monthsAbbr.join('|') + ') (\\d{4}) ' + timePart + ' GMT$', 'i');
  var utcDateGroupMap = {year:3, month:2, day:1, hour:4, min:5, sec: 6, subsec: 7, timezone: 8};

  // yyyy
  var dateVarYearOnly = /^\d{4}$/;
  var dateVarYearOnlyGroupMap = {year:0};



// MMMM dd, yyyy hh:mm:ss.SSS PM

  var formatSpecs = [
    { strict: true, regex: localDateTimeRE, groupMap: localDateTimeGroupMap },
    { strict: true, regex: isoDateTimeRE, groupMap: isoDateTimeGroupMap },
    { strict: true, regex: unixDate, groupMap: unixDateGroupMap },
    { strict: true, regex: browserDate, groupMap: browserDateGroupMap},
    { strict: true, regex: utcDate, groupMap: utcDateGroupMap},
    { strict: false, regex: dateVar2, groupMap: dateVar2GroupMap },
    { strict: true, regex: dateVar1, groupMap: dateVar1GroupMap },
    { strict: true, regex: dateVar3, groupMap: dateVar3GroupMap },
    { strict: false, regex: dateVarYearOnly, groupMap: dateVarYearOnlyGroupMap },
    { strict: false, regex: dateVar4, groupMap: dateVar4GroupMap }
  ];

  function extractDateProps(match, map) {
    function fixHour(hr, amPm) {
      if (isNaN(hr)) {
        return null;
      }
      var newHr = Number(hr);
      if (amPm != null && (0<newHr<=12)) {
        newHr = newHr % 12;
        if (amPm && amPm.toLowerCase() === 'pm') {
          newHr += 12;
        }
      }
      return newHr;
    }
    function fixMonth(m) {
      if (!isNaN(m)) {
        return Number(m);
      }
      var lcMonth = m.toLowerCase();
      var monthIx = monthsArray.findIndex(function (monthName) { return monthName === lcMonth; });
      return (monthIx % 12) + 1;
    }
    function fixYear(y) {
      if (y.length === 2) {
        y = Number(y);
        if (y<49) {
          return 2000 + y;
        } else {
          return 1900 + y;
        }
      }
      else {
        return y;
      }
    }
    return {
      year: Number(fixYear(match[map.year])),
      month: fixMonth(match[map.month] || 1),
      day: Number(match[map.day] || 1),
      hour: fixHour(match[map.hour] || 0,match[map.ampm]) ,
      min: Number(match[map.min] || 0) ,
      sec: Number(match[map.sec] || 0),
      subsec: Number(match[map.subsec] || 0),
    };
  }
  function isValidDateSpec(dateSpec) {
    var isValid =
        !isNaN(dateSpec.year) &&
        (!isNaN(dateSpec.month) && (1<=dateSpec.month<=12)) &&
        (!isNaN(dateSpec.day) && (1<=dateSpec.day<=31)) &&
        (!isNaN(dateSpec.hour) && (0<=dateSpec.hour<=23)) &&
        (!isNaN(dateSpec.min) && (0<=dateSpec.min<=59)) &&
        (!isNaN(dateSpec.sec) && (0<=dateSpec.sec<=59)) &&
        !isNaN(dateSpec.subsec);
    if (isValid) { return dateSpec; }
  }


  function parseDate(iValue, iLoose) {
    if (iValue == null) {
      return iValue;
    }
    if (iValue instanceof Date) {
      return iValue;
    }
    iValue = String(iValue);
    var match;
    var dateSpec;
    var groupMap;
    var date;
    var spec = formatSpecs.some(function (spec) {
      var m;
      var parsed = false;
      if (spec.strict || iLoose) {
        m = iValue.match(spec.regex);
        if (m) {
          match = m;
          groupMap = spec.groupMap;
          parsed = true;
        }
      }
      return parsed;
    });

    if (spec && match) {
      dateSpec = isValidDateSpec(extractDateProps(match, groupMap));
      if (dateSpec) {
        date = new Date(dateSpec.year, (-1 + dateSpec.month), dateSpec.day,
            dateSpec.hour, dateSpec.min, dateSpec.sec, dateSpec.subsec);
        if (date) date.valueOf = function() { return Date.prototype.valueOf.apply(this) / 1000; };
        return date;
      }
    }
  }
  function isDateString(iValue, iLoose) {
    return (typeof iValue === 'string') && !!formatSpecs.find(function (spec) {
      if (!(spec.strict || iLoose)) {
        return false;
      }
      return spec.regex.test(iValue);
    });
  }

  return {
    parseDate: parseDate,
    isDateString: isDateString
  };

}());

DG.parseDate = DG.DateUtilities.dateParser.parseDate;

/* >>>>>>>>>> BEGIN source/components/graph/axes/datetime_axis_view_helper.js */
// ==========================================================================
//                              DG.DateTimeAxisViewHelper
//
//  Author:   William Finzer
//
//  Copyright (c) 2016 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('utilities/date_utilities');
sc_require('components/graph/axes/axis_view_helper');

/** @class  DG.DateTimeAxisViewHelper - This class is instantiated by instances of
 * DG.CellLinearAxisView in order to draw a datetime axis.
 *
 * @extends DG.AxisViewHelper
 */
DG.DateTimeAxisViewHelper = DG.AxisViewHelper.extend(
    /** @scope DG.DateTimeAxisViewHelper.prototype */ (function () {

      // DateTime levels
      var EDateTimeLevel = DG.DateUtilities.EDateTimeLevel,
          // kSecond = DG.DateUtilities.kSecond,
          kMinute = DG.DateUtilities.kMinute,
          kHour = DG.DateUtilities.kHour,
          kDay = DG.DateUtilities.kDay,
          // kMonth = DG.DateUtilities.kMonth,
          kYear = DG.DateUtilities.kYear,
          kMonthNames = [
            'DG.Formula.DateShortMonthJanuary',
            'DG.Formula.DateShortMonthFebruary',
            'DG.Formula.DateShortMonthMarch',
            'DG.Formula.DateShortMonthApril',
            'DG.Formula.DateShortMonthMay',
            'DG.Formula.DateShortMonthJune',
            'DG.Formula.DateShortMonthJuly',
            'DG.Formula.DateShortMonthAugust',
            'DG.Formula.DateShortMonthSeptember',
            'DG.Formula.DateShortMonthOctober',
            'DG.Formula.DateShortMonthNovember',
            'DG.Formula.DateShortMonthDecember'
          ];

      /**
       * Given the date value, return the string that fully describes the given
       * level for that date, and return the date corresponding to that string.
       *
       * @param iLevel {EDateTimeLevel}
       * @param iDate {Date } (or value that can be converted to Date. If numeric should be milliseconds)
       * @return {{ labelString: {String}, labelDate: {Date}}}
       */
      function getLevelLabelForValue(iLevel, iDate) {
        var tLabelString = '',
            tLabelDate = NaN;
        if (!DG.isDate(iDate))
          iDate = new Date(iDate);
        if (DG.isDate(iDate)) {
          // We always need the year
          var tYear = iDate.getFullYear(),
              tMonth = iDate.getMonth();

          if (iLevel === EDateTimeLevel.eYear) {
            tLabelString = String(tYear);
            tLabelDate = new Date(tYear, 1, 1);
          }
          else if (iLevel === EDateTimeLevel.eMonth) {
            tLabelDate = new Date(tYear, tMonth, 1);
            tLabelString = kMonthNames[tMonth].loc() + ', ' + tYear;
          }
          else {
            // From below here we'll need the date and its short label
            var tDay = iDate.getDate(),
                tHour = 0,
                tMinute = 0,
                tSecond = 0;

            if (iLevel < EDateTimeLevel.eDay) {
              tHour = iDate.getHours();
              if (iLevel < EDateTimeLevel.eHour) {
                tMinute = iDate.getMinutes();
                if (iLevel < EDateTimeLevel.eMinute) {
                  tSecond = iDate.getSeconds();
                }
              }
            }
              tLabelDate = new Date(tYear, tMonth, tDay, tHour, tMinute, tSecond);
              tLabelString = tLabelDate.toLocaleDateString();
            }
          }

        return {labelString: tLabelString, labelDate: tLabelDate};
      }

      /**
       * Return as both string and date, the date that represents the "next" date
       * at the given level; e.g. after Dec 1, 2001 at the month level, comes Jan 1, 2002.
       *
       * @param iLevel {EDateTimeLevel}
       * @param iDate {Date } (or value that can be converted to Date. If numeric should be in ms)
       * @return {{ labelString: {String}, labelDate: {Date}}}
       */
      function getNextLevelLabelForValue(iLevel, iDate) {
        var tNextDate;
        if (!DG.isDate(iDate))
          iDate = new Date(iDate);
        if (DG.isDate(iDate)) {
          var tYear = iDate.getFullYear(),
              tMonth = iDate.getMonth(),
              tDayOfMonth = iDate.getDate(),
              tHour = iDate.getHours(),
              tMinute = iDate.getMinutes(),
              tSecond = iDate.getSeconds();
          switch (iLevel) {
            case EDateTimeLevel.eYear:
              tYear++;
              break;
            case EDateTimeLevel.eMonth:
              tMonth++;
              if (tMonth > 12) {
                tYear++;
                tMonth = 1;
              }
              break;
            case EDateTimeLevel.eDay:
              tDayOfMonth++;
              break;
            case EDateTimeLevel.eHour:
              tHour++;
              if (tHour > 24) {
                tDayOfMonth++;
                tHour = 0;
              }
              break;
            case EDateTimeLevel.eMinute:
              tMinute++;
              if (tMinute > 60) {
                tHour++;
                tMinute = 0;
              }
              break;
            case EDateTimeLevel.eSecond:
              tSecond++;
              if (tSecond > 60) {
                tMinute++;
                tSecond = 0;
              }
              break;
            default:
          }

          if (iLevel <= EDateTimeLevel.eHour)	// It was either year or month level
            tNextDate = new Date(tYear, tMonth, tDayOfMonth, tHour, tMinute, tSecond);
          else
            tNextDate = new Date(tYear, tMonth, tDayOfMonth);
        }

        return getLevelLabelForValue(iLevel, tNextDate);
      }

      /**
       * Return a date and its string representation that is an exact value for the given level and is at or
       * above the given date.
       *
       * @param iLevel {EDateTimeLevel}
       * @param iDate {Date } (or value that can be converted to Date)
       * @param iGap {Integer} Only used if iLevel is eYear
       * @return {{ labelString: {String}, labelDate: {Date}}}
       */
      function findFirstDateAboveOrAtLevel(iLevel, iDate, iGap) {
        var tResultDate = NaN,
            tLabelString = '';
        if (!DG.isDate(iDate))
          iDate = new Date(iDate);
        if (DG.isDate(iDate)) {
          var tYear = iDate.getFullYear(),
              tMonth = iDate.getMonth(),
              tDayOfMonth = iDate.getDate(),
              tHour = iDate.getHours(),
              tMinute = iDate.getMinutes(),
              tSecond = iDate.getSeconds();
          switch (iLevel) {
            case EDateTimeLevel.eYear:
              tYear = Math.ceil( tYear / iGap) * iGap;
              tResultDate = new Date(tYear, 0, 1);
              if (tResultDate.valueOf() < iDate.valueOf())
                tResultDate = new Date(++tYear, 0, 1);
              tLabelString = String(tYear);
              break;
            case EDateTimeLevel.eMonth:
              tResultDate = new Date(tYear, tMonth, 1);
              if (tResultDate.valueOf() < iDate.valueOf()) {
                tMonth++;
                if (tMonth > 12) {
                  tYear++;
                  tMonth = 1;
                }
                tResultDate = new Date(tYear, tMonth, 1);
              }
              tLabelString = kMonthNames[tResultDate.getMonth()].loc();
              break;
            case EDateTimeLevel.eDay:
              tResultDate = new Date(tYear, tMonth, tDayOfMonth);
              if (tResultDate.valueOf() < iDate.valueOf()) {
                tDayOfMonth++;
                tResultDate = new Date(tYear, tMonth, tDayOfMonth);
              }
              tDayOfMonth = tResultDate.getDate();
              tLabelString = String(tDayOfMonth);
              break;
            case EDateTimeLevel.eHour:
              tResultDate = new Date(tYear, tMonth, tDayOfMonth, tHour);
              if (tResultDate.valueOf() < iDate.valueOf()) {
                tHour++;
                tResultDate = new Date(tYear, tMonth, tDayOfMonth, tHour);
              }
              tHour = tResultDate.getHours();
              tLabelString = tHour + ':00';
              break;
            case EDateTimeLevel.eMinute:
              tResultDate = new Date(tYear, tMonth, tDayOfMonth, tHour, tMinute);
              if (tResultDate.valueOf() < iDate.valueOf())
                tResultDate = new Date(tYear, tMonth, tDayOfMonth, tHour, ++tMinute);
              tMinute = tResultDate.getMinutes();
              tLabelString = String(tMinute);
              break;
            case EDateTimeLevel.eSecond:
              tResultDate = new Date(tYear, tMonth, tDayOfMonth, tHour, tMinute, tSecond);
              if (tResultDate.valueOf() < iDate.valueOf())
                tResultDate = new Date(tYear, tMonth, tDayOfMonth, tHour, tMinute, tSecond);
              tSecond = tResultDate.getSeconds();
              tLabelString = String(tSecond);
              break;
            default:
          }
        }

        return {labelString: tLabelString, labelDate: tResultDate};
      }

      /**
       * Return a date that is greater than the given date by the given increment
       * at the given level.
       *
       * @param iLevel {EDateTimeLevel}
       * @param iDate {Date } (or value that can be converted to Date)
       * @return {{ labelString: {String}, labelDate: {Date}}}
       */
      function getLabelForIncrementedDateAtLevel(iLevel, iDate, iIncrementBy) {
        var tResultDate = NaN,
            tLabelString = '';
        if (!DG.isDate(iDate))
          iDate = new Date(iDate);
        if (DG.isDate(iDate)) {
          var tYear = iDate.getFullYear(),
              tMonth = iDate.getMonth(),
              tDayOfMonth = iDate.getDate(),
              tHour = iDate.getHours(),
              tMinute = iDate.getMinutes(),
              tSecond = iDate.getSeconds(),
              tMinuteString, tSecondString;
          switch (iLevel) {
            case EDateTimeLevel.eYear:
              tYear += iIncrementBy;
              tResultDate = new Date(tYear, 0, 1);
              tLabelString = String(tYear);
              break;
            case EDateTimeLevel.eMonth:
              tMonth += iIncrementBy;
              while (tMonth > 12) {
                tYear++;
                tMonth -= 12;
              }
              tResultDate = new Date(tYear, tMonth, 1);
              tLabelString = kMonthNames[tResultDate.getMonth()].loc();
              break;
            case EDateTimeLevel.eDay:
              tDayOfMonth += iIncrementBy;
              tResultDate = new Date(tYear, tMonth, tDayOfMonth);
              tDayOfMonth = tResultDate.getDate();
              tLabelString = String(tDayOfMonth);
              break;
            case EDateTimeLevel.eHour:
              tHour += iIncrementBy;
              while (tHour > 24) {
                tDayOfMonth++;
                tHour -= 24;
              }
              tResultDate = new Date(tYear, tMonth, tDayOfMonth, tHour);
              tHour = tResultDate.getHours();
              tLabelString = tHour + ':00';
              break;
            case EDateTimeLevel.eMinute:
              tMinute += iIncrementBy;
              tResultDate = new Date(tYear, tMonth, tDayOfMonth, tHour, tMinute);
              tMinute = tResultDate.getMinutes();
              tMinuteString = tMinute < 10 ? '0' + tMinute : String(tMinute);
              tLabelString = tHour + ':' + tMinuteString;
              break;
            case EDateTimeLevel.eSecond:
              tSecond += iIncrementBy;
              tResultDate = new Date(tYear, tMonth, tDayOfMonth, tHour, tMinute, tSecond);
              tSecond = tResultDate.getSeconds();
              tMinuteString = tMinute < 10 ? '0' + tMinute : String(tMinute);
              tSecondString = tSecond < 10 ? '0' + tSecond : String(tSecond);
              tLabelString = tHour + ':' + tMinuteString + ':' + tSecondString;
              break;
            default:
          }
        }

        return {labelString: tLabelString, labelDate: tResultDate};
      }

      return {

        /**
         * Determine whether there are one or two levels, and draw accordingly
         */
        drawTicks: function () {
          var tLower = 1000 * this.get('lowerBound'), // milliseconds
              tUpper = 1000 * this.get('upperBound');
          if (SC.none(tLower) || SC.none(tUpper) || (tUpper === tLower))
              return; // not yet ready
          var tLevels = DG.DateUtilities.determineLevels(tLower, tUpper),
              tNumLevels = (tLevels.outerLevel !== tLevels.innerLevel) ? 2 : 1,
              tMaxNumberExtent = tNumLevels * DG.RenderingUtilities.kDefaultFontHeight;
          if (tMaxNumberExtent !== this.get('maxNumberExtent')) {
            this.set('maxNumberExtent', tMaxNumberExtent);
          }
          else {
            if (tNumLevels === 2) {
              this.drawOuterLabels(tLevels.outerLevel);
            }
            this.drawInnerLabels(tLevels.innerLevel, tLevels.increment);
          }
        },

        /**
         *
         * @param iLevel {EDateTimeLevel}
         */
        drawOuterLabels: function (iLevel) {
          var tPaper = this.get('paper'),
              tElementsToClear = this.get('elementsToClear'),
              tRotation = 0,	// Default is unrotated
              tRefPoint = {x: 0, y: 0},
              tOrientation = this.get('orientation'),
              tLowerBoundsSec = this.get('lowerBound'),
              tLowerBoundsMS = tLowerBoundsSec * 1000,
              tUpperBoundsSec = this.get('upperBound'),
              tUpperBoundsMS = tUpperBoundsSec * 1000,
              tPixelMin = this.get('pixelMin'),
              tPixelMax = this.get('pixelMax'),
              tThisLabel, tNextLabel,
              tFirstLabelString,
              tCoord,
              tSomethingDrawn = false;

          var drawOneOuterLabel = function (iCoord, iRefPoint, iLabelString, iRotation, iTextAnchor) {
            var tElement;
            switch (tOrientation) {
              case DG.GraphTypes.EOrientation.kHorizontal:
                iCoord += tPixelMin;	// offset by left start of axis
                iRefPoint.x = iCoord;
                break;
              case DG.GraphTypes.EOrientation.kVertical:
                iCoord += tPixelMax;	// offset by top start of axis
                iRefPoint.y = iCoord;
                break;
            }
            tElement = tPaper.text(iRefPoint.x, iRefPoint.y, iLabelString)
                .attr({'text-anchor': iTextAnchor});
            DG.RenderingUtilities.rotateText(tElement, iRotation, iRefPoint.x, iRefPoint.y);
            tElementsToClear.push(tElement);
          }.bind(this);

          if (tOrientation === DG.GraphTypes.EOrientation.kHorizontal) {
            tRefPoint.y = 1.5 * DG.RenderingUtilities.kDefaultFontHeight + this.kTickLength + this.kAxisGap;
          }
          else {	// 'vertical'
            tRefPoint.x = this.getPath('axisView.layout').width - this.kAxisGap -
                this.kTickLength - 1.5 * DG.RenderingUtilities.kDefaultFontHeight;
            tRotation = -90;
          }
          tThisLabel = getLevelLabelForValue(iLevel, tLowerBoundsMS);
          tFirstLabelString = tThisLabel.labelString;	// Make a copy because it might be what we end up drawing

          while (true) {  // eslint-disable-line no-constant-condition
            tNextLabel = getNextLevelLabelForValue(iLevel, tThisLabel.labelDate);
            if (isNaN(tNextLabel.labelDate))
              break;	// we break on invalid dates. Instead of breaking, we could attempt to go on to format any valid
            // dates that are in our range

            if (tThisLabel.labelDate > tUpperBoundsMS) {
              if (!tSomethingDrawn) {
                // This is the special case of one outer label spanning the whole axis
                tCoord = this.dataToCoordinate((tLowerBoundsSec + tUpperBoundsSec) / 2);
                drawOneOuterLabel(tCoord, tRefPoint, tFirstLabelString, tRotation, 'middle');
              }
              break;	// Nothing more to do
            }
            else if (tSomethingDrawn || (tNextLabel.labelDate < tUpperBoundsMS)) {	// This is the normal case
              tCoord = this.dataToCoordinate(Math.max(tThisLabel.labelDate / 1000, tLowerBoundsSec));
              var tOKToDraw = true;
              if (tThisLabel.labelDate < tLowerBoundsMS) {
                // If drawing this label will overlap the next label, then don't draw it
                var tTextExtent = DG.RenderingUtilities.textExtentOnCanvas(tPaper, tNextLabel.labelString),
                    tNextCoord = this.dataToCoordinate(tNextLabel.labelDate / 1000);
                if (tTextExtent.x > 7 * Math.abs(tNextCoord - tCoord) / 8)
                  tOKToDraw = false;
              }
              if (tOKToDraw)
                drawOneOuterLabel(tCoord, tRefPoint, tThisLabel.labelString, tRotation, 'start');
              tSomethingDrawn = true;	// even if we really didn't
            }
            tThisLabel = tNextLabel;
          }
        },

        drawInnerLabels: function (iLevel, iIncrement) {

          var findDrawValueModulus = function (iInnerLevel, iFirstDateLabel) {
                var tInterval = 1,
                    tFoundWorkableInterval = false;
                while (!tFoundWorkableInterval) {
                  var tDate = iFirstDateLabel.labelDate,
                      tLabel = iFirstDateLabel.labelString,
                      tCurrentDateLabel = iFirstDateLabel,
                      tLastPixelUsed,
                      tFirstTime = true,
                      tFoundCollision = false;
                  while (!tFoundCollision && (tDate < tUpperBounds)) {
                    var tPixel = this.dataToCoordinate(tDate / 1000),
                        tTextExtent = DG.RenderingUtilities.textExtentOnCanvas(tPaper, tLabel),
                        tHalfWidth = 5 * tTextExtent.x / 8,	// Overestimation creates gap between labels
                        tOverlapped = (tOrientation === DG.GraphTypes.EOrientation.kHorizontal) ?
                                        tPixel - tHalfWidth < tLastPixelUsed :
                                        tPixel + tHalfWidth > tLastPixelUsed;
                    if (tFirstTime || !tOverlapped) {
                      tFirstTime = false;
                      tLastPixelUsed = tPixel + ((tOrientation === DG.GraphTypes.EOrientation.kHorizontal) ? tHalfWidth : -tHalfWidth);
                      tCurrentDateLabel = getLabelForIncrementedDateAtLevel(iInnerLevel,
                          tDate, tInterval * iIncrement);
                      tDate = tCurrentDateLabel.labelDate;
                      tLabel = tCurrentDateLabel.labelString;
                    }
                    else
                      tFoundCollision = true;
                  }
                  if (tFoundCollision)
                    tInterval++;
                  else
                    tFoundWorkableInterval = true;
                }
                return tInterval;
              }.bind(this),

              drawTickAndLabel = function (iDateLabel, iDrawLabel) {
                var tRotation = 0,
                    tRefPoint = {x: 0, y: 0},
                    tTickStart = 0,
                    tPixel = this.dataToCoordinate(iDateLabel.labelDate / 1000);
                if (tOrientation === DG.GraphTypes.EOrientation.kHorizontal) {
                  tRefPoint.y = this.kTickLength + this.kAxisGap + DG.RenderingUtilities.kDefaultFontHeight / 2;
                  tTickStart = 0;	// y-value
                  tPixel += tPixelMin;
                  tRefPoint.x = tPixel;
                  tElementsToClear.push(
                      tPaper.line(tPixel, 0, tPixel, this.kTickLength)
                  );
                }
                else {	// 'vertical'
                  tRotation = -90;
                  tTickStart = this.getPath('axisView.layout').width;	// x-value
                  tRefPoint.x = tTickStart - this.kTickLength - this.kAxisGap -
                      DG.RenderingUtilities.kDefaultFontHeight / 2;
                  tPixel += tPixelMax;
                  tRefPoint.y = tPixel;
                  tElementsToClear.push(
                      tPaper.line(tTickStart, tPixel, tTickStart - this.kTickLength, tPixel)
                  );
                }

                if (iDrawLabel) {
                  var tElement = tPaper.text(tRefPoint.x, tRefPoint.y, iDateLabel.labelString);
                  DG.RenderingUtilities.rotateText(tElement, tRotation, tRefPoint.x, tRefPoint.y);
                  tElementsToClear.push(tElement);
                }
              }.bind(this);

          var tUpperBounds = this.get('upperBound') * 1000,
              tOrientation = this.get('orientation'),
              tPixelMax = this.get('pixelMax'),
              tPixelMin = this.get('pixelMin'),
              tElementsToClear = this.get('elementsToClear'),
              tPaper = this.get('paper'),
              tDateLabel = findFirstDateAboveOrAtLevel(iLevel, this.get('lowerBound') * 1000, iIncrement),
              tDrawValueModulus = findDrawValueModulus(iLevel, tDateLabel),
              tCounter = 0;

          // To get the right formatting we have to call as below. Use 0 as increment for first time through.
          tDateLabel = getLabelForIncrementedDateAtLevel(iLevel, tDateLabel.labelDate, 0);

          while (tDateLabel.labelDate < tUpperBounds) {
            drawTickAndLabel(tDateLabel, tCounter === 0);
            tCounter = (tCounter + 1) % tDrawValueModulus;
            tDateLabel = getLabelForIncrementedDateAtLevel(iLevel, tDateLabel.labelDate, iIncrement);
          }
        },

        /**
         Call the given function once for each tick with arguments
         iWorldCoordinateOfTick, iScreenCoordinateOfTick
         @param {Function} to be called for each tick
         */
        forEachTickDo: function( iDoF) {
          var tLower = 1000 * this.get('lowerBound'), // milliseconds
              tUpper = 1000 * this.get('upperBound'),
              tLevels = DG.DateUtilities.determineLevels(tLower, tUpper),
              tDateLabel = findFirstDateAboveOrAtLevel(tLevels.innerLevel, tLower,
                              tLevels.increment),
              tValue;
          while (tDateLabel.labelDate < tUpper) {
            tValue = tDateLabel.labelDate.valueOf();
            iDoF( tValue, this.dataToCoordinate( tValue / 1000));
            tDateLabel = getLabelForIncrementedDateAtLevel(tLevels.innerLevel, tDateLabel.labelDate,
                tLevels.increment);
          }
        },

        /**
         * Caller wants to know the appropriate level at which to display a string representing
         * a value on the axis.
         * @return {string}
         */
        getValueDisplayResolution: function() {
          var tDelta = (this.coordinateToData(1) - this.coordinateToData(0)) * 1000,
              tResult;
          if( tDelta < kMinute)
            tResult = 'second';
          else if( tDelta < kHour)
            tResult = 'minute';
          else if( tDelta < kDay)
            tResult = 'hour';
          else if( tDelta < kDay * 30)
            tResult = 'day';
          else if( tDelta < kYear)
            tResult = 'month';
          else
            tResult = 'year';
          return tResult;
        }

      };
    }()));


/* >>>>>>>>>> BEGIN source/components/graph/axes/formula_axis_model.js */
// ==========================================================================
//                        DG.FormulaAxisModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2021 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/axes/cell_axis_model');

/** @class  DG.FormulaAxisModel - This override allows us to display a formula expression as the axis label.

  @extends DG.CellLinearAxisModel
*/
DG.FormulaAxisModel = DG.CellLinearAxisModel.extend(
/** @scope DG.FormulaAxisModel.prototype */ 
{
  /**
   * Will be set by PlotView to provide access to formula expression to display as label
   * @property {DG.ComputedBarChartModel}
   */
  expressionSource: null,

  init: function() {
    arguments.callee.base.apply(this,arguments);
    this.set('attributeDescription',
        DG.AttributePlacementDescription.create());  // because we observe it even though we don't use it
  },
  
  destroy: function() {
    this.expressionSource = null;
    arguments.callee.base.apply(this,arguments);
  },

  /**
   Override
   */
  labels: function() {
    var tLabel = this.expressionSource ? this.expressionSource.get('expression') : '';
    if( SC.empty( tLabel))
      tLabel = "DG.BarChartFunction.emptyExpressionAxisPrompt".loc();
    return [tLabel];
  }.property('scaleType'),

  /**
   *
   * @return {String}
   */
  getLabelDescription: function( /*iIndex*/) {
    return "DG.FormulaAxisView.labelDescription".loc();
  },

  /**
   * Override until we can handle cells on numeric axis
   * @param iName
   * @return {number}
   */
  cellNameToCellNumber: function( iName) {
    return 0;
  }

 });


/* >>>>>>>>>> BEGIN source/components/graph/axes/formula_axis_view.js */
// ==========================================================================
//                          DG.FormulaAxisView
// 
//  A view of a linear axis that can display a formula expression as its label
//  
//  Author:   William Finzer
//
//  Copyright (c) 2021 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/axes/cell_linear_axis_view');

/** @class

  We override so we can do the right thing with the axis label

  @extends DG.CellLinearAxisView
*/
DG.FormulaAxisView = DG.CellLinearAxisView.extend(
/** @scope DG.FormulaAxisView.prototype */ (function() {

  return {

    displayProperties: 'model.expressionSource.formula'.w(),

    /**
     * We return a single menu item with which the user can edit the formula for computing bar lengths
     * @returns {[{title,action]}
     */
    getMenuItems: function () {
      var tMenuItems = [
        { title: 'Edit formula', action: null }
      ];

      return tMenuItems;
    },

    /**
     * This function is installed as the handler for the menu that appears when my label (a formula expression)
     * is clicked.
     * We always want to edit the formula.
     */
    menuChangeHandler: function() {
      var tFormulaOwner = this.getPath('model.expressionSource');
      tFormulaOwner.editFormula();
    }

  };

}())
);


/* >>>>>>>>>> BEGIN source/components/graph/axes/numeric_axis_view_helper.js */
// ==========================================================================
//                              DG.NumericAxisViewHelper
//
//  Author:   William Finzer
//
//  Copyright (c) 2016 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/axes/axis_view_helper');

/** @class  DG.NumericAxisViewHelper - This class is instantiated by instances of
 * DG.CellLinearAxisView in order to draw a numeric axis.
 *
 * @extends DG.AxisViewHelper
 */
DG.NumericAxisViewHelper = DG.AxisViewHelper.extend(
    /** @scope DG.NumericAxisViewHelper.prototype */ (function () {

      return {

        drawTicks: function ()       {

          function formatter( iNum) {
            return DG.MathUtilities.notAYear(iNum) ?
                Intl.NumberFormat(tLanguage, {maximumFractionDigits: tFracDigits}).format(iNum) :
                tFormat( iNum);
          }

          var tPaper = this.get('paper'),
              tElementsToClear = this.get('elementsToClear'),
              tLower = this.get('lowerBound'),
              tUpper = this.get('upperBound'),
              tBaseline = this.get('axisLineCoordinate'),
              tOrientation = this.get('orientation'),
              tTickGap = this.get( 'tickGap'),
              tStart = Math.ceil( tLower / tTickGap) * tTickGap,
              tTickCount = Math.floor( Math.abs(( tUpper - tStart) / tTickGap)),
              tLabelString,
              tMaxNumberExtent = DG.RenderingUtilities.kDefaultFontHeight,
              tFracDigits = (tTickGap < 1) ? Math.ceil( Math.abs( Math.log( tTickGap) / Math.LN10)) : 0,
              tFormat = DG.Format.number().group("").fractionDigits( 0, tFracDigits),
              tLanguage = DG.get('currentLanguage')
              ;
          /* Return the frequency of drawing value labels that will not cause collisions.
            A returned value of 1 means draw every value label, 2 means draw every other,
            etc. */
          var findWorkableGap = function( iStart, iOffset) {
            var mScaleIsReversed = false,
                tModulus = 1,
                tWorkableGapFound = false,  // guarantee first time through loop
                tHalfWidth, tHalfHeight
                ;

            while (!tWorkableGapFound) {
              var lastPixelUsed = 0,
                  firstTime = true,
                  tModifiedTickGap = tModulus * tTickGap,
                  tTickIndex;

              tTickCount = Math.floor( Math.abs( (tUpper - iStart) / tModifiedTickGap));
              tWorkableGapFound = true; // assume success

              for( tTickIndex = 0;
                   (tTickIndex <= tTickCount) && tWorkableGapFound  ;
                   tTickIndex++) {
                var spot = iStart + tTickIndex * tModifiedTickGap,
                    tickPixel = this.dataToCoordinate( spot + iOffset),
                    tTextExtent;

                tLabelString = formatter( spot);

                tTextExtent = DG.RenderingUtilities.textExtentOnCanvas( tPaper, tLabelString);

                switch( tOrientation) {
                  case DG.GraphTypes.EOrientation.kVertical:
                  case DG.GraphTypes.EOrientation.kVertical2:
                    tHalfHeight = tTextExtent.y / 2;

                    if (firstTime || (Math.abs( lastPixelUsed - tickPixel) > tHalfHeight)) {
                      firstTime = false;
                      lastPixelUsed = tickPixel + (mScaleIsReversed ?
                              tHalfHeight : -tHalfHeight);
                    }
                    else {  // Nope, text is on top of itself
                      tWorkableGapFound = false;
                      tModulus++;
                    }
                    break;
                  case DG.GraphTypes.EOrientation.kHorizontal:
                    // By pretending half the width is a bit greater than it is, we leave
                    // room between
                    tHalfWidth = 5.5 * tTextExtent.x / 8;

                    // Only draw label if we aren't going to collide with the previous number
                    if (firstTime || (Math.abs( tickPixel - lastPixelUsed)  > tHalfWidth)) {
                      firstTime = false;
                      lastPixelUsed = tickPixel + (mScaleIsReversed ?
                              -tHalfWidth : tHalfWidth);
                    }
                    else {  // Nope, text is on top of itself
                      tWorkableGapFound = false;
                      tModulus++;
                    }
                    break;
                }
              }
            }
            return tModulus;
          }.bind( this);

          var //tOffset = mIntegerBinOffsetting ? 0.5 : 0.0;
              tOffset = 0,
          // Compute the frequency for drawing text so it doesn't bump itself
              tDrawValueModulus = findWorkableGap( tStart, tOffset),
          // If we're not drawing every label for lack of space, then compute a start
          // value for the draw value counter so that we choose to draw sensible labels;
          // e.g. include 0, include integers, ...
          //tInitialDrawValueCounter = FindInitialDrawValueCounter( tStart, tDrawValueModulus);
              tInitialDrawValueCounter = 0,
          // If there's enough screen space, we'll add some intermediate ticks.
          //tNumSubIntervals = FindNumSubIntervals( tStart, tOffset, iCellNumber, tDrawValueModulus * mTickGap);
          //tNumSubIntervals = 0,
              tCounter = tInitialDrawValueCounter,
//            tSubTickPixelGap = (this_.cellDataToCoordinate( tCellNumber, tStart + 2 * tTickGap + tOffset) -
//                      this_.cellDataToCoordinate( tCellNumber, tStart + tTickGap + tOffset)) /
//                          tNumSubIntervals,
              tPixelMax = this.get('pixelMax'),
              tTickIndex = 0,
              tTickLength = (tOrientation === DG.GraphTypes.EOrientation.kVertical2) ? -this.kTickLength : this.kTickLength,
              tAxisGap = (tOrientation === DG.GraphTypes.EOrientation.kVertical2) ? -this.kAxisGap : this.kAxisGap,
              tAnchor = (tOrientation === DG.GraphTypes.EOrientation.kVertical2) ? 'start' : 'end';

          this.forEachTickDo( function( iSpot, iTickPixel) {
            var tNum, tLabelExtent, tWidth, tHeight;
            tLabelString = formatter(iSpot);
            tNum = tPaper.text( 0, 0, tLabelString)
                .addClass('dg-axis-tick-label');
            tElementsToClear.push( tNum);
            tLabelExtent = DG.RenderingUtilities.getExtentForTextElement(
                tNum, DG.RenderingUtilities.kDefaultFontHeight);
            tWidth = tLabelExtent.width;
            tHeight = tLabelExtent.height;

            switch( tOrientation) {
              case DG.GraphTypes.EOrientation.kVertical:
              case DG.GraphTypes.EOrientation.kVertical2:
                iTickPixel += tPixelMax;  // offset by top of axis
                if( (iTickPixel < this.get('pixelMin')) && (tTickIndex >= 0))
                  tElementsToClear.push(
                      tPaper.line( tBaseline, iTickPixel, tBaseline - tTickLength, iTickPixel)
                          .attr( { stroke: DG.PlotUtilities.kAxisColor }));
                //DrawSubTicks( iTickPixel, tSubTickPixelGap, tNumSubIntervals);

                if (tCounter === 0) {
                  if( (iTickPixel < this.get('pixelMin')) && (tTickIndex >= 0)) {
                    tNum.attr( { x: tBaseline - tTickLength - tAxisGap,
                      y: iTickPixel,
                      'text-anchor': tAnchor });
//                  tNum.node.setAttribute( 'style', tNum.node.getAttribute('style') +
//                            'dominant-baseline:middle');
//                  tNum.node.setAttribute( 'dominant-baseline', 'middle');
                    tMaxNumberExtent = Math.max( tMaxNumberExtent, tWidth);
                  }
                }
                else
                  tNum.hide();
                break;

              case DG.GraphTypes.EOrientation.kHorizontal:
                iTickPixel += this.get('pixelMin');  // offset by left start of axis
                if( (iTickPixel >= this.get('pixelMin')) && (tTickIndex >= 0))
                  tElementsToClear.push(
                      tPaper.line( iTickPixel, tBaseline, iTickPixel, tBaseline + tTickLength)
                          .attr( { stroke: DG.PlotUtilities.kAxisColor }));
                //DrawSubTicks( iTickPixel, tSubTickPixelGap, tNumSubIntervals);
                if (tCounter === 0) {
                  if ((iTickPixel >= this.get('pixelMin')) && (tTickIndex >= 0)) {
                    tNum.attr({ x: iTickPixel + 1,
                      y: tBaseline + tTickLength + tAxisGap + tHeight / 3 });
                    tMaxNumberExtent = Math.max( tMaxNumberExtent, tHeight);
                  }
                }
                else
                  tNum.hide();
                break;
            }
            if( tTickIndex >= 0)
              tCounter = (tCounter + 1) % tDrawValueModulus;
            tTickIndex++;
          }.bind( this));
          this.setIfChanged( 'maxNumberExtent', tMaxNumberExtent);
        },

        /**
         Call the given function once for each tick with arguments
         iWorldCoordinateOfTick, iScreenCoordinateOfTick
         @param {Function} to be called for each tick
         */
        forEachTickDo: function( iDoF) {
          var tTickIndex,
              tLower = this.get('lowerBound'),
              tUpper = this.get('upperBound'),
              tTickGap = this.get('tickGap'),
              tStart = Math.ceil( tLower / tTickGap) * tTickGap,
              tTickCount = Math.abs( (tUpper - tStart) / tTickGap),
              tSpot;
          for( tTickIndex = 0; tTickIndex <= tTickCount; tTickIndex++)  {
            tSpot = tStart + tTickIndex * tTickGap;
            iDoF( tSpot, this.dataToCoordinate( tSpot));
          }
          }
      };
    }()));


/* >>>>>>>>>> BEGIN source/components/graph/axes/qual_cell_linear_axis_view.js */
// ==========================================================================
//                          DG.QualCellLinearAxisView
// 
//  A view of a linear axis possibly broken into cells.
//  
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/axes/cell_linear_axis_view');

/** @class

    An axis with a numeric scale, possible broken into cells.

 @extends DG.CellLinearAxisView
 */
DG.QualCellLinearAxisView = DG.CellLinearAxisView.extend(
    /** @scope DG.QualCellLinearAxisView.prototype */ (function () {
      var kDefaultLow = 0,
          kDefaultHigh = 100,
          kRange = kDefaultHigh - kDefaultLow,
          kPadFraction = 0.1,
          kActualDefaultLow = kDefaultLow - kRange * kPadFraction,
          kActualDefaultHigh = kDefaultHigh + kRange * kPadFraction;

      return {

/*
        modelDidChange: function () {
          var tModel = this.get('model');
          if (tModel) {
            // tModel.setLowerAndUpperBounds(kActualDefaultLow, kActualDefaultHigh);
          }
        }.observes('model'),
*/

        /**
         Called each time we have to regenerate or modify the visualization
         */
        doDraw: function doDraw() {
          var kAxisGap = 4,
              tBaseline = this.get('axisLineCoordinate'),
              tOrientation = this.get('orientation'),
              tMaxNumberExtent = DG.RenderingUtilities.kDefaultFontHeight
              ;

          var ensureLowAndHighAreVisible = function () {
                var tCurrLow = this.getPath('model.lowerBound'),
                    tCurrHigh = this.getPath('model.upperBound');
                if (!SC.none( tCurrLow) && tCurrLow > kActualDefaultLow)
                  this.setPath('model.lowerBound', kActualDefaultLow);
                if (!SC.none( tCurrHigh) && tCurrHigh < kActualDefaultHigh)
                  this.setPath('model.upperBound', kActualDefaultHigh);
              }.bind(this),

              drawLowHigh = function () {
                [{value: kDefaultLow, string: ''}, {value: kDefaultHigh, string: ''}].forEach(
                    function (iLabel) {
                      var tLabelElement = this.get('paper').text(0, 0, iLabel.string)
                          .addClass('dg-axis-tick-label');
                      this._elementsToClear.push(tLabelElement);
                      var tLabelExtent = DG.RenderingUtilities.getExtentForTextElement(
                          tLabelElement, DG.RenderingUtilities.kDefaultFontHeight),
                          tCoord = this.dataToCoordinate(iLabel.value),
                          tHeight = tLabelExtent.height;
                      switch (tOrientation) {
                        case DG.GraphTypes.EOrientation.kHorizontal:
                          tLabelElement.attr({
                            x: tCoord + 1,
                            y: tBaseline + kAxisGap + tHeight / 3
                          });
                          tMaxNumberExtent = Math.max(tMaxNumberExtent, tHeight);
                          break;
                        case DG.GraphTypes.EOrientation.kVertical:
                          tLabelElement.attr({
                            x: tBaseline - kAxisGap,
                            y: tCoord,
                            'text-anchor': 'end'
                          });
                          tMaxNumberExtent = Math.max(tMaxNumberExtent, tLabelExtent.width);
                          break;
                      }
                    }.bind(this)
                );
              }.bind(this);

          ensureLowAndHighAreVisible();
          this._elementsToClear.push(this.renderAxisLine());
          drawLowHigh();
          this.renderLabel();
          this.setIfChanged('maxNumberExtent', tMaxNumberExtent);
        },

        forEachTickDo: function() {
          // Do nothing because, unlike our base class, we have no ticks
        }

      };

    }())
);


/* >>>>>>>>>> BEGIN source/components/graph/data_model/attribute_placement_description.js */
// ==========================================================================
//                    DG.AttributePlacementDescription
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class  DG.AttributePlacementDescription - A complete description of how an attribute is to be used.

 @extends SC.Object
 */
DG.AttributePlacementDescription = SC.Object.extend(
    /** @scope DG.AttributePlacementDescription.prototype */
    {
      /**
       @property { DG.Attribute }
       */
      attribute: function (iKey, iValue) {
        if (!SC.none(iValue)) {
          this._attributes = [iValue];
          this.setupStats();
        }
        return (this._attributes.length > 0) ? this._attributes[0] : DG.Analysis.kNullAttribute;
      }.property(),

      /**
       * Return my array of attributes.
       */
      attributes: function () {
        return this._attributes;
      }.property(),

      /**
       *
       * @param iIndex
       * @return {DG.Attribute} or -1 if none
       */
      attributeAt: function (iIndex) {
        if ((iIndex >= 0) && (iIndex < this._attributes.length))
          return this._attributes[iIndex];
        else
          return DG.Analysis.kNullAttribute;
      },

      /**
       *
       * @param iName {String}
       * @return {DG.AttributeModel}
       */
      attributeNamed: function (iName) {
        return this.get('attributes').find(function (iAttr) {
          return (iAttr.get('name') === iName);
        });
      },

      attributeIDAt: function (iIndex) {
        var tAttribute = this.attributeAt(iIndex);
        return (tAttribute !== DG.Analysis.kNullAttribute) ? tAttribute.get('id') : null;
      },

      /**
       * If not already present, adds the given attribute to my array.
       * @param iAttribute
       */
      addAttribute: function (iAttribute) {
        if( iAttribute) {
          if (!this._attributes.contains(iAttribute))
            this._attributes.push(iAttribute);
          this.setupStats();
          this.invalidateCaches();
          this.notifyPropertyChange('attribute');
          iAttribute.addObserver('collection', this, 'collectionDidChange');
        }
      },

      removeAttributeAtIndex: function (iIndex) {
        DG.assert(iIndex < this._attributes.length);
        var tAttribute = this._attributes[iIndex];
        this._attributes.splice(iIndex, 1);
        this.invalidateCaches();
        this.notifyPropertyChange('attribute');
        tAttribute.removeObserver('collection', this, 'collectionDidChange');
      },

      removeAttribute: function (iAttribute) {
        this._attributes.removeObject(iAttribute);
        this.invalidateCaches();
        this.notifyPropertyChange('attribute');
        iAttribute.removeObserver('collection', this, 'collectionDidChange');
      },

      removeAllAttributes: function () {
        this._attributes.forEach(function (iAttribute) {
          iAttribute.removeObserver('collection', this, 'collectionDidChange');
        }.bind(this));
        this._attributes = [];
        this.setPath('attributeStats.attributes', []);
        this.invalidateCaches();
        this.notifyPropertyChange('attribute');
      },

      removeAllAttributesButFirst: function () {
        while (this._attributes.length > 1) {
          this._attributes.pop().removeObserver('collection', this, 'collectionDidChange');
        }
        this.invalidateCaches();
        this.notifyPropertyChange('attribute');
      },

      collectionDidChange: function () {
        this.notifyPropertyChange('collection');
      },

      /**
       @property { DG.AttributeStats }
       */
      attributeStats: null,

      number_of_categories_limit: function( iKey, iValue) {
        if( iValue) {
          this.setPath('attributeStats.number_of_categories_limit', iValue);
        }
        return this.getPath('attributeStats.number_of_categories_limit');
      }.property(),

      /**
       * @property {[{String}]}
       */
      cellNames: function () {
        return this.getPath('attributeStats.cellNames');
      }.property(),
      cellNamesDidChange: function() {
        this.notifyPropertyChange('cellNames');
      }.observes('attributeStats.categoricalStats.cellNames'),

      /**
       * Note: True range is adjusted by offsetMinProportion.
       @property{{min:{Number}, max:{Number} isDataInteger:{Boolean}}}
       */
      minMax: function () {
        var tMinMax = this.getPath('attributeStats.minMax'),
            tRange = tMinMax.max - tMinMax.min;
        tMinMax.min -= this.get('offsetMinProportion') * tRange;
        return tMinMax;
      }.property(),
      minMaxDidChange: function () {
        this.notifyPropertyChange('minMax');
      }.observes('*attributeStats.minMax', 'offsetMinProportion'),

      /**
       * Set to cause minimum of numeric values to be offset downward by this proportion of the range.
       * Useful for keeping areas on a map from getting colored white.
       * @property{Number}
       */
      offsetMinProportion: 0,

      /**
       @private { Array of DG.Attribute }
       */
      _attributes: null,

      init: function () {
        this._attributes = [];  // Before arguments.callee.base.apply(this,arguments) so observes can be set up
        arguments.callee.base.apply(this,arguments);
        this.attributeStats = DG.AttributeStats.create();
      },

      /**

       */
      setupStats: function () {
        this.attributeStats.beginPropertyChanges();
        this.attributeStats.set('collectionClient', this.get('collectionClient'));
        this.attributeStats.set('attributes', this.get('attributes'));
        this.attributeStats.endPropertyChanges();
      },

      setCases: function (iCases) {
        this.attributeStats.setCases(iCases);
      },

      /**
       * Return ID of first attribute.
       @property { Number }
       */
      attributeID: function () {
        var tAttribute = this.get('attribute');
        return (tAttribute !== DG.Analysis.kNullAttribute) ? tAttribute.get('id') : null;
      }.property('attribute'),

      /**
       * Both datetime and numeric data are treated as numeric.
       @property {Boolean}
       */
      isNumeric: function () {
        var tType = this.get('attributeType');
        return tType === DG.Analysis.EAttributeType.eNumeric ||
            tType === DG.Analysis.EAttributeType.eDateTime;
      }.property('attributeType'),

      /**
       @property {Boolean}
       */
      isCategorical: function () {
        return this.get('attributeType') === DG.Analysis.EAttributeType.eCategorical;
      }.property('attributeType'),

      /**
       @property {Boolean}
       */
      isNull: function () {
        return this.get('attributeID') === null;
      }.property('attributeID'),

      /**
       @property {Boolean}
       */
      isColor: function () {
        return this.get('attributeType') === DG.Analysis.EAttributeType.eColor;
      }.property('attributeType'),

      /**
       @property {Boolean}
       */
      noAttributes: function () {
        var tAttributes = this.get('attributes');
        return !tAttributes || !SC.isArray(tAttributes) || (tAttributes.length === 0);
      }.property('attributes'),

      /**
       @property {Boolean}
       */
      hasFormula: function () {
        var tFormula = this.getPath('attribute.formula');
        return !SC.empty(tFormula);
      }.property(),

      /**
       @property {DG.Analysis.EAttributeType}
       */
      attributeType: function () {
        var tAttributeStats = this.get('attributeStats');
        if (SC.none(tAttributeStats))
          return DG.Analysis.EAttributeType.eNone;
        else
          return tAttributeStats.get('attributeType');
      }.property(),

      attributeTypeDidChange: function () {
        this.notifyPropertyChange('attributeType');
      }.observes('*attributeStats.attributeType'),

      /**
       @property {DG.Analysis.EAnalysisRole}
       */
      role: DG.Analysis.EAnalysisRole.eNone,

      /**
       @property { DG.CollectionClient }
       */
      collectionClient: null,

      collectionClientDidChange: function () {
        this.setPath('attributeStats.collectionClient',
            this.get('collectionClient'));
      }.observes('collectionClient'),

      /**
       Pass along to attribute stats
       @param {Array}  iCases - Array of DG.Case. These are the cases that are used for computation
       */
      invalidateCaches: function (iCases, iChange) {
        var stats = this.get('attributeStats');
        if (stats)
          stats.invalidateCaches(iCases, iChange);
        if (this._attributes.length === 0)
          this.setPath('attributeStats.attributeType', DG.Analysis.EAttributeType.eNone);
      },

      /**
       Pass along to attribute stats
       @param {Array}  iCases - Array of DG.Case. These are the cases that are used for computation
       */
      colorMapDidChange: function () {
        this.invalidateCaches();
        this.propertyDidChange('categoryMap');
      }.observes('attribute.categoryMap'),

      casesForCategory: function (iCellName) {
        var tCellMap = this.getPath('attributeStats.cellMap');
        return (tCellMap && tCellMap[iCellName]) ? tCellMap[iCellName].cases : [];
      }

    });


/* >>>>>>>>>> BEGIN source/components/graph/data_model/attribute_stats.js */
// ==========================================================================
//                        DG.AttributeStats
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

    Deals with an array of attributes and maintains univariate (categorical or numeric) statistics
 for them.

 @extends SC.Object
 */
DG.AttributeStats = SC.Object.extend((function () // closure
    /** @scope DG.AttributeStats.prototype */ {

  return {

    /**
     * The attributes for this slot
     * @property {Array of DG.AttributeModel}
     */
    attributes: null,

    /**
     * A cache of computed univariate statistics
     * @property {DG.UnivariateStats}
     */
    numericStats: null,

    /**
     * A cache of computed categorical statistics
     * @property {DG.CategoricalStats}
     */
    categoricalStats: null,

    /**
     * Passed in as the number of categories that can be dealt with.
     * @property {Number}
     */
    number_of_categories_limit: null,

    number_of_categories_limitDidChange: function () {
      this._categoricalCacheIsValid = false;
    }.observes('number_of_categories_limit'),

    /**
     * @property {Array of DG.Case} Passed in through invalidateCaches
     */
    _cases: null,

    /**
     * @property {Boolean}
     */
    _numericCacheIsValid: null,

    /**
     * @property {Boolean}
     */
    _categoricalCacheIsValid: null,

    /**
     * Only gets a value if 'attributeType' is set rather than computed.
     * @property {DG.Analysis.EAttributeType}
     */
    _attributeType: null,

    /**
     * Initialize those members that require it.
     */
    init: function () {
      arguments.callee.base.apply(this,arguments);
      this._cases = [];
      this.attributes = [];
      this.numericStats = DG.UnivariateStats.create();
      this._numericCacheIsValid = true; // because there is nothing to compute

      this.categoricalStats = DG.CategoricalStats.create();
      this._categoricalCacheIsValid = true; // because there is nothing to compute
    },

    setCases: function (iCases) {
      this._cases = iCases;
    },

    attributeDidChange: function () {
      var tAttributes = this.get('attributes'),
          tFirstAttr = (tAttributes.length > 0) ? tAttributes[0] : null,
          tType = SC.none(tFirstAttr) ? null : tFirstAttr.get('type');
      switch (tType) {
        case 'numeric':
          tType = DG.Analysis.EAttributeType.eNumeric;
          break;
        case 'categorical':
          tType = DG.Analysis.EAttributeType.eCategorical;
          break;
        default:
          tType = null;
      }
      this.invalidateCaches();
      this.set('attributeType', tType);
    }.observes('attributes'),

    /**
     *
     * @param iCases {Array} of DG.Case
     */
    invalidateCaches: function (iCases, iChange) {

      function isBetterMin(n1, n2) {
        return SC.none(n2) || (n1 < n2);
      }

      function isBetterMax(n1, n2) {
        return SC.none(n2) || (n1 > n2);
      }

      var tLastValue, tCaseIDs,
          processOneNumeric = function (iCase, iVarID) {
            var tInfo = {}, tValue = iCase.getNumValue(iVarID, tInfo);
            if (isFinite(tValue)) {
              this.numericStats.incrementProperty('count');
              this.numericStats.set('sum', this.numericStats.sum + tValue);
              // boolean values get converted to 0 and 1. For purposes of computing
              // ranges we wish to avoid these.
              if (tInfo.type !== 'boolean') {
                if (isBetterMin(tValue, this.numericStats.rangeMin))
                  this.numericStats.set('rangeMin', tValue);
                if (isBetterMax(tValue, this.numericStats.rangeMax))
                  this.numericStats.set('rangeMax', tValue);
                if (tValue > 0) {
                  if (isBetterMin(tValue, this.numericStats.positiveMin))
                    this.numericStats.set('positiveMin', tValue);
                  if (isBetterMax(tValue, this.numericStats.positiveMax))
                    this.numericStats.set('positiveMax', tValue);
                }
              }
              this.numericStats.setIfChanged('squaredDeviations', null);  // We can't compute this without iteration
            }
            else if (tInfo.isNominal && !isNaN(tValue)) {
              this.numericStats.setIfChanged('attributeType',
                  DG.ColorUtilities.isColorSpecString(tValue) ? DG.Analysis.EAttributeType.eColor :
                      DG.Analysis.EAttributeType.eCategorical);
            }
          }.bind(this),

          processOneCategorical = function (iCase, iVarID, iCategoryMap) {
            var tValue = iCase.getStrValue(iVarID),
                tCellMapEntry;
            if (!SC.empty(tValue)) {
              var tIndexOfValueInCatMap = iCategoryMap.__order.indexOf( tValue),
                  tCellMapLength = Object.getOwnPropertyNames(tCellMap).length,
                  tNumberOfCategoriesLimit = this.get('number_of_categories_limit');
              if (SC.none(tCellMap[tValue])) {
                var tCellNum = tIndexOfValueInCatMap >= 0 ? tIndexOfValueInCatMap : tCellMapLength;
                if(SC.none(tNumberOfCategoriesLimit) || tCellNum < tNumberOfCategoriesLimit) {
                  tCellMap[tValue] = {cases: [], cellNumber: tCellNum};
                  tCellMapEntry = tCellMap[tValue];
                  tLastValue = tValue;
                }
                else if(!SC.none(tNumberOfCategoriesLimit)) {
                  if( tCellMapLength === tNumberOfCategoriesLimit) {
                    if (tLastValue && !tCellMap[DG.PlotUtilities.kOther]) {
                      tCellMap[DG.PlotUtilities.kOther] = tCellMap[tLastValue];
                      delete tCellMap[tLastValue];
                    }
                    tCellMapEntry = tCellMap[DG.PlotUtilities.kOther];
                  }
                }
                DG.ObjectMap.forEach( tCellMap, function( iKey, iValue) {
                  var tIndex = iCategoryMap.__order.indexOf( iKey);
                  if( tIndex >= 0 && iValue.cellNumber !== tIndex) {
                    iValue.cellNumber = tIndex;
                    iCase._didDisturbCellOrder = true;
                  }
                });
              }
              else {
                tCellMapEntry = tCellMap[ tValue];
              }
              if (tCellMapEntry) tCellMapEntry.cases.push(iCase);
              this.categoricalStats.incrementProperty('count');
            }
          }.bind(this),
          tType = this.get('attributeType'),
          tCellMap = this.getPath('categoricalStats.cellMap'),
          tAttributes = this.get('attributes'),
          shouldProcessNumeric = this._numericCacheIsValid,
          shouldProcessCategorical = this._categoricalCacheIsValid &&
              (tType === DG.Analysis.EAttributeType.eCategorical),
          tVarID, tCategoryMap;

      if( iCases)
        this.setCases( iCases);// Do this first so subsequently computed stats will use the right cases
      if (iChange &&
          ((iChange.operation === 'createCase') ||
              (iChange.operation === 'createCases'))) {

        tCaseIDs = iChange.result.caseIDs || [iChange.result.caseID];

        if (shouldProcessNumeric) {
          this.numericStats.beginPropertyChanges();
        }
        if (shouldProcessCategorical) {
          this.categoricalStats.beginPropertyChanges();
          this.setIfChanged('_categoricalCacheIsValid', false);
        }
        tCaseIDs.forEach(function (iCaseID) {
          var tCase = DG.store.find(DG.Case, iCaseID);
          if (tCase) {
            tAttributes.forEach(function (iAttribute) {
              tVarID = iAttribute.get('id');
              tCategoryMap = iAttribute.get('categoryMap');
              if (shouldProcessNumeric) {
                processOneNumeric(tCase, tVarID);
              }
              if (shouldProcessCategorical)
                processOneCategorical(tCase, tVarID, tCategoryMap);
            }.bind(this));
          }
        }.bind(this));
        if (shouldProcessNumeric)
          this.numericStats.endPropertyChanges();
        if (shouldProcessCategorical) {
          tAttributes.forEach(function (iAttribute) {
            iAttribute.updateCategoryMap();
          });
          this.categoricalStats.endPropertyChanges();
        }
        return;
      } else if (iChange && iChange.operation === 'deleteCases') {
        if (shouldProcessNumeric) {
          this.numericStats.beginPropertyChanges();
          this.numericStats.reset();
        }
        if (shouldProcessCategorical) {
          this.categoricalStats.beginPropertyChanges();
          this.categoricalStats.reset();
          this._computeCategoricalStats();
        }
        this._cases.forEach(function (tCase) {
          if (tCase) {
            tAttributes.forEach(function (iAttribute) {
              tVarID = iAttribute.get('id');
              tCategoryMap = iAttribute.get('categoryMap');
              if (shouldProcessNumeric) {
                processOneNumeric(tCase, tVarID);
              }
              if (shouldProcessCategorical)
                processOneCategorical(tCase, tVarID, tCategoryMap);
              else
                this.setIfChanged('_categoricalCacheIsValid', false);
            }.bind(this));
          }
        }.bind(this));
        if (shouldProcessNumeric)
          this.numericStats.endPropertyChanges();
        if (shouldProcessCategorical) {
          this.categoricalStats.endPropertyChanges();
        }
        return;
      }

      // We're currently required to use set here so that dependents will hear about change
      this.setIfChanged('_numericCacheIsValid', false);
      this.setIfChanged('_categoricalCacheIsValid', false);
    },

    /**
     @property{{min:{Number}, max:{Number} isDataInteger:{Boolean}}}
     */
    minMax: function () {
      if (!this._numericCacheIsValid)
        this._computeNumericStats();
      var tRange = this.numericStats.get('numericRange');
      return {
        min: tRange.min,
        max: tRange.max,
        isDataInteger: this.numericStats.get('dataIsInteger')
      };
    }.property(),

    /**
     It is possible to set this property, thus implying that the attributes
     are to be treated one way or another.
     @property{DG.Analysis.EAttributeType} True if all values are numbers or blank
     */
    attributeType: function (iKey, iValue) {
      if (iValue !== undefined)
        this._attributeType = iValue;
      if (!SC.none(this._attributeType))
        return this._attributeType;

      var tAttributes = this.get('attributes');

      // We don't have a value stored, so we compute the answer
      if (tAttributes.length === 0) {
        this._attributeType = DG.Analysis.EAttributeType.eNone;
      }
      else {
        // If our first attribute has a type assigned, we return it
        switch (tAttributes[0].get('type')) {
          case 'nominal':
          case 'categorical':
            this._attributeType = DG.Analysis.EAttributeType.eCategorical;
            break;
          case 'numeric':
            this._attributeType = DG.Analysis.EAttributeType.eNumeric;
            break;
          case 'date':
            this._attributeType = DG.Analysis.EAttributeType.eDateTime;
            break;
          default:
            // Do nothing
        }
      }

      // If we still haven't got a type, determine it from the actual values, if any
      if (SC.none(this._attributeType)) {
        if (!this._numericCacheIsValid)
          this._computeNumericStats();
        this._attributeType = this.getPath('numericStats.attributeType');
      }

      return this._attributeType;
    }.property('attributes'),

    attributeTypeDidChange: function () {
      this.notifyPropertyChange('attributeType');
    }.observes('*numericStats.attributeType'),

    /**
     Run through all attributes and their values and cache computed statistics.
     @private
     */
    _computeNumericStats: function () {
      var tCases = this._cases,
          tAttributes = this.get('attributes'),
          tNumericCaseCount = 0,
          tTreatAsNumeric = this._attributeType === DG.Analysis.EAttributeType.eNumeric ||
              (tAttributes.length > 0 && tAttributes[0].get('type') === 'numeric'),
          tTreatAsDateTime = this._attributeType === DG.Analysis.EAttributeType.eDateTime ||
              (tAttributes.length > 0 && tAttributes[0].get('type') === 'date'),
          tAttributeType,
          tDataIsNumeric = true,  // True both for numbers and dates
          tDataIsDateTime = tCases.get('length') > 0,
          tFoundADateDuringDataIsDateTime = false,
          tColorValuesExist = false,
          tMin = Number.POSITIVE_INFINITY,
          tMax = Number.NEGATIVE_INFINITY,
          tPositiveMin = Number.MAX_VALUE,
          tPositiveMax = -Number.MAX_VALUE,
          tSum = 0,
          tSumDiffs = 0,
          tSumSquareDiffs = 0,
          //tDataIsInteger = true,
          tMean,
          tValues = [];

        function addCaseValueToStats(iCaseValue) {
          // We have to determine whether iCaseValue is a date.
          // If it is numeric, it is not a date
          var tValue = tTreatAsNumeric ? DG.MathUtilities.extractNumeric(iCaseValue) : Number( iCaseValue);
          tFoundADateDuringDataIsDateTime = tDataIsDateTime &&
              (tFoundADateDuringDataIsDateTime || DG.isDate(iCaseValue) || DG.isDateString( iCaseValue));
          tDataIsDateTime = tTreatAsDateTime || (tDataIsDateTime && (SC.empty(iCaseValue) || DG.isDate(iCaseValue) || DG.isDateString( iCaseValue)));
          if (tDataIsDateTime && (!SC.empty(iCaseValue))) {
            var tDate = DG.isDate( iCaseValue) ? iCaseValue : DG.createDate( iCaseValue);
            if (tDate) {tNumericCaseCount++;
              if (tDate.valueOf() < tMin) tMin = tDate.valueOf();
              if (tDate.valueOf() > tMax) tMax = tDate.valueOf();}
          } else if (!SC.empty(tValue) && (typeof iCaseValue !== 'boolean') && isFinite(tValue)) {
            tNumericCaseCount++;
            if (tValue < tMin) tMin = tValue;
            if (tValue > tMax) tMax = tValue;
            tSum += tValue;
            tValues.push(tValue);
            if (tValue > 0) {
              tPositiveMin = Math.min(tValue, tPositiveMin);
              tPositiveMax = Math.max(tValue, tPositiveMax);
            }
          }
          // Let infinity and NaN through as numbers. And don't let null be treated as categorical
          else if ((typeof iCaseValue !== 'number') && !SC.empty(iCaseValue)) {
            tValue = String(iCaseValue);
            tDataIsNumeric = tDataIsNumeric && SC.empty(tValue);
            tColorValuesExist = tColorValuesExist || DG.ColorUtilities.isColorSpecString(tValue);
          }
        }

      this.numericStats.reset();

      this.numericStats.beginPropertyChanges();
      if (SC.isArray(tCases)) {
        tAttributes.forEach(function (iAttribute) {
          var tVarID = iAttribute.get('id');
          tCases.forEach(function (iCase) {
            // We use the raw value here because Date objects will remain such
            addCaseValueToStats(iCase.getRawValue(tVarID));
          });
        });
      }
      tDataIsDateTime = tDataIsDateTime && tFoundADateDuringDataIsDateTime;

      if (tNumericCaseCount > 0) {
        this.numericStats.set('count', tNumericCaseCount);
        this.numericStats.set('sum', tSum);
        this.numericStats.set('rangeMin', tMin);
        this.numericStats.set('rangeMax', tMax);
        tMean = tSum / tNumericCaseCount;
        tValues.forEach(function (iValue) {
          var tDiff = iValue - tMean;
          tSumDiffs += tDiff;
          tSumSquareDiffs += tDiff * tDiff;
        });
        // The second term serves as a correction factor for roundoff error.
        // See Numeric Recipes in C, section 14.1 for details.
        tSumSquareDiffs -= tSumDiffs * tSumDiffs / tNumericCaseCount;
        this.numericStats.set('squaredDeviations', tSumSquareDiffs);

        if (tPositiveMin <= tPositiveMax) {
          this.numericStats.set('positiveMin', tPositiveMin);
          this.numericStats.set('positiveMax', tPositiveMax);
        }
      }
      if (tDataIsDateTime) {
        tAttributeType = DG.Analysis.EAttributeType.eDateTime;
      }
      else if (tDataIsNumeric) {
        tAttributeType = DG.Analysis.EAttributeType.eNumeric;
      }
      else if (tColorValuesExist) {
        tAttributeType = DG.Analysis.EAttributeType.eColor;
      }
      else {
        tAttributeType = DG.Analysis.EAttributeType.eCategorical;
      }
      this.numericStats.set('attributeType', tAttributeType);
      this._numericCacheIsValid = true;
      this.numericStats.endPropertyChanges();
    },

    /**
     @property{Number} The number of categorical cells
     */
    numberOfCells: function () {
      if (this.get('attributeType') === DG.Analysis.EAttributeType.eNumeric)
        return 1;
      if (!this._categoricalCacheIsValid)
        this._computeCategoricalStats();
      return this.getPath('categoricalStats.numberOfCells');
    }.property(),

    numberOfCellsDidChange: function () {
      this.notifyPropertyChange('numberOfCells');
    }.observes('*categoricalStats.numberOfCells'),

    /**
     @property{Number} The number of categorical cells
     */
    numericRange: function () {
      if (!this._numericCacheIsValid)
        this._computeNumericStats();
      return this.getPath('numericStats.numericRange');
    }.property(),

    numericRangeDidChange: function () {
      this.notifyPropertyChange('numericRange');
    }.observes('*numericStats.numericRange'),

    dataDidChange: function () {
      // We only have to deal with categorical stats if we are not numeric
      // Note that for this to work in the long run we're going to have to respond to any change
      //    in whether the attributes are numeric or not.
      if ((this.get('attributeType') === DG.Analysis.EAttributeType.eCategorical) && !this._categoricalCacheIsValid) {
        var tOldNumCells = this.categoricalStats.get('numberOfCells'),
            tNewNumCells;
        this._computeCategoricalStats();
        tNewNumCells = this.categoricalStats.get('numberOfCells');
        if (tNewNumCells !== tOldNumCells) {
          this.notifyPropertyChange('numberOfCells');
        }
      }
    }.observes('_categoricalCacheIsValid'),

    /**
     @property{Object} The names of the properties of this object are the cell names
     */
    cellMap: function () {
      if (!this._categoricalCacheIsValid)
        this._computeCategoricalStats();
      return this.categoricalStats.get('cellMap');
    }.property(),
    cellMapDidChange: function () {
      this.notifyPropertyChange('cellMap');
    }.observes('categoricalStats.cellMap'),

    /**
     @property{Object} The names of the properties of this object are the cell names
     */
    cellNames: function () {
      if (!this._categoricalCacheIsValid)
        this._computeCategoricalStats();
      return this.categoricalStats.get('cellNames');
    }.property(),
    cellNamesDidChange: function () {
      this.notifyPropertyChange('cellNames');
    }.observes('*categoricalStats.cellMap'),

    /**
     @return{Number} corresponding to given name
     */
    cellNameToCellNumber: function (iCellName) {
      if (!this._categoricalCacheIsValid)
        this._computeCategoricalStats();
      return this.categoricalStats.cellNameToCellNumber(iCellName);
    },

    /**
     Run through all attribute values and cache categorical stats.
     Note: Caller's responsibility to check for this._categoricalCacheIsValid. This routine will
            run regardless.
     @private
     */
    _computeCategoricalStats: function () {
      var tCases = this._cases,
          tAttributes = this.get('attributes'),
          tCaseCount = 0,
          tCellMap = {},
          tArrayOfKeysAndNumber = [],
          tNumCells,
          tNumberOfCategoriesLimit = this.get('number_of_categories_limit');

      function addCaseValueToStats(iCase, iCaseValue) {
        var tValue = String(iCaseValue);
        // Note that a null iCaseValue becomes "null" under string coercion
        if (!SC.none(iCaseValue) && !SC.empty(tValue)) {
          if (SC.none(tCellMap[tValue])) {
            tCellMap[tValue] = {cases: [], cellNumber: null};
          }
          tCellMap[tValue].cases.push(iCase);
          tCaseCount++;
        }
      }

      this.categoricalStats.reset();

      if (SC.isArray(tCases)) {
        tAttributes.forEach(function (iAttribute) {
          iAttribute.updateCategoryMap();

          var tVarID = iAttribute.get('id');
          tCases.forEach(function (iCase) {
            addCaseValueToStats(iCase, iCase.getValue(tVarID));
          });
          var tCellNumber = 0,
              tBlockIfEmpty = iAttribute.get('blockDisplayOfEmptyCategories');
          iAttribute.forEachCategory(function (iName, iColor, iIndex) {
            if (!tBlockIfEmpty || (tCellMap[iName] && tCellMap[iName].cases.length > 0)) {
              tCellMap[iName].cellNumber = tCellNumber++;
            }
          });
          tNumCells = tCellNumber;
          // If we have more categories than the limit, combine extra categories into kOther
          if(!SC.none(tNumberOfCategoriesLimit) && tNumCells > tNumberOfCategoriesLimit + 1) {
            // Make a sorted array for efficient identification of categories beyond limit
            DG.ObjectMap.forEach(tCellMap, function( iKey, iValue) {
              tArrayOfKeysAndNumber.push({ key: iKey, cellNumber: iValue.cellNumber});
            });
            tArrayOfKeysAndNumber.sort( function( iPair1, iPair2) {
              return iPair1.cellNumber - iPair2.cellNumber;
            });

            var tOtherEntry = { cases: [], cellNumber: null },
                tKeyNumberPairForLastEntry;
            while( tNumCells > tNumberOfCategoriesLimit) {
              tKeyNumberPairForLastEntry = tArrayOfKeysAndNumber.pop();
              tCellMap[tKeyNumberPairForLastEntry.key].cases.forEach( function( iCase) {
                tOtherEntry.cases.push( iCase);
              });
              tOtherEntry.cellNumber = tKeyNumberPairForLastEntry.cellNumber;
              delete tCellMap[tKeyNumberPairForLastEntry.key];
              tNumCells--;
            }
            tCellMap[DG.PlotUtilities.kOther] = tOtherEntry;
          }
        });

        this.categoricalStats.beginPropertyChanges();
        this.categoricalStats.set('cellMap', tCellMap);
        this.categoricalStats.set('count', tCaseCount);
        this._categoricalCacheIsValid = true;
        this.categoricalStats.endPropertyChanges();
      }
    }
  };
}()));


/* >>>>>>>>>> BEGIN source/components/graph/data_model/categorical_stats.js */
// ==========================================================================
//                        DG.CategoricalStats
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

    Encapsulates a cache of cell counts for a categorical attribute.

 @extends SC.Object
 */
DG.CategoricalStats = SC.Object.extend(
    /** @scope DG.CategoricalStats.prototype */ {

      /**
       * How many cases
       * @property {Number}
       */
      count: null,

      /**
       * One property for each of the possible categorical values
       * @property {SC.Object}
       */
      cellMap: null,

      /** @private
       The previously computed number of cells, used for change detection.
       @property {Number}
       */
      _prevNumberOfCells: 0,

      init: function () {
        arguments.callee.base.apply(this,arguments);
        this.cellMap = {};
      },

      /**
       * The number of distinct values
       * @property {Number}
       */
      numberOfCells: function () {
        return DG.ObjectMap.length(this.cellMap);
      }.property(),

      countOrNumberOfCellsDidChange: function () {
        var currNumberOfCells = this.get('numberOfCells');
        if (currNumberOfCells !== this._prevNumberOfCells)
          this.notifyPropertyChange('numberOfCells');
        this._prevNumberOfCells = currNumberOfCells;
      }.observes('count', 'cellMap'),

      /**
       @return{Number} corresponding to given name
       */
      cellNameToCellNumber: function (iCellName) {
        var tCell = SC.empty(iCellName) ? null : this.cellMap[iCellName.toString()];
        tCell = tCell || this.cellMap[DG.PlotUtilities.kOther];
        return tCell && tCell.cellNumber;
      },

      /**
       * @property {[{String}]}
       */
      cellNames: function () {
        var tNames = [];
        DG.ObjectMap.forEach(this.get('cellMap'), function (iName, iCell) {
          tNames.push({ name: iName, cellNumber: iCell.cellNumber});
        });
        tNames = tNames.sort( function( iObj1, iObj2) {
          return iObj1.cellNumber - iObj2.cellNumber;
        });
        return tNames.map( function( iObj) {
          return iObj.name;
        });
      }.property('cellMap'),

      /**
       * Return all values to original state
       */
      reset: function () {
        // Don't use 'set' since it can lead to infinite loops
        this.count = 0;
        this.cellMap = {};
      }

    });


/* >>>>>>>>>> BEGIN source/components/graph_map_common/plot_data_configuration.js */
// ==========================================================================
//                      DG.PlotDataConfiguration
//
//  Author:   William Finzer
//
//  Copyright ©2014 Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class  DG.PlotDataConfiguration - The object that describes the manner in which attributes are
 assigned to places in a graph.

 @extends SC.Object
 */
DG.PlotDataConfiguration = SC.Object.extend(
    /** @scope DG.PlotDataConfiguration.prototype */
    {
      /**
       The data context which is the source of the data for this graph.
       @property   {DG.DataContext}
       */
      _dataContext: null,
      dataContext: function (iKey, iValue) {
        if (iValue) {
          if (this._dataContext)
            this._dataContext.removeObserver('changeCount', this, 'handleDataContextNotification');
          this._dataContext = iValue;
          this._dataContext.addObserver('changeCount', this, 'handleDataContextNotification');
        }
        return this._dataContext;
      }.property(),

      handleDataContextNotification: function (iNotifier) {
        iNotifier.get('newChanges').forEach(function (iChange) {
          if (iChange.operation === 'moveAttribute')
            this.updateCaptionAttribute();
        }.bind(this));
      },

      /**
       * The 'caption' should always be the attribute leftmost in the child-most collection among those
       * belonging to the attributes that are plotted.
       */
      updateCaptionAttribute: function () {
        var tCollections = this.getPath('dataContext.collections'), // parent-most has index 0
            tChildMostCollectionIndex = -1; // default to parent-most collection
        if (!tCollections)
          return; // Not ready for this yet
        ['x', 'y', 'legend', 'y2', 'top', 'right', 'polygon'].forEach(function (iKey) {
          var tAttributeCollection = this.getPath(iKey + 'AttributeDescription.attribute.collection'),
              tFoundIndex = tAttributeCollection ? tCollections.indexOf(tAttributeCollection) : -1;
          tChildMostCollectionIndex = Math.max(tChildMostCollectionIndex, tFoundIndex);
        }.bind(this));
        if (tChildMostCollectionIndex === -1)
          tChildMostCollectionIndex = tCollections.length - 1;
        var tCases = this.get('cases'),
            tCaptionAttributeDescription = this.get('captionAttributeDescription'),
            tAttributes = tCollections[tChildMostCollectionIndex].get('attrs'),
            tLeftMostAttrNotHidden = tAttributes.find(function (iAttr) {
              return !iAttr.get('hidden');
            });
        tCaptionAttributeDescription.setCases(tCases);
        tCaptionAttributeDescription.set('attribute', null);  // Kludge to force recomputing of attribute type
        tCaptionAttributeDescription.set('attribute', tLeftMostAttrNotHidden);
      },

      /**
       * Because this can happen during restoreStorage when a restored dataContext is swapped in for
       * the destroyed one we're holding onto, we need to go through and hook up each attribute
       * description with the correct collection client and attribute.
       */
      dataContextDidChange: function () {

        var validateAttributes = function () {
          var tDataContext = this.get('dataContext'),
              tDestroyedAttributeExists = this.get('attributesByPlace').some(function (iAttrDescs) {
                return iAttrDescs && iAttrDescs[0] && iAttrDescs[0].getPath('attribute.isDestroyed');
              });
          if (tDestroyedAttributeExists) {
            ['x', 'y', 'legend', 'y2', 'top', 'right', 'polygon'].forEach(function (iKey) {
              var tKey = iKey + 'AttributeDescription',
                  tAttributeDescription = this.get(tKey),
                  tCurrentAttributes = (tAttributeDescription && tAttributeDescription.get('attributes')) || [],
                  tSuspectAttribute = tCurrentAttributes.length > 0 ? tCurrentAttributes[0] : null,
                  tLookedUpAttributeRef = tSuspectAttribute && tDataContext.getAttrRefByID(tSuspectAttribute.id),
                  tValidCollection = tLookedUpAttributeRef && tLookedUpAttributeRef.collection,
                  tValidAttrs = tCurrentAttributes.map(function (iAttr) {
                    var tGottenAttrRef = tDataContext.getAttrRefByID(iAttr.id);
                    return tGottenAttrRef && tGottenAttrRef.attribute;
                  }),
                  tValidAttrRefs = {collection: tValidCollection, attributes: tValidAttrs};
              this.setAttributeAndCollectionClient(tKey, tValidAttrRefs);
            }.bind(this));

            var tCasesController = this.getPath('collectionClient.casesController');
            if (!tCasesController.hasObserverFor('selection', this, this.selectionDidChange))
              tCasesController.addObserver('selection', this, this.selectionDidChange);
          }
        }.bind(this);

        validateAttributes();
        this.invalidateCaches();
        this.notifyPropertyChange('defaultTitle');
      }.observes('dataContext'),

      /**
       The outer array is indexed by DG.GraphTypes.EPlace
       @property { [ [ {DG.AttributePlacementDescription}] ] }
       */
      attributesByPlace: null,

      /**
       @property { DG.CollectionClient }
       */
      collectionClient: function () {
        var tResult = (this.chooseChildCollection(this.get('xCollectionClient'), this.get('yCollectionClient')) ||
            this.get('legendCollectionClient'));
        if (!tResult) {
          // We first try for the child collection
          tResult = this.getPath('dataContext.childCollection');
          // But if it has zero cases we'll settle for the parent collection
          if (tResult && tResult.getPath('casesController.arrangedObjects').length() === 0) {
            tResult = this.getPath('dataContext.parentCollection');
          }
        }
        return tResult;
      }.property('xCollectionClient', 'yCollectionClient', 'legendCollectionClient', 'dataContext'),

      xCollectionClient: function () {
        return this.getPath('xAttributeDescription.collectionClient');
      }.property(),

      yCollectionClient: function () {
        return this.getPath('yAttributeDescription.collectionClient');
      }.property(),

      y2CollectionClient: function () {
        return this.getPath('y2AttributeDescription.collectionClient');
      }.property(),

      legendCollectionClient: function () {
        return this.getPath('legendAttributeDescription.collectionClient');
      }.property(),

      xCollectionDidChange: function () {
        this.notifyPropertyChange('xCollectionClient');
      }.observes('*xAttributeDescription.collectionClient'),

      yCollectionDidChange: function () {
        this.notifyPropertyChange('yCollectionClient');
      }.observes('*yAttributeDescription.collectionClient'),

      y2CollectionDidChange: function () {
        this.notifyPropertyChange('y2CollectionClient');
      }.observes('*y2AttributeDescription.collectionClient'),

      legendCollectionDidChange: function () {
        this.notifyPropertyChange('legendCollectionClient');
      }.observes('*legendAttributeDescription.collectionClient'),

      /**
       * @property {String}
       */
      defaultTitle: function () {
        return this.getPath('collectionClient.name');
      }.property('dataContext'),

      /** of the collections belonging to the attributes, return the one that is "childmost"
       * @property: DG.Collection
       */
      childmostCollection: function() {
        var tChildMost = null;
        this.get('attributesByPlace').forEach(function(iAttrDescs) {
          var tCollection = iAttrDescs.length > 0 && iAttrDescs[0].getPath('collectionClient.collection');
          if( tCollection && (!tChildMost || tCollection.isDescendantOf(tChildMost)))
            tChildMost = tCollection;
        });
        return tChildMost || this.getPath('collectionClient.collection');
      }.property(),

      /**
       @property { DG.AttributePlacementDescription }
       */
      xAttributeDescription: function (iKey, iValue) {
        return this.attributeDescriptionForPlace(iKey, iValue, DG.GraphTypes.EPlace.eX);
      }.property(),

      /**
       @property { DG.AttributePlacementDescription }
       */
      yAttributeDescription: function (iKey, iValue) {
        return this.attributeDescriptionForPlace(iKey, iValue, DG.GraphTypes.EPlace.eY);
      }.property(),

      /**
       @property { DG.AttributePlacementDescription }
       */
      y2AttributeDescription: function (iKey, iValue) {
        return this.attributeDescriptionForPlace(iKey, iValue, DG.GraphTypes.EPlace.eY2);
      }.property(),

      /**
       @property { DG.AttributePlacementDescription }
       */
      legendAttributeDescription: function (iKey, iValue) {
        return this.attributeDescriptionForPlace(iKey, iValue, DG.GraphTypes.EPlace.eLegend);
      }.property(),

      numberOfLegendQuantiles: 5,
      legendQuantilesAreLocked: false,
      _legendQuantiles: null,
      legendQuantiles: function() {
        if( !this.get('legendQuantilesAreLocked') || !this._legendQuantiles) {
          var tNumQuantiles = this.get('numberOfLegendQuantiles'),
              tValues = this.numericValuesForPlace(DG.GraphTypes.EPlace.eLegend);
          this._legendQuantiles = DG.MathUtilities.nQuantileValues(tValues, tNumQuantiles);
          // We need the last value to be slightly larger than the max value so that the max value
          // will be included in the last quantile.
          this._legendQuantiles[tNumQuantiles] += Math.abs(this._legendQuantiles[tNumQuantiles] -
                                                   this._legendQuantiles[0]) * 0.000001;
        }
        return this._legendQuantiles;
      }.property('numberOfLegendQuantiles', 'legendQuantilesAreLocked'),

      quantilesAreLockedDidChange: function() {
        if( !this.get('legendQuantilesAreLocked'))
          this._legendQuantiles = null;
        else
          this.get('legendQuantiles');  // Make sure they are computed
      }.observes('legendQuantilesAreLocked'),

      /**
       @property { DG.AttributePlacementDescription }
       */
      attributeDescriptionForPlace: function (iKey, iValue, iPlace) {
        if (iValue) {
          DG.assert(iValue instanceof DG.AttributePlacementDescription);
          this.attributesByPlace[iPlace][0] = iValue;
          iValue.addObserver('collection', this, 'collectionDidChange');
          iValue.addObserver('categoryMap', this, 'categoryMapDidChange');
        }

        return !SC.none(this.attributesByPlace) ?
            this.attributesByPlace[iPlace][0] : null;
      }.property(),

      /**
       * Used in attributeIsNominal for testing attributes that are not necessarily assigned to this data configuration.
       * @property { DG.AttributePlacementDescription }
       */
      _tempAttrDescription: null,

      /**
       * One of my attributeDescription's attribute's collections has changed.
       * We look up the corresponding collectionClient and set the attributeDescription's
       * collectionClient property.
       * @param iAttrDescription {DG.AttributePlacementDescription}
       */
      collectionDidChange: function (iAttrDescription) {
        var tID = iAttrDescription.getPath('attribute.collection.id'),
            tClient = this.get('dataContext').getCollectionByID(tID);
        iAttrDescription.set('collectionClient', tClient);
      },

      /**
       * One of my attribute description's attribute's category map changed; e.g. by user dragging
       * categories displayed on cell axis.
       */
      categoryMapDidChange: function () {
        this.propertyDidChange('categoryMap');
      },

      /**
       @param{DG.Analysis.EAnalysisRole}
       @return{DG.AttributePlacementDescription}
       */
      firstAttributeDescriptionForRole: function (iRole) {
        return this.firstPlaceAndAttributeDescriptionForRole(iRole).attributeDescription;
      },

      /**
       @param{DG.Analysis.EAnalysisRole}
       @return{DG.AttributePlacementDescription}
       */
      firstAttributeIDForRole: function (iRole) {
        var tResult = this.firstPlaceAndAttributeDescriptionForRole(iRole);
        return tResult.attributeDescription.get('attributeID');
      },

      /**
       @param{DG.Analysis.EAnalysisRole}
       @return{DG.GraphTypes.EPlace}
       */
      getPlaceForRole: function (iRole) {
        return this.firstPlaceAndAttributeDescriptionForRole(iRole).place;
      },

      xAttributeID: function () {
        return this.getPath('xAttributeDescription.attributeID');
      }.property(),

      yAttributeID: function () {
        return this.getPath('yAttributeDescription.attributeID');
      }.property(),

      y2AttributeID: function () {
        return this.getPath('y2AttributeDescription.attributeID');
      }.property(),

      legendAttributeID: function () {
        return this.getPath('legendAttributeDescription.attributeID');
      }.property(),

      xAttributeIDDidChange: function () {
        this.notifyPropertyChange('xAttributeID');
      }.observes('*xAttributeDescription.attributeID'),

      yAttributeIDDidChange: function () {
        this.notifyPropertyChange('yAttributeID');
      }.observes('*yAttributeDescription.attributeID'),

      y2AttributeIDDidChange: function () {
        this.notifyPropertyChange('y2AttributeID');
      }.observes('*y2AttributeDescription.attributeID'),

      legendAttributeIDDidChange: function () {
        this.notifyPropertyChange('legendAttributeID');
      }.observes('*legendAttributeDescription.attributeID'),

      recomputeLegendQuantilesIfLocked: function() {
        if( this.get('legendQuantilesAreLocked')) {
          this.set('legendQuantilesAreLocked', false);
          this.set('legendQuantilesAreLocked', true);
        }
      },

      /**
       @property {Boolean}
       */
      xIsNumeric: function () {
        return this.getPath('xAttributeDescription.isNumeric');
      }.property(),

      /**
       @property {Boolean}
       */
      yIsNumeric: function () {
        return this.getPath('yAttributeDescription.isNumeric');
      }.property(),

      /**
       @property {Boolean}
       */
      y2IsNumeric: function () {
        return this.getPath('y2AttributeDescription.isNumeric');
      }.property(),

      xIsNumericDidChange: function () {
        this.notifyPropertyChange('xIsNumeric');
      }.observes('*xAttributeDescription.isNumeric'),

      yIsNumericDidChange: function () {
        this.notifyPropertyChange('yIsNumeric');
      }.observes('*yAttributeDescription.isNumeric'),

      y2IsNumericDidChange: function () {
        this.notifyPropertyChange('y2IsNumeric');
      }.observes('*y2AttributeDescription.isNumeric'),

      /**
       @property {DG.Analysis.EAttributeType}
       */
      xType: function () {
        return DG.Analysis.forceColorToCategorical(this.getPath('xAttributeDescription.attributeType'));
      }.property(),

      /**
       @property {DG.Analysis.EAttributeType}
       */
      yType: function () {
        return DG.Analysis.forceColorToCategorical(this.getPath('yAttributeDescription.attributeType'));
      }.property(),

      /**
       @property {DG.Analysis.EAttributeType}
       */
      y2Type: function () {
        return DG.Analysis.forceColorToCategorical(this.getPath('y2AttributeDescription.attributeType'));
      }.property(),

      xTypeDidChange: function () {
        this.notifyPropertyChange('xType');
      }.observes('*xAttributeDescription.attributeType'),

      yTypeDidChange: function () {
        this.notifyPropertyChange('yType');
      }.observes('*yAttributeDescription.attributeType'),

      y2TypeDidChange: function () {
        this.notifyPropertyChange('y2Type');
      }.observes('*y2AttributeDescription.attributeType'),

      /**
       * This property is never actually assigned. It is used only as a notification bottleneck
       * @property { null }
       */
      attributeAssignment: null,

      /**
       * @result {Boolean}
       */
      hasAtLeastOneAttributeAssigned: function () {
        return ['x', 'y', 'legend'].some(function (iKey) {
          return !this.getPath(iKey + 'AttributeDescription.isNull');
        }.bind(this));
      },

      /**
       *
       * @param iPrefixes {[String]}
       */
      noAttributesFor: function (iPrefixes) {
        return iPrefixes.every(function (iPrefix) {
          return this.getPath(iPrefix + 'AttributeDescription.noAttributes');
        }.bind(this));
      },

      /**
       Returns true if this graph references attributes in collections with aggregate
       functions, which is useful when determining whether a graph needs to be redrawn.
       @property   {Boolean}
       */
      hasAggregates: function () {
        var collectionIDs = {},
            foundID,

            /**
             Utility function used to help identify the minimum set of collections that
             have to be checked for aggregate functions. Since most graphs refer to
             attributes for a single collection, there's no point in redundantly checking
             for aggregates in the same collection due to multiple attribute references.
             Adds the specified collection to the collectionIDs local variable map.
             @param    {String}  iDescriptor -- 'x', 'y', 'legend'
             */
            considerCollection = function (iDescriptor) {
              var collection = this.getPath(iDescriptor + 'AttributeDescription.collectionClient'),
                  collectionID = collection && collection.get('id');
              if (!SC.none(collectionID))
                collectionIDs[collectionID] = collection;
            }.bind(this);

        // Consider each of our possible collections in turn
        considerCollection('x');
        considerCollection('y');
        considerCollection('legend');

        // Search through our set of collections, stopping on the first one that has aggregates.
        foundID = DG.ObjectMap.findKey(collectionIDs,
            function (iCollectionID, iCollection) {
              return iCollection && iCollection.get('hasAggregates');
            });
        return !SC.none(foundID);
      }.property(),

      yAttributeIDAt: function (iIndex) {
        return this.get('yAttributeDescription').attributeIDAt(iIndex);
      },

      y2AttributeIDAt: function (iIndex) {
        return this.get('y2AttributeDescription').attributeIDAt(iIndex);
      },

      /**
       * @property {Array}
       */

      _hiddenCases: null,

      hiddenCases: function (iKey, iValue) {
        if (iValue) {
          this._hiddenCases = iValue;
          this.invalidateCaches();
        }
        return this._hiddenCases;
      }.property(),

      /**
       Initialization function
       */
      init: function () {
        arguments.callee.base.apply(this,arguments);
        this._hiddenCases = [];
        this._plotCaseArray = DG.PlotUtilities.PlotCaseArray.create();
      },

      destroy: function () {
        var xDesc = this.get('xAttributeDescription'),
            yDesc = this.get('yAttributeDescription'),
            y2Desc = this.get('y2AttributeDescription'),
            legDesc = this.get('legendAttributeDescription');

        if (xDesc)
          xDesc.removeObserver('collectionClient', this, 'xCollectionDidChange');
        if (yDesc)
          yDesc.removeObserver('collectionClient', this, 'yCollectionDidChange');
        if (y2Desc)
          y2Desc.removeObserver('collectionClient', this, 'y2CollectionDidChange');
        if (legDesc)
          legDesc.removeObserver('collectionClient', this, 'legendCollectionDidChange');

        if (this.get('attributesByPlace'))
          this.get('attributesByPlace').forEach(function (iAttrDesc) {
            iAttrDesc.removeObserver('collection', this, 'collectionDidChange');
            iAttrDesc.removeObserver('categoryMap', this, 'categoryMapDidChange');
          }.bind(this));

        this._hiddenCases = [];  // For good measure

        arguments.callee.base.apply(this,arguments);
      },

      /**
       Sets the specified attribute for the specified attribute description,
       e.g. puts the specified attribute in the appropriate place for an axis.
       If iAttrRefs is null, then the specified place is cleared of any attribute.
       @param {String} iDescription -- e.g. 'xAttributeDescription' or 'yAttributeDescription'
       @param {Object}               iAttrRefs -- the attribute to set
       {DG.CollectionClient}  iAttrRefs.collection -- the collection containing the specified attribute
       {Array of DG.Attribute}iAttrRefs.attributes -- the attributes to set
       @param {DG.Analysis.EAnalysisRole} iRole Optional
       @param {DG.Analysis.EAttributeType} iType Optional
       */
      setAttributeAndCollectionClient: function (iDescription, iAttrRefs, iRole, iType) {
        var tDescription = this.get(iDescription);
        if (tDescription) {
          tDescription.removeAllAttributes();
          tDescription.beginPropertyChanges();
          tDescription.set('collectionClient', (iAttrRefs && iAttrRefs.collection) || null);
          this._casesCache = null;  // because setting a new attribute and collection client can require recomputation of cases
          tDescription.setCases(this.get('cases'));
          if (!SC.none(iAttrRefs)) {
            var tAttributes = iAttrRefs.attributes || [iAttrRefs.attribute];
            tAttributes.forEach(function (iAttribute) {
              tDescription.addAttribute(iAttribute);
            });
          }
          if (!SC.none(iRole))
            tDescription.set('role', iRole);
          if (!SC.none(iType))
            tDescription.setPath('attributeStats.attributeType', iType);
          this._casesCache = null;
          tDescription.invalidateCaches(this.get('cases'));  // So that notification order won't be important
          tDescription.endPropertyChanges();
        }
      },

      /**
       * Change the attribute type on the given axis, so the Graph treats it differently than it's native data type.
       * @param iDescriptionKey {String} to get our {DG.AttributePlacementDescription}
       * @param iTreatAsNumeric {Boolean} numeric or categorical
       */
      setAttributeType: function (iDescriptionKey, iTreatAsNumeric) {
        DG.assert(typeof iDescriptionKey === 'string');
        DG.assert(typeof iTreatAsNumeric === 'boolean');
        var tDescription = this.get(iDescriptionKey),
            tType = (iTreatAsNumeric ? DG.Analysis.EAttributeType.eNumeric : DG.Analysis.EAttributeType.eCategorical),
            tAttribute = tDescription && tDescription.get('attribute'),
            tStats = tDescription && tDescription.get('attributeStats');
        DG.assert(tAttribute !== DG.Analysis.kNullAttribute);
        tDescription.invalidateCaches(this.get('cases'));  // So that notification order won't be important
        if (tStats) {
          /* Date type is treated as numeric. If the underlying type is date and we are to treat the
           attribute as numeric, then we explicitly set it as date. */
          var tStatsType = tStats.getPath('numericStats.attributeType');
          if (tStatsType === DG.Analysis.EAttributeType.eDateTime && iTreatAsNumeric)
            tType = tStatsType;
          tStats.set('attributeType', tType);
        }
      },

      /**
       * Choose one collection to treat as the child collection.
       * If there is no parent/child relationship, just pick a collection.
       * @param {DG.CollectionClient}
       * @param {DG.CollectionClient}
       */
      chooseChildCollection: function (iCC1, iCC2) {
        var tContext = this.get('dataContext'),
            tCollections = tContext ? tContext.get('collections') : [],
            tCC1Index = iCC1 ? tCollections.indexOf(iCC1.get('collection')) : -1,
            tCC2Index = iCC2 ? tCollections.indexOf(iCC2.get('collection')) : -1;

        return (tCC1Index > tCC2Index) ? iCC1 : iCC2;
      },

      /**
       * @return {Array of Integer }
       */
      plottedCollectionIDs: function () {
        var plottedCollectionIDs = [],
            collectionClient = this.get('collectionClient'),
            collectionClientID = collectionClient && collectionClient.get('id'),
            // Temporary elimination of legend because it can cause inclusion of unwanted cases
            properties = ['xCollectionClient', 'yCollectionClient', 'y2CollectionClient'/*, 'legendCollectionClient'*/];
        if (collectionClient && !SC.none(collectionClientID))
          plottedCollectionIDs.push(collectionClientID);

        properties.forEach(function (iProperty) {
          var collection = this.get(iProperty),
              collectionID = collection && collection.get('id');
          if (!SC.none(collectionID)) {
            if (plottedCollectionIDs.indexOf(collectionID) < 0)
              plottedCollectionIDs.push(collectionID);
          }
        }.bind(this));
        return plottedCollectionIDs;
      }.property('collectionClient', 'xCollectionClient',
          'yCollectionClient', 'y2CollectionClient', 'legendCollectionClient').cacheable(),

      /**
       Returns an array of attribute IDs representing the attributes
       that are assigned to any place in the configuration.
       @returns  {number[]} - array of unique attribute IDs assigned to places
       */
      placedAttributeIDs: function () {
        var place, i, attrDesc, attrID, attrs, attrCount,
            placedAttrs = [];
        for (place = DG.GraphTypes.EPlace.eFirstPlace; place <= DG.GraphTypes.EPlace.eLastPlace; ++place) {
          attrDesc = this.attributeDescriptionForPlace(null, null, place);
          attrs = attrDesc && attrDesc.get('attributes');
          attrCount = attrs ? attrs.length : 0;
          for (i = 0; i < attrCount; ++i) {
            attrID = attrDesc.attributeIDAt(i);
            if (placedAttrs.indexOf(attrID) < 0)
              placedAttrs.push(attrID);
          }
        }
        return placedAttrs;
      }.property(),

      /**
       * Plots (dot chart, dot plot) that wish cases that belong to the same legend category to
       * be contiguous in the array of cases will use the default (true) for this property.
       * Plots (scatterplot) that do not wish this sorting to occur will set the property to false.
       * @property {Boolean}
       */
      sortCasesByLegendCategories: true,

      _casesCache: null, // Array of DG.Case
      _plotCaseArray: null, // DG.PlotUtilities.PlotCaseArray

      /**
       * @property {SC.Array of DG.Case} All cases, both hidden and visible
       */
      allCases: function () {
        // By returning a source regardless of whether the two collection clients are the same
        //  or not, we make it possible to make a plot in which the attribute on the x-axis
        //  is from a child collection and the one on the y-axis is from the parent. Ideally,
        //  we determine which of the two is the child and then the child can be on the y-axis.
        var tSource = this.get('collectionClient') ||
            DG.currDocumentController().collectionDefaults().collectionClient;
        return tSource ? tSource.getPath('casesController.arrangedObjects') : null;
      }.property(),

      /**
       * We look at x, y and y2 attributes that are present. If there is an x-attribute but the case
       * has no x-value, we exclude the case. If there is a y-attribute, no y2-attribute and no y-value, we
       * exclude the case. If there is an x-attribute, y-attribute and y-2 attribute, we exclude the
       * case if there is neither a y-attribute nor a y-2 attribute.
       @property { {DG.PlotUtilities.PlotCaseArray} that behaves like an SC.Array of DG.Case }
       */
      cases: function () {
        var tAttributesByPlace = this.get('attributesByPlace') || [];

        function getID(iKey) {
          var tPlace = DG.GraphTypes.EPlace[iKey];
          // Make sure we can make our way to the id
          return tAttributesByPlace && tAttributesByPlace[tPlace] && tAttributesByPlace[tPlace][0] &&
              tAttributesByPlace[tPlace][0].getPath('attribute.id');
        }

        if (SC.none(this._casesCache)) {
          var tCases = this.get('displayOnlySelected') ? this.get('selection') : this.get('allCases'),
              tHidden = this.get('hiddenCases'),
              tNotHidden,
              tResult = [],
              tAttrIDs;
          if (tCases) {
            // We subtract the hidden cases so that they are not known about by the graph
            tNotHidden = DG.ArrayUtils.subtract(tCases, tHidden,
                function (iCase) {
                  return iCase ? iCase.get('id') : null;
                });

            tAttrIDs = {
              x: getID('eX'),
              y: getID('eY'),
              y2: getID('eY2')
            };

            tNotHidden.forEach(function (iCase) {
              var tXIsValid = SC.none(tAttrIDs.x) || iCase.hasValue(tAttrIDs.x),
                  tYIsValid = SC.none(tAttrIDs.y) || iCase.hasValue(tAttrIDs.y) ||
                      (!SC.none(tAttrIDs.y2) && iCase.hasValue(tAttrIDs.y2));
              if (tXIsValid && tYIsValid)
                tResult.push(iCase);
            });

            // If there is a legend attribute then we sort the cases.
            // For a categorical legend we sort so that cases
            //   belonging to a given category are together. The order of categories is determined by
            //   the attribute's categoryMap
            // For a numeric legend we sort by the attribute values.
            var tLegendAttrs = tAttributesByPlace[DG.GraphTypes.EPlace.eLegend],
                tLegendAttrDesc = tLegendAttrs && tLegendAttrs[0],
                tMapOriginalToSorted = [];
            for (var index = 0; index < tResult.length; index++) {
              tMapOriginalToSorted.push(index);
            }
            if (this.get('sortCasesByLegendCategories') && tLegendAttrDesc) {
              var tLegendID = tLegendAttrDesc.getPath('attribute.id');
              switch (tLegendAttrDesc.get('attributeType')) {
                case DG.Analysis.EAttributeType.eCategorical:
                  var tCategoryMap = tLegendAttrDesc.getPath('attribute.categoryMap');
                  tMapOriginalToSorted = DG.ArrayUtils.stableSort(tMapOriginalToSorted, function (iIndex1, iIndex2) {
                    var tValue1 = tResult[iIndex1].getStrValue(tLegendID),
                        tValue2 = tResult[iIndex2].getStrValue(tLegendID);
                    if (SC.empty(tValue1))
                      return 1;
                    else if (SC.empty(tValue2))
                      return -1;
                    else
                      return tCategoryMap.__order.indexOf(tValue2) - tCategoryMap.__order.indexOf(tValue1);
                  });
                  break;
                case DG.Analysis.EAttributeType.eNumeric:
                  tMapOriginalToSorted = DG.ArrayUtils.stableSort(tMapOriginalToSorted, function (iIndex1, iIndex2) {
                    var tValue1 = tResult[iIndex1].getValue(tLegendID),
                        tValue2 = tResult[iIndex2].getValue(tLegendID);
                    return tValue2 - tValue1;
                  });
                  break;
              }
            }
            this._plotCaseArray.set('_cases', tResult);
            this._plotCaseArray.set('_map', tMapOriginalToSorted);
          }
        }
        this._casesCache = this._plotCaseArray;
        return this._casesCache;
      }.property('xCollectionClient', 'yCollectionClient', 'legendCollectionClient'),

      /**
       *
       * @param iPlace {DG.GraphTypes.EPlace}
       * @returns {Array of {Number}}
       */
      numericValuesForPlace: function (iPlace) {
        var tValues = [],
            tAttrDesc = this.get('attributesByPlace')[iPlace][0],
            tAttrID = tAttrDesc.getPath('attribute.id');
        if (tAttrDesc.get('isNumeric')) {
          var tCases = this.get('cases');
          tValues = [];
          if (tCases) {
            tCases.forEach(function (iCase) {
              var tValue = iCase.getForcedNumericValue(tAttrID);
              if (DG.MathUtilities.isNumeric(tValue)) {
                tValues.push(tValue);
              }
            });
          }
        }
        return tValues;
      },

      /**
       * @return {Number}
       */
      getCaseCount: function () {
        return this.getPath('cases.length');
      },

      _displayOnlySelected: false,
      displayOnlySelected: function (iKey, iValue) {
        if (!SC.none(iValue)) {
          this.invalidateCaches();
          this.notifyPropertyChange('hiddenCasesWillChange');
          this._displayOnlySelected = iValue;
        }
        return this._displayOnlySelected;
      }.property(),

      /**
       * Remove the hidden cases from my collection client's selection
       * @property {[DG.Case]}
       */
      selection: function () {
        var tSelection = this.getPath('collectionClient.casesController.selection');
        tSelection = tSelection ? tSelection.toArray() : [];
        return DG.ArrayUtils.subtract(tSelection, this.get('hiddenCases'),
            function (iCase) {
              return iCase ? iCase.get('id') : null;
            });
      }.property('xCollectionClient', 'yCollectionClient', 'y2CollectionClient', 'legendCollectionClient', 'hiddenCases'),

      selectionDidChange: function () {
        this.notifyPropertyChange('selection');
      }.observes('collectionClient.casesController.selection'),

      /**
       * Bottleneck for detecting attribute assignment change
       */
      attributeAssignmentDidChange: function () {
        this.notifyPropertyChange('attributeAssignment');
      }.observes('.xAttributeDescription.attribute', '.yAttributeDescription.attribute', '.y2AttributeDescription.attribute',
          '.legendAttributeDescription.attribute', '.topAttributeDescription.attribute',
          '.rightAttributeDescription.attribute'),

      /**
       Iteration through all attribute descriptions.
       @param{Function} with signature (DG.AttributePlacementDescription)
       */
      forEachAttribute: function (iDoF) {
        this.get('attributesByPlace').forEach(function (iArray) {
          iArray.forEach(iDoF);
        });
      },

      /**
       Return the first attribute description for which iTestF returns true.
       @param{Function} with signature (DG.AttributePlacementDescription) returning Boolean
       @return {{attributeDescription: {DG.AttributePlacementDescription},
              place: {DG.Analysis.EPlace} }}
       */
      firstAttributeDescriptionSuchThat: function (iTestF) {
        var tAttributesByPlace = this.get('attributesByPlace'),
            tNumPlaces = tAttributesByPlace.length,
            tPlace;
        for (tPlace = 0; tPlace < tNumPlaces; tPlace++) {
          var tAttributeArray = tAttributesByPlace[tPlace],
              tLength = !SC.none(tAttributeArray) ? tAttributeArray.length : 0,
              tIndex;
          for (tIndex = 0; tIndex < tLength; tIndex++) {
            if (iTestF(tAttributeArray[tIndex]))
              return {
                attributeDescription: tAttributeArray[tIndex],
                place: tPlace
              };
          }
        }
        return {attributeDescription: null, place: DG.GraphTypes.EPlace.eUndefined};
      },

      /**
       @param{DG.Analysis.EAnalysisRole}
       @return{{attributeDescription: {DG.AttributePlacementDescription},
              place: {DG.Analysis.EPlace} }}
       */
      firstPlaceAndAttributeDescriptionForRole: function (iRole) {
        return this.firstAttributeDescriptionSuchThat(function (iDesc) {
          return iDesc.get('role') === iRole;
        });
      },

      /**
       * Utility method
       */
      invalidateAttributeDescriptionCaches: function (iCases, iChange) {
        if (this.get('xAttributeDescription'))
          this.get('xAttributeDescription').invalidateCaches(iCases, iChange);
        if (this.get('yAttributeDescription'))
          this.get('yAttributeDescription').invalidateCaches(iCases, iChange);
        if (this.get('y2AttributeDescription'))
          this.get('y2AttributeDescription').invalidateCaches(iCases, iChange);
        if (this.get('legendAttributeDescription'))
          this.get('legendAttributeDescription').invalidateCaches(iCases, iChange);
      },

      /**
       Pass along to attribute descriptions
       */
      invalidateCaches: function (iCases, iChange) {
        var tCases;
        if (!iCases && iChange && this._casesCache &&
            ((iChange.operation === 'createCase') || (iChange.operation === 'createCases'))) {

          // If the change is from a collection other than one we care about, bail
          var tChangedCollectionID = iChange.collection && iChange.collection.get('id'),
              tPlottedCollectionID = this.getPath('collectionClient.id'),
              tChangedCollectionIDs = iChange.collections && iChange.collections.map(function (iColl) {
                return iColl.get('id');
              }),
              tChangeIsRelevant = (tChangedCollectionID === tPlottedCollectionID) ||
                  (tChangedCollectionIDs && tChangedCollectionIDs.indexOf(tPlottedCollectionID) >= 0);
          // Newly created cases are never selected, so if displayOnlySelected is true, bail
          tChangeIsRelevant = tChangeIsRelevant && !this.get('displayOnlySelected');
          if (!tChangeIsRelevant)
            return;

          if (iChange.result.caseIDs || iChange.result.caseID) {
            var caseIDs = iChange.result.caseIDs || [iChange.result.caseID];
            caseIDs.forEach(function (iCaseID) {
              var tNewCase = this.get('dataContext').getCaseByID(iCaseID);
              if (tNewCase)
                this._casesCache.push(tNewCase);
            }.bind(this));
          }
          tCases = this._casesCache;
        } else {
          this._casesCache = null;
          tCases = iCases || this.get('cases');
        }
        this.invalidateAttributeDescriptionCaches(tCases, iChange);
      },

      whatIsBeingDisplayedDidChange: function () {
        this._casesCache = null;
        this.invalidateAttributeDescriptionCaches();
      }.observes('hiddenCases', 'displayOnlySelected'),

      /**
       * Something has happened such that cases have been deleted. Some cases in our hiddenCases array
       * may be among those deleted. We need to remove them.
       */
      synchHiddenCases: function () {
        var tHidden = this.get('hiddenCases'),
            tNoLongerPresent = tHidden.filter(function (iCase) {
              var tFound = DG.store.find(DG.Case, iCase.get('id'));
              return SC.none(tFound);
            });
        if (tNoLongerPresent.length > 0) {
          this.set('hiddenCases', DG.ArrayUtils.subtract(tHidden, tNoLongerPresent,
              function (iCase) {
                return iCase.get('id');
              }));
        }
      },

      /**
       @property { Array of SC.Array }
       */
      arrangedObjectArrays: function () {
        var tXVarCC = this.get('xCollectionClient'),
            tYVarCC = this.get('yCollectionClient'),
            tLegVarCC = this.get('legendCollectionClient'),
            tY2VarCC = this.get('y2CollectionClient'),
            tArrays = !SC.none(tXVarCC) ? [tXVarCC.casesController.arrangedObjects()] : [];
        if ((tXVarCC !== tYVarCC) && !SC.none(tYVarCC))
          tArrays.push(tYVarCC.casesController.arrangedObjects());
        if (!SC.none(tLegVarCC) && (tLegVarCC !== tXVarCC) && (tLegVarCC !== tYVarCC))
          tArrays.push(tLegVarCC.casesController.arrangedObjects());
        if (!SC.none(tY2VarCC) && (tY2VarCC !== tXVarCC) && (tY2VarCC !== tYVarCC) && (tY2VarCC !== tLegVarCC))
          tArrays.push(tY2VarCC.casesController.arrangedObjects());

        // In the situation in which there is not an x or a y or a legend collection client, we still want to
        // have arranged objects so that the "empty" plot will work
        if (tArrays.length === 0) {
          var tCC = DG.currDocumentController().collectionDefaults().collectionClient;
          if (tCC)
            tArrays.push(tCC.casesController.arrangedObjects());
        }

        return tArrays;
      }.property('xCollectionClient', 'yCollectionClient', 'legendCollectionClient'),

      /**
       @param { DG.GraphTypes.EPlace }
       @return{ {min:{Number}, max:{Number} isDataInteger:{Boolean}} }
       */
      getDataMinAndMaxForDimension: function (iDimension) {
        var tAttributeDescription;
        switch (iDimension) {
          case DG.GraphTypes.EPlace.eX:
            tAttributeDescription = this.get('xAttributeDescription');
            break;
          case DG.GraphTypes.EPlace.eY:
            tAttributeDescription = this.get('yAttributeDescription');
            break;
          case DG.GraphTypes.EPlace.eY2:
            tAttributeDescription = this.get('y2AttributeDescription');
            break;
          case DG.GraphTypes.EPlace.eLegend:
            tAttributeDescription = this.get('legendAttributeDescription');
            break;
        }
        return tAttributeDescription.getPath('attributeStats.minMax');
      },

      /**
       *
       * @returns {Boolean}
       */
      atLeastOneFormula: function () {
        var tProperties = ['xAttributeDescription', 'yAttributeDescription', 'legendAttributeDescription',
          'y2AttributeDescription'];
        return tProperties.some(function (iProperty) {
          return this.getPath(iProperty + '.hasFormula');
        }.bind(this));
      },

      /**
       * The given array of cases will be concatenated with the current array of hidden cases.
       * By using 'set' we trigger notification for observers.
       * @param iArrayOfCases
       */
      hideCases: function (iArrayOfCases) {
        if (!iArrayOfCases || !iArrayOfCases.length) return;
        this.notifyPropertyChange('hiddenCasesWillChange');
        this.set('hiddenCases', this.get('hiddenCases').concat(iArrayOfCases).uniq());
      },

      /**
       * The given array of cases will be subtracted from the current array of hidden cases.
       * By using 'set' we trigger notification for observers.
       * @param iArrayOfCases
       */
      showCases: function (iArrayOfCases) {
        if (!iArrayOfCases || !iArrayOfCases.length) return;
        this.notifyPropertyChange('hiddenCasesWillChange');
        this.set('hiddenCases', DG.ArrayUtils.subtract(this.get('hiddenCases'), iArrayOfCases,
            function (iCase) {
              return iCase && iCase.get('id');
            })
        );
      },

      /**
       * Set hidden cases to the empty array.
       * By using 'set' we trigger notification for observers.
       */
      showAllCases: function () {
        if (this.get('hiddenCases').length > 0)
          this.set('hiddenCases', []);
      },

      /**
       * Called from GraphModel.restoreStorage
       * @param iArrayOfCaseIDs {Array} of {Number}
       */
      restoreHiddenCases: function (iArrayOfCaseIDs) {
        this.showAllCases();
        if (!iArrayOfCaseIDs || !iArrayOfCaseIDs.length) return;
        this.set('hiddenCases', iArrayOfCaseIDs.map(function (iID) {
              return this.get('dataContext').getCaseByID(iID);
            }.bind(this)
        ));
      },

      /**
       *
       * @param ioStorage {Object}
       * @param iDim {String}
       */
      addToStorageForDimension: function (ioStorage, iDim) {
        var tCollection = this.get(iDim + 'CollectionClient'),
            tAttrDesc = this.get(iDim + 'AttributeDescription'),
            tAttrs = (tAttrDesc && tAttrDesc.get('attributes')) || [];
        if (tCollection && (tAttrs.length > 0)) {
          ioStorage._links_[iDim + 'Coll'] = tCollection.toLink();
          var tKey = iDim + 'Attr';
          tAttrs.forEach(function (iAttr) {
            DG.ArchiveUtils.addLink(ioStorage, tKey, iAttr);
          });
        }
        if (tAttrDesc) {
          ioStorage[iDim + 'Role'] = tAttrDesc.get('role');  // Has a role even without an attribute
          ioStorage[iDim + 'AttributeType'] = tAttrDesc.get('attributeType');
        }
      },

      /**
       * Store the parameters relating to number of legend quantiles, whether they are locked, and,
       * if locked, what they are.
       * @param ioStorage
       */
      addLegendQuantilesToStorage: function (ioStorage) {
        var tLocked = this.get('legendQuantilesAreLocked');
        ioStorage.numberOfLegendQuantiles = this.get('numberOfLegendQuantiles');
        ioStorage.legendQuantilesAreLocked = tLocked;
        if( tLocked) {
          ioStorage.legendQuantiles = this._legendQuantiles;
        }
      },

      restoreLegendQuantiles: function (iStorage) {
        this.set('numberOfLegendQuantiles', iStorage.numberOfLegendQuantiles || 5);
        if( iStorage.legendQuantilesAreLocked) {
          this._legendQuantiles = iStorage.legendQuantiles;
        }
        this.set('legendQuantilesAreLocked', iStorage.legendQuantilesAreLocked === true);
      },

      /**
       * The given attribute is typically not assigned to us but we need to know whether it should be treated as
       * nominal or not. We cannot use Attribute:isNominal because that will not use the same set of cases we will.
       *
       * @param iAttribute {DG.Attribute }
       * @return {boolean}
       */
      attributeIsNominal: function (iAttribute) {

        function getCollectionClient(iContext, iCollection) {
          var collectionID = iCollection && iCollection.get('id');
          return iContext && !SC.none(collectionID) && iContext.getCollectionByID(collectionID);
        }

        if (!this._tempAttrDescription) {
          this._tempAttrDescription = DG.AttributePlacementDescription.create();
        }
        var tDescription = this._tempAttrDescription;

        if (tDescription.get('attribute') !== iAttribute) {
          var tCollectionClient = getCollectionClient(this.get('dataContext'), iAttribute.get('collection'));
          tDescription.removeAllAttributes();
          tDescription.beginPropertyChanges();
          tDescription.set('collectionClient', (tCollectionClient) || null);
          this._casesCache = null;  // because setting a new attribute and collection client can require recomputation of cases
          tDescription.setCases(this.get('cases'));
          tDescription.addAttribute(iAttribute);
          tDescription.invalidateCaches(this.get('cases'));  // So that notification order won't be important
          tDescription.endPropertyChanges();
        }
        return tDescription.get('isCategorical');
      }

    });


/* >>>>>>>>>> BEGIN source/components/graph/data_model/graph_data_configuration.js */
// ==========================================================================
//                      DG.GraphDataConfiguration
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph_map_common/plot_data_configuration');

/** @class  DG.GraphDataConfiguration - The object that describes the manner in which attributes are
    assigned to places in a graph.

  @extends DG.PlotDataConfiguration
*/
DG.GraphDataConfiguration = DG.PlotDataConfiguration.extend(
/** @scope DG.GraphDataConfiguration.prototype */ 
{
  topCollectionClient: function () {
    return this.getPath('topAttributeDescription.collectionClient');
  }.property(),

  rightCollectionClient: function () {
    return this.getPath('rightAttributeDescription.collectionClient');
  }.property(),

  topCollectionDidChange: function () {
    this.notifyPropertyChange('topCollectionClient');
  }.observes('*topAttributeDescription.collectionClient'),

  rightCollectionDidChange: function () {
    this.notifyPropertyChange('rightCollectionClient');
  }.observes('*rightAttributeDescription.collectionClient'),

  /**
   @property { DG.AttributePlacementDescription }
   */
  topAttributeDescription: function (iKey, iValue) {
    return this.attributeDescriptionForPlace(iKey, iValue, DG.GraphTypes.EPlace.eTopSplit);
  }.property(),

  /**
   @property { DG.AttributePlacementDescription }
   */
  captionAttributeDescription: function (iKey, iValue) {
    return this.attributeDescriptionForPlace(iKey, iValue, DG.GraphTypes.EPlace.eCaption);
  }.property(),

  /**
   @property { DG.AttributePlacementDescription }
   */
  rightAttributeDescription: function (iKey, iValue) {
    return this.attributeDescriptionForPlace(iKey, iValue, DG.GraphTypes.EPlace.eRightSplit);
  }.property(),

  topAttributeID: function () {
    return this.getPath('topAttributeDescription.attributeID');
  }.property(),

  rightAttributeID: function () {
    return this.getPath('rightAttributeDescription.attributeID');
  }.property(),

  topAttributeIDDidChange: function () {
    this.notifyPropertyChange('topAttributeID');
  }.observes('*topAttributeDescription.attributeID'),

  rightAttributeIDDidChange: function () {
    this.notifyPropertyChange('rightAttributeID');
  }.observes('*rightAttributeDescription.attributeID'),

  /**
   * It is in initialization that we specialize from base class
   */
  init: function() {

    var attributeDescriptions = {
          caption: DG.AttributePlacementDescription.create(),
          x: DG.AttributePlacementDescription.create(),
          y: DG.AttributePlacementDescription.create(),
          y2: DG.AttributePlacementDescription.create(),
          legend: DG.AttributePlacementDescription.create(),
          top: DG.AttributePlacementDescription.create(),
          right: DG.AttributePlacementDescription.create()
        },
        tPlace,
        tDefaults = DG.currDocumentController().collectionDefaults();

    arguments.callee.base.apply(this,arguments);
    
    /**
        Utility function for use in confuguring the attribute descriptions
        @param  {String}    iAttrPrefix -- {'x','y','legend'}
        @param  {String}    iAttrInfix -- {'X','Y','Legend'}
        @param  {Number}    iNumericRole -- Numeric analysis role
        @param  {Number}    iCategoricalRole -- Categorical analysis role
     */
    var configAttrDesc = function( iAttrPrefix, iAttrInfix, iNumericRole, iCategoricalRole) {
      var attrDesc = attributeDescriptions[ iAttrPrefix],
          attrSpec = tDefaults['plot' + iAttrInfix + 'Attr'],
          isAttrNumeric = tDefaults['plot' + iAttrInfix + 'AttrIsNumeric'];
      isAttrNumeric = SC.none(isAttrNumeric) ? true : isAttrNumeric;
          
      DG.assert( attrDesc, 'Check for missing attribute description.');
      
      // Configure the attribute description for the specified default attribute
      if( attrSpec) {
        // Must set collection before attribute for attribute stats to be configured properly
        attrDesc.set('collectionClient', tDefaults.collectionClient);
        attrDesc.set('attribute', attrSpec);
        attrDesc.setPath('attributeStats.attributeType',
                        SC.none( attrSpec)
                            ? DG.Analysis.EAttributeType.eNone
                            : isAttrNumeric
                                ? DG.Analysis.EAttributeType.eNumeric
                                : DG.Analysis.EAttributeType.eCategorical);
        attrDesc.set('role',
                      SC.none( attrSpec)
                          ? DG.Analysis.EAnalysisRole.eNone
                          : isAttrNumeric ? iNumericRole : iCategoricalRole);
      }
      //
      // Null out the attribute description when no default attribute is specified.
      else {
        attrDesc.set('collectionClient', null);
        attrDesc.removeAllAttributes();
      }

      // We must set these up manually, because the infrastructure isn't in place by
      // the time arguments.callee.base.apply(this,arguments) (i.e. SC.Object.init()) is called.
      attrDesc.addObserver('collectionClient', this, iAttrPrefix + 'CollectionDidChange');
      attrDesc.addObserver('collection', this, 'collectionDidChange');
    }.bind( this);
    
    configAttrDesc('x', 'X', DG.Analysis.EAnalysisRole.ePrimaryNumeric,
                             DG.Analysis.EAnalysisRole.ePrimaryCategorical);
    configAttrDesc('y', 'Y', DG.Analysis.EAnalysisRole.eSecondaryNumeric,
                             DG.Analysis.EAnalysisRole.eSecondaryCategorical);
    configAttrDesc('y2', 'Y2', DG.Analysis.EAnalysisRole.eSecondaryNumeric,
                             DG.Analysis.EAnalysisRole.eSecondaryCategorical);
    configAttrDesc('legend', 'Legend', DG.Analysis.EAnalysisRole.eLegendNumeric,
                                       DG.Analysis.EAnalysisRole.eLegendCategorical);
    attributeDescriptions.legend.addObserver('attributeStats.categoricalStats.cellMap', this, 'legendColorMapDidChange');

    // Prepare the attributes array. It has as many elements as there are places,
    //  and, initially, those elements are empty arrays.
    this.attributesByPlace = [];
    for( tPlace = 0; tPlace < DG.GraphTypes.EPlace.eNumPlaces; tPlace++)
      this.attributesByPlace[tPlace] = [];
    
    // Actually, during this coding transition, we're going to stash the previously
    // initialized attribute descriptions in attributesByPlace.
    this.attributeDescriptionForPlace('caption', attributeDescriptions.caption, DG.GraphTypes.EPlace.eCaption);
    this.attributeDescriptionForPlace('x', attributeDescriptions.x, DG.GraphTypes.EPlace.eX);
    this.attributeDescriptionForPlace('y', attributeDescriptions.y, DG.GraphTypes.EPlace.eY);
    this.attributeDescriptionForPlace('y2', attributeDescriptions.y2, DG.GraphTypes.EPlace.eY2);
    this.attributeDescriptionForPlace('legend', attributeDescriptions.legend, DG.GraphTypes.EPlace.eLegend);
    this.attributeDescriptionForPlace('topSplit', attributeDescriptions.top, DG.GraphTypes.EPlace.eTopSplit);
    this.attributeDescriptionForPlace('right', attributeDescriptions.right, DG.GraphTypes.EPlace.eRightSplit);

    this.set('dataContext', tDefaults.dataContext);
  },

  destroy: function () {
    var topDesc = this.get('topAttributeDescription'),
        rightDesc = this.get('rightAttributeDescription');

    if (topDesc)
      topDesc.removeObserver('collectionClient', this, 'topCollectionDidChange');
    if (rightDesc)
      rightDesc.removeObserver('collectionClient', this, 'rightCollectionDidChange');

    arguments.callee.base.apply(this,arguments);
  },

  /**
   * We override so that we can make sure the caption attribute is set correctly
   */
  setAttributeAndCollectionClient: function () {
    arguments.callee.base.apply(this,arguments);
    this.updateCaptionAttribute();
  },

  legendColorMapDidChange: function() {
    this._casesCache = null;
  },

  /**
   Returns true if this graph references attributes in collections with aggregate
   functions, which is useful when determining whether a graph needs to be redrawn.
   @property   {Boolean}
   */
  hasAggregates: function () {
    var tResult = arguments.callee.base.apply(this,arguments);
    if( !tResult) {
      var collectionIDs = {},
          foundID,

          considerCollection = function (iDescriptor) {
            var collection = this.getPath(iDescriptor + 'AttributeDescription.collectionClient'),
                collectionID = collection && collection.get('id');
            if (!SC.none(collectionID))
              collectionIDs[collectionID] = collection;
          }.bind(this);

      // Consider each of our split collections in turn
      considerCollection('top');
      considerCollection('right');

      // Search through our set of collections, stopping on the first one that has aggregates.
      foundID = DG.ObjectMap.findKey(collectionIDs,
          function (iCollectionID, iCollection) {
            return iCollection && iCollection.get('hasAggregates');
          });
      tResult = !SC.none(foundID);
    }
    return tResult;
  }.property(),

  /**
   * @property {Boolean}
   */
  hasSplitAttribute: function() {
    return !!this.get('rightAttributeID') || !!this.get('topAttributeID');
  }.property( 'rightAttributeID', 'topAttributeID'),

  /**
   * Utility method
   */
  invalidateAttributeDescriptionCaches: function (iCases, iChange) {
    arguments.callee.base.apply(this,arguments);
    if (this.get('topAttributeDescription'))
      this.get('topAttributeDescription').invalidateCaches(iCases, iChange);
    if (this.get('rightAttributeDescription'))
      this.get('rightAttributeDescription').invalidateCaches(iCases, iChange);
  },

  /**
   *
   * @returns {Boolean}
   */
  atLeastOneFormula: function () {
    var tProperties = ['topAttributeDescription', 'rightAttributeDescription'];
    return (arguments.callee.base.apply(this,arguments) ||
        tProperties.some(function (iProperty) {
          return this.getPath(iProperty + '.hasFormula');
        }.bind(this)));
  }

});


/* >>>>>>>>>> BEGIN source/components/graph/data_model/univariate_stats.js */
// ==========================================================================
//                          DG.UnivariateStats
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

  Encapsulates the basic univariate statistics.

 @extends SC.Object
 */
DG.UnivariateStats = SC.Object.extend(
  /** @scope DG.UnivariateStats.prototype */ {

    /**
     * How many cases
     * @property {Number}
     */
    count:0,

    /**
     * Are all values either numbers or blank?
     * @property {DG.Analysis.EAttributeType}
     */
    attributeType:null,

    /**
     * Are all numeric values integers?
     * @property {Boolean}
     */
    dataIsInteger:null,

    /**
     * Sum of values
     * @property {Number}
     */
    sum:null,

    /**
     * Sum of squares of deviations from mean
     * @property {Number}
     */
    squaredDeviations:null,

    /**
     * Smallest value
     * @property {Number}
     */
    rangeMin:null,

    /**
     * Largest value
     * @property {Number}
     */
    rangeMax:null,

    /**
     * Useful as something to notify against when either min or max has (or might have) changed
     * @property{ {min:{Number}, max:{Number}}
     */
    numericRange:function () {
      return { min:this.get( 'rangeMin' ), max:this.get( 'rangeMax' )};
    }.property( 'rangeMin', 'rangeMax' ),

    /**
     * Smallest value greater than zero
     * @property {Number}
     */
    positiveMin:null,

    /**
     * Largest value greater than zero if there is one
     * @property {Number}
     */
    positiveMax:null,

    /**
     * True if count is either undefined or zero
     * @property {Boolean}
     */
    isEmpty:function () {
      return !this.count;
    }.property( 'count' ),

    /**
     * Mean value
     * @property {Number}
     */
    mean:function () {
      return !this.isEmpty() ? this.sum / this.count : NaN;
    }.property( 'count', 'sum' ).cacheable(),

    /**
     * True if count is either undefined or zero
     * @property {Boolean}
     */
    hasRange:function () {
      return DG.isFinite( this.rangeMin ) && DG.isFinite( this.rangeMax );
    }.property( 'rangeMin', 'rangeMax' ).cacheable(),

    /**
     * Return all values to original state
     */
    reset:function () {
      this.count = 0;
      this.attributeType = null;
      this.dataIsInteger = null;
      this.sum = null;
      this.squaredDeviations = null;
      this.rangeMin = null;
      this.rangeMax = null;
      this.positiveMin = null;
      this.positiveMax = null;
  }

  } );


/* >>>>>>>>>> BEGIN source/components/graph_map_common/data_display_controller.js */
// ==========================================================================
//                          DG.DataDisplayController
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/* global tinycolor */

sc_require('controllers/component_controller');

/** @class

    DG.DataDisplayController provides controller functionaly, particular gear menu items,
 for scatter plots.

 @extends SC.Controller
 */
DG.DataDisplayController = DG.ComponentController.extend(
    /** @scope DG.DataDisplayController.prototype */
    (function () {

      var kConfigPaneIconClass = 'moonicon-icon-segmented-bar-chart',
          kStylesPaneIconClass = 'moonicon-icon-styles';

      function getCollectionClientFromDragData(iContext, iDragData) {
        var collectionID = iDragData.collection && iDragData.collection.get('id');
        return iContext && !SC.none(collectionID) && iContext.getCollectionByID(collectionID);
      }


      return {
        kValuesPaneIconClass: 'moonicon-icon-values',

        dataContext: null,
        dataDisplayModel: null,
        legendView: null,
        stylesPane: null,

        /**
         * With the advent of map plotting multiple data contexts there is nothing we can do in common for
         * maps and graphs.
         * @return {{}}
         */
        createComponentStorage: function () {
          return {};
        },

        restoreComponentStorage: function (iStorage, iDocumentID) {
          arguments.callee.base.apply(this,arguments);
          var contextID = this.getLinkID(iStorage, 'context'),
              dataContext = null;

          if (!SC.none(contextID)) {
            dataContext = DG.currDocumentController().getContextByID(contextID);
            if (dataContext) {
              this.set('dataContext', dataContext);
              this.setPath('dataDisplayModel.dataConfiguration.dataContext', dataContext);
            }
          }
        },

        /**
         When our 'dataContext' is changed, we must let our model know.
         */
        dataContextDidChange: function () {
          var dataDisplayModel = this.get('dataDisplayModel');
          if (dataDisplayModel)
            dataDisplayModel.set('dataContext', this.get('dataContext'));
        }.observes('dataContext'),

        /**
         When our model changes, make sure it has the right 'dataContext'.
         */
        modelDidChange: function () {
          // Our model is our component; its content is the graph model
          var dataDisplayModel = this.getPath('model.content');
          this.set('dataDisplayModel', dataDisplayModel);
          if (dataDisplayModel) {
            dataDisplayModel.set('dataContext', this.get('dataContext'));
            dataDisplayModel.set('componentID', this.getPath('model.id'));
          }
        }.observes('model'),

        init: function () {
          arguments.callee.base.apply(this,arguments);
        },

        childmostCollectionTitle: function() {
          return this.getPath('dataDisplayModel.childmostCollectionTitle');
        }.property(),

        setComponentTitleByChildmostCollection: function() {
          if( !this.getPath('model.userSetTitle'))
            this.setPath('model.title', this.get('childmostCollectionTitle'));
        },

      /** Submenu items for copying/exporting component images */
      createImageExportMenuItems: function() {
        var tIsMapView = this.getPath('model.type') === 'DG.MapView',
            tBackground = this.getPath('graphModel.plotBackgroundImage'),
            tBackgroundCue = tBackground ?
                  'DG.DataDisplayMenu.removeBackgroundImage' : 'DG.DataDisplayMenu.addBackgroundImage',
            tBackgroundAction = tBackground ? 'removeBackgroundImage' : 'addBackgroundImage',
            tBackgroundItems = tIsMapView ? [] : [
                  { title: tBackgroundCue, isEnabled: true,
                    target: this, action: tBackgroundAction }
                ],
            tBothAxesAreNumeric = this.getPath('graphModel.bothAxesAreNumeric');
        if( tBackground && tBothAxesAreNumeric) {
          var tLockInfo = this.getPath('graphModel.plotBackgroundImageLockInfo'),
              tLocked = tLockInfo && tLockInfo.locked,
              tLockedCue = tLocked ? 'DG.DataDisplayMenu.unlockImageFromAxes' :
                  'DG.DataDisplayMenu.lockImageToAxes',
              tLockAction = tLocked ? 'unlockImageFromAxes' : 'lockImageToAxes';
          tBackgroundItems.push(
              { title: tLockedCue, isEnabled: true,
                target: this, action: tLockAction }
          );
        }
        return tBackgroundItems.concat([
          { title: ('DG.DataDisplayMenu.copyAsImage'), isEnabled: true/*(SC.browser.name !== SC.BROWSER.safari)*/,
            target: this, action: 'copyAsImage' },
          { title: ('DG.DataDisplayMenu.exportPngImage'), isEnabled: true,
            target: this, action: 'makePngImage' },
          { title: ('DG.DataDisplayMenu.exportSvgImage'), isEnabled: true,
            target: this, action: 'makeSvgImage' }
        ]);
      },

      createInspectorButtons: function () {
          var tResult = arguments.callee.base.apply(this,arguments),
              this_ = this;
          if( !this.get('dataDisplayModel').wantsInspector())
              return tResult;

          tResult.push(DG.IconButton.create({
            layout: {width: 32, left: 0, height: 25},
            classNames: 'dg-display-rescale'.w(),
            iconClass: 'moonicon-icon-scaleData',
            iconExtent: {width: 30, height: 25},
            target: this,
            action: 'rescaleFunction',
            toolTip: 'DG.Inspector.rescale.toolTip',  // "Rescale graph axes to encompass data"
            localize: true,
            init: function () {
              arguments.callee.base.apply(this,arguments);
              this_.get('dataDisplayModel').addObserver('canRescale', this, 'plotDidChange');
            },
            plotDidChange: function () {
              this.displayDidChange();
              this.set('isEnabled', this_.getPath('dataDisplayModel.canRescale'));
              this.set('toolTip', this_.getPath('dataDisplayModel.canMixUp') ?
                  'DG.Inspector.mixUp.toolTip' : 'DG.Inspector.rescale.toolTip');
            }
          }));

          var showHideShowPopup = function () {
            var tMenu = DG.MenuPane.create({
                  classNames: 'dg-display-hideshow-popup'.w(),
                  layout: {width: 200, height: 150}
                }),
                tMenuItems = this.get('dataDisplayModel').createHideShowSelectionMenuItems();
            tMenu.set('items', tMenuItems);
            tMenu.popup(tHideShowButton);
          }.bind(this);

          var tHideShowButton = DG.IconButton.create({
            layout: {width: 32},
            classNames: 'dg-display-hideshow'.w(),
            iconClass: 'moonicon-icon-hideShow',
            showBlip: true,
            target: this,
            action: showHideShowPopup,
            toolTip: 'DG.Inspector.hideShow.toolTip',  // "Show all cases or hide selected/unselected cases"
            localize: true
          });
          tResult.push(tHideShowButton);

          tResult.push(DG.IconButton.create({
            layout: {width: 32},
            classNames: 'dg-inspector-pane-button dg-display-values'.w(),
            iconClass: this.kValuesPaneIconClass,
            showBlip: true,
            target: this,
            action: 'showHideValuesPane',
            toolTip: 'DG.Inspector.displayValues.toolTip',
            localize: true
          }));

          var tConfigurationButton = DG.IconButton.create({
            layout: {width: 32},
            classNames: 'dg-inspector-pane-button dg-display-configuration'.w(),
            iconClass: kConfigPaneIconClass,
            showBlip: true,
            target: this,
            action: 'showHideConfigurationPane',
            toolTip: 'DG.Inspector.displayConfiguration.toolTip',
            localize: true,
            init: function () {
              arguments.callee.base.apply(this,arguments);
              this_.get('dataDisplayModel').addObserver('canSupportConfigurations', this, 'plotDidChange');

              this.plotDidChange(); // For initialization of visibility
            },
            plotDidChange: function () {
              this.set('isVisible', this_.getPath('dataDisplayModel.canSupportConfigurations'));
            }
          });
          tResult.push(tConfigurationButton);

          // iconClass is different for MapView style control
        var tIsMapView = this.getPath('model.type') === 'DG.MapView';
          tResult.push(DG.IconButton.create({
            layout: {width: 32},
            classNames: 'dg-inspector-pane-button dg-display-styles'.w(),
            iconClass: tIsMapView ? 'moonicon-icon-layers' : 'moonicon-icon-styles',
            showBlip: true,
            target: this,
            action: 'showHideStylesPane',
            toolTip: tIsMapView ? 'DG.Inspector.displayLayers.toolTip' : 'DG.Inspector.displayStyles.toolTip',
            localize: true
          }));

          var tImageExportButton;

          var showImageExportPopup = function () {
            var tMenu = DG.MenuPane.create({
                  classNames: 'dg-display-show-image-popup'.w(),
                  layout: {width: 200, height: 150}
                }),
                tMenuItems = this.createImageExportMenuItems();
            tMenu.set('items', tMenuItems);
            tMenu.popup(tImageExportButton);
          }.bind(this);

          if (this.makePngImage) {
            tImageExportButton = DG.IconButton.create({
              layout: {width: 32},
              iconExtent: {width: 30, height: 25},
              classNames: 'dg-display-camera'.w(),
              iconClass: 'moonicon-icon-tileScreenshot',
              target: this,
              action: showImageExportPopup,
              toolTip: 'DG.Inspector.makeImage.toolTip',
              localize: true
            });
            tResult.push(tImageExportButton);
          }

          return tResult;
        },

        /**
         * The content of the configuration pane depends on what plot is showing.
         */
        showHideConfigurationPane: function () {
          var this_ = this,
              kTitleHeight = 26,
              kMargin = 20,
              kLeading = 5,
              kRowHeight = 20;
              if (DG.InspectorPickerPane.close(kConfigPaneIconClass)) {
                return; // don't reopen if we just closed
              }
              this.configurationPane = DG.InspectorPickerPane.create(
              {
                buttonIconClass: kConfigPaneIconClass,
                classNames: 'dg-inspector-picker'.w(),
                layout: {width: 200, height: 260},
                contentView: SC.View.extend(SC.FlowedLayout,
                    {
                      layoutDirection: SC.LAYOUT_VERTICAL,
                      isResizable: false,
                      isClosable: false,
                      defaultFlowSpacing: {left: kMargin, bottom: kLeading},
                      canWrap: false,
                      align: SC.ALIGN_TOP,
                      layout: {right: 22},
                      childViews: 'title'.w(),
                      title: DG.PickerTitleView.extend({
                        layout: {height: kTitleHeight},
                        flowSpacing: {left: 0, bottom: kLeading},
                        title: 'DG.Inspector.configuration',
                        localize: true,
                        iconURL: '../../../../static/dg/de/cert/resources/images/icon-segmented-bar-chart.svg'
                      }),
                      init: function () {
                        arguments.callee.base.apply(this,arguments);
                        this_.getPath('dataDisplayModel.configurationDescriptions').forEach(function (iDesc) {
                          iDesc.properties.layout = Object.assign({height: kRowHeight}, iDesc.properties.layout);
                          iDesc.properties.localize = true;
                          this.appendChild(iDesc.constructorClass.create(iDesc.properties));
                        }.bind(this));
                        this_.getPath('dataDisplayModel.lastConfigurationControls').forEach(function (iControl) {
                          this.appendChild(iControl);
                        }.bind(this));
                      }
                    })
              });
          this.configurationPane.popup(this.get('inspectorButtons')[3], SC.PICKER_POINTER);
        },

        /**
         * The styles pane provides control over point size, color, and transparency.
         */
        showHideStylesPane: function () {
          var this_ = this,
              kTitleHeight = 26,
              kMargin = 20,
              kLeading = 5,
              tIsMapView = this.getPath('model.type') === 'DG.MapView',
              tStylesButton = this.get('inspectorButtons').find( function( iButton) {
                return iButton.get('classNames').indexOf( 'dg-display-styles') >= 0;
              });
          if (DG.InspectorPickerPane.close(kStylesPaneIconClass)) {
            return; // don't reopen if we just closed
          }

          // Note: Styles-pane title and icon are different for map views.
          this.stylesPane = DG.InspectorPickerPane.create(
              {
                // So we can identify closure through click on button icon
                buttonIconClass: tIsMapView ? 'moonicon-icon-layers' : 'moonicon-icon-styles',
                classNames: 'dg-inspector-picker'.w(),
                layout: {width: 250, height: 150},
                contentView: SC.View.extend(SC.FlowedLayout,
                    {
                      layoutDirection: SC.LAYOUT_VERTICAL,
                      isResizable: false,
                      isClosable: false,
                      defaultFlowSpacing: {left: kMargin, bottom: kLeading},
                      canWrap: false,
                      align: SC.ALIGN_TOP,
                      childViews: 'title'.w(),
                      title: DG.PickerTitleView.extend({
                        layout: {height: kTitleHeight},
                        flowSpacing: {left: 0, bottom: kLeading},
                        title: this.getPath('model.type') === 'DG.MapView' ? 'DG.Inspector.layers' : 'DG.Inspector.styles',
                        localize: true,
                        iconURL: tIsMapView ? '../../../../static/dg/de/cert/resources/images/icon-layers.svg' :
                            '../../../../static/dg/de/cert/resources/images/icon-styles.svg'
                      }),
                      init: function () {
                        arguments.callee.base.apply(this,arguments);
                        this_.get('styleControls').forEach(function (iControl) {
                          this.appendChild(iControl);
                        }.bind(this));
                      }
                    })
              });
          this.stylesPane.popup(tStylesButton, SC.PICKER_POINTER);
        },

        styleControls: function () {
          var this_ = this,
              tDataConfiguration = this.getPath('dataDisplayModel.dataConfiguration'),
              tLegendAttrDesc = tDataConfiguration.get('legendAttributeDescription'),
              tCategoryMap = tLegendAttrDesc.getPath('attribute.categoryMap'),
              currentOpenSession = null,
              setCategoryColor = function (iColor, iColorKey) {
                currentOpenSession = currentOpenSession || Math.random();
                DG.UndoHistory.execute(DG.Command.create({
                  name: 'data.style.categoryColorChange',
                  undoString: 'DG.Undo.graph.changePointColor',
                  redoString: 'DG.Redo.graph.changePointColor',
                  log: "Changed categorical point color",
                  execute: function() {
                    this.reduceKey = this.name + iColorKey + currentOpenSession;
                    this._beforeStorage = {
                      color: tCategoryMap[iColorKey],
                      alpha: this_.getPath('dataDisplayModel.transparency')
                    };
                    tCategoryMap[iColorKey] = iColor.toHexString();
                    this_.setPath('dataDisplayModel.transparency', iColor.getAlpha());
                    this_.get('dataDisplayModel').propertyDidChange('pointColor');
                    if( tLegendAttrDesc.get('attribute'))
                      tLegendAttrDesc.get('attribute').propertyDidChange('categoryMap');
                  },
                  undo: function () {
                    tCategoryMap[iColorKey] = this._beforeStorage.color;
                    this_.setPath('dataDisplayModel.transparency', this._beforeStorage.alpha);
                    this_.get('dataDisplayModel').propertyDidChange('pointColor');
                  },
                  reduce: function (previous) {
                    if (previous.reduceKey === this.reduceKey) {
                      this._beforeStorage = previous._beforeStorage;
                      return this;
                    }
                  }
                }));
              },
              setCategoryColorFinalized = function () {
                currentOpenSession = null;
              },
              createSetColorAndAlphaCommand = function (name, colorAttr, alphaAttr, iColor) {
                return DG.Command.create({
                  name: 'data.style.'+name,
                  undoString: 'DG.Undo.graph.'+name,
                  redoString: 'DG.Redo.graph.'+name,
                  log: "Changed point color",
                  execute: function() {
                    SC.run( function() {
                      this.reduceKey = this.name + currentOpenSession;
                      this._beforeStorage = {
                        color: this_.getPath('dataDisplayModel.' + colorAttr),
                        alpha: this_.getPath('dataDisplayModel.' + alphaAttr)
                      };
                      this_.setPath('dataDisplayModel.' + colorAttr, iColor.toHexString());
                      this_.setPath('dataDisplayModel.' + alphaAttr, iColor.getAlpha());
                      if( tLegendAttrDesc.get('attribute'))
                        tLegendAttrDesc.get('attribute').propertyDidChange('categoryMap');
                    }.bind( this));
                  },
                  undo: function () {
                    this_.setPath('dataDisplayModel.' + colorAttr, this._beforeStorage.color);
                    this_.setPath('dataDisplayModel.' + alphaAttr, this._beforeStorage.alpha);
                  },
                  reduce: function (previous) {
                    if (previous.reduceKey === this.reduceKey) {
                      this._beforeStorage = previous._beforeStorage;
                      return this;
                    }
                  }
                });
              },
              createSetAttributeColorCommand = function (name, end, alphaAttr, iColor) {
                return DG.Command.create({
                  name: 'data.style.'+name,
                  undoString: 'DG.Undo.graph.'+name,
                  redoString: 'DG.Redo.graph.'+name,
                  log: "Changed" + end + " attribute color",
                  execute: function() {
                    this.reduceKey = this.name + currentOpenSession;
                    this._beforeStorage = {
                      color: tCategoryMap[end + '-attribute-color'],
                      alpha: this_.getPath('dataDisplayModel.' + alphaAttr)
                    };
                    tCategoryMap[end + '-attribute-color'] = iColor.toHexString();
                    this_.setPath('dataDisplayModel.' + alphaAttr, iColor.getAlpha());
                    this_.get('dataDisplayModel').propertyDidChange('pointColor');
                    if( tLegendAttrDesc.get('attribute'))
                      tLegendAttrDesc.get('attribute').propertyDidChange('categoryMap');
                  },
                  undo: function () {
                    tCategoryMap['attribute-color'] = this._beforeStorage.color;
                    this_.setPath('dataDisplayModel.' + alphaAttr, this._beforeStorage.alpha);
                  },
                  reduce: function (previous) {
                    if (previous.reduceKey === this.reduceKey) {
                      this._beforeStorage = previous._beforeStorage;
                      return this;
                    }
                  }
                });
              },
              setColor = function (iColor) {
                currentOpenSession = currentOpenSession || Math.random();
                DG.UndoHistory.execute(createSetColorAndAlphaCommand("changePointColor",
                    "pointColor", "transparency", iColor));
              },
              setLowColor = function (iColor) {
                currentOpenSession = currentOpenSession || Math.random();
                  DG.UndoHistory.execute(createSetAttributeColorCommand("changeAttributeColor", "low",
                      "transparency", iColor));
              },
              setHighColor = function (iColor) {
                currentOpenSession = currentOpenSession || Math.random();
                  DG.UndoHistory.execute(createSetAttributeColorCommand("changeAttributeColor", "high",
                      "transparency", iColor));
              },
              setColorFinalized = function () {
                currentOpenSession = null;
              },
              setStroke = function (iColor) {
                currentOpenSession = currentOpenSession || Math.random();
                DG.UndoHistory.execute(createSetColorAndAlphaCommand("changeStrokeColor",
                    "strokeColor", "strokeTransparency", iColor));
              },
              setStrokeFinalized = function () {
                currentOpenSession = null;
              },
              getStylesLayer = function () {
                return this_.stylesPane.layer();
              },
              kRowHeight = 20,
              tResult = [
                DG.PickerControlView.create({
                  layout: {height: kRowHeight},
                  label: 'DG.Inspector.pointSize',
                  controlView: SC.SliderView.create({
                    layout: {width: 120},
                    classNames: 'dg-graph-pointSize-slider'.w(),
                    controlSize: SC.SMALL_CONTROL_SIZE,
                    value: this.getPath('dataDisplayModel.pointSizeMultiplier'),
                    minimum: 0, maximum: 3, step: 0,
                    valueChanged: function () {
                      var picker = this;
                      DG.UndoHistory.execute(DG.Command.create({
                        name: 'data.style.pointSizeChanged',
                        undoString: 'DG.Undo.graph.changePointSize',
                        redoString: 'DG.Redo.graph.changePointSize',
                        log: "Changed point size",
                        execute: function() {
                          this._beforeStorage = this_.getPath('dataDisplayModel.pointSizeMultiplier');
                          this_.setPath('dataDisplayModel.pointSizeMultiplier', picker.get('value'));
                        },
                        undo: function () {
                          this_.setPath('dataDisplayModel.pointSizeMultiplier', this._beforeStorage);
                        },
                        reduce: function (previous) {
                          if (previous.name === this.name) {
                            this._beforeStorage = previous._beforeStorage;
                            return this;
                          }
                        }
                      }));
                    }.observes('value')
                  })
                })
              ];
          if (tLegendAttrDesc.get('isNull')) {
            var tInitialColor = tinycolor(this.getPath('dataDisplayModel.pointColor'))
                  .setAlpha(this.getPath('dataDisplayModel.transparency'));
            tResult.push(
                DG.PickerControlView.create({
                  layout: {height: 2 * kRowHeight},
                  label: 'DG.Inspector.color',
                  controlView: DG.PickerColorControl.create({
                    layout: {width: 120},
                    classNames: 'dg-graph-point-color'.w(),
                    initialColor: tInitialColor,
                    setColorFunc: setColor,
                    closedFunc: setColorFinalized,
                    appendToLayerFunc: getStylesLayer
                  })
                })
            );
          }
          else if( tLegendAttrDesc.get('isNumeric')) {
            if(tCategoryMap && SC.none( tCategoryMap['attribute-color'])) {
              var tColor = DG.ColorUtilities.calcAttributeColor( tLegendAttrDesc);
              tCategoryMap['attribute-color'] = tColor.colorString || tColor;
            }
            var tAttrColor = tCategoryMap && tCategoryMap['attribute-color'],
                tControlView = SC.View.create(SC.FlowedLayout,
                    {
                      layoutDirection: SC.LAYOUT_HORIZONTAL,
                      layout: {width: 120 },
                      isResizable: false,
                      isClosable: false,
                      //defaultFlowSpacing: {right: 5},
                      canWrap: false,
                      align: SC.ALIGN_TOP
                    }
                ),
                tSpectrumEnds = DG.ColorUtilities.getAttributeColorSpectrumEndsFromColorMap( tCategoryMap, tAttrColor),
                tLowEndColor = tinycolor(tSpectrumEnds.low.colorString)
                    .setAlpha(this.getPath('dataDisplayModel.transparency')),
                tHighEndColor = tinycolor(tSpectrumEnds.high.colorString)
                    .setAlpha(this.getPath('dataDisplayModel.transparency'));
            tControlView.appendChild( DG.PickerColorControl.create({
                  layout: {width: 60},
                  classNames: 'dg-graph-point-color'.w(),
                  initialColor: tLowEndColor,
                  setColorFunc: setLowColor,
                  closedFunc: setColorFinalized,
                  appendToLayerFunc: getStylesLayer
                })
            );
            tControlView.appendChild( DG.PickerColorControl.create({
                  layout: {width: 60},
                  classNames: 'dg-graph-point-color'.w(),
                  initialColor: tHighEndColor,
                  setColorFunc: setHighColor,
                  closedFunc: setColorFinalized,
                  appendToLayerFunc: getStylesLayer
                })
            );
            tResult.push(
                DG.PickerControlView.create({
                  layout: {height: 2 * kRowHeight},
                  label: 'DG.Inspector.legendColor',
                  controlView:tControlView
                })
            );
            tResult.push(SC.CheckboxView.create({
              layout: {height: 25},
              title: 'DG.Inspector.lockLegendQuantiles',
              toolTip: 'DG.Inspector.lockLegendQuantilesTooltip',
              value: tDataConfiguration.get('legendQuantilesAreLocked'),
              classNames: 'dg-graph-lockLegendQuantiles-check'.w(),
              localize: true,
              valueDidChange: function () {
                var quantilesAreLocked = !tDataConfiguration.get('legendQuantilesAreLocked'),
                   logMessage = "Set quantilesAreLocked to " + quantilesAreLocked;
                DG.UndoHistory.execute(DG.Command.create({
                  name: 'legend.quantilesAreLockedChange',
                  undoString: quantilesAreLocked ? 'DG.Undo.legend.lockQuantiles' : 'DG.Undo.legend.unlockQuantiles',
                  redoString: quantilesAreLocked ? 'DG.Redo.legend.lockQuantiles' : 'DG.Redo.legend.unlockQuantiles',
                  log: logMessage,
                  execute: function () {
                    tDataConfiguration.toggleProperty('legendQuantilesAreLocked');
                  }.bind(this),
                  undo: function () {
                    tDataConfiguration.toggleProperty('legendQuantilesAreLocked');
                  }.bind(this)
                }));
              }.bind(this).observes('value')
            }));
          }
          tResult.push(
              DG.PickerControlView.create({
                layout: {height: 2 * kRowHeight},
                label: 'DG.Inspector.stroke',
                controlView: DG.PickerColorControl.create({
                  layout: {width: 120},
                  classNames: 'dg-graph-stroke-color'.w(),
                  initialColor: tinycolor(this.getPath('dataDisplayModel.strokeColor'))
                      .setAlpha(this.getPath('dataDisplayModel.strokeTransparency')),
                  setColorFunc: setStroke,
                  closedFunc: setStrokeFinalized,
                  appendToLayerFunc: getStylesLayer
                })
              })
          );
          tResult.push(SC.CheckboxView.create({
            layout: {height: 25},
            title: 'DG.Inspector.strokeSameAsFill',
            value: this.getPath('dataDisplayModel.strokeSameAsFill'),
            classNames: 'dg-graph-strokeSameAsFill-check'.w(),
            localize: true,
            valueDidChange: function () {
              var becomingSameAsFill = !this.getPath('dataDisplayModel.strokeSameAsFill'),
                  logMessage = "Made stroke color " + (becomingSameAsFill ? "same as fill" : "independent of fill");
              DG.UndoHistory.execute(DG.Command.create({
                name: 'plot.strokeSameAsFillChange',
                undoString: becomingSameAsFill ? 'DG.Undo.graph.makeStrokeSameAsFill' : 'DG.Undo.graph.makeStrokeIndependent',
                redoString: becomingSameAsFill ? 'DG.Redo.graph.makeStrokeSameAsFill' : 'DG.Redo.graph.makeStrokeIndependent',
                log: logMessage,
                execute: function () {
                  this.get('dataDisplayModel').toggleProperty('strokeSameAsFill');
                }.bind(this),
                undo: function () {
                  this.get('dataDisplayModel').toggleProperty('strokeSameAsFill');
                }.bind(this)
              }));
            }.bind(this).observes('value')
          }));
          if (tLegendAttrDesc.get('isCategorical')) {
            var tContentView = SC.View.create(SC.FlowedLayout,
                {
                  layoutDirection: SC.LAYOUT_VERTICAL,
                  isResizable: false,
                  isClosable: false,
                  defaultFlowSpacing: {bottom: 5},
                  canWrap: false,
                  align: SC.ALIGN_TOP,
                }
                ),
                tScrollView = SC.ScrollView.create({
                  layout: {height: 100},
                  hasHorizontalScroller: false,
                  contentView: tContentView
                }),
                tAttribute = tLegendAttrDesc.get('attribute');
            tAttribute.forEachCategory(function (iCategory) {
              var tCalcColor = DG.ColorUtilities.calcCaseColor(iCategory, tLegendAttrDesc),
                  tInitialColor = tCategoryMap[iCategory] ?
                  tCategoryMap[iCategory] :
                      tCalcColor.colorString || tCalcColor;
              tInitialColor = tinycolor(tInitialColor.colorString || tInitialColor).
                                setAlpha(this.getPath('dataDisplayModel.transparency'));
              tContentView.appendChild(DG.PickerControlView.create({
                layout: {height: 2 * kRowHeight},
                label: iCategory,
                controlView: DG.PickerColorControl.create({
                  layout: {width: 120},
                  classNames: 'dg-graph-point-color'.w(),
                  initialColor: tInitialColor,
                  colorKey: iCategory,
                  setColorFunc: setCategoryColor,
                  closedFunc: setCategoryColorFinalized,
                  appendToLayerFunc: getStylesLayer
                })
              }));
            }.bind(this));
            tResult.push(tScrollView);
          }

          return tResult;
        }.property(),

        addAxisHandler: function (iAxisView) {
          var this_ = this,
              tNodes = iAxisView.get('labelNodes');

          if (SC.isArray(tNodes)) {
            tNodes.forEach(function (iNode, iIndex) {

              function mouseDownHandler(iEvent) {
                SC.run( function() {
                  this_.setupAttributeMenu(iEvent, iAxisView, iIndex);
                });
                iEvent.preventDefault();
                iEvent.stopImmediatePropagation();
              }

              iNode.unmousedown(mouseDownHandler); // In case it got added already
              iNode.mousedown(mouseDownHandler);
            });
          }
        },

        /**
         An axis view has been assigned to the property named iPropertyKey.
         We want to hook up to its labelNode so that clicking on it will bring
         up an attribute menu.
         */
        axisViewChanged: function (iThis, iPropertyKey) {
          var this_ = this,
              tView = this.get(iPropertyKey);
          if (!SC.none(tView)) {
            this.addAxisHandler( tView);
            tView.addObserver('labelNode', this,
                function () {
                  this_.addAxisHandler(tView);
                });
          }
        }.observes('xAxisView', 'yAxisView', 'y2AxisView', 'legendView', 'topAxisView', 'rightAxisView'),

        setupAttributeMenu: function (event, iAxisView, iAttrIndex) {
          var tDataDisplayModel = this.get('dataDisplayModel'),
              tMenuLayout = {left: event.layerX, top: event.layerY, height: 20, width: 20},
              tMenuAnchorView = SC.View.create({
                layout: tMenuLayout,
                backgroundColor: 'transparent'
              }),

              tOrientation = iAxisView.get('orientation'),
          // The following parameter is supposed to specify the preferred position of the menu
          // relative to the anchor. But it doesn't seem to have any effect.
          // SC.POINTER_LAYOUT = ["perfectRight", "perfectLeft", "perfectTop", "perfectBottom"];
              tPreferMatrix = (tOrientation === DG.GraphTypes.EOrientation.kHorizontal) ?
                  [0, 2, 1, 3, 0] :
                  [0, 1, 3, 2, 0],
              tAxisKey = '',
              tMenuItems,

          tAttributeMenu = DG.MenuPane.create({});

          // A FormulaAxisView has its own handler for its menu
          var tChangeHandler = iAxisView.menuChangeHandler ? iAxisView.menuChangeHandler.bind(iAxisView) :
              this.attributeMenuItemChanged;
          tAttributeMenu.addObserver('selectedItem', this, tChangeHandler);

          iAxisView.appendChild(tMenuAnchorView);

          if (iAxisView.instanceOf(DG.LegendView))
            tAxisKey = 'legend';
          else {
            switch (tOrientation) {
              case DG.GraphTypes.EOrientation.kHorizontal:
                tAxisKey = 'x';
                break;
              case DG.GraphTypes.EOrientation.kVertical:
                tAxisKey = 'y';
                break;
              case DG.GraphTypes.EOrientation.kVertical2:
                tAxisKey = 'y2';
                break;
              default:
                tAxisKey = tOrientation;
            }
          }

          tMenuItems = iAxisView.getMenuItems ? iAxisView.getMenuItems() : this.getAttributeMenuItems();
          // WARNING: before we added this separator, the "Remove Attribute" menu item had a bug where it would not respond correctly
          // on the first click.  It appears that SC.MenuItemView.mouseUp() gets a null 'targetMenuItem' at that point,
          // which prevents our menu handler from being called.  This may or may not a bug related to the submenu just above this point.
          // --Craig and Kirk 2012-06-07
          tMenuItems.push({isSeparator: YES});
          var kNotForSubmenu = false;
          tMenuItems.push(tDataDisplayModel.createRemoveAttributeMenuItem(
              iAxisView, tAxisKey, kNotForSubmenu, iAttrIndex));
          if (tAxisKey !== 'y2')
            tMenuItems.push(tDataDisplayModel.createChangeAttributeTypeMenuItem(iAxisView, tAxisKey));
          tAttributeMenu.set('items', tMenuItems);
          tAttributeMenu.selectedAxis = tOrientation;
          tAttributeMenu.isLegend = iAxisView.instanceOf(DG.LegendView);

          // We need SC to accomplish the layout of the anchor view before we
          // show the popup menu. Initiating and ending a runloop seems to be one way
          // to accomplish this.
          SC.run(function(){
            tAttributeMenu.popup(tMenuAnchorView, tPreferMatrix);
          }.bind(this));
          iAxisView.removeChild(tMenuAnchorView);
        },

        /**
         *
         * @returns {[{title,subMenu]}
         */
        getAttributeMenuItems: function () {
          var tMenuItems = [],
              //tContext = this.get('dataContext'),
              tContexts = DG.currDocumentController().get('contexts');
          tContexts.forEach( function( iContext) {
            iContext.forEachCollection( function( iCollClient) {
              var tName = iCollClient.get('name'),
                  tAttrNames = iCollClient.getVisibleAttributeNames();
              tMenuItems.push({ title: tName,
                subMenu: tAttrNames.map( function( iAttrName) {
                  return { title: iAttrName, collection: iCollClient, context: iContext };
                })});
            });
          });
          if( tMenuItems.length === 1) {
            return tMenuItems[0].subMenu;
          }
          else
            return tMenuItems;
        },

        /**
         Handle a 'Change...' or 'Remove {location} Attribute' menu item.
         Menu items set up by setupAttributeMenu()
         */
        attributeMenuItemChanged: function ( iMenu) {
          var tNewItem = iMenu.get('selectedItem'),
              tCollectionClient = tNewItem && tNewItem.collection,
              tAxisOrientation = iMenu.selectedAxis,
              tIsLegend = iMenu.isLegend;

          // For safety's sake, remove this method as an observer of iMenu
          iMenu.removeObserver('selectedItem', this, this.attributeMenuItemChanged);

          DG.UndoHistory.execute(DG.Command.create({
            name: 'axis.attributeChange',
            undoString: 'DG.Undo.axisAttributeChange',
            redoString: 'DG.Redo.axisAttributeChange',
            executeNotification: {
              action: 'notify',
              resource: 'component',
              values: {
                operation: 'attributeChange',
                type: 'DG.GraphView',
                id: this.getPath('model.id'),
                attributeName: tNewItem.get('title'),
                axisOrientation: tAxisOrientation
              }
            },
            _beforeStorage: null,
            _afterStorage: null,
            _componentId: this.getPath('model.id'),
            _controller: function () {
              return DG.currDocumentController().componentControllersMap[this._componentId];
            },
            execute: function () {
              var controller = this._controller();
              this._beforeStorage = controller.createComponentStorage();

              var tAttrRefs,
                  tDataDisplayModel = controller.get('dataDisplayModel'),
                  tDataContext = tNewItem && tNewItem.context;

              controller.handlePossibleForeignDataContext && controller.handlePossibleForeignDataContext(tDataContext);

              if (!tNewItem) {
                this.set('causedChange', false);
                return;
              }
              if (tCollectionClient) {
                // change attribute. Note: Can't use index because of possible hidden attributes.
                var tAttr = tCollectionClient.attrsController.get('content').find(function(iObject) {
                  return iObject.name === tNewItem.title;
                });
                tAttrRefs = {
                  collection: tCollectionClient,
                  attributes: [tAttr]
                };
                if (tIsLegend) {
                  tNewItem.log = "legendAttributeChange: { to attribute %@ }".fmt(tAttrRefs.attributes[0].get('name'));
                  tDataDisplayModel.changeAttributeForLegend(tDataContext, tAttrRefs);
                } else {
                  tNewItem.log = 'plotAxisAttributeChange: { orientation: %@, attribute: %@ }'.fmt(tAxisOrientation, tAttrRefs.attributes[0].get('name'));
                  tDataDisplayModel.changeAttributeForAxis(tDataContext, tAttrRefs, tAxisOrientation);
                }
              } else if (tNewItem.target === tDataDisplayModel) {
                // remove or change attribute
                tNewItem.itemAction.apply(tNewItem.target, tNewItem.args);
              }
              controller.setComponentTitleByChildmostCollection();
              this.log = tNewItem.log || 'Axis attribute menu item selected: %@'.fmt(tNewItem.title);
            },
            undo: function () {
              var controller = this._controller();
              this._afterStorage = controller.createComponentStorage();
              controller.restoreComponentStorage(this._beforeStorage);
              controller.setComponentTitleByChildmostCollection();
            },
            redo: function () {
              this._controller().restoreComponentStorage(this._afterStorage);
              this._afterStorage = null;
              this._controller().setComponentTitleByChildmostCollection();
            }
          }));
        },

        /**
         The plot, map, or legend view has received a drop of an attribute. Our job is to forward this properly on to
         the graph so that the configuration can be changed.
         */
        plotOrLegendViewDidAcceptDrop: function (iView, iKey, iDragData) {
          if (SC.none(iDragData)) // The over-notification caused by the * in the observes
            return;       // means we get here at times there isn't any drag data.

          var controller = this;

          DG.UndoHistory.execute(DG.Command.create({
            name: 'axis.attributeChange',
            undoString: 'DG.Undo.axisAttributeChange',
            redoString: 'DG.Redo.axisAttributeChange',
            _beforeStorage: null,
            _afterStorage: null,
            _componentId: this.getPath('model.id'),
            executeNotification: {
              action: 'notify',
              resource: 'component',
              values: {
                operation: 'legendAttributeChange',
                type: this.get('dataDisplayModel').constructor.toString(),
                id: this.getPath('model.id'),
                attributeName: iDragData.attribute.get('name')
              }
            },
            execute: function () {
              this._beforeStorage = controller.createComponentStorage();

              var tDragContext = iDragData.context,
                  tCollectionClient = getCollectionClientFromDragData(tDragContext, iDragData),
                  tDisplayModel = controller.get('dataDisplayModel');
              tDisplayModel.handleDroppedContext( tDragContext);
              controller.set('dataContext', tDragContext);

              iView.dragData = null;

              tDisplayModel.changeAttributeForLegend(
                  tDragContext,
                  {
                    collection: tCollectionClient,
                    attributes: [iDragData.attribute]
                  });
              controller.get('view').select();
              controller.setComponentTitleByChildmostCollection();

              this.log = 'legendAttributeChange: { to attribute %@ }'.fmt(iDragData.attribute.get('name'));
            },
            undo: function () {
              this._afterStorage = controller.createComponentStorage();
              controller.restoreComponentStorage(this._beforeStorage);
              controller.setComponentTitleByChildmostCollection();
            },
            redo: function () {
              controller.restoreComponentStorage(this._afterStorage);
              this._afterStorage = null;
              controller.setComponentTitleByChildmostCollection();
            }
          }));
        },

        convertToImage: function (imageType, rootEl, width, height, title) {

          function saveImage(dataUrl, extension, mime) {
            var reader = new FileReader();
            reader.addEventListener("loadend", function() {
              var data = reader.result.split(",").pop();  // get rid of base64 header
              DG.exportFile(data, extension, mime);
            });
            reader.readAsDataURL(dataUrl);
          }

          if (imageType === 'png') {
            DG.ImageUtilities.captureSVGElementsToImage(rootEl, width, height,
                title)
                .then(function (blob) {
                  saveImage(blob, "png", "image/png");
                }, function (msg) {
                  DG.log(msg);
                });
          }
          else if (imageType === 'svg') {
            DG.exportFile(
                  DG.ImageUtilities.captureGraphToSVG(rootEl, width, height, title),
              'svg', 'text/plain');
          }
        },

        openDrawToolWithImage: function (rootEl, width, height, title) {

          DG.ImageUtilities.captureSVGElementsToImage(rootEl, width, height, title, true)
            .then(function (dataURL) {
              SC.run(function () {
                DG.appController.importDrawToolWithDataURL(dataURL, title);
              });
            }, function (msg) {
              DG.log(msg);
            });
        },

        makePngImage: function () {
          var componentView = this.get('view');
          var graphView = componentView && componentView.get('contentView');
          var width = graphView.getPath('frame.width');
          var height = graphView.getPath('frame.height');
          var title = componentView.get('title');
          this.convertToImage('png', graphView.get('layer'), width, height, title);
        },

        makeSvgImage: function () {
          var componentView = this.get('view');
          var graphView = componentView && componentView.get('contentView');
          var width = graphView.getPath('frame.width');
          var height = graphView.getPath('frame.height');
          var title = componentView.get('title');
          this.convertToImage('svg', graphView.get('layer'), width, height, title);
        },

        copyAsImage: function () {
          var componentView = this.get('view'),
              title = (componentView && componentView.get('title')) ||
                  "DG.DocumentController.graphTitle".loc(),
              graphView = componentView && componentView.get('contentView'),
              layer = graphView && graphView.get('layer'),
              width = graphView && graphView.getPath('frame.width'),
              height = graphView && graphView.getPath('frame.height');
          if (graphView)
            this.openDrawToolWithImage(layer, width, height, title);
        },


      };

    }()) // function closure
);

/* >>>>>>>>>> BEGIN source/components/graph/graph_controller.js */
// ==========================================================================
//                          DG.GraphController
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/* global tinycolor */

sc_require('components/graph_map_common/data_display_controller');

/** @class

    DG.GraphController provides controller functionality, particular gear menu items,
 for graphs.

 @extends SC.DataDisplayController
 */
DG.GraphController = DG.DataDisplayController.extend(
    /** @scope DG.GraphController.prototype */
    (function () {

      function getCollectionClientFromDragData(iContext, iDragData) {
        var collectionID = iDragData.collection && iDragData.collection.get('id');
        return iContext && !SC.none(collectionID) && iContext.getCollectionByID(collectionID);
      }

      return {
        graphModel: function () {
          return this.get('dataDisplayModel');
        }.property('dataDisplayModel'),
        xAxisView: null,
        yAxisView: null,
        bottomAxisLabelView: null,
        leftAxisLabelView: null,
        y2AxisView: null,
        plotView: null,
        axisMultiTarget: null,
        topAxisView: null,
        rightAxisView: null,

        createComponentStorage: function () {
          var storage = {_links_: {}},
              dataContext = this.get('dataContext'),
              dataConfiguration = this.getPath('dataDisplayModel.dataConfiguration'),
              hiddenCases = dataConfiguration && dataConfiguration.get('hiddenCases');

          if (dataContext)
            storage._links_.context = dataContext.toLink();

          storage.displayOnlySelected = dataConfiguration.get('displayOnlySelected');
          dataConfiguration.addToStorageForDimension(storage, 'legend');
          dataConfiguration.addLegendQuantilesToStorage(storage);

          if (hiddenCases) {
            storage._links_.hiddenCases = hiddenCases
                .filter(function (iCase) {
                  return !!iCase;
                })
                .map(function (iCase) {
                  return iCase.toLink();
                });
          }
          storage.pointColor = this.getPath('dataDisplayModel.pointColor');
          storage.strokeColor = this.getPath('dataDisplayModel.strokeColor');
          storage.pointSizeMultiplier = this.getPath('dataDisplayModel.pointSizeMultiplier');
          storage.transparency = this.getPath('dataDisplayModel.transparency');
          storage.strokeTransparency = this.getPath('dataDisplayModel.strokeTransparency');
          storage.strokeSameAsFill = this.getPath('dataDisplayModel.strokeSameAsFill');

          var plotModels = this.getPath('graphModel.plots');

          var storeAxis = function (iDim) {
            var tAxis = this.getPath('graphModel.' + iDim + 'Axis');
            if (tAxis)
              storage[iDim + 'AxisClass'] = String(tAxis.constructor);
            if (tAxis && tAxis.get('isNumeric')) {
              storage[iDim + 'LowerBound'] = tAxis.get('lowerBound');
              storage[iDim + 'UpperBound'] = tAxis.get('upperBound');
            }
          }.bind(this);

          storage.isTransparent = this.getPath('graphModel.isTransparent');
          storage.plotBackgroundColor = this.getPath('graphModel.plotBackgroundColor');
          storage.plotBackgroundOpacity = this.getPath('graphModel.plotBackgroundOpacity');
          storage.plotBackgroundImage = this.getPath('graphModel.plotBackgroundImage');
          storage.plotBackgroundImageLockInfo = this.getPath('graphModel.plotBackgroundImageLockInfo');
          storage.enableNumberToggle = this.getPath('graphModel.enableNumberToggle');
          if (storage.enableNumberToggle)
            storage.numberToggleLastMode = this.getPath('graphModel.numberToggle.lastMode');
          storage.enableMeasuresForSelection = this.getPath('graphModel.enableMeasuresForSelection');

          dataConfiguration.addToStorageForDimension(storage, 'x');
          dataConfiguration.addToStorageForDimension(storage, 'y');
          dataConfiguration.addToStorageForDimension(storage, 'y2');
          dataConfiguration.addToStorageForDimension(storage, 'top');
          dataConfiguration.addToStorageForDimension(storage, 'right');

          storeAxis('x');
          storeAxis('y');
          storeAxis('y2');
          storeAxis('top');
          storeAxis('right');

          if (plotModels) {
            storage.plotModels = [];
            plotModels.forEach(function (iPlot) {
              storage.plotModels.push({
                plotModelStorage: iPlot.createStorage(),
                plotClass: String(iPlot.constructor)
              });
            });
          }

          return storage;
        },

        restoreComponentStorage: function (iStorage, iDocumentID) {
          var graphModel = this.get('dataDisplayModel');

          arguments.callee.base.apply(this,arguments);

          if (SC.none(iStorage._links_))
            return; // We don't support the older format 0096 and before. Just bring up the default graph
                    // that we already have.

          graphModel.restoreStorage(iStorage);

          // There may be some animations that have been set up. We have to stop them so that changes
          // we make below (e.g. to axis bounds) will stick.
          graphModel.stopAnimation();

          graphModel.updateAxisArrays();
          graphModel.updateSplitPlotArray();
          // Configure the axes
          ['x', 'y', 'y2'].forEach(function (iKey) {
            var tAxis = graphModel.get(iKey + 'Axis');
            if (tAxis && tAxis.get('isNumeric') &&
                isFinite(iStorage[iKey + 'LowerBound']) && isFinite(iStorage[iKey + 'UpperBound'])) {
              tAxis.setLowerAndUpperBounds(iStorage[iKey + 'LowerBound'], iStorage[iKey + 'UpperBound']);
            }
          });
        },

        /**
         * @property {DG.GraphView}
         */
        graphView: function () {
          return this.getPath('view.containerView.contentView');
        }.property('view'),

        viewDidChange: function () {
          this.notifyPropertyChange('graphView');
          var graphView = this.get('graphView');
          if (graphView) {
            this.set('xAxisView', graphView.get('xAxisView'));
            this.set('yAxisView', graphView.get('yAxisView'));
            this.set('bottomAxisLabelView', graphView.get('bottomAxisLabelView'));
            this.set('leftAxisLabelView', graphView.get('leftAxisLabelView'));
            this.set('y2AxisView', graphView.get('y2AxisView'));
            this.set('plotView', graphView.get('plotBackgroundView'));
            this.set('legendView', graphView.get('legendView'));
            this.set('axisMultiTarget', graphView.get('yAxisMultiTarget'));
            this.set('topAxisView', graphView.get('topAxisView'));
            this.set('rightAxisView', graphView.get('rightAxisView'));
            graphView.set('controller', this);
            graphView.addObserver('plotViewsReconfigured', this, this.addPlotViewObservers);
            graphView.addObserver('plotViewsWillBeDestroyed', this, this.removePlotViewObservers);
            this.addPlotViewObservers();
          }
        }.observes('*view.containerView.contentView'),

        /**
         * We get here through notification when our graphView has deleted all the plot views except the root
         * so that it can create new ones that work for a new attribute configuration.
         */
        addPlotViewObservers: function() {
          var this_ = this;
          this.getPath('graphView.plotBackgroundViewArray').forEach(
              function (iBackgroundViewArray, iRow) {
                iBackgroundViewArray.forEach(function (iBackgroundPlotView, iCol) {
                  // We don't have to add to the root plotView
                  if ((iRow !== 0 || iCol !== 0) && iBackgroundPlotView)
                    iBackgroundPlotView.addObserver('dragData', this_, this_.plotOrLegendViewDidAcceptDrop);
                });
              });
          this.getPath('graphView.xAxisViewArray').concat(this.getPath('graphView.yAxisViewArray')).
            forEach(function (iAxisView, iIndex) {
              if (iAxisView && !iAxisView.hasObserverFor('dragData', this_, this_.axisViewDidAcceptDrop))
                iAxisView.addObserver('dragData', this_, this_.axisViewDidAcceptDrop);
          });
        },

        /**
         * We get here through notification when our graphView is about to delete all the plot views except the root
         * so that it can create new ones that work for a new attribute configuration.
         */
        removePlotViewObservers: function() {
          var this_ = this;
          this.get('graphView').get('plotBackgroundViewArray').forEach(
              function( iBackgroundViewArray, iRow){
                iBackgroundViewArray.forEach( function( iBackgroundPlotView, iCol){
                  // We don't have to add to the root plotView
                  if( (iRow !== 0 || iCol !== 0) && iBackgroundPlotView)
                    iBackgroundPlotView.removeObserver('dragData', this_, this_.plotOrLegendViewDidAcceptDrop);
                });
              } );
          this.getPath('graphView.xAxisViewArray').concat(this.getPath('graphView.yAxisViewArray')).
          forEach(function (iAxisView, iIndex) {
            if (iAxisView)
              iAxisView.removeObserver('dragData', this_, this_.axisViewDidAcceptDrop);
          });
        },

        /**
         * The content of the values pane depends on what plot is showing; e.g. a scatterplot will have a checkbox
         * for showing a movable line, while a univariate dot plot will have one for showing a movable value.
         */
        showHideValuesPane: function () {
          var this_ = this,
              kTitleHeight = 26,
              kMargin = 20,
              kLeading = 5,
              kRowHeight = 20;
          if (DG.InspectorPickerPane.close(this.kValuesPaneIconClass)) {
            return; // don't reopen if we just closed
          }
          this.valuesPane = DG.InspectorPickerPane.create(
              {
                buttonIconClass: this.kValuesPaneIconClass,
                classNames: 'dg-inspector-picker'.w(),
                layout: {width: 200, height: 260},
                contentView: SC.View.extend(SC.FlowedLayout,
                    {
                      layoutDirection: SC.LAYOUT_VERTICAL,
                      isResizable: false,
                      isClosable: false,
                      defaultFlowSpacing: {left: kMargin, bottom: kLeading},
                      canWrap: false,
                      align: SC.ALIGN_TOP,
                      layout: {right: 22},
                      childViews: 'title showLabel'.w(),
                      title: DG.PickerTitleView.extend({
                        layout: {height: kTitleHeight},
                        flowSpacing: {left: 0, bottom: kLeading},
                        title: 'DG.Inspector.values',
                        localize: true,
                        iconURL: '../../../../static/dg/de/cert/resources/images/icon-values.svg'
                      }),
                      showLabel: SC.LabelView.extend({
                        layout: {height: kRowHeight},
                        value: 'DG.Inspector.displayShow',
                        localize: true
                      }),
                      init: function () {
                        arguments.callee.base.apply(this,arguments);
                        this_.getPath('dataDisplayModel.checkboxDescriptions').forEach(function (iDesc) {
                          if( iDesc.control) {
                            this.appendChild( iDesc.control);
                            if( iDesc.control.instanceOf(SC.ButtonView) && iDesc.action) {
                              iDesc.control.set('action', function() {
                                this_.get(iDesc.action)(this_.get('dataDisplayModel'),
                                   this_.get('inspectorButtons')[2]);
                              });
                            }
                          }
                          else {
                            iDesc.layout = {height: kRowHeight};
                            iDesc.localize = true;
                            this.appendChild(SC.CheckboxView.create(iDesc));
                          }
                        }.bind(this));
                        this_.getPath('dataDisplayModel.lastValueControls').forEach(function (iControl) {
                          this.appendChild(iControl);
                        }.bind(this));
                      }
                    })
              });
          this.valuesPane.popup(this.get('inspectorButtons')[2], SC.PICKER_POINTER);
        },

        /**
         * This pane is displayed for the univariate plot ruler menu when the user clicks "Measures of Spread"
         */
        showHideSpreadsSubPane: function (iDataDisplayModel, iAnchorView) {
          var kMargin = 20,
              kLeading = 5,
              kRowHeight = 20,
              tSavedInspectorPicker = DG.get('inspectorPicker');  // We have to restore this as the global
          var tValuesPane = DG.InspectorPickerPane.create(
              {
                classNames: 'dg-inspector-picker '.w(),
                layout: {width: 200, height: 260},
                contentView: SC.View.extend(SC.FlowedLayout,
                    {
                      layoutDirection: SC.LAYOUT_VERTICAL,
                      isResizable: false,
                      isClosable: false,
                      defaultFlowSpacing: {left: kMargin, bottom: kLeading},
                      canWrap: false,
                      align: SC.ALIGN_TOP,
                      layout: {right: 22},
                      childViews: 'close'.w(),
                      close: SC.ButtonView.extend({
                        classNames: 'dg-inspector-back'.w(),
                        layout: {top: 3, height: kRowHeight + 3, width: 50},
                        flowSpacing: {top: 3, left: kMargin / 2, bottom: kLeading},
                        title: '←',
                        action: function() {
                          tValuesPane.remove();
                          tValuesPane.destroy();
                        }
                      }),
                      init: function () {
                        arguments.callee.base.apply(this,arguments);
                        iDataDisplayModel.get('spreadCheckboxDescriptions').forEach(function (iDesc) {
                          if( iDesc.control) {
                            this.appendChild(iDesc.control);
                          }
                          else {
                            iDesc.layout = { height: kRowHeight };
                            iDesc.localize = true;
                            this.appendChild(SC.CheckboxView.create(iDesc));
                          }
                        }.bind(this));
                      }
                    })
              });
          DG.set('inspectorPicker', tSavedInspectorPicker); // Restore the global because it got clobbered
          // Store a pointer to this pane, so we can close it when the main picker pane is closed
          DG.setPath('inspectorPicker.subPane', tValuesPane);
          tValuesPane.popup(iAnchorView, SC.PICKER_POINTER);
        }.bind(this),

        addBackgroundImage: function () {

          function handleAbnormal() {
            console.log("Abort or error on file read.");
          }

          function handleRead() {
            var tImage = this.result;
            DG.UndoHistory.execute(DG.Command.create({
              name: 'graph.addBackgroundImage',
              undoString: 'DG.Undo.graph.addBackgroundImage',
              redoString: 'DG.Redo.graph.addBackgroundImage',
              _backgroundImage: null,
              executeNotification: {
                action: 'notify',
                resource: 'component',
                values: {
                  operation: 'backgroundImage',
                  type: 'DG.GraphView'
                }
              },
              execute: function () {
                tGraphModel.set('plotBackgroundImage', tImage);
              },
              undo: function () {
                this._backgroundImage = tGraphModel.get('plotBackgroundImage');
                tGraphModel.set('plotBackgroundImage', null);
              },
              redo: function () {
                tGraphModel.set('plotBackgroundImage', this._backgroundImage);
              }
            }));

          }

          function parseData(iData) {
            if (iData) {
              var tReader = new FileReader();
              tReader.onabort = handleAbnormal;
              tReader.onerror = handleAbnormal;
              tReader.onload = handleRead;
              tReader.readAsDataURL(iData.file.object);
            }
          }

          var tGraphModel = this.get('graphModel');
          return DG.cfmClient._ui.importDataDialog((function (_this) {
            return function (data) {
              return parseData(data);
            };
          })(this));

        },

        removeBackgroundImage: function () {
          var tGraphModel = this.get('graphModel');

          DG.UndoHistory.execute(DG.Command.create({
            name: 'graph.removeBackgroundImage',
            undoString: 'DG.Undo.graph.removeBackgroundImage',
            redoString: 'DG.Redo.graph.removeBackgroundImage',
            _backgroundImage: null,
            executeNotification: {
              action: 'notify',
              resource: 'component',
              values: {
                operation: 'backgroundImage',
                type: 'DG.GraphView'
              }
            },
            execute: function () {
              this._backgroundImage = tGraphModel.get('plotBackgroundImage');
              tGraphModel.set('plotBackgroundImage', null);
            },
            undo: function () {
              tGraphModel.set('plotBackgroundImage', this._backgroundImage);
            },
            redo: function () {
              tGraphModel.set('plotBackgroundImage', null);
            }
          }));
        },

        lockImageToAxes: function () {
          var tGraphModel = this.get('graphModel'),
              tInfo = {
                locked: true,
                xAxisLowerBound: tGraphModel.getPath('xAxis.lowerBound'),
                xAxisUpperBound: tGraphModel.getPath('xAxis.upperBound'),
                yAxisLowerBound: tGraphModel.getPath('yAxis.lowerBound'),
                yAxisUpperBound: tGraphModel.getPath('yAxis.upperBound')
              };

          DG.UndoHistory.execute(DG.Command.create({
            name: 'graph.lockBackgroundImage',
            undoString: 'DG.Undo.graph.lockBackgroundImage',
            redoString: 'DG.Redo.graph.lockBackgroundImage',
            _backgroundImage: null,
            executeNotification: {
              action: 'notify',
              resource: 'component',
              values: {
                operation: 'lockBackgroundImage',
                type: 'DG.GraphView'
              }
            },
            execute: function () {
              tGraphModel.set('plotBackgroundImageLockInfo', tInfo);
            },
            undo: function () {
              tGraphModel.set('plotBackgroundImageLockInfo', null);
            },
            redo: function () {
              tGraphModel.set('plotBackgroundImageLockInfo', tInfo);
            }
          }));
        },

        unlockImageFromAxes: function () {
          var tGraphModel = this.get('graphModel'),
              tInfo = tGraphModel.get('plotBackgroundImageLockInfo');

          DG.UndoHistory.execute(DG.Command.create({
            name: 'graph.unlockBackgroundImage',
            undoString: 'DG.Undo.graph.unlockBackgroundImage',
            redoString: 'DG.Redo.graph.unlockBackgroundImage',
            _backgroundImage: null,
            executeNotification: {
              action: 'notify',
              resource: 'component',
              values: {
                operation: 'unlockBackgroundImage',
                type: 'DG.GraphView'
              }
            },
            execute: function () {
              tGraphModel.set('plotBackgroundImageLockInfo', null);
            },
            undo: function () {
              tGraphModel.set('plotBackgroundImageLockInfo', tInfo);
            }
          }));
        },


        plotFunction: function () {
          this.graphModel.get('plot').togglePlotFunction();
        },

        /**
         * A case plot can't be rescaled, but it can do a mixUp.
         */
        rescaleFunction: function () {
          var tGraphModel = this.get('graphModel'),
              tPlot = tGraphModel.get('plot');
          if (tPlot && tPlot.mixUp)
            tGraphModel.mixUp();
          else if (tGraphModel.get('hasNumericAxis'))
            tGraphModel.rescaleAxesFromData(true /* allowAxisRescale */, true /* Animate action */,
                true /* log it */, true /* user action */);
        },

        /**
         * If the given drag data has a data context different than our own, we must reset the
         * graph model. (I.e. until such time as we are able to handle multiple contexts on one graph.)
         * @param iDragData
         */
        handlePossibleForeignDataContext: function (iDataContext) {
          var tDragContext = iDataContext,
              tExistingContext = this.get('dataContext');

          if (tDragContext && (tDragContext !== tExistingContext)) {
            if( tExistingContext)
              this.get('graphModel').reset();
            this.set('dataContext', tDragContext);
            var tConfig = this.getPath('graphModel.dataConfiguration');
            tConfig.set('dataContext', tDragContext);
            tConfig.invalidateCaches();
          }
        },

        /**
         An axis view has received a drop of an attribute. Our job is the tell the graph
         model which attribute and collection client to change so that we move into the
         desired configuration of attributes.
         Note that we need the '*' in the observes because the views are swapped out when the
         graph gets reconfigured.
         */
        axisViewDidAcceptDrop: function (iAxis, iKey, iDragData) {
          iDragData = iDragData || iAxis.dragData;
          if (SC.none(iDragData)) // The over-notification caused by the * in the observes
            return;       // means we get here at times there isn't any drag data.

          DG.UndoHistory.execute(DG.Command.create({
            name: 'axis.attributeChange',
            undoString: 'DG.Undo.axisAttributeChange',
            redoString: 'DG.Redo.axisAttributeChange',
            executeNotification: {
              action: 'notify',
              resource: 'component',
              values: {
                operation: 'attributeChange',
                type: 'DG.GraphView',
                id: this.getPath('model.id'),
                attributeName: iDragData.attribute.get('name'),
                axisOrientation: iAxis.get('orientation')
              }
            },
            _beforeStorage: null,
            _afterStorage: null,
            _componentId: this.getPath('model.id'),
            _controller: function () {
              return DG.currDocumentController().componentControllersMap[this._componentId];
            },
            execute: function () {
              var controller = this._controller();
              this._beforeStorage = controller.createComponentStorage();

              controller.handlePossibleForeignDataContext(iDragData.context);

              var tDataContext = controller.get('dataContext'),
                  tCollectionClient = getCollectionClientFromDragData(tDataContext, iDragData),
                  tOrientation = iAxis.get('orientation'),
                  tModel = controller.get('graphModel'),
                  tAttrRefs = {
                    collection: tCollectionClient,
                    attributes: [iDragData.attribute]
                  };

              iAxis.dragData = null;
              tModel.changeAttributeForAxis(tDataContext, tAttrRefs, tOrientation);

              this.log = 'plotAxisAttributeChange: ' +
                  '{ "orientation": "%@", "attribute": "%@" }'
                      .fmt(iAxis.get('orientation'), iDragData.attribute.get('name'));
              controller.get('view').select();
              controller.setComponentTitleByChildmostCollection();
            },
            undo: function () {
              var controller = this._controller();
              this._afterStorage = controller.createComponentStorage();
              controller.restoreComponentStorage(this._beforeStorage);
              controller.setComponentTitleByChildmostCollection();
            },
            redo: function () {
              this._controller().restoreComponentStorage(this._afterStorage);
              this._controller().setComponentTitleByChildmostCollection();
              this._afterStorage = null;
            }
          }));
        }.observes('*xAxisView.dragData', '*yAxisView.dragData', '*bottomAxisLabelView.dragData',
            '*leftAxisLabelView.dragData', '*rightAxisView.dragData', '*topAxisView.dragData'),

        /**
         The add attribute target has received a drop of an attribute. We respond by adding an
         attribute to whatever is already on the y-axis.
         */
        multiTargetDidAcceptDrop: function (iAxisMultiTarget, iKey, iDragData) {
          if (SC.none(iDragData)) // The over-notification caused by the * in the observes
            return;       // means we get here at times there isn't any drag data.

          DG.UndoHistory.execute(DG.Command.create({
            name: 'axis.attributeChangeMultiTarget',
            undoString: 'DG.Undo.axisAttributeAdded',
            redoString: 'DG.Redo.axisAttributeAdded',
            _beforeStorage: null,
            _afterStorage: null,
            _componentId: this.getPath('model.id'),
            _controller: function () {
              return DG.currDocumentController().componentControllersMap[this._componentId];
            },
            executeNotification: {
              action: 'notify',
              resource: 'component',
              values: {
                operation: 'add axis attribute',
                type: 'DG.GraphView'
              }
            },
            execute: function () {
              var controller = this._controller(),
                  tDataConfiguration = controller.getPath('graphModel.dataConfiguration');
              this._beforeStorage = controller.createComponentStorage();

              controller.handlePossibleForeignDataContext(iDragData.context);

              var tDataContext = controller.get('dataContext'),
                  tCollectionClient = getCollectionClientFromDragData(tDataContext, iDragData),
                  tGraphModel = controller.get('graphModel'),
                  tAttrRefs = {
                    collection: tCollectionClient,
                    attributes: [iDragData.attribute]
                  };

              iAxisMultiTarget.dragData = null;

              if (tDataConfiguration.attributeIsNominal(iDragData.attribute)) {
                tGraphModel.splitByAttribute(tDataContext, tAttrRefs, 'top');

                this.log = 'Graph split vertically attribute %@'.fmt(iDragData.attribute.get('name'));
              }
              else {
                tGraphModel.addAttributeToAxis(tDataContext, tAttrRefs);

                this.log = 'Attribute dragged and dropped: %@, %@'.fmt('vertical', iDragData.attribute.get('name'));
              }
              controller.get('view').select();
            },
            undo: function () {
              var controller = this._controller();
              this._afterStorage = controller.createComponentStorage();
              controller.restoreComponentStorage(this._beforeStorage);
              controller.get('graphModel').notifyPropertyChange('attributeRemoved');
            },
            redo: function () {
              this._controller().restoreComponentStorage(this._afterStorage);
              this._afterStorage = null;
              this._controller().get('graphModel').notifyPropertyChange('attributeAdded');
            }
          }));
        }.observes('*axisMultiTarget.dragData'),

        /**
         The Y2 axis has received a drop of an attribute. We respond by creating a new scatterplot that
         uses the existing x-axis and the Y2 axis.
         */
        y2AxisDidAcceptDrop: function (iY2Axis, iKey, iDragData) {
          if (SC.none(iDragData)) // The over-notification caused by the * in the observes
            return;       // means we get here at times there isn't any drag data.

          DG.UndoHistory.execute(DG.Command.create({
            name: 'axis.attributeChangeY2',
            undoString: 'DG.Undo.axisAttributeChangeY2',
            redoString: 'DG.Redo.axisAttributeChangeY2',
            _beforeStorage: null,
            _afterStorage: null,
            _componentId: this.getPath('model.id'),
            _controller: function () {
              return DG.currDocumentController().componentControllersMap[this._componentId];
            },
            executeNotification: {
              action: 'notify',
              resource: 'component',
              values: {
                operation: 'add 2nd axis attribute',
                type: 'DG.GraphView'
              }
            },
            execute: function () {
              var controller = this._controller(),
                  tDataConfiguration = controller.getPath('graphModel.dataConfiguration');
              this._beforeStorage = controller.createComponentStorage();

              var tDataContext = controller.get('dataContext'),
                  tCollectionClient = getCollectionClientFromDragData(tDataContext, iDragData),
                  tOrientation = iY2Axis.get('orientation'),
                  tModel = controller.get('graphModel'),
                  tAttrRefs = {
                    collection: tCollectionClient,
                    attributes: [iDragData.attribute]
                  };

              iY2Axis.dragData = null;
              if (tDataConfiguration.attributeIsNominal(iDragData.attribute)) {
                tModel.splitByAttribute(tDataContext, tAttrRefs, 'right');
              }
              else {
                tModel.changeAttributeForY2Axis(tDataContext, tAttrRefs, tOrientation);
              }
              controller.get('view').select();

              this.log = 'changeAttributeOnSecondYAxis: { attribute: %@ }'.fmt(iDragData.attribute.get('name'));
            },
            undo: function () {
              var controller = this._controller();
              this._afterStorage = controller.createComponentStorage();
              controller.restoreComponentStorage(this._beforeStorage);
              controller.get('graphModel').notifyPropertyChange('attributeRemoved');
            },
            redo: function () {
              this._controller().restoreComponentStorage(this._afterStorage);
              this._afterStorage = null;
              this._controller().get('graphModel').notifyPropertyChange('y2AttributeAdded');
            }
          }));
        }.observes('*y2AxisView.dragData'),

        /**
         Our base class can handle this except for the situation in which this is the first attribute being dropped,
         in which case we want to override the default behavior and simulate drop on the x-axis, which is probably
         what the user intended, but missed.
         */
        plotOrLegendViewDidAcceptDrop: function (iView, iKey, iDragData) {
          var tDataConfig = this.getPath('graphModel.dataConfiguration');
          iDragData = iDragData || iView.get('dragData'); // In certain situations we have to get it directly
          if (!tDataConfig.get('xAttributeID') &&
              !tDataConfig.get('yAttributeID') &&
              !tDataConfig.get('legendAttributeID')) {
            iView.dragData = null;  // So we don't come back around
            this.axisViewDidAcceptDrop(this.get('xAxisView'), iKey, iDragData);
          }
          else
            arguments.callee.base.apply(this,arguments);
        }.observes('*plotView.dragData', '*legendView.dragData'),

        styleControls: function () {
          var tResult = arguments.callee.base.apply(this,arguments);
          var
              kRowHeight = 20,
              this_ = this,
              currentOpenSession = null,
              tBkgColor = tinycolor(this.getPath('graphModel.plotBackgroundColor') || 'white'),
              tOpacity = this.getPath('graphModel.plotBackgroundOpacity');
          tOpacity = SC.none(tOpacity) ? 1 : tOpacity;
          var tInitialColor = tBkgColor.setAlpha(tOpacity),
              getStylesLayer = function () {
                return this.stylesPane.layer();
              }.bind(this),
              createSetColorAndAlphaCommand = function (name, colorAttr, alphaAttr, iColor) {
                return DG.Command.create({
                  name: 'data.style.' + name,
                  undoString: 'DG.Undo.graph.' + name,
                  redoString: 'DG.Redo.graph.' + name,
                  log: "Changed background color",
                  executeNotification: {
                    action: 'notify',
                    resource: 'component',
                    values: {
                      operation: 'change background color',
                      type: 'DG.GraphView'
                    }
                  },
                  execute: function () {
                    this.reduceKey = this.name + currentOpenSession;
                    this._beforeStorage = {
                      color: this_.getPath('graphModel.' + colorAttr),
                      alpha: this_.getPath('graphModel.' + alphaAttr)
                    };
                    this_.setPath('graphModel.' + colorAttr, iColor.toHexString());
                    this_.setPath('graphModel.' + alphaAttr, iColor.getAlpha());
                  },
                  undo: function () {
                    this_.setPath('graphModel.' + colorAttr, this._beforeStorage.color);
                    this_.setPath('graphModel.' + alphaAttr, this._beforeStorage.alpha);
                  },
                  reduce: function (previous) {
                    if (previous.reduceKey === this.reduceKey) {
                      this._beforeStorage = previous._beforeStorage;
                      return this;
                    }
                  }
                });
              },
              setColor = function (iColor) {
                currentOpenSession = currentOpenSession || Math.random();
                DG.UndoHistory.execute(createSetColorAndAlphaCommand("changeBackgroundColor",
                    "plotBackgroundColor", "plotBackgroundOpacity", iColor));
              },
              setColorFinalized = function () {
                currentOpenSession = null;
              };
          tResult.push(
              DG.PickerControlView.create({
                layout: {height: 2 * kRowHeight},
                label: 'DG.Inspector.backgroundColor',
                controlView: DG.PickerColorControl.create({
                  layout: {width: 120},
                  classNames: 'dg-graph-point-color'.w(),
                  initialColor: tInitialColor,
                  setColorFunc: setColor,
                  closedFunc: setColorFinalized,
                  appendToLayerFunc: getStylesLayer
                })
              })
          );
          tResult.push(SC.CheckboxView.create({
            layout: {height: 25},
            title: 'DG.Inspector.graphTransparency',
            value: this.getPath('graphModel.isTransparent'),
            classNames: 'dg-graph-transparent-check'.w(),
            localize: true,
            valueDidChange: function () {
              var turningTransparent = !this.getPath('graphModel.isTransparent'),
                  logMessage = "Made plot background " + (turningTransparent ? "transparent" : "opaque");
              DG.UndoHistory.execute(DG.Command.create({
                name: 'plot.transparencyChange',
                undoString: 'DG.Undo.graph.toggleTransparent',
                redoString: 'DG.Redo.graph.toggleTransparent',
                log: logMessage,
                executeNotification: {
                  action: 'notify',
                  resource: 'component',
                  values: {
                    operation: 'toggle background transparency',
                    type: 'DG.GraphView'
                  }
                },
                execute: function () {
                  this.get('graphModel').toggleProperty('isTransparent');
                }.bind(this),
                undo: function () {
                  this.get('graphModel').toggleProperty('isTransparent');
                }.bind(this)
              }));
            }.bind(this).observes('value')
          }));

          return tResult;
        }.property()
      };

    }()) // function closure
);


/* >>>>>>>>>> BEGIN source/components/graph_map_common/data_layer_model.js */
// ==========================================================================
//                            DG.DataLayerModel
//
//  Author:   William Finzer
//
//  Copyright ©2014 Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('alpha/destroyable');
sc_require('components/graph/utilities/plot_utilities');

/** @class  DG.DataLayerModel - The model for a for use in a display situation such as a graph or map.

 @extends SC.Object
 */
DG.DataLayerModel = SC.Object.extend( DG.Destroyable,
  /** @scope DG.DataLayerModel.prototype */
  {
    autoDestroyProperties: [ 'legend' ],

    /**
     * @property {number} May be used to access controller for calls to createComponentStorage and
     * restoreComponentStorage for purposes of undo/redo
     */
    componentID: null,

    /**
     @property { DG.LegendModel }
     */
    legend: null,

    /**
     @property { DG.GraphDataConfiguration }
     */
    dataConfiguration: null,

    /**
     * @property {String}
     */
    defaultTitle: function() {
      return this.getPath('dataConfiguration.defaultTitle');
    }.property(),

    defaultTitleChanged: function() {
      this.notifyPropertyChange('defaultTitle');
    }.observes('*dataConfiguration.defaultTitle'),

    /**
      @property { DG.CollectionClient }
    */
    collectionClient: null,
    collectionClientBinding: '*dataConfiguration.collectionClient',

    /**
      The plot model needs access to the cases controller that is stored in my dataConfiguration's
        collection client.
      @property { SC.ArrayController }
    */
    casesController: null,
    casesControllerBinding: '*dataConfiguration.collectionClient.casesController',

    /**
     * @property {Array} of DG.Case
     */
    cases: function() {
      return this.getPath('dataConfiguration.cases');
    }.property(),

    casesDidChange: function() {
      this.notifyPropertyChange('cases');
    }.observes('*dataConfiguration.cases'),
    
    /**
      @property { SC.SelectionSet }
    */
    selection: function() {
      return this.getPath('dataConfiguration.selection');
    }.property(),

    selectionDidChange: function() {
      this.notifyPropertyChange('selection');
    }.observes('*dataConfiguration.selection'),
    
    /**
     Work around current notification bug whereby we get notified that number of cases has
     changed even when it hasn't.
     @property {Number}
     */
    _oldNumberOfCases: 0,

    /**
     * Point color default can be changed by user.
     * @property {String} representing a color
     */
    pointColor: DG.PlotUtilities.kDefaultPointColor,

    /**
     * This function is passed as an accessor to certain plots and axes
     * @return {*}
     */
    getPointColor: function() {
      return this.get('pointColor');
    },

    /**
     * Stroke color default can be changed by user.
     * @property {String} representing a color
     */
    _strokeColor: null,
    /**
     * @property{Number} between 0 and 1
     */
    _strokeTransparency: null,

    strokeColor: function( iKey, iValue) {
      var tLegendAttribute = this.hasLegendVar() &&
            this.getPath('dataConfiguration.legendAttributeDescription.attribute'),
          tLegendColorMap = tLegendAttribute && tLegendAttribute.get('categoryMap');
      if( iValue !== undefined) {
        this._strokeColor = iValue;
        if(tLegendColorMap)
            tLegendColorMap['stroke-color'] = iValue;
      }
      var tLegendStrokeColor = DG.ColorUtilities.getStrokeColorFromColorMap( tLegendColorMap),
          tResult = tLegendStrokeColor || this._strokeColor ||
              (tLegendAttribute ? DG.PlotUtilities.kDefaultStrokeColorWithLegend :
                  DG.PlotUtilities.kDefaultStrokeColor);
      return tResult;
    }.property(),

    strokeTransparency: function( iKey, iValue) {
      var tLegendAttribute = this.hasLegendVar() &&
            this.getPath('dataConfiguration.legendAttributeDescription.attribute'),
          tLegendColorMap = tLegendAttribute && tLegendAttribute.get('categoryMap');
      if( iValue !== undefined) {
        this._strokeTransparency = iValue;
        if(tLegendColorMap)
          tLegendColorMap['stroke-transparency'] = iValue;
      }
      var tLegendStrokeTransparency = tLegendColorMap ? tLegendColorMap['stroke-transparency'] : null,
          tResult;
      if (!SC.none(tLegendStrokeTransparency))
        tResult = tLegendStrokeTransparency;
      else if (!SC.none(this._strokeTransparency))
        tResult = this._strokeTransparency;
      else
        tResult = tLegendAttribute ? DG.PlotUtilities.kDefaultStrokeOpacityWithLegend :
            DG.PlotUtilities.kDefaultStrokeOpacity;
      return tResult;
    }.property(),

    /**
     * If true, then the stroke color/transparency will be the same as that used to fill the element
     * @property {Boolean}
     */
    strokeSameAsFill: false,

    hasLegendVar: function() {
      return !SC.none( this.getPath('dataConfiguration.legendAttributeDescription.attributeID'));
    },

    /**
     * Point size is computed at the view level and then multiplied by this number. Default is 1.
     * @property {Number} between 0 and 2
     */
    pointSizeMultiplier: 1,

    /**
     * Needed for MapPointLayer that relies on this accessor in call to PlotLayer::CalcPointRadius
     * @returns {Number}
     */
    getPointSizeMultiplier: function() {
      return this.get('pointSizeMultiplier');
    },

    /**
     * Point size is computed at the view level and then multiplied by this number. Default is 1.
     * @property {Number} between 0 and 2
     */
    transparency: DG.PlotUtilities.kDefaultPointOpacity,

    /**
     Prepare dependencies.
     */
    init: function() {
      arguments.callee.base.apply(this,arguments);

     },

    destroy: function() {
      if( this.get('dataContext'))
         this.get('dataContext').removeObserver('changeCount', this, 'handleDataContextNotification');
      arguments.callee.base.apply(this,arguments);
      // Special case in which we have to destroy a property _after_ rest of destroy has happened in order to
      // allow all observers of dataConfiguration to get removed.
      this.destroyProperty('dataConfiguration');
    },

    /**
     * This is called when the dataContext has changed. We prepare to accept a new dataContext and be
     * reconfigured with new axes, plots, and legends.
     */
    reset: function() {
      this.init();
    },

    /**
     * Subclasses will append if necessary.
     * These appear in the valuePane of the inspector
     * @property {[SC.Control]}
     */
    lastValueControls: function() {
      return [];
    }.property(),

   /**
     * Subclasses will append if necessary.
     * These appear in the configurationPane of the inspector
     * @property {[SC.Control]}
     */
    lastConfigurationControls: function() {
      return [];
    }.property(),

    /**
     * Default is true. Subclasses will override as desired.
     * @returns {boolean}
     */
    wantsInspector: function() {
      return true;
    },

    /**
      The data context for the graph. Set by caller after construction initially and
      reset for graphs restored from document to point to the restored data context.
      @property   {DG.DataContext}
     */
    dataContext: function( iKey, iValue) {
      var tContext = this.getPath('dataConfiguration.dataContext');
      if( iValue) {
        if( iValue !== tContext) {
          if( tContext){
            tContext.removeObserver('changeCount', this, 'handleDataContextNotification');
          }
          this.setPath('dataConfiguration.dataContext', iValue);
          iValue.addObserver('changeCount', this, 'handleDataContextNotification');
        }
        return this;
      }
      else if( tContext && !tContext.hasObserverFor('changeCount', this)) {
        tContext.addObserver('changeCount', this, 'handleDataContextNotification');
      }
      return this.getPath('dataConfiguration.dataContext');
    }.property(),  // Todo: Figure out if this can be cacheable

    _dataContextDidChange: function() {
      this.notifyPropertyChange('dataContext');
    }.observes('*dataConfiguration.dataContext'),
    
    /**
      Called when the 'dataContext' property is changed.
     */
    dataContextDidChange: function() {
      var tContext = this.get('dataConfiguration.dataContext');
      if( tContext && !tContext.hasObserverFor('changeCount'))
        tContext.addObserver('changeCount', this, 'handleDataContextNotification');
    }.observes('dataContext'),

    childmostCollectionTitle: function() {
      return this.getPath('dataConfiguration.childmostCollection.title');
    }.property(),

    /**
      Delete the currently selected cases.
      Passes the request on to the data context to do the heavy lifting.
     */
    deleteSelectedCases: function() {
      var tContext = this.get('dataContext'),
          tSelectedCases = this.get('selection'),
          tChange;
      if( tContext) {
        tChange = {
          operation: 'selectCases',
          select: false,
          cases: tSelectedCases
        };
        tContext.applyChange( tChange);
        tChange = {
          operation: 'deleteCases',
          cases: tSelectedCases
        };
        tContext.applyChange( tChange);
      }
    },

    /**
      Delete the currently unselected cases.
      Passes the request on to the data context to do the heavy lifting.
     */
    deleteUnselectedCases: function(){
      var tCases = this.getPath('dataConfiguration.cases');
      var tUnselected = DG.ArrayUtils.subtract( tCases, this.get('selection'),
                                                            function( iCase) {
                                                              return iCase.get('id');
                                                            });
      var tChange = {
            operation: 'deleteCases',
            cases: DG.copy(tUnselected)
          };
      this.get('dataContext').applyChange( tChange);
    },

    /**
      Select/deselect all of the points in all the plots.
      @param  {Boolean}   iSelect -- True to select all points, false to deselect all.
                                      Defaults to true (select all) if undefined/null.
     */
    selectAll: function( iSelect) {
      var tSelect = SC.none( iSelect) ? true : !!iSelect,
          tCases = tSelect ? this.get('cases') : null,  // null means all cases, even hidden ones
          tContext = this.get('dataContext'),
          tChange = {
            operation: 'selectCases',
            collection: this.get('collectionClient'),
            cases: tCases,
            select: tSelect
          };
      if (tContext) {
        tContext.applyChange( tChange);
      }
      DG.logUser( iSelect ? "selectAll" : "deselectAll");
    },

    /**
     * Utility function for use by subclasses.
     * @param iStorage
     * @param iCollLinkName
     * @param iAttrLinkName
     * @returns {*}
     */
    instantiateAttributeRefFromStorage: function( iStorage, iCollLinkName, iAttrLinkName) {
      var kNullResult = { collection: null, attributes: [] },
          tDataContext = this.getPath('dataConfiguration.dataContext');
      if( SC.empty( iCollLinkName) || SC.empty( iAttrLinkName) || !iStorage || !iStorage._links_)
        return kNullResult;

      var collLink = iStorage._links_[ iCollLinkName],
          coll = collLink && collLink.id && tDataContext.getCollectionByID( collLink.id),
          attrs = [],
          tLinkCount = DG.ArchiveUtils.getLinkCount( iStorage, iAttrLinkName ),
          tIndex;
      if( !coll)
        return kNullResult;

      for( tIndex = 0; tIndex < tLinkCount; tIndex++) {
        var tAttr = coll.getAttributeByID( DG.ArchiveUtils.getLinkID( iStorage, iAttrLinkName, tIndex));
        if( tAttr)
          attrs.push(tAttr);
      }
      return { collection: coll, attributes: attrs };
    },

    /**
     * Use the properties of the given object to restore my hidden cases.
     * Subclasses can override but should call sc_super.
     * @param iStorage {Object}
     */
    restoreStorage: function( iStorage) {
      // CODAP builds prior to 0289 stored hidden cases not as links, but as simple case IDs.
      // More recent builds store links, which we now convert on restore.
      var tHiddenCasesLinks = iStorage._links_ && iStorage._links_.hiddenCases;
      if( SC.isArray( tHiddenCasesLinks)) {
        var tLinkCount = DG.ArchiveUtils.getLinkCount( iStorage, 'hiddenCases'),
            tIndex;
        iStorage.hiddenCases = [];
        for( tIndex = 0; tIndex < tLinkCount; tIndex++) {
          iStorage.hiddenCases.push( DG.ArchiveUtils.getLinkID( iStorage, 'hiddenCases', tIndex));
        }
      }
      this.get('dataConfiguration').restoreHiddenCases( iStorage.hiddenCases);
      this.setPath('dataConfiguration.displayOnlySelected', iStorage.displayOnlySelected);

      if( !SC.none( iStorage.pointColor))
        this.set('pointColor', iStorage.pointColor);
      if( !SC.none( iStorage.strokeColor))
        this.set('strokeColor', iStorage.strokeColor);
      if( !SC.none( iStorage.pointSizeMultiplier))
        this.set('pointSizeMultiplier', iStorage.pointSizeMultiplier);
      if( !SC.none( iStorage.transparency))
        this.set('transparency', iStorage.transparency);
      if( !SC.none( iStorage.strokeTransparency))
        this.set('strokeTransparency', iStorage.strokeTransparency);
      if( !SC.none( iStorage.strokeSameAsFill))
        this.set('strokeSameAsFill', iStorage.strokeSameAsFill);
    },

    handleOneDataContextChange: function( iNotifier, iChange) {
      var tOperation = iChange && iChange.operation;

      switch( tOperation) {
        case 'deleteAttributes':
          iChange.attrs.forEach(function (iAttr) {
            iAttr = iAttr.attribute || iAttr; // We get here with two forms. Cover both.
            ['x', 'y', 'legend', 'y2', 'area'].forEach(function (iKey) {
              var tDescKey = iKey + 'AttributeDescription',
                  tAxisKey = iKey + 'Axis',
                  tAttrs = this.getPath('dataConfiguration.' + tDescKey + '.attributes');
              if(tAttrs) {
                tAttrs.forEach(function (iPlottedAttr, iIndex) {
                  if (iPlottedAttr === iAttr) {
                    if (iKey === 'legend')
                      this.removeLegendAttribute();
                    else
                      this.removeAttribute(tDescKey, tAxisKey, iIndex);
                  }
                }.bind(this));
              }
            }.bind(this));
          }.bind( this));
          break;
        case 'deleteCollection':
          this.dataContextOrCollectionWasDeleted(iChange.collection); // jshint ignore:line
          // fallthrough deliberate
        case 'updateAttributes':
          this.handleUpdateAttributes( iChange);
          break;
        case 'createCollection':
          this.notifyPropertyChange('caseOrder');
          break;
        case 'deleteDataContext':
          this.reset();
          this.dataContextOrCollectionWasDeleted();
          break;
        default:
          // Nothing to do
      }
      // Give the legend a chance
      var tLegend = this.get('legend');
      if( tLegend)
          tLegend.handleOneDataContextChange( iNotifier, iChange);
    },


    dataContextOrCollectionWasDeleted: function ( iCollection) {
      DG.log('dataContextWasDeleted');
      ['x', 'y', 'legend', 'y2', 'area'].forEach(function (iKey) {
        var tDescKey = iKey + 'AttributeDescription',
            tAxisKey = iKey + 'Axis',
            tCollectionClient = this.getPath('dataConfiguration.'
                + tDescKey + '.collectionClient'),
            tAttrs = this.getPath('dataConfiguration.' + tDescKey + '.attributes');
        if (tCollectionClient && tAttrs) {
          if (!iCollection || tCollectionClient === iCollection) {
            tAttrs.forEach(function (iPlottedAttr, iIndex) {
              if (iKey === 'legend')
                this.removeLegendAttribute();
              else
                this.removeAttribute(tDescKey, tAxisKey, iIndex);
            }.bind(this));
          }
        }
      }.bind(this));
      var tConfig = this.get('dataConfiguration');
      if(tConfig)
        tConfig.synchHiddenCases();
    },

    /**
     * Subclasses will override
     * @param iChange {Object}
     */
    handleUpdateAttributes: function( iChange) {
    },

    /**
      Returns an array of indices corresponding to the indices
      of the cases affected by the specified change.
     */
    buildIndices: function( iChange) {
      var srcCases = this.getPath('dataConfiguration.cases');
      if( (iChange.operation === 'updateCases') &&
          srcCases && !SC.none( iChange.cases) &&
          !this.getPath('dataConfiguration.hasAggregates')) {
        var updatedCasesByID = {},
            indices = SC.IndexSet.create();
        // Build a map of IDs for affected cases
        iChange.cases.forEach( function( iCase) {
                                updatedCasesByID[ iCase.get('id')] = iCase;
                               });
        // Loop through source cases to determine indices for the affected cases
        srcCases.forEach( function( iCase, iIndex) {
                            var caseID = iCase.get('id');
                            if( updatedCasesByID[ caseID])
                              indices.add( iIndex);
                          });
        return indices;
      }
      return SC.IndexSet.create( 0, this.getPath('dataConfiguration.cases.length'));
    },

    /**
      Responder for notifications from the DataContext.
     */
    handleDataContextNotification: function( iNotifier) {
      var newChanges = iNotifier.get('newChanges' ),
          tNumChanges = newChanges.length,
          i;
      for( i = 0; i < tNumChanges; i++) {
        this.handleOneDataContextChange( iNotifier, newChanges[ i]);
      }
    },

    getModelPointStyleAccessors: function() {
      var this_ = this;
      return {
        getPointColor: this_.getPointColor.bind(this_),
        getStrokeColor: function() {
          return this_.get('strokeSameAsFill') ?  this_.get('pointColor') : this_.get('strokeColor');
        },
        getPointSizeMultiplier: function() {
          return this_.get('pointSizeMultiplier');
        },
        getTransparency: function() {
          return this_.get('transparency');
        },
        getStrokeTransparency: function() {
          return this_.get('strokeSameAsFill') ?  this_.get('transparency') : this_.get('strokeTransparency');
        },
        getStrokeSameAsFill: function() {
          return this_.get('strokeSameAsFill');
        }
      };
    },

    /** create a menu item that removes the attribute on the given axis/legend */
    createRemoveAttributeMenuItem: function( iAxisOrLegendView, iXYorLegend, isForSubmenu, iAttrIndex ) {
      iAttrIndex = iAttrIndex || 0;
      var tDescKey = iXYorLegend + 'AttributeDescription',
          tAxisKey = iXYorLegend + 'Axis', // not used by removeLegendAttribute()
          tAttributes = this.getPath( 'dataConfiguration.' + tDescKey + '.attributes'),
          tAttribute = (SC.isArray( tAttributes) && iAttrIndex < tAttributes.length) ?
              tAttributes[ iAttrIndex] : DG.Analysis.kNullAttribute,
          tName = (tAttribute === DG.Analysis.kNullAttribute) ? '' : tAttribute.get( 'name'),
          tResourceName = isForSubmenu ? 'attribute_' : 'removeAttribute_',
          tTitle = ('DG.DataDisplayMenu.' + tResourceName + iXYorLegend).loc( tName ),
          tAction;
      switch( iXYorLegend) {
        case 'x':
        case 'y':
        case 'y2':
          tAction = this.removeAttribute;
          break;
        case 'legend':
          tAction = this.removeLegendAttribute;
          break;
        case 'top':
        case 'right':
          tAction = this.removeSplitAttribute;
          break;
      }
      return {
        title: tTitle,
        target: this,
        itemAction: tAction,
        isEnabled: (tAttribute !== DG.Analysis.kNullAttribute),
        log: "attributeRemoved: { attribute: %@, axis: %@ }".fmt(tName, iXYorLegend),
        args: [ tDescKey, tAxisKey, iAttrIndex ] };
    },

    /** create a menu item that changes the attribute type on the given axis/legend */
    createChangeAttributeTypeMenuItem: function( iAxisView, iXYorLegend ) {
      var tDescKey = iXYorLegend + 'AttributeDescription',
          tAxisKey = iXYorLegend + 'Axis',
          tDescription = this.getPath( 'dataConfiguration.' + tDescKey),
          tAttribute = tDescription && tDescription.get( 'attribute'),
          tAttributeName = tAttribute && (tAttribute !== -1) ? tAttribute.get('name') : '',
          tIsNumeric = tDescription && tDescription.get( 'isNumeric'),
          tTitle =( tIsNumeric ? 'DG.DataDisplayMenu.treatAsCategorical' : 'DG.DataDisplayMenu.treatAsNumeric').loc();
      return {
        title: tTitle,
        target: this,
        itemAction: this.changeAttributeType, // call with args, toggling 'numeric' setting
        isEnabled: (tAttribute !== DG.Analysis.kNullAttribute),
        log: "plotAxisAttributeChangeType: { axis: %@, attribute: %@, numeric: %@ }".fmt( tAxisKey, tAttributeName, !tIsNumeric),
        args: [ tDescKey, tAxisKey, !tIsNumeric ] };
    },

    /** Submenu items for hiding selected or unselected cases, or showing all cases */
    createHideShowSelectionMenuItems: function() {
      var tSelection = this.getPath('dataConfiguration.selection' ).toArray(),
          tSomethingIsSelected = tSelection && tSelection.get('length') !== 0,
          tCases = this.getPath('dataConfiguration.cases' ),
          tSomethingIsUnselected = tSelection && tCases && (tSelection.get('length') < tCases.get('length')),
          tSomethingHidden = this.getPath('dataConfiguration.hiddenCases' ).length > 0,
          tHideSelectedNumber = (tSelection && tSelection.length > 1) ? 'Plural' : 'Sing',
          tHideUnselectedNumber = (tSelection && tCases &&
              (tCases.get('length') - tSelection.length > 1)) ? 'Plural' : 'Sing',
          tDisplayingOnlySelected = this.getPath('dataConfiguration.displayOnlySelected'),
          self = this;

      function hideSelectedCases() {
        DG.UndoHistory.execute(DG.Command.create({
          name: 'graph.display.hideSelectedCases',
          undoString: 'DG.Undo.hideSelectedCases',
          redoString: 'DG.Redo.hideSelectedCases',
          log: "Hide %@ selected cases".fmt(tSelection.length),
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'hideSelected',
              type: '',
              numberHidden: tSelection.length
            }
          },
          execute: function() {
            this._undoData = tSelection;
            self.get('dataConfiguration' ).hideCases( tSelection );
          },
          undo: function() {
            self.get('dataConfiguration' ).showCases( this._undoData );
          },
          redo: function() {
            self.get('dataConfiguration' ).hideCases( this._undoData );
          }
        }));
      }

      function hideUnselectedCases() {
        var tUnselected = DG.ArrayUtils.subtract( tCases, tSelection,
            function( iCase) {
              return iCase.get('id');
            });
        DG.UndoHistory.execute(DG.Command.create({
          name: 'graph.display.hideUnselectedCases',
          undoString: 'DG.Undo.hideUnselectedCases',
          redoString: 'DG.Redo.hideUnselectedCases',
          log: "Hide unselected cases",
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'hideUnselected',
              type: '',
              numberHidden: tUnselected.length
            }
          },
          execute: function() {
            this._undoData = tUnselected;

            this.log = "Hide %@ unselected cases".fmt(tUnselected.length);
            self.get('dataConfiguration' ).hideCases( tUnselected );
          },
          undo: function() {
            self.get('dataConfiguration' ).showCases( this._undoData );
          },
          redo: function() {
            self.get('dataConfiguration' ).hideCases( this._undoData );
          }
        }));
      }

      function showAllCases() {
        DG.UndoHistory.execute(DG.Command.create({
          name: 'graph.display.showAllCases',
          undoString: 'DG.Undo.showAllCases',
          redoString: 'DG.Redo.showAllCases',
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'showAllCases',
              type: ''
            }
          },
          log: "Show all cases",
          execute: function() {
            self.setPath('dataConfiguration.displayOnlySelected', false );
            this._undoData = self.getPath('dataConfiguration.hiddenCases');
            self.get('dataConfiguration' ).showAllCases();
          },
          undo: function() {
            self.get('dataConfiguration' ).hideCases( this._undoData );
          }
        }));
      }

      function displayOnlySelected() {
        DG.UndoHistory.execute(DG.Command.create({
          name: 'graph.display.displayOnlySelected',
          undoString: 'DG.Undo.displayOnlySelected',
          redoString: 'DG.Redo.displayOnlySelected',
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'displayOnlySelected',
              type: ''
            }
          },
          log: "Display only selected cases",
          execute: function() {
            self.setPath('dataConfiguration.displayOnlySelected', true );
          },
        }));
      }

      return [
        // Note that these 'built' string keys will have to be specially handled by any
        // minifier we use
        { title: ('DG.DataDisplayMenu.hideSelected' + tHideSelectedNumber), isEnabled: tSomethingIsSelected,
          target: this, action: hideSelectedCases },
        { title: ('DG.DataDisplayMenu.hideUnselected' + tHideUnselectedNumber), isEnabled: tSomethingIsUnselected,
          target: this, action: hideUnselectedCases },
        { title: 'DG.DataDisplayMenu.showAll', isEnabled: tSomethingHidden || tDisplayingOnlySelected,
          target: this, action: showAllCases },
        { title: 'DG.DataDisplayMenu.displayOnlySelected', isEnabled: !tDisplayingOnlySelected,
          target: this, action: displayOnlySelected }
      ];
    },

    /**
     * Removing the attribute is just changing with null arguments
     */
    removeLegendAttribute: function() {
      this.changeAttributeForLegend( null, null);
    },

    /**
     * Subclasses will override
     */
    removeSplitAttribute: function() {
    },

    /**
     * Change the attribute type (EAttributeType) on the axis described by the given key,
     * to treat a Numeric attribute as Categorical.
     * @param{String} iDescKey - key to the desired attribute description (x...|y...|legendAttributeDescription)
     * @param{String} iAxisKey - key to the axis whose attribute is to be removed (x...|yAxis)
     * @param{Boolean} true if we want to treat the attribute as numeric (else categorical).
     */
    changeAttributeType: function( iDescKey, iAxisKey, iTreatAsNumeric ) {
      var tDataConfiguration = this.get('dataConfiguration');

      // We're handling a case specific to graphs here for convenience
      if( !iTreatAsNumeric && this.getY2Plot && this.getY2Plot()) {
        this.removeAttribute('y2AttributeDescription', 'y2Axis', 0);
      }

      this.set('aboutToChangeConfiguration', true ); // signals dependents to prepare

      tDataConfiguration.setAttributeType( iDescKey, iTreatAsNumeric );

      this.invalidate( null, true /* also invalidate plot caches */);
      this.set('aboutToChangeConfiguration', false ); // reset for next time
    },

    /**
     Sets the attribute for the legend.
     @param  {DG.DataContext}      iDataContext -- The data context for this graph
     @param  {Object}              iAttrRefs -- The attribute to set for the axis
     {DG.CollectionClient} iAttrRefs.collection -- The collection that contains the attribute
     {DG.Attribute}        iAttrRefs.attribute -- Array of attributes to set for the legend
     */
    changeAttributeForLegend: function( iDataContext, iAttrRefs) {

      function newAttributeCollectionIsDescendant() {

        function isDescendantOf(iColl1, iColl2) {
          // Is iColl1 a descendant of iColl2
          var tChildren = iColl2 && iColl2.get('children'),
              found = false;
          while (!found && tChildren) {
            var tChild = tChildren.length >= 0 && tChildren[0];
            if (tChild === iColl1)
              found = true;
            else tChildren = tChild && tChild.get('children');
          }
          return found;
        }

        if( !iAttrRefs)
          return false; // Since we didn't get an attribute, its collection is not a descendant

        // iAttrRefs.collection is actually a CollectionClient
        var tNewCollection = iAttrRefs.collection.get('collection'),
            tXCollection = dataConfiguration.getPath('xAttributeDescription.collectionClient.collection'),
            tYCollection = dataConfiguration.getPath('yAttributeDescription.collectionClient.collection'),
            tPolygonCollection = dataConfiguration.getPath('polygonAttributeDescription.collectionClient.collection'),
            tChildMost;
        if(tPolygonCollection)
          tChildMost = tPolygonCollection;
        else if( tXCollection && tYCollection){
          tChildMost = isDescendantOf(tXCollection, tYCollection) ? tXCollection : tYCollection;
        }
        else {
          tChildMost = tXCollection || tYCollection;
        }
        return isDescendantOf(tNewCollection, tChildMost);
      }

      var dataConfiguration = this.get('dataConfiguration');

      if( newAttributeCollectionIsDescendant())
        return; // Because legend attribute has to be at same level as or higher than existing data attributes

      this.set('aboutToChangeConfiguration', true ); // signals dependents to prepare

      if( iDataContext)
        dataConfiguration.set('dataContext', iDataContext);
      dataConfiguration.setAttributeAndCollectionClient('legendAttributeDescription', iAttrRefs);
      // This is a hack to force the legend to recompute legendQuantiles if necessary
      dataConfiguration.recomputeLegendQuantilesIfLocked();
      this.invalidate();
      this.set('aboutToChangeConfiguration', false ); // reset for next time
    },

    /**
     @private
     */
    dataRangeDidChange: function( iSource, iKey, iObject, iIndices) {
      this.invalidate();
    },

    /**
     *
     * @param iChange
     * @param iInvalidateDisplayCaches {Boolean}
     */
    invalidate: function( iChange, iInvalidateDisplayCaches) {
      this.get( 'dataConfiguration' ).invalidateCaches( null, iChange);
    }

  } );


/* >>>>>>>>>> BEGIN source/components/graph/graph_model.js */
// ==========================================================================
//                            DG.GraphModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph_map_common/data_layer_model');

/** @class  DG.GraphModel - The model for a graph.

 @extends DG.DataLayerModel
 */
DG.GraphModel = DG.DataLayerModel.extend(
  /** @scope DG.GraphModel.prototype */
  {
    autoDestroyProperties: [ 'plot', 'xAxis', 'yAxis', 'y2Axis' ],

    dataConfigurationClass: function() {
      return DG.GraphDataConfiguration;
    }.property(),

    isTransparent: false, // part of model state that determines whether plot views are transparent
    plotBackgroundColor: null, // part of model state that specifies color of plot background. Default is white
    plotBackgroundOpacity: 1, // part of model state that specifies opacity of plot background. Default is 1
    plotBackgroundImage: null,  // to be displayed by the view as part of the background
    plotBackgroundImageLockInfo: null,  // null if image not locked to axes

    /**
     * @property {DG.NumberToggleModel}
     */
    numberToggle: null,

    /**
     * @property {Boolean}
     */
    enableMeasuresForSelection: null,

    /**
     @property { DG.AxisModel }
     */
    xAxis: function( iKey, iValue) {
      if( iValue) {
        this.get('axisCoordinator').setAxis('x', 0, iValue);
      }
      return this.get('xAxisArray')[0];
    }.property(),

    /**
     @property { DG.AxisModel }
     */
    yAxis: function( iKey, iValue) {
      if( iValue) {
        this.get('axisCoordinator').setAxis('y', 0, iValue);
      }
      return this.get('yAxisArray')[0];
    }.property(),

    /**
     * This second axis is only instantiated when the user has indicated a desire to plot an attribute on an axis
     * to the right of the plot.
     * @property { DG.AxisModel }
     */
    y2Axis: function( iKey, iValue) {
      if( iValue) {
        this.get('axisCoordinator').setAxis('y2', 0, iValue);
      }
      return this.get('y2AxisArray')[0];
    }.property(),

    /**
     * For numeric axes in each dimension, receives notification of bounds change and synchs the other
     * axes' bounds with the bounds belonging to the notifying axis.
     * @property {DG.AxisCoordinator}
     */
    axisCoordinator: null,

    /*
     * With the possibility of splitting plots, we have arrays of each of the axes
     */
    xAxisArray: function() {
      return this.getPath('axisCoordinator.xAxisArray');
    }.property('axisCoordinator.xAxisArray'),
    yAxisArray: function() {
      return this.getPath('axisCoordinator.yAxisArray');
    }.property('axisCoordinator.yAxisArray'),
    y2AxisArray: function() {
      return this.getPath('axisCoordinator.y2AxisArray');
    }.property('axisCoordinator.y2AxisArray'),

    // When plots are split, we have top and right axis
    topAxis: null,
    rightAxis: null,

    /**
     * This function will be passed to sibling plots so they can propagate changes to their siblings.
     * @returns {*}
     */
    getRootPlot: function() {
      return this.get('plot');
    },

    /**
     * Returns the first plot in _plots, if any. When used to set,
     * wipes out the current array and replaces it with a new array
     * containing just iValue
     * TODO: This function property may not be used any more. If so, get rid of it.
     *
     * @param iKey
     * @param iPlot
     * @return {DG.Plot}
     */
    plot: function( iKey, iPlot) {
      if( !SC.none( iPlot)) {
        this._plots.forEach( function( iPlot) {
          iPlot.removeObserver('connectingLine', this, this.connectingLineChanged);
          iPlot.removeObserver('canSupportConfigurations', this, this.canSupportConfigurationsChanged);
          this.removePlotObserver( iPlot);
          iPlot.destroy();
        }.bind( this));
        this._plots[0] = iPlot;
        this._plots.length = 1;
        // TODO: Figure out a more elegant way to observe this property
        iPlot.addObserver('connectingLine', this, this.connectingLineChanged);
        iPlot.addObserver('canSupportConfigurations', this, this.canSupportConfigurationsChanged);
        iPlot.set('enableMeasuresForSelection', this.get('enableMeasuresForSelection'));
      }
      return (this._plots.length < 1) ? null : this._plots[0];
    }.property(),

    _plots: null,

    plots: function() {
      return this._plots;
    }.property(),

    allPlots: function() {
      var tResult = [];
      this._plots.forEach( function( iPlot) {
        tResult = tResult.concat( [iPlot].concat( iPlot.get('siblingPlots')));
      });
      return tResult;
    }.property(),

    lastPlot: function() {
      var tNumPlots = this._plots.length;
      return ( tNumPlots > 0) ? this._plots[ tNumPlots - 1] : null;
    }.property(),

    /**
     * Return the plot at the given index, null if out of bounds
     * @param iIndex
     * @return {DG.Plot}
     */
    getPlotAtIndex: function( iIndex) {
      if( iIndex < this._plots.length) {
        return this._plots[ iIndex];
      }
      return null;
    },

    /**
     * If not already present, adds the given plot to my array.
     * @param iPlot
     */
    addPlot: function( iPlot) {
      if( !this._plots.contains( iPlot)) {
        var tFirstPlot = this.get('plot');
        // TODO: Clumsy way to transfer setting for connectingLine. Fix it!
        if( tFirstPlot.isAdornmentVisible('connectingLine'))
          iPlot.setAdornmentVisibility('connectingLine', true);
        if( iPlot.get('verticalAxisIsY2')) {
          this._plots.push( iPlot);
        }
        else {
          var tYAttrIndex = iPlot.get('yAttributeIndex');
          this._plots.splice(tYAttrIndex, 0, iPlot);
        }
        iPlot.set('enableMeasuresForSelection', this.get('enableMeasuresForSelection'));
      }
    },

    removePlot: function( iPlot) {
      var tIndex = this._plots.indexOf( iPlot);
      if( tIndex >= 0)
        this.removePlotAtIndex( tIndex);
    },

    /**
     * In addition to removing the plot, synchronize the remaining plots' yAttributeIndex
     * @param iPlotIndex {Number}
     */
    removePlotAtIndex: function( iPlotIndex) {
      var tPlot = this._plots[ iPlotIndex];
      if( tPlot) {
        this._plots.splice(iPlotIndex, 1);
        this.removePlotObserver(tPlot);
        tPlot.destroy();
        var tActualYIndex = 0;
        this._plots.forEach(function (iPlot, iIndex) {
          // Only plots for attributes on regular y-axis need their yAttributeIndex updated
          if (!iPlot.get('verticalAxisIsY2')) {
            iPlot.setIfChanged('yAttributeIndex', tActualYIndex);
            tActualYIndex++;
          }
        });
      }
    },

    /**
     * This is a 3-dim array of PlotModels. The innermost dimension allows for multiple overlaid scatterplots.
     * [row][column][overlay]
     * @property {[[DG.PlotModel]]}
     */
    splitPlotArray: null,

    /**
     * @property {Boolean}
     */
    isSplit: function() {
      return this.getPath('dataConfiguration.hasSplitAttribute');
    }.property(),
    isSplitDidChange: function() {
      this.propertyDidChange('isSplit');
    }.observes('dataConfiguration.hasSplitAttribute'),

    numSplitRows: function() {
      return this.getPath('dataConfiguration.rightAttributeDescription.attributeStats.numberOfCells') || 1;
    }.property(),

    numSplitColumns: function() {
      return this.getPath('dataConfiguration.topAttributeDescription.attributeStats.numberOfCells') || 1;
    }.property(),

    /**
     Observers can use this property to know when to get ready for a change; e.g. to set up a cache of current
     point positions for an animation.
     @property {Boolean}
     */
    aboutToChangeConfiguration: false,
    /**
     * Whenever we're done changing configuration, make sure the plot background image lock state
     * is consistent with axis configuration. We can only lock background image if both axes are numeric.
     */
    setProperBackgroundLockInfo: function() {
      if( !this.get('aboutToChangeConfiguration')) {
        if(!this.bothAxesAreNumeric())
          this.set('plotBackgroundImageLockInfo', null);
      }
    }.observes('aboutToChangeConfiguration'),

    /**
     Keep plot axis in synch
     */
    xAxisChanged: function() {
      var tPlot = this.get( 'plot' );
      if( !SC.none( tPlot ) )
        tPlot.set( 'xAxis', this.get( 'xAxis' ) );
    }.observes( 'xAxis' ),

    /**
     Keep plot axis in synch
     */
    yAxisChanged: function() {
      var tPlot = this.get( 'plot' );
      if( !SC.none( tPlot ) )
        tPlot.set( 'yAxis', this.get( 'yAxis' ) );
    }.observes( 'yAxis' ),

    /**
     Keep plot axis in synch
     */
    y2AxisChanged: function() {
      var tPlot = this.get( 'plot' );
      if( !SC.none( tPlot ) )
        tPlot.set( 'y2Axis', this.get( 'y2Axis' ) );
    }.observes( 'y2Axis' ),

    /**
     * The menu item applies to the zeroth plot. We pass this command along to any other
     * plots as well.
     */
    connectingLineChanged: function() {
      var tPlots = this.get('plots' ),
          tVisible = (tPlots.length > 0) ? tPlots[0].getAdornmentModel('connectingLine' ).get('isVisible') : false;
      this.get('plots' ).forEach( function( iPlot, iIndex) {
        if( iIndex > 0)
          iPlot.setAdornmentVisibility( 'connectingLine', tVisible);
      });
    },

    /**
     Prepare dependencies.
     */
    init: function() {
      arguments.callee.base.apply(this,arguments);

      function getAxisClassFromType( iType) {
        if( iType === DG.Analysis.EAttributeType.eNumeric || iType === DG.Analysis.EAttributeType.eDateTime)
          return DG.CellLinearAxisModel;
        else if( iType === DG.Analysis.EAttributeType.eCategorical)
          return DG.CellAxisModel;
        else
          return DG.AxisModel;
      }

      var configureAttributeDescription = function (iKey, iDataContext) {
            var tAttributeName = this.get(iKey + 'AttributeName'),
                tAttribute,
                tDefaults = iDataContext?iDataContext.collectionDefaults():DG.currDocumentController().collectionDefaults(),
                tCollectionClient = tDefaults.collectionClient;
            if (tAttributeName) {
              delete this[iKey + 'AttributeName'];  // Because that was how it was passed in
              tAttribute = iDataContext ? iDataContext.getAttributeByName(tAttributeName) :
                  (tCollectionClient ? tCollectionClient.getAttributeByName(tAttributeName) : null);
              if (tAttribute) {
                if (iDataContext && !tCollectionClient)
                  tCollectionClient = iDataContext.getCollectionForAttribute(tAttribute);
                this.get('dataConfiguration').setAttributeAndCollectionClient(iKey + 'AttributeDescription',
                    {collection: tCollectionClient, attributes: [tAttribute]});
              }
            }
          }.bind(this),
          configureSplitAxis = function (iPrefix) {
            // The top and right axes are always DG.CellAxis, so we might as well create them here
            // Note that if they already exist, we need to leave them in place or they get disconnected
            // from their axis views. This happens during reset when we change contexts
            var tAxis = this.get(iPrefix + 'Axis'),
                tDescription = tConfiguration.get(iPrefix + 'AttributeDescription');
            if( !tAxis) {
              tAxis = DG.CellAxisModel.create();
              this.set(iPrefix + 'Axis', tAxis);
            }
            tAxis.set('dataConfiguration', tConfiguration);
            tAxis.set('attributeDescription', tDescription);
          }.bind( this);

      function getExtraYAttributes (model) {
        var yAttrName =  model.get('yAttributeName');
        if (Array.isArray(yAttrName)) {
          model.set('yAttributeName', yAttrName[0]);
          return yAttrName.slice(1);
        } else {
          return [];
        }
      }

      // Beginning of init
      // Set up data configuration
      var tConfiguration = this.get('dataConfigurationClass').create(),
          tContext = tConfiguration.get('dataContext');
      // If the context has been discovered in the init of the configuration, we take this opportunity
      // to hook up our observer to it.
      if( tContext) {
        tContext.addObserver('changeCount', this, 'handleDataContextNotification');
      }
      this.set( 'dataConfiguration', tConfiguration);

      var tLegendDescription = tConfiguration.get('legendAttributeDescription');

      this.set('legend', DG.LegendModel.create( { dataConfiguration: tConfiguration }));
      this.setPath('legend.attributeDescription', tLegendDescription);

      var tDataContext = this.initialDataContext;
      var extraYAttributes = getExtraYAttributes(this);
      if( tDataContext) {
        this.setPath('dataConfiguration.initialDataContext');
        this.setPath('dataConfiguration.dataContext', tDataContext);
        delete this.initialDataContext;  // It was passed in this way, but it's not one of our legitimate properties
      }

      this._plots = [];
      this.splitPlotArray = [[this._plots]];

      this.axisCoordinator = DG.AxisCoordinator.create();

      ['x', 'y', 'y2', 'legend', 'right', 'top'].forEach(function (iKey) {
        configureAttributeDescription(iKey, tDataContext);
        if( ['x', 'y', 'y2'].indexOf( iKey) >= 0) {
          var tDescription = this.getPath(
              'dataConfiguration.' + (iKey + 'AttributeDescription')),
              tAxisClass = getAxisClassFromType(tDescription.get('attributeType')),
              tAxis = tAxisClass.create(
                  {dataConfiguration: this.dataConfiguration});
          this.set(iKey + 'Axis', tAxis);
          this.passGetPointColorToAxis(iKey, tAxis);
          this.setPath(iKey + 'Axis.attributeDescription', tDescription);
        }
      }.bind(this));

      this.synchPlotWithAttributes();

      // Set additional Y Attributes, if present
      extraYAttributes.forEach(function (iAttrName) {
        if (!tDataContext) {
          DG.log('Cannot place y attribute: no Data Context: ' + iAttrName);
          return;
        }
        var attr = tDataContext.getAttributeByName(iAttrName);
        if (!attr) {
          DG.log('Cannot place y attribute: not found: ' + iAttrName);
          return;
        }
        var attrRef = {
          collection: tDataContext.getCollectionForAttribute(attr),
          attributes: [attr]
        };
        this.addAttributeToAxis(tDataContext, attrRef);
      }.bind(this));

      // Set Y2 Attribute if present
      var tY2AttributeDescription = this.getPath('dataConfiguration.y2AttributeDescription');
      if (tY2AttributeDescription && tY2AttributeDescription.get('attributes').length && tDataContext) {
        this.changeAttributeForY2Axis(tDataContext, {
          collection: tY2AttributeDescription.get('collectionClient'),
          attributes: tY2AttributeDescription.get('attributes')
        });
      }

      configureSplitAxis( 'top');
      configureSplitAxis( 'right');

      var showNumberToggle = DG.get('IS_INQUIRY_SPACE_BUILD') || this.get('enableNumberToggle'),
          numberToggle = this.get('numberToggle'),
          numberToggleLastMode = this.get('numberToggleLastMode'),
          dataConfiguration = this.get('dataConfiguration');
      if (!numberToggle) {
        numberToggle = DG.NumberToggleModel.create({ dataConfiguration: dataConfiguration,
                                                      isEnabled: showNumberToggle });
        if (numberToggle && numberToggleLastMode) {
          numberToggle.set('lastMode', numberToggleLastMode);
        }
        this.set('numberToggle', numberToggle);
      }
      else {
        numberToggle.set('dataConfiguration', dataConfiguration);
      }
      this.set('enableNumberToggle', showNumberToggle);

      // We might already have some data, so let's adapt to it. But it would seem that we can't
      // possibly have data, so it's a mystery why we have to call rescaleAxesFromData
      // TODO: Understand this better
      this.invalidate();
      this.rescaleAxesFromData( true /* allow scale shrinkage */,
                                true /* animate points */ );

      this.addObserver('dataConfiguration.hiddenCasesWillChange', this.displayedCasesWillChange);
      this.addObserver('dataConfiguration.hiddenCases', this.displayedCasesDidChange);
      this.addObserver('dataConfiguration.displayOnlySelected', this.displayedCasesDidChange);
    },

    destroy: function() {
      this.removeObserver('dataConfiguration.hiddenCasesWillChange', this.displayedCasesWillChange);
      this.removeObserver('dataConfiguration.hiddenCases', this.displayedCasesDidChange);
      this.removeObserver('dataConfiguration.displayOnlySelected', this.displayedCasesDidChange);
      this.axisCoordinator.destroy();

      arguments.callee.base.apply(this,arguments);
    },

    enableNumberToggleDidChange: function() {
      this.setPath('numberToggle.isEnabled', this.get('enableNumberToggle'));
    }.observes('enableNumberToggle'),

    numberToggleLastModeDidChange: function() {
      this.setPath('numberToggle.lastMode', this.get('numberToggleLastMode'));
    }.observes('numberToggleLastMode'),

    enableMeasuresForSelectionDidChange: function() {
      var tEnabled = this.get('enableMeasuresForSelection');
      this.get('allPlots').forEach( function( iPlot) {
        iPlot.set('enableMeasuresForSelection', tEnabled);
      });
    }.observes('enableMeasuresForSelection'),

    /** Submenu items for hiding selected or unselected cases, or showing all cases */
    createHideShowSelectionMenuItems: function() {

      var menuItems = arguments.callee.base.apply(this,arguments),

          isNumberToggleEnabled = this.get('enableNumberToggle'),
          enableNumberToggleItemText = isNumberToggleEnabled
                                        ? 'DG.DataDisplayMenu.disableNumberToggle'
                                        : 'DG.DataDisplayMenu.enableNumberToggle',
          isMeasuresForSelectionEnabled = this.get('enableMeasuresForSelection'),
          enableMeasuresForSelectionItemText = isMeasuresForSelectionEnabled
                                        ? 'DG.DataDisplayMenu.disableMeasuresForSelection'
                                        : 'DG.DataDisplayMenu.enableMeasuresForSelection',
          self = this;

      function toggleCapability( iCapability) {
        var isEnabled = self.get('enable' + iCapability);
        DG.UndoHistory.execute(DG.Command.create({
          name: isEnabled ? 'graph.display.disable' + iCapability : 'graph.display.enable' + iCapability,
          undoString: isEnabled ? 'DG.Undo.disable' + iCapability : 'DG.Undo.enable' + iCapability,
          redoString: isEnabled ? 'DG.Redo.disable' + iCapability : 'DG.Redo.enable' + iCapability,
          log: isEnabled ? "Disable" + iCapability : "Enable" + iCapability,
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'toggle ' + iCapability,
              type: 'DG.GraphView'
            }
          },
          execute: function() {
            this._undoData = !!self.get('enable' + iCapability);
            self.set('enable' + iCapability, !isEnabled);
          },
          undo: function() {
            self.set('enable' + iCapability, this._undoData);
          }
        }));
      }

      function toggleNumberToggle() {
        toggleCapability('NumberToggle');
      }

      function toggleMeasuresForSelection() {
        toggleCapability('MeasuresForSelection');
      }

      menuItems.push({ title: enableNumberToggleItemText, isEnabled: true,
                        target: this, action: toggleNumberToggle });
      menuItems.push({ title: enableMeasuresForSelectionItemText, isEnabled: true,
                        target: this, action: toggleMeasuresForSelection });
      return menuItems;
    },

    /**
      Gets the attribute for the specified axis.
      @param  {String}              iOrientation -- identifies the axis ('horizontal' or 'vertical')
     */
    getAttributeForAxis: function(iOrientation) {
      var tDescKey;
      switch( iOrientation) {
        case DG.GraphTypes.EOrientation.kHorizontal:
          tDescKey = 'xAttributeDescription';
          break;
        case DG.GraphTypes.EOrientation.kVertical:
          tDescKey = 'yAttributeDescription';
          break;
        case DG.GraphTypes.EOrientation.kVertical2:
          tDescKey = 'y2AttributeDescription';
          break;
      }

      return this.getPath('dataConfiguration.' + tDescKey + '.attribute');
    },

    /**
      Sets the attribute for the specified axis.
     Note that prior to the "split at top or right" feature we only had to worry about the "zeroth" plot.
     But with splitting, we have to take into account that all the plots may need to be swapped out for new
     ones. We accomplish that by detecting that the new attribute is not of the same nominal/numeric type and,
     if so, wiping out all the sibling plots so we can start over.
      @param  {DG.DataContext}      iDataContext -- The data context for this graph
      @param  {Object}              iAttrRefs --
              {DG.CollectionClient} iAttrRefs.collection -- The collection that contains the attribute
              {DG.Attribute}        iAttrRefs.attributes -- The array of attributes to set for the axis
      @param  {String}              iOrientation -- identifies the axis ('horizontal' or 'vertical')
     */
    changeAttributeForAxis: function( iDataContext, iAttrRefs, iOrientation) {
      var this_ = this,
          tTargetDescKey, tTargetAxisKey, tOtherDim,
          tIsXorYChange = false,
          tIsSplit = this.get('isSplit');

      function switchAxes() {

        function synchAxis( iDescKey, iAxisKey, iAxisClass, iScaleType) {
          var tCurrentAxisClass = this_.get( iAxisKey).constructor,
              tAxisModelParams = { dataConfiguration: tDataConfiguration };

          // If the variable and axis are incompatible, we'll have to change the axis
          if( iAxisClass !== tCurrentAxisClass ) {
            var tAxisToDestroy = this_.get( iAxisKey ),
                tNewAxis = iAxisClass.create(tAxisModelParams);
            tNewAxis.set( 'attributeDescription', tDataConfiguration.get( iDescKey ) );
            tNewAxis.setLinkToPlotIfDesired( this_.get('plot'));
            tNewAxis.set('scaleType', iScaleType);
            this_.passGetPointColorToAxis(iAxisKey, tNewAxis);
            this_.set( iAxisKey, tNewAxis );
            tAxisToDestroy.destroy();
            this_.setPath('plot.' + iAxisKey, tNewAxis);
          }
        }

        // We want to reconfigure the graph without triggering any of the responses to the
        // changes until we're done. Note that while the axes may change, the plot type should not.
        var tSourceDescKey = tOtherDim + 'AttributeDescription',
            tTargetRole = tDataConfiguration.getPath( tSourceDescKey + '.role'),
            tTargetType = tDataConfiguration.getPath( tSourceDescKey + '.attributeStats.attributeType'),
            tSourceRole = tDataConfiguration.getPath( tTargetDescKey + '.role'),
            tSourceType = tDataConfiguration.getPath( tTargetDescKey + '.attributeStats.attributeType'),
            tSourceAxisKey = tOtherDim + 'Axis',
            tTargetAxisClass = this_.get( tSourceAxisKey).constructor,
            tTargetAxisScaleType = this_.getPath( tSourceAxisKey + '.scaleType'),
            tSourceAxisClass = this_.get( tTargetAxisKey).constructor,
            tSourceAxisScaleType = this_.getPath( tTargetAxisKey + '.scaleType'),
            tAttrsForSource = SC.none(tCurrentAttribute) ? [] : [tCurrentAttribute],
            tCollClientForSource = tDataConfiguration.getPath(tSourceDescKey + '.collectionClient'),
            tAttrRefsForSource = {
              attributes: tAttrsForSource,
              collection: tCollClientForSource
            };
        tDataConfiguration.setAttributeAndCollectionClient(tTargetDescKey, iAttrRefs,
            tTargetRole, tTargetType);
        tDataConfiguration.setAttributeAndCollectionClient(tSourceDescKey, tAttrRefsForSource,
            tSourceRole, tSourceType);
        this_.beginPropertyChanges();
        synchAxis(tTargetDescKey, tTargetAxisKey, tTargetAxisClass, tTargetAxisScaleType);
        synchAxis(tSourceDescKey, tSourceAxisKey, tSourceAxisClass, tSourceAxisScaleType);
        this_.endPropertyChanges();
        this_.invalidate();
        this_.rescaleAxesFromData(true, true);
      }

      function removeAllButZerothAttribute() {
        var tNumAttributes = tDataConfiguration.getPath(tTargetDescKey + '.attributes').length;
        while( tNumAttributes > 1) {
          this_.removeAttribute(tTargetDescKey, tTargetAxisKey, --tNumAttributes);
        }
      }

      if( tIsSplit) {
        this.removeAllSplitPlotsAndAxes();
      }
      switch (iOrientation) {
        case DG.GraphTypes.EOrientation.kHorizontal:
          tTargetDescKey = 'xAttributeDescription';
          tTargetAxisKey = 'xAxis';
          tOtherDim = 'y';
          tIsXorYChange = true;
          break;
        case DG.GraphTypes.EOrientation.kVertical:
          tTargetDescKey = 'yAttributeDescription';
          tTargetAxisKey = 'yAxis';
          tOtherDim = 'x';
          tIsXorYChange = true;
          break;
        case DG.GraphTypes.EOrientation.kVertical2:
          tTargetDescKey = 'y2AttributeDescription';
          tTargetAxisKey = 'y2Axis';
          tOtherDim = 'x';
          break;
        case DG.GraphTypes.EOrientation.kTop:
        case DG.GraphTypes.EOrientation.kRight:
          tTargetDescKey = iOrientation + 'AttributeDescription';
          tTargetAxisKey = iOrientation + 'Axis';
          break;
      }

      this.set('aboutToChangeConfiguration', true); // signals dependents to prepare

      var tDataConfiguration = this.get('dataConfiguration'),
          tCurrentAttribute = tDataConfiguration.getPath(tTargetDescKey + '.attribute'),
          tOtherAttribute = tDataConfiguration.getPath(tOtherDim + 'AttributeDescription.attribute'),
          tNewAttribute = iAttrRefs.attributes[0],
          tIsAxisSwitch = tNewAttribute === tOtherAttribute;

      tDataConfiguration.beginPropertyChanges();

      if (tIsAxisSwitch) {
        switchAxes();
      }
      else {
        if( tTargetAxisKey === 'yAxis')
          removeAllButZerothAttribute();
        tDataConfiguration.set('dataContext', iDataContext);
        tDataConfiguration.setAttributeAndCollectionClient(tTargetDescKey, iAttrRefs);

        this.synchPlotWithAttributes();
        this.synchAxes();

        if( tIsXorYChange) {
          // Plots (e.g. BinnedPlotModel) need to know this directly so that can act differently
          //  than for other attribute changes
          this.get('allPlots').forEach(function (iPlot) {
            iPlot.xOrYAttributeDidChange(tTargetAxisKey);
          });
        }

        this.invalidate();
      }

      tDataConfiguration.endPropertyChanges();
      this.set('aboutToChangeConfiguration', false); // reset for next time
      if( tIsSplit) {
        this.updateAxisArrays();
        this.updateSplitPlotArray();
        this.notifyPropertyChange('splitPlotChange');
      }
    },

    /**
      Sets the attribute for the specified axis.
      @param  {DG.DataContext}      iDataContext -- The data context for this graph
      @param  {Object}              iAttrRefs -- The attribute to set for the axis
             {DG.CollectionClient} iAttrRefs.collection -- The collection that contains the attribute
             {DG.Attribute}        iAttrRefs.attributes -- The array of attributes to set for the axis
     */
    addAttributeToAxis: function( iDataContext, iAttrRefs) {
      DG.logUser("addAxisAttribute: { attribute: %@ }", iAttrRefs.attributes[0].get('name'));

      var tYAttrDescription = this.getPath('dataConfiguration.yAttributeDescription' ),
          tAttrIndex = tYAttrDescription.get('attributes' ).length,
          tIsSplit = this.get('isSplit');

      if( tIsSplit) {
        this.removeAllSplitPlotsAndAxes();
      }

      if( tAttrIndex === 0) {
        // We aren't adding after all. Happens when foreign context is brought to multi-attribute place
        this.changeAttributeForAxis( iDataContext, iAttrRefs, DG.GraphTypes.EOrientation.kVertical);
        return;
      }

      tYAttrDescription.addAttribute( iAttrRefs.attributes[0]);

      var tRootPlot = this.get('plot'),
          tProperties = $.extend(this.getModelPointStyleAccessors(),
              tRootPlot.getPropsForCopy(),
              {
                xAxis: this.get('xAxis'),
                yAxis: this.get('yAxis'),
                y2Axis: this.get('y2Axis'),
                yAttributeIndex: tAttrIndex
              }),
      // The only plot we can currently make with multiple attributes is a scatterplot
          tPlot = DG.ScatterPlotModel.create(tProperties);

      this.addPlot( tPlot);
      tPlot.installAdornmentModelsFrom(tRootPlot);
      var tConnectingLineModel = tRootPlot.getAdornmentModel('connectingLine');
      if( tConnectingLineModel)
        tPlot.setAdornmentVisibility('connectingLine', tConnectingLineModel.get('isVisible'));

      this.notifyPropertyChange('attributeAdded');

      if( tIsSplit) {
        this.updateAxisArrays();
        this.updateSplitPlotArray();
        this.notifyPropertyChange('splitPlotChange');
      }
    },

    /**
     * Subclasses will override
     */
    removeSplitAttribute: function( iDescKey, iAxisKey, iIndex) {
      this.removeAllSplitPlotsAndAxes();
      this.get('dataConfiguration').setAttributeAndCollectionClient(iDescKey, null,
          DG.Analysis.EAnalysisRole.eNone, DG.Analysis.EAttributeType.eNone);

      this.updateAxisArrays();
      this.updateSplitPlotArray();
      this.notifyPropertyChange('splitPlotChange');
    },

    /**
     * Return the plot whose yAxis property is our y2Axis.
     * @returns {DG.PlotModel}
     */
    getY2Plot: function() {
      var tY2Plot,
          tY2Axis = this.get('y2Axis');
      this.get('plots').forEach( function( iPlot) {
        if( iPlot.get('yAxis') === tY2Axis)
          tY2Plot = iPlot;
      });
      return tY2Plot;
    },

    /**
      Sets the attribute for the specified axis.
      @param  {DG.DataContext}      iDataContext -- The data context for this graph
      @param  {Object}              iAttrRefs -- The attribute to set for the axis
             {DG.CollectionClient} iAttrRefs.collection -- The collection that contains the attribute
             {DG.Attribute}        iAttrRefs.attributes -- The array of attributes to set for the axis
      @param  {String}              iOrientation -- identifies the axis ('horizontal' or 'vertical')
     */
    changeAttributeForY2Axis: function( iDataContext, iAttrRefs) {

      if( this.getPath('dataConfiguration.yAttributeDescription.attributes').length === 0) {
        // We aren't adding after all. Happens when foreign context is brought to multi-attribute place
        this.changeAttributeForAxis( iDataContext, iAttrRefs, DG.GraphTypes.EOrientation.kVertical);
        return;
      }

      var setNewBounds = function() {
        var tAxis = this.get('y2Axis');
        if( !tAxis || !tAxis.get('isNumeric'))
          return;

        var tDataConfiguration = this.get('dataConfiguration'),
            tMinMax = tDataConfiguration && tDataConfiguration.getDataMinAndMaxForDimension( DG.GraphTypes.EPlace.eY2);
        tAxis.setDataMinAndMax( tMinMax.min, tMinMax.max, true);
      }.bind(this);

      var tY2AttrDescription = this.getPath('dataConfiguration.y2AttributeDescription' ),
          tIsSplit = this.get('isSplit');
      if( tIsSplit) {
        this.removeAllSplitPlotsAndAxes();
      }
      tY2AttrDescription.removeAllAttributes();
      tY2AttrDescription.addAttribute( iAttrRefs.attributes[0]);
      tY2AttrDescription.set('collectionClient', iAttrRefs.collection);

      this.privSyncAxisWithAttribute( 'y2AttributeDescription', 'y2Axis' );

      if( !this.getY2Plot()) {
        // The only plot we can currently make with Y2 axis is a scatterplot
        var tProperties = $.extend( this.getModelPointStyleAccessors(), { verticalAxisIsY2: true }),
            tPlot = DG.ScatterPlotModel.create( tProperties);
        tPlot.beginPropertyChanges();
        tPlot.setIfChanged('dataConfiguration', this.get('dataConfiguration'));
        tPlot.setIfChanged('xAxis', this.get('xAxis'));
        tPlot.setIfChanged('yAxis', this.get('y2Axis'));
        tPlot.endPropertyChanges();

        this.addPlot(tPlot);
      }

      setNewBounds();

      this.notifyPropertyChange('y2AttributeAdded');

      if( tIsSplit) {
        this.updateAxisArrays();
        this.updateSplitPlotArray();
        this.notifyPropertyChange('splitPlotChange');
      }
    },

    /**
     * Change the attribute type (EAttributeType) on the axis described by the given key,
     * to treat a Numeric attribute as Categorical.
     * @param{String} iDescKey - key to the desired attribute description (x...|y...|legendAttributeDescription)
     * @param{String} iAxisKey - key to the axis whose attribute is to be removed (x...|yAxis)
     * @param{Boolean} true if we want to treat the attribute as numeric (else categorical).
     */
    changeAttributeType: function( iDescKey, iAxisKey, iTreatAsNumeric ) {
      arguments.callee.base.apply(this,arguments);

      if( iDescKey === 'xAttributeDescription' || iDescKey === 'yAttributeDescription') {
        this.synchPlotWithAttributes();
        this.synchAxes();
        this.rescaleAxesFromData(true /*allowShrinkage*/, true /*animatePoints*/);
        this.updateAxisArrays();
        this.updateSplitPlotArray();
        this.notifyPropertyChange('splitPlotChange');
      }
    },

    /**
     * The top or right "axis view" has accepted the drop of a nominal attribute
     * @param iDataContext {DG.DataContext}
     * @param iAttrRefs { {attributes: [{DG.Attribute}], collection: {DG.Collection}}}
     * @param iSplitPosition { 'top' | 'right' }
     */
    splitByAttribute: function( iDataContext, iAttrRefs, iSplitPosition) {

      function replaceOtherWithCurrent() {
        this_.removeAllSplitPlotsAndAxes();
        var tCurrentAttribute = tDataConfiguration.getPath( tTargetDescKey + '.attribute'),
            tCurrentCollection = tDataConfiguration.getPath( tTargetDescKey + '.collection');
        tDataConfiguration.setAttributeAndCollectionClient( tOtherDescKey, {
          attributes: [ tCurrentAttribute ], collection: tCurrentCollection
        });
        this_.notifyPropertyChange('removedAllSplitPlotsAndAxes');
      }

      this.set('aboutToChangeConfiguration', true); // signals dependents to prepare

      var this_ = this,
          tDataConfiguration = this.get('dataConfiguration'),
          tOtherSplitPosition = iSplitPosition === 'top' ? 'right' : 'top',
          tTargetDescKey = iSplitPosition + 'AttributeDescription',
          tOtherDescKey = tOtherSplitPosition + 'AttributeDescription',
          tDroppedAttribute = iAttrRefs.attributes[0],
          tOtherAttribute = tDataConfiguration.getPath( tOtherDescKey + '.attribute');
      if( tDroppedAttribute === tOtherAttribute) {
        replaceOtherWithCurrent();
      }
      if( this.get('isSplit'))
        this.removeAllSplitPlotsAndAxes();
      tDataConfiguration.set('dataContext', iDataContext);
      tDataConfiguration.setAttributeAndCollectionClient(tTargetDescKey, iAttrRefs);

      this.invalidate();

      this.updateAxisArrays();

      this.updateSplitPlotArray();

      this.set('aboutToChangeConfiguration', false); // reset for next time

      this.notifyPropertyChange('splitPlotChange');
    },

    /**
     * A category map for an attribute on either the top or right axis has changed.
     * By invalidating all split plots the correct points will be drawn on the next redraw.
     */
    splitCategoriesDidChange: function() {
      this.forEachSplitPlotElementDo( function( iPlotArray) {
        iPlotArray.forEach( function( iPlot) {
          iPlot.invalidateCaches();
        });
      });
    }.observes('dataConfiguration.categoryMap'),

    /**
     * Useful for knowing whether we can rescale.
     * @return {Boolean}
     */
    hasNumericAxis: function() {
      return this.getPath('xAxis.isNumeric') || this.getPath('yAxis.isNumeric');
    }.property('xAxis', 'yAxis'),

    /**
     * Useful for knowing whether we can lock background.
     * @return {Boolean}
     */
    bothAxesAreNumeric: function() {
      return this.getPath('xAxis.isNumeric') && this.getPath('yAxis.isNumeric');
    }.property('xAxis', 'yAxis'),

    /**
     * @return {Boolean}
     */
    canRescale: function() {
      return this.get('hasNumericAxis') || (this.get('plot') && this.get('plot').mixUp);
    }.property('hasNumericAxis', 'plot'),

    /**
     * @return {Boolean}
     */
    canMixUp: function() {
      var tPlot = this.get('plot');
      return tPlot && tPlot.mixUp;
    }.property('plot'),

    /**
     * Pass down to plot
     * @property {Boolean}
     */
    canSupportConfigurations: function() {
      return this.getPath('plot.canSupportConfigurations');
    }.property('plot'),
    canSupportConfigurationsChanged: function() {
      this.notifyPropertyChange('canSupportConfigurations');
    },

    /**
     * If there are no cases, don't do anything
     * @param iShrink {boolean}
     * @param iAnimate {boolean}
     * @param iLogIt {boolean}
     * @param iUserAction {boolean}
     */
    rescaleAxesFromData: function( iShrink, iAnimate, iLogIt, iUserAction) {
        this.forEachSplitPlotElementDo(function (iPlotArray) {
          if (iPlotArray[0])  // During some transitions, we may temporarily not have any plots in this cell
            iPlotArray[0].rescaleAxesFromData(iShrink, iAnimate, iLogIt, iUserAction);
        });
    },

    mixUp: function() {
      this.forEachSplitPlotElementDo( function( iPlotArray) {
        var tZeroPlot = iPlotArray[0];
        if( tZeroPlot && tZeroPlot.mixUp)  // During some transitions, we may temporarily not have any plots in this cell
          tZeroPlot.mixUp();
      });
    },

    /**
     * This is a bit awkward, but if the axis is a DG.CellLinearAxisModel and the key is for a y-axis
     * we pass our getPointColor accessor to the axis so it can be passed on to the appropriate label
     * node to keep the 0th label color synched to the 0th scatterplot point color.
     * @param iKey {string}
     * @param iAxis {DG.AxisModel}
     */
    passGetPointColorToAxis: function( iKey, iAxis) {
      if( iKey.charAt(0) === 'y' && (iKey.length === 1 || iKey.charAt(1) !== '2') &&
          iAxis.constructor === DG.CellLinearAxisModel)
        iAxis.set('getPointColor', this.getPointColor.bind(this));
    },

    /**
     * Attribute and plot assignment together determine what class of axis should appear on each dimension.
     * We query the plot for each dimension and, if the axis class is not currently present, we construct
     * the desired axis and destroy the old one, being careful to let everyone know of the change.
     */
    synchAxes: function() {
      var this_ = this,
          tDataConfiguration = this.get('dataConfiguration'),
          tPlot = this.get('plot');
      [{place: DG.GraphTypes.EPlace.eX, dim: 'x'}, {place: DG.GraphTypes.EPlace.eY, dim: 'y'},
        {place: DG.GraphTypes.EPlace.eY2, dim: 'y2'}].forEach( function( iObj) {
        var tDesiredAxisClass = tPlot.getDesiredAxisClassFor( iObj.place),
            tCurrentAxis = this_.get( iObj.dim + 'Axis');
        if( tDesiredAxisClass && tCurrentAxis.constructor !== tDesiredAxisClass) {
          var tNewAxis = tDesiredAxisClass.create( {
                dataConfiguration: tDataConfiguration,
                attributeDescription: tDataConfiguration.get( iObj.dim + 'AttributeDescription')
              });
          this_.passGetPointColorToAxis(iObj.dim, tNewAxis);
          this_.set( iObj.dim + 'Axis', tNewAxis);
          tPlot.set( iObj.dim + 'Axis', tNewAxis);
          tCurrentAxis.destroy();
        }
      });
      if( tDataConfiguration.getPath('xAttributeDescription.isCategorical') &&
          tDataConfiguration.getPath('yAttributeDescription.isNumeric') &&
          tDataConfiguration.getPath('yAttributeDescription.attributes').length > 1) {
        // Make sure there is only one attribute assigned to y-axis
        var tNumAttributes = tDataConfiguration.getPath('yAttributeDescription.attributes').length;
        while( tNumAttributes > 1) {
          this.removeAttribute('yAttributeDescription', 'yAxis', --tNumAttributes);
        }

      }
    },

    /**
     * Sychronize the axis model to a new attribute or attribute description, to sure correct kind of axis is installed.
     * @param{String} iDescKey - key to the desired attribute description (x...|yAttributeDescription)
     * @param{String} iAxisKey - key to the axis to be changed (x...|yAxis)
     */
    privSyncAxisWithAttribute: function( iDescKey, iAxisKey ) {
      var tDataConfiguration = this.get('dataConfiguration'),
          tVarIsNumeric = tDataConfiguration.getPath( iDescKey + '.isNumeric'),
          tPossibleNumericClasses = [DG.CellLinearAxisModel, DG.BinnedAxisModel],
          tDesiredAxisClass = tVarIsNumeric ? DG.CellLinearAxisModel : DG.CellAxisModel,
          tCurrentAxisClass = this.get( iAxisKey).constructor,
          tAxisModelParams = { dataConfiguration: tDataConfiguration };

      // If the variable and axis are incompatible, we'll have to change the axis
      // Note that there are two possible numeric axes
      if( tDesiredAxisClass !== tCurrentAxisClass &&
          !(tVarIsNumeric && tPossibleNumericClasses.indexOf( tCurrentAxisClass) >= 0)) {
        var tAxisToDestroy = this.get( iAxisKey ),
            tNewAxis = tDesiredAxisClass.create(tAxisModelParams);
        tNewAxis.set( 'attributeDescription', tDataConfiguration.get( iDescKey ) );
        this.passGetPointColorToAxis( iAxisKey, tNewAxis);
        this.set( iAxisKey, tNewAxis );
        tAxisToDestroy.destroy();
      }
    },

    /**
     * Dot charts and bar charts have a property, displayAsBarChart, which, when toggled, amounts to request
     * to swap one for the other.
     * @param iPlot {DG.PlotModel}
     */
    addPlotObserver: function( iPlot) {
      switch( iPlot.constructor) {
        case DG.BarChartModel:
        case DG.ComputedBarChartModel:
          iPlot.addObserver('isBarHeightComputed', this, this.swapComputedBarChartType);
          if (iPlot.constructor === DG.BarChartModel)
            iPlot.addObserver('breakdownType', this, this.propagateBreakdownType);
          /* falls through */
        case DG.DotChartModel:
          iPlot.addObserver('displayAsBarChart', this, this.swapChartType);
          break;
        case DG.BinnedPlotModel:
          iPlot.addObserver('dotsAreFused', this, this.dotsAreFusedDidChange);
          /* falls through */
        case DG.DotPlotModel:
        case DG.LinePlotModel:
          iPlot.addObserver('displayAsBinned', this, this.changePlotModelType);
          if( iPlot.constructor === DG.DotPlotModel)
            iPlot.addObserver('showMeasureLabels', this, this.propagateShowMeasuresLabels);
          break;
      }
    },

    /**
     * Called before we destroy a plot.
     * @param iPlot {DG.PlotModel}
     */
    removePlotObserver: function( iPlot) {
      iPlot.removeObserver('connectingLine', this, this.connectingLineChanged);
      switch( iPlot.constructor) {
        case DG.BarChartModel:
        case DG.ComputedBarChartModel:
          iPlot.removeObserver('isBarHeightComputed', this, this.swapComputedBarChartType);
          if (iPlot.constructor === DG.BarChartModel)
            iPlot.removeObserver('breakdownType', this, this.propagateBreakdownType);
          /* falls through */
        case DG.DotChartModel:
          iPlot.removeObserver('displayAsBarChart', this, this.swapChartType);
          break;
        case DG.BinnedPlotModel:
          iPlot.removeObserver('dotsAreFused', this, this.dotsAreFusedDidChange);
          /* falls through */
        case DG.DotPlotModel:
        case DG.LinePlotModel:
          iPlot.removeObserver('displayAsBinned', this, this.changePlotModelType);
          if( iPlot.constructor === DG.DotPlotModel)
            iPlot.removeObserver('showMeasureLabels', this, this.propagateShowMeasuresLabels);
          break;
      }
    },

    swapPlotForNewPlot: function( iNewPlotClass)       {
      var tOldPlot = this.get('plot'),
          tConfig = this.get('dataConfiguration'),
          tIsSplit = this.get('isSplit'),
          tNewPlot, tAdornmentModels;
      if( tIsSplit) {
        this.removeAllSplitPlotsAndAxes();
      }
      this.set('aboutToChangeConfiguration', true); // signal to prepare
      iNewPlotClass.configureRoles(tConfig);
      var tPlotProps = this.getModelPointStyleAccessors();
      tPlotProps.getRootPlot = this.getRootPlot.bind(this);
      if (tOldPlot.kindOf(DG.BarChartBaseModel))
        tPlotProps.breakdownType = tOldPlot.get('breakdownType');
      tNewPlot = iNewPlotClass.create(tPlotProps);
      this.addPlotObserver(tNewPlot);

      tAdornmentModels = tOldPlot.copyAdornmentModels(tNewPlot);

      tNewPlot.beginPropertyChanges();
      tNewPlot.setIfChanged('dataConfiguration', tConfig);
      tNewPlot.setIfChanged('xAxis', this.get('xAxis'));
      tNewPlot.setIfChanged('yAxis', this.get('yAxis'));
      for (var tProperty in tAdornmentModels) {
        if (tAdornmentModels.hasOwnProperty(tProperty)) {
          var tModel = tAdornmentModels[tProperty];
          tNewPlot.setIfChanged(tProperty, tModel);
        }
      }
      tNewPlot.endPropertyChanges();
      tNewPlot.set('isAnimating', false); // Gets set by rescaleAxesFromData, but it's too early to set it

      this.setIfChanged('plot', tNewPlot);

      this.removePlotObserver(tOldPlot);
      tOldPlot.destroy();

      // allow for switching axis type, e.g. CellLinearAxis <=> CountAxis for bar charts with/without formulas
      this.synchAxes();
      tNewPlot.rescaleAxesFromData(true /*iAllowAxisShrinkage*/);

      this.set('aboutToChangeConfiguration', false);  // all done
      if( tIsSplit) {
        this.updateAxisArrays();
        this.updateSplitPlotArray();
        this.notifyPropertyChange('splitPlotChange');
      }
    },

    /**
     * We swap out the given plot model for its alternate. A BarChart gets a count axis and, if we're making a
     * dot chart, we must remove the count axis.
     * @param iChartPlot {DG.BarChartModel | DG.ComputedBarChartModel }
     * @param iKey {String} Should be 'isBarHeightComputed'
     * @param iValue {Boolean}
     */
    swapComputedBarChartType: function( iChartPlot, iKey, iValue) {
      var this_ = this,
          tInitialValue = iChartPlot.get('isBarHeightComputed'),
          tOldPlotClass = iChartPlot.constructor,
          tNewPlotClass = tOldPlotClass === DG.ComputedBarChartModel ?
              DG.BarChartModel : DG.ComputedBarChartModel,
          tUndo = tInitialValue ? 'DG.Undo.graph.showAsComputedBarChart' : 'DG.Undo.graph.showAsStandardBarChart',
          tRedo = tInitialValue ? 'DG.Redo.graph.showAsComputedBarChart' : 'DG.Redo.graph.showAsStandardBarChart';
      DG.UndoHistory.execute(DG.Command.create({
        name: "graph.toggleComputedBarChart",
        undoString: tUndo,
        redoString: tRedo,
        log: ("toggleShowAs: %@").fmt(tInitialValue ? "ComputedBarChart" : "BarChart"),
        _beforeStorage: null,
        _afterStorage: null,
        _componentId: this.get('componentID'),
        _controller: function () {
          return DG.currDocumentController().componentControllersMap[this._componentId];
        },
        execute: function() {
          this._beforeStorage = this._controller().createComponentStorage();
          this_.swapPlotForNewPlot(tNewPlotClass);
        },
        undo: function() {
          this._afterStorage = this._controller().createComponentStorage();
          this._controller().restoreComponentStorage(this._beforeStorage);
        },
        redo: function () {
          this._controller().restoreComponentStorage(this._afterStorage);
          this._afterStorage = null;
        }
      }));
    },

    /**
     * We swap out the given plot model for its alternate. A BarChart gets a count axis and, if we're making a
     * dot chart, we must remove the count axis.
     * @param iChartPlot {DG.DotChartModel | DG.BarChartModel }
     * @param iKey {String} Should be 'displayAsBarChart'
     * @param iValue {Boolean}
     */
    swapChartType: function( iChartPlot, iKey, iValue) {
      var tInitialValue = iChartPlot.get('displayAsBarChart'),
          tOldPlotClass = iChartPlot.constructor,
          tNewPlotClass = tOldPlotClass === DG.DotChartModel ?
              DG.BarChartModel : DG.DotChartModel,
          tUndo = tInitialValue ? ('DG.Undo.graph.showAsBarChart') : ('DG.Undo.graph.showAsDotChart'),
          tRedo = tInitialValue ? ('DG.Redo.graph.showAsBarChart') : ('DG.Redo.graph.showAsDotChart');
      DG.UndoHistory.execute(DG.Command.create({
        name: "graph.toggleBarChart",
        undoString: tUndo,
        redoString: tRedo,
        log: ("toggleShowAs: %@").fmt(tInitialValue ? "DotChart" : "BarChart"),
        executeNotification: {
          action: 'notify',
          resource: 'component',
          values: {
            operation: 'switch bar and dot',
            type: 'DG.GraphView'
          }
        },
        execute: function() {
          this.swapPlotForNewPlot(tNewPlotClass);
        }.bind(this),
        undo: function() {
          this.swapPlotForNewPlot( tOldPlotClass);
        }.bind(this)
      }));
    },

    /**
     * We swap out the given plot model for its alternate. Note that the primary axis of a binned plot is a
     * binned numeric axis while that for a normal dot plot is a cell linear axis.
     * @param iDotPlot {DG.DotPlotModel | DG.BinnedPlotModel }
     * @param iKey {String} Should be 'displayAsBinned'
     * @param iValue {Boolean | "bars"}
     */
    changePlotModelType: function(iPlotModel, iKey, iValue) {
      var tValue = iPlotModel.get('displayAsBinned'),
          tPlotTypeMap = {
            "false": {
              constructor: DG.DotPlotModel,
              logLabel: "DotPlot",
              undo: 'DG.Undo.graph.showAsDotPlot',
              redo: 'DG.Redo.graph.showAsDotPlot'
            },
            "true": {
              constructor: DG.BinnedPlotModel,
              logLabel: "BinnedPlot",
              undo: 'DG.Undo.graph.showAsBinnedPlot',
              redo: 'DG.Redo.graph.showAsBinnedPlot'
            },
            bars: {
              constructor: DG.LinePlotModel,
              logLabel: "LinePlot",
              undo: 'DG.Undo.graph.showAsLinePlot',
              redo: 'DG.Redo.graph.showAsLinePlot'
            }
          },
          tOldPlotClass = iPlotModel.constructor;
      var tPlotTypeEntry = tPlotTypeMap[tValue];
      if (!tPlotTypeEntry) return;
      DG.UndoHistory.execute(DG.Command.create({
        name: "graph.changeDotPlotModelType",
        undoString: tPlotTypeEntry.undo,
        redoString: tPlotTypeEntry.redo,
        log: ("toggleShowAs: %@").fmt(tPlotTypeEntry.logLabel),
        executeNotification: {
          action: 'notify',
          resource: 'component',
          values: {
            operation: 'toggle show as %@'.fmt(tPlotTypeEntry.logLabel),
            type: 'DG.GraphView'
          }
        },
        execute: function() {
          this.swapPlotForNewPlot(tPlotTypeEntry.constructor);
        }.bind(this),
        undo: function() {
          this.swapPlotForNewPlot(tOldPlotClass);
        }.bind(this)
      }));
    },

    /**
     * We need to adjust the axes since we're flipping between a histogram with CellLinearAxisModel plus CountAxisModel,
     * and a binned plot with BinnedAxisModel plus AxisModel.
     * Note that undo/redo is taken care of before we get here.
     * @param iBinnedPlot {DG.BinnedPlotModel }
     */
    dotsAreFusedDidChange: function( iBinnedPlot) {
      var tDataConfiguration = this.get('dataConfiguration'),
          tPrimaryAxisPlace = iBinnedPlot.get('primaryAxisPlace'),
          tPrimaryKey = tPrimaryAxisPlace === DG.GraphTypes.EPlace.eX ? 'x' : 'y',
          tSecondaryAxisPlace = iBinnedPlot.get('secondaryAxisPlace'),
          tSecondaryKey = tSecondaryAxisPlace === DG.GraphTypes.EPlace.eX ? 'x' : 'y';
      this.set('aboutToChangeConfiguration', true); // signals dependents to prepare
      this.get('xAxis').destroy();
      this.get('yAxis').destroy();
      // this.beginPropertyChanges();
      iBinnedPlot.invalidateComputationContext(); // because we're changing its axes
      if( iBinnedPlot.get('dotsAreFused')) {
        // Transitioning to Histogram
        this.set(tPrimaryKey + 'Axis', DG.CellLinearAxisModel.create({
          dataConfiguration: tDataConfiguration,
          attributeDescription: this.getPath('dataConfiguration.' + tPrimaryKey + 'AttributeDescription')
        }));
        this.set(tSecondaryKey + 'Axis', DG.CountAxisModel.create({
          dataConfiguration: tDataConfiguration
        }));
      }
      else {
        // Transitioning to binned dot plot
        this.set(tPrimaryKey + 'Axis', DG.BinnedAxisModel.create({
          dataConfiguration: tDataConfiguration,
          attributeDescription: this.getPath('dataConfiguration.' + tPrimaryKey + 'AttributeDescription'),
          binnedPlotModel: iBinnedPlot
        }));
        this.set(tSecondaryKey + 'Axis', DG.AxisModel.create({
          dataConfiguration: tDataConfiguration,
          attributeDescription: iBinnedPlot.get(tSecondaryKey + 'AxisDescription')
        }));
      }
      this.propertyDidChange('plot'); // Let view know plot has changed (even though class has not)
      this.set('aboutToChangeConfiguration', false); // reset for next time
    },

    /**
     * The root plot's breakdown type (count or percent) has changed. Propagate this change to split plots if any.
     */
    propagateBreakdownType: function() {
      var tNewBound = this.getPath('plot.naturalUpperBound');
      if( this.get('isSplit')) {
        var tType = this.getPath('plot.breakdownType');
        this.forEachSplitPlotElementDo( function( iPlotArray, iRow, iCol) {
          if( iRow !== 0 || iCol !== 0) {
            iPlotArray[0].set('breakdownType', tType);
            tNewBound = Math.max( tNewBound, iPlotArray[0].get('naturalUpperBound'));
          }
        });
      }
      this.getPath('plot.secondaryAxisModel').setLowerAndUpperBounds(0, tNewBound, true /* with animation */);
    },

    /**
     * The root plot's showMeasureLabels flag has changed. Propagate this change to split plots if any.
     */
    propagateShowMeasuresLabels: function() {
      var tShowing = this.getPath('plot.showMeasureLabels');
      if( this.get('isSplit')) {
        this.forEachSplitPlotElementDo( function( iPlotArray, iRow, iCol) {
          if( iRow !== 0 || iCol !== 0) {
            iPlotArray[0].set('showMeasureLabels', tShowing);
          }
        });
      }
    },

    /**
     Figure out the appropriate plot for the current attribute configuration. If it is not
     the current plot, switch.
     We have need of three local variables that point to a plot.
       tCurrentPlot is the plot instance (possibly null) when we start
       tNewPlot is any new plot we create
       tOperativePlot is the actual plot with which we proceed. It may be the same as tCurrentPlot or tNewPlot.
       At the end, we figure out whether tCurrentPlot has to be destroyed or not based on whether there was a
         current plot and whether we made a new plot.
     */
    synchPlotWithAttributes: function() {
      var tConfig = this.get( 'dataConfiguration' ),
        tXType = tConfig.get( 'xType' ),
        tYType = tConfig.get( 'yType' ),
        tCurrentPlot = this.get( 'plot' ),
        tNewPlotClass, tNewPlot, tOperativePlot,
        tPlotTable,
        tAdornmentModels = {};
      // DateTime types are treated as numeric for the purposes of synching with a plot
      tXType = (tXType === DG.Analysis.EAttributeType.eDateTime) ? DG.Analysis.EAttributeType.eNumeric : tXType;
      tYType = (tYType === DG.Analysis.EAttributeType.eDateTime) ? DG.Analysis.EAttributeType.eNumeric : tYType;
      // The elements of this table are the classes for the new plot under each of the 9
      //  possible pairs for x and y attribute types.
      tPlotTable = [
        [ // x has no attribute
          DG.CasePlotModel /* y has none */, DG.DotPlotModel /* y is numeric */, DG.DotChartModel /* y is categorical */
        ],
        [ // x is numeric
          DG.DotPlotModel /* y has none */, DG.ScatterPlotModel /* y is numeric */, DG.DotPlotModel /* y is categorical */
        ],
        [ // x is categorical
          DG.DotChartModel /* y has none */, DG.DotPlotModel /* y is numeric */, DG.DotChartModel /* y is categorical */
        ]
      ];

      tNewPlotClass = tPlotTable[ tXType][ tYType];
      if( SC.none( tNewPlotClass ) )
        tNewPlotClass = DG.PlotModel;

      var tBothAxesCategorical = tXType === DG.Analysis.EAttributeType.eCategorical &&
                                  tYType === DG.Analysis.EAttributeType.eCategorical;
      // If the current plot is a BinnedPlotModel, it is compatible with needing a DotPlotModel
      if( tNewPlotClass === DG.DotPlotModel && tCurrentPlot &&
          tCurrentPlot.constructor === DG.BinnedPlotModel) {
        tNewPlotClass = DG.BinnedPlotModel;
        // In the presence of a categorical attribute, a binned plot model cannot have fused dots
        // because we can't yet combine count axis with categorical axis.
        if( tXType === DG.Analysis.EAttributeType.eCategorical || tYType === DG.Analysis.EAttributeType.eCategorical)
          tCurrentPlot.set('dotsAreFused', false);
      }
      else if(tNewPlotClass === DG.DotPlotModel && tCurrentPlot && tCurrentPlot.constructor === DG.LinePlotModel) {
        // We're allowed to keep the line/bar plot
        tNewPlotClass = DG.LinePlotModel;
      }
      else if( tNewPlotClass === DG.DotChartModel && tCurrentPlot && tCurrentPlot.constructor === DG.BarChartModel &&
                !tBothAxesCategorical) {
        // We're allowed to keep the bar chart
        tNewPlotClass = DG.BarChartModel;
      }

      tNewPlotClass.configureRoles( tConfig );
      if( SC.none( tCurrentPlot ) || (tNewPlotClass !== tCurrentPlot.constructor) ) {
        tNewPlot = tOperativePlot = tNewPlotClass.create( this.getModelPointStyleAccessors());
        tNewPlot.set('getRootPlot', this.getRootPlot.bind(this));
        this.addPlotObserver( tNewPlot);
      }
      else
        tOperativePlot = tCurrentPlot;

      if( tCurrentPlot && tOperativePlot !== tCurrentPlot ) {
        // copy adornments that work across plot types
        tAdornmentModels = tCurrentPlot.copyAdornmentModels( tOperativePlot );
      }
      tOperativePlot.setIfChanged( 'dataConfiguration', tConfig );
      tOperativePlot.setIfChanged( 'xAxis', this.get( 'xAxis' ) );
      tOperativePlot.setIfChanged( 'yAxis', this.get( 'yAxis' ) );
      tOperativePlot.installAdornmentModels( tAdornmentModels);

      this.setIfChanged('plot', tOperativePlot);

      if( !SC.none(tNewPlot) && !SC.none(tCurrentPlot)) {
        this.removePlotObserver( tCurrentPlot);
        tCurrentPlot.destroy();
      }
    },

    /**
     Remove the attribute on the axis described by the given key.
     @param{String} key to the desired attribute description
     @param{String} key to the axis whose attribute is to be removed
     @param{Number} index of attribute in the list
     */
    removeAttribute: function (iDescKey, iAxisKey, iAttrIndex) {

      var
          /**
           * This is the normal case - there's one attribute assigned to the axis, and we remove it.
           * When we remove the last attribute, we have to do some plot reconfiguration. When it's not
           * the last attribute, we assume that the plot configuration remains the same.
           */
          removeLastAttribute = function () {
            var tAxisToDestroy = this.get(iAxisKey),
                tNewAxis = DG.AxisModel.create( { dataConfiguration: tConfig }),
                tOtherDesc = (iDescKey === 'xAttributeDescription') ? 'yAttributeDescription' : 'xAttributeDescription',
                tY2Plot = (iAxisKey === 'y2Axis') ? this.getY2Plot() : null,
                tSecondaryRole, tPrimaryRole;

            this.set('aboutToChangeConfiguration', true); // signals dependents to prepare

            tConfig.setAttributeAndCollectionClient(iDescKey, null,
                DG.Analysis.EAnalysisRole.eNone, DG.Analysis.EAttributeType.eNone);
            // The role of the attribute placement description on the axis whose attribute is removed must be secondary
            // and the other axis role must now be primary
            switch (this.getPath('dataConfiguration.' + tOtherDesc + '.attributeType')) {
              case DG.Analysis.EAttributeType.eNumeric:
                tSecondaryRole = DG.Analysis.EAnalysisRole.eSecondaryNumeric;
                tPrimaryRole = DG.Analysis.EAnalysisRole.ePrimaryNumeric;
                break;
              case DG.Analysis.EAttributeType.eCategorical:
                tSecondaryRole = DG.Analysis.EAnalysisRole.eSecondaryCategorical;
                tPrimaryRole = DG.Analysis.EAnalysisRole.ePrimaryCategorical;
                break;
              default:
                tSecondaryRole = DG.Analysis.EAnalysisRole.eNone;
                tPrimaryRole = DG.Analysis.EAnalysisRole.eNone;
            }
            tConfig.get(iDescKey).set('role', tSecondaryRole);
            tConfig.get(tOtherDesc).set('role', tPrimaryRole);

            tNewAxis.set('attributeDescription', tConfig.get(iDescKey));
            this.set(iAxisKey, tNewAxis);
            tAxisToDestroy.destroy();

            if (iAxisKey === 'y2Axis') {
              if (tY2Plot) {
                this.removePlot(tY2Plot);
                this.notifyPropertyChange('attributeRemoved');
              }
            }
            else {
              this.synchPlotWithAttributes();
              this.synchAxes();
            }

            this.invalidate();
            this.set('aboutToChangeConfiguration', false); // reset for next time
          }.bind(this),

          /**
           * We're removing one of 2 or more attributes. The axis will stay the same. One plot will be removed.
           */
          removeIndexedAttribute = function () {
            var tAttrDesc = tConfig.get(iDescKey);
            tAttrDesc.removeAttributeAtIndex(iAttrIndex);
            this.removePlotAtIndex(iAttrIndex);

            this.notifyPropertyChange('attributeRemoved');
          }.bind(this);

      iAttrIndex = iAttrIndex || 0;
      var tConfig = this.get('dataConfiguration'),
          tAttributes = tConfig.getPath(iDescKey + '.attributes'),
          tIsSplit = this.get('isSplit');

      if( tIsSplit) {
        this.removeAllSplitPlotsAndAxes();
      }

      if( tAttributes.length === 0)
        return;
      if (tAttributes.length === 1) {
        if( iAxisKey === 'xAxis')
          tConfig.get('yAttributeDescription').removeAllAttributesButFirst();

        // If we are removing the last x or y-axis attribute and there is a y2-axis attribute, remove the latter first.
        if( ((iAxisKey === 'yAxis') || (iAxisKey === 'xAxis')) && this.getY2Plot())
          this.removeAttribute( 'y2AttributeDescription', 'y2Axis', 0);

        removeLastAttribute();
      }
      else
        removeIndexedAttribute();

      if(tIsSplit) {
        this.updateAxisArrays();
        this.updateSplitPlotArray();
        this.notifyPropertyChange('splitPlotChange');
      }
    },

    displayedCasesWillChange: function() {
      if (!this._isBeingRestored && this.get('isSplit')) {
        this.removeAllSplitPlotsAndAxes();
      }
    },

    displayedCasesDidChange: function() {
      if( !this._isBeingRestored) {
        this.invalidate();
        this.rescaleAxesFromData( false, /* no shrinkage allowed */ true /* animate */);
        this.get('plots').forEach(function(plot) {
          plot.invalidateAggregateAdornments();
        });
        if( this.get('isSplit')) {
          this.updateAxisArrays();
          this.updateSplitPlotArray();
          this.notifyPropertyChange('splitPlotChange');
        }
      }
    },

    /**
     *
     */
    updateAxisArrays: function() {
      var this_ = this;

      function configureAxisSlot( iKey, iIndex, iClass, iAttrDesc) {
        var tArray = this_.get(iKey + 'AxisArray'),
            tRootAxis = tArray[0],
            tCurrentAxis = tArray[iIndex],
            tNewAxis;
        if (!tCurrentAxis || tCurrentAxis.constructor !== iClass) {
          tNewAxis = iClass.create({
            dataConfiguration: tDataConfig,
            attributeDescription: tDataConfig.get(iAttrDesc)
          });
          if( tRootAxis.get('isNumeric')) {
            tNewAxis.setLowerAndUpperBounds(tRootAxis.get( 'lowerBound'), tRootAxis.get( 'upperBound'));
          }
          this_.get('axisCoordinator').setAxis( iKey, iIndex, tNewAxis);
        }
      }

      var tDataConfig = this.get('dataConfiguration'),
          tXAxisClass = this.get('xAxis').constructor,
          tYAxisClass = this.get('yAxis').constructor,
          tY2AxisClass = this.get('y2Axis').constructor;
      this.forEachRowDo( function( iRow) {
        configureAxisSlot( 'y', iRow, tYAxisClass, 'yAttributeDescription');
        configureAxisSlot( 'y2', iRow, tY2AxisClass, 'y2AttributeDescription');
      });
      this.forEachColumnDo( function( iColumn) {
        configureAxisSlot( 'x', iColumn, tXAxisClass, 'xAttributeDescription');
      });
    },

    /**
     * Make sure there are the right number of plot elements in the array and that
     * they are configured properly
     */
    updateSplitPlotArray: function() {
      var this_ = this,
          tRootPlotArray = this.get('splitPlotArray')[0][0],
          tNumPlotsPerCell = tRootPlotArray.length,
          tPlotClass = tRootPlotArray[0].constructor;  // All plots will be of this class

      this.forEachSplitPlotElementDo( function( iPlotArray, iRow, iCol) {
        var tAttrIndex = 0;
        for( var tPlotIndex = 0; tPlotIndex < tNumPlotsPerCell; tPlotIndex++) {
          var tRootPlot = tRootPlotArray[ tPlotIndex],
              tCurrentPlot = iPlotArray[tPlotIndex],
              tXAxis = this_.get('xAxisArray')[iCol],
              tYAxis = this_.get('yAxisArray')[iRow],
              tNewPlot;
          if( !tCurrentPlot || tCurrentPlot.constructor !== tPlotClass) {
            var tProperties = $.extend(this_.getModelPointStyleAccessors(),
                tRootPlot.getPropsForCopy(),
                {
                  splitPlotRowIndex: iRow,
                  splitPlotColIndex: iCol,
                  xAxis: tXAxis,
                  yAxis: tYAxis,
                  y2Axis: this_.get('y2AxisArray')[0],
                  yAttributeIndex: tRootPlot.get('verticalAxisIsY2') ? 0 : tAttrIndex++,
                  getRootPlot: this_.getRootPlot.bind(this_)
                });
            tNewPlot = tPlotClass.create(tProperties);
            tXAxis.setLinkToPlotIfDesired( tNewPlot);
            tYAxis.setLinkToPlotIfDesired( tNewPlot);
            if( tPlotIndex === 0) {
              tRootPlot.addSibling(tNewPlot);
            }
            tNewPlot.installAdornmentModelsFrom(tRootPlot);
            iPlotArray[tPlotIndex] = tNewPlot;
            if (tCurrentPlot) {
              this_.removePlotObserver(tCurrentPlot);
            }
          }
          else {
            tCurrentPlot.set('splitPlotRowIndex', iRow);
            tCurrentPlot.set('splitPlotColIndex', iCol);
            if( !tCurrentPlot.get('verticalAxisIsY2')) {
              tCurrentPlot.set('yAttributeIndex', tAttrIndex++);
            }
            tCurrentPlot.invalidateCaches();
            tCurrentPlot.updateAdornmentModels();
          }
        }
      });
      this.propagateShowMeasuresLabels();
      this.rescaleAxesFromData( true, false);
    },

    /**
     * Called when an x or y attribute has changed type so that we can update the splitting from scratch
     * once the new attribute is installed.
     */
    removeAllSplitPlotsAndAxes: function() {

      function wipeOutAxisArray( iAxisArray) {
        iAxisArray.forEach( function( iAxis, iIndex) {
          if( iIndex !== 0)
            iAxis.destroy();
        });
        iAxisArray.length = 1;
      }

      var this_ = this,
          tSplitPlotArray = this.get('splitPlotArray'),
          tRootPlot = tSplitPlotArray[0][0][0];
      this.forEachSplitPlotElementDo( function( iPlotArray, iRow, iColumn) {
        if( iRow !== 0 || iColumn !== 0) {
          iPlotArray.forEach(function (iPlot) {
            this_.removePlotObserver(iPlot);
            iPlot.destroy();
          });
        }
      });
      tSplitPlotArray.length = 1;
      tSplitPlotArray[0].length = 1;
      tRootPlot.set('siblingPlots', []);

      wipeOutAxisArray( this.get('xAxisArray'));
      wipeOutAxisArray( this.get('yAxisArray'));
      wipeOutAxisArray( this.get('y2AxisArray'));

      this.notifyPropertyChange('removedAllSplitPlotsAndAxes');
    },

    forEachRowDo: function( iFunc) {
      var tRowAttrDescription = this.getPath('dataConfiguration.rightAttributeDescription'),
          tRowLength = tRowAttrDescription.getPath('attributeStats.numberOfCells') || 1,
          tRowIndex;
      for( tRowIndex = 0; tRowIndex < tRowLength; tRowIndex++) {
        iFunc( tRowIndex);
      }
    },

    forEachColumnDo: function( iFunc) {
      var tColAttrDescription = this.getPath('dataConfiguration.topAttributeDescription'),
          tColLength = tColAttrDescription.getPath('attributeStats.numberOfCells') || 1,
          tColIndex;
      for( tColIndex = 0; tColIndex < tColLength; tColIndex++) {
        iFunc( tColIndex);
      }
    },

    /**
     * Cause the given functor to operate on each of the split plot elements using
     * the template iFunc(<[DG.PlotModel]>, iRow, iColumn)
     * @param iFunc {Function}
     */
    forEachSplitPlotElementDo: function( iFunc) {
      var tSplitPlotArray = this.get('splitPlotArray'),
          tRowAttrDescription = this.getPath('dataConfiguration.rightAttributeDescription'),
          tRowLength = tRowAttrDescription.getPath('attributeStats.numberOfCells') || 1,
          tColAttrDescription = this.getPath('dataConfiguration.topAttributeDescription'),
          tColLength = tColAttrDescription.getPath('attributeStats.numberOfCells') || 1,
          tRowIndex, tColIndex;
      for( tRowIndex = 0; tRowIndex < tRowLength; tRowIndex++) {
        if( !tSplitPlotArray[ tRowIndex]) {
          tSplitPlotArray[ tRowIndex] = [];
        }
        for( tColIndex = 0; tColIndex < tColLength; tColIndex++) {
          if( !tSplitPlotArray[tRowIndex][tColIndex]) {
            tSplitPlotArray[tRowIndex][tColIndex] = [];
          }
          iFunc( tSplitPlotArray[tRowIndex][tColIndex], tRowIndex, tColIndex);
        }
      }

    },

    /**
     * Return an array of all the selected cases over all split plots
     * @return number[]
     */
    selection: function() {
      var tResult = [];
      this.forEachSplitPlotElementDo( function( iPlot) {
        var tSelection = iPlot[0].get('selection');
        if( Array.isArray(tSelection))
          tResult = tResult.concat( tSelection);
      });
      return tResult;
    }.property(),

    /**
     * Use the properties of the given object to restore my plot, axes, and legend.
     * @param iStorage {Object}
     */
    restoreStorage: function( iStorage) {
      var this_ = this,
          tDataConfig = this.get('dataConfiguration'),
          tYAttrIndex = 0,
          tY2AttrIndex = 0,
          tStartsOutSplit = this.get('isSplit'),
          tEndsUpSplit;
      if( tStartsOutSplit)
        this.removeAllSplitPlotsAndAxes();

      this._isBeingRestored = true;

      tDataConfig.restoreLegendQuantiles( iStorage);

      var instantiateArrayOfPlots = function( iPlots) {
        iPlots.forEach( function( iModelDesc, iIndex) {
          if( !iModelDesc.plotClass)
            return;
          var tPlot = DG.Core.classFromClassName( iModelDesc.plotClass ).create( this.getModelPointStyleAccessors()),
          tActualYAttrIndex = iModelDesc.plotModelStorage.verticalAxisIsY2 ? tY2AttrIndex++ : tYAttrIndex++;
          tPlot.beginPropertyChanges();
          tPlot.set('getRootPlot', this.getRootPlot.bind(this_));
          tPlot.set('enableMeasuresForSelection', this.get('enableMeasuresForSelection'));
          tPlot.setIfChanged( 'dataConfiguration', tDataConfig);
          ['xAxis', 'yAxis', 'y2Axis'].forEach( function( iAxisKey) {
            var tAxis = this.get(iAxisKey);
            tPlot.setIfChanged( iAxisKey, tAxis);
            tAxis.setLinkToPlotIfDesired( tPlot);
          }.bind( this));
          tPlot.setIfChanged( 'yAttributeIndex', tActualYAttrIndex);
          tPlot.restoreStorage(iModelDesc.plotModelStorage);
          tPlot.set('getRootPlot', this.getRootPlot.bind(this_));
          tPlot.endPropertyChanges();
          this.addPlotObserver( tPlot);
          if( iIndex === 0)
            this.set('plot', tPlot);
          else
            this.addPlot( tPlot);
        }.bind( this));
      }.bind( this);

      arguments.callee.base.apply(this,arguments);

      // Start the plots from scratch
      while( this._plots.length > 0) {
        var tPlot = this._plots.pop();
        this.removePlotObserver( tPlot);
        tPlot.destroy();
      }
      tDataConfig.set('displayOnlySelected', iStorage.displayOnlySelected);

      ['isTransparent', 'plotBackgroundColor', 'plotBackgroundOpacity', 'plotBackgroundImage',
      'plotBackgroundImageLockInfo', 'enableMeasuresForSelection'].forEach( function( iKey) {
        if( !SC.none( iStorage[iKey]))
          this_.set(iKey, iStorage[iKey]);
      });
      // Special case
      if( iStorage.enableNumberToggle && !SC.none( iStorage.numberToggleLastMode))
        this.setPath('numberToggle.lastMode', iStorage.numberToggleLastMode);

      this.set('aboutToChangeConfiguration', true ); // signals dependents to prepare

      ['x', 'y', 'y2', 'legend', 'top', 'right'].forEach( function( iKey) {
        var tAttrRef = this.instantiateAttributeRefFromStorage(iStorage, iKey + 'Coll', iKey + 'Attr');
        tDataConfig.setAttributeAndCollectionClient(iKey + 'AttributeDescription', tAttrRef,
            iStorage[iKey + 'Role'], iStorage[iKey + 'AttributeType']);
      }.bind( this));

      ['x', 'y', 'y2', 'top', 'right'].forEach( function( iKey) {
        var tAxisClassName = iStorage[iKey + 'AxisClass'],
            tAxisClass = tAxisClassName && DG[tAxisClassName.substring(3)], // convert string to axis class
            tPrevAxis = this.get( iKey + 'Axis'),
            tCurrentAxisClass = tPrevAxis.constructor;
        if( tAxisClass && tAxisClass !== tCurrentAxisClass) {
          var tNewAxis = tAxisClass.create({ dataConfiguration: tDataConfig});
          tNewAxis.set('attributeDescription', tDataConfig.get(iKey + 'AttributeDescription'));
          this.passGetPointColorToAxis( iKey, tNewAxis);
          this.set(iKey + 'Axis', tNewAxis);
          tPrevAxis.destroy();
        }
      }.bind( this));

      instantiateArrayOfPlots( (iStorage.plotClass ? [ {plotClass: iStorage.plotClass }] : null) ||
                                  iStorage.plotModels ||
                                  []);
      this._isBeingRestored = false;

      this.set('aboutToChangeConfiguration', false ); // We're done. View layer can adapt

      tEndsUpSplit = this.get('isSplit');
      if( tEndsUpSplit) {
        this.updateAxisArrays();
        this.updateSplitPlotArray();
      }
      if( tStartsOutSplit || tEndsUpSplit)
        this.notifyPropertyChange('splitPlotChange');

    },

    checkboxDescriptions: function() {
      return this.getPath('plot.checkboxDescriptions');
    }.property('plot'),

    spreadCheckboxDescriptions: function() {
      return this.getPath('plot.spreadCheckboxDescriptions');
    }.property('plot'),

    configurationDescriptions: function() {
      return this.getPath('plot.configurationDescriptions');
    }.property('plot'),

    lastValueControls: function() {
      return this.getPath('plot.lastValueControls');
    }.property('plot'),

    lastConfigurationControls: function() {
      return this.getPath('plot.lastConfigurationControls');
    }.property('plot'),

    /**
     * My plot model and my axes may have animations going on. If so, stop them.
     */
    stopAnimation: function() {
      this.get('plot').stopAnimation();
      this.get('xAxis').stopAnimation();
      this.get('yAxis').stopAnimation();
      var tY2Axis = this.get('y2Axis');
      tY2Axis && tY2Axis.stopAnimation();
    },

    isParentCase: function( iCase) {
      var parent = iCase.get('parent');
      return SC.none( parent);
    },

    handleDroppedContext: function( iContext) {
      if( this.get('dataContext') !== iContext) {
        this.reset();
      }
    },

    isPlotAffectedByChange: function(iChange) {
      var plotModel = this.get('plot'),
          toggleModel = this.get('enableNumberToggle') && this.get('numberToggle');
      return (plotModel && plotModel.isAffectedByChange(iChange)) ||
              (toggleModel && toggleModel.isAffectedByChange(iChange));
    },

    handleOneDataContextChange: function( iNotifier, iChange) {
      arguments.callee.base.apply(this,arguments);

      var plotModel = this.get('plot'),
          operation = iChange && iChange.operation;

      // No response necessary if the change doesn't affect us.
      if( plotModel && !this.isPlotAffectedByChange( iChange))
        return;

      // The GraphModel response is operation-specific.
      switch( operation) {
        case 'deleteCases':
          this.get('dataConfiguration').synchHiddenCases();
          this.dataDidChange( null, null, iChange);
          break;
        case 'createCase':
        case 'createCases':
        case 'createCollection':
        case 'deleteCollection':
        case 'resetCollections':
        case 'moveAttribute':   // Will only get here if the move is from one collection to another
          this.dataDidChange( null, null, iChange);
          this.get('dataConfiguration').updateCaptionAttribute();
          break;
        case 'updateCases':
        case 'dependentCases':
          // We must invalidate before we build indices because the change may
          // have affected the set of included cases, which affects indices.
          // It would be better not to be dealing with indices at all, but
          // that refactoring is left for another day.
          this.get('dataConfiguration').invalidateCaches( null, iChange);
          iChange.indices = this.buildIndices( iChange);
          this.dataRangeDidChange( this, 'revision', this, iChange.indices);
          break;
        case 'selectCases':
          if( this.getPath('dataConfiguration.displayOnlySelected')) {
            this.dataDidChange(null, null, iChange);
          }
          if( this.get('enableMeasuresForSelection')) {
            this.get('allPlots').forEach( function( iPlot) {
              iPlot.updateAdornmentModels();
            });
          }
          break;
      }

      // Forward the notification to the plots, so they can respond as well.
      this.get('allPlots').forEach(function (iPlot) {
        iPlot.handleDataContextNotification(iNotifier, iChange);
      });
      // Forward the notification to the number toggle, so it can respond as well.
      var numberToggleModel = this.get('numberToggle');
      if(numberToggleModel) {
        numberToggleModel.handleDataContextNotification(iNotifier, iChange);
      }
    },

    /**
     * One or more of the attributes used on this graph has been changed; e.g. by having its name changed.
     * We pass responsibility for dealing with the change to the appropriate sub-model.
     * @override
     * @param iChange {Object}
     */
    handleUpdateAttributes: function( iChange) {
      var tDataConfiguration = this.get('dataConfiguration'),
          tChangedAttrIDs = iChange && iChange.result && iChange.result.attrIDs;
      if( SC.isArray( tChangedAttrIDs)) {
        tChangedAttrIDs.forEach( function( iAttrID) {
          ['x', 'y', 'y2', 'legend'].forEach( function( iKey) {
            var tAssignedAttrs = tDataConfiguration.getPath( iKey + 'AttributeDescription.attributes'),
                tAssignedAttrIDs = tAssignedAttrs && tAssignedAttrs.map(function (iAttr) {
                  return iAttr.get('id');
                });
            if( tAssignedAttrIDs && tAssignedAttrIDs.indexOf( iAttrID) >= 0) {
              var tSubModel = (iKey === 'legend') ? this.get( iKey) : this.get( iKey + 'Axis');
              if( tSubModel)
                tSubModel.handleUpdateAttribute( iAttrID);
            }
          }.bind( this));
        }.bind( this));
      }
    },

    /**
     @private
     */
    dataDidChange: function( iSource, iKey, iChange ) {

      var aCaseLiesOutsideBounds = function (iCollectionClient, iCaseIDs) {
        // ensure we have a collectionClient and not a Collection
        iCollectionClient = this.get('dataContext').getCollectionByID(iCollectionClient.get('id'));
        return iCaseIDs.some(function (iCaseID) {
          var tCase = iCollectionClient.getCaseByID( iCaseID);
          if (!tCase) { return false; }
          return ['x', 'y', 'y2'].some(function (iDim) {
            var tFound = false,
                tAxis = this.get(iDim + 'Axis');
            if (tAxis && tAxis.get('isNumeric')) {
              var tLower = tAxis.get('lowerBound'),
                  tUpper = tAxis.get('upperBound');
              tFound = this.getPath('dataConfiguration.' + iDim + 'AttributeDescription.attributes').some(function (iAttr) {
                var tValue = tCase.getNumValue(iAttr.get('id'));
                return isFinite(tValue) && (tValue < tLower || tValue > tUpper);
              });
            }
            return tFound;
          }.bind(this));
        }.bind(this));
      }.bind(this);

      var tPlot = this.get('plot');
      if( tPlot && tPlot.isAffectedByChange( iChange)) {
        this.invalidate( iChange);  // So that when we ask for cases we get the right ones
        var dataConfig = this.get('dataConfiguration'),
            tAllCases = dataConfig && dataConfig.get('cases'),
            tNewCaseIDs = iChange.result.caseIDs,
            tDataLength = tAllCases ? tAllCases.length() : 0,
            tCollections = iChange.collection?[iChange.collection]:iChange.collections?iChange.collections:[];
        if( tDataLength !== this._oldNumberOfCases ) {
          var isAddingCases = (tDataLength > this._oldNumberOfCases);
          if( tPlot && isAddingCases) {
            var newCase = tAllCases.at( tDataLength-1);
            if( this.isParentCase( newCase))
              tPlot.set('openParentCaseID', newCase.get('id'));
            if( tNewCaseIDs && tCollections.some(function (collection) {
                return aCaseLiesOutsideBounds(collection, tNewCaseIDs);
              })) {
              // We always rescale the axes on new data. Previously, we rescaled
              // for child cases but skipped rescale on parent cases because in
              // most cases the parent case values aren't filled in until the end
              // when the closeCase command is issued. Some games provide all their
              // parent-level case values at createCase-time, however, and then
              // don't trigger any updateCase notifications at closeCase time.
              // Therefore, we always rescale here even though that could lead to
              // rescaling at openCase and again at closeCase under some circumstances.
              tPlot.rescaleAxesFromData(false /* don't allow scale shrinkage */,
                  false /* don't animate points */);
            }
          }
          this._oldNumberOfCases = tDataLength;
        }
        return;
      }
      // Must redraw everything if there are aggregate functions
      // Should be able to refine this to only changes that affect the plot
      if( this.getPath('dataConfiguration.hasAggregates'))
        this.invalidate();
    },

    /**
     @private
     */
    invalidate: function( iChange, iInvalidatePlotCaches) {
      var tPlot = this.get( 'plot' );
      arguments.callee.base.apply(this,arguments);

      if( iInvalidatePlotCaches && !SC.none( tPlot ) )
        tPlot.invalidateCaches();
    }

  } );

/* >>>>>>>>>> BEGIN source/components/graph/graph_types.js */
// ==========================================================================
//                            DG.GraphTypes
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

DG.GraphTypes = {

  /**
   * Enumeration of places.
   */
  EPlace: {
        eUndefined: -1,
        eFirstPlace: 0,
        eX: 0,
        eY: 1,
        eLegend: 2,
        eY2: 3,
        ePolygon: 4,
        eCaption: 5,
        eTopSplit: 6,
        eRightSplit: 7,
        eLastPlace: 7,
        eNumPlaces: 8
  },

  EOrientation: {
    kNone: 'none',
    kHorizontal: 'horizontal',
    kVertical: 'vertical',
    kVertical2: 'vertical2',
    kTop: 'top',
    kRight: 'right'
  }

};


/* >>>>>>>>>> BEGIN source/components/graph/graph_view.js */
// ==========================================================================
//                            DG.GraphView
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class  DG.GraphView - The view for a graph. Coordinates axes and plots.

 @extends SC.View
 */
DG.GraphView = SC.View.extend(
    /** @scope DG.GraphView.prototype */
    {
      displayProperties: ['model.dataConfiguration.attributeAssignment',
        'model.dataConfiguration.legendQuantilesAreLocked'],

      classNames: ['dg-graph-view'],

      /**
       The model on which this view is based.
       @property { DG.GraphModel }
       */
      model: null,

      controller: null,

      /**
       * @property { SC.View }
       */
      leftEdgeBackground: null,
      rightEdgeBackground: null,

      yAxisMultiTarget: null,
      legendView: null,
      numberToggleView: null,
      measuresForSelectedInfoView: null,  // DG.SelectedInfoView

      /**
       * The following three arrays are instrumental in bringing about splitting of a graph
       * into multiple plot views.
       * @property [{DG.AxisView}]
       */
      xAxisViewArray: null,
      yAxisViewArray: null,
      y2AxisViewArray: null,

      /**
       * The following two axis views lay out the categories when the graph is split in one
       * or both dimensions.
       * @property {DG.CellAxisView}
       */
      topAxisView: null,
      rightAxisView: null,

      // When a graph is split, we have multiple axis views, but we only want one label
      // We use these for bottom and left axis labels regardless, though.
      bottomAxisLabelView: null,
      leftAxisLabelView: null,

      /**
       @property { DG.AxisView }
       */
      xAxisView: function (iKey, iValue) {
        if (!this.xAxisViewArray)
          this.xAxisViewArray = [];
        if (iValue) {
          this.get('xAxisViewArray')[0] = iValue;
        }
        return this.xAxisViewArray[0];
      }.property(),

      /**
       @property { DG.AxisView }
       */
      yAxisView: function (iKey, iValue) {
        if (!this.yAxisViewArray)
          this.yAxisViewArray = [];
        if (iValue) {
          this.get('yAxisViewArray')[0] = iValue;
        }
        return this.yAxisViewArray[0];
      }.property(),

      /**
       * @property { DG.AxisView }
       */
      y2AxisView: function (iKey, iValue) {
        if (!this.y2AxisViewArray)
          this.y2AxisViewArray = [];
        if (iValue) {
          this.get('y2AxisViewArray')[0] = iValue;
        }
        return this.y2AxisViewArray[0];
      }.property(),

      /**
       * @property {DG.PlotBackgroundView}
       */
      plotBackgroundView: null,

      /**
       * When the graph is split into multiple plots, this 2-dim array holds one plot background view
       * for each cell. It is shared by the possibly multiple (scatter)plot views in that cell.
       * @property [[{DG.PlotBackgroundView}]]
       */
      plotBackgroundViewArray: null,

      _functionEditorView: null,
      functionEditorView: function (iKey, iValue) {
        if (iValue !== undefined) {
          if (this._functionEditorView) {
            this.removeChild(this._functionEditorView);
          }
          if (iValue) {
            this.appendChild(iValue);
            iValue.addObserver('isVisible', this, this.handleAxisOrLegendLayoutChange);
          }
          this._functionEditorView = iValue;
        }
        return this._functionEditorView;
      }.property(),

      _plottedValueEditorView: null,
      plottedValueEditorView: function (iKey, iValue) {
        if (iValue !== undefined) {
          if (this._plottedValueEditorView) {
            this.removeChild(this._plottedValueEditorView);
          }
          if (iValue) {
            this.appendChild(iValue);
            iValue.addObserver('isVisible', this, this.handleAxisOrLegendLayoutChange);
          }
          this._plottedValueEditorView = iValue;
        }
        return this._plottedValueEditorView;
      }.property(),

      /**
       * Returns the first plotView in _plotViews, if any. When used to set,
       * wipes out the current array and replaces it with a new array
       * containing just iValue
       *
       * @param iKey
       * @param iValue
       * @return {DG.PlotView}
       */
      plotView: function (iKey, iValue) {
        if (!SC.none(iValue)) {
          this._plotViews.forEach(function (iPlotView) {
            iPlotView.destroy();
          });
          this._plotViews[0] = iValue;
          this._plotViews.length = 1;
        }
        return (this._plotViews.length < 1) ? null : this._plotViews[0];
      }.property(),

      _plotViews: null,
      _drawPlotsInvocations: 0, // Used to limit redrawing of plots to what is necessary
      _displayDidChangeInvocationsOfDrawPlots: 0, // Another attempt to limit redrawing

      /**
       * This array of plot views is the one that is the only such if the graph is not split.
       * @property [{DG.PlotView}]
       */
      plotViews: function () {
        return this._plotViews;
      }.property(),

      /**
       * This 3-dim array of plot views is parallel to the array of plot models owned by my model.
       * @property [[[{DG.PlotView}]]]
       */
      splitPlotViewArray: null,

      /**
       * If not already present, adds the given plotView to my array.
       * We have to put the new plotView in the same position in the array that the
       * new plot is in the array of plots my model holds onto.
       * @param iPlotView
       */
      addPlotView: function (iPlotView) {
        if (!this._plotViews.contains(iPlotView)) {
          var tNewPlot = iPlotView.get('model'),
              tPlots = this.getPath('model.plots'),
              tIndexOfNewPlot = this._plotViews.length;
          tPlots.forEach(function (iPlot, iPlotIndex) {
            if (iPlot === tNewPlot)
              tIndexOfNewPlot = iPlotIndex;
          });
          this._plotViews.splice(tIndexOfNewPlot, 0, iPlotView);
          iPlotView.setIfChanged('paperSource', this.get('plotBackgroundView'));
          this._plotViews.forEach( function( _plotView, iIndex) {
            _plotView.setIfChanged('plotIndex', iIndex);
            _plotView.setIfChanged('numPlots', tPlots.length);
          });
          iPlotView.set('isFirstPlot', tIndexOfNewPlot === 0);  // Important to do this _after_ plotIndex is set
        }
      },

      plotDisplayDidChange: function () {
        this._displayDidChangeInvocationsOfDrawPlots++;
        this.invokeOnceLater(function () {
          this._displayDidChangeInvocationsOfDrawPlots--;
          if (this._displayDidChangeInvocationsOfDrawPlots === 0) {
            this.drawPlots();
          }
        });
      },

      addPlotViewObserver: function (iPlotView) {
        if( !iPlotView.hasObserverFor('plotDisplayDidChange', this, this.plotDisplayDidChange))
          iPlotView.addObserver('plotDisplayDidChange', this, this.plotDisplayDidChange);
      },

      removePlotViewObserver: function (iPlotView) {
        iPlotView.removeObserver('plotDisplayDidChange', this, this.plotDisplayDidChange);
      },

      /**
       * Bottleneck for configuring a plotView
       * @param iPlotView
       * @param iPlotModel
       * @param iCurrentPoints
       */
      setPlotViewProperties: function (iPlotView, iPlotModel, iYAxisKey, iCurrentPoints) {
        var tAxisModelWasChanged = false;

        var installAxisView = function (iAxisViewDescription) {
          var tNewViewClass = iAxisViewDescription.axisClass,
              tPrefix = iAxisViewDescription.axisKey;
          if (!SC.none(tNewViewClass)) {
            var tOldView = this.get(tPrefix + 'AxisView');
            if (tOldView.constructor === tNewViewClass)
              return; // Already done

            var tNewModelClass = DG.PlotUtilities.mapAxisViewClassToAxisModelClass(tNewViewClass),
                tExistingAxisModel = this.getPath('model.' + tPrefix + 'Axis'),
                tExistingAxisModelClass = tExistingAxisModel && tExistingAxisModel.constructor,
                tOrientation = tOldView.get('orientation'),
                tPaperSource = iAxisViewDescription.axisKey === 'x' ?
                    this.get('bottomAxisLabelView') : this.get('leftAxisLabelView'),
                tNewAxisModel = (tExistingAxisModelClass === tNewModelClass) ? tExistingAxisModel :
                    tNewModelClass.create(iAxisViewDescription.axisModelProperties || {}, {
                      dataConfiguration: this.getPath('model.dataConfiguration')
                    }),
                tNewView = tNewViewClass.create({
                  orientation: tOrientation,
                  model: tNewAxisModel,
                  paperSourceForLabel: tPaperSource
                });
            this.removeChild(tOldView);
            this.appendChild(tNewView);
            this.set(tPrefix + 'AxisView', tNewView);
            this.setPath('plotBackgroundView.' + tPrefix + 'AxisView', tNewView);
            this.setPath('plotView.' + tPrefix + 'AxisView', tNewView);
            this.setPath('controller.' + tPrefix + 'AxisView', tNewView);
            tOldView.destroy();
            if (tExistingAxisModelClass !== tNewModelClass) {
              tNewAxisModel.set('attributeDescription',
                  this.getPath('model.dataConfiguration.' + tPrefix + 'AttributeDescription'));
              this.setPath('model.' + tPrefix + 'Axis', tNewAxisModel);
              this.setPath('model.plot.' + tPrefix + 'Axis', tNewAxisModel);
              tAxisModelWasChanged = true;
            }
          }
        }.bind(this);

        iYAxisKey = iYAxisKey || 'yAxisView';
        iPlotView.beginPropertyChanges();
        iPlotView.setIfChanged('paperSource', this.get('plotBackgroundView'));
        iPlotView.setIfChanged('model', iPlotModel);
        iPlotView.setIfChanged('parentView', this);
        iPlotView.setIfChanged('xAxisView', this.get('xAxisView'));
        iPlotView.setIfChanged('yAxisView', this.get(iYAxisKey));
        // special requirements set up here, with possible return of description of an axis to be added
        iPlotView.getAxisViewDescriptions().forEach(installAxisView);
        if (tAxisModelWasChanged && iPlotModel.rescaleAxesFromData)
          iPlotModel.rescaleAxesFromData(true /* allow scale shrinkage */,
              true /* animate points */);
        iPlotView.setupAxes();
        if (!SC.none(iCurrentPoints))
          iPlotView.set('transferredElementCoordinates', iCurrentPoints);
        iPlotView.endPropertyChanges();

        this.addPlotViewObserver(iPlotView);
      },

      init: function () {
        var this_ = this;

        this.currTime = 0; // For measuring time spent

        function getAxisViewClass(iAxis, iAttributeType) {
          switch (iAxis.constructor) {
            case DG.AxisModel:
              return DG.AxisView;
            case DG.CellLinearAxisModel:
              return (iAttributeType === 'qualitative') ? DG.QualCellLinearAxisView : DG.CellLinearAxisView;
            case DG.FormulaAxisModel:
              return DG.FormulaAxisView;
            case DG.CellAxisModel:
              return DG.CellAxisView;
            case DG.CountAxisModel:
              return DG.CountAxisView;
            case DG.BinnedAxisModel:
              return DG.BinnedAxisView;
          }
          return null;
        }

        function initPlotViewArrays() {
          this_._plotViews = [];
          this_.splitPlotViewArray = [[this_._plotViews]];
          this_.plotBackgroundViewArray = [[this_.plotBackgroundView]];
        }

        var tXAxis = this.getPath('model.xAxis'),
            tXAxisAttributeType = this.getPath('model.dataConfiguration.xAttributeDescription.attribute.type'),
            tYAxis = this.getPath('model.yAxis'),
            tYAxisAttributeType = this.getPath('model.dataConfiguration.yAttributeDescription.attribute.type'),
            tY2Axis = this.getPath('model.y2Axis'),
            tDataConfiguration = this.getPath('model.dataConfiguration'),
            tBottomAxisLabelView = DG.AxisLabelView.create({
              orientation: DG.GraphTypes.EOrientation.kHorizontal,
              plottedAttribute: tXAxis.get('firstAttribute'),
              dataConfiguration: tDataConfiguration
            }),
            tLeftAxisLabelView = DG.AxisLabelView.create({orientation: DG.GraphTypes.EOrientation.kVertical,
              plottedAttribute: tYAxis.get('firstAttribute'),
              dataConfiguration: tDataConfiguration}),
            tXAxisView = getAxisViewClass(tXAxis, tXAxisAttributeType).create({
              orientation: DG.GraphTypes.EOrientation.kHorizontal, paperSourceForLabel: tBottomAxisLabelView
            }),
            tYAxisView = getAxisViewClass(tYAxis, tYAxisAttributeType).create({
              orientation: DG.GraphTypes.EOrientation.kVertical, paperSourceForLabel: tLeftAxisLabelView
            }),
            tY2AxisView = getAxisViewClass(tY2Axis).create({orientation: DG.GraphTypes.EOrientation.kVertical2}),
            tTopAxis = this.getPath('model.topAxis'),
            tTopAxisView = getAxisViewClass(tTopAxis).create({orientation: DG.GraphTypes.EOrientation.kTop, centering: 'true'}),
            tRightAxis = this.getPath('model.rightAxis'),
            tRightAxisView = getAxisViewClass(tRightAxis).create({orientation: DG.GraphTypes.EOrientation.kRight, centering: 'true'}),
            tBackgroundView = DG.PlotBackgroundView.create({
              xAxisView: tXAxisView, yAxisView: tYAxisView,
              graphModel: this.get('model'),
              rowIndex: 0,
              colIndex: 0
            }),
            tSelectedInfoView = DG.SelectedInfoView.create({ graphModel: this.get('model')});

        arguments.callee.base.apply(this,arguments);

        this.set('leftEdgeBackground', SC.View.create({classNames: 'dg-axis-view'.w()}));
        this.appendChild(this.get('leftEdgeBackground'));
        this.set('rightEdgeBackground', SC.View.create({classNames: 'dg-axis-view'.w()}));
        this.appendChild(this.get('rightEdgeBackground'));
        this.appendChild(tBottomAxisLabelView);
        this.set('bottomAxisLabelView', tBottomAxisLabelView);
        this.appendChild(tLeftAxisLabelView);
        this.set('leftAxisLabelView', tLeftAxisLabelView);


        this.set('plotBackgroundView', tBackgroundView);
        initPlotViewArrays();

        this.set('xAxisView', tXAxisView);
        this.appendChild(tXAxisView);
        this.set('yAxisView', tYAxisView);
        this.appendChild(tYAxisView);

        // y2AxisView must be 'under' plotBackgroundView for dragging to work properly when there is no
        // attribute on y2 axis.
        this.set('y2AxisView', tY2AxisView);
        tY2AxisView.set('xAttributeDescription', this.getPath('model.xAxis.attributeDescription'));
        tY2AxisView.set('otherYAttributeDescription', this.getPath('model.yAxis.attributeDescription'));
        tYAxisView.set('otherYAttributeDescription', this.getPath('model.y2Axis.attributeDescription'));

        this.set('topAxisView', tTopAxisView);
        this.appendChild(tTopAxisView);
        this.set('rightAxisView', tRightAxisView);
        this.appendChild(tRightAxisView);

        this.appendChild(tBackgroundView);

        this.legendView = DG.LegendView.create({model: this.getPath('model.legend')});
        this.appendChild(this.legendView);

        this.createMultiTarget();

        if (this.getPath('model.numberToggle')) {
          var isNumberToggleEnabled = this.getPath('model.numberToggle.isEnabled'),
              tNumberToggleView = DG.NumberToggleView.create({
                model: this.getPath('model.numberToggle'),
                isVisible: isNumberToggleEnabled
              });
          this.set('numberToggleView', tNumberToggleView);
          this.appendChild(tNumberToggleView);
        }

        this.set('measuresForSelectedInfoView', tSelectedInfoView);
        this.appendChild( tSelectedInfoView);

        tXAxisView.set('model', tXAxis);
        tYAxisView.set('model', tYAxis);

        tY2AxisView.set('model', tY2Axis);

        tTopAxisView.set('model', tTopAxis);
        tRightAxisView.set('model', tRightAxis);

        this.assignPlotViewToEachPlot();

        this.appendChild(tY2AxisView); // So it will be on top and drag-hilite will show over plot
        tY2AxisView.set('isVisible', tY2AxisView.get('model').constructor !== DG.AxisModel);
        tTopAxisView.set('isVisible', this.getPath('model.numSplitColumns') > 1);
        tRightAxisView.set('isVisible', this.getPath('model.numSplitRows') > 1);

        // If we're split, now is the time to initialize arrays
        this.handleSplitAttributeChange();
      },

      destroy: function () {
        var tPlotViews = this.get('plotViews'),
            tModel = this.get('model');
        arguments.callee.base.apply(this,arguments);
        // Plotviews are not actually subviews so sc_super doesn't destroy them
        tPlotViews.forEach(function (iPlotView) {
          iPlotView.destroy();
        });
        tModel.destroy(); // so that it can unlink observers
      },

      /**
       * Override to deal with removing functionEditorView & plottedValueEditorView
       * @param iChildView {SC.View}
       */
      removeChild: function (iChildView) {
        if (!iChildView.isDescendantOf(this))
          return; // In a splitting scenario multiple plot views can add editor views.
                  // Each time, pre-existing editor is removed.
        if (iChildView && iChildView === this._functionEditorView) {
          this._functionEditorView.removeObserver('isVisible', this, this.handleAxisOrLegendLayoutChange);
          this._functionEditorView = null;
        }
        if (iChildView && iChildView === this._plottedValueEditorView) {
          this._plottedValueEditorView.removeObserver('isVisible', this, this.handleAxisOrLegendLayoutChange);
          this._plottedValueEditorView = null;
        }

        arguments.callee.base.apply(this,arguments);
      },

      mouseDown: function () {
        DG.globalEditorLock.commitCurrentEdit();
        return false;
      },

      /**
       * Signature of iFunc is <DG.PlotView, iRow, iCol, iIndex>
       * @param iFunc {Function}
       */
      forEachPlotViewDo: function (iFunc) {
        if (this.getPath('model.isSplit')) {
          this.get('splitPlotViewArray').forEach(function (iColArray, iRowIndex) {
            iColArray.forEach(function (iPlotViewArray, iColIndex) {
              iPlotViewArray.forEach(function (iPlotView, iIndex) {
                iFunc(iPlotView, iRowIndex, iColIndex, iIndex);
              });
            });
          });
        }
        else {
          var tPlotViews = this.get('plotViews');
          tPlotViews.forEach(function (iPlotView, iIndex) {
            iFunc(iPlotView, 0, 0, iIndex);
          });
        }
      },

      /**
       * We use this during init and during an undo restore (which doesn't go through init) to make sure each
       * plot has a corresponding plotview.
       */
      assignPlotViewToEachPlot: function() {
        // Make a copy of the array of plotViews so we can see if any are left over that should be removed
        var tPlotViewsCopy = this._plotViews.map(function(iPlotView) { return iPlotView;});
        this.getPath('model.plots').forEach(function (iPlotModel) {
          var tFoundPlotView;
          this.forEachPlotViewDo( function( iPlotView) {
            if( !tFoundPlotView && iPlotView.get('model') === iPlotModel)
              tFoundPlotView = iPlotView;
          });
          if( !tFoundPlotView) {
            var tPlotView = this.mapPlotModelToPlotView(iPlotModel).create({model: iPlotModel});
            this.addPlotView(tPlotView);
            this.setPlotViewProperties(tPlotView, iPlotModel,
                iPlotModel.get('verticalAxisIsY2') ? 'y2AxisView' : 'yAxisView');
          }
          else {
            var tIndex = tPlotViewsCopy.indexOf( tFoundPlotView);
            tPlotViewsCopy.splice( tIndex, 1);
          }
        }.bind(this));
        // Destroy any remaining plotViews of the originals
        tPlotViewsCopy.forEach( function( iPlotView) {
          iPlotView.destroy();
        });
      },

      /**
       * Draw my plot views
       */
      drawPlots: function (iChangedProperty) {
        if (this._isConfigurationInProgress)
          return; // Not a good time to draw
        var tNumPlots = this.get('plotViews').length;
          this.forEachPlotViewDo(function (iPlotView, iRow, iCol, iIndex) {
            if (iPlotView.readyToDraw())
              iPlotView.doDraw(iIndex, tNumPlots, iChangedProperty);
          });
      },

      pointsDidChange: function (iModel, iProperty) {
        this.drawPlots(iProperty);
        this.get('legendView').displayDidChange();
        this.get('yAxisView').displayDidChange();
      }.observes('model.pointColor', 'model.strokeColor', 'model.pointSizeMultiplier',
          'model.transparency', 'model.strokeTransparency', 'model.strokeSameAsFill'),

      categoriesDidChange: function (iAxisView, iProperty) {
        if (this.getPath('model.aboutToChangeConfiguration') || !this.get('plotViews'))
          return; // So we don't attempt to draw during init or in the midst of a configuration change

/*
        var tOrientation = iAxisView.get('orientation');
        if( tOrientation === 'top' || tOrientation === 'right')
          this.get('model').splitCategoriesDidChange();
*/

        this.get('plotViews').forEach(function (iPlotView, iIndex) {
          iPlotView.categoriesDidChange();
        });

        var tLegendView = this.get('legendView');
        this.drawPlots();
        if (tLegendView)
          tLegendView.displayDidChange();
        // Note: Asterisks below are necessary in case axis view gets swapped out
      }.observes('*xAxisView.categoriesDragged', '*yAxisView.categoriesDragged',
          '*topAxisView.categoriesDragged', '*rightAxisView.categoriesDragged'),

      selectionOrDisplayOnlySelectedDidChange: function() {
        // Delay updating the messages until after the selection has been updated
        this.invokeLater( function() {
          var tMsgs = [];
          if(this.getPath('model.dataConfiguration.displayOnlySelected') &&
              this.getPath('model.dataConfiguration.selection').length === 0) {
            tMsgs = [0, 1,2,3,4,5].map( function(i) {
              return ('DG.PlotBackgroundView.msg' + i).loc();
            });
          }
          this.get('plotBackgroundViewArray').forEach(function( iBackgroundViewSubArray) {
            iBackgroundViewSubArray[0].setIfChanged('messages', tMsgs);
          });
        }, 200);
      }.observes('model.dataConfiguration.displayOnlySelected',
          'model.dataConfiguration.selection'),

      prepareToSelectPoints: function () {
        this.forEachPlotViewDo(function (iPlotView) {
          iPlotView.hideDataTip();
          iPlotView.preparePointSelection();
        });
      },
      completeSelection: function () {
        this.get('plotViews').forEach(function (iPlotView) {
          iPlotView.cleanUpPointSelection();
        });
      },

      /**
       * Give each plotView a chance
       * Note that it would be more natural for the graph view to tell the graph model to select the cases than
       * to do it here directly with the data context.
       * Ignore the cases found in iLast
       * @param iRect
       * @param iBaseSelection
       * @param iLast {{x:number,y:number,width:number,height:number}}
       * iRowIndex {{Number}} Index into splitPlotViewArray
       * iColIndex {{Number}} Index into splitPlotViewArray
       */
      selectPointsInRect: function (iRect, iBaseSelection, iLast, iRowIndex, iColIndex) {
        iBaseSelection = iBaseSelection || [];
        var tDataContext = this.getPath('model.dataContext');
        var tCollection = this.getPath('model.collectionClient');
        var tSelectChange = {
          operation: 'selectCases',
          collection: tCollection,
          cases: iBaseSelection,
          select: true,
          extend: true
        };
        var tDeselectChange = {
          operation: 'selectCases',
          collection: tCollection,
          cases: [],
          select: false,
          extend: true
        };

        if (SC.none(tDataContext))
          return;

        this.get('splitPlotViewArray')[iRowIndex][iColIndex].forEach(function (iPlotView) {
          var tPlotSelection = iPlotView.getCasesForDelta(iRect, iLast);
          tSelectChange.cases = tSelectChange.cases.concat(tPlotSelection);
          var tPlotDeselection = iPlotView.getCasesForDelta(iLast, iRect);
          tDeselectChange.cases = tDeselectChange.cases.concat(tPlotDeselection);
        });

        if (tSelectChange.cases.length !== 0) {
          tDataContext.applyChange(tSelectChange);
        }
        if (tDeselectChange.cases.length !== 0) {
          tDataContext.applyChange(tDeselectChange);
        }
      },

      /**
       * Pass to first plotview
       * @param iEvent
       */
      handleBackgroundClick: function (iEvent) {
        this.get('plotView').handleBackgroundClick(iEvent);
      },

      /**
       * Pass to first plotview
       * @param iEvent
       */
      handleBackgroundDblClick: function (iEvent) {
        this.get('plotView').handleBackgroundDblClick(iEvent);
      },

      measuresForSelectedInfoVisibilityDidChange: function() {
        this.renderLayout(this.renderContext(this.get('tagName')));
      }.observes('measuresForSelectedInfoView.isVisible'),

      /**
       Set the layout (view position) for our three subviews.
       @param {SC.RenderContext} the render context
       @param {Boolean} Is this the first time the rendering is happening?  Set to true if any of the 3 view are new.
       @returns {void}
       */
      renderLayout: function (context, firstTime) {
        // Prevent recursive calls
        if (this._isRenderLayoutInProgress)
          return;
        this._isRenderLayoutInProgress = true;

        arguments.callee.base.apply(this,arguments);

        function layoutUnsplitPlot() {
          tTopAxisView.adjust({width: 0, height: 0});
          tRightAxisView.adjust({width: 0, height: 0});
          if (firstTime) {
            // set or reset all layout parameters (initializes all parameters)
            tXAxisView.set('layout', {
              left: tYWidth, right: tSpaceForY2,
              bottom: tLegendHeight + tHeightForBottomLabel, height: tXAxisHeight
            });
            tYAxisView.set('layout', {
              left: tWidthForLeftLabel,
              top: tTopSpace,
              bottom: tLegendHeight + tXHeight, width: tYAxisWidth
            });
            tY2AxisView.set('layout', {
              right: 0,
              top: tTopSpace,
              bottom: tLegendHeight + tXHeight,
              width: tY2DesiredWidth
            });
            tPlotBackground.set('layout', {
              left: tYWidth,
              right: tSpaceForY2,
              top: tTopSpace,
              bottom: tXHeight + tLegendHeight
            });
            this_.makeSubviewFrontmost(tY2AxisView);
          }
          else {
            // adjust() method avoids triggering observers if layout parameter is already at correct value.
            var tCurrXHeight = tXAxisView.get('layout').height;
            tXAxisView.adjust({
              left: tYWidth, right: tSpaceForY2, bottom: tLegendHeight + tHeightForBottomLabel,
              height: tXAxisHeight
            });
            if (tCurrXHeight !== tXAxisHeight)
              tXAxisView.notifyPropertyChange('drawHeight');

            var tCurrYWidth = tYAxisView.get('layout').width;
            tYAxisView.adjust({
              bottom: tXHeight + tLegendHeight, width: tYAxisWidth,
              top: tTopSpace
            });
            if (tCurrYWidth !== tYAxisWidth)
              tYAxisView.notifyPropertyChange('drawWidth');

            tY2AxisView.adjust({
              bottom: tLegendHeight + tXHeight, width: tY2DesiredWidth,
              top: tTopSpace
            });
            if (!tHasY2Attribute) {
              tY2AxisView.set('isVisible', false);
            }
            tPlotBackground.adjust({
              left: tYWidth,
              right: tSpaceForY2,
              top: tTopSpace,
              bottom: tXHeight + tLegendHeight
            });
          }
        }

        function layoutSplitPlots( iTopHeight, iRightSpace) {
          var tXAxisViewArray = this_.get('xAxisViewArray'),
              tYAxisViewArray = this_.get('yAxisViewArray'),
              tY2AxisViewArray = this_.get('y2AxisViewArray'),
              tPlotBackgroundViewArray = this_.get('plotBackgroundViewArray'),
              tNumRows = tPlotBackgroundViewArray.length,
              tNumColumns = tPlotBackgroundViewArray[0].length,
              tFrame = this_.get('frame'),
              tRowHeight = (tFrame.height - tXHeight - tLegendHeight - tTopSpace - iTopHeight) / tNumRows,
              tColWidth = (tFrame.width - tYWidth - tSpaceForY2 - iRightSpace) / tNumColumns,
              tRowIndex, tColIndex;
          if (firstTime) {
            tTopAxisView.set('layout', {
              left: tYWidth, top: tTopSpace,
              right: iRightSpace, height: iTopHeight
            });
            tRightAxisView.set('layout', {
              width: iRightSpace, top: tTopSpace + iTopHeight,
              right: 0, bottom: tLegendHeight + tXHeight
            });
          }
          else {
            tTopAxisView.adjust({top: tTopSpace, left: tYWidth, right: iRightSpace, height: iTopHeight});
            tRightAxisView.adjust({
              width: iRightSpace, top: tTopSpace + iTopHeight,
              bottom: tLegendHeight + tXHeight
            });
          }
          for (tRowIndex = 0; tRowIndex < tNumRows; tRowIndex++) {
            var tThisYAxisView = tYAxisViewArray[tRowIndex],
                tTop = tTopSpace + iTopHeight + (tNumRows - tRowIndex - 1) * tRowHeight;
            if (tThisYAxisView) {
              if (firstTime) {
                tThisYAxisView.set('layout', {
                  left: tWidthForLeftLabel, top: tTop, height: tRowHeight, width: tYAxisWidth
                });
                tY2AxisViewArray[tRowIndex].set('layout', {
                  right: iRightSpace, top: tTop, height: tRowHeight, width: tY2DesiredWidth
                });
                if (!tHasY2Attribute) {
                  tY2AxisViewArray[tRowIndex].set('isVisible', false);
                }
              }
              else {
                var tCurrYWidth = tThisYAxisView.get('layout').width;
                tThisYAxisView.adjust({left: tWidthForLeftLabel, height: tRowHeight,
                  width: tYAxisWidth, top: tTop});
                if (tCurrYWidth !== tYAxisWidth && tRowIndex === 0)
                  tThisYAxisView.notifyPropertyChange('drawWidth');
                tY2AxisViewArray[tRowIndex].adjust({
                  right: iRightSpace, top: tTop,
                  height: tRowHeight, width: tY2DesiredWidth
                });
              }
              for (tColIndex = 0; tColIndex < tNumColumns; tColIndex++) {
                var tBackgroundView = tPlotBackgroundViewArray[tRowIndex][tColIndex],
                    tLeft = tYWidth + tColIndex * tColWidth;

                if (tRowIndex === 0) {
                  var tThisXAxisView = tXAxisViewArray[tColIndex],
                      tCurrXHeight;
                  if (tThisXAxisView) {
                    if (firstTime) {
                      tThisXAxisView.set('layout',
                          {
                            left: tLeft, width: tColWidth + 1, bottom: tLegendHeight + tHeightForBottomLabel,
                            height: tXAxisHeight
                          });
                    }
                    else {
                      tCurrXHeight = tThisXAxisView.get('layout').height;
                      tThisXAxisView.adjust({
                        left: tLeft, width: tColWidth + 1,
                        bottom: tLegendHeight + tHeightForBottomLabel, height: tXAxisHeight,
                        top: null, right: null
                      });
                      if (tCurrXHeight !== tXAxisHeight && tRowIndex === 0 && tColIndex === 0)
                        tThisXAxisView.notifyPropertyChange('drawHeight');
                    }
                  }
                }
                if (tBackgroundView) {
                  if (firstTime)
                    tBackgroundView.set('layout', {
                      left: tLeft,
                      top: tTop,
                      width: tColWidth + 1,
                      height: tRowHeight + 1
                    });
                  else
                    tBackgroundView.adjust({left: tLeft, top: tTop, width: tColWidth + 1, height: tRowHeight + 1});
                }
              }
            }
          }


        }

        var this_ = this,
            tLeftEdgeBackgroundView = this.get('leftEdgeBackground'),
            tRightEdgeBackgroundView = this.get('rightEdgeBackground'),
            tBottomAxisLabelView = this.get('bottomAxisLabelView'),
            tHeightForBottomLabel = tBottomAxisLabelView ? tBottomAxisLabelView.get('desiredExtent') : 0,
            tLeftAxisLabelView = this.get('leftAxisLabelView'),
            tWidthForLeftLabel = tLeftAxisLabelView ? tLeftAxisLabelView.get('desiredExtent') : 0,
            tXAxisView = this.get('xAxisView'),
            tYAxisView = this.get('yAxisView'),
            tY2AxisView = this.get('y2AxisView'),
            tTopAxisView = this.get('topAxisView'),
            tRightAxisView = this.get('rightAxisView'),
            tY2AttributeID = this.getPath('model.dataConfiguration.y2AttributeID'),
            tHasY2Attribute = tY2AttributeID && (tY2AttributeID !== DG.Analysis.kNullAttribute),
            tPlotBackground = this.get('plotBackgroundView'),
            tPlotViews = this.get('plotViews'),
            tLegendView = this.get('legendView'),
            tNumberToggleView = this.get('numberToggleView'),
            tSelectedInfoView = this.get('measuresForSelectedInfoView'),
            tFunctionView = this.get('functionEditorView'),
            tPlottedValueView = this.get('plottedValueEditorView'),
            tShowNumberToggle = tNumberToggleView && tNumberToggleView.shouldShow(),
            tXAxisHeight = !tXAxisView ? 0 : Math.min(tXAxisView.get('desiredExtent'), this.get('frame').height / 3),
            tXHeight = tXAxisHeight + tHeightForBottomLabel,
            tYAxisWidth = !tYAxisView ? 0 : Math.min(tYAxisView.get('desiredExtent'), this.get('frame').width / 3),
            tYWidth = tYAxisWidth + tWidthForLeftLabel,
            tSpaceForY2 = (!tY2AxisView || !tHasY2Attribute) ? 0 : tY2AxisView.get('desiredExtent'),
            tY2DesiredWidth = !tY2AxisView ? 0 : tY2AxisView.get('desiredExtent'),
            tLegendHeight = !tLegendView ? 0 : tLegendView.get('desiredExtent'),
            tNumberToggleHeight = tShowNumberToggle ? tNumberToggleView.get('desiredExtent') : 0,
            tSelectedInfoHeight = tSelectedInfoView ? tSelectedInfoView.get('desiredExtent') : 0,
            tFunctionViewHeight = (tFunctionView && tFunctionView.get('isVisible')) ?
                tFunctionView.get('desiredExtent') : 0,
            tPlottedValueViewHeight = (tPlottedValueView && tPlottedValueView.get('isVisible')) ?
                tPlottedValueView.get('desiredExtent') : 0,
            tTopSpace = tNumberToggleHeight + tFunctionViewHeight + tPlottedValueViewHeight + tSelectedInfoHeight;
        if (!SC.none(tXAxisView) && !SC.none(tYAxisView) &&
            !SC.none(tPlotViews) && (tPlotViews.length > 0)) {
          if( tSelectedInfoView)
            tSelectedInfoView.adjust( { height: tSelectedInfoHeight, top: tNumberToggleHeight});
          tTopAxisView.set('isVisible', this_.getPath('model.numSplitColumns') > 1);
          tRightAxisView.set('isVisible', this_.getPath('model.numSplitRows') > 1);
          var tTopHeight = tTopAxisView.get('isVisible') ? Math.min( tTopAxisView.get('desiredExtent'), this.get('frame').height / 3) : 0,
              tRightSpace = tRightAxisView.get('isVisible') ? Math.min( tRightAxisView.get('desiredExtent'), this.get('frame').width / 3) : 0;
          tLeftEdgeBackgroundView.set('layout', {left: 0, bottom: 0, top: 0, width: tYWidth});
          tRightEdgeBackgroundView.set('layout', {right: 0, bottom: 0, top: 0, width: tRightSpace + tSpaceForY2});

          tBottomAxisLabelView.set('layout', {
            bottom: tLegendHeight, left: tYWidth, right: tSpaceForY2 + tRightSpace,
            height: tHeightForBottomLabel
          });
          tLeftAxisLabelView.set('layout', {
            top: tTopSpace,
            bottom: tHeightForBottomLabel + tLegendHeight, left: 0, width: tWidthForLeftLabel
          });
          if (this.getPath('model.isSplit'))
            layoutSplitPlots( tTopHeight, tRightSpace);
          else
            layoutUnsplitPlot();
          if (tFunctionView)
            tFunctionView.adjust('top', tNumberToggleHeight + tSelectedInfoHeight);
          if (tPlottedValueView)
            tPlottedValueView.adjust('top', tNumberToggleHeight + tFunctionViewHeight + tSelectedInfoHeight);
          if (firstTime) {
            tLegendView.set('layout', {bottom: 0, height: tLegendHeight});
          }
          else {
            tLegendView.adjust('height', tLegendHeight);
            if (tNumberToggleView)
              tNumberToggleView.adjust({height: tNumberToggleHeight});
            // NumberToggleView visibility is handled by binding
          }
        }
        this._isRenderLayoutInProgress = false;
        this._drawPlotsInvocations++;
        this.invokeOnceLater(function () {
          this._drawPlotsInvocations--;
          if (this._drawPlotsInvocations === 0) {
            this.drawPlots();
          }
        }.bind(this));
      },

      viewDidResize: function () {
        arguments.callee.base.apply(this,arguments);
        this.renderLayout(this.renderContext(this.get('tagName')));
      },

      /**
       * Better if this were in SC.View, but it's fraught with problems, so we specialize it here.
       * @param iChildView
       */
      makeSubviewFrontmost: function (iChildView) {
        if (iChildView && this.get('childViews').indexOf(iChildView) >= 0) {
          this.removeChild(iChildView);
          this.appendChild(iChildView);
        }
      },

      /**
       * Private property to prevent recursive execution of renderLayout. Seems most important in Firefox.
       */
      _isRenderLayoutInProgress: false,

      /**
       * Private property to prevent recursive execution of renderLayout. Seems most important in Firefox.
       */
      _isConfigurationInProgress: false,

      /**
       When a model axis changes, we need to respond by changing its corresponding view.
       */
      handleAxisModelChange: function () {
        var this_ = this,
            tInitLayout = false,
            tPlotBackgroundView = this.get('plotBackgroundView');

        function handleOneAxis(iAxisKey, iAxisViewKey) {
          var tModel = this_.getPath(iAxisKey),
              tModelClass = tModel && tModel.constructor,
              tView = this_.get(iAxisViewKey),
              tViewClass = tView && tView.constructor,
              tNewViewClass, tNewView,
              tPlotView = this_.get('plotView'),
              tLabelView, tPlace, tAttr, tAttrType = '',
              tSetup;
          switch (iAxisViewKey) {
            case 'xAxisView':
              tLabelView = this_.get('bottomAxisLabelView');
              tSetup = {orientation: DG.GraphTypes.EOrientation.kHorizontal, paperSourceForLabel: tLabelView};
              tPlace = DG.GraphTypes.EPlace.eX;
              break;
            case 'yAxisView':
              tLabelView = this_.get('leftAxisLabelView');
              tSetup = {orientation: DG.GraphTypes.EOrientation.kVertical, paperSourceForLabel: tLabelView};
              tPlace = DG.GraphTypes.EPlace.eY;
              break;
            case 'y2AxisView':
              tSetup = {orientation: DG.GraphTypes.EOrientation.kVertical2};
              tPlace = DG.GraphTypes.EPlace.eY2;
              break;
          }
          if (tLabelView && tModel) {
            tLabelView.set('plottedAttribute', tModel.get('firstAttribute'));
          }
          tSetup.layout = {left: 0, top: 0, width: 0, height: 0};
          if (this_.getPath('model.dataConfiguration')) {
            tAttr = this_.getPath('model.dataConfiguration').attributesByPlace[tPlace][0].get('attribute');
            if (tAttr !== DG.Analysis.kNullAttribute) {
              tAttrType = tAttr.get('type');
            }
          }
          switch (tModelClass) {
            case DG.AxisModel:
              tNewViewClass = DG.AxisView;
              break;
            case DG.CellAxisModel:
              tNewViewClass = DG.CellAxisView;
              break;
            case DG.CellLinearAxisModel:
              // todo: It's a lot work to get to make this one decision. We could simplify things with a QualCellLinearAxis
              // model that would fall into the existing pattern for choosing the view class.
              tNewViewClass = (tAttrType === 'qualitative') ?
                  DG.QualCellLinearAxisView : DG.CellLinearAxisView;
              break;
            case DG.FormulaAxisModel:
              tNewViewClass = DG.FormulaAxisView;
              break;
            case DG.CountAxisModel:
              tNewViewClass = DG.CountAxisView;
              break;
            case DG.BinnedAxisModel:
              tNewViewClass = DG.BinnedAxisView;
              break;
            default:
              tNewViewClass = null;
          }
          if (tNewViewClass && (tViewClass !== tNewViewClass)) {
            tNewView = tNewViewClass.create(tSetup);
            // tNewView.adjust({top: 400});
            tNewView.set('model', tModel);
            this_.removeChild(tView);
            this_.appendChild(tNewView);
            this_.set(iAxisViewKey, tNewView);
            tPlotBackgroundView.set(iAxisViewKey, tNewView);
            if (!SC.none(tPlotView)) {
              tPlotView.set(iAxisViewKey, tNewView);
              tPlotView.setupAxes();
            }
            tView.destroy();
            this_.controller.set(iAxisViewKey, tNewView);
            tInitLayout = true; // new view requires a new layout
          }
        }
        this.beginPropertyChanges();
        handleOneAxis('model.xAxis', 'xAxisView');
        handleOneAxis('model.yAxis', 'yAxisView');
        handleOneAxis('model.y2Axis', 'y2AxisView');
        this.setPath('y2AxisView.otherYAttributeDescription', this.getPath('model.yAxis.attributeDescription'));
        this.setPath('y2AxisView.xAttributeDescription', this.getPath('model.xAxis.attributeDescription'));
        this.setPath('yAxisMultiTarget.attributeDescription', this.getPath('model.yAxis.attributeDescription'));
        this.setPath('yAxisMultiTarget.otherAttributeDescription', this.getPath('model.xAxis.attributeDescription'));
        this.renderLayout(this.renderContext(this.get('tagName')), tInitLayout);
        this.endPropertyChanges();
      }.observes('.model.xAxis', '.model.yAxis', '.model.y2Axis'),

      handleLegendModelChange: function () {
        var tLegendModel = this.getPath('model.legend');
        this.setPath('legendView.model', tLegendModel);
      }.observes('.model.legend'),

      /**
       When my plot model changes, we need to respond by changing its corresponding view.
       */
      handlePlotModelChange: function () {
        var tPlot = this.getPath('model.plot'),
            tCurrentView = this.get('plotView'),
            tViewClass = tCurrentView && tCurrentView.constructor,
            tCurrentPoints, tNewViewClass, tNewView,
            tInitLayout = false;

        if( !tCurrentView || tPlot.get('isDestroyed'))  // We get here without a current plotview or plot during close
          return;

        tNewViewClass = this.mapPlotModelToPlotView(tPlot);
        if (tNewViewClass && (tViewClass !== tNewViewClass)) {
          tNewView = tNewViewClass.create();
          tInitLayout = true;
        }
        if (!SC.none(tCurrentView))
          tCurrentPoints = tCurrentView.get('cachedPointCoordinates');

        if (SC.none(tNewView)) {
          // Make sure the current view has all the right properties
          this.setPlotViewProperties(tCurrentView, tPlot, 'yAxisView', tCurrentPoints);
        }
        else {
          this.set('plotView', tNewView); // Destroys tCurrentView
          this.setPlotViewProperties(tNewView, tPlot, 'yAxisView', tCurrentPoints);
          if (tInitLayout) {
            this.renderLayout(this.renderContext(this.get('tagName')), tInitLayout);
          }
        }
      }.observes('.model.plot'),

      /**
       * Our model has experienced a change in attributes that determine the splitting into multiple
       * plots. We make sure we have the necessary axis views and plot views assigned to the correct
       * models.
       */
      handleSplitAttributeChange: function () {
        var this_ = this;

        function configureAxisViewArrays() {

          function configureOneAxisViewArray(iAxisModelArray, ioAxisViewArray) {
            // The zeroth element of the view array is already correctly configured
            var tZerothView = ioAxisViewArray[0],
                tViewClass = tZerothView.constructor,
                tOrientation = tZerothView.get('orientation'),
                tCentering = tZerothView.get('centering'),
                tNumModels = iAxisModelArray.length,
                tIndex;
            for (tIndex = 1; tIndex < tNumModels; tIndex++) {
              var tCurrentView = ioAxisViewArray[tIndex],
                  tNewView;
              if (!tCurrentView || tCurrentView.constructor !== tViewClass) {
                tNewView = tViewClass.create({
                  orientation: tOrientation,
                  centering: tCentering,
                  model: iAxisModelArray[tIndex],
                  suppressLabel: true
                });
                this_.appendChild(tNewView);
                if (tCurrentView) {
                  this_.removeChild(tCurrentView);
                  tCurrentView.destroy();
                }
                ioAxisViewArray[tIndex] = tNewView;
              }
              else {
                tCurrentView.set('model', iAxisModelArray[tIndex]);
              }
            }
            for (tIndex = tNumModels; tIndex < ioAxisViewArray.length; tIndex++) {
              ioAxisViewArray[tIndex].destroy();
            }
            ioAxisViewArray.length = tNumModels;
          }

          configureOneAxisViewArray(this_.getPath('model.xAxisArray'), this_.get('xAxisViewArray'));
          configureOneAxisViewArray(this_.getPath('model.yAxisArray'), this_.get('yAxisViewArray'));
          configureOneAxisViewArray(this_.getPath('model.y2AxisArray'), this_.get('y2AxisViewArray'));
        }

        function configurePlotViewArrays() {
          var tModel = this_.get('model'),
              tPlotViewArray = this_.get('splitPlotViewArray'),
              tPlotBackgroundViewArray = this_.get('plotBackgroundViewArray'),
              tPlotViewClass = tPlotViewArray[0][0][0].constructor;
          tModel.forEachSplitPlotElementDo(function (iPlotModelArray, iRow, iColumn) {
            if (iRow !== 0 || iColumn !== 0) {
              iPlotModelArray.forEach(function (iPlotModel, iIndex) {
                if (!tPlotViewArray[iRow])
                  tPlotViewArray[iRow] = [];
                if (!tPlotViewArray[iRow][iColumn])
                  tPlotViewArray[iRow][iColumn] = [];
                if (!tPlotBackgroundViewArray[iRow])
                  tPlotBackgroundViewArray[iRow] = [];
                var
                    tBackgroundView = tPlotBackgroundViewArray[iRow][iColumn],
                    tCurrentPlotView = tPlotViewArray[iRow][iColumn][iIndex],
                    tNewPlotView;
                if (!tBackgroundView) {
                  tBackgroundView = DG.PlotBackgroundView.create({
                    xAxisView: this_.get('xAxisViewArray')[iColumn],
                    yAxisView: this_.get('yAxisViewArray')[iRow],
                    graphModel: this_.get('model'),
                    darkenBackground: (iRow + iColumn) % 2 !== 0,
                    rowIndex: iRow,
                    colIndex: iColumn
                  });
                  tPlotBackgroundViewArray[iRow][iColumn] = tBackgroundView;
                  this_.invokeLast(function () {
                    // Don't append until after we've established the plot view
                    this_.appendChild(tBackgroundView);
                  });
                }
                else {
                  tBackgroundView.set('xAxisView', this_.get('xAxisViewArray')[iColumn]);
                  tBackgroundView.set('yAxisView', this_.get('yAxisViewArray')[iRow]);
                }
                tBackgroundView.set('rowIndex', iRow);
                tBackgroundView.set('colIndex', iColumn);
                if (!tCurrentPlotView || tCurrentPlotView.constructor !== tPlotViewClass) {
                  var tYAxisViewArrayKey = iPlotModel.get('verticalAxisIsY2') ? 'y2AxisViewArray' : 'yAxisViewArray';
                  tNewPlotView = tPlotViewClass.create({
                    paperSource: tPlotBackgroundViewArray[iRow][iColumn],
                    model: iPlotModel,
                    parentView: this_,
                    xAxisView: this_.get('xAxisViewArray')[iColumn],
                    yAxisView: this_.get(tYAxisViewArrayKey)[iRow]
                  });
                  tPlotViewArray[iRow][iColumn][iIndex] = tNewPlotView;
                  this_.addPlotViewObserver(tNewPlotView);
                  if (tCurrentPlotView) {
                    this_.removePlotViewObserver(tCurrentPlotView);
                    tCurrentPlotView.destroy();
                  }
                }
              });
            }
          });
          this_.notifyPropertyChange('plotViewsReconfigured');
        }

        this._isConfigurationInProgress = true; // Prevent drawing until all this is done
        configureAxisViewArrays();
        configurePlotViewArrays();
        this._isConfigurationInProgress = false;
        this.renderLayout(this.renderContext(this.get('tagName')), false);
        this.invokeLater( function() {
          // This will take place after appendChild of any new background view
          this.forEachPlotViewDo(function( iPlotView) {
            iPlotView.updateSelection();
          });
        }, 10);
      }.observes('.model.splitPlotChange'),

      allModelSplitsWereRemoved: function () {
        var this_ = this,
            tBackgroundViews = this.get('plotBackgroundViewArray');
        // Our controller is observing these plot views that are about to be deleted so we have to
        // give it a chance to remove observers
        this_.notifyPropertyChange('plotViewsWillBeDestroyed');
        this_.forEachPlotViewDo(function (iPlotView, iRow, iColumn, iIndex) {
          if (iRow !== 0 || iColumn !== 0) {
            this_.removePlotViewObserver(iPlotView);
            iPlotView.destroy();
            if (iIndex === 0) {
              var tBackgroundView = tBackgroundViews[iRow][iColumn];
              this_.removeChild(tBackgroundView);
              tBackgroundView.destroy();
              tBackgroundViews[iRow][iColumn] = null;
            }
          }
        });
        tBackgroundViews[0].length = 1;
        tBackgroundViews.length = 1;
        this.get('splitPlotViewArray').length = 1;
        this.get('splitPlotViewArray')[0].length = 1;
      }.observes('.model.removedAllSplitPlotsAndAxes'),

      /**
       * Return the array of plot views for the given row, col
       * @param iRow {Number}
       * @param iCol {Number}
       * @return {[{DG.PlotView}]}
       */
      getPlotViewArray: function (iRow, iCol) {
        return this.get('splitPlotViewArray')[iRow][iCol];
      },

      plotWithoutView: function () {
        var tPlots = this.getPath('model.plots'),
            tPlotViews = this._plotViews,
            tPlotWithoutView;
        tPlots.forEach(function (iPlot) {
          if (!tPlotViews.some(function (iPlotView) {
            return iPlot === iPlotView.get('model');
          })) {
            tPlotWithoutView = iPlot;
          }
        });
        return tPlotWithoutView;
      },

      /**
       * An attribute has been added to the vertical axis. There are now multiple plot models.
       * For now, this only works with scatterplots, so we know we have to construct a
       * ScatterPlotView.
       * Note that we're assuming that if an attribute was just added, it must be the last, and
       * we can bind the new scatterplot view to the last plot.
       */
      handleAttributeAdded: function () {
        var tPlotModel = this.plotWithoutView(),
            tPlotView;
        if (!SC.none(tPlotModel)) {
          tPlotView = DG.ScatterPlotView.create({
            model: tPlotModel,
            paperSource: this.get('plotBackgroundView')  // required during initialization
          });
          this.addPlotView(tPlotView);
          this.renderLayout(this.renderContext(this.get('tagName')), false);
          this.setPlotViewProperties(tPlotView, tPlotModel, 'yAxisView');
        }
      }.observes('model.attributeAdded'),

      /**
       * An attribute has been added to the second vertical axis. There are now multiple plot models.
       * For now, this only works with scatterplots, so we know we have to construct a
       * ScatterPlotView.
       * Note that we're assuming that if an attribute was just added, it must be the last, and
       * we can bind the new scatterplot view to the last plot.
       */
      handleY2AttributeAdded: function () {
        var tPlotModel = this.getPath('model.lastPlot'),
            tPlotView;
        if (!SC.none(tPlotModel)) {
          this.handleAxisModelChange();
          tPlotView = this.get('plotViews').find( function( iPlotView) {
            return iPlotView.get('model') === tPlotModel;
          });
          if( !tPlotView) {
            tPlotView = DG.ScatterPlotView.create({
              model: tPlotModel,
              paperSource: this.get('plotBackgroundView')  // required during initialization
            });
            this.addPlotView(tPlotView);
          }
          this.renderLayout(this.renderContext(this.get('tagName')), false);
          this.setPlotViewProperties(tPlotView, tPlotModel, 'y2AxisView');
          // The y2AxisView needs to know how many attribute descriptions there are on the other y-axis so that
          // it can properly set the color of the label.
          this.get('y2AxisView').set('otherYAttributeDescription', this.getPath('model.yAxis.attributeDescription'));
          this.get('y2AxisView').set('xAttributeDescription', this.getPath('model.xAxis.attributeDescription'));
          this.get('yAxisView').set('otherYAttributeDescription', this.getPath('model.y2Axis.attributeDescription'));
          tPlotView.displayDidChange();
        }
      }.observes('model.y2AttributeAdded'),

      /**
       * An attribute has been removed from the vertical axis. But there is at least one attribute
       * left on that axis. We run through the plotViews to find the one whose model is no longer
       * one of our plots. That one, we destroy.
       */
      handleAttributeRemoved: function () {
        var tPlots = this.getPath('model.plots'),
            tPlotViews = this.get('plotViews'),
            tIndexOfPlotViewToRemove;
        tPlotViews.forEach(function (iPlotView, iIndex) {
          if (tPlots.indexOf(iPlotView.get('model')) < 0) {
            tIndexOfPlotViewToRemove = iIndex;
            iPlotView.removePlottedElements(true /*call 'remove'*/, true /* animate */);
            iPlotView.destroy();
          }
        });
        if( !SC.none( tIndexOfPlotViewToRemove)) {
          // Our plot background view needs to move the array of plotted elements to the end
          this.get('plotBackgroundView').shiftPlottedElementsToEndOfMap(tIndexOfPlotViewToRemove);
          tPlotViews.splice(tIndexOfPlotViewToRemove, 1);
          tPlotViews.forEach(function (iPlotView, iIndex) {
            iPlotView.set('isFirstPlot', iIndex === 0);
          });
        }
      }.observes('model.attributeRemoved'),

      /**
       * Handle a click in an axis label by bringing up the appropriate axis menu.
       * @param {SC.Event} the click event (with clientData supplied by sender)
       * @returns {Boolean} YES indicating that the event has been handled
       */
      axisLabelClick: function (iEvent) {
        var controller = this.get('controller');
        if (controller) {
          controller.setupAttributeMenu(iEvent, iEvent.clientData.axisView, iEvent.clientData.labelIndex);
        }
        return YES;
      },

      /**
       * When our model signals that the configuration is about to change, we give our plot view a chance to
       * cache the positions of elements so they can be used in an animation
       *
       * If the configuration change is finished then we check to make sure that the axis views match the type
       * of the attributes because an attribute may have gone from numeric to qualitative or vice versa.
       */
      configurationIsAboutToChange: function () {
        if (this.getPath('model.aboutToChangeConfiguration')) {
          this.get('plotView').prepareForConfigurationChange();
        }
        else {  // model configuration has finished changing. Take care of view layer.
          this.assignPlotViewToEachPlot();
          this.get('plotView').handleConfigurationChange();
          this.synchAxisViewsWithAttributeTypes();
        }
      }.observes('.model.aboutToChangeConfiguration'),

      /**
       * Currently the only things that can get out of synch here is eNumeric with DG.QualCellLinearAxisView
       * and eQualitative with DG.CellLinearAxisView.
       */
      synchAxisViewsWithAttributeTypes: function () {
        var tInitLayout = false;

        var synchOneAxis = function (iPrefix) {
          var tCurrentViewClass = this.get(iPrefix + 'AxisView').constructor,
              tAttrType = this.getPath('model.dataConfiguration.' + iPrefix + 'AttributeDescription.attribute.type'),
              tCurrentAxisModel = this.getPath('model.' + iPrefix + 'Axis'),
              tCurrentAxisModelClass = tCurrentAxisModel.constructor,
              tNewViewClass, tNewView, tOldView;
          if (tCurrentViewClass === DG.CellLinearAxisView && tAttrType === 'qualitative') {
            tNewViewClass = DG.QualCellLinearAxisView;
          }
          else if (tCurrentViewClass === DG.QualCellLinearAxisView && tAttrType === 'numeric') {
            tNewViewClass = DG.CellLinearAxisView;
          }
          else if (tCurrentAxisModelClass === DG.CountAxisModel) {
            tNewViewClass = DG.CountAxisView;
          }
          else if (tCurrentAxisModelClass === DG.FormulaAxisModel) {
            tNewViewClass = DG.FormulaAxisView;
          }
          else if (tCurrentAxisModelClass === DG.BinnedAxisModel) {
            tNewViewClass = DG.BinnedAxisView;
          }
          if (!SC.none(tNewViewClass) && tNewViewClass !== tCurrentViewClass) {
            tOldView = this.get(iPrefix + 'AxisView');
            tNewView = tNewViewClass.create({
              orientation: tOldView.get('orientation'),
              model: tCurrentAxisModel
            });
            this.removeChild(tOldView);
            this.appendChild(tNewView);
            this.set(iPrefix + 'AxisView', tNewView);
            this.setPath('plotBackgroundView.' + iPrefix + 'AxisView', tNewView);
            this.setPath('plotView.' + iPrefix + 'AxisView', tNewView);
            this.setPath('controller.' + iPrefix + 'AxisView', tNewView);
            tOldView.destroy();
            tInitLayout = true;
          }
        }.bind(this);

        synchOneAxis('x');
        synchOneAxis('y');
        // The yAxisMultiTarget can get out of synch if the document has more than one data context
        this.setPath('yAxisMultiTarget.dataConfiguration', this.getPath('model.dataConfiguration'));
        if (tInitLayout) {
          this.renderLayout(this.renderContext(this.get('tagName')), tInitLayout);
          this.invokeLater(function () {
            this.drawPlots();
          });
        }
      },

      /**
       * When the layout needs of an axis change, we need to adjust the layout of the plot and the other axis.
       */
      handleAxisOrLegendLayoutChange: function () {
        this.renderLayout(this.renderContext(this.get('tagName')));
      }.observes('*xAxisView.desiredExtent', '*yAxisView.desiredExtent',
          '.legendView.desiredExtent', '.legendView.labelNode', '*y2AxisView.desiredExtent',
          '.rightAxisView.desiredExtent', '.topAxisView.desiredExtent'),

      /**
       * When the number toggle changes, we need to adjust the layout of the plot and axes.
       */
      handleNumberToggleDidChange: function () {
        this.renderLayout(this.renderContext(this.get('tagName')));
      }.observes('*model.numberToggle.isEnabled', '*model.numberToggle.caseCount'),

      mapPlotModelToPlotView: function (iPlotModel) {
        var tModelClass = iPlotModel && iPlotModel.constructor,
            tNewViewClass = null;
        switch (tModelClass) {
          case DG.PlotModel:
            tNewViewClass = DG.PlotView;
            break;
          case DG.CasePlotModel:
            tNewViewClass = DG.CasePlotView;
            break;
          case DG.DotPlotModel:
            tNewViewClass = DG.DotPlotView;
            break;
          case DG.BinnedPlotModel:
            tNewViewClass = iPlotModel.get('dotsAreFused') ? DG.HistogramView : DG.BinnedPlotView;
            break;
          case DG.LinePlotModel:
            tNewViewClass = DG.LinePlotView;
            break;
          case DG.ScatterPlotModel:
            tNewViewClass = DG.ScatterPlotView;
            break;
          case DG.DotChartModel:
            tNewViewClass = DG.DotChartView;
            break;
          case DG.BarChartModel:
            tNewViewClass = DG.BarChartView;
            break;
          case DG.ComputedBarChartModel:
            tNewViewClass = DG.ComputedBarChartView;
            break;
        }
        return tNewViewClass;
      },

      /**
       * yAxisMultiTarget has to be deepest from a drag point of view or it won't be able to
       * notice that something is being dragged into it.
       */
      createMultiTarget: function () {
        var tMulti = DG.AxisMultiTarget.create(),
            tExtent = tMulti.get('desiredExtent');
        this.appendChild(tMulti);
        tMulti.set('dataConfiguration', this.getPath('model.dataConfiguration'));
        tMulti.set('attributeDescription', this.getPath('model.yAxis.attributeDescription'));
        tMulti.set('otherAttributeDescription', this.getPath('model.xAxis.attributeDescription'));
        //tMulti.set('layout', { left: 0, top: 0, width: tExtent.width, height: tExtent.height });
        tMulti.set('layout', {left: 0, top: 0, right: 0, height: tExtent.height});
        tMulti.set('isVisible', false); // Start out hidden

        this.set('yAxisMultiTarget', tMulti);
      }

    });

/* >>>>>>>>>> BEGIN source/components/graph/plots/plot_model.js */
// ==========================================================================
//                            DG.PlotModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('alpha/destroyable');
/* global Set:true */

/** @class  DG.PlotModel - The model for a graph's plot.

 @extends SC.Object
 */
DG.PlotModel = SC.Object.extend(DG.Destroyable,
    /** @scope DG.PlotModel.prototype */
    {
      /**
       Assigned by the graph model that owns me.
       @property { DG.GraphDataConfiguration }
       */
      dataConfiguration: null,

      /**
       * @property {Number}
       */
      splitPlotRowIndex: 0,

      /**
       * @property {Number}
       */
      splitPlotColIndex: 0,

      /**
       * The zeroth plot in a graph that has been split has siblings. When things change
       * that should be reflected in these siblings, the zeroth plot explicitly tells sibs
       * to make the change.
       * @property {[{DG.PlotModel}]}
       */
      siblingPlots: null,

      /**
       * Function set by graph model that owns me to allow me to propagate changes to my siblings.
       */
      getRootPlot: null,

      /**
       @property { DG.DataContext }  The data context
       */
      dataContext: function () {
        return this.getPath('dataConfiguration.dataContext');
      }.property(),

      dataContextDidChange: function () {
        this.notifyPropertyChange('dataContext');
      }.observes('*dataConfiguration.dataContext'),

      /**
       Note: There is an ambiguity about which is the collection client when
       the plot has attributes from different collections.
       @property { DG.CollectionClient }  The collection client
       */
      collectionClient: function () {
        return this.getPath('dataConfiguration.collectionClient');
      }.property(),

      collectionClientDidChange: function () {
        this.notifyPropertyChange('collectionClient');
      }.observes('*dataConfiguration.collectionClient'),

      /**
       * Only used if we are one plot in an array of split plots.
       @property { [{DG.Case}] }
       */
      _casesCache: null,

      /**
       @property { [{DG.Case}] }
       */
      cases: function () {
        var tCases;
        if( this.getPath('dataConfiguration.hasSplitAttribute')) {
          if( !this._casesCache) {
            var tRowAttrDescription = this.getPath('dataConfiguration.rightAttributeDescription'),
                tColAttrDescription = this.getPath('dataConfiguration.topAttributeDescription'),
                tRowAttrID = tRowAttrDescription.getPath('attribute.id'),
                tColAttrID = tColAttrDescription.getPath('attribute.id'),
                tRowValue = (tRowAttrID === DG.Attribute.kNullAttribute) ? null :
                  tRowAttrDescription.getPath('attributeStats.cellNames')[ this.get('splitPlotRowIndex')],
                tColValue = (tColAttrID === DG.Attribute.kNullAttribute) ? null :
                  tColAttrDescription.getPath('attributeStats.cellNames')[ this.get('splitPlotColIndex')];
            this._casesCache = this.getPath('dataConfiguration.cases').filter( function( iCase) {
              var tRowCaseValue = iCase.getValue( tRowAttrID),
                  tColCaseValue = iCase.getValue( tColAttrID);
              if( ['boolean', 'number'].includes(typeof tRowCaseValue))
                tRowCaseValue = String(tRowCaseValue);
              if( ['boolean', 'number'].includes(typeof tColCaseValue))
                tColCaseValue = String(tColCaseValue);
              return (tRowValue === null || tRowCaseValue === tRowValue) &&
                  (tColValue === null || tColCaseValue === tColValue);
            });
          }
          tCases = this._casesCache;
        }
        else {
          tCases = this.getPath('dataConfiguration.cases');
          this._casesCache = null;
        }
        return tCases;
      }.property(),

      casesDidChange: function () {
        this.notifyPropertyChange('cases');
      }.observes('*dataConfiguration.collectionClient', '*dataConfiguration.cases'),

      /**
       The plot model needs access to the cases controller that is stored in my dataConfiguration's
       collection client.
       @property { SC.ArrayController }
       */
      casesController: function () {
        return this.getPath('dataConfiguration.collectionClient.casesController');
      }.property(),

      casesControllerDidChange: function () {
        this.notifyPropertyChange('casesController');
      }.observes('*dataConfiguration.collectionClient.casesController'),

      /**
       @property { SC.SelectionSet }
       */
      selection: function () {
        var tSelection = this.getPath('dataConfiguration.selection'),
            tCases = this.get('cases').toArray();
        tSelection = tSelection.filter(function (iCase) {
          return tCases.indexOf(iCase) >= 0;
        });
        return tSelection;
      }.property(),

      selectionDidChange: function () {
        this.notifyPropertyChange('selection');
      }.observes('*dataConfiguration.selection'),

      /**
       @property { Number }
       */
      xVarID: function () {
        return this.getPath('dataConfiguration.xAttributeID');
      }.property(),

      xVarIDDidChange: function () {
        this.notifyPropertyChange('xVarID');
      }.observes('*dataConfiguration.xAttributeID'),

      /**
       * A scatterplot may index into an array of attributes held by the y-attribute-description
       */
      yAttributeIndex: 0,

      /**
       @property { Number }
       */
      yVarID: function () {
        var tConfig = this.get('dataConfiguration');
        return tConfig ? tConfig.yAttributeIDAt(this.yAttributeIndex) : null;
      }.property(),

      yVarIDDidChange: function () {
        this.notifyPropertyChange('yVarID');
      }.observes('*dataConfiguration.yAttributeID'),

      /**
       @property { Number }
       */
      y2VarID: function () {
        var tConfig = this.get('dataConfiguration');
        return tConfig ? tConfig.y2AttributeIDAt(this.yAttributeIndex) : null;
      }.property(),

      y2VarIDDidChange: function () {
        this.notifyPropertyChange('y2VarID');
      }.observes('*dataConfiguration.y2AttributeID'),

      /**
       @property { Number }
       */
      legendVarID: function () {
        return this.getPath('dataConfiguration.legendAttributeID');
      }.property(),

      legendVarIDDidChange: function () {
        this.notifyPropertyChange('legendVarID');
      }.observes('*dataConfiguration.legendAttributeID'),

      /**
       @property {Number}  The variable ID of the attribute assigned to the numeric axis
       */
      primaryVarID: function () {
        switch (this.get('primaryAxisPlace')) {
          case DG.GraphTypes.EPlace.eX:
            return this.get('xVarID');
          case DG.GraphTypes.EPlace.eY:
            return this.get('yVarID');
          default:
            return null;
        }
      }.property('xVarID', 'yVarID'),

      /**
       @property {Number}  The variable ID of the attribute assigned to the numeric axis
       */
      secondaryVarID: function () {
        switch (this.get('secondaryAxisPlace')) {
          case DG.GraphTypes.EPlace.eX:
            return this.get('xVarID');
          case DG.GraphTypes.EPlace.eY:
            return this.get('yVarID');
          default:
            return null;
        }
      }.property('xVarID', 'yVarID'),

      /**
       @property { DG.AxisModel }
       */
      xAxis: null,

      /**
       @property { DG.AxisModel }
       */
      yAxis: null,

      /**
       * True if this plot is using the 2nd vertical axis.
       @property { DG.Boolean }
       */
      verticalAxisIsY2: false,

      autoDestroyProperties: ['plotAnimator', 'caseValueAnimator'],

      /**
       @property { DG.GraphAnimator }
       */
      plotAnimator: null,

      /**
       @property { DG.CaseValueAnimator }
       */
      caseValueAnimator: null,

      /**
       * This function is set by the graph that owns me.
       * @property{Function}
       */
      getPointColor: null,

      /**
       * This function is set by the graph that owns me.
       * @property{Function}
       */
      getStrokeColor: null,

      strokeColor: function () {
        return this.getStrokeColor();
      }.property(),

      /**
       * This function is set by the graph that owns me.
       * @property{Function}
       */
      getStrokeTransparency: null,

      strokeTransparency: function () {
        return this.getStrokeTransparency();
      }.property(),

      /**
       * This function is set by the graph that owns me.
       * @property{Function}
       */
      getStrokeSameAsFill: null,

      strokeSameAsFill: function () {
        return this.getStrokeSameAsFill();
      }.property(),

      /**
       * This function is set by the graph that owns me.
       * @property{Function}
       */
      getPointSizeMultiplier: null,

      /**
       * This function is set by the graph that owns me.
       * @property{Function}
       */
      getTransparency: null,

      /**
       * Some plots can. Override as desired
       * @property {Boolean}
       */
      canSupportConfigurations: function () {
        return false;
      }.property(),

      /**
       Key-value pairs for adornment models,
       e.g. _adornmentModels['plottedValue'] = plottedValueModel.
       @property   {Object}
       */
      _adornmentModels: null,

      /**
       * @property {[DG.PlotAdornmentModel]}
       */
      adornmentModelsAsArray: function() {
        var tResult = [];
        DG.ObjectMap.forEach(this._adornmentModels, function( iKey, iAdornmentModel) {
          tResult.push( iAdornmentModel);
        });
        return tResult;
      }.property(),

      /**
       @property { DG.PlottedCountModel }
       */
      _plottedCountModel: null,
      plottedCount: function (key, value) {
        // if we are called with a new value, or have no Plotted Count Model
        if (value || !this._plottedCountModel) {
          if (value) {
            this._plottedCountModel = value;
          } else {
            this._plottedCountModel = DG.PlottedCountModel.create({plotModel: this});
          }
          this.setAdornmentModel('plottedCount', this._plottedCountModel); // Add to list of adornments
          this._plottedCountModel.setComputingNeeded(); // initialize
        }
        return this._plottedCountModel;
      }.property(),

      /**
       * May be overridden, e.g. by DotPlotModel
       * @property {Boolean}
       */
      wantsPercentCheckbox: false,

      /**
       * Generally false. But some plots, like a bar chart, will require an 'other' axis; e.g. for count.
       * @property {Boolean}
       */
      wantsOtherAxis: false,

      /**
       * Set by GraphModel. Passed down to relevant adornments.
       * @property {Boolean}
       */
      enableMeasuresForSelection: false,

      enableMeasuresForSelectionDidChange: function(){
        var tEnable = this.get('enableMeasuresForSelection');
        this.get('adornmentModelsAsArray').forEach( function( iAdornmentModel) {
          iAdornmentModel.set('enableMeasuresForSelection', tEnable);
        });
      }.observes('enableMeasuresForSelection'),

      /**
       @return { Boolean }
       */
      shouldPlottedCountBeChecked: function (iWhat) {
        return this.getPath('plottedCount.isShowing' + iWhat);
      },

      /**
       * If we need to make a plotted Value, do so. In any event toggle its visibility.
       * This method gets used by both DotPlotModel and ScatterPlotModel.
       */
      togglePlotValue: function () {
        var this_ = this;

        function toggle() {

          function doToggle( iPlot) {
            iPlot.toggleAdornmentVisibility('plottedValue', 'togglePlotValue');
          }

          this_.get('siblingPlots').forEach( doToggle);
          doToggle( this_);
        }

        function connectFunctions() {
          var tSiblingPlots = this_.get('siblingPlots'),
              tMasterPlottedValue = this_.getAdornmentModel('plottedValue');
          tMasterPlottedValue.set('siblingPlottedFunctions',
              tSiblingPlots.map( function( iPlot) {
                return iPlot.getAdornmentModel( 'plottedValue');
              }));
        }

        var willShow = !this.isAdornmentVisible('plottedValue');
        DG.UndoHistory.execute(DG.Command.create({
          name: "graph.togglePlotValue",
          undoString: (willShow ? 'DG.Undo.graph.showPlotValue' : 'DG.Undo.graph.hidePlotValue'),
          redoString: (willShow ? 'DG.Redo.graph.showPlotValue' : 'DG.Redo.graph.hidePlotValue'),
          log: "togglePlotValue: %@".fmt(willShow ? "show" : "hide"),
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'toggle plotted value',
              type: 'DG.GraphView'
            }
          },
          execute: function () {
            toggle();
            connectFunctions();
          },
          undo: function () {
            toggle();
            this_.getAdornmentModel('plottedValue').set('siblingPlottedFunctions', null);
          }
        }));
      },

      /**
       If we need to make a count model, do so. In any event toggle its visibility.
       */
      togglePlottedCount: function (iWhat) {
        var this_ = this;

        function toggle() {

          function doToggle( iPlot) {
            var tCurrentValue = iPlot.getPath('plottedCount.isShowing' + iWhat);
            iPlot.setPath('plottedCount.isShowing' + iWhat, !tCurrentValue);
          }

          doToggle( this_);
          this_.get('siblingPlots').forEach( doToggle);
        }

        var tInitialValue = this_.getPath('plottedCount.isShowing' + iWhat),
            tUndo = tInitialValue ? ('DG.Undo.graph.hide' + iWhat) : ('DG.Undo.graph.show' + iWhat),
            tRedo = tInitialValue ? ('DG.Redo.graph.hide' + iWhat) : ('DG.Redo.graph.show' + iWhat);
        DG.UndoHistory.execute(DG.Command.create({
          name: "graph.toggleCount",
          undoString: tUndo,
          redoString: tRedo,
          log: ("togglePlotted" + iWhat + ": %@").fmt(tInitialValue ? "hide" : "show"),
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'toggle plotted ' + iWhat,
              type: 'DG.GraphView'
            }
          },
          execute: function () {
            toggle();
          }.bind(this),
          undo: function () {
            toggle();
          }.bind(this)
        }));
      },

      /**
       Initialization method
       */
      init: function () {
        arguments.callee.base.apply(this,arguments);

        this._adornmentModels = {};
        this.siblingPlots = [];

        this.addObserver('dataConfiguration', this, 'dataConfigurationDidChange');
        this.addObserver('xAxis', this, 'xAxisDidChange');
        this.addObserver('yAxis', this, 'yAxisDidChange');

        this.addObserver('dataConfiguration.xAttributeDescription.attribute.categoryMap',
            this, 'colorMapDidChange');
        this.addObserver('dataConfiguration.yAttributeDescription.attribute.categoryMap',
            this, 'colorMapDidChange');
        this.addObserver('dataConfiguration.legendAttributeDescription.attribute.categoryMap',
            this, 'colorMapDidChange');
      },

      /**
       Destruction method
       */
      destroy: function () {
        // Detach the axes
        this.removeObserver('xAxis', this, 'xAxisDidChange');
        this.removeObserver('yAxis', this, 'yAxisDidChange');
        this.removeObserver('dataConfiguration.xAttributeDescription.attribute.categoryMap',
            this, 'colorMapDidChange');
        this.removeObserver('dataConfiguration.yAttributeDescription.attribute.categoryMap',
            this, 'colorMapDidChange');
        this.removeObserver('dataConfiguration.legendAttributeDescription.attribute.categoryMap',
            this, 'colorMapDidChange');
        // Detach the data Configuration
        this.removeObserver('dataConfiguration', this, 'dataConfigurationDidChange');

        // Destroy the adornment models
        DG.ObjectMap.forEach(this._adornmentModels,
            function (iKey, iModel) {
              if (iModel && iModel.destroy)
                iModel.destroy();
            });
        this._adornmentModels = null;
        this.siblingPlots = null;

        arguments.callee.base.apply(this,arguments);

        this.set('xAxis', null);
        this.set('yAxis', null);
        this.set('dataConfiguration', null);
      },

      _observedXAxis: null,
      _observedYAxis: null,

      /**
       Observer function triggered when the 'xAxis' property changes.
       */
      xAxisDidChange: function () {
        if (this._observedXAxis) {
          this._observedXAxis.removeObserver('lowerBound', this, 'axisBoundsDidChange');
          this._observedXAxis.removeObserver('upperBound', this, 'axisBoundsDidChange');
          this._observedXAxis = null;
        }

        var xAxis = this.get('xAxis');
        if (xAxis) {
          xAxis.addObserver('lowerBound', this, 'axisBoundsDidChange');
          xAxis.addObserver('upperBound', this, 'axisBoundsDidChange');
          this._observedXAxis = xAxis;
        }
      },

      /**
       Observer function triggered when the 'yAxis' property changes.
       */
      yAxisDidChange: function () {
        if (this._observedYAxis) {
          this._observedYAxis.removeObserver('lowerBound', this, 'axisBoundsDidChange');
          this._observedYAxis.removeObserver('upperBound', this, 'axisBoundsDidChange');
          this._observedYAxis = null;
        }

        var yAxis = this.get('yAxis');
        if (yAxis) {
          yAxis.addObserver('lowerBound', this, 'axisBoundsDidChange');
          yAxis.addObserver('upperBound', this, 'axisBoundsDidChange');
          this._observedYAxis = yAxis;
        }
      },

      addSibling: function( iPlotModel) {
        this.get('siblingPlots').push( iPlotModel);
      },

      /**
       @property { SC.Array } of SC.Array
       */
      dataArrays: function () {
        return this.getPath('dataConfiguration.arrangedObjectArrays');
      }.property('dataConfiguration'/*,'dataConfiguration.arrangedObjectArrays'*/),
      // Inexplicably, dependent key seems not to work here.
      // We use explicit observers instead.

      /**
       A view will typically observe this property. When it switches to true, the view should
       animate its elements to the currently computable coordinates, and, until the property
       switches back, it should suspend subsequent computation of coordinates for plotted
       elements.
       @property {Boolean}
       */
      isAnimating: false,

      /**
       Return the specified adornment model.
       @param    {String}    iAdornmentKey -- The key for the adornment, e.g. 'plottedValue'
       @returns  {DG.AdornmentModel} Returns the specified adornment model (or undefined).
       */
      getAdornmentModel: function (iAdornmentKey) {
        return iAdornmentKey && this._adornmentModels && this._adornmentModels[iAdornmentKey];
      },

      /**
       Sets the specified adornment model.
       @param    {String}            iAdornmentKey -- The key for the adornment, e.g. 'plottedValue'
       @param    {DG.AdornmentModel} iAdornmentModel -- the specified adornment model
       */
      setAdornmentModel: function (iAdornmentKey, iAdornmentModel) {
        if( !this._adornmentModels)
          this._adornmentModels = {};
        DG.assert(iAdornmentKey);
        this._adornmentModels[iAdornmentKey] = iAdornmentModel;
        this.notifyPropertyChange(iAdornmentKey);
      },

      /**
       Return whether the specified adornment is currently visible.
       @param    {String}    iAdornmentKey -- The key for the adornment, e.g. 'plottedValue'
       @returns  {Boolean}   True if the adornment is visible, false otherwise
       */
      isAdornmentVisible: function (iAdornmentKey) {
        var model = this.getAdornmentModel(iAdornmentKey);
        return model ? model.get('isVisible') : false;
      },

      /**
       Hides/shows the specified adornment.
       Constructs the adornment model if it doesn't already exist
       If the visibility changes, calls notifyPropertyChange( iAdornmentKey).
       @param    {String}    iAdornmentKey -- e.g. 'plottedValue', 'plottedFunction'
       @param    {Boolean}   iVisibility -- true to show, false to hide
       @return   {DG.PlotAdornmentModel}
       */
      setAdornmentVisibility: function (iAdornmentKey, iVisibility) {
        var model = this.getAdornmentModel(iAdornmentKey);
        if (!model) {
          var modelClass = DG.PlotAdornmentModel.registry[iAdornmentKey];
          DG.assert(modelClass, "No model class registered for '%@'".fmt(iAdornmentKey));
          model = modelClass && modelClass.create({
            plotModel: this,
            adornmentKey: iAdornmentKey,
            enableMeasuresForSelection: this.get('enableMeasuresForSelection')
          });
          if (model)
            this.setAdornmentModel(iAdornmentKey, model);
        }
        if (model && (this.isAdornmentVisible(iAdornmentKey) !== iVisibility)) {
          model.set('isVisible', iVisibility);
          this.notifyPropertyChange(iAdornmentKey);
        }
        return model;
      },

      /**
       Toggle the visibility of the specified adornment.
       Will create the adornment the first time it's shown.
       @param    {String}    iAdornmentKey -- e.g. 'plottedValue', 'plottedFunction'
       @param    {String}    iToggleLogString -- Name of action logged to server
       @returns  {DG.PlotAdornmentModel}   The specified adornment model
       */
      toggleAdornmentVisibility: function (iAdornmentKey, iToggleLogString) {
        DG.assert(!SC.empty(iAdornmentKey));
        var adornmentModel = this.getAdornmentModel(iAdornmentKey),
            tIsVisible = adornmentModel && adornmentModel.get('isVisible');
        return this.setAdornmentVisibility(iAdornmentKey, !tIsVisible);
      },

      /**
       @property {DG.AxisModel}
       */
      getAxisForPlace: function (iPlace) {
        switch (iPlace) {
          case DG.GraphTypes.EPlace.eX:
            return this.get('xAxis');
          case DG.GraphTypes.EPlace.eY:
            return this.get('yAxis');
          case DG.GraphTypes.EPlace.eY2:
            return this.get('y2Axis');
          default:
            return null;
        }
      },

      /**
       *
       * @param iPlace {DG.GraphTypes.EPlace}
       * @return { class }
       */
      getDesiredAxisClassFor: function( iPlace) {
        return DG.AxisModel;
      },

      /**
       * @param iKey {String} If present, the property that changed to bring about this call
       Subclasses may override
       Called when attribute configuration changes occur, for instance.
       */
      invalidateCaches: function ( iKey) {
        this._casesCache = null;
        this.invalidateAggregateAdornments();
        this.notifyPropertyChange('plotConfiguration');
      },

      /**
       Subclasses may override
       @param { DG.GraphTypes.EPlace }
       @return{ {min:{Number}, max:{Number} isDataInteger:{Boolean}} }
       */
      getDataMinAndMaxForDimension: function (iPlace) {
        var tDataConfiguration = this.get('dataConfiguration');
        return tDataConfiguration && tDataConfiguration.getDataMinAndMaxForDimension(iPlace);
      },

      updateAdornmentModels: function() {
        var tPrimaryAxisModel = this.get('primaryAxisModel');
        this.get('adornmentModelsAsArray').forEach( function( iAdornmentModel) {
            iAdornmentModel.setComputingNeeded();
            iAdornmentModel.recomputeValueIfNeeded( tPrimaryAxisModel);
        });
      },

      /**
       Subclasses may override
       */
      handleDataConfigurationChange: function () {
      },

      /**
       Subclasses may override
       */
      rescaleAxesFromData: function (iAllowScaleShrinkage, iAnimatePoints, iLogIt) {
      },

      invalidateAggregateAdornments: function () {
        // TODO: use more robust ID
        var id = DG.Debug.scObjectID(this),
            depMgr = this.getPath('dataConfiguration.dataContext.dependencyMgr');
        if (depMgr)
          depMgr.invalidateDependentsOf([{type: DG.DEP_TYPE_PLOT, id: id, name: 'plot-' + id}]);
      },

      /**
       Observer function triggered when the visible bounds of the axes are changed.
       */
      axisBoundsDidChange: function () {
        this.notifyPropertyChange('axisBounds');
      },

      /**
       * For selected cases, the values given by the array of attribute IDs will be animated by the amounts
       * specified in the array of deltas.
       * @param iAttrIDs {[Number]}
       * @param iDeltas {[Number]}
       * @param iSelectedCases? {{}[]}
       */
      animateSelectionBackToStart: function (iAttrIDs, iDeltas, iSelectedCases) {
        if(iDeltas.every(function(iDelta) { return iDelta === 0;}))
          return;
        if (SC.none(this.caseValueAnimator))
          this.caseValueAnimator = DG.CaseValueAnimator.create();
        else  // We must end the animation before setting animator properties
          this.caseValueAnimator.endAnimation();

        this.caseValueAnimator.set('dataContext', this.get('dataContext'));
        this.caseValueAnimator.set('cases', iSelectedCases || DG.copy(this.get('selection')));
        this.caseValueAnimator.set('attributeIDs', iAttrIDs);
        this.caseValueAnimator.set('deltas', iDeltas);

        this.caseValueAnimator.animate();
      },

      /**
       * We add this "extra" accessor for checkbox descriptions so that the BinnedPlotModel can get to it without
       * encountering the UnivariateAdornmentBaseModel's accessor for checkboxDescriptions.
       */
      checkboxDescriptionsForPlotModel: function () {
        var this_ = this,
            tXHasCells = this.get('xAxis').numberOfCells() > 1,
            tYHasCells = this.get('yAxis').numberOfCells() > 1,
            tPlotWantsPercents = this.get('wantsPercentCheckbox'),
            tDescriptions = [
              {
                title: 'DG.Inspector.graphCount',
                value: this_.shouldPlottedCountBeChecked('Count'),
                classNames: 'dg-graph-count-check'.w(),
                valueDidChange: function () {
                  this_.togglePlottedCount('Count');
                }.observes('value')
              }
            ];
        if (tPlotWantsPercents || tXHasCells || tYHasCells) {
          tDescriptions.push({
            title: 'DG.Inspector.graphPercent',
            value: this_.shouldPlottedCountBeChecked('Percent'),
            classNames: 'dg-graph-percent-check'.w(),
            handlingMovableValueChange: false,
            valueDidChange: function () {
              if (!this.handlingMovableValueChange)
                this_.togglePlottedCount('Percent');
            }.observes('value'),
            init: function () {
              arguments.callee.base.apply(this,arguments);
              this_.addObserver('movableValueChange', this, 'handleMovableValueChange');
            },
            destroy: function () {
              this_.removeObserver('movableValueChange', this, 'handleMovableValueChange');
              arguments.callee.base.apply(this,arguments);
            },
            handleMovableValueChange: function () {
              this.handlingMovableValueChange = true;
              this.set('value', this_.shouldPlottedCountBeChecked('Percent'));
              this.set('isEnabled', this_.get('wantsPercentCheckbox'));
              this.handlingMovableValueChange = false;
            }
          });
        }
        return tDescriptions;
      }.property(),

      checkboxDescriptions: function () {
        return this.checkboxDescriptionsForPlotModel();
      }.property(),

      configurationDescriptions: function () {
        return [];
      }.property(),

      spreadCheckboxDescriptions: function () {
        return [];
      }.property(),

      lastValueControls: function () {
        return [];
      }.property(),

      lastConfigurationControls: function () {
        return [];
      }.property(),

      /**
       Call the given function once for each case that has a value for each axis.
       Given function should have the signature (iCase, iCaseIndex)
       */
      forEachCaseDo: function (iDoF) {
        var tCases = this.get('cases');
        if (!SC.none(tCases))
          tCases.forEach(iDoF);
      },

      /**
       Returns an array of collection IDs corresponding to the collections that
       are currently being plotted by the graph.
       @returns  {Array of {Number}}
       */
      getPlottedCollectionIDs: function () {
        return this.getPath('dataConfiguration.plottedCollectionIDs') || [];
      },

      getPlottedCollectionIDsIncludesIDs: function(iCollectionIDs) {
        var tPlottedCollectionIDs = this.getPlottedCollectionIDs();
        return iCollectionIDs.some(function (iID) {
          return tPlottedCollectionIDs.indexOf(iID) >= 0;
        });
      },
      /**
       Returns an array of attribute IDs corresponding to the attributes that
       are currently being plotted by the graph.
       @returns  {Array of {Number}}
       */
      getPlottedAttributeIDs: function () {
        var plottedAttributeIDs = [],
            dataConfiguration = this.get('dataConfiguration'),
            attrDescriptions = dataConfiguration.get('attributesByPlace');
        if (!dataConfiguration) return plottedAttributeIDs;
        attrDescriptions.forEach(function (iDescArray) {
          iDescArray.forEach( function( iDesc) {
            iDesc.get('attributes').forEach( function( iAttr) {
              var tID = iAttr.get('id');
              if( !SC.none(tID) && tID !== DG.Analysis.kNullAttribute &&
                  plottedAttributeIDs.indexOf(tID) < 0)
                plottedAttributeIDs.push(tID);
            });
          });
        });
        return plottedAttributeIDs;
      },

      /**
       *
       * @param iAttributeIDs {(string|number)[]}
       * @return {boolean}
       */
      getPlottedAttributesIncludeIDs: function (iAttributeIDs) {
        var plottedAttrIDs = this.getPlottedAttributeIDs();
        return iAttributeIDs.some(function(iAttributeID) {
          return plottedAttrIDs.indexOf(Number(iAttributeID)) >= 0;
        });
      },

      /**
       Returns true if any of the plotted attributes contain formulas, false otherwise.
       @returns  {Boolean}
       */
      getPlottedAttributesContainFormulas: function () {
        var tDataConfiguration = this.get('dataConfiguration');
        return tDataConfiguration && tDataConfiguration.atLeastOneFormula();
      },

      /**
       * Called directly by GraphModel so that anything that needs to be done special for
       * a change in x or y attribute, as opposed to legend, can be done. See BinnedPlotModel.
       * @parameter {String}  Either 'xAxis' or 'yAxis'
       */
      xOrYAttributeDidChange: function( iAxisKey) {
        // subclasses may override
      },

      /**
       Returns true if the plot is affected by the specified change such that
       a redraw is required, false otherwise. Used to avoid redrawing when
       attribute values that aren't being plotted are changed, for instance.
       @param    {Object}    iChange -- The change request to/from the DataContext
       @returns  {Boolean}   True if the plot must redraw, false if it is unaffected
       */
      isAffectedByChange: function (iChange) {
        var isAffected = false;
        if (!iChange || !iChange.operation) return false;
        switch (iChange.operation) {
          case 'dependentCases':
            var i, change, changeCount = (iChange.changes && iChange.changes.length) || 0;
            for (i = 0; i < changeCount; ++i) {
              change = iChange.changes[i];
              if (change.attributeIDs && this.getPlottedAttributesIncludeIDs(change.attributeIDs))
                isAffected = true;
            }
            break;
          case 'updateCases':
            var changedAttrIDs = Array.isArray(iChange.attributeIDs) ?  iChange.attributeIDs : [];
            // only if the attributes involved are being plotted OR
            // if there are formulas such that the plotted attributes
            // are affected indirectly.
              // An updateCases from a plugin can be missing the an attributeIDs property. In that case
              // the changes are in a values array of objects each of which consists of attribute name as
              // key and the new value as value of that key. We look up the id of attributes.
              if( SC.none( iChange.attributeID) && Array.isArray(iChange.values) && iChange.collection) {
                var tCollection = iChange.collection.collection,
                    tAttrSet = new Set();
                iChange.values.forEach( function(iChangeObject) {
                  DG.ObjectMap.keys(iChangeObject).forEach(function( iKey) {
                    tAttrSet.add(iKey);
                  });
                });
                tAttrSet.forEach(function(iKey) {
                  var tAttr = tCollection.getAttributeByName(iKey);
                  if( tAttr)
                    changedAttrIDs.push(tAttr.get('id'));
                });
              }
            else if( !SC.none( iChange.attributeID))
              changedAttrIDs.push( iChange.attributeID);
            isAffected = this.getPlottedAttributesIncludeIDs(changedAttrIDs);
            break;
            /* jshint -W086 */  // Expected a 'break' statement before 'case'. (W086)
            // fall through intentional -- w/o attribute IDs, rely on collection
          case 'createCase':
          case 'createCases':
            // Only if the case(s) created are in a collection that is being plotted
            var changedCollectionID = iChange.collection && iChange.collection.get('id'),
                plottedCollectionIDs = this.getPlottedCollectionIDs();
            isAffected = !changedCollectionID || (plottedCollectionIDs.indexOf(changedCollectionID) >= 0);
            break;
          case 'deleteCases':
          case 'selectCases':
          case 'moveCases':
            // We could do a collection test if that information were reliably
            // available in the change request, but that's not currently so.
            isAffected = true;
            break;
          case 'createCollection':
            var tAttributes = iChange.attributes,
                tIDs = tAttributes && tAttributes.map( function( iAttribute) {
                  // sometimes the attributes object is a plain, not sproutcore, object
                  return iAttribute.get && iAttribute.get('id');
                });
            // if we did not see attributes with ids, we assume we are affected
              if(!SC.none( tIDs)) {
                if (tIDs.length > 0 && SC.none(tIDs[0])) {
                  isAffected = true;
                } else {
                  isAffected = this.getPlottedAttributesIncludeIDs(tIDs);
                }
              }
            break;
          case 'moveAttribute':
            var tFromID = iChange.fromCollection && iChange.fromCollection.get('id'),
                tToID = iChange.toCollection && iChange.toCollection.get('id');
            isAffected = this.getPlottedCollectionIDsIncludesIDs([tFromID, tToID]) &&
                            tFromID !== tToID;
            break;
        }
        return isAffected;
      },

      /**
       Responder for DataContext notifications. The PlotModel does not
       receive DataContext notifications directly, however. Instead, it
       receives them from the GraphModel, which receives them directly
       from the DataContext.
       */
      handleDataContextNotification: function (iNotifier, iChange) {
        this.invalidateCaches();
        // Currently, much of the handling is in the PlotViews.
        // Some of it would fit better in the model, but for now we
        // leave things the way they are and simply make the change
        // available for the PlotViews to respond to.
        this.set('lastChange', iChange);
      },

      _observedDataConfiguration: null,

      /**
       Responder method for dataConfiguration changes.
       */
      dataConfigurationDidChange: function (iSource, iKey) {
        if (this._observedDataConfiguration && (iKey === 'dataConfiguration')) {
          this._observedDataConfiguration.removeObserver('cases', this, 'dataConfigurationDidChange');
          this._observedDataConfiguration.removeObserver('attributeAssignment', this, 'dataConfigurationDidChange');
          this._observedDataConfiguration.removeObserver('arrangedObjectArrays', this, 'sourceArraysDidChange');
          this._observedDataConfiguration.removeObserver('hiddenCases', this, 'dataConfigurationDidChange');
          this._observedDataConfiguration.removeObserver('displayOnlySelected', this, 'dataConfigurationDidChange');
          this._observedDataConfiguration.removeObserver('hasSplitAttribute', this, 'dataConfigurationDidChange');
          this._observedDataConfiguration = null;
        }

        var dataConfiguration = this.get('dataConfiguration');
        if (dataConfiguration) {
          this.get('siblingPlots').concat([this]).forEach( function( iPlot) {
            iPlot.invalidateCaches(iKey);
            iPlot.handleDataConfigurationChange(iKey);
          });

          if (iKey === 'dataConfiguration') {
            dataConfiguration.addObserver('cases', this, 'dataConfigurationDidChange');
            dataConfiguration.addObserver('attributeAssignment', this, 'dataConfigurationDidChange');
            dataConfiguration.addObserver('arrangedObjectArrays', this, 'sourceArraysDidChange');
            dataConfiguration.addObserver('hiddenCases', this, 'dataConfigurationDidChange');
            dataConfiguration.addObserver('displayOnlySelected', this, 'dataConfigurationDidChange');
            dataConfiguration.addObserver('hasSplitAttribute', this, 'dataConfigurationDidChange');
            this._observedDataConfiguration = dataConfiguration;
            dataConfiguration.set('sortCasesByLegendCategories', true); // subclasses may override to false
          }
        }
      },

      /**
       Observer function triggered when the underlying arrays are changed.
       */
      sourceArraysDidChange: function (iSource, iKey) {
        this.invalidateCaches();
        this.notifyPropertyChange('dataArrays');
      },

      colorMapDidChange: function () {
        this.invalidateCaches();
        this.propertyDidChange('colorMap');
      },

      /**
       * Select the cases whose indices appear in the given array
       * @param iIDs {[Integer]}
       * @param iExtend {Boolean}
       */
      selectCasesWithIndices: function (iIndices, iExtend) {
        var tCases = this.get('cases'),
            tCasesToSelect = [];
        iIndices.forEach(function (iCaseIndex) {
          if (iCaseIndex < tCases.get('length')) {
            tCasesToSelect.push(tCases.unorderedAt(iCaseIndex));
          }
        });
        this.get('dataContext').applyChange({
          operation: 'selectCases',
          collection: this.get('collectionClient'),
          cases: tCasesToSelect,
          select: true,
          extend: iExtend
        });
      },

      /**
       @param {Number} The index of the case to be selected.
       @param {Boolean} Should the current selection be extended?
       */
      selectCaseByIndex: function (iIndex, iExtend) {
        var tCases = this.get('cases'),
            tCase = tCases.unorderedAt(iIndex),
            tSelection = this.get('selection'),
            tChange = {
              operation: 'selectCases',
              collection: this.get('collectionClient'),
              cases: [tCase],
              select: true,
              extend: iExtend
            };

        if (tSelection.get('length') !== 0) {
          if (tSelection.contains(tCase)) {  // Case is already selected
            if (iExtend) {
              tChange.select = false;
            }
            // clicking on a selected case leaves it selected
            else return;
          }
          else {
            tChange.select = true;
          }
        }

        this.get('dataContext').applyChange(tChange);
        if (tChange.select)
          DG.logUser("caseSelected: %@", iIndex);
        else
          DG.logUser("caseDeselected: %@", iIndex);
      },

      /**
       * If I have an animation, end it.
       */
      stopAnimation: function () {
        var tPlotAnimator = this.get('plotAnimator'),
            tCaseValueAnimator = this.get('caseValueAnimator');
        if (!SC.none(tPlotAnimator))
          tPlotAnimator.endAnimation();
        if (!SC.none(tCaseValueAnimator))
          tCaseValueAnimator.endAnimation();
      },

      /**
       * When making a copy of a plot (e.g. for use in split) the returned object
       * holds those properties that should be assigned to the copy.
       * @return {{}}
       */
      getPropsForCopy: function() {
        return {
          dataConfiguration: this.get('dataConfiguration'),
          verticalAxisIsY2: this.get('verticalAxisIsY2')
        };
      },

      /**
       * Create the model data to save with document.
       * Derived plot models will add to this storage.
       * @return {Object} the saved data.
       */
      createStorage: function () {
        var tStorage = {verticalAxisIsY2: this.get('verticalAxisIsY2')};

        // Store any adornment models
        if (DG.ObjectMap.length(this._adornmentModels) > 0) {
          tStorage.adornments = {};
          DG.ObjectMap.forEach(this._adornmentModels,
              function (iAdornmentKey, iAdornmentModel) {
                var adornmentStorage = iAdornmentModel.createStorage &&
                    iAdornmentModel.createStorage();
                if (DG.ObjectMap.length(adornmentStorage))
                  tStorage.adornments[iAdornmentKey] = adornmentStorage;
              });
        }
        return tStorage;
      },

      /**
       Utility function for simplified support of adornments in legacy documents.
       Used to move adornment storage objects down into the plot model's 'adornments'
       section, where it can be handled generically by PlotModel's restoreStorage().
       @param    {Object}    iModelStorage -- Storage object passed to plot's restoreStorage()
       @param    {String}    iAdornmentKey -- e.g. 'plottedValue', 'plottedFunction'
       @param    {Object}    iAdornmentStorage -- Storage object for adornment's restoreStorage()
       */
      moveAdornmentStorage: function (iModelStorage, iAdornmentKey, iAdornmentStorage) {
        if (iAdornmentStorage) {
          if (!iModelStorage.adornments) iModelStorage.adornments = {};
          iModelStorage.adornments[iAdornmentKey] = iAdornmentStorage;
        }
      },

      /**
       * Restore our model after opening document.
       * Derived plot models will also restore plot-specific parameters
       * @param iStorage
       */
      restoreStorage: function (iStorage) {
        // I have my axes, but until now I can't take care of changing my yAxis to the y2Axis
        this.verticalAxisIsY2 = iStorage.verticalAxisIsY2;
        if (this.verticalAxisIsY2) {
          this.set('yAxis', this.get('y2Axis'));
        }

        // Remove adornment models not found in storage

        // Restore any adornment models
        DG.ObjectMap.forEach(iStorage.adornments,
            function (iAdornmentKey, iAdornmentStorage) {
              var modelClass = DG.PlotAdornmentModel.registry[iAdornmentKey],
                  adornmentModel = modelClass && modelClass.create({plotModel: this});
              if (adornmentModel) {
                adornmentModel.restoreStorage(iAdornmentStorage);
                this.setAdornmentModel(iAdornmentKey, adornmentModel);
                // TODO: Get rid of this next line
                this.set(iAdornmentKey, adornmentModel);
              }
            }.bind(this));
      },

      /**
       * Create a copy of adornment models to be transferred to a new plot type.
       * We *don't* change the new plot model, but instead return an array of new properties,
       * so that the caller can control when the new plot model is changed, for example
       * inside a beginPropertyChanges()...endPropertyChanges() set.
       * @param {Object} iNewPlotModel
       * @returns {Object} array of properties to use for new model.
       */
      copyAdornmentModels: function (iNewPlotModel) {
        DG.assert((typeof iNewPlotModel === "object") && (iNewPlotModel instanceof DG.PlotModel));
        var tAdornmentModels = {},
            tPlottedCount = this.get('plottedCount');

        if (tPlottedCount) {  // copy plottedCount for all PlotModel types
          tAdornmentModels.plottedCount = tPlottedCount;
          tPlottedCount.set('plotModel', iNewPlotModel);
          this._plottedCountModel = null; // So we don't destroy the one we're passing to the new plot
          this._adornmentModels.plottedCount = null;
        }

        return tAdornmentModels;
      },

      /**
       *
       * @param {Object} iAdornments
       */
      installAdornmentModels: function( iAdornments) {
        var this_ = this;
        DG.ObjectMap.forEach( iAdornments, function( iKey, iValue) {
          this_.set( iKey, iValue);
        });
      },

      /**
       * Return a list of objects { key, class, storage }
       * Subclasses should override calling sc_super first.
       * @return {[Object]}
       */
      getAdornmentSpecs: function() {
        var tSpecs = [],
            tPlottedCount = this.get('plottedCount');
        if( tPlottedCount)
          tSpecs.push( {
            key: 'plottedCount',
            "class": tPlottedCount.constructor,
            storage: tPlottedCount.createStorage()
          });
        return tSpecs;
      },

      /**
       * For each adornment in source, make a corresponding adornment for me.
       * @param {DG.PlotModel} iSourcePlot
       */
      installAdornmentModelsFrom: function( iSourcePlot) {
        var this_ = this,
            tAdornmentSpecs = iSourcePlot.getAdornmentSpecs();
        tAdornmentSpecs.forEach( function( iSpec) {
          var tAdornmentModel = iSpec["class"].create({ plotModel: this_ });
          tAdornmentModel.restoreStorage( iSpec.storage);
          if( iSpec.useAdornmentModelsArray)
            this_.setAdornmentModel( iSpec.key, tAdornmentModel);
          else
            this_.set( iSpec.key, tAdornmentModel);
        });
      },

      /**
       * Get an array of non-missing case counts in each axis cell.
       * Also cell index on primary and secondary axis, with primary axis as major axis.
       * @return {Array} [{count, primaryCell, secondaryCell},...] (all values are integers 0+).
       */
      getCellCaseCounts: function () {
        DG.assert(false, "derived classes must override getCellCaseCounts()");
        return [];
      }

    });

/**
 class (static) method called before plot creation to make sure roles are correct
 @param {DG.GraphDataConfiguration}
 */
DG.PlotModel.configureRoles = function (iConfig) {

};

/* >>>>>>>>>> BEGIN source/components/graph/plots/chart_model.js */
// ==========================================================================
//                          DG.ChartModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2017 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/plots/plot_model');

/** @class  DG.ChartModel - The model for a plot with categorical axes

  @extends SC.Object
*/
DG.ChartModel = DG.PlotModel.extend(
/** @scope DG.ChartModel.prototype */
{

  /**
  @property{DG.GraphTypes.EPlace}
  */
  primaryAxisPlace: function() {
    var dataConfiguration = this.get('dataConfiguration');
    return dataConfiguration && dataConfiguration.getPlaceForRole( DG.Analysis.EAnalysisRole.ePrimaryCategorical);
  }.property('xVarID', 'yVarID'),

  /**
  @property{DG.GraphTypes.EPlace}
  */
  secondaryAxisPlace: function() {
    var dataConfiguration = this.get('dataConfiguration');
    return dataConfiguration && dataConfiguration.getPlaceForRole( DG.Analysis.EAnalysisRole.eSecondaryCategorical);
  }.property('xVarID', 'yVarID'),

/**
  @property{DG.CellAxisModel}
  */
  primaryAxisModel: function() {
    return this.getAxisForPlace( this.get('primaryAxisPlace'));
  }.property('primaryAxisPlace', 'xAxis', 'yAxis'),

/**
  @property{DG.CellAxisModel}
  */
  secondaryAxisModel: function() {
    return this.getAxisForPlace( this.get('secondaryAxisPlace'));
  }.property('secondaryAxisPlace', 'xAxis', 'yAxis'),

  /**
    'vertical' means the stacks of dots are vertical, while 'horizontal' means they are horizontal
    @property{String}
    */
    orientation: function() {
      return (this.get('primaryAxisPlace') === DG.GraphTypes.EPlace.eX) ? DG.GraphTypes.EOrientation.kVertical :
          DG.GraphTypes.EOrientation.kHorizontal;
    }.property(),

  /**
   * A dot chart can be configured as a bar chart
   * But (for now) not if there are categorical attributes on both x and y axes
   * @property {Boolean}
   */
  canSupportConfigurations: function() {
    return this.getPath( 'dataConfiguration.xAttributeDescription.isNull') ||
        this.getPath( 'dataConfiguration.yAttributeDescription.isNull');
  }.property(),
  canSupportConfigurationsChanged: function() {
    this.notifyPropertyChange('canSupportConfigurations');
  }.observes('dataConfiguration.xAttributeDescription.isNull', 'dataConfiguration.yAttributeDescription.isNull'),

  /**
   * @property {Boolean}
   */
  displayAsBarChart: null,

  /**
    @property{SC.Array of SC.Array of SC.Array of {theCase, caseIndex}}
  */
  cachedCells: null,

  /**
    Reverse lookup. Indexed by case index.
    @property{SC.Array of {primaryCell, primaryCell, indexInCell}}
  */
  cachedIndex: null,

  validCachedCells: function() {
    if( !this._cacheIsValid)
      this._buildCache();
    return this.get('cachedCells');
  }.property(),

  xAxisDidChange: function() {
    arguments.callee.base.apply(this,arguments);
    this.invalidateCaches();
  },

  yAxisDidChange: function() {
    arguments.callee.base.apply(this,arguments);
    this.invalidateCaches();
  },

  numberOfCategoriesLimitDidChange: function() {
    this.invalidateCaches();
  }.observes('*xAxis.numberOfCategoriesLimit', '*yAxis.numberOfCategoriesLimit'),

  /**
    @property{Number} The maximum number of cases in any cell
  */
  maxInCell: function() {
    if( !this._cacheIsValid)
      this._buildCache();
    return this._maxInCell;
  }.property(),

  /**
   * An array of counts, indexed by primary cell
   * @property { [Integer]}
   */
  primaryCellCounts: function() {
    if( !this._cacheIsValid)
      this._buildCache();
    return this.get('cachedCells').map( function( iCell) {
      return iCell[0].length;
    });
  }.property(),

  /**
    Responder for DataContext notifications. The PlotModel does not
    receive DataContext notifications directly, however. Instead, it
    receives them from the GraphModel, which receives them directly
    from the DataContext.
   */
  handleDataContextNotification: function( iNotifier, iChange) {
    if( !this.isAffectedByChange( iChange))
      return;

    var addToCache = function( iCase, iIndex, iPrimaryCell, iSecondaryCell) {
      var tCellLength;
      if(SC.none( iPrimaryCell) || SC.none( iSecondaryCell))
        return;

      var tCachedCells = this.get('cachedCells' ),
          tCachedIndex = this.get('cachedIndex' ),
          tMaxInCell = this.get('_maxInCell');

      if( SC.none( tCachedCells[ iPrimaryCell]))
        tCachedCells[ iPrimaryCell] = [];
      if( SC.none( tCachedCells[ iPrimaryCell][ iSecondaryCell]))
        tCachedCells[ iPrimaryCell][ iSecondaryCell] = [];
      tCachedCells[ iPrimaryCell][iSecondaryCell].push( { theCase: iCase, caseIndex: iIndex });
      tCellLength = tCachedCells[ iPrimaryCell][ iSecondaryCell].length;
      tCachedIndex[ iIndex] = { primaryCell: iPrimaryCell, secondaryCell: iSecondaryCell, indexInCell: tCellLength - 1 };
      this.beginPropertyChanges();
        this.set('cachedCells', tCachedCells);
        this.set('cachedIndex', tCachedIndex);
        this.set('_maxInCell', Math.max( tMaxInCell, tCellLength));
      this.endPropertyChanges();
    }.bind( this);



    if( (iChange.operation === 'createCase') || (iChange.operation === 'createCases')) {
      var tCaseDisturbedCellOrder = false,
          tCaseIDs = iChange.result.caseIDs || [ iChange.result.caseID ],
      tIndexOfCaseInArray = this.getPath('dataConfiguration.cases').length() - tCaseIDs.length,
          tCC = this.get('computationContext' );
      tCaseIDs.forEach( function( iCaseID) {
        var tCase = DG.store.find(DG.Case, iCaseID);
        if (tCase) {
          if( tCase._didDisturbCellOrder) {
            tCaseDisturbedCellOrder = true;
            delete tCase._didDisturbCellOrder;
          }
          if( !tCaseDisturbedCellOrder)
            this.doForOneCase(tCase, tIndexOfCaseInArray++, tCC, addToCache);
        }
      }.bind( this));
      if( tCaseDisturbedCellOrder)
        this.invalidateCaches();
    }
    else
      this.invalidateCaches();

    arguments.callee.base.apply(this,arguments); // Call this last because it results in view update, which we're not ready to do first
  },

  /**
    With this iteration we pass to the given function the index of the case in the cell.
    @return {{primaryCell, secondaryCell, indexInCell}}
  */
  lookupCellForCaseIndex: function( iIndex) {
    if( !this._cacheIsValid)
      this._buildCache();
    return this.get('cachedIndex')[ iIndex];
  },

  /**
   * If SC's property caching worked the way we would like it to, we wouldn't need this private property.
   * As it is, we store a cached computation context here, nulling it out by hand when caches must be
   * invalidated.
   */
  _cachedComputationContext: null,

  /**
   * Caching this computation context allows us to save a lot of 'gets'
   * @property{Object}
   */
  computationContext: function() {
    if( !this._cachedComputationContext) {
      this._cachedComputationContext = {
        primaryAxis: this.get('primaryAxisModel'),
        secondaryAxis: this.get('secondaryAxisModel'),
        primaryVarID: this.get('primaryVarID'),
        secondaryVarID: this.get('secondaryVarID'),
        legendVarID: this.get('legendVarID')
      };
    }
    return this._cachedComputationContext;
  }.property('primaryAxisModel', 'secondaryAxisModel', 'primaryVarID', 'secondaryVarID', 'legendVarID' ),

  doForOneCase: function( iCase, iIndex, iCC, iDoF) {
    var tPrimaryVal = iCase.getValue( iCC.primaryVarID),
        tPrimaryIsValid = SC.none( iCC.primaryVarID) || !SC.none( tPrimaryVal),
        tSecondaryVal = iCase.getValue( iCC.secondaryVarID),
        tSecondaryIsValid = SC.none( iCC.secondaryVarID) || !SC.none( tSecondaryVal),
        tPrimaryCell, tSecondaryCell;
    if( tPrimaryIsValid && tSecondaryIsValid) {
      tPrimaryCell = iCC.primaryAxis.cellNameToCellNumber( tPrimaryVal);
      tSecondaryCell = iCC.secondaryAxis.cellNameToCellNumber( tSecondaryVal);
      iDoF( iCase, iIndex, tPrimaryCell, tSecondaryCell);
    }
  },

  /**
    Call the given function once for each case that has a value for each axis.
    function signature for iDoF is { iCase, iCaseIndex, iPrimaryCellIndex, iSecondaryCellIndex }
  */
  forEachBivariateCaseDo: function( iDoF, iForSelectionOnly) {
    var tCases = iForSelectionOnly ? this.get('selection') : this.get('cases'),
        tCC = this.get('computationContext');
    if( !tCC.primaryAxis || !tCases || !tCC.secondaryAxis)
      return; // Can happen during transitions. Bail!
    tCases.forEach( function( iCase, iIndex) {
      this.doForOneCase( iCase, iIndex, tCC, iDoF);
    }.bind(this));
  },

  /**
   * @param iKey {String} If present, the property that changed to bring about this call
    My data has changed, so my cache is no longer valid.
  */
  invalidateCaches: function( iKey) {
    arguments.callee.base.apply(this,arguments);
    this.set('_cacheIsValid', false);
    this._cachedComputationContext = null;
  },

  /**
   * Get an array of non-missing case counts in each axis cell.
   * Also cell index on primary and secondary axis, with primary axis as major axis.
   * @return {Array} [{count, primaryCell, secondaryCell},...] (all values are integers 0+).
   */
  getCellCaseCounts: function( iForSelectionOnly) {
    var tAxis1 = this.get('primaryAxisModel'),
        tAxis2 = this.get('secondaryAxisModel'),
        tValueArray = [];

    if( !( tAxis1 && tAxis2 )) {
      return tValueArray; // too early to recompute, caller must try again later.
    }
    var tNumCells1 = tAxis1.get('numberOfCells') || 1,
        tNumCells2 = tAxis2.get('numberOfCells') || 1;
    var totalCells = tNumCells1*tNumCells2;
    var i, tCellIndex;

    // initialize the values
    for( i=0; i<totalCells; ++i ) {
      tValueArray.push({ count: 0, selectedCount: 0,
        primaryCell: Math.floor(i/tNumCells2), secondaryCell: i%tNumCells2 });
    }

    // compute count of cases in each cell, excluding missing values
    this.forEachBivariateCaseDo( function( iCase, iIndex, iPrimaryCell, iSecondaryCell) {
      tCellIndex = iPrimaryCell*tNumCells2 + iSecondaryCell;
      if( isFinite( tCellIndex) && DG.MathUtilities.isInIntegerRange( tCellIndex, 0, totalCells )) {
        var iValue = tValueArray[ tCellIndex ];
        iValue.count += 1;
      }
    });

    if( iForSelectionOnly) {
      // compute count of cases in each cell, excluding missing values
      this.forEachBivariateCaseDo(function (iCase, iIndex, iPrimaryCell, iSecondaryCell) {
        tCellIndex = iPrimaryCell * tNumCells2 + iSecondaryCell;
        if (isFinite(tCellIndex) && DG.MathUtilities.isInIntegerRange(tCellIndex, 0, totalCells)) {
          var iValue = tValueArray[tCellIndex];
          iValue.selectedCount += 1;
        }
      }, iForSelectionOnly);
    }

    return tValueArray;
  },

  /**
    Build a sparse 3-dim matrix of cases.
  */
  _buildCache: function() {
    var tCachedCells = [],
        tCachedIndex = [],
        tMaxInCell = 0;
    this.forEachBivariateCaseDo( function( iCase, iIndex, iPrimaryCell, iSecondaryCell) {
      var tCellLength;
      // forEachBivariateCaseDo() assumes that if there is no attribute on the secondary axis,
      // then there is no secondary cell. This code assumes that if there's no secondary cell
      // then there's nothing to cache. In the case of a computed bar chart we want to cache
      // the primary cell counts even when there's no explicit secondary cell.
      iSecondaryCell = iSecondaryCell || 0;
      if(SC.none( iPrimaryCell) || SC.none( iSecondaryCell))
        return;

      if( SC.none( tCachedCells[ iPrimaryCell]))
        tCachedCells[ iPrimaryCell] = [];
      if( SC.none( tCachedCells[ iPrimaryCell][ iSecondaryCell]))
        tCachedCells[ iPrimaryCell][ iSecondaryCell] = [];
      tCachedCells[ iPrimaryCell][iSecondaryCell].push( { theCase: iCase, caseIndex: iIndex });
      tCellLength = tCachedCells[ iPrimaryCell][ iSecondaryCell].length;
      tCachedIndex[ iIndex] = { primaryCell: iPrimaryCell, secondaryCell: iSecondaryCell, indexInCell: tCellLength - 1 };
      tMaxInCell = Math.max( tMaxInCell, tCellLength);
    });
    this._cacheIsValid = true;
    this.beginPropertyChanges();
      this.set('cachedCells', tCachedCells);
      this.set('cachedIndex', tCachedIndex);
      this.set('_maxInCell', tMaxInCell);
    this.endPropertyChanges();
  },

  /**
   If we need to make a count model, do so. In any event toggle its visibility.
   Note that the command is executed at the GraphModel level.
   */
  toggleDisplayAsBarChart: function() {
    this.toggleProperty('displayAsBarChart');
  },

  configurationDescriptions: function() {
    var this_ = this,
        tDescriptions = arguments.callee.base.apply(this,arguments);
    tDescriptions.push(
        {
          constructorClass: SC.CheckboxView,
          properties: {
            title: 'DG.Inspector.graphBarChart',
            value: this_.get('displayAsBarChart'),
            classNames: 'dg-graph-barchart-check'.w(),

            valueDidChange: function () {
              this_.toggleDisplayAsBarChart();
              DG.mainPage.mainPane.hideInspectorPicker();
            }.observes('value')
          }
        }
    );
    return tDescriptions;
  }.property(),

  /**
    @property{Boolean}
    @private
  */
  _cacheIsValid: false,
  /**
    @property{Number}
    @private
  */
  _maxInCell: 0

});

/**
  class method called before plot creation to make sure roles are correct
  @param {DG.GraphDataConfiguration}
*/
DG.ChartModel.configureRoles = function( iConfig) {
  var tXType = iConfig.get('xType'),
      tAxisKey = (tXType === DG.Analysis.EAttributeType.eCategorical) ? 'x' : 'y',
      tOtherAxisKey = (tAxisKey === 'x') ? 'y' : 'x';
  iConfig.setPath( tAxisKey + 'AttributeDescription.role',
                    DG.Analysis.EAnalysisRole.ePrimaryCategorical);
  iConfig.setPath( tOtherAxisKey + 'AttributeDescription.role',
                    DG.Analysis.EAnalysisRole.eSecondaryCategorical);
};

/* >>>>>>>>>> BEGIN source/components/graph/plots/numeric_plot_model_mixin.js */
// ==========================================================================
//                      DG.NumericPlotModelMixin
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class  Mixin to encapsulate certain behaviors that plot models with one or two numeric
    axes have in common.
*/
DG.NumericPlotModelMixin =
{
  /**
    Animate a dilation of the plot around the given fixed point.
    @param {Array of {DG.GraphTypes.EPlace}}
    @param {x:{Number}, y:{Number}}
    @param {Number}
  */
  doDilation: function( iPlaces, iFixedPoint, iFactor) {
    var this_ = this,
      tAxisInfoArray = [];

    function computeNewBounds( iAxis, iFixedCoord) {
      if( SC.none( iAxis))
        return;

      var tNewBounds = iAxis.computeBoundsForDilation( iFixedCoord, iFactor);
      tAxisInfoArray.push ( { axis: iAxis, newBounds: tNewBounds });
    }

    iPlaces.forEach( function( iPlace) {
      var tCoord = (iPlace === DG.GraphTypes.EPlace.eX) ? iFixedPoint.x : iFixedPoint.y;
      computeNewBounds( this_.getAxisForPlace( iPlace), tCoord);
    });

    if( SC.none( this.plotAnimator))
      this.plotAnimator = DG.GraphAnimator.create( { plot: this });
    this.plotAnimator.set('axisInfoArray', tAxisInfoArray).animate();
  },

  /**
    Each axis should rescale based on the values to be plotted with it.
    @param{Array of {DG.GraphTypes.EPlace}}
    @param{Boolean} Default is false
    @param{Boolean} Default is true
  */
  doRescaleAxesFromData: function( iPlaces, iAllowScaleShrinkage, iAnimatePoints, iUserAction) {
    if( this.getPath('dataConfiguration.cases').length() === 0)
      return; // Don't rescale if there are no cases
    var this_ = this,
      tAxisInfoArray = [],
      tOldBoundsArray = [];

    function setNewBounds( iPlace, iAxis, isPseudoNumeric) {
      var tAttribute = iAxis && iAxis.getPath('attributeDescription.attribute'),
          // a pseudo-numeric axis is a numeric axis that doesn't correspond to an attribute
          tIsPseudoNumeric = isPseudoNumeric || (iAxis &&
              iAxis.constructor === DG.CountAxisModel);
      if( !iAxis || !iAxis.setDataMinAndMax ||
          (!tIsPseudoNumeric && tAttribute === DG.Analysis.kNullAttribute)) {
        tOldBoundsArray.push({}); // Must have an object here or things get out of sync
        return;
      }
      iAxis.set('scaleCanAnimate', SC.none( tAttribute) || tAttribute.get('type') !== 'qualitative');

      // For the purpose of getting new bounds, if we're working with the y-axis of a plot that
      // is plotting on y2, we have to change iPlace so we get the right min and max.
      if( iPlace === DG.GraphTypes.EPlace.eY && this_.get('verticalAxisIsY2'))
        iPlace = DG.GraphTypes.EPlace.eY2;

      var tMinMax = this_.getDataMinAndMaxForDimension( iPlace),
          tOldLower = iAxis.get('lowerBound'),
          tOldUpper = iAxis.get('upperBound'),
          tNewLower, tNewUpper;
      tOldBoundsArray.push( { lower: tOldLower, upper: tOldUpper });
      iAxis.setDataMinAndMax( tMinMax.min, tMinMax.max, iAllowScaleShrinkage || false);
      tNewLower = iAxis.get('lowerBound');
      tNewUpper = iAxis.get('upperBound');
      tAxisInfoArray.push ( { axis: iAxis, newBounds: { lower: tNewLower, upper: tNewUpper } });
    }

    function setOldBounds( iAxis, iBounds) {
      if( !SC.none( iAxis))
        iAxis.setLowerAndUpperBounds(iBounds.lower, iBounds.upper);
    }

    function boundsChanged( iAxisInfoArray, iOldBoundsArray) {
      var tIndex;
      for( tIndex = 0; tIndex < iAxisInfoArray.length; tIndex++) {
        if( !SC.none(iOldBoundsArray[ tIndex].lower) && !SC.none(iOldBoundsArray[ tIndex].upper) &&
            ((iAxisInfoArray[ tIndex].newBounds.lower !== iOldBoundsArray[ tIndex].lower) ||
            (iAxisInfoArray[ tIndex].newBounds.upper !== iOldBoundsArray[ tIndex].upper)))
          return true;
      }
      return false;
    }

    function axisForPlace( iPlace) {
      var tPlace = iPlace;
      if( this_.get('verticalAxisIsY2')) {
        switch( iPlace) {
          case DG.GraphTypes.EPlace.eY:
              tPlace = DG.GraphTypes.EPlace.eY2;
            break;
          case DG.GraphTypes.EPlace.eY2:
              tPlace = DG.GraphTypes.EPlace.eUndefined;
            break;
        }
      }
      return this_.getAxisForPlace( tPlace);
    }

    // Body of rescaleAxesFromData
    if( SC.none( iAnimatePoints))
      iAnimatePoints = true;

    DG.UndoHistory.execute(DG.Command.create({
      name: 'axis.rescaleFromData',
      undoString: 'DG.Undo.axisRescaleFromData',
      redoString: 'DG.Redo.axisRescaleFromData',
      causedChange: iUserAction,        // if this was not triggered by user, don't add to undo stack
      log: "Rescale axes from data",
      executeNotification: {
        action: 'notify',
        resource: 'component',
        values: {
          operation: 'rescaleGraph',
          type: 'DG.GraphView'
        }
      },
      execute: function() {

        iPlaces.forEach( function( iPlace) {
          setNewBounds( iPlace, axisForPlace( iPlace), this_.get('isBarHeightComputed'));
        });

        // we store clones of the data, because if/when we animate, the two arrays we need are emptied
        this._undoData = { bounds: tOldBoundsArray.slice(), places: iPlaces.slice() };

        if( boundsChanged( tAxisInfoArray, tOldBoundsArray)) {
          if (iAnimatePoints) {
            DG.sounds.playMixup();
            this_.set('isAnimating', true);    // Signals view that axes are in new state and points
            // can be animated to new coordinates
            // We'll go through both iPlaces and tOldBoundsArray in reverse order
            while ((iPlaces.length > 0) && (tOldBoundsArray.length > 0)) {
              setOldBounds(axisForPlace(iPlaces.pop()), tOldBoundsArray.pop());
            }

            if (SC.none(this_.plotAnimator))
              this_.plotAnimator = DG.GraphAnimator.create({plot: this_});
            this_.plotAnimator.set('axisInfoArray', tAxisInfoArray).animate(this_, this_.onRescaleIsComplete);
          }
          else {
            // Make sure there is no pending animation
            if( this_.plotAnimator)
              this_.plotAnimator.reset();
            // Without animation, set the axes to the correct bounds
            tAxisInfoArray.forEach( function( iInfo) {
              iInfo.axis.setDataMinAndMax( iInfo.newBounds.lower, iInfo.newBounds.upper);
            });
          }
        }
      },
      undo: function() {
        if (this._undoData) {
          this._undoData.places.forEach( function( iPlace, i) {
            var iAxis = axisForPlace( iPlace),
                data  = this._undoData.bounds[i];
            if (iAxis && data)
              iAxis.setLowerAndUpperBounds( data.lower, data.upper);
          }.bind(this));
          this_.onRescaleIsComplete();
        }
      },
      redo: function() {
        if (this._undoData) {
          this._undoData.places.forEach( function( iPlace) {
            setNewBounds( iPlace, axisForPlace( iPlace), this_.get('isBarHeightComputed'));
          });

          // Only animate if the bounds have changed
          if( iAnimatePoints && boundsChanged( tAxisInfoArray, tOldBoundsArray)) {
            DG.sounds.playMixup();
            this_.set('isAnimating', true);    // Signals view that axes are in new state and points
                                               // can be animated to new coordinates
            // We'll go through both iPlaces and tOldBoundsArray in reverse order
            while( (iPlaces.length > 0) && (tOldBoundsArray.length > 0)) {
              setOldBounds( axisForPlace( iPlaces.pop()), tOldBoundsArray.pop());
            }

            if( SC.none( this_.plotAnimator))
              this_.plotAnimator = DG.GraphAnimator.create( { plot: this_ });
            this_.plotAnimator.set('axisInfoArray', tAxisInfoArray).animate( this_, this_.onRescaleIsComplete);
          }
        }
      },
    }));
  },

    /**
     * Subclasses that have something to do after axes are rescaled should override.
     */
    onRescaleIsComplete: function() {
    }

};

/* >>>>>>>>>> BEGIN source/components/graph/plots/bar_chart_base_model.js */
// ==========================================================================
//                          DG.BarChartBaseModel
//
//  Author:   William Finzer, Kirk Swenson
//
//  Copyright (c) 2020 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/plots/chart_model');
sc_require('components/graph/plots/numeric_plot_model_mixin');

/** @class  DG.BarChartBaseModel - The model for a plot with categorical axes

 @extends DG.ChartModel
 */
DG.BarChartBaseModel = DG.ChartModel.extend(DG.NumericPlotModelMixin,
    /** @scope DG.BarChartBaseModel.prototype */
    {
      /**
       * Override
       * @property {Boolean}
       */
      displayAsBarChart: true,

      /**
       * For non-computed bar charts, whether to show count or percent
       * @property {DG.Analysis.EBreakdownType}
       */
      breakdownType: DG.Analysis.EBreakdownType.eCount,

      /**
       * Whether the bar height is computed from a formula.
       * @property {Boolean}
       */
      isBarHeightComputed: false,

      /**
       * We want an 'other' axis for count or percent.
       * @property {Boolean}
       */
      wantsOtherAxis: true,

      /**
       * When making a copy of a plot (e.g. for use in split) the returned object
       * holds those properties that should be assigned to the copy.
       * @return {{}}
       */
      getPropsForCopy: function() {
        var tResult = arguments.callee.base.apply(this,arguments);
        return $.extend( tResult, {
          breakdownType: this.get('breakdownType')
        });
      },

      /**
       *
       * @param iPlace {DG.GraphTypes.EPlace}
       * @return { class }
       */
      getDesiredAxisClassFor: function( iPlace) {
        if( iPlace === this.get('primaryAxisPlace'))
          return DG.CellAxisModel;
        return arguments.callee.base.apply(this,arguments);
      },

      /**
       * Change the value corresponding to the given key
       * @param iKey {String} Should be 'breakdownType'
       * @param iValue {Boolean}
       */
      changeBreakdownType: function( iKey, iValue) {
        var tInitialValue = this.get(iKey);
        DG.UndoHistory.execute(DG.Command.create({
          name: "graph.changeBreakdownType",
          undoString: 'DG.Undo.graph.changeBreakdownType',
          redoString: 'DG.Redo.graph.changeBreakdownType',
          log: ("change %@ from %@ to %@").fmt(iKey, tInitialValue, iValue),
          execute: function() {
            this.set(iKey, iValue);
          }.bind(this),
          undo: function() {
            this.set(iKey, tInitialValue);
          }.bind(this)
        }));
      },

      lastConfigurationControls: function () {
        var tControls = arguments.callee.base.apply(this,arguments),
            this_ = this,
            kRowHeight = 18,
            kChartRadioCount = 0,     // === DG.Analysis.EBreakdownType.eCount
            kChartRadioPercent = 1,   // === DG.Analysis.EBreakdownType.ePercent
            kChartRadioFormula = 2;

        function mapModelValuesToRadioValue() {
          return this_.get('isBarHeightComputed')
                  ? kChartRadioFormula
                  : this_.get('breakdownType');
        }

        tControls.push(
            SC.LabelView.create({
              layout: {height: kRowHeight},
              value: 'DG.Inspector.displayScale',
              localize: true
            })
        );

        tControls.push(
            SC.RadioView.create({
              itemTitleKey: 'title',
              itemValueKey: 'value',
              items: [
                { value: kChartRadioCount, title: 'DG.Inspector.graphCount'.loc() },
                { value: kChartRadioPercent, title: 'DG.Inspector.graphPercent'.loc() },
                { value: kChartRadioFormula, title: 'DG.Inspector.graphFormula'.loc() }
              ],
              value: mapModelValuesToRadioValue(this_),
              layoutDirection: SC.LAYOUT_VERTICAL,
              layout: {height: 3.5 * kRowHeight},
              classNames: 'dg-inspector-radio'.w(),
              valueDidChange: function () {
                var currValue = mapModelValuesToRadioValue(this_);
                switch(this.value) {
                  case kChartRadioCount:
                  case kChartRadioPercent:
                    if (currValue !== kChartRadioFormula) {
                      // we're not switching plot type
                      this_.changeBreakdownType('breakdownType', this.value);
                      break;
                    }
                    // so it will be copied to the new plot
                    this_.set('breakdownType', this.value);
                    /* falls through */
                  case kChartRadioFormula:
                    // we're switching to/from a computed bar chart
                    this_.set('isBarHeightComputed', this.value === kChartRadioFormula);
                    DG.mainPage.mainPane.hideInspectorPicker();
                    break;
                }
              }.observes('value')
            })
        );
        return tControls;
      }.property('plot'),

      /**
       Each axis should rescale based on the values to be plotted with it.
       @param iAllowScaleShrinkage{Boolean} Default is false
       @param iAnimatePoints {Boolean} Default is true
       @param iLogIt {Boolean} Default is false
       @param iUserAction {Boolean} Default is false
       */
      rescaleAxesFromData: function (iAllowScaleShrinkage, iAnimatePoints, iLogIt, iUserAction) {
        if (iAnimatePoints === undefined)
          iAnimatePoints = true;
        this.doRescaleAxesFromData([this.get('secondaryAxisPlace')], iAllowScaleShrinkage, iAnimatePoints, iUserAction);
        if (iLogIt)
          DG.logUser("rescaleBarChart");
      },

      /**
       * @return {Object} the saved data.
       */
      createStorage: function () {
        var tStorage = arguments.callee.base.apply(this,arguments);

        tStorage.breakdownType = this.breakdownType;

        return tStorage;
      },

      /**
       * @param iStorage
       */
      restoreStorage: function (iStorage) {
        arguments.callee.base.apply(this,arguments);
        if (!SC.none(iStorage.breakdownType)) {
          this.set( 'breakdownType', iStorage.breakdownType);
        }
      }


    });

/* >>>>>>>>>> BEGIN source/components/graph_map_common/plot_layer.js */
// ==========================================================================
//                            DG.PlotLayer
//
//  Author:   William Finzer
//
//  Copyright ©2014 Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('alpha/destroyable');
sc_require('components/graph/utilities/plot_utilities');
/*global RTree:true */

/** @class  DG.PlotLayer - The base class for plotting points using Raphael.

 @extends SC.Object.extend
 */
DG.PlotLayer = SC.Object.extend(DG.Destroyable,
    /** @scope DG.PlotLayer.prototype */
    {
      autoDestroyProperties: ['_dataTip'],

      /**
       * The paper we draw on is shared, not owned.
       * @property {DG.RaphaelBase}
       */
      paperSource: null,

      /**
       * @property {Raphael paper}
       */
      paper: function () {
        return this.getPath('paperSource.paper');
      }.property('paperSource'),

      paperDidChange: function () {
        this.notifyPropertyChange('paper');
      }.observes('*paperSource.paper'),

      plottedElements: function () {
        return this.get('paperSource').getPlottedElements( this.plotLayerNumber);
      }.property('paper'),

      plotLayerNumber: 0,

      /**
       * @property {DG.LayerManager}
       */
      layerManager: function () {
        return this.getPath('paperSource.layerManager');
      }.property(),

      layerManagerDidChange: function () {
        this.notifyPropertyChange('layerManager');
      }.observes('*paperSource.layerManager'),

      /**
       * Get from paperSource
       * @property {}
       */
      frame: function () {
        return this.getPath('paperSource.frame');
      }.property(),

      frameDidChange: function () {
        this.notifyPropertyChange('frame');
      }.observes('*paperSource.frame'),

      /**
       * Get from paperSource
       * @property {}
       */
      elementsToClear: function () {
        return this.getPath('paperSource._elementsToClear');
      }.property(),

      elementsToClearDidChange: function () {
        this.notifyPropertyChange('elementsToClear');
      }.observes('*paperSource._elementsToClear'),

      /**
       * @private
       * @property { DG.PointDataTip } for displaying attributes of whatever is underneath the mouse
       */
      _dataTip: null,

      /**
       * Lazy instantiation.
       * @property {DG.PointDataTip }
       */
      dataTip: function () {
        if (!this._dataTip) {
          this._dataTip = DG.PointDataTip.create({plotLayer: this, layerName: DG.LayerNames.kDataTip});
        }
        return this._dataTip;
      }.property(),

      /**
       * Since we are not a view, we notify so that the view that owns us can take
       * appropriate action.
       */
      displayDidChange: function () {
        this.notifyPropertyChange('plotDisplayDidChange');
      }.observes('model.isVisible'),

      /**
       The model on which this view is based.
       @property { DG.PlotModel|DG.MapLayerModel }
       */
      model: null,

      /**
       @property { DG.DataContext }  The data context
       */
      dataContext: function () {
        return this.getPath('model.dataContext');
      }.property(),

      dataContextDidChange: function () {
        this.notifyPropertyChange('dataContext');
      }.observes('*model.dataContext'),

      caseOrderDidChange: function () {
        this._mustMoveElementsToNewCoordinates = true;
      },

      selection: null,
      selectionBinding: '*model.casesController.selection',

      /**
       * If defined, this function gets called after cases have been added or values changed, but only once,
       * and only after a sufficient time has elapsed.
       * @property { Function }
       */
      cleanupFunc: null,

      /**
       * Wait at least this long before calling cleanupFunc
       * @property {Number} in milliseconds
       */
      cleanupDelay: 300,

      /**
       * While waiting to do a cleanup, call installCleanup at this interval to check to see if now is the time.
       * @property {Number} in milliseconds
       */
      cleanupInterval: 300,

      /**
       * Are we already awaiting an opportunity to cleanup?
       * @property {Boolean}
       */
      waitingForCleanup: false,

      /**
       * Time at which the last call for a cleanup occurred.
       * @property {Number}
       */
      timeOfLastCleanupCall: null,

      /**
       * Used to schedule cleanup. We hold onto it so we can invalidate it during destroy.
       * @property {SC.Timer}
       */
      cleanupTimer: null,

      installCleanup: function () {
        if (!this.cleanupFunc)
          return;

        var checkTime = function () {
          var tNow = Date.now();
          if (tNow - this.timeOfLastCleanupCall > this.cleanupDelay) {
            this.cleanupFunc();
            this.waitingForCleanup = false;
            this.cleanupTimer = null;
          }
          else {
            this.cleanupTimer = SC.Timer.schedule({target: this, action: checkTime, interval: this.cleanupInterval});
          }
        };

        this.timeOfLastCleanupCall = Date.now();
        if (!this.waitingForCleanup) {
          this.waitingForCleanup = true;
          this.cleanupTimer = SC.Timer.schedule({target: this, action: checkTime, interval: this.cleanupInterval});
        }
      },

      /**
       @property { String }
       */
      changeKey: 'dataDidChange',

      /**
       * @property { Number } current point radius of cases being displayed.
       */
      _pointRadius: DG.PlotUtilities.kPointRadiusMax,

      /**
       True if rendered content is up-to-date, false if redraw is required.
       @property { Boolean }
       */
      _isRenderingValid: false,

      blankDropHint: 'DG.GraphView.dropInPlot',

      /**
       * Refers specifically to a legend attribute
       * @property {DG.Attribute}
       */
      plottedAttribute: function () {
        return this.getPath('model.dataConfiguration.legendAttributeDescription.attribute');
      }.property(),

      /**
       Prepare dependencies.
       */
      init: function () {
        arguments.callee.base.apply(this,arguments);
        if (this.get('model')) {
          // Required for initialization.
          this.modelDidChange();
        }
      },

      /**
       Prepare dependencies.
       */
      modelDidChange: function (iSource, iKey) {
        this.dataConfigurationDidChange(iSource, iKey);

        // We want dataDidChange to be called when cases change
        this.addObserver('model.dataConfiguration.cases', this, 'dataDidChange');
        this.addObserver('model.dataConfiguration.hiddenCases', this, 'dataDidChange');
        this.addObserver('model.dataConfiguration.dataContext.selectionChangeCount', this, 'selectionChangeCount');

        this._isRenderingValid = false;
      }.observes('model'),

      /**
       Here we set up observers so that if the length of a data array is changed, dataDidChange
       is called, and if a case value changes (which changes its 'revision' property), dataRangeDidChange
       gets called.
       */
      dataConfigurationDidChange: function (iSource, iKey) {
        // initialize point radius when attaching new set of cases, since dataDidChange() is not called then.
        this._pointRadius = this.calcPointRadius();

        this._isRenderingValid = false;
      },

      destroy: function () {
        if( this.get('paperSource')) {
          this.removePlottedElements(false, true);
        }
        this.removeObserver('model.dataConfiguration.cases', this, 'dataDidChange');
        this.removeObserver('model.dataConfiguration.hiddenCases', this, 'dataDidChange');
        this.removeObserver('model.dataConfiguration.dataContext.selectionChangeCount', this, 'selectionChangeCount');
        if (this.cleanupTimer)
          this.cleanupTimer.invalidate();
        this.hideDataTip();

        arguments.callee.base.apply(this,arguments);

        this.model = null;
      },

      /**
       Respond to DataContext notifications from the PlotModel.
       */
      handleDataContextNotification: function (iSource, iKey) {
        var tModel = this.get('model'),
            lastChange = tModel && tModel.get('lastChange'),
            operation = lastChange && lastChange.operation;

        // No response necessary if plot isn't affected.
        if (!tModel || !tModel.isAffectedByChange(lastChange))
          return;

        switch (operation) {
          case 'createCollection':
          case 'deleteCollection':
          case 'resetCollections':
            this.caseOrderDidChange(); // jshint ignore:line
            // Deliberate fallthrough
          case 'createCase':
          case 'createCases':
          case 'deleteCases':
            // usually dataDidChange, but derived classes can override
            var changeKey = this.get('changeKey');
            if (!SC.empty(changeKey)) {
              var handler = this[changeKey];
              if (handler)
                handler.call(this, this, iKey, operation);
            }
            break;
          case 'updateCases':
          case 'dependentCases':
          case 'createAttributes':
          case 'updateAttributes':
            this.dataRangeDidChange(this, 'revision', this, lastChange.indices);
            break;
          case 'moveAttribute':
            this.handleMoveAttribute();
            break;
          case 'moveCases':
            this.handleMoveCases();
            break;
        }
      }.observes('.model.lastChange'),

      /**
       Observer function triggered when the plot configuration changes.
       */
      plotConfigurationDidChange: function () {
        this._isRenderingValid = false;
        this._elementOrderIsValid = false;
        this.displayDidChange();
      }.observes('.model.plotConfiguration'),

      /**
       Observer function called when the view/paper is resized.
       */
      paperSizeDidChange: function () {
        this._isRenderingValid = false;
        this.displayDidChange();
      }.observes('paperSize'),

      selectionChangeCount: function () {
        this._elementOrderIsValid = false;
      },

      /**
       * subclasses will override as needed
       */
      handleMoveAttribute: function() {

      },

      /**
       * The order of cases has changed. Invalidating caches will get the cases in the correct order.
       * Drawing the data will force the graphic elements to correspond to correct cases. Finally,
       * signaling that selection changed will highlight the correct elements.
       * subclasses will override as needed
       */
      handleMoveCases: function() {
        this.getPath('model.dataConfiguration').invalidateCaches();
        this.drawData();
        this.selectionDidChange();
      },

      /**
       Give subclasses a chance to do whatever they need to do before we recompute all the
       point coordinates.
       */
      prepareToResetCoordinates: function () {
      },

      /**
       Utility function to be called when the coordinates of all circles must be updated.
       New circle elements will be created if necessary, but this method never removes
       elements so it cannot be used to handle deletion of cases.
       */
      refreshCoordinates: function () {
        if (this.get('paper'))
          this.drawData();
      },

      /**
       * May be overridden to make sure a re-used element has the correct attributes for this plot view
       * @param iCase {DG.Case}
       * @param iIndex {Number}
       */
      assignElementAttributes: function (iElement, iIndex, iAnimate) {
        // Remove event handlers
        iElement.undrag();  // No-op if no drag handlers
        if (iElement.events) {
          iElement.events.forEach(function (iHandler) {
            iHandler.unbind();
          });
          iElement.events.length = 0;
        }
        var this_ = this;
        iElement.addClass(DG.PlotUtilities.kColoredDotClassName)
            .attr({cursor: 'pointer'})
            .mousedown(function (iEvent) {
              SC.run(function () {
                this_.get('model').selectCaseByIndex(iIndex, iEvent.shiftKey);
              });
            });
        iElement.index = iIndex;
        if (iAnimate)
          DG.PlotUtilities.doCreateCircleAnimation(iElement);
        return iElement;
      },

      callCreateElement: function (iCase, iIndex, iAnimate, iIsVisible) {
        var tPlottedElements = this.get('plottedElements'),
            tLayerManager = this.get('layerManager'),
            tDestLayer = tLayerManager.getLayer(DG.LayerNames.kPoints),
            tElement,
            tFromLayer;
        // Note that it's possible that an element has been wiped out through a remove. A test for that
        //  is to check the node property of the element.
        if (tPlottedElements[iIndex] && tPlottedElements[iIndex].node) {
          tElement = tPlottedElements[iIndex];
          tFromLayer = tLayerManager.layerForElement( tElement);
        }
        else {
          tElement = this.createElement(iCase, iIndex, iAnimate);
          tPlottedElements[iIndex] = tElement;
        }
        if( tFromLayer) {
          tLayerManager.moveElementFromTo( tElement, tFromLayer, tDestLayer);
        }
        else {
          tDestLayer.push(tElement);
        }
        this._elementOrderIsValid = false; // So updateSelection will work
        return this.assignElementAttributes(tElement, iIndex, iAnimate, iIsVisible);
      },

      /**
       * Compute the color and transparency of the stroke for points based on the presence of a legend
       * attribute and on the existence of model parameters.
       * @return { strokeColor: {Color}, strokeTransparency {Number}}
       */
      getStrokeParams: function () {
        var tModel = this.get('model');
        DG.assert(tModel);
        return {
          strokeColor: tModel.get('strokeColor'),
          strokeTransparency: tModel.get('strokeTransparency'),
          strokeSameAsFill: tModel.get('strokeSameAsFill')
        };
      },

      /**
       Plots that show data as points should be able to use this as is. Others will probably
       override.
       */
      dataDidChange: function (iObject, iProperty, iOperation) {
        if (!this.readyToDraw())
          return;   // not ready to create elements yet
        var tCases = this.getPath('model.cases'),
            tRC = this.createRenderContext(),
            tWantNewPointRadius = (this._pointRadius !== this.calcPointRadius());
        // We don't redraw if tCases is undefined or tRC is null. This can happen during the
        // deletion of the plot model
        if (!tCases || !tRC)
          return;

        this._elementOrderIsValid = false;
        // update the point radius before creating or updating plotted elements
        if (tWantNewPointRadius) {
          this._pointRadius = this.calcPointRadius();
          this._isRenderingValid = false;
          this.displayDidChange();
        }
        // update adornments when cases added or removed
        // note: don't rely on tDataLength != tPlotElementLength test for this
        this.updateAdornments();

        var tDataLength = tCases && tCases.get('length'),
            tPlottedElements = this.get('plottedElements'),
            tPlotElementLength = tPlottedElements.length,
            tLayerManager = this.get('layerManager'),
            tIndex;

        // for any new cases
        if (tDataLength > tPlotElementLength) {
          // create plot elements for added cases
          for (tIndex = tPlotElementLength; tIndex < tDataLength; tIndex++) {
            var tCase = tCases.at(tIndex);
            if (tCase) {
              this.callCreateElement(tCase, tIndex, this.animationIsAllowable());
              this.setCircleCoordinate(tRC, tCase, tIndex);
            }
          }
        }
        // Get rid of plot elements for removed cases and update all coordinates
        if (tDataLength < tPlotElementLength) {
          for (tIndex = tDataLength; tIndex < tPlotElementLength; tIndex++) {
            // It can happen during closing of a document that the elements no longer exist, so we have to test
            if (!SC.none(tPlottedElements[tIndex])) {
              tPlottedElements[tIndex].stop();
              tLayerManager.removeElement(tPlottedElements[tIndex]);
              DG.PlotUtilities.doHideRemoveAnimation(tPlottedElements[tIndex], tLayerManager);
            }
          }
          tPlottedElements.length = tDataLength;

        }
        if ((iProperty === 'hiddenCases') || (iOperation === 'deleteCases')) {
          this.notifyPropertyChange('plotDisplayDidChange');
          /*
                this.prepareToResetCoordinates();
                tCases.forEach(function (iCase, iIndex) {
                  this_.setCircleCoordinate(tRC, tCases.at(iIndex), iIndex);
                });
          */
        }

        this._isRenderingValid = false;
        if (iProperty === 'hiddenCases') {
          this.updateSelection();
        }

        // There might be some cleanup that has to be done after a suitable waiting time
        this.installCleanup();
      },

      /**
       Subclasses should call arguments.callee.base.apply(this,arguments)
       */
      dataRangeDidChange: function (iSource, iQuestion, iKey, iChanges) {
        this.removeExtraElements();
        this.updateAdornments();
        this.get('dataTip').handleChanges(iChanges);
        this.updateSelection();
      },

      /**
       * Subclasses may override
       */
      updateAdornments: function () {

      },

      /**
       * We determine if sufficient time has passed since the last call to allow (expensive) animation
       * to occur in createCircle.
       * Note that this side effects _createAnimationOn and _timeLastCreate.
       * @return {Boolean}
       */
      animationIsAllowable: function () {
        var tNow = Date.now(),
            tDelta = tNow - this._timeLastCreate;
        if (tDelta < DG.PlotUtilities.kDefaultAnimationTime) {
          this._createAnimationOn = false;
        }
        else if (tNow - this._timeLastCreate > this._kAllowableInterval)
          this._createAnimationOn = true;
        this._timeLastCreate = tNow;
        return this._createAnimationOn;
      },

      /**
       * If we have paper, we're ready to draw.
       * @return {Boolean}
       */
      readyToDraw: function () {
        return !SC.none(this.get('paper')) && !SC.none(this.getPath('model.dataConfiguration'));
      },

      /**
       * Properties having to do with determining whether createElement animation should be turned on
       */

      /**
       * The last time we called createElement. If sufficient time has elapsed, we can turn on animation
       */
      _timeLastCreate: null,

      /**
       * Controls whether we allow createElement to do an animation. Turned off when animations are overlapping.
       * Turned back on when sufficient time has elapsed.
       */
      _createAnimationOn: true,

      _kAllowableInterval: 1000, // milliseconds

  // Private properties

  _elementOrderIsValid: false,  // Set to false when selection changes
  _mustMoveElementsToNewCoordinates: false,  // Set to true when collection is created or deleted

  /**
   * Remove elements in plottedElements beyond the length of the array of cases
   */
  removeExtraElements: function() {

    var tCasesLength = this.getPath('model.cases').length(),

        tPlottedElements = this.get('plottedElements'),
        tPlotElementLength = tPlottedElements.length,
        tLayerManager = this.get('layerManager');
    for( var tIndex = tCasesLength; tIndex < tPlotElementLength; tIndex++) {
      DG.PlotUtilities.doHideRemoveAnimation( tPlottedElements[ tIndex], tLayerManager);
    }

  },

      /**
       Subclasses will override
       */
      drawData: function drawData() {
        if (!this.get('paper')) return; // abort if not yet ready to draw

        var this_ = this,
            tCases = this.getPath('model.cases'),
            tRC = this.createRenderContext(),
            tPlottedElements = this.get('plottedElements');

        if (SC.none(tCases) || !tRC)
          return; // No cases, nothing to draw or can't create render context

        // remove invalid case elements
        this._mustMoveElementsToNewCoordinates = false;
        tRC.casesAdded = true; // ensure that cases are re-created below

        // remove extra case elements
        if (tRC.casesRemoved) {
          this.removeExtraElements();
        }

        // update the cached circle size (dependent on the number of cases)
        if (tRC.casesAdded) {
          this._pointRadius = this.calcPointRadius();
        }

        // If we're going to be adding cases, then we'll want to call updateSelection because
        // these new cases may be selected. Setting _elementOrderIsValid to false accomplishes this.
        if (tPlottedElements.length < tCases.get('length'))
          this_._elementOrderIsValid = false;

        // update case elements, adding them if necessary
        if( tRC.updatedPositions || tRC.updatedColors || tRC.casesAdded || this._mustMoveElementsToNewCoordinates) {
          this.resetCoordinates(tCases, tRC);
        }
      },

      resetCoordinates: function (iCases, iRC) {
        var tPlotElementLength = this.get('plottedElements').length;
        this.prepareToResetCoordinates();
        iCases.forEach(function (iCase, iIndex) {
          if (iIndex >= tPlotElementLength)
            this.callCreateElement(iCase, iIndex, true, iRC.isVisible);
          this.setCircleCoordinate(iRC, iCase, iIndex);
        }.bind(this));
        this._mustMoveElementsToNewCoordinates = false;
      },

      /**
       Set our _isRenderingValid flag when rendering is complete.
       */
      didDraw: function () {
        arguments.callee.base.apply(this,arguments);
        this._isRenderingValid = true;
      },

      /**
       * Remove all the point elements
       */
      clear: function () {
        var tLayerManager = this.get('layerManager'),
            tPlottedElements = this.get('plottedElements');
        tPlottedElements.forEach(function (iElement) {
          tLayerManager.removeElement(iElement); // remove from plot
        });
      },
      /**

       */
      selectionDidChange: function () {
        this._elementOrderIsValid = false;
        this.updateSelection();
        this._isRenderingValid = false;
        if (this.getPath('model.enableMeasuresForSelection'))
          this.updateAdornments();
      }.observes('selection'),

      /**
       Get case icon CSS class; extended objects can override for different look to elements.
       @param {boolean} iIsSelected Is the case selected?
       @param {boolean} iIsColored Is the case one whose color is given by a legend attribute (defaults to false)
       @returns {string}
       */
      getPlottedElementClass: function (iIsSelected, iIsColored) {
        return (iIsColored ?
            (iIsSelected ? DG.PlotUtilities.kSelectedColoredDotClassName : DG.PlotUtilities.kColoredDotClassName) :
            (iIsSelected ? DG.PlotUtilities.kSelectedDotClassName : DG.PlotUtilities.kDotClassName));
      },

      /**
       For each case, set the fill of its corresponding point to show its selection state
       */
      updateSelection: function () {
        if (!this.get('model'))
          return;   // because this can get called by pending changes after I have been destroyed
        if (this._elementOrderIsValid)
          return;
        if (!this.get('paper'))
          return;

        var this_ = this,
            tPlottedElements = this.get('plottedElements'),
            tSelection = this.getPath('model.selection'),
            // Points are 'colored' if there is a legend or if there is more than one plot
            tIsColored = (this.getPath('model.dataConfiguration.legendAttributeDescription.attribute') !==
                DG.Analysis.kNullAttribute) ||
                (this.get('numPlots') > 1),
            tLayerManager = this.get('layerManager'),
            tCases = this.getPath('model.cases'),
            tUnselectedRadius = this._pointRadius,
            tZeroElement = tPlottedElements[0] && tPlottedElements[0].node,
            tIsRect = tZeroElement && tZeroElement.constructor === SVGRectElement,
            tSelectedRadius = tUnselectedRadius + DG.PlotUtilities.kPointRadiusSelectionAddend;

        if (!tCases || !tSelection)
          return;

        if (this._mustMoveElementsToNewCoordinates) {
          this.resetCoordinates(tCases, this.createRenderContext());
        }

        if (tIsRect) {
          tSelectedRadius = tUnselectedRadius = 0.1;
        }
        tCases.forEach(function (iCase, iIndex) {
          var tIsSelected, tElement, tFrom, tTo, tClass, tRadius,
              tTransform = '';
          // We sometimes get here with fewer plotted elements than cases,
          // perhaps when newly added cases don't have plottable values.
          if ((iIndex < tPlottedElements.length) && tPlottedElements[iIndex]) {
            tElement = tPlottedElements[iIndex];
            tIsSelected = tSelection.indexOf(iCase) >= 0;
            tFrom = tIsSelected ? DG.LayerNames.kPoints : DG.LayerNames.kSelectedPoints;
            tTo = tIsSelected ? DG.LayerNames.kSelectedPoints : DG.LayerNames.kPoints;
            tClass = this_.getPlottedElementClass(tIsSelected, tIsColored);
            tRadius = tIsSelected ? tSelectedRadius : tUnselectedRadius;
            if (!tElement.hasClass(tClass)) {
              if (tIsSelected) {
                tElement._selected = true;
                tTransform = tElement.transform();
                tElement.transform('');
              }
              else
                delete tElement._selected;
              DG.PlotUtilities.kDotClasses.forEach(function (iClass) {
                tElement.removeClass(iClass);
              });
              tElement.addClass( tClass);
              tLayerManager.moveElementFromTo(tElement, tFrom, tTo);
              tElement.attr({r: tRadius});
              if (tIsSelected)
                tElement.transform(tTransform);
            }
          }
        });
        this._elementOrderIsValid = true;
      },

      _selectionTree: null,

      preparePointSelection: function () {

        var doInsertion = function (iX, iY, iCase) {
          this._selectionTree.insert({
                x: iX,
                y: iY,
                w: 1,
                h: 1
              },
              iCase
          );
        }.bind(this);

        var tCases = this.getPath('model.cases'),
            tPlottedElements = this.get('plottedElements'),
            tElementsAreRects = tPlottedElements.length > 0 &&
                tPlottedElements[0][0].constructor === SVGRectElement;

        this._selectionTree = new RTree();
        tPlottedElements.forEach(function (iElement, iIndex) {
          var tCase = tCases.unorderedAt(iIndex);
          if (tCase) {  // Some plottedElements have no case and are waiting for reuse
            if (tElementsAreRects) {
              doInsertion(iElement.attrs.x, iElement.attrs.y, tCase);
              doInsertion(iElement.attrs.x + iElement.attrs.width, iElement.attrs.y, tCase);
              doInsertion(iElement.attrs.x + iElement.attrs.width, iElement.attrs.y + iElement.attrs.height, tCase);
              doInsertion(iElement.attrs.x, iElement.attrs.y + iElement.attrs.height, tCase);
            }
            else {
              doInsertion(iElement.attrs.cx, iElement.attrs.cy, tCase);
            }
          }
        }.bind(this));
      },
      cleanUpPointSelection: function () {
        this._selectionTree = null;
      },
      /**
       * Gets the cases which are in iNewRect ignoring those in the region defined by
       * iLastRect.
       * This function is usable for incremental selection.
       * @param iNewRect
       * @param iLastRect
       */
      getCasesForDelta: function (iNewRect, iLastRect) {
        /**
         * Returns the intersection of the two rectangles. Zero area intersections
         * (adjacencies) are handled as if they where not intersections.
         *
         * @param {{x:number,y:number,width:number,height:number}} iA
         * @param {{x:number,y:number,width:number,height:number}} iB
         * @return {[{x:number,y:number,width:number,height:number}]|null}
         */
        function rectangleIntersect(iA, iB) {
          var left = Math.max(iA.x, iB.x);
          var right = Math.min(iA.x + iA.width, iB.x + iB.width);
          var top = Math.max(iA.y, iB.y);
          var bottom = Math.min(iA.y + iA.height, iB.y + iB.height);

          if (right - left <= 0 || bottom - top <= 0) return null;
          return {x: left, y: top, width: right - left, height: bottom - top};
        }

        /**
         * Returns an array of zero, one, or more rectangles that represent the
         * remainder of the first rectangle after the intersection with the second
         * rectangle is removed. If the rectangle do not intersect, then the whole of
         * the firs rectangle is returned.
         *
         * @param {{x:number,y:number,width:number,height:number}} iA
         * @param {{x:number,y:number,width:number,height:number}} iB
         * @return {[{x:number,y:number,width:number,height:number}]}
         */
        function rectangleSubtract(iA, iB) {
          var intersectRect = rectangleIntersect(iA, iB);
          var result = [];
          var intersectLR;
          var rectangleALR;

          if (intersectRect) {
            intersectLR = {x: intersectRect.x + intersectRect.width, y: intersectRect.y + intersectRect.height};
            rectangleALR = {x: iA.x + iA.width, y: iA.y + iA.height};
            if (iA.x < intersectRect.x) {
              result.push({
                x: iA.x, y: iA.y, width: intersectRect.x - iA.x, height: iA.height
              });
            }
            if (intersectLR.x < rectangleALR.x) {
              result.push({
                x: intersectLR.x, y: iA.y, width: rectangleALR.x - intersectLR.x, height: iA.height
              });
            }
            if (iA.y < intersectRect.y) {
              result.push({
                x: intersectRect.x, y: iA.y, width: intersectRect.width, height: intersectRect.y - iA.y
              });
            }
            if (intersectLR.y < rectangleALR.y) {
              result.push({
                x: intersectRect.x, y: intersectLR.y, width: intersectRect.width, height: rectangleALR.y - intersectLR.y
              });
            }
          } else {
            result.push(iA);
          }

          return result;
        }

        var rects = rectangleSubtract(iNewRect, iLastRect);
        var selected = [];


        rects.forEach(function (iRect) {
          var tRect;
          var tSelected;
          tRect = {x: iRect.x, y: iRect.y, w: iRect.width, h: iRect.height};
          tSelected = this._selectionTree.search(tRect);
          if (tSelected && tSelected.length > 0) {
            selected = selected.concat(tSelected);
          }
        }.bind(this));
        return selected;
      },
      /**
       @param {{ x: {Number}, y: {Number}, width: {Number}, height: {Number} }} iRect
       @return {Array} of DG.Case
       */
      getCasesForPointsInRect: function (iRect) {
        var tCases, tSelected, tRect;

        if (this._selectionTree) {
          tRect = {x: iRect.x, y: iRect.y, w: iRect.width, h: iRect.height};
          tSelected = this._selectionTree.search(tRect);
        } else {
          tCases = this.getPath('model.cases');
          tSelected = [];

          this.get('plottedElements').forEach(function (iElement, iIndex) {
            if (DG.ViewUtilities.ptInRect({x: iElement.attrs.cx, y: iElement.attrs.cy}, iRect))
              tSelected.push(tCases.at(iIndex));
          });
        }
        return tSelected;
      },

      /**
       * Remove all plotted elements
       */
      removePlottedElements: function (iCallRemove, iAnimate) {
        var tLayerManager = this.get('layerManager'),
            tPlottedElements = this.get('plottedElements');
        tPlottedElements.forEach(function (iElement) {
          if (iAnimate) {
            DG.PlotUtilities.doHideRemoveAnimation(iElement, tLayerManager);
          }
          else
            tLayerManager.removeElement(iElement, iCallRemove);
        });
        // tPlottedElements.length = 0;
      },

      /**
       @property { Number }  Takes into account any borders the parent views may have
       Kludge alert! We're dealing with a SproutCore bug with computing frames in the presence
       of borders. [SCBUG]
       */
      drawWidth: function () {
        return this.get('frame').width - 2 * DG.ViewUtilities.kBorderWidth;
      }.property('frame'),

      /**
       @property { Number }  Takes into account any borders the parent views may have
       Kludge alert! We're dealing with a SproutCore bug with computing frames in the presence
       of borders. [SCBUG]
       */
      drawHeight: function () {
        return this.get('frame').height - 2 * DG.ViewUtilities.kBorderWidth;
      }.property('frame'),

      /**
       Graph controller observes this property to detect that a drag has taken place.
       @property {{collection:{DG.CollectionRecord}, attribute:{DG.Attribute}, text:{String},
              axisOrientation:{String} }}
       */
      dragData: null,

      /**
       Attempt to assign the given attribute to this axis.
       @param {SC.Drag} iDragObject 'data' property contains 'collection', 'attribute', 'text' properties
       @param {SC.DRAG_LINK} iDragOp
       */
      performDragOperation: function (iDragObject, iDragOp) {
        this.set('dragData', iDragObject.data);
        return SC.DRAG_LINK;
      },

      showDataTip: function (iElement, iIndex) {
        if (DG.NO_DATA_TIP_PREF || this.getPath('paperSource.tempDisallowDataTips'))
          return;
        this.get('dataTip').show(iElement.attr('cx'), iElement.attr('cy'), iElement.attr('r'), iIndex);
      },

      hideDataTip: function () {
        if (DG.NO_DATA_TIP_PREF)
          return;
        var tDataTip = this.get('dataTip');
        if (tDataTip)
          tDataTip.hide();
      },

      /**
       * Compute the desired point radius, which depends on the number of cases to be plotted.
       * Caller should compare to this._pointRadius (actual size of case circles already created)
       * @return {Number} radius of circle for each case, as a positive integer.
       */
      calcPointRadius: function () {
        var tModel = this.get('model');
        if( !tModel)
          return; // Can happen during undo
        // Search for a point size in [min-max] range, where the point size is a power of logbase that is close to the data length.
        // This step function avoids excessive plot resizing with every change in number of cases.
        var tDataConfiguration = tModel.get('dataConfiguration'),
            tDataLength = tDataConfiguration ? tDataConfiguration.getCaseCount() : 0,
            tMultiplierFunc = tModel.getPointSizeMultiplier,
            tMultiplier = tMultiplierFunc ? tMultiplierFunc.call(this.get('model')) : 1,
            tRadius = DG.PlotUtilities.kPointRadiusMax,
            tMinSize = DG.PlotUtilities.kPointRadiusMin,
            tPower = DG.PlotUtilities.kPointRadiusLogBase,
            tResult;
        // for loop is fast equivalent to radius = max( minSize, maxSize - floor( log( logBase, max( dataLength, 1 )))
        for (var i = tPower; i <= tDataLength; i = i * tPower) {
          --tRadius;
          if (tRadius <= tMinSize) break;
        }
        tResult = tRadius * tMultiplier;
        return tResult < 1 ? 0 : tResult;
      },

      radiusForCircleElement: function (iElement) {
        return this._pointRadius + (iElement._selected ? DG.PlotUtilities.kPointRadiusSelectionAddend : 0);
      },

      /**
       * Subclasses will override
       * @return {*}
       */
      createRenderContext: function () {
        return {};
      },

      /**
       * Show or hide the given plot element to match it's desired status.
       * Todo: Find a way to reinstate animation
       * @param {Element} iPlottedElement, a Rafael element
       * @param {Boolean} iWantHidden, true if we want the element to be hidden
       * @return {Boolean} true if element is now shown.
       */
      showHidePlottedElement: function (iPlottedElement, iWantHidden, iIndex /*, iAnimate*/) {
        var tIsHidden = iPlottedElement.isHidden();
        if (iWantHidden) {
          if (!tIsHidden) {
            // if want hidden but element is shown:
            // hide immediately (TODO: find a way to animate the hiding/showing),
            // and set the position/radius/color to a consistent state in case we animate after being shown.
            iPlottedElement.stop();
            iPlottedElement.hide();
            iPlottedElement.attr({cx: 0, cy: 0, r: 1, fill: DG.ColorUtilities.kMissingValueCaseColor.colorString});
          }
        } else if (tIsHidden) {
          var tAttrs = {'fill-opacity': DG.PlotUtilities.kDefaultPointOpacity, 'opacity': 1};
          this.assignElementAttributes( iPlottedElement, iIndex);
          iPlottedElement.stop();
          iPlottedElement.attr( tAttrs);
          iPlottedElement.show();
        }
        return !iWantHidden;
      },

      /**
       * Update the position of the plotted element.
       * Assumes but does not require that the element is visible (see showHidePlottedElement())
       * @param iPlottedElement {}
       * @param iAttrs {{cx:Number, cy:Number, r:Number, fill:String, stroke:String,
   *                  'fill-opacity':Number, 'stroke-opacity':Number}}
       * @param iAnimate {Boolean}
       * @param iCallback {Function}
       */
      updatePlottedElement: function (iPlottedElement, iAttrs, iAnimate, iCallback) {
        // Any prior positional animation is no longer valid
        if (iPlottedElement.posAnimation) {
          iPlottedElement.stop(iPlottedElement.posAnimation);
          iPlottedElement.posAnimation = null;
        }

        // Raphael animation completion function, called when animation is complete
        // with "this" set to the Raphael object.
        function completeAnimation() {
          this.posAnimation = null;
          if (iCallback)
            iCallback();
        }

        if (iAnimate) {
          // note: animating color does not look good (interaction with other plot changes), so update immediately
          iPlottedElement.attr({stroke: iAttrs.stroke, 'stroke-opacity': iAttrs['stroke-opacity']});

          // Hover animation changes the transform which affects positioning.
          // If we're trying to animate position, we simply complete the hover animation.
          if (iPlottedElement.hoverAnimation) {
            iPlottedElement.stop(iPlottedElement.hoverAnimation);
            iPlottedElement.hoverAnimation = null;
            iPlottedElement.transform('');
          }

          // Set up the position animation and start the animation
          iPlottedElement.posAnimation = Raphael.animation(iAttrs, DG.PlotUtilities.kDefaultAnimationTime,
              '<>', completeAnimation);
          iPlottedElement.animate(iPlottedElement.posAnimation);
        } else {
          // Counteract any transform effect, e.g. from a hover animation
          var currTransform = iPlottedElement.transform(),
              currTransformIsIdentity = SC.empty(currTransform) || (SC.isArray(currTransform) && currTransform.length === 0)
                  || (currTransform.toString() === 's1');
          if (!currTransformIsIdentity)
            iPlottedElement.transform('');

          //iPlottedElement.attr( iAttrs);
          // We use a modified version of Raphael's 'attr' because we're always dealing with circles
          DG.PlotUtilities.setPlottedPointAttributes(iPlottedElement, iAttrs);

          // Some points got made but never had a chance to finish their creation animation
//      if( iPlottedElement.attr('stroke-opacity') < 1 ) {
//        iPlottedElement.animate( {'fill-opacity': DG.PlotUtilities.kDefaultPointOpacity, 'stroke-opacity': 1 },
//                                DG.PlotUtilities.kDefaultAnimationTime, '<>');
//      }

          // Restore the transform to its original value
          if (!currTransformIsIdentity)
            iPlottedElement.transform(currTransform);
        }
      },

      /**
       * Add an element to our list of temporary, about-to-vanish plot elements,
       * so that we can animate it before it disappears.  Note that this animated
       * element looks like a normal plotted element but is underneath the plotted element (in the z-axis),
       * and will be deleted at the next rendering.
       * Note: Here we assume the vanishing element is visible throughout the animation period,
       * so caller should not vanish a case if missing and therefore hidden in the new or old plot.
       * @param iOldAttrs {cx,cy,r,fill} position and other attributes of old (deleted) plotted element
       * @param iNewAttrs {cx,cy} pposition and optionally other attributes of new plotted element we apparently are merging with
       */
      vanishPlottedElement: function (iOldAttrs, iNewAttrs) {

        function completeVanishAnimation() {
          this.hide(); // hide this element until it is deleted from elementsToClear list (at next rendering).
        }

        // create circle animation
        var tCircle = this.get('paper').circle(-100, -100, this._pointRadius) // match createElement()
            .toBack() // behind existing elements
            .addClass(DG.PlotUtilities.kColoredDotClassName) // match createElement
            .attr(iOldAttrs) // starting position to match updatePlottedElement()
            .animate(iNewAttrs, DG.PlotUtilities.kDefaultAnimationTime, '<>', completeVanishAnimation);

        // add it to list of elements be erased at next rendering (ideally after animation is done)
        this.get('elementsToClear').push(tCircle);
      },

      /**
       * This gets called when the point size changes but nothing else, as for example, when we connect points
       * in a scatterplot with lines and want the point size to decrease.
       */
      updatePointSize: function () {
        this._pointRadius = this.calcPointRadius();
        var tAttr = {r: this._pointRadius};
        this.get('plottedElements').forEach(function (iElement) {
          iElement.animate(tAttr, DG.PlotUtilities.kDefaultAnimationTime, '<>');
        });
      },

      /**
       * Subclasses will override
       */
      didCreateLayer: function () {
      }

    });

/* >>>>>>>>>> BEGIN source/components/graph/plots/plot_view.js */
// ==========================================================================
//                            DG.PlotView
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph_map_common/plot_layer');

/** @class  DG.PlotView - The base class for a plot layer that appears in a graph.

 @extends DG.PlotLayer
 */
DG.PlotView = DG.PlotLayer.extend(
    /** @scope DG.PlotView.prototype */
    {
      autoDestroyProperties: ['plottedCountAdorn', 'plottedValueAdorn'],

      /**
       * These two properties are used to determine point color when there are multiple plots in a graph
       */
      plotIndex: 0,
      numPlots: 1,

      plotIndexDidChange: function () {
        // Keep my plotLayerNumber in synch
        this.set('plotLayerNumber', this.get('plotIndex'));
      }.observes('plotIndex'),

      /**
       @property { DG.AxisView}
       */
      xAxisView: null,
      /**
       @property { DG.AxisView }
       */
      yAxisView: null,

      /**
       * We can check the orientation of the yAxis.
       */
      isUsingY2: function () {
        return this.getPath('yAxisView.orientation') === DG.GraphTypes.EOrientation.kVertical2;
      }.property(),
      isUsingY2DidChange: function () {
        this.notifyPropertyChange('isUsingY2');
      }.observes('*yAxisView.orientation'),

      /**
       * Expected type of plotted elements
       */
      plottedElementType: 'circle',

      /**
       Used to store point coordinates at the beginning of a configuration change.
       @property { Array of {cx:{Number}, cy:{Number}} }
       */
      cachedPointCoordinates: null,

      /**
       * These are point coordinates that were gathered up from the plot before a configuration change
       @property { Array of {cx:{Number}, cy:{Number}} }
       */
      transferredElementCoordinates: null,

      /**
       * Set to false if you have your own way of animating to a new state
       @property {Boolean}
       */
      allowTransferAnimation: true,

      _areAdornmentsInitialized: false,

      /**
       @property {DG.FormulaTextEditView}
       */
      plottedValueEditView: null,

      /** @property {DG.PlottedCountAdornment} */
      plottedCountAdorn: null,

      /**
       * Used by both dot plot and scatter plot
       * @property {DG.PlottedValueAdornment}
       */
      plottedValueAdorn: null,

      /**
       Prepare dependencies.
       */
      init: function () {
        arguments.callee.base.apply(this,arguments);
      },

      destroy: function () {
        this.removePlottedValueEditView();
        arguments.callee.base.apply(this,arguments);
      },

      removePlottedValueEditView: function () {
        if (this.plottedValueEditView) {
          this.plottedValueEditView.removeFromParent();
          this.plottedValueEditView.destroy();
          this.plottedValueEditView = null;
        }
      },

      /**
       * Subclasses may override to set certain axis view properties for their purpose.
       */
      setupAxes: function () {

      },

      /**
       * Gives plot a chance to return descriptions of axis views
       * @return {[{}]}
       */
      getAxisViewDescriptions: function () {
        return [];
      },

      /**
       Observer function called when the axis bounds change.
       */
      axisBoundsDidChange: function () {
        this._isRenderingValid = false;
        this.displayDidChange();
      }.observes('xAxisView.model.lowerBound', 'xAxisView.model.upperBound',
          'yAxisView.model.lowerBound', 'yAxisView.model.upperBound', '.model.axisBounds'),

      /** Invalidate and update adornments shared by all plot types */
      updateAdornments: function () {
        var tCountAdornModel = this.plottedCountAdorn && this.plottedCountAdorn.get('model');
        if (tCountAdornModel) {  // update counts if present
          this.plottedCountAdorn.get('model').setComputingNeeded();
          this.plottedCountAdorn.updateToModel();
        }

        var tPlottedValueAdorn = this.get('plottedValueAdorn');
        if (tPlottedValueAdorn) {
          tPlottedValueAdorn.updateToModel();
        }
      },

      rescaleOnParentCaseCompletion: function (iCases) {
        var caseCount = iCases && iCases.length,
            lastCase = caseCount && iCases[caseCount - 1],
            lastCaseID = lastCase && lastCase.get('id'),
            openParentCaseID = this.getPath('model.openParentCaseID');
        if (!SC.none(lastCaseID) && (lastCaseID === openParentCaseID)) {
          var plot = this.get('model');
          if (plot && plot.rescaleAxesFromData) {
            plot.rescaleAxesFromData(false /* don't allow scale shrinkage */,
                false /* don't animate points */);
          }
          this.setPath('model.openParentCaseID', null);
        }
      },

      /**
       Initialize the adornments from the set of adornment models.
       */
      initializeAdornments: function () {
        /* TODO: for historical reasons, the implementation of the plotted count
         * adornment is different from other adornments. it's state is managed
         * separately. Should be unified. */
        this.plottedCountChanged();

        var model = this.get('model'),
            adornmentModels = model && model._adornmentModels;
        DG.ObjectMap.forEach(adornmentModels,
            function (iAdornmentKey, iAdornmentModel) {
              model.notifyPropertyChange(iAdornmentKey);
            });

        this._areAdornmentsInitialized = true;
      },

      /**
       *
       * @param iIndex  Index of this plot view in array of plotviews owned by graph
       * @param iNumPlots Number of plotviews owned by graph
       */
      doDraw: function doDraw(iIndex, iNumPlots) {
        if (!SC.none(iIndex)) {
          this.set('plotIndex', iIndex);
          this.set('numPlots', iNumPlots);
        }
        if (!this._areAdornmentsInitialized) {
          this.initializeAdornments();
        } else {
          this.updateAdornments();
        }

        // The following seemed necessary at one point, but has since caused problems.
        // We leave it commented in because we may discover situations in which it _is_ necessary.
        // if( this.getPath('model.isAnimating')) {
        // In some situations we get both animation and transferred points coordinates. The first is sufficient
        // this.set('transferredElementCoordinates', null);
        // }

      },

      /**
       For use in transferring current element positions of this plot to a new plot about
       to take its place.
       @return {[{cx:{Number}, cy:{Number}, r: {Number}, fill: {String} ]}
       */
      getElementPositionsInParentFrame: function () {
        var tFrame = this.get('frame'),
            tPlottedElements = this.get('plottedElements');
        DG.assert(tPlottedElements.length === 0 || tPlottedElements[0][0].constructor !== SVGRectElement,
            'Expecting circle, not rect');
        return tPlottedElements.map(function (iElement) {
          var tRadius = (iElement.isHidden() ? 0 : iElement.attr('r')); // use r:0 as proxy for hidden plot element
          return {
            cx: iElement.attr('cx') + tFrame.x,
            cy: iElement.attr('cy') + tFrame.y,
            r: tRadius,
            fill: iElement.attr('fill'),
            type: 'circle'
          };
        });
      },

      /**
       * Returns 'transferredElementCoordinates' converted to view coordinates.
       */
      getTransferredElementsViewCoords: function () {
        var coords = this.get('transferredElementCoordinates'),
            frame = this.get('frame');
        if (coords && frame) {
          coords.forEach(function (iPoint, iIndex) {
            // adjust old coordinates from parent frame to this view
            // assign x/y and cx/cy to support animating to rects or circles
            if (iPoint.cx != null) iPoint.cx -= frame.x;
            if (iPoint.cy != null) iPoint.cy -= frame.y;
            if (iPoint.x != null) iPoint.x -= frame.x;
            if (iPoint.y != null) iPoint.y -= frame.y;
          });
        }
        return coords;
      },

      /**
       * Called from animateFromTransferredElements to create animatable elements.
       * @param {DG.Case} iCase
       * @param {number} iIndex
       * @param {Object} iOldEltAttrs
       */
      createAnimatingElement: function (iCase, iIndex, iOldEltAttrs) {
        var tElement = this.callCreateElement(iCase, iIndex, false);
        iOldEltAttrs && tElement.attr(iOldEltAttrs);
        return tElement;
      },

      /**
       Called when this view is taking over from another one in order to animate points from their
       previous position to their new position. Handles 3 types of animations:
       (a) one-to-many animation for moving from parent to corresponding child case(s)
       (b) many-to-one animation for moving from child case(s) to corresponding parent case
       (c) one-to-one animation for moving within a collection (this is default).
       */
      animateFromTransferredElements: function () {
        var tCases = this.getPath('model.cases'),
            tRC = this.createRenderContext(),
            tOldPointAttrs = this.getTransferredElementsViewCoords(),
            tOldElementType = tOldPointAttrs.length > 0 && tOldPointAttrs[0].type,
            tNewPointAttrs = [], // used if many-to-one animation
            tNewToOldCaseMap = [],
            tOldToNewCaseMap = [];
        // During undo/redo we can get here without cases. Bail!
        if (!tCases || !tRC)
          return;

        function caseLocationSimple(iIndex) {
          // assume a 1 to 1 correspondence of the current case indices to the new cases
          return tOldPointAttrs[iIndex];
        }

        function caseLocationViaMap(iIndex) {
          // use our case index map to go from current case index to previous case index
          return tOldPointAttrs[tNewToOldCaseMap[iIndex]];
        }

        this._getTransferredElementsToCasesMap(tNewToOldCaseMap, tOldToNewCaseMap);
        this.set('transferredElementCoordinates', null);
        var hasElementMap = tNewToOldCaseMap.length > 0,
            hasVanishingElements = tOldToNewCaseMap.length > 0,
            getCaseCurrentLocation = (hasElementMap ? caseLocationViaMap : caseLocationSimple),
            tHaveInstalledCallback = false;

        this._elementOrderIsValid = false;
        DG.sounds.playMixup();
        this.prepareToResetCoordinates();
        if (tOldElementType !== this.get('plottedElementType')) {
          this.removePlottedElements(true);
          // one would think that removePlottedElements() would obviate the need for this, but no
          this.get('plottedElements').forEach(function (iElement) {
            iElement.remove();
          });
          this.get('plottedElements').length = 0;
        }

        var eachCaseFunc = function (iCase, iIndex, iIsLast) {
              // Because this function is called during an invokeLater, it can happen that
              // since the time the loop was initiated, the plotview has been destroyed!
              if (this.isDestroyed)
                return;
              // create new circles, animating from old coordinates where possible
              var tPt = getCaseCurrentLocation(iIndex),
                  tAnimate = false,
                  tCallBack;
              this.createAnimatingElement(iCase, iIndex, tPt);
              if (!SC.none(tPt)) {
                tAnimate = true;
                if (iIsLast) {
                  tCallBack = function () {
                    this.setPath('model.isAnimating', false);  // Allow standard draw
                    // Draw once more because it can happen that a graph layout has happened since we computed
                    // point coordinates
                    this.drawData();
                  }.bind(this);
                }
              }
              // setCircleCoordinate returns null if coordinates are not valid
              tPt = this.setCircleCoordinate(tRC, iCase, iIndex, tAnimate, tCallBack);
              if (tPt && tCallBack) {
                tHaveInstalledCallback = true;
              }
              if (hasVanishingElements) {
                tNewPointAttrs.push(tPt);
              }
              return this.getPath('model.isAnimating');
            }.bind(this),

            finallyFunc = function () {
              if (!tHaveInstalledCallback)
                this.setPath('model.isAnimating', false);
              if (hasVanishingElements) {
                // create a vanishing element for each old point that needs one (used if many-to-one animation)
                tOldPointAttrs.forEach(function (iOldAttrs, iIndex) {
                  var tNewIndex = tOldToNewCaseMap[iIndex],
                      tNewAttrs = tNewPointAttrs[tNewIndex];
                  if (SC.none(tNewIndex) || SC.none(tNewAttrs) || (iOldAttrs.r === 0))
                    return; // no vanishing element, if (1) element persists or (2) new circle hidden or (3) old circle hidden
                  this.vanishPlottedElement(iOldAttrs, tNewAttrs);
                });
              }
              this.notifyPropertyChange('plotDisplayDidChange');
            }.bind(this);
        this.setPath('model.isAnimating', true); // So plot's standard draw won't wipe out animation
        tCases.forEachWithInvokeLater(eachCaseFunc, finallyFunc);
      },

      /**
       * Get a map from the current (new) case index to the index of the transferred point coordinates (old case),
       * and vise versa, if and only if we are animating from many cases to fewer cases, or vise versa.
       * Used to handle special case animations, when switching from parent to child collection or back,
       * where cases appear to get split or joined.  If neither array is populated, the caller can assume
       * a 1 to 1 case index mapping.
       * @param iNewToOldCaseMap {[]} empty Array, or array of index values, one for each (new) case.
       * @param iOldToNewCaseMap {[]} empty Array, or array of index values, one for each (old) transferred point coordinate.
       */
      _getTransferredElementsToCasesMap: function (iNewToOldCaseMap, iOldToNewCaseMap) {
        var tTransferredPoints = this.get('transferredElementCoordinates'),
            tCases = this.getPath('model.cases'),
            tCollectionClient = this.getPath('model.collectionClient'),
            tChildCollectionClient = this.getPath('model.dataContext.childCollection'),
            tParentCollectionClient = this.getPath('model.dataContext.parentCollection'),
            tParentNumCases = tParentCollectionClient ? tParentCollectionClient.getCaseCount() : 0,
            tChildNumCases = tChildCollectionClient ? tChildCollectionClient.getCaseCount() : 0,
            tNewNumCases = tCases ? tCases.get('length') : 0,
            tOldNumCases = tTransferredPoints.length;

        function isParentToChildTransformation() {
          // TODO this function needs improvement.  Returns true even if not changing collections, if number of cases happens to match parent-to-child transform.
          return (tParentCollectionClient &&
              (tParentNumCases === tOldNumCases) && // TODO: fix this bad assumption, better to check collection id saved with old cases instead
              (tCollectionClient && tCollectionClient.isDescendantOf(tParentCollectionClient)));
        }

        function isChildToParentTransformation() {
          // TODO this function needs improvement.  Returns true even if not changing collections, if number of cases happens to match child-to-parent transform.
          return (tChildCollectionClient &&
              (tChildNumCases === tOldNumCases) && // TODO: fix this bad assumption, better to check collection id saved with old cases instead
              (tCollectionClient && tCollectionClient.isAncestorOf(tChildCollectionClient)));
        }

        function getParentCaseNumChildren(iCaseIndex) {
          // return the number of children of the given case in the parent collection
          var tParentCase = tParentCollectionClient.getCaseAt(iCaseIndex),
              tParentCaseChildren = tParentCase && tParentCase.get('children');
          if (tParentCaseChildren) {
            tParentCaseChildren = tParentCaseChildren.filter(function (iCase) {
              return tCases.indexOf(iCase) >= 0;
            });
            return tParentCaseChildren.get('length');
          } else
            return 0;
        }

        function getParentToChildTransformation(iNewToOld, iOldToNew) {
          // fill iNewToOld[] with child case index to parent case index mapping
          // because typically many child cases will want location of the same shared parent case for animation
          var tOldIndex, tNewIndex, tNumChildren;

          for (tOldIndex = 0; tOldIndex < tOldNumCases; ++tOldIndex) {
            tNumChildren = getParentCaseNumChildren(tOldIndex);
            for (tNewIndex = 0; tNewIndex < tNumChildren; ++tNewIndex) {
              iNewToOld.push(tOldIndex);
            }
          }
          if (!DG.assert(iNewToOld.length === tNewNumCases, "Parent/Child case mismatch")) {
            iNewToOld.length = 0; // don't use this map if length error
          }
          DG.assert(iOldToNew.length === 0, "another parent/child case mismatch");
        }

        function getChildToParentTransformation(iNewToOld, iOldToNew) {
          // fill iNewToOld[] with parent case index to child case index mapping, using 'undefined' if no child case index
          // fill iOldToNew[] with child case index to parent case index mapping, for extra old cases that are vanishing
          // because typically each newly created parent case will start at location of 0th child case,
          // and typically all but 0th child case must animate to position of newly created parent case.
          var tOldIndex, tNewIndex, tNumChildren, tChild, tChildCaseIndex;

          tOldIndex = 0;
          for (tNewIndex = 0; tNewIndex < tNewNumCases; ++tNewIndex) {
            tNumChildren = getParentCaseNumChildren(tNewIndex);
            iNewToOld.push((tNumChildren > 0) ? tOldIndex : undefined); // map each parent case to 1st child case if any, otherwise undefined
            for (tChild = 0; tChild < tNumChildren; ++tChild) {
              // ignore the 0th child case (undefined mapping), give index of 1st+ child case which is to be vanished
              tChildCaseIndex = ((tChild === 0) ? undefined : iNewToOld.length - 1);
              iOldToNew.push(tChildCaseIndex);
              ++tOldIndex;
            }
          }
        }

        if (isParentToChildTransformation()) {
          getParentToChildTransformation(iNewToOldCaseMap, iOldToNewCaseMap);

        } else if (isChildToParentTransformation()) {
          getChildToParentTransformation(iNewToOldCaseMap, iOldToNewCaseMap);
        }
        //DG.log("DG.PlotView._getTransferredElementsToCasesMap() collection id=%@, NewToOldCaseMap %@", tCollectionClient.get('id'), iNewToOldCaseMap.toString());
        //DG.log("DG.PlotView._getTransferredElementsToCasesMap() collection id=%@, OldToNewCaseMap %@", tCollectionClient.get('id'), iOldToNewCaseMap.toString());
      },

      /**
       * Our model is signalling that it is about to change (DG.GraphModel.aboutToChangeConfiguration.set(true))
       * We use this opportunity to prepare for an animation.
       * See also handleConfigurationChange.
       */
      prepareForConfigurationChange: function () {
        this.set('cachedPointCoordinates', this.getElementPositionsInParentFrame());
      },

      /**
       * Our model is signalling that it has changed (DG.GraphModel.aboutToChangeConfiguration.set(false))
       * We use this opportunity to update views.
       * See also prepareForConfigurationChange.
       */
      handleConfigurationChange: function () {
        // In certain circumstances we have already moved point coordinates to transferredElementCoordinates.
        // Protect against wiping these out.
        if (this.get('allowTransferAnimation') && !this.get('transferredElementCoordinates')) {  // the configuration has changed
          this.set('transferredElementCoordinates', this.get('cachedPointCoordinates'));
        }
      },

      /**
       Subclasses may override. Note that deselection happens in startMarquee.
       @param iEvent {SC.Event}
       */
      handleBackgroundClick: function (iEvent) {
      },

      /**
       Subclasses will override if they have a double-click behavior
       @param iEvent {SC.Event}
       */
      handleBackgroundDblClick: function (iEvent) {
      },

      /**
       * This value depends only on plotIndex and numPlots
       */
      getAttributeColor: function () {
        var tPlotIndex = this.get('plotIndex'),
            tNumPlots = this.get('numPlots');
        return SC.none(tPlotIndex) || (tPlotIndex === 0) ? null :
            DG.ColorUtilities.calcAttributeColorFromIndex(tPlotIndex, tNumPlots);
      },

      getPointColor: function () {
        var tModel = this.get('model');
        return tModel.getPointColor ? tModel.getPointColor() : DG.PlotUtilities.kDefaultPointColor;
      },

      /**
       * Construct and return a new render context
       * used for setCircleCoordinate()
       * @return {*}
       */
      createRenderContext: function () {
        var tModel = this.get('model'),
            tConfig = tModel.get('dataConfiguration'),
            tLegendDesc = tConfig.get('legendAttributeDescription'),
            tYVarIDKey = tModel.getPath('verticalAxisIsY2') ? 'y2VarID' : 'yVarID',
            tStrokeParams = this.getStrokeParams(),
            tIsNumeric = tLegendDesc && tLegendDesc.get('isNumeric'),
            tQuantileValues = (tIsNumeric) ? tConfig.get('legendQuantiles') : [];
        this._pointRadius = this.calcPointRadius(); // make sure created circles are of right size
        return {
          // render needs (set all to true for now, maybe later we can optimize by not doing all of them?)
          casesAdded: true,
          casesRemoved: true,
          updatedColors: true,
          updatedPositions: true,

          // cached render parameters common to all cases
          xAxisView: this.get('xAxisView'),
          yAxisView: this.get('yAxisView'),
          xVarID: tModel.get('xVarID'),
          yVarID: tModel.get(tYVarIDKey),
          legendDesc: tLegendDesc,
          legendVarID: tLegendDesc && tLegendDesc.get('attributeID'),
          pointColor: this.getPointColor(),
          transparency: tModel.getTransparency ? tModel.getTransparency() : DG.PlotUtilities.kDefaultPointOpacity,
          strokeTransparency: tStrokeParams.strokeTransparency,
          attrColor: this.getAttributeColor(),

          /**
           * Calculate the case color string
           * @param iCase {DG.Case}
           * @return {String}
           */
          calcCaseColorString: function (iCase) {
            DG.assert(iCase);
            var tColorValue = tIsNumeric ? iCase.getForcedNumericValue(this.legendVarID) :
                    iCase.getValue(this.legendVarID),
                tCaseColor = DG.ColorUtilities.calcCaseColor(tColorValue, this.legendDesc,
                    this.attrColor || this.pointColor, tQuantileValues);
            return tCaseColor.colorString || tCaseColor;
          },
          calcStrokeColorString: function (iCase) {
            if (tStrokeParams.strokeSameAsFill)
              return this.calcCaseColorString(iCase);
            else return tStrokeParams.strokeColor;
          }
        };
      },

      /**
       Create or destroy the matching adornment when our model creates/destroys the DG.PlottedCountModel.
       */
      plottedCountChanged: function () {
        var tCountModel = this.getPath('model.plottedCount');
        // This adornment may have been passed from a previous plot. Make sure knows it needs to recompute
        if (tCountModel.get('isVisible'))
          tCountModel.setComputingNeeded();
        // Rather than attempt to reconnect an existing adornment, we throw out the old and rebuild.
        if (this.plottedCountAdorn) {
          this.plottedCountAdorn.destroy();
          this.plottedCountAdorn = null;
        }
        if (tCountModel && this.get('paper')) {
          this.plottedCountAdorn = DG.PlottedCountAdornment.create({
            parentView: this, valueAxisView: this.get('primaryAxisView'),
            model: tCountModel, paperSource: this.get('paperSource'),
            layerName: DG.LayerNames.kAdornments
          });
          this.plottedCountAdorn.updateToModel();
        }
      }.observes('*model.plottedCount'),

      /**
       The visibility of the model's plotted function has changed. We respond accordingly.
       */
      plottedValueChanged: function () {
        var plotModel = this.get('model'),
            tPlottedValue = plotModel && plotModel.getAdornmentModel('plottedValue'),
            tPlottedValueAdorn = this.get('plottedValueAdorn'),
            tFormulaEditContextExists = DG.PlottedFormulaEditContext.hasFormulaEditContextFor(tPlottedValue),
            tPlottedValueEditView = this.get('plottedValueEditView'),
            tPlottedValueIsVisible = tPlottedValue && tPlottedValue.get('isVisible');
        if (tPlottedValueEditView && !tPlottedValueIsVisible) {  // If it's not visible, we can avoid much of the work
          tPlottedValueEditView.set('isVisible', false);
        }
        if (!tFormulaEditContextExists && tPlottedValueEditView) {
          this.removePlottedValueEditView();
          tPlottedValueEditView = null;
        }
        if (tPlottedValue) {
          if (tPlottedValue && !tPlottedValueEditView) {
            tPlottedValueEditView = DG.PlottedValueAdornment.createFormulaEditView(tPlottedValue);
            this.set('plottedValueEditView', tPlottedValueEditView);
            this.setPath('parentView.plottedValueEditorView', tPlottedValueEditView);
          }
          // noinspection JSObjectNullOrUndefined
          tPlottedValueEditView.set('isVisible', tPlottedValue.get('isVisible'));

          if (tPlottedValueAdorn) {
            tPlottedValueAdorn.set('parentView', this);
            tPlottedValueAdorn.set('model', tPlottedValue);
            tPlottedValueAdorn.set('paperSource', this.get('paperSource'));
          } else {
            tPlottedValueAdorn = DG.PlottedValueAdornment.create({
              parentView: this,
              model: tPlottedValue,
              paperSource: this.get('paperSource'),
              layerName: DG.LayerNames.kAdornments
            });
            this.set('plottedValueAdorn', tPlottedValueAdorn);
          }
        } else if (tPlottedValueAdorn) {
          tPlottedValueAdorn.destroy();
          this.set('plottedValueAdorn', null);
        }
      }.observes('*model.plottedValue'),

      /**
       Called when the order of the categories on an axis changes (e.g. cells are dragged)
       */
      categoriesDidChange: function (iObject, iProperty) {
      },

      /**
       * Here we do the initialization that relies on there being a paper to draw on.
       */
      didCreateLayer: function () {
        this.plottedCountChanged(); // create count adornment to match model, now that we have paper
      }

    });

/* >>>>>>>>>> BEGIN source/components/graph/plots/chart_view.js */
// ==========================================================================
//                          DG.ChartView
//
//  Author:   William Finzer
//
//  Copyright (c) 2017 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/plots/plot_view');

/** @class  DG.ChartView, a plot of dots each placed according to categorical values

 @extends DG.PlotView
 */
DG.ChartView = DG.PlotView.extend(
    /** @scope DG.ChartView.prototype */
    {
      displayProperties: ['xAxisView.model.numberOfCells', 'yAxisView.model.numberOfCells'],

      /**
       * If defined, this function gets called after cases have been added or values changed, but only once,
       * and only after a sufficient time has elapsed.
       * @property { Function }
       */
      cleanupFunc: function () {
        this.computeCellParams();
        this.displayDidChange();
      },

      /**
       * The primaryAxisView needs to be told that its tick marks and labels are to be centered in each cell.
       */
      setupAxes: function () {
        this.setPath('xAxisView.centering', true);
        this.setPath('yAxisView.centering', true);
      },

      /**
       @property { DG.CellAxisView }
       */
      primaryAxisView: function () {
        return (this.getPath('model.orientation') === DG.GraphTypes.EOrientation.kVertical) ? this.get('xAxisView') : this.get('yAxisView');
      }.property('orientation', 'yAxisView', 'xAxisView'),

      /**
       @property { DG.CellAxisView }
       */
      secondaryAxisView: function () {
        return (this.getPath('model.orientation') === DG.GraphTypes.EOrientation.kVertical) ? this.get('yAxisView') : this.get('xAxisView');
      }.property('orientation', 'yAxisView', 'xAxisView'),

      dataDidChange: function (iNotifier, iChangeKey, iOperation) {
        if (!this.getPath('model.dataConfiguration'))
          return; // Can happen during destroy
        // Override because we're going to do the work in updateElements
        if (iOperation !== 'createCase' && iOperation !== 'createCases')
          this.get('model').invalidateCaches();
        this._elementOrderIsValid = false;
        // Call the following explicitly since we're not calling sc_super
        if (iChangeKey === 'hiddenCases') {
          this.updateSelection();
        }
        this.installCleanup();
      },

      /**
       * Construct and return a new render context
       * used for setCircleCoordinate()
       * @return {*}
       */
      createRenderContext: function () {
        var tRC = arguments.callee.base.apply(this,arguments);

        // cache some more render parameters common to all cases, but unique to ChartView.
        tRC.primaryAxisView = this.get('primaryAxisView');
        tRC.secondaryAxisView = this.get('secondaryAxisView');
        tRC.isVerticalOrientation = this.getPath('model.orientation') === DG.GraphTypes.EOrientation.kVertical;
        tRC.cellHalfWidth = tRC.secondaryAxisView.get('fullCellWidth') / 2;

        return tRC;
      },

      /**
       Generate the svg needed to display the plot
       */
      doDraw: function doDraw() {
        arguments.callee.base.apply(this,arguments);

        if (!this.getPath('model._cacheIsValid'))
          this.updateElements();

        this.drawData();
      },

      updateElements: function () {
        // update adornments when cases added or removed
        // note: don't rely on tDataLength != tPlotElementLength test for this
        this.updateAdornments();
      },

      /**
       Only recreate elements if necessary. Otherwise, just set svg element coordinates.
       */
      drawData: function drawData() {
        if (SC.none(this.get('paper')))
          return; // not ready to draw
        if (this.getPath('model.isAnimating'))
          return; // Bars are animating to new position

        if (!SC.none(this.get('transferredElementCoordinates'))) {
          this.animateFromTransferredElements();
          return;
        }

        var this_ = this,
            tModel = this.get('model'),
            tCases = tModel.get('cases'),
            tPlottedElements = this.get('plottedElements'),
            tPlotElementLength = tPlottedElements.length,
            tRC;

        if (!tCases)
          return; // We can get here before things are linked up during restore


        tRC = this.createRenderContext();
        this.computeCellParams();

        tCases.forEach(function (iCase, iIndex) {
          var tCellIndices = tModel.lookupCellForCaseIndex(iIndex);
          if (iIndex >= tPlotElementLength)
            this_.callCreateElement(iCase, iIndex);
          this_.privSetElementCoords(tRC, iCase, iIndex, tCellIndices);
        });
      },

      /**
       * Must be overridden
       * @param iRC
       * @param iCase
       * @param iIndex
       * @param iCellIndices
       * @param iAnimate
       * @param iCallback
       */
      privSetElementCoords: function (iRC, iCase, iIndex, iCellIndices, iAnimate, iCallback) {

      }

      });


/* >>>>>>>>>> BEGIN source/components/graph/plots/bar_chart_base_view.js */
// ==========================================================================
//                          DG.BarChartBaseView
//
//  Author:   William Finzer
//
//  Copyright (c) 2017 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/plots/chart_view');

/** @class  DG.BarChartBaseView, a plot of rectangles, one for each category. Each rectangle is made of
 * thinner rectangles, one for each case.

 @extends DG.ChartView
 */
DG.BarChartBaseView = DG.ChartView.extend(
  /** @scope DG.BarChartBaseView.prototype */
    {
      /**
       * Expected type of plotted elements
       */
      plottedElementType: 'rect',

      /**
       * If we're displaying as a barchart, this is how high the slices are in a given bar in display coordinates
       * @property {[Number]}
       */
      barSliceHeights: null,

      _categoryCellToolTip: null,
      categoryCellToolTip: function () {
        if (!this._categoryCellToolTip) {
          this._categoryCellToolTip = DG.ToolTip.create({
            paperSource: this,
            layerName: 'dataTip'
          });
        }
        return this._categoryCellToolTip;
      }.property(),

      /**
       * @property {DG.Layer}
       */
      _coverRectsLayer: null,
      coverRectsLayer: function () {
        if (!this._coverRectsLayer && this.getPath('paperSource.layerManager')) {
          this._coverRectsLayer = this.getPath('paperSource.layerManager.' + DG.LayerNames.kCoverRects);
        }
        return this._coverRectsLayer;
      }.property(),

      upperBoundDidChange: function () {
        this.computeCellParams();
        this.displayDidChange();
      }.observes('*secondaryAxisView.model.upperBound'),

      init: function () {
        arguments.callee.base.apply(this,arguments);

        this.barSliceHeights = [];
      },

      destroy: function () {
        var tLayerManager = this.get('layerManager'),
            tPlottedElements = this.get('plottedElements');
        tPlottedElements.forEach(function (iElement) {
          tLayerManager.removeElement(iElement, true /* callRemove */);
        });
        tPlottedElements.length = 0;
        this.get('coverRectsLayer').clear();

        arguments.callee.base.apply(this,arguments);
      },

      dataRangeDidChange: function (iSource, iQuestion, iKey, iChanges) {
        var this_ = this,
            tCases = this.getPath('model.cases'),
            tRC = this.createRenderContext(),
            tChanges = (SC.typeOf(iChanges) === SC.T_NUMBER ? [iChanges] : iChanges);
        tChanges = tChanges || [];

        this.model.invalidateCaches();
        this.computeCellParams();

        tChanges.forEach(function (iIndex) {
          // We can get in here after a delete, in which case, iChanges can be referring to
          // a plot element that no longer exists.
          if (!this_.get('plottedElements')[iIndex])
            this_.callCreateElement(tCases.at(iIndex), iIndex, this_._createAnimationOn);
          var tCellIndices = this_.get('model').lookupCellForCaseIndex(iIndex);
          this_.privSetElementCoords(tRC, tCases.at(iIndex), iIndex, tCellIndices);
        });
        arguments.callee.base.apply(this,arguments);
      },

      /**
       * Construct and return a new render context
       * used for setCircleCoordinate()
       * @return {*}
       */
      createRenderContext: function () {
        var tRC = arguments.callee.base.apply(this,arguments);

        // cache some more render parameters common to all cases, but unique to BarChartBaseView.
        tRC.barSliceHeights = this.get('barSliceHeights');
        tRC.barWidth = tRC.primaryAxisView.get('fullCellWidth') / 2;
        tRC.zeroOnSecondaryAxis = tRC.secondaryAxisView.dataToCoordinate(0);

        return tRC;
      },

      /**
       * If defined, this function gets called after cases have been added or values changed, but only once,
       * and only after a sufficient time has elapsed.
       * @property { Function }
       */
      cleanupFunc: function () {
        this.get('model').rescaleAxesFromData(true /* allow shrinkage */, true /* allow animation */);
        arguments.callee.base.apply(this,arguments);
      },

      /**
       * Base class returns empty string. Subclasses override to compute an informative string.
       * @param iPrimaryName {String}
       * @param iCategoryName {String}
       * @param iTotalNumCases {Number}
       * @param iElement  {Element} Has cell specific properties we need
       * @return {String}
       */
      getToolTipText: function(iPrimaryName, iCategoryName, iTotalNumCases, iElement) {
        return '';
      },

      /**
       * @param iCase
       * @param iIndex
       * @param iAnimate
       */
      createElement: function (iCase, iIndex, iAnimate) {
        // Can't create rects if we don't have paper for them
        if (!this.get('paper')) return;

        var tRect = this.get('paper').rect(-1000, -1000, 0, 0)
            .attr({
              fill: DG.PlotUtilities.kDefaultPointColor,
              stroke: 'none'
            });
        tRect.node.setAttribute('shape-rendering', 'geometricPrecision');
        /*
                if (iAnimate)
                  DG.PlotUtilities.doCreateRectAnimation(tRect);
        */
        return tRect;
      },

      updateAllCoordinates: function (iAnimate, iCallback) {
        var tModel = this.get('model'),
            tRC = this.createRenderContext(),
            tCases = this.getPath('model.cases'),
            tDataLength = tCases && tCases.get('length');
        tCases.forEach(function (iCase, iIndex) {
          var tCallback = iIndex === tDataLength - 1 ? iCallback : null,
              tCellIndices = tModel.lookupCellForCaseIndex(iIndex);
          this.privSetElementCoords(tRC, iCase, iIndex, tCellIndices, iAnimate, tCallback);
        }.bind(this));
      },

      /**
       @param { Boolean }
       @param { Function }
       */
      updateElements: function (iAnimate, iCallback) {
        // It's possible to get here before didCreateLayer() creates the get('paper').
        if (!this.get('paper'))
          return;
        arguments.callee.base.apply(this,arguments);
        this.computeCellParams();
        var tModel = this.get('model'),
            tCases = this.getPath('model.cases'),
            tRC = this.createRenderContext(),
            tDataLength = tCases && tCases.get('length'),
            tPlottedElements = this.get('plottedElements'),
            tPlotElementLength = tPlottedElements.length,
            tLayerManager = this.get('layerManager'),
            tIndex, tCellIndices;

        // for any new cases
        if (tDataLength > tPlotElementLength) {
          // add plot elements for added cases
          for (tIndex = tPlotElementLength; tIndex < tDataLength; tIndex++) {
            this.callCreateElement(tCases.at(tIndex), tIndex, this.animationIsAllowable());
            tCellIndices = tModel.lookupCellForCaseIndex(tIndex);
            this.privSetElementCoords(tRC, tCases.at(tIndex), tIndex, tCellIndices, iAnimate, iCallback);
          }
        }
        // Get rid of plot elements for removed cases and update all coordinates
        if (tDataLength < tPlotElementLength) {
          for (tIndex = tDataLength; tIndex < tPlotElementLength; tIndex++) {
            // It can happen during closing of a document that the elements no longer exist, so we have to test
            if (!SC.none(tPlottedElements[tIndex])) {
              tPlottedElements[tIndex].stop();
              DG.PlotUtilities.doHideRemoveAnimation(tPlottedElements[tIndex], tLayerManager);
            }
          }
          // update all coordinates because we don't know which cases were deleted
          this.updateAllCoordinates(iAnimate, iCallback);
        }
        this._isRenderingValid = false;
      },

      /**
       Only recreate elements if necessary. Otherwise, just set svg element coordinates.
       */
      drawData: function drawData() {
        arguments.callee.base.apply(this,arguments);

        // this.updateSelection();

        this.drawSubBars();
      },

      /**
       * Cases are stacked as rectangles, grouped first by a primary attribute and then by a legend attribute.
       */
      drawSubBars: function () {

        /**
         * iPrimaryCoord - left/bottom edge of cell on primary/categorical axis
         * iStartCoord - bottom/left edge of bar [segment] on secondary/numeric axis
         *                (top/right edge of previous bar [segment])
         * iCount - count of cases represented by this bar [segment]
         * iCaseIndices - the indices of the cases represented by this bar [segment]
         * iNumCasesInContainingCell - the number of cases in the current cell
         *                (used for tooltip and percentage calculations)
         * iCategoryName - the legend category for the current cell, if any (used for tooltip)
         * iPrimaryName - the primary axis category for the current cell (used for tooltip)
         * iTotalNumCases - the total number of cases in all cells (used for tooltip only when no legend is present)
         */
        var makeRect = function (iPrimaryCoord, iStartCoord, iCount, iCaseIndices,
                                 iNumCasesInContainingCell, iCategoryName, iPrimaryName, iTotalNumCases) {
          var this_ = this,
              tToolTipText, tToolTip,
              tTotalCount = tHasLegend ? iNumCasesInContainingCell : iTotalNumCases,
              tBarTop = this.getBarHeight(iPrimaryName, iCount, tTotalCount),
              tCurrCoord = tRC.secondaryAxisView.dataToCoordinate(tBarTop),
              tX, tY, tWidth, tHeight;
          if (tRC.isVerticalOrientation) {
            tX = iPrimaryCoord - tRC.barWidth / 2 - 1;
            tY = tBarTop < 0 ? iStartCoord : tCurrCoord - 1;
            tWidth = tRC.barWidth + 2;
            tHeight = Math.abs(iStartCoord - tCurrCoord + 2);
          } else {
            tX = tBarTop < 0 ? tCurrCoord - 1 : iStartCoord;
            tY = iPrimaryCoord - tRC.barWidth / 2 - 1;
            tWidth = Math.abs(tCurrCoord + 2 - iStartCoord);
            tHeight = tRC.barWidth + 2;
          }
          var tRect = tPaper.rect(tX, tY, tWidth, tHeight)
              .attr({stroke: 'none', fill: 'white', 'fill-opacity': 0.001, cursor: 'pointer'})
              .hover(function (iEvent) {
                    // Note that Firefox can come through here repeatedly so we have to check for existence
                    this.animate({
                      'fill-opacity': 0.4
                    }, DG.PlotUtilities.kDataTipShowTime);
                    tToolTip = this_.get('categoryCellToolTip');
                    tToolTipText = this_.getToolTipText(iPrimaryName, iCategoryName, iTotalNumCases, this);
                    tToolTip.set('text', tToolTipText);
                    tToolTip.set('tipOrigin', {x: iEvent.layerX, y: iEvent.layerY});
                    tToolTip.show();
                  },
                  function (event) { // out
                    this.stop();
                    this.animate({
                      'fill-opacity': 0.001
                    }, DG.PlotUtilities.kHighlightHideTime);
                    if (tToolTip)
                      tToolTip.hide();
                  }
              )
              .mousedown(function (iEvent) {
                SC.run(function () {
                  this_.get('model').selectCasesWithIndices(this.caseIndices, iEvent.shiftKey);
                }.bind(this));
              });
          tRect.caseIndices = iCaseIndices;
          tRect.numCasesInContainingCell = iNumCasesInContainingCell;
          tCoverRectsLayer.push(tRect);
          return tCurrCoord;
        }.bind(this);

        var tPaper = this.get('paper'),
            tCoverRectsLayer = this.get('coverRectsLayer'),
            tCellArray = this.getPath('model.validCachedCells'),
            tRC = this.createRenderContext(),
            tPrimaryVarID = this.getPath('model.primaryVarID'),
            tLegendVarID = this.getPath('model.legendVarID'),
            tHasLegend = !SC.none(tLegendVarID),
            tTotalNumCases = this.getPath('model.cases').length();
        tCoverRectsLayer.clear();
        tCellArray.forEach(function (iPrimary, iPrimaryIndex) {
          // This is the primary division. It has an array for each category on the secondary axis
          var tPrimaryCoord = tRC.primaryAxisView.cellToCoordinate(iPrimaryIndex),
              tPrimaryName = iPrimary[0][0].theCase.getValue(tPrimaryVarID);
          iPrimary.forEach(function (iSecondary, iSecondaryIndex) {
            var tCount = 0,
                tTotalNumCasesInPrimary = iSecondary.length,
                tTotalNumCasesForBar = tHasLegend ? tTotalNumCasesInPrimary : tTotalNumCases,
                tBarTop = this.getBarHeight(tPrimaryName, tCount, tTotalNumCasesForBar),
                tPreviousCoord = tRC.secondaryAxisView.dataToCoordinate(tBarTop),
                tPreviousValue = null,
                tCaseIndices = [],
                tValue;
            // The given array contains an element for each case belonging to this stack
            iSecondary.forEach(function (iCaseContainer, iIndex) {
              tValue = iCaseContainer.theCase.getValue(tLegendVarID);
              // don't render the first bar segment since it's rendered below
              if (tPreviousValue && tValue !== tPreviousValue) {
                tPreviousCoord = makeRect(tPrimaryCoord, tPreviousCoord, tCount,
                    tCaseIndices, tTotalNumCasesInPrimary, tPreviousValue, tPrimaryName, tTotalNumCasesForBar);
                tCaseIndices = [];
              }
              tCaseIndices.push(iCaseContainer.caseIndex);
              tCount++;
              tPreviousValue = tValue;
            }.bind(this));
            // renders the bar for simple bar charts and the first bar segment for split bars
            makeRect(tPrimaryCoord, tPreviousCoord, tCount,
                tCaseIndices, tTotalNumCasesInPrimary, tValue, tPrimaryName, tTotalNumCases);
          }.bind(this));
        }.bind(this));
      },

      /**
       Override base class because we're dealing with rectangles, not points.
       @return {Array of {x:{Number}, y:{Number}, width:{Number}, height:{Number}, cx:{Number}, cy:{Number}, r:{Number}, fill:{String}}}
       */
      getElementPositionsInParentFrame: function () {

        var tFrame = this.get('frame');
        return this.get('plottedElements').map(function (iElement) {
          var tX = iElement.attr('x') + tFrame.x,
              tY = iElement.attr('y') + tFrame.y,
              tWidth = iElement.attr('width'),
              tHeight = iElement.attr('height'),
              tR = 0, //Math.min( tWidth, tHeight) / 2,
              tCx = tX + tWidth / 2,
              tCy = tY + tHeight / 2,
              tResult = {
                x: tX, y: tY, width: tWidth, height: tHeight, cx: tCx, cy: tCy, r: tR,
                fill: iElement.attr('fill'), type: 'rect', stroke: iElement.attr('stroke'),
                'stroke-opacity': iElement.attr('stroke-opacity')
              };
          return tResult;
        });
      },

      /**
       We override the base class implementation
       */
      animateFromTransferredElements: function () {
        var this_ = this,
            tModel = this.get('model'),
            tCases = tModel.get('cases'),
            tRC = this.createRenderContext(),
            tFrame = this.get('frame'), // to convert from parent frame to this frame
            tOldElementAttrs = this.get('transferredElementCoordinates'),
            tNewElementAttrs = [], // used if many-to-one animation (parent to child collection)
            tNewToOldCaseMap = [],
            tOldToNewCaseMap = [],
            tOldElementsAreCircles = tOldElementAttrs[0] && tOldElementAttrs[0].type === 'circle';
        if (!tCases)
          return;

        function turnOffAnimation() {
          tModel.set('isAnimating', false);
          this_.get('plottedElements').forEach(function (iElement) {
            iElement.stop();
          });
          this_.displayDidChange(); // Force redisplay in correct position
        }

        function caseLocationSimple(iIndex) {
          // assume a 1 to 1 correspondence of the current case indices to the new cases
          return tOldElementAttrs[iIndex];
        }

        function caseLocationViaMap(iIndex) {
          // use our case index map to go from current case index to previous case index
          return tOldElementAttrs[tNewToOldCaseMap[iIndex]];
        }

        DG.sounds.playMixup();
        this._getTransferredElementsToCasesMap(tNewToOldCaseMap, tOldToNewCaseMap);
        var hasElementMap = tNewToOldCaseMap.length > 0,
            hasVanishingElements = tOldToNewCaseMap.length > 0,
            getCaseCurrentLocation = (hasElementMap ? caseLocationViaMap : caseLocationSimple),
            tPlottedElements = this.get('plottedElements'),
            tTransAttrs;

        this.prepareToResetCoordinates();
        this.removePlottedElements();
        // Normally we leave the elements (circles) for re-use. But since we want rects, we have let go of the circles.
        tPlottedElements.forEach(function (iElement) {
          iElement.remove();
        });
        tPlottedElements.length = 0;
        this.computeCellParams();
        tOldElementAttrs.forEach(function (iElement, iIndex) {
          // adjust old coordinates from parent frame to this view
          // In case it's a point
          iElement.cx -= tFrame.x;
          iElement.cy -= tFrame.y;
          // in case it's a rect
          iElement.x -= tFrame.x;
          iElement.y -= tFrame.y;
        });
        tCases.forEach(function (iCase, iIndex) {
          var tOldElement = getCaseCurrentLocation(iIndex),
              tCellIndices = tModel.lookupCellForCaseIndex(iIndex),
              tElement = this_.callCreateElement(iCase, iIndex, false);
          if (!SC.none(tOldElement)) {
            tTransAttrs = {
              r: tOldElementsAreCircles ? tOldElement.r : 0,
              x: tOldElementsAreCircles ? tOldElement.cx - tOldElement.r : tOldElement.x,
              y: tOldElementsAreCircles ? tOldElement.cy - tOldElement.r : tOldElement.y,
              width: tOldElementsAreCircles ? 2 * tOldElement.r : tOldElement.width,
              height: tOldElementsAreCircles ? 2 * tOldElement.r : tOldElement.height,
              fill: tOldElement.fill,
              stroke: tOldElement.fill
            };
            tElement.attr(tTransAttrs);
          }
          tElement = this_.privSetElementCoords(tRC, iCase, iIndex, tCellIndices, true /* animate */);
          if (hasVanishingElements) {
            tNewElementAttrs.push(tElement);
          }
        });
        if (hasVanishingElements) {
          // create a vanishing element for each old element that needs one (used if many-to-one animation)
          tOldElementAttrs.forEach(function (iOldAttrs, iIndex) {
            var tNewIndex = tOldToNewCaseMap[iIndex],
                tNewAttrs = tNewElementAttrs[tNewIndex];
            if (SC.none(tNewIndex) || SC.none(tNewAttrs) || (iOldAttrs.r === 0))
              return; // no vanishing element, if (1) element persists or (2) new element hidden or (3) old element hidden
            this_.vanishPlottedElement(iOldAttrs, tNewAttrs);
          });
        }
        this.set('transferredElementCoordinates', null);

        tModel.set('isAnimating', true);
        SC.Timer.schedule({action: turnOffAnimation, interval: DG.PlotUtilities.kDefaultAnimationTime});
      }
    }
);

/* >>>>>>>>>> BEGIN source/components/graph/plots/bar_chart_formula_context.js */
sc_require('formula/collection_formula_context');

/** @class  The formula context used by the PlottedFunctionModel

 @extends DG.GlobalFormulaContext
 */
DG.BarChartFormulaContext = DG.CollectionFormulaContext.extend((function () {

  return {

    /**
     Set on construction
     @type {DG.PlotModel}
     */
    plotModel: null,

    /**
     Utility function for identifying the name of the primary attribute.
     @returns  {String}  the name of the variable on the primary axis
     */
    primaryVarName: function () {
      var varID = this.getPath('plotModel.primaryVarID'),
          varAttr = varID && DG.Attribute.getAttributeByID(varID),
          varName = varAttr && varAttr.get('name');
      return varName || null;
    }.property('plotModel'),

    /**
     Utility function for identifying the name of the X-axis attribute.
     @param    {String}    iName -- The name of the identifier being matched
     @returns  {Boolean}   True if the identifier matches the name of the
     x-axis attribute, false otherwise.
     */
    isPrimaryVarName: function (iName) {
      return !!iName && (iName === this.get('primaryVarName'));
    }.property('primaryVarName'),

    /**
     Utility function for identifying the ID of the primary categorical attribute.
     @returns  {String}  the ID of the primary categorical variable
     */
    groupVarID: function () {
      // we always want to override the default
      return this.getPath('plotModel.primaryVarID') || -1;
    }.property('plotModel'),

    /**
     * Return true if the given case is currently among those being plotted.
     *
     * @param  {Object}              iEvalContext -- { _case_: , _id_: }
     * @return {boolean}
     */
    filterCase: function (iEvalContext) {
      var tResult = arguments.callee.base.apply(this,arguments),
          tCases = this.getPath('plotModel.cases');
      return tResult && tCases.indexOf(iEvalContext._case_) >= 0;
    },

    /**
     Called when the formula has been recompiled to clear any stale dependencies.
     Derived classes may override as appropriate.
     */
    didCompile: function () {
      arguments.callee.base.apply(this,arguments);

      // register the 'plot' dependency for invalidation
      var plotModel = this.get('plotModel'),
          // TODO: use a more robust ID
          plotID = DG.Debug.scObjectID(plotModel);
      this.registerDependency({
        independentSpec: {
          type: DG.DEP_TYPE_PLOT,
          id: plotID,
          name: 'plot-' + plotID
        },
        aggFnIndices: this.ALL_FUNCTIONS
      });
    },

    /**
     Called by the DependencyMgr to invalidate dependent nodes.
     @param {object}     ioResult
     @param {object}     iDependent
     @param {object}     iDependency
     @param {DG.Case[]}  iCases - array of cases affected
     if no cases specified, all cases are affected
     @param {boolean}    iForceAggregate - treat the dependency as an aggregate dependency
     */
    invalidateDependent: function (ioResult, iDependent, iDependency, iCases, iForceAggregate) {
      arguments.callee.base.apply(this,arguments);

      // invalidate affected aggregate functions
      if (iDependency.aggFnIndices)
        this.invalidateFunctions(iDependency.aggFnIndices);
      // Note that there is a redundancy between this notification, which indicates when
      // any dependent has changed, and the DG.GlobalFormulaContext sending of the same
      // notification when a global value changes. Ultimately, the GlobalFormulaContext
      // mechanism should be disabled, but we leave that for another day.
      this.notifyPropertyChange('dependentChange');
    }

  }; // return from function closure
}())); // function closure

/* >>>>>>>>>> BEGIN source/components/graph/plots/bar_chart_formula_edit_context.js */
// ==========================================================================
//                      DG.BarChartFormulaEditContext
//
//  Author:   William Finzer
//
//  Copyright (c) 2021 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

DG.BarChartFormulaEditContext = DG.PlottedFormulaEditContext.extend({

  plotModel: null,  // Set by caller during create

  openFormulaEditorDialog: function() {
    var formulaContext = this,
        dataContext = this.getPath('plotModel.dataContext'),
        result = DG.AttributeFormulaView.buildOperandsMenuAndCompletionData(dataContext),
        clientOptions = this.get('clientOptions'),
        options = Object.assign({
                    applyTarget: formulaContext,
                    applyAction: 'applyNewFormula',
                    attrNamePrompt: 'DG.PlottedFormula.defaultNamePrompt'.loc(),
                    attrNameValue: "",
                    attrNameIsEnabled: false,
                    formulaValue: formulaContext.getPath('plotModel.expression'),
                    formulaCompletions: result.completionData,
                    formulaOperands: result.operandsMenu
                  }, clientOptions),
        formulaDialog = DG.CreateAttributeFormulaView(options);
    this.set('formulaDialog', formulaDialog);
    return formulaDialog;
  },

  createEditCommand: function(newFormula) {
    var clientOptions = this.get('clientOptions'),
        originalFormula = this.getPath('plotModel.expression');

    var setFormula = function setFormula(formula) {
      this.setPath('plotModel.expression', formula);
    }.bind(this);

    return DG.Command.create({
      isUndoable: clientOptions.isUndoable,
      name: clientOptions.commandName,
      undoString: clientOptions.undoString,
      redoString: clientOptions.redoString,
      log: clientOptions.logMessage &&
            clientOptions.logMessage.fmt(originalFormula, newFormula),
      execute: function() {
        setFormula(newFormula);
      },
      undo: function() {
        setFormula(originalFormula);
      },
      redo: function() {
        setFormula(newFormula);
      }
    });
  },

  applyNewFormula: function() {
    var cmd = this.createEditCommand(this.getPath('formulaDialog.formula'));
    if( cmd.isUndoable)
      DG.UndoHistory.execute(cmd);
    else
      cmd.execute();

    var dialog = this.get('formulaDialog');
    if (dialog) {
      dialog.close();
      this.set('formulaDialog', null);
    }
  }
});

DG.BarChartFormulaEditContext.formulaEditContexts = {};

DG.BarChartFormulaEditContext.hasFormulaEditContextFor = function(iPlotModel) {
  return iPlotModel &&
      !SC.none(DG.BarChartFormulaEditContext.formulaEditContexts[DG.Debug.scObjectID(iPlotModel)]);
};

DG.BarChartFormulaEditContext.getFormulaEditContext = function(iPlotModel) {
  var plotID = DG.Debug.scObjectID(iPlotModel);
  if (!DG.BarChartFormulaEditContext.formulaEditContexts[plotID]) {
    DG.BarChartFormulaEditContext.formulaEditContexts[plotID] =
      DG.BarChartFormulaEditContext.create({ plotModel: iPlotModel });
  }
  return DG.BarChartFormulaEditContext.formulaEditContexts[plotID];
};

DG.BarChartFormulaEditContext.destroyFormulaEditContext = function( iID) {
  var tContext = DG.BarChartFormulaEditContext.formulaEditContexts[iID];
  if( tContext) {
    tContext.destroy();
    delete DG.BarChartFormulaEditContext.formulaEditContexts[iID];
  }
};
/* >>>>>>>>>> BEGIN source/components/graph/plots/bar_chart_model.js */
// ==========================================================================
//                          DG.BarChartModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2017 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/plots/bar_chart_base_model');

/** @class  DG.BarChartModel - The model for a plot with categorical axes

 @extends DG.BarChartBaseModel
 */
DG.BarChartModel = DG.BarChartBaseModel.extend(
    /** @scope DG.BarChartModel.prototype */
    {
      /**
       *
       * @param iPlace {DG.GraphTypes.EPlace}
       * @return { class }
       */
      getDesiredAxisClassFor: function( iPlace) {
        if(iPlace === this.get('secondaryAxisPlace'))
          return DG.CountAxisModel;
        return arguments.callee.base.apply(this,arguments);
      },

      naturalUpperBound: function () {
        var tNaturalUpperBound,
            tMaxInCell = this.get('maxInCell'),
            tHasLegend = !SC.none(this.get('legendVarID'));
        switch (this.get('breakdownType')) {
          case DG.Analysis.EBreakdownType.eCount:
            tNaturalUpperBound = Math.max( 4, tMaxInCell);
            break;
          case DG.Analysis.EBreakdownType.ePercent:
            tNaturalUpperBound = tHasLegend ? 100 : 100 * tMaxInCell / this.get('cases').length();
            break;
        }
        return 1.05 * tNaturalUpperBound;
      }.property('breakdownType'),

      breakdownTypeDidChange: function () {
        this.setPath('secondaryAxisModel.scaleType', this.get('breakdownType'));
      }.observes('breakdownType'),

      /**
       Subclasses may override
       @param { DG.GraphTypes.EPlace }
       @return{ {min:{Number}, max:{Number} isDataInteger:{Boolean}} }
       */
      getDataMinAndMaxForDimension: function (iPlace) {
        var tResult = {
          min: 0,
          max: this.get('naturalUpperBound'),
          isDataInteger: this.get('breakdownType') === DG.Analysis.EBreakdownType.eCount
        };
        return tResult;
      }


    });

/* >>>>>>>>>> BEGIN source/components/graph/plots/bar_chart_view.js */
// ==========================================================================
//                          DG.BarChartView
//
//  Author:   William Finzer
//
//  Copyright (c) 2017 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/plots/bar_chart_base_view');

/* global pluralize */

/** @class  DG.BarChartView, a plot of rectangles, one for each category. Each rectangle is made of
 * thinner rectangles, one for each case.

 @extends DG.BarChartBaseView
 */
DG.BarChartView = DG.BarChartBaseView.extend(
    /** @scope DG.BarChartView.prototype */
    {
      /**
       * Make sure the count axis has the correct upper bounds
       */
      setupAxes: function () {
        arguments.callee.base.apply(this,arguments);
        var tCountAxisView = this.get('secondaryAxisView');
        // Only set the bounds if they aren't already present
        if (tCountAxisView && SC.none(tCountAxisView.getPath('model.lowerBound'))) {
          tCountAxisView.get('model').setLowerAndUpperBounds(0, this.getPath('model.naturalUpperBound'));
        }
      },

      /**
       * Return the class of the count axis with the x or y to put it on.
       * @return {[{}]}
       */
      getAxisViewDescriptions: function () {
        var tDescriptions = arguments.callee.base.apply(this,arguments),
            tCountKey = this.getPath('model.orientation') === DG.GraphTypes.EOrientation.kVertical ? 'y' : 'x';
        tDescriptions.push({
          axisKey: tCountKey,
          axisClass: DG.CountAxisView
        });
        return tDescriptions;
      },

      getBarHeight: function (iPrimaryName, iCount, iTotal) {
        return this.getPath('model.breakdownType') === DG.Analysis.EBreakdownType.eCount
            ? iCount : 100 * iCount / iTotal;
      },

      /**
       *
       * @param iRC {*}
       * @param iCase {DG.Case}
       * @param iIndex {Integer}
       * @param iCellIndices {{primaryCell, secondaryCell, indexInCell}}
       * @param iAnimate {Boolean}
       * @param iCallback {Function}
       */
      privSetElementCoords: function (iRC, iCase, iIndex, iCellIndices, iAnimate, iCallback) {
        DG.assert(iRC && iRC.xAxisView);
        DG.assert(iCase);
        DG.assert(DG.MathUtilities.isInIntegerRange(iIndex, 0, this.get('plottedElements').length));
        var tRect = this.get('plottedElements')[iIndex]/*,
      tIsMissingCase = SC.none( iCellIndices )*/;

        // It can happen that we don't have cell indices yet. Bail for now cause we'll be back later.
        if (!iCellIndices)
          return;

        // show or hide if needed, then update if shown.
        // if( this.showHidePlottedElement(tRect, tIsMissingCase)) {

        var tCellHalfWidth = iRC.barWidth,
            tCellHeight = iRC.secondaryAxisView.get('fullCellWidth'),
            tBarSliceHeight = iRC.barSliceHeights[iCellIndices.primaryCell],
            tTop = (iCellIndices.indexInCell + 1) * tBarSliceHeight,
            tEdge = iRC.primaryAxisView.cellToCoordinate(iCellIndices.primaryCell) -
                tCellHalfWidth / 2,
            tCoordX, tCoordY, tWidth, tHeight;

        if (iRC.isVerticalOrientation) {
          tCoordX = tEdge;
          tCoordY = tCellHeight - tTop;
          tWidth = tCellHalfWidth;
          tHeight = tBarSliceHeight;
        } else {
          tCoordX = tTop - tBarSliceHeight;
          tCoordY = tEdge;
          tWidth = tBarSliceHeight;
          tHeight = tCellHalfWidth;
        }
        var tNewAttrs = {
          x: tCoordX, y: tCoordY, r: 0.1, width: tWidth, height: tHeight,
          fill: iRC.calcCaseColorString(iCase),
          opacity: iRC.transparency,
          'fill-opacity': iRC.transparency,
          'stroke-opacity': 0
        };
        tRect.show();
        if (iAnimate) {
          tRect.animate(tNewAttrs, DG.PlotUtilities.kDefaultAnimationTime, '<>', iCallback);
        } else {
          tRect.attr(tNewAttrs);
        }
        return tRect;
      },

      /**
       We need to decide on the number of points in a row. To do so, we find the
       maximum number of points in a cell and choose so that this max number will
       fit within the length of a cell rect. If there are so many points that they don't fit
       even by using the full length of a cell rect, then we compute an overlap.
       */
      computeCellParams: function () {
        var tMaxInCell = this.getPath('model.maxInCell'),
            tTotalNumCases = this.getPath('model.cases').length(),
            tHasLegend = !SC.none(this.getPath('model.legendVarID')),
            tMaxPercentInCell = 100 * tMaxInCell / tTotalNumCases,
            tSecondaryAxisView = this.get('secondaryAxisView'),
            tCoordOfMaxInCell = tSecondaryAxisView.dataToCoordinate(tMaxInCell),
            tCoordOf100Percent = tSecondaryAxisView.dataToCoordinate(100),
            tCoordOfMaxPercentInCell = tSecondaryAxisView.dataToCoordinate(tMaxPercentInCell),
            tCoordOfZero = tSecondaryAxisView.dataToCoordinate(0),
            tBreakdownType = this.getPath('model.breakdownType'),
            tMinBarSliceHeight = Math.abs(tCoordOfMaxInCell - tCoordOfZero) / tMaxInCell,
            tMinPercentSliceHeight = Math.abs(tCoordOfMaxPercentInCell - tCoordOfZero) / tMaxInCell,
            tSliceHeights = this.getPath('model.primaryCellCounts').map(function (iCount) {
              var tSliceHeight = 0;
              switch (tBreakdownType) {
                case DG.Analysis.EBreakdownType.eCount:
                  tSliceHeight = tMinBarSliceHeight;
                  break;
                case DG.Analysis.EBreakdownType.ePercent:
                  tSliceHeight = tHasLegend ? Math.abs(tCoordOf100Percent - tCoordOfZero) / iCount :
                      tMinPercentSliceHeight;
              }
              return tSliceHeight;
            });

        this.setIfChanged('barSliceHeights', tSliceHeights);
      },

      /**
       * Base class returns empty string. Subclasses override to compute an informative string.
       * @param iPrimaryName {String}
       * @param iCategoryName {String}
       * @param iTotalNumCases {Number}
       * @param iElement  {Element} Has cell specific properties we need: caseIndices and numCasesInContainingCell
       * @return {String}
       */
      getToolTipText: function(iPrimaryName, iCategoryName, iTotalNumCases, iElement) {
        var tLegendVarID= this.getPath('model.legendVarID'),
            tTemplate, tToolTipText;
        if (!SC.none(tLegendVarID)) {
          tTemplate = iElement.caseIndices.length > 1 ? "DG.BarChartModel.cellTipPlural" :
              "DG.BarChartModel.cellTipSingular";
          if (this.numCasesInContainingCell > 1) {
            iPrimaryName = pluralize(iPrimaryName);
            if (iPrimaryName.endsWith("S")) {
              iPrimaryName = iPrimaryName.replace(/S$/, 's');
            }
          }
          tToolTipText = tTemplate.loc(
              iElement.caseIndices.length,
              iElement.numCasesInContainingCell,
              iPrimaryName,
              Math.round(1000 * iElement.caseIndices.length / iElement.numCasesInContainingCell) / 10,
              iCategoryName
          );
        } else {
          tTemplate = iElement.caseIndices.length > 1 ? "DG.BarChartModel.cellTipNoLegendPlural" :
              "DG.BarChartModel.cellTipNoLegendSingular";
          tToolTipText = tTemplate.loc(
              iElement.caseIndices.length,
              iTotalNumCases,
              Math.round(1000 * iElement.caseIndices.length / iTotalNumCases) / 10,
              iPrimaryName
          );
        }
        return tToolTipText;
      }

    }
);

/* >>>>>>>>>> BEGIN source/components/graph/plots/univariate_plot_model.js */
// ==========================================================================
//                            DG.UnivariatePlotModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2019 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/plots/plot_model');
sc_require('components/graph/plots/numeric_plot_model_mixin');

/** @class  DG.UnivariatePlotModel The model for a dot plot.

 @extends SC.PlotModel
 */
DG.UnivariatePlotModel = DG.PlotModel.extend(DG.NumericPlotModelMixin,
    /** @scope DG.UnivariatePlotModel.prototype */
    {
      /**
       * Originally a boolean; extended to support line/bar plot
       * @property {Boolean | "bars"}
       */
      displayAsBinned: null,

      /**
       @property{Number}
       */
      primaryVarID: function () {
        return (this.get('primaryAxisPlace') === DG.GraphTypes.EPlace.eX) ?
            this.get('xVarID') : this.get('yVarID');
      }.property('primaryAxisPlace', 'xVarID', 'yVarID')/*.cacheable()*/,

      /**
       @property{DG.GraphTypes.EPlace}
       */
      primaryAxisPlace: function () {
        var dataConfiguration = this.get('dataConfiguration');
        return dataConfiguration && dataConfiguration.getPlaceForRole(DG.Analysis.EAnalysisRole.ePrimaryNumeric);
      }.property('xVarID', 'yVarID')/*.cacheable()*/,

      /**
       @property{DG.GraphTypes.EPlace}
       */
      secondaryAxisPlace: function () {
        var dataConfiguration = this.get('dataConfiguration');
        return dataConfiguration && dataConfiguration.getPlaceForRole(DG.Analysis.EAnalysisRole.eSecondaryCategorical);
      }.property('xVarID', 'yVarID')/*.cacheable()*/,

      /**
       @property{DG.CellLinearAxisModel}
       */
      primaryAxisModel: function () {
        return this.getAxisForPlace(this.get('primaryAxisPlace'));
      }.property('primaryAxisPlace', 'xAxis', 'yAxis')/*.cacheable()*/,

      /**
       @property{DG.CellLinearAxisModel}
       */
      secondaryAxisModel: function () {
        return this.getAxisForPlace(this.get('secondaryAxisPlace'));
      }.property('secondaryAxisPlace', 'xAxis', 'yAxis')/*.cacheable()*/,

      /**
       'vertical' means the stacks of dots are vertical, while 'horizontal' means they are horizontal
       @property{String}
       */
      orientation: function () {
        return (this.get('primaryAxisPlace') === DG.GraphTypes.EPlace.eX) ? DG.GraphTypes.EOrientation.kVertical :
            DG.GraphTypes.EOrientation.kHorizontal;
      }.property('primaryAxisPlace'),

      destroy: function() {
        this.invalidateComputationContext();
        arguments.callee.base.apply(this,arguments);
      },

      handleDataConfigurationChange: function ( iKey) {
        if (!DG.assert(!this.get('isDestroyed'), "DG.DotPlotModel.handleDataConfiguration() shouldn't be triggered after destroy()!"))
          return;
        arguments.callee.base.apply(this,arguments);
        var kAnimate = true, kDontLog = false;
        this.rescaleAxesFromData( iKey !== 'hiddenCases', kAnimate, kDontLog);
        this.updateAdornmentModels();
      },

      /**
       * @param iKey {String} If present, the property that changed to bring about this call
       Subclasses may override
       Called when attribute configuration changes occur, for instance.
       */
      invalidateCaches: function ( iKey) {
        arguments.callee.base.apply(this,arguments);
        this.invalidateComputationContext();
      },

      /**
       * If SC's property caching worked the way we would like it to, we wouldn't need this private property.
       * As it is, we store a cached computation context here, nulling it out by hand when caches must be
       * invalidated.
       */
      _cachedComputationContext: null,

      /**
       * Caching this computation context allows us to save a lot of 'gets'
       * @property{Object}
       */
      computationContext: function() {
        if( !this._cachedComputationContext) {
          this._cachedComputationContext = {
            primaryAxis: this.get('primaryAxisModel'),
            secondaryAxis: this.get('secondaryAxisModel'),
            primaryVarID: this.get('primaryVarID'),
            secondaryVarID: this.get('secondaryVarID'),
            legendVarID: this.get('legendVarID')
          };
        }
        return this._cachedComputationContext;
      }.property('primaryAxisModel', 'secondaryAxisModel', 'primaryVarID', 'secondaryVarID', 'legendVarID' ),

      invalidateComputationContext: function() {
        this._cachedComputationContext = null;
      }.observes('primaryAxisModel', 'secondaryAxisModel', 'primaryVarID', 'secondaryVarID', 'legendVarID' ),

      doForOneCase: function( iCase, iIndex, iCC, iDoF) {
        var tPrimaryVal = iCase.getValue( iCC.primaryVarID),
            tPrimaryIsValid = SC.none( iCC.primaryVarID) || !SC.none( tPrimaryVal),
            tSecondaryVal = iCase.getValue( iCC.secondaryVarID),
            tSecondaryIsValid = SC.none( iCC.secondaryVarID) || !SC.none( tSecondaryVal),
            tPrimaryCell, tSecondaryCell;
        if( tPrimaryIsValid && tSecondaryIsValid) {
          tPrimaryCell = iCC.primaryAxis.valueToCellNumber( tPrimaryVal);
          tSecondaryCell = iCC.secondaryAxis.cellNameToCellNumber( tSecondaryVal);
          iDoF( iCase, iIndex, tPrimaryCell, tSecondaryCell);
        }
      },

      /**
       Call the given function once for each case that has a value for each axis.
       function signature for iDoF is { iCase, iCaseIndex, iPrimaryCellIndex, iSecondaryCellIndex }
       */
      forEachBivariateCaseDo: function( iDoF, iForSelectionOnly) {
        var tCases = iForSelectionOnly ? this.get('selection') : this.get('cases'),
            tCC = this.get('computationContext');
        if( !tCC.primaryAxis || !tCases || !tCC.secondaryAxis)
          return; // Can happen during transitions. Bail!
        tCases.forEach( function( iCase, iIndex) {
          this.doForOneCase( iCase, iIndex, tCC, iDoF);
        }.bind(this));
      },

      /**
       * Get an array of non-missing case counts in each axis cell.
       * Also cell index on primary and secondary axis, with primary axis as major axis.
       * @return {Array} [{count, primaryCell, secondaryCell},...] (all values are integers 0+).
       */
      getCellCaseCounts: function ( iForSelectionOnly) {
        var tNumericAxisModel = this.get('primaryAxisModel'),
            tCategoricalAxisModel = this.get('secondaryAxisModel'),
            tValueArray = [];

        if (!( tCategoricalAxisModel && tNumericAxisModel )) {
          return tValueArray; // too early to recompute, caller must try again later.
        }

        var tNumCatCells = tCategoricalAxisModel.get('numberOfCells'),
            tNumNumericCells = tNumericAxisModel.get('numberOfCells'),
            tNumCells = tNumCatCells * tNumNumericCells,
            tCellIndex;

        // initialize the values
        for (var i = 0; i < tNumCells; ++i) {
          tValueArray.push({count: 0, selectedCount: 0, primaryCell: Math.floor( i / tNumCatCells),
            secondaryCell: i % tNumCatCells });
        }

        // compute count of cases in each cell, excluding missing values
        this.forEachBivariateCaseDo( function( iCase, iIndex, iPrimaryCell, iSecondaryCell) {
          tCellIndex = iPrimaryCell*tNumCatCells + iSecondaryCell;
          if( isFinite( tCellIndex) && DG.MathUtilities.isInIntegerRange( tCellIndex, 0, tNumCells )) {
            var iValue = tValueArray[ tCellIndex ];
            iValue.count += 1;
            DG.assert( iValue.primaryCell === (iPrimaryCell || 0), "primary cell index error in DG.UnivariatePlotModel.getCellCaseCounts()" );
            DG.assert( iValue.secondaryCell === (iSecondaryCell || 0), "secondary cell index error in DG.UnivariatePlotModel.getCellCaseCounts()" );
          }
        });

        if( iForSelectionOnly) {
          // compute count of selected cases in each cell, excluding missing values
          this.forEachBivariateCaseDo(function (iCase, iIndex, iPrimaryCell, iSecondaryCell) {
            tCellIndex = iPrimaryCell * tNumCatCells + iSecondaryCell;
            if (isFinite(tCellIndex) && DG.MathUtilities.isInIntegerRange(tCellIndex, 0, tNumCells)) {
              var iValue = tValueArray[tCellIndex];
              iValue.selectedCount += 1;
            }
          }, iForSelectionOnly);
        }

        return tValueArray;
      },

      /**
       * A dot plot can be configured as a binned chart
       * @property {Boolean}
       */
      canSupportConfigurations: function() {
        return true;
      }.property(),

      configurationDescriptions: function() {
        var this_ = this,
            kRowHeight = 20,
            tDescriptions = arguments.callee.base.apply(this,arguments);
        tDescriptions.push(
            {
              constructorClass: SC.RadioView,
              properties:
                {
                  layout: { height: 3 * kRowHeight },
                  items: [
                    {
                      title: 'DG.Inspector.graphPlotPoints'.loc(),
                      value: false, // was originally a boolean
                      enabled: YES
                    },
                    {
                      title: 'DG.Inspector.graphGroupIntoBins'.loc(),
                      value: true,  // was originally a boolean
                      enabled: YES
                    },
                    {
                      title: 'DG.Inspector.graphBarForEachPoint'.loc(),
                      value: 'bars',
                      enabled: YES
                    }
                  ],
                  value: this_.get('displayAsBinned'),
                  valueDidChange: function () {
                    var value = this.get('value');
                    this_.set('displayAsBinned', value);
                    DG.mainPage.mainPane.hideInspectorPicker();
                  }.observes('value'),
                  itemTitleKey: 'title',
                  itemValueKey: 'value',
                  itemIsEnabledKey: 'enabled',
                  isEnabled: YES,
                  layoutDirection: SC.LAYOUT_VERTICAL
                }
            }
        );
        return tDescriptions;
      }.property(),

    });

/**
 class method called before plot creation to make sure roles are correct
 @param {DG.GraphDataConfiguration}
 */
DG.UnivariatePlotModel.configureRoles = function (iConfig) {
  var tXType = iConfig.get('xType'),
      tXIsNumeric = tXType === DG.Analysis.EAttributeType.eNumeric ||
          tXType === DG.Analysis.EAttributeType.eDateTime,
      tAxisKey = tXIsNumeric ? 'x' : 'y',
      tOtherAxisKey = (tAxisKey === 'x') ? 'y' : 'x';
  iConfig.setPath(tAxisKey + 'AttributeDescription.role',
      DG.Analysis.EAnalysisRole.ePrimaryNumeric);
  iConfig.setPath(tOtherAxisKey + 'AttributeDescription.role',
      DG.Analysis.EAnalysisRole.eSecondaryCategorical);
};

/* >>>>>>>>>> BEGIN source/components/graph/plots/univariate_adornment_base_model.js */
// ==========================================================================
//                            DG.UnivariateAdornmentBaseModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2023 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/plots/univariate_plot_model');
/*global pluralize:true*/

/** @class  DG.DotPlotModel The model for a dot plot.

 @extends SC.PlotModel
 */
DG.UnivariateAdornmentBaseModel = DG.UnivariatePlotModel.extend(
    /** @scope DG.UnivariateAdornmentBaseModel.prototype */
    {
      multipleMovableValuesModel: function () {
        var tMultipleMovableValues = this.getAdornmentModel('multipleMovableValues');
        if (!tMultipleMovableValues) {
          tMultipleMovableValues = DG.MultipleMovableValuesModel.create({
            plotModel: this,
            axisModel: this.get('primaryAxisModel')
          });
          tMultipleMovableValues.addObserver('values', this, 'valuesDidChange');
          this.setAdornmentModel('multipleMovableValues', tMultipleMovableValues);
        }
        return tMultipleMovableValues;
      }.property(),

      /**
       * @property {Boolean}
       */
      isShowingMovableValues: function () {
        return this.getPath('multipleMovableValuesModel.valueModels').length > 0;
      }.property(),

      /**
       * True because we can display percents with movable values
       * @property {Boolean}
       */
      wantsPercentCheckbox: function() {
        return this.get('isShowingMovableValues') || this.get('enableMeasuresForSelection');
      }.property(),

      /** If true, labels for mean, median, std dev and MAD will show and persist
       * @property {boolean}
       */
      showMeasureLabels: false,

      destroy: function () {
        var tMultipleMovableValues = this.getAdornmentModel('multipleMovableValues');
        if (tMultipleMovableValues) {
          tMultipleMovableValues.removeObserver('valueModels', this, 'valuesDidChange');
        }
        arguments.callee.base.apply(this,arguments);
      },

      /**
       We override our base class because we want to handle display of counts and percents
       in our multipleMovableValues adornment.
       However, if we have no movable values, we defer to our base class.
       */
      togglePlottedCount: function (iWhat) {

        if (!this.get('isShowingMovableValues')) {
          arguments.callee.base.apply(this,arguments);
          return;
        }

        var this_ = this;

        function toggle() {

          function doToggle( iPlot) {
            var tMultipleMovableValues = iPlot.get('multipleMovableValuesModel'),
                tCurrentValue = tMultipleMovableValues.get('isShowing' + iWhat);
            tMultipleMovableValues.setComputingNeeded();
            tMultipleMovableValues.set('isShowing' + iWhat, !tCurrentValue);
          }

          doToggle( this_);
          this_.get('siblingPlots').forEach( doToggle);
        }

        var tInitialValue = this.getPath('multipleMovableValuesModel.isShowing' + iWhat),
            tUndo = tInitialValue ? ('DG.Undo.graph.hide' + iWhat) : ('DG.Undo.graph.show' + iWhat),
            tRedo = tInitialValue ? ('DG.Redo.graph.hide' + iWhat) : ('DG.Redo.graph.show' + iWhat);
        DG.UndoHistory.execute(DG.Command.create({
          name: "graph.toggleCount",
          undoString: tUndo,
          redoString: tRedo,
          log: ("togglePlotted" + iWhat + ": %@").fmt(tInitialValue ? "hide" : "show"),
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'toggle movable value',
              type: 'DG.GraphView'
            }
          },
          execute: function () {
            toggle();
          }.bind(this),
          undo: function () {
            toggle();
          }.bind(this),
        }));
      },

      /**
       * Override base class to refer to multipleMovableValuesModel
       @return { Boolean }
       */
      shouldPlottedCountBeChecked: function (iWhat) {
        if( this.get('isShowingMovableValues'))
          return this.getPath('multipleMovableValuesModel.isShowing' + iWhat);
        else
          return arguments.callee.base.apply(this,arguments);
      },

      /**
       * Add another movable value.
       * If it's the first one, we may have to deal with counts showing via the base class adornment.
       */
      addMovableValue: function () {
        var this_ = this,
            tAddedValues = [];

            function doAddMovableValue() {

              function addMovableValueToPlot( iPlot, iIndexMinusOne) {
                var tIndex = iIndexMinusOne + 1,
                    tMultipleMovableValues = iPlot.get('multipleMovableValuesModel'),
                    tNumAlreadyShowing = tMultipleMovableValues.get('valueModels').length,
                    tPlottedCount = iPlot.get('plottedCount'), // from base class
                    tBaseClassCountIsShowing = (tNumAlreadyShowing === 0) && tPlottedCount &&
                        tPlottedCount.get('isShowingCount'),
                    tBaseClassPercentIsShowing = (tNumAlreadyShowing === 0) && tPlottedCount &&
                        tPlottedCount.get('isShowingPercent'),
                    tAddedValue = tAddedValues[ tIndex];
                if (tAddedValue) {
                  tMultipleMovableValues.addThisValue(tAddedValue);
                  tAddedValues[ tIndex] = null;
                }
                else {
                  tAddedValue = tMultipleMovableValues.addValue();
                  tAddedValues[ tIndex] = tAddedValue;
                }
                if (tBaseClassCountIsShowing) {
                  tPlottedCount.set('isShowingCount', false);
                  tMultipleMovableValues.set('isShowingCount', true);
                }
                if (tBaseClassPercentIsShowing) {
                  tPlottedCount.set('isShowingPercent', false);
                  tMultipleMovableValues.set('isShowingPercent', true);
                }
                iPlot.notifyPropertyChange('movableValueChange');
              }

              addMovableValueToPlot( this_, -1);
              this_.get('siblingPlots').forEach( addMovableValueToPlot);
            }

            function doUndoAddMovableValue() {

              function undoAddMovableValueFromPlot( iPlot, iIndexMinusOne) {
                var tIndex = iIndexMinusOne + 1,
                    tAddedValue = tAddedValues[ tIndex];
                iPlot.getAdornmentModel('multipleMovableValues').removeThisValue(tAddedValue);
              }

              undoAddMovableValueFromPlot( this_, -1);
              this_.get('siblingPlots').forEach( undoAddMovableValueFromPlot);
            }

        DG.UndoHistory.execute(DG.Command.create({
          name: "graph.addMovableValue",
          undoString: 'DG.Undo.graph.addMovableValue',
          redoString: 'DG.Redo.graph.addMovableValue',
          log: "Added Movable Value",
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'add movable value',
              type: 'DG.GraphView'
            }
          },
          execute: doAddMovableValue,
          undo: doUndoAddMovableValue
        }));

      },

      /**
       * Add another movable value
       */
      removeMovableValue: function () {
        var this_ = this,
            tRootMMVs = this.getAdornmentModel('multipleMovableValues'),
            tShowing = { count: tRootMMVs.get('isShowingCount'),
              percent: tRootMMVs.get('isShowingPercent')},
            tNumShowing = tRootMMVs.get('valueModels').length,
            tRemovedValues = [];

            function doRemoveMovableValue() {

              function removeMovableValueFromPlot( iPlot, iIndexMinusOne) {
                var tIndex = iIndexMinusOne + 1,
                    tMultipleMovableValues = iPlot.getAdornmentModel('multipleMovableValues'),
                    tPlottedCount,
                    tRemovedValue = tRemovedValues[ tIndex];
                if( !tMultipleMovableValues)
                  return;

                if( tNumShowing === 1 && (tShowing.count || tShowing.percents) ) {
                  tPlottedCount = iPlot.get('plottedCount');
                  tPlottedCount.set('isShowingCount', tShowing.count);
                  tPlottedCount.set('isShowingPercent', tShowing.percent);
                }
                if( tRemovedValue)
                  tMultipleMovableValues.removeThisValue( tRemovedValue);
                else
                  tRemovedValues[ tIndex] = tMultipleMovableValues.removeValue();
                iPlot.notifyPropertyChange('movableValueChange');
              }

              removeMovableValueFromPlot( this_, -1);
              this_.get('siblingPlots').forEach( removeMovableValueFromPlot);
            }

            function doUndoRemoveMovableValue() {

              function undoRemoveMovableValueFromPlot( iPlot, iIndexMinusOne) {
                var tIndex = iIndexMinusOne + 1,
                    tMultipleMovableValues = iPlot.getAdornmentModel('multipleMovableValues'),
                    tRemovedValue = tRemovedValues[ tIndex];
                if( tNumShowing === 1 && (tShowing.count || tShowing.percents) ) {
                  tMultipleMovableValues.set('isShowingCount', tShowing.count);
                  tMultipleMovableValues.set('isShowingPercent', tShowing.percent);
                  iPlot.setPath('plottedCount.isShowingCount', false);
                  iPlot.setPath('plottedCount.isShowingPercent', false);
                }
                tMultipleMovableValues.addThisValue(tRemovedValue);
                tRemovedValues[ tIndex] = null;
                iPlot.notifyPropertyChange('movableValueChange');
              }

              undoRemoveMovableValueFromPlot( this_, -1);
              this_.get('siblingPlots').forEach( undoRemoveMovableValueFromPlot);
            }

        DG.UndoHistory.execute(DG.Command.create({
          name: "graph.removeMovableValue",
          undoString: 'DG.Undo.graph.removeMovableValue',
          redoString: 'DG.Redo.graph.removeMovableValue',
          log: "Added Movable Value",
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'remove movable value',
              type: 'DG.GraphView'
            }
          },
          execute: doRemoveMovableValue,
          undo: doUndoRemoveMovableValue
        }));
      },

      valuesDidChange: function () {
        this.notifyPropertyChange('valuesDidChange');
      },

      /**
       Toggle the visibility of the specified DG.PlottedAverageModel.
       Will create the adornment the first time it's shown.
       @param    {String}    iAdornmentKey -- e.g. 'plottedMean'
       @param    {String}    iToggleLogString -- Name of action logged to server
       */
      toggleAverage: function (iAdornmentKey, iToggleLogString) {
        var this_ = this;

        function toggle() {

          function doToggle( iPlot) {
            var avg = iPlot.toggleAdornmentVisibility(iAdornmentKey, iToggleLogString);
            if (avg) {
              if (avg.get('isVisible')) {
                avg.recomputeValue();     // initialize
              } else {
                avg.setComputingNeeded(); // make sure we recompute when made visible again
              }
            }
          }

          doToggle( this_);
          this_.get('siblingPlots').forEach( doToggle);

          return this_.getAdornmentModel( iAdornmentKey).get('isVisible');
        }

        DG.UndoHistory.execute(DG.Command.create({
          name: "graph." + iToggleLogString,  // e.g. graph.togglePlottedMean
          undoString: null,
          log: iToggleLogString,
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: iToggleLogString,
              type: 'DG.GraphView'
            }
          },
          execute: function () {
            var wasShown = toggle(),

                verb = wasShown ? "show" : "hide",
                action = iToggleLogString.replace("toggle", verb);

            this.set('undoString', 'DG.Undo.graph.' + action); // e.g. DG.Undo.graph.showPlottedMean
            this.set('redoString', 'DG.Redo.graph.' + action);
          },
          undo: function () {
            toggle();
          },
        }));
      },

      /**
       Assume the PlottedStErrModel exists and set its number of standard errors in an undable way.
       @param    {Number}    iNewNumStdErrs
       */
      setNumStdErrs: function (iNewNumStdErrs) {
        var this_ = this,
            logString = 'graph.setNumStdErrs: %@'.fmt(iNewNumStdErrs);

        DG.UndoHistory.execute(DG.Command.create({
          name: 'graph.setNumStdErrs',
          undoString: 'DG.Undo.graph.setNumStErrs',
          redoString: 'DG.Redo.graph.setNumStErrs',
          log: logString,
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'setNumStdErrs',
              type: 'DG.GraphView'
            }
          },
          execute: function () {
            this._numStdErrs = this_.getAdornmentModel('plottedStErr').get('numberOfStdErrs');
            this_.getAdornmentModel('plottedStErr').set('numberOfStdErrs', iNewNumStdErrs);
          },
          undo: function () {
            var stashedNumStdErrs = this_.getAdornmentModel('plottedStErr').get('numberOfStdErrs');
            this_.getAdornmentModel('plottedStErr').set('numberOfStdErrs', this._numStdErrs);
            this._numStdErrs = stashedNumStdErrs;
          },
          redo: function () {
            this.undo();
          }
        }));
     },

      /**
       Toggle the visibility of the mean.
       */
      togglePlottedMean: function () {
        this.toggleAverage('plottedMean', 'togglePlottedMean');
      },

      /**
       Toggle the visibility of the median.
       */
      togglePlottedMedian: function () {
        this.toggleAverage('plottedMedian', 'togglePlottedMedian');
      },

      /**
       Toggle the visibility of the Standard Deviation.
       */
      togglePlottedStDev: function () {
        this.toggleAverage('plottedStDev', 'togglePlottedStDev');
      },

      /**
       Toggle the visibility of the Standard Error.
       */
      togglePlottedStErr: function () {
        this.toggleAverage('plottedStErr', 'togglePlottedStErr');
      },

      /**
       Toggle the visibility of the Standard Deviation.
       */
      togglePlottedMad: function () {
        this.toggleAverage('plottedMad', 'togglePlottedMad');
      },

      /**
       Toggle the visibility of the IQR.
       */
      togglePlottedIQR: function () {
        this.toggleAverage('plottedIQR', 'togglePlottedIQR');
      },

      /**
       Toggle the visibility of the Normal Curve.
       */
      togglePlottedNormal: function () {
        this.toggleAverage('plottedNormal', 'togglePlottedNormal');
      },

      /**
       Toggle the visibility of the Box Plot.
       */
      togglePlottedBoxPlot: function () {
        this.toggleAverage('plottedBoxPlot', 'togglePlottedBoxPlot');
      },

      /**
       Toggle whether boxplot outliers are showing.
       */
      toggleShowOutliers: function () {
        var this_ = this;

        function toggle() {

          function doToggle(iPlot) {
            var tBoxPlotModel = iPlot.getAdornmentModel('plottedBoxPlot');
            if (tBoxPlotModel) {
              tBoxPlotModel.toggleProperty('showOutliers');
              tBoxPlotModel.setComputingNeeded();
            }
          }

          doToggle(this_);
          this_.get('siblingPlots').forEach(doToggle);
          return this_.getAdornmentModel('plottedBoxPlot').get('showOutliers');
        }


        DG.UndoHistory.execute(DG.Command.create({
          name: "graph.boxPlot.showOutliers",
          undoString: null,
          log: "graph.boxPlot.showOutliers",
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'toggle show outliers',
              type: 'DG.GraphView'
            }
          },
          execute: function () {
            var wasShown = toggle(),

                verb = wasShown ? "show" : "hide",
                action = "toggleOutliers".replace("toggle", verb);

            this.set('undoString', 'DG.Undo.graph.' + action); // e.g. DG.Undo.graph.showPlottedMean
            this.set('redoString', 'DG.Redo.graph.' + action);
          },
          undo: function () {
            toggle();
          }
        }));
      },

      /**
       Toggle whether boxplot informal confidence interval is showing.
       */
      toggleShowICI: function () {
        var this_ = this;

        function toggle() {

          function doToggle(iPlot) {
            var tBoxPlotModel = iPlot.getAdornmentModel('plottedBoxPlot');
            if (tBoxPlotModel) {
              tBoxPlotModel.toggleProperty('showICI');
              tBoxPlotModel.setComputingNeeded();
            }
          }

          doToggle(this_);
          this_.get('siblingPlots').forEach(doToggle);
          return this_.getAdornmentModel('plottedBoxPlot').get('showICI');
        }


        DG.UndoHistory.execute(DG.Command.create({
          name: "graph.boxPlot.showICI",
          undoString: null,
          log: "graph.boxPlot.showICI",
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'toggle show outliers',
              type: 'DG.GraphView'
            }
          },
          execute: function () {
            var wasShown = toggle(),

               verb = wasShown ? "show" : "hide",
               action = "toggleICI".replace("toggle", verb);

            this.set('undoString', 'DG.Undo.graph.' + action); // e.g. DG.Undo.graph.showPlottedMean
            this.set('redoString', 'DG.Redo.graph.' + action);
          },
          undo: function () {
            toggle();
          }
        }));
      },

      updateAdornmentsModels: function() {
        arguments.callee.base.apply(this,arguments);
        ['multipleMovableValues', 'plottedMean', 'plottedMedian', 'plottedStDev', 'plottedStErr', 'plottedNormal',
          'plottedBoxPlot', 'plottedCount'].forEach(function (iAdornmentKey) {
          var adornmentModel = this.getAdornmentModel(iAdornmentKey);
          if (adornmentModel) {
            if (adornmentModel.setComputingNeeded)
              adornmentModel.setComputingNeeded();  // invalidate if axis model/attribute change
            if (iAdornmentKey === 'multipleMovableValues') {
              adornmentModel.recomputeValueIfNeeded(this.get('primaryAxisModel'));
            }
            else {
              adornmentModel.recomputeValueIfNeeded(); // recompute only if/when visible
            }
          }
        }.bind(this));
      },

      /**
       * Pass to my multipleMovableValues. We do this only after axis bounds have changed
       */
      onRescaleIsComplete: function() {
        this.get('multipleMovableValuesModel').handleChangedAxisAttribute();
      },

      createStorage: function () {
        var tStorage = arguments.callee.base.apply(this,arguments);
        tStorage.showMeasureLabels = this.get('showMeasureLabels');
        return tStorage;
      },

      restoreStorage: function (iStorage) {
        arguments.callee.base.apply(this,arguments);
        this.showMeasureLabels = iStorage.showMeasureLabels || false;
        var tMultipleMovable = this.getAdornmentModel('multipleMovableValues');
        if (tMultipleMovable)
          tMultipleMovable.set('axisModel', this.get('primaryAxisModel'));
      },

      /**
       * Return a list of objects { key, class, useAdornmentModelsArray, storage }
       * Subclasses should override calling sc_super first.
       * @return {[Object]}
       */
      getAdornmentSpecs: function() {
        var tSpecs = arguments.callee.base.apply(this,arguments);
        DG.ObjectMap.forEach( this._adornmentModels, function( iKey, iAdorn) {
          tSpecs.push( {
            key: iKey,
            "class": iAdorn.constructor,
            useAdornmentModelsArray: true,
            storage: iAdorn.createStorage()
          });
        });
        return tSpecs;
      },

      /**
       * Base class will do most of the work. We just have to finish up the multipleMovableValues model.
       * @param {DG.PlotModel} iSourcePlot
       */
      installAdornmentModelsFrom: function( iSourcePlot) {
        arguments.callee.base.apply(this,arguments);
        var tMultipleMovable = this.getAdornmentModel('multipleMovableValues');
        if (tMultipleMovable)
          tMultipleMovable.set('axisModel', this.get('primaryAxisModel'));
      },

      createStdErrorOption: function() {
        function isStdErrVisible() {
          return this_.isAdornmentVisible('plottedStErr');
        }

        var this_ = this,
           kMargin = 20,
           kLeading = 5,
           kPadding = 5,
           kRowHeight = 20,
           tStdErrModel = this.getAdornmentModel('plottedStErr'),
           tNumStdErrs = tStdErrModel ? tStdErrModel.get('numberOfStdErrs') : 1,
           tLabel = tNumStdErrs === 1 ? 'DG.Inspector.graphPlottedStErr'.loc()
                                      : pluralize('DG.Inspector.graphPlottedStErr'.loc()),
           tShowStdErrCheckbox = SC.CheckboxView.create( {
             layout: {left: 0, top: 3, height: kRowHeight, width: 25 },
             localize: true,
             flowSpacing: { left: kMargin, top: kLeading },
             title: '',
             value: this.isAdornmentVisible('plottedStErr'),
             classNames: 'dg-graph-plottedStErr-check dg-ruler-check'.w(),
             valueDidChange: function () {
               this_.togglePlottedStErr();
               tNumberEditField.set('isEnabled', isStdErrVisible());
             }.observes('value')
           }),
           tNumberEditField = SC.TextFieldView.create({
             layout: { height: kRowHeight + kLeading, width : 50 },
             isEnabled: isStdErrVisible(),
             flowSpacing: { left: 0, top: 0 },
             supportsAutoResize: true,
             type: 'number',
             value: tNumStdErrs,
             maxLength: 5,
             valueDidChange: function () {
               var tProposedValue = Number(this.get('value'));
               if( DG.isFinite( tProposedValue)) {
                 if (tProposedValue >= 0)
                   this_.setNumStdErrs(tProposedValue);
                 else
                   this.set('value', tNumStdErrs);
               }
             }.observes('value')
           }),
           tLabelView = SC.LabelView.create({
             layout: { height: kRowHeight, width : 100 },
             value: tLabel,
             localize: true
           });
        this.invokeLater( function() {
          document.getElementById(tNumberEditField.get('layerId')).style.background = 'white';
        }, 100);
        return SC.View.create( SC.FlowedLayout,
           {
             layoutDirection: SC.LAYOUT_HORIZONTAL,
             isResizable: false,
             isClosable: false,
             layout: {left: 0, height: kRowHeight + kLeading},
             defaultFlowSpacing: {left: kPadding, top: kLeading},
             shouldResizeWidth: false,
             canWrap: false,
             flowSpacing: {left: 0},
             init: function() {
               arguments.callee.base.apply(this,arguments);
               this.appendChild( tShowStdErrCheckbox);
               this.appendChild(tNumberEditField);
               this.appendChild(tLabelView);
             }
           });
      },

      checkboxDescriptions: function () {
        var this_ = this,
            tShowLabelsCheckbox = [],
            kRowHeight = 20;

        function toggleShowMeasureLabels() {
          var tString = this_.get('showMeasureLabels') ? 'hide' : 'show';
          DG.UndoHistory.execute(DG.Command.create({
            name: 'toggle show measure labels',
            undoString: 'DG.Undo.graph.'+ tString + 'MeasureLabels',
            redoString: 'DG.Redo.graph.'+ tString + 'MeasureLabels',
            log: tString + ' measure labels',
            _redoValue: null,
            executeNotification: {
              action: 'notify',
              resource: 'component',
              values: {
                operation: tString + ' measure labels',
                type: 'DG.Graph'
              }
            },
            execute: function() {
              this_.toggleProperty('showMeasureLabels');
            },
            undo: function() {
              this.execute();
            }
          }));
        }

        function createRadioGroupWithControls( iTitle, iVisibilityProperty, iControls) {
          var tGroupView = DG.RulerGroupView.create( {
            title: iTitle.loc(),
            visibilityStateProperty: iVisibilityProperty,
          });
          iControls.forEach( function( iDesc) {
            if( iDesc.control) {
              tGroupView.appendChild(iDesc.control);
            }
            else {
              iDesc.classNames.push('dg-ruler-check');
              iDesc.layout = { height: kRowHeight };
              iDesc.localize = true;
              tGroupView.appendChild(SC.CheckboxView.create(iDesc));
            }
          }.bind( this));
          tGroupView.syncChildViewVisibility();
          return tGroupView;
        }

        function createBoxPlotToggle() {
          var kMargin = 20,
              kLeading = 5,
              kRowHeight = 20,
             tBoxPlotModel = this_.getAdornmentModel('plottedBoxPlot'),
             kIciEnabled = DG.get('informalConfidenceIntervalEnabled')==='yes' ||
                           (tBoxPlotModel && this_.getAdornmentModel('plottedBoxPlot').get('showICI')),
              tShowOutliersCheckbox = SC.CheckboxView.create( {
                layout: { height: kRowHeight },
                localize: true,
                flowSpacing: { left: 2 * kMargin },
                title: 'DG.Inspector.graphBoxPlotShowOutliers',
                value: this_.getAdornmentModel('plottedBoxPlot') ?
                    this_.getAdornmentModel('plottedBoxPlot').get('showOutliers') : false,
                classNames: 'dg-graph-boxPlotShowOutliers-check'.w(),
                valueDidChange: function () {
                  this_.toggleShowOutliers();
                }.observes('value')
              }),
             tShowIciCheckbox = SC.CheckboxView.create( {
               layout: { height: kRowHeight },
               localize: true,
               flowSpacing: { left: 2 * kMargin },
               title: 'DG.Inspector.graphBoxPlotShowICI',
               value: tBoxPlotModel ? tBoxPlotModel.get('showICI') : false,
               classNames: 'dg-graph-boxPlotShowICI-check'.w(),
               valueDidChange: function () {
                 this_.toggleShowICI();
               }.observes('value')
             }),
              tBoxPlotCheckbox = SC.CheckboxView.create( {
                layout: { left: kMargin, height: kRowHeight },
                localize: true,
                title: 'DG.Inspector.graphPlottedBoxPlot',
                value: this_.isAdornmentVisible('plottedBoxPlot'),
                classNames: 'dg-graph-plottedBoxPlot-check'.w(),
                valueDidChange: function () {
                  this_.togglePlottedBoxPlot();
                  tShowOutliersCheckbox.set('isEnabled', isBoxPlotVisible());
                  tShowIciCheckbox.set('isEnabled', isBoxPlotVisible());
                }.observes('value')
              });

          function isBoxPlotVisible() {
            return this_.isAdornmentVisible('plottedBoxPlot');
          }

          var tComposite =  SC.View.create( SC.FlowedLayout,
              {
                layoutDirection: SC.LAYOUT_VERTICAL,
                isResizable: false,
                isClosable: false,
                layout: {left: kMargin, height: 2 * (kRowHeight + kLeading)},
                defaultFlowSpacing: {left: kMargin, bottom: kLeading},
                canWrap: false,
                align: SC.ALIGN_TOP,
                // layout: {right: 22},
                boxplot: null,
                showOutliers: null,
                init: function() {
                  arguments.callee.base.apply(this,arguments);
                  tShowOutliersCheckbox.set('isEnabled', this_.isAdornmentVisible('plottedBoxPlot'));
                  this.appendChild( tBoxPlotCheckbox);
                  this.appendChild(tShowOutliersCheckbox);
                  if( kIciEnabled) {
                    tShowIciCheckbox.set('isEnabled', this_.isAdornmentVisible('plottedBoxPlot'));
                    this.appendChild(tShowIciCheckbox);
                  }
                }
              });
          return tComposite;
        }

        function createMeasuresOfCenterGroup() {
          return createRadioGroupWithControls('DG.Inspector.graphCenterOptions', 'measuresOfCenter',
          [{
              title: 'DG.Inspector.graphPlottedMean',
              value: this_.isAdornmentVisible('plottedMean'),
              classNames: 'dg-graph-plottedMean-check'.w(),
              valueDidChange: function () {
              this_.togglePlottedMean();
            }.observes('value')
           },
            {
              title: 'DG.Inspector.graphPlottedMedian',
              value: this_.isAdornmentVisible('plottedMedian'),
              classNames: 'dg-graph-plottedMedian-check'.w(),
              valueDidChange: function () {
                this_.togglePlottedMedian();
              }.observes('value')
            }
          ]);
        }

        function createMeasuresOfSpreadGroup() {
          return createRadioGroupWithControls('DG.Inspector.graphSpreadOptions', 'measuresOfSpread',
          [
            {
              title: 'DG.Inspector.graphPlottedStDev',
              value: this_.isAdornmentVisible('plottedStDev'),
              classNames: 'dg-graph-plottedStDev-check'.w(),
              valueDidChange: function () {
                this_.togglePlottedStDev();
              }.observes('value')
            },
            {
              control: this_.createStdErrorOption()
            },
            {
              title: 'DG.Inspector.graphPlottedMeanAbsDev',
              value: this_.isAdornmentVisible('plottedMad'),
              classNames: 'dg-graph-plottedMad-check'.w(),
              valueDidChange: function () {
                this_.togglePlottedMad();
              }.observes('value')
            }
          ]);
        }

        function createBoxPlotAndNormalCurveGroup() {
          var kGaussianFitEnabled = DG.get('gaussianFitEnabled')==='yes',
              tDotsAreFused = this_.get('dotsAreFused'),
              groupTitle = kGaussianFitEnabled && tDotsAreFused ? 'DG.Inspector.graphBoxPlotGaussianFitOptions'
                       : 'DG.Inspector.graphBoxPlotNormalCurveOptions';
          return createRadioGroupWithControls(groupTitle.loc(), 'boxPlotAndNormalCurve',
          [
            {
              control: createBoxPlotToggle()
            },
            {
              title: (tDotsAreFused && kGaussianFitEnabled) ? 'DG.Inspector.graphPlottedGaussianFit'
                                                                        :'DG.Inspector.graphPlottedNormal',
              value: this_.isAdornmentVisible('plottedNormal'),
              classNames: 'dg-graph-plottedNormal-check'.w(),
              valueDidChange: function () {
                this_.togglePlottedNormal();
              }.observes('value')
            }
          ]);
        }

        function createOtherValuesGroup() {
          var kMargin = 20,
              kLeading = 5;
          return createRadioGroupWithControls('DG.Inspector.graphOtherValuesOptions', 'otherValues',
             [
               {
                 title: 'DG.Inspector.graphPlottedValue',
                 value: this_.isAdornmentVisible('plottedValue'),
                 classNames: 'dg-graph-plottedValue-check'.w(),
                 valueDidChange: function () {
                   this_.togglePlotValue();
                 }.observes('value')
               },
               {
                 control: SC.ButtonView.create({
                   classNames: 'dg-movable-value-button'.w(),
                   defaultFlowSpacing: {left: kMargin, bottom: kLeading},
                   themeName: 'capsule',
                   title: 'DG.Inspector.graphAdd',
                   localize: YES,
                   action: this_.addMovableValue.bind(this_),
                 })
               },
               {
                 control: SC.ButtonView.create({
                   classNames: 'dg-movable-value-button',
                   defaultFlowSpacing: {left: kMargin, bottom: kLeading},
                   title: 'DG.Inspector.graphRemove',
                   themeName: 'capsule',
                   localize: YES,
                   action: this_.removeMovableValue.bind(this_),
                 })
               }
             ]);
        }

        if( !SC.platform.touch) { // We don't show this option on a touch system
          tShowLabelsCheckbox.push(
             {
               title: 'DG.Inspector.showLabels',
               value: this_.get('showMeasureLabels'),
               classNames: 'dg-graph-showLabels-check'.w(),
               valueDidChange: function () {
                 toggleShowMeasureLabels();
               }.observes('value')
             }
          );
        }

        return arguments.callee.base.apply(this,arguments).concat(tShowLabelsCheckbox.concat([
          { control: createMeasuresOfCenterGroup() },
          { control: createMeasuresOfSpreadGroup() },
          { control: createBoxPlotAndNormalCurveGroup() },
          { control: createOtherValuesGroup() }
        ]));
      }.property(),

    });

DG.UnivariateAdornmentBaseModel.rulerState = {
  measuresOfCenter: true, // is visible by default
  measuresOfSpread: false, // not visible by default
  boxPlotAndNormalCurve: false, // not visible by default
  otherValues: false, // not visible by default
};

/* >>>>>>>>>> BEGIN source/components/graph/plots/binned_plot_model.js */
// ==========================================================================
//                            DG.BinnedPlotModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2020 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/plots/univariate_adornment_base_model');

/**
 * @class  DG.BinnedPlotModel The model for a dot plot in which the dots are binned.
 *
 * Notes
 *  - When the plot is grouped into cells by a categorical attribute, the alignment and width is the same for
 *    all the cells.
 *  - The default number of bins applies across all the cells rather than separately for each cell. Thus, to
 *    determine the alignment and width we have to find the min and max of all the values, regardless of cell.
 *
 * @extends DG.UnivariateAdornmentBaseModel
 */
DG.BinnedPlotModel = DG.UnivariateAdornmentBaseModel.extend((function () {

  var kDefaultNumberOfBins = 4;

      return {
        /** @scope DG.BinnedPlotModel.prototype */
        displayAsBinned: true,

        dotsAreFused: false,
        dotsAreFusedDidChange: function() {
          if( this.get('dotsAreFused')) {
            this.setPath('plottedCount.isVisible', false);
          }
        }.observes('dotsAreFused'),

        restoreInProgress: false,

        wantsOtherAxis: function() {
          return this.get('dotsAreFused');
        }.property('dotsAreFused'),

        /**
         * Histograms (dots are fused) get one set of axis models and binned plots another.
         * @param iPlace {DG.GraphTypes.EPlace}
         * @return { class }
         */
        getDesiredAxisClassFor: function( iPlace) {
          var tDotsAreFused = this.get('dotsAreFused');
          if( iPlace === this.get('primaryAxisPlace'))
            return tDotsAreFused ? DG.CellLinearAxisModel : DG.BinnedAxisModel;
          else if(iPlace === this.get('secondaryAxisPlace')) {
            if( tDotsAreFused)
              return DG.CountAxisModel;
            else {
              return SC.none( this.get('secondaryVarID')) ? DG.AxisModel : DG.CellAxisModel;
            }
          }
          else return arguments.callee.base.apply(this,arguments);
        },

        propagateToSiblings: function(iKey, iValue) {
          var tRootPlot = this.getRootPlot && this.getRootPlot(),
             tAllPlots = tRootPlot && tRootPlot.get('siblingPlots');
          if( tAllPlots) {
            tRootPlot.set(iKey, iValue);
            tAllPlots.forEach(function(iPlot) {
              iPlot.set(iKey, iValue);
            });
          }
        },

        /**
         * The left edge of the zeroth bin has this value
         * @property {Number}
         */
        _leastBinEdge: 0,
        leastBinEdge: function( iKey, iValue) {
          if( !SC.none( iValue)) {
            this._leastBinEdge = iValue;
          }
          else if(!this._casesMap) {
            this.updateCasesMap();
          }
          return this._leastBinEdge;
        }.property(),

        maxBinEdge: function() {
          return this.get('leastBinEdge') + this.get('totalNumberOfBins') * this.get('width');
        }.property('leastBinEdge', 'width', 'totalNumberOfBins'),

        /**
         * One of the bins is constrained to this value
         * @property {Number}
         */
        _alignment: null,
        alignment: function( iKey, iValue) {
          if( iValue !== undefined && iValue !== this._alignment) {
            this._alignment = iValue;
            this.propagateToSiblings( iKey, iValue);
          }
          else if(!this._casesMap) {
            this.updateCasesMap();
          }
          return this._alignment;
        }.property(),

        /**
         * All bins are this wide
         * @property {Number}
         */
        _width: null,
        width: function( iKey, iValue) {
          if( iValue !== undefined && iValue !== this._width) {
            this._width = iValue;
            this.propagateToSiblings( iKey, iValue);
          }
          else if(!this._casesMap) {
            this.updateCasesMap();
          }
          return this._width;
        }.property(),

        /**
         * @property {Number}
         */
        _widthIncrement: null,
        widthIncrement: function( iKey, iValue) {
          if( iValue !== undefined) {
            this._widthIncrement = iValue;
          }
          else if(!this._casesMap) {
            this.updateCasesMap();
          }
          return this._widthIncrement;
        }.property(),

        /**
         * @property {[{  value: {Number}, cell: {Number}, bin: { Number}, indexInBin: {Number} }]}
         */
        _casesMap: null,
        casesMap: function( iKey, iValue) {
          if( !SC.none( iValue)) {
            this._casesMap = iValue;
          }
          else if(!this._casesMap) {
            this.updateCasesMap();
          }
          return this._casesMap;
        }.property(),

        /**
         * @property { [{ lowerEdgeWorld: {Number}, count: {Number}, indices: [{Number}] }] }
         */
        bars: function() {
          var tTotalNumberOfBins = this.get('totalNumberOfBins'),
              tCasesMap = this.get('casesMap'),
              tBars = new Array( tTotalNumberOfBins),
              tWidth = this.get('width'),
              tLowerEdge = this.get('leastBinEdge');
          for(var i = 0; i < tTotalNumberOfBins; i++) {
            tBars[i] = { count: 0, indices: [],
                        lowerEdgeWorld: tLowerEdge + i * tWidth};
          }
          tCasesMap.forEach( function( iObject, iIndex) {
            tBars[iObject.bin].count++;
            tBars[iObject.bin].indices.push( iIndex);
            tLowerEdge += tWidth;
          });

          return tBars;
        }.property(),

        totalCount: function() {
          return this.get('bars').reduce( function( iSum, iBar) {
            return iSum + iBar.count;
          }, 0);
        }.property('bars'),

        /**
         * What is the most number of case values in a given bin?
         */
        _maxBinCount: 0,
        maxBinCount: function( iKey, iValue) {
          if( !SC.none( iValue)) {
            this._maxBinCount = iValue;
          }
          else if(!this._casesMap) {
            this.updateCasesMap();
          }
          return this._maxBinCount;
        }.property(),

        /**
         * What is the total number of bins across all cells?
         */
        _totalNumberOfBins: 0,
        totalNumberOfBins: function( iKey, iValue) {
          if( !SC.none( iValue)) {
            this._totalNumberOfBins = iValue;
          }
          else if(!this._casesMap) {
            this.updateCasesMap();
          }
          return this._totalNumberOfBins;
        }.property(),

        /**
         * Set to true to avoid infinite loops
         * @property {Boolean}
         */
        recomputing: false,

        isDateTime: function() {
          var tPrimaryPlace = this.get('primaryAxisPlace'),
              tAxisPrefix = tPrimaryPlace === DG.GraphTypes.EPlace.eX ? 'x' : 'y';
          return this.getPath('dataConfiguration.' + tAxisPrefix + 'AttributeDescription.attributeType') ===
              DG.Analysis.EAttributeType.eDateTime;
        }.property(),

        /**
         *
         * @param iIndex {Number}
         * @return { {value: {Number}, cell: {Number}, bin: { Number}, indexInBin: {Number}} }
         */
        infoForCase: function( iIndex) {
          var tCasesMap = this.get('casesMap');
          return tCasesMap && tCasesMap[ iIndex];
        },

        valueToBinNumber: function( iValue) {
          var tLeastBinEdge = this.get('leastBinEdge'),
              tWidth = this.get('width');
          return Math.floor( (iValue - tLeastBinEdge) / tWidth);
        },

        handleDataContextNotification: function (iNotifier, iChange) {
          if( iChange.operation !== 'selectCases')
            this.invalidateCasesMap();
          arguments.callee.base.apply(this,arguments);
        },

        /**
         * @param iKey {String} If present, the property that changed to bring about this call
         */
        invalidateCaches: function ( iKey) {
          arguments.callee.base.apply(this,arguments);
          this.invalidateCasesMap();
        },

        invalidateCasesMap: function() {
          this._casesMap = null;
          this.notifyPropertyChange('changed');
        }.observes('width', 'alignment'),

        /**
         * Called directly by GraphModel. If it is our primary axis attribute that has changed,
         * we need to recompute width, alignment, and increment.
         * @parameter {String}  Either 'xAxis' or 'yAxis'
         */
        xOrYAttributeDidChange: function( iAxisKey) {
          var tPrimaryPlace = this.get('primaryAxisPlace'),
              tPlaceThatChanged = (iAxisKey === 'xAxis') ? DG.GraphTypes.EPlace.eX : DG.GraphTypes.EPlace.eY;
          if( tPrimaryPlace === tPlaceThatChanged) {
            this.set('width', null);
            this.set('alignment', null);
            this.set('widthIncrement', null);
          }
        },

        updateCasesMap: function () {
          if( this.recomputing)
            return; // Avoid recursion
          this.recomputing = true;

          var tCases = this.get('cases'),
              tNumericVarID = this.get('primaryVarID'),
              tNumericAxisModel = this.get('primaryAxisModel'),
              tCategoricalVarID = this.get('secondaryVarID'),
              tCategoricalAxisModel = this.get('secondaryAxisModel'),
              tMin = Number.MAX_VALUE,
              tMax = -Number.MAX_VALUE,
              tBinCounts = [],
              tWidth = this._width,
              tAlignment = this._alignment,
              tLeastBinEdge = this._leastBinEdge,
              tMaxBinCount = this._maxBinCount,
              tTotalNumberOfBins = this._totalNumberOfBins;

          if (!(tCategoricalAxisModel && tNumericAxisModel)) {
            this.recomputing = false;
            return; // too early to recompute, caller must try again later.
          }

          var tNumCells = tCategoricalAxisModel.get('numberOfCells');
          this._casesMap = [];

          if( tCases.length() === 0 && (SC.none( tWidth) || SC.none( tAlignment))) {
            tWidth = 1;
            tAlignment = 0;
            tLeastBinEdge = 0;
            tMaxBinCount = 0;
            tTotalNumberOfBins = 0;
          }
          else {
            tCases.forEach(function (iCase, iIndex) {
              var tNumericValue = iCase.getForcedNumericValue(tNumericVarID),
                  tCellValue = iCase.getStrValue(tCategoricalVarID),
                  tCellNumber = tCategoricalAxisModel.cellNameToCellNumber(tCellValue);
              if (tCellNumber != null &&
                  DG.MathUtilities.isInIntegerRange(tCellNumber, 0, tNumCells) && // if Cell Number not missing
                  !SC.none(tNumericValue)) { // if numeric value not missing
                tMin = Math.min(tMin, tNumericValue);
                tMax = Math.max(tMax, tNumericValue);
                this._casesMap[iIndex] = {value: tNumericValue, cell: tCellNumber};
              }
            }.bind(this));
            // We can get in here during a transition without a valid casesMap
            if( this._casesMap.length !== 0) {
              tWidth = this.get('width');
              if (SC.none(tWidth)) {
                tWidth = DG.MathUtilities.goodTickValue((tMax - tMin) / kDefaultNumberOfBins);
              }
              tAlignment = this.get('alignment') || Math.floor(tMin / tWidth) * tWidth;
              tLeastBinEdge = tAlignment - Math.ceil((tAlignment - tMin) / tWidth) * tWidth;
              tMaxBinCount = 0;
              // Note that we add a small number so that we get enough bins to accommodate a number
              // that lies exactly on the top edge
              tTotalNumberOfBins = Math.ceil((tMax - tLeastBinEdge) / tWidth + 0.000001);
              this._widthIncrement = DG.MathUtilities.goodTickValue((tMax - tMin) / tTotalNumberOfBins) / 20;

              // Put each case in a bin
              // this._casesMap.forEach(function (iObject) {
              tCases.forEach(function (iCase, iIndex) {
                var tObject = this._casesMap[iIndex];
                if( tObject) {
                  tObject.bin = Math.floor((tObject.value - tLeastBinEdge) / tWidth);
                  if (!tBinCounts[tObject.cell])
                    tBinCounts[tObject.cell] = [];
                  if (!tBinCounts[tObject.cell][tObject.bin])
                    tBinCounts[tObject.cell][tObject.bin] = 0;
                  tObject.indexInBin = tBinCounts[tObject.cell][tObject.bin];
                  tBinCounts[tObject.cell][tObject.bin]++;
                  tMaxBinCount = Math.max(tMaxBinCount, tBinCounts[tObject.cell][tObject.bin]);
                }
              }.bind(this));
            }
          }

          this.beginPropertyChanges();
          this.set('width', tWidth);
          this.set('alignment', tAlignment);
          this.set('leastBinEdge', tLeastBinEdge);
          this.set('maxBinCount', tMaxBinCount);
          this.set('totalNumberOfBins', tTotalNumberOfBins);
          this.endPropertyChanges();

          this.recomputing = false;
          this.restoreInProgress = false;
        },

        /**
         * For each bin, pass the [min,max) interval to the given functor
         * @param iFunc {Function}
         */
        forEachBinDo: function (iFunc) {
          if( !this._casesMap) {
            this.updateCasesMap();
          }
          var tLowerEdge = this.get('leastBinEdge'),
              tNumberOfBins = this.get('totalNumberOfBins'),
              tWidth = this.get('width'),
              tWidthIncrement = this.get('widthIncrement'),
              tDigits = tWidthIncrement >= 1 ? 0 : Math.abs( Math.floor( Math.log10(tWidthIncrement))),
              tIsDateTime = this.get('isDateTime'),
              tDateLevel = tIsDateTime ?
                  DG.DateUtilities.mapLevelToPrecision(DG.DateUtilities.determineLevels(tLowerEdge, tLowerEdge +
                      ( tNumberOfBins - 1) * tWidth).innerLevel) :
                  null;
          for( var tBinNum = 0; tBinNum < tNumberOfBins; tBinNum++) {
            var tLower = tIsDateTime ? DG.DateUtilities.formatDate( tLowerEdge, tDateLevel, true /* useShort */) :
                  DG.MathUtilities.formatNumber( tLowerEdge, tDigits),
                tUpper = tIsDateTime ? DG.DateUtilities.formatDate( tLowerEdge + tWidth, tDateLevel, true /* useShort */) :
                    DG.MathUtilities.formatNumber( tLowerEdge + tWidth, tDigits);
            iFunc( tBinNum, tLower, tUpper);
            tLowerEdge += tWidth;
          }
        },

        /**
         * Return a list of objects { key, class, useAdornmentModelsArray, storage }
         * Subclasses should override calling sc_super first.
         * @return {[Object]}
         */
        getAdornmentSpecs: function () {
          var tSpecs = arguments.callee.base.apply(this,arguments);
          DG.ObjectMap.forEach(this._adornmentModels, function (iKey, iAdorn) {
            tSpecs.push({
              key: iKey,
              "class": iAdorn.constructor,
              useAdornmentModelsArray: true,
              storage: iAdorn.createStorage()
            });
          });
          return tSpecs;
        },

        /**
         * Base class will do most of the work. We just have to finish up the multipleMovableValues model.
         * @param {DG.PlotModel} iSourcePlot
         */
        installAdornmentModelsFrom: function (iSourcePlot) {
          arguments.callee.base.apply(this,arguments);
        },

        /**
         Each axis should rescale based on the values to be plotted with it.
         @param{Boolean} Default is false
         @param{Boolean} Default is true
         @param{Boolean} Default is false
         @param{Boolean} Default is false
         */
        rescaleAxesFromData: function (iAllowScaleShrinkage, iAnimatePoints, iLogIt, iUserAction) {
          if (iAnimatePoints === undefined)
            iAnimatePoints = true;
          this.doRescaleAxesFromData([DG.GraphTypes.EPlace.eX, DG.GraphTypes.EPlace.eY],
              iAllowScaleShrinkage, iAnimatePoints, iUserAction);
          if (iLogIt)
            DG.logUser("rescaleBinnedPlot");
        },

        /**
         @override
         @param iPlace { DG.GraphTypes.EPlace }
         @return{ {min:{Number}, max:{Number} isDataInteger:{Boolean}} }
         */
        getDataMinAndMaxForDimension: function (iPlace) {
          if( iPlace === this.get('secondaryAxisPlace')) {
            return {
              min: 0,
              max: this.get('maxBinCount'),
              isDataInteger: true
            };
          }
          else if( iPlace === this.get('primaryAxisPlace')) {
            return {
              min: this.get('leastBinEdge'),
              max: this.get('maxBinEdge')
            };
          }
        },

        /**
         * Change the value corresponding to the given key
         * @param iKey {String} Should be 'displayAsBinned'
         * @param iValue {Boolean}
         * @param iParamString {String}
         */
        changeBinParam: function( iKey, iValue, iParamString) {
          var tInitialValue = this.get(iKey);
          DG.UndoHistory.execute(DG.Command.create({
            name: "graph.changeBinParam",
            undoString: 'DG.Undo.graph.' + iParamString,
            redoString: 'DG.Redo.graph.' + iParamString,
            log: ("change %@ from %@ to %@").fmt(iKey, tInitialValue, iValue),
            executeNotification: {
              action: 'notify',
              resource: 'component',
              values: {
                operation: 'change bin parameter',
                type: 'DG.GraphView'
              }
            },
            execute: function() {
              this.set(iKey, iValue);
            }.bind(this),
            undo: function() {
              this.set(iKey, tInitialValue);
            }.bind(this)
          }));
        },

        toggleDotsAreFused: function() {
          var tDotsStartOutFused = this.get('dotsAreFused'),
              tUndo = tDotsStartOutFused ? 'DG.Undo.graph.dissolveRectanglesToDots' :
                  'DG.Undo.graph.fuseDotsToRectangles',
              tRedo = tDotsStartOutFused ? 'DG.Redo.graph.dissolveRectanglesToDots' :
                  'DG.Redo.graph.fuseDotsToRectangles';
          DG.UndoHistory.execute(DG.Command.create({
            name: "graph.changeDotPlotModelType",
            undoString: tUndo,
            redoString: tRedo,
            log: ("toggleShowAs: %@").fmt(tDotsStartOutFused ? "Histogram" : "BinnedDotPlot"),
            executeNotification: {
              action: 'notify',
              resource: 'component',
              values: {
                operation: 'toggle between histogram and dots',
                type: 'DG.GraphView'
              }
            },
            execute: function() {
              this.toggleProperty('dotsAreFused');
            }.bind(this),
            undo: function() {
              this.execute();
            }
          }));
        },

        checkboxDescriptions: function () {
          if( !this.get('dotsAreFused')) {
            return this.get('checkboxDescriptionsForPlotModel');  // Jump to base class
          }
          return arguments.callee.base.apply(this,arguments);
        }.property(),

        lastValueControls: function () {
          if( !this.get('dotsAreFused')) {
            return [];  // We don't have any
          }
          return arguments.callee.base.apply(this,arguments);
        }.property(),

        lastConfigurationControls: function () {
          var this_ = this,
              tControls = arguments.callee.base.apply(this,arguments),
              kRowHeight = 18;

          [ {
              label: 'DG.Inspector.graphBinWidth', key: 'width', paramString: 'changeBinWidth'
            },
            {
              label: 'DG.Inspector.graphAlignment', key: 'alignment', paramString: 'changeBinAlignment'
            }].forEach(function (iInfo) {
            tControls.push(
                SC.View.create({
                  layout: {height: kRowHeight},
                  init: function () {
                    arguments.callee.base.apply(this,arguments);
                    this.appendChild(SC.LabelView.create({
                      layout: {height: kRowHeight},
                      value: iInfo.label,
                      localize: true
                    }));
                    this.appendChild(SC.TextFieldView.create({
                      classNames: 'dg-inspector-textentry',
                      layout: {height: kRowHeight, width: 40, right: 0},
                      applyImmediately: false,
                      value: this_.get(iInfo.key),
                      valueDidChange: function () {
                        var tNewValue = Number(this.get('value')),
                            tCurrentValue = this_.get(iInfo.key);
                        if(isNaN(tNewValue) || (tNewValue <= 0 && iInfo.key === 'width')) {
                          this.set('value', tCurrentValue);
                        }
                        else if( tNewValue !== tCurrentValue)
                          this_.changeBinParam(iInfo.key, tNewValue, iInfo.paramString);
                      }.observes('value')
                    }));
                  }
                })
            );
          });
          if( this.get('secondaryVarID') === DG.Analysis.kNullAttribute) {
            tControls.push(SC.CheckboxView.create({
              layout: {height: kRowHeight},
              title: 'DG.Inspector.graphBarChart',
              classNames: 'dg-graph-fuse-check'.w(),
              value: this_.get('dotsAreFused'),
              valueDidChange: function () {
                this_.toggleDotsAreFused();
                DG.mainPage.mainPane.hideInspectorPicker();
              }.observes('value'),
              localize: true
            }));
          }

          return tControls;
        }.property('plot'),

        /**
         * Create the model data to save with document.
         * Derived plot models will add to this storage.
         * @return {Object} the saved data.
         */
        createStorage: function () {
          var tStorage = arguments.callee.base.apply(this,arguments);

          ['width', 'alignment', 'dotsAreFused', 'totalNumberOfBins'].forEach( function( iProp) {
            tStorage[iProp] = this.get(iProp);
          }.bind( this));

          return tStorage;
        },

        /**
         * @param iStorage
         */
        restoreStorage: function (iStorage) {
          arguments.callee.base.apply(this,arguments);
          this.restoreInProgress = true;
          ['width', 'alignment', 'dotsAreFused', 'totalNumberOfBins'].forEach( function( iProp) {
            if (!SC.none(iStorage[iProp])) {
              this.set( iProp, iStorage[iProp]);
            }
          }.bind( this));
        }

      };
    }())
);

/**
 class method called before plot creation to make sure roles are correct
 @param iConfig {DG.GraphDataConfiguration}
 */
DG.BinnedPlotModel.configureRoles = function (iConfig) {
  // Base class has method for this
  DG.UnivariatePlotModel.configureRoles(iConfig);
};

/* >>>>>>>>>> BEGIN source/components/graph/plots/univariate_plot_view.js */
// ==========================================================================
//                          DG.UnivariatePlotView
//
//  Author:   William Finzer
//
//  Copyright (c) 2019 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/plots/plot_view');

/** @class  DG.UnivariatePlotView - A plot of dots piled up along a numeric axis

 @extends DG.PlotView
 */
DG.UnivariatePlotView = DG.PlotView.extend(
    /** @scope DG.UnivariatePlotView.prototype */
    {
      displayProperties: ['secondaryAxisView.model.numberOfCells', 'overlap'],

      /**
       * Return the class of the count axis with the x or y to put it on.
       * @return {[{}]}
       */
      getAxisViewDescriptions: function () {
        var tDescriptions = arguments.callee.base.apply(this,arguments),
            tCatAxisKey = this.getPath('model.orientation') === DG.GraphTypes.EOrientation.kVertical ? 'y' : 'x',
            tCatAttributeID = this.getPath('model.' + tCatAxisKey + 'VarID'),
            tCatAxisClass = tCatAttributeID === DG.Analysis.kNullAttribute ? DG.AxisView : DG.CellAxisView;
        tDescriptions.push( {
          axisKey: tCatAxisKey,
          axisClass: tCatAxisClass
        });
        return tDescriptions;
      },     /**
       @property{ DG.CellLinearAxisView | DG.BinnedAxisView}
       */
      primaryAxisView: function () {
        switch (this.getPath('model.primaryAxisPlace')) {
          case DG.GraphTypes.EPlace.eX:
            return this.get('xAxisView');
          case DG.GraphTypes.EPlace.eY:
            return this.get('yAxisView');
          default:
            return null;
        }
      }.property()/*.cacheable()*/,
      primaryAxisViewDidChange: function () {
        this.notifyPropertyChange('primaryAxisView');
      }.observes('*model.primaryAxisPlace', 'xAxisView', 'yAxisView'),

      /**
       @property{DG.AxisView | DG.CellAxisView}
       */
      secondaryAxisView: function () {
        switch (this.getPath('model.primaryAxisPlace')) {
          case DG.GraphTypes.EPlace.eX:
            return this.get('yAxisView');
          case DG.GraphTypes.EPlace.eY:
            return this.get('xAxisView');
          default:
            return null;
        }
      }.property()/*.cacheable()*/,
      secondaryAxisViewDidChange: function () {
        this.notifyPropertyChange('secondaryAxisView');
      }.observes('*model.secondaryAxisPlace', 'xAxisView', 'yAxisView'),

      /**
       * Prepare axes for univariate plot, including resetting plot-specific values.
       */
      setupAxes: function () {
        var tPrimaryAxisModel = this.getPath('primaryAxisView.model');
        if (tPrimaryAxisModel) {
          if (tPrimaryAxisModel.get('preferZeroLowerBound'))
            tPrimaryAxisModel.set('preferZeroLowerBound', false);
          if (tPrimaryAxisModel.get('drawZeroLine'))
            tPrimaryAxisModel.set('drawZeroLine', false);
        }

        // The secondaryAxisView needs to be told that its tick marks and labels are not to be centered in each cell.
        // Though this is the default, if the prior plot was a dot chart, the axis will be stuck in centering mode.
        var tCellAxis = this.get('secondaryAxisView');
        if (tCellAxis) {
          tCellAxis.set('centering', false);
        }
      },

      /**
       When there is room for each stack, the overlap is 0. As soon as one of the stacks reaches
       the plot boundary, the overlap must increase. The amount that must be subtracted from
       each stack coordinate is the overlap times the index of the point in the stack.
       @property {Number}
       */
      overlap: 0,

      /**
       * Update the plot when case values have changed.
       */
      dataRangeDidChange: function (iSource, iQuestion, iKey, iChanges) {
        this.notifyPropertyChange('plotDisplayDidChange');
        arguments.callee.base.apply(this,arguments);
      },

      /**
       * Construct and return a new render context
       * used for setCircleCoordinate()
       * @return {*}
       */
      createRenderContext: function () {
        var tRC = arguments.callee.base.apply(this,arguments),
            tModel = this.get('model');

        // cache some more render parameters common to all cases, but unique to UnivariatePlotView.
        tRC.categoryAxisView = this.get('secondaryAxisView');
        tRC.categoryAxisModel = tRC.categoryAxisView && tRC.categoryAxisView.get('model');
        tRC.categoryVarID = tModel && tModel.get('secondaryVarID');
        tRC.primaryVarID = tModel && tModel.get('primaryVarID');
        tRC.primaryAxisPlace = tModel && tModel.get('primaryAxisPlace');
        tRC.primaryAxisView = this.get('primaryAxisView');

        if (!tRC.primaryAxisView)
          return null;

        return tRC;
      },

      createElement: function (iCase, iIndex, iAnimate) {
        var tCircle = this.get('paper').circle(-100, -100, this._pointRadius);

        tCircle.node.setAttribute('shape-rendering', 'geometricPrecision');

        return this.assignElementAttributes(tCircle, iIndex, iAnimate);
      },

      /**
       We may clear and draw everything from scratch if required.
       */
      drawData: function drawData() {

        if (this.getPath('model.isAnimating'))
          return; // Points are animating to new position

        if (!SC.none(this.get('transferredElementCoordinates'))) {
          this.animateFromTransferredElements();
          return;
        }

        arguments.callee.base.apply(this,arguments);
      },

      /**
       * This function gets called by a scheduled timer. We force a recomputation of overlap and a redisplay.
       */
      cleanupFunc: function () {
        this.prepareToResetCoordinates();
        this.displayDidChange();
      }

    });

/* >>>>>>>>>> BEGIN source/components/graph/plots/binned_plot_view.js */
// ==========================================================================
//                          DG.BinnedPlotView
//
//  Author:   William Finzer
//
//  Copyright (c) 2019 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/plots/univariate_plot_view');

/** @class  DG.BinnedPlotView, a plot of dots each placed according to numeric value bins

 @extends DG.UnivariatePlotView
 */
DG.BinnedPlotView = DG.UnivariatePlotView.extend(
    /** @scope DG.BinnedPlotView.prototype */
    {
      kLineSlideHCur: DG.Browser.customCursorStr('../../../../static/dg/de/cert/resources/cursors/LineSlideH.cur', 8, 8),
      kLineSlideVCur: DG.Browser.customCursorStr('../../../../static/dg/de/cert/resources/cursors/LineSlide.cur', 8, 8),

      /**
       * @property { Boolean }
       */
      dragInProgress: false,

      /**
       * @property {Element}
       */
      elementBeingDragged: null,

      numPointsInRow: 0,
      /**
       * @property {[{boundary: Element, cover: Element, worldValue: Number, lowerEdgeScreenCoord: Number }]}
       */
      binBoundaries: null,

      init: function () {
        arguments.callee.base.apply(this,arguments);
        this.binBoundaries = [];
      },

      destroy: function () {
        var tLayerManager = this.getPath('paperSource.layerManager');
        this.binBoundaries.forEach(function (iSpec) {
          tLayerManager.removeElement(iSpec.boundary);
          iSpec.boundary.remove();
          tLayerManager.removeElement(iSpec.cover);
          iSpec.cover.remove();
        });
        this.binBoundaries = null;
        arguments.callee.base.apply(this,arguments);
      },

      /**
       * Return the class of the count axis with the x or y to put it on.
       * @return {[{}]}
       */
      getAxisViewDescriptions: function () {
        var tDescriptions = arguments.callee.base.apply(this,arguments),
            tBinnedAxisKey = this.getPath('model.orientation') === DG.GraphTypes.EOrientation.kVertical ? 'x' : 'y';
        tDescriptions.push( {
          axisKey: tBinnedAxisKey,
          axisClass: DG.BinnedAxisView,
          axisModelProperties: {binnedPlotModel: this.get('model')}
        });
        return tDescriptions;
      },

      /**
       * Construct and return a new render context
       * used for setCircleCoordinate()
       * @return {*}
       */
      createRenderContext: function () {
        var tRC = arguments.callee.base.apply(this,arguments);

        if (tRC) {
          tRC.model = this.get('model');
          tRC.cellHalfWidth = tRC.categoryAxisView.get('fullCellWidth') / 2;
        }

        return tRC;
      },

      /**
       * Set the coordinates and other attributes of the case circle (a Rafael element in this.get('plottedElements')).
       * @param {{}} iRC case-invariant Render Context
       * @param {DG.Case} iCase the case data
       * @param {number} iIndex index of case in collection
       * @param {Boolean} iAnimate (optional) want changes to be animated into place?
       * @param {function} iCallback
       * @returns {{cx:{Number},cy:{Number}}} final coordinates or null if not defined (hidden plot element)
       */
      setCircleCoordinate: function (iRC, iCase, iIndex, iAnimate, iCallback) {
        iAnimate = iAnimate || this.dragInProgress;
        var tPlottedElements = this.get('plottedElements'),
            tInfo = iRC.model.infoForCase(iIndex);
        if(!tInfo)
          return; // Happens during transition from one plot to another
        DG.assert(iCase, 'There must be a case');
        DG.assert(DG.MathUtilities.isInIntegerRange(iIndex, 0, tPlottedElements.length),
            'index %@ out of bounds for plottedElements of length %@'.loc(iIndex, tPlottedElements.length));
        var tCircle = tPlottedElements[iIndex],
            tBinCoord = iRC.primaryAxisView.binToCoordinate(tInfo.bin),
            tIsMissingCase = (!tInfo || !DG.isFinite(tBinCoord) ||
                iRC.primaryAxisPlace === DG.GraphTypes.EPlace.eUndefined);

        // show or hide if needed, then update if shown.
        if (this.showHidePlottedElement(tCircle, tIsMissingCase, iIndex) && iRC.categoryAxisModel) {

          var tCellNumber = tInfo.cell,
              tCellCoord = SC.none(tCellNumber) ? 0 : iRC.categoryAxisView.cellToCoordinate(tCellNumber),
              tCellHalfWidth = iRC.cellHalfWidth,
              tRadius = this._pointRadius,
              tNumInRow = this.get('numPointsInRow'),
              tRow = Math.floor(tInfo.indexInBin / tNumInRow),
              tCol = tInfo.indexInBin - tRow * tNumInRow,
              tPrimaryCoord = tBinCoord - (tNumInRow - 1) * tRadius + tCol * 2 * tRadius,
              tOverlap = this.get('overlap'),
              tStackCoord = tRadius + (2 * tRadius - tOverlap) * tRow + 1,
              tCoordX, tCoordY;

          // Express coordinates in terms of x and y
          switch (iRC.primaryAxisPlace) {
            case DG.GraphTypes.EPlace.eX:
              tCoordX = tPrimaryCoord;
              tCoordY = tCellCoord - tStackCoord + tCellHalfWidth;
              break;
            case DG.GraphTypes.EPlace.eY:
              tCoordX = tCellCoord + tStackCoord - tCellHalfWidth;
              tCoordY = tPrimaryCoord;
              break;
          }

          var tAttrs = {
            cx: tCoordX,
            cy: tCoordY,
            r: this.radiusForCircleElement(tCircle),
            fill: iRC.calcCaseColorString(iCase),
            stroke: iRC.calcStrokeColorString(iCase),
            'fill-opacity': iRC.transparency,
            'stroke-opacity': iRC.strokeTransparency
          };
          this.updatePlottedElement(tCircle, tAttrs, iAnimate, iCallback);
          return {cx: tCoordX, cy: tCoordY, r: tRadius};
        }
        return null;
      },

      assignElementAttributes: function (iElement, iIndex, iAnimate) {
        arguments.callee.base.apply(this,arguments);

        var this_ = this,
            kOpaque = 1,
            tInitialTransform = null;

        iElement.hover(function (event) {  // over
              if (!this_.dragInProgress) {
                // Note that Firefox can come through here repeatedly so we have to check for existence
                if (SC.none(tInitialTransform)) {
                  tInitialTransform = '';
                  this.animate({
                    opacity: kOpaque,
                    transform: DG.PlotUtilities.kDataHoverTransform
                  }, DG.PlotUtilities.kDataTipShowTime);
                  this_.showDataTip(this, iIndex);
                }
              }
            },
            function (event) { // out
              if( !this_.dragInProgress) {
                this.stop();
                this.animate({
                  opacity: DG.PlotUtilities.kDefaultPointOpacity,
                  transform: tInitialTransform
                }, DG.PlotUtilities.kHighlightHideTime);
                tInitialTransform = null;
                this_.hideDataTip();
              }
            });
        return iElement;
      },

      modelWidthOrAlignmentDidChange: function() {
        this.displayDidChange();
      }.observes('model.changed'),

      markBinParamsChange: function( iInitialAlignment, iInitialBinWidth) {
        var this_ = this,
            tNewAlignment = this.getPath('model.alignment'),
            tNewBinWidth = this.getPath('model.width');
        DG.UndoHistory.execute(DG.Command.create({
          name: 'graph.drag.binBoundary',
          undoString: 'DG.Undo.graph.dragBinBoundary',
          redoString: 'DG.Redo.graph.dragBinBoundary',
          log: "dragBinBoundary from { alignment: %@, width: %@ } to { alignment: %@, width: %@ }".
                  fmt(iInitialAlignment, iInitialBinWidth, tNewAlignment, tNewBinWidth),
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'drag bin boundary',
              type: 'DG.GraphView'
            }
          },
          execute: function() { },
          undo: function() {
            this_.setPath('model.alignment', iInitialAlignment);
            this_.setPath('model.width', iInitialBinWidth);
          },
          redo: function() {
            this_.setPath('model.alignment', tNewAlignment);
            this_.setPath('model.width', tNewBinWidth);
          }
        }));
      },

      /**
       Generate the svg needed to display the plot
       */
      doDraw: function doDraw() {
        var this_ = this;

        function drawBinBoundaries() {
          var kMinBinWidth = 20,
              tInitialAlignment, tInitialWorldWidth, tNewBinAlignment, tBinWidthAtStartOfDrag,
              tModel = this_.get('model'),
              tLeastBinEdgeWorld = tModel.get('leastBinEdge'),
              tWorldWidth = tModel.get('width'),
              tWidthIncrement,
              tPaper = this_.get('paper'),
              tOrientation = this_.getPath('primaryAxisView.orientation'),
              tAdornmentLayer = this_.getPath('layerManager.' + DG.LayerNames.kAdornments),
              tPlace = this_.getPath('primaryAxisView.pixelMin'),
              tLineStart = this_.getPath('secondaryAxisView.pixelMin'),
              tBinWidthPixels = this_.getPath('primaryAxisView.binWidth'),
              tWorldPerPixel,
              tBinHeight = Math.abs(this_.getPath('secondaryAxisView.pixelMax') -
                  this_.getPath('secondaryAxisView.pixelMin')) - 5,
              tNumBins = this_.getPath('model.totalNumberOfBins'),
              tBoundaries = this_.get('binBoundaries'),
              tCursor = (tOrientation === DG.GraphTypes.EOrientation.kVertical) ?
                  this_.kLineSlideVCur : this_.kLineSlideHCur,
              tTitle = 'DG.BinnedPlotModel.dragBinTip'.loc();

          function colorBoundaries() {
            var kDefaultColor = DG.PlotUtilities.kBinBorderLineColor,
                kDragColor = 'steelblue';

            function decorateLine( iLine, iColor, iWidth) {
              iLine.attr( { stroke: iColor, 'stroke-width': iWidth });
            }

            if( this_.dragInProgress) {
              this_.binBoundaries.forEach( function( iSpec, iIndex) {
                if( iSpec.worldValue === tNewBinAlignment) {
                  decorateLine( iSpec.boundary, kDragColor, 2);
                  if( iIndex > 0)
                    decorateLine( this_.binBoundaries[iIndex - 1].boundary, kDefaultColor, 2);
                }
                else
                  decorateLine( iSpec.boundary, kDefaultColor, 1);
              });
            }
            else {
              this_.binBoundaries.forEach( function( iSpec) {
                decorateLine( iSpec.boundary, kDefaultColor, 1);
              });
            }
          }

          function beginTranslate(iWindowX, iWindowY) {
            this_.dragInProgress = true;
            this_.elementBeingDragged = this;
            tBinWidthPixels = this_.getPath('primaryAxisView.binWidth');
            tInitialAlignment = tModel.get('alignment');
            tWorldWidth = tModel.get('width');
            tInitialWorldWidth = tModel.get('width');
            tWidthIncrement = tModel.get('widthIncrement');
            tWorldPerPixel = tWorldWidth / tBinWidthPixels;
            tBinWidthAtStartOfDrag = this_.getPath('primaryAxisView.binWidth');
            this_.set('binNumBeingDragged', this.binNum);
            tNewBinAlignment = tBoundaries[this.binNum].worldValue;
            colorBoundaries();
          }

          function continueTranslate(idX, idY) {
            var tOrientation = this_.getPath('primaryAxisView.orientation'),
                tDelta = (tOrientation === DG.GraphTypes.EOrientation.kVertical) ? -idY : idX,
                tNewBinWidthPixels = Math.max(kMinBinWidth, tBinWidthAtStartOfDrag + tDelta),
                tNewWorldWidth = tNewBinWidthPixels * tWorldPerPixel;
            tNewWorldWidth = Math.round(tNewWorldWidth / tWidthIncrement) * tWidthIncrement;
            SC.run(function () {
              tModel.beginPropertyChanges();
              tModel.set('alignment', tNewBinAlignment);
              tModel.set('width', tNewWorldWidth);
              tModel.endPropertyChanges();
            });
            colorBoundaries();
          }

          function endTranslate(idX, idY) {
            var tNewWidth = tModel.get('width');
            if( tNewBinAlignment !== tInitialAlignment || tInitialWorldWidth !== tNewWidth) {
              this_.markBinParamsChange( tInitialAlignment, tInitialWorldWidth);
            }
            this_.set('binNumBeingDragged', null);
            this_.dragInProgress = false;
            if( this_.elementBeingDragged.shouldGoAway) {
              tAdornmentLayer.prepareToMoveOrRemove(this_.elementBeingDragged);
              this_.elementBeingDragged.remove();
              this_.elementBeingDragged = null;
            }
            colorBoundaries();
            this_.displayDidChange();
          }

          if(!tPaper)
            return; // Not ready to draw

          for (var tBinNum = 0; tBinNum < tNumBins; tBinNum++) {
            var tWorldValue = tLeastBinEdgeWorld + tBinNum * tWorldWidth,
                tLeft, tTop, tRight, tBottom, tLowerEdgeScreenCoord,
                tLine, tCover;
            if (tOrientation === DG.GraphTypes.EOrientation.kVertical) {
              tLeft = tLineStart;
              tTop = tPlace - (tBinNum + 1) * tBinWidthPixels;
              tRight = tLeft + tBinHeight;
              tBottom = tTop;
              tLowerEdgeScreenCoord = tTop + tBinWidthPixels;
            }
            else {
              tLeft = tPlace + (tBinNum + 1) * tBinWidthPixels;
              tTop = tLineStart - tBinHeight;
              tRight = tLeft;
              tBottom = tLineStart;
              tLowerEdgeScreenCoord = tLeft - tBinWidthPixels;
            }
            if (!tBoundaries[tBinNum]) {
              tLine = tPaper.line(tLeft, tTop, tRight, tBottom);
              tCover = tPaper.line(tLeft, tTop, tRight, tBottom)
                  .drag(continueTranslate, beginTranslate, endTranslate);
              tCover.binNum = tBinNum;
              tAdornmentLayer.push(
                  tLine.attr({
                    stroke: DG.PlotUtilities.kBinBorderLineColor,
                    'stroke-width': DG.PlotUtilities.kBinBorderWidth
                  }));
              tAdornmentLayer.push(
                  tCover.attr({
                    'stroke-width': 6, stroke: DG.RenderingUtilities.kSeeThrough,
                    cursor: tCursor, title: tTitle
                  }));
              tBoundaries[tBinNum] = {boundary: tLine, cover: tCover };
            }
            else {
              tLine = tBoundaries[tBinNum].boundary;
              tCover = tBoundaries[tBinNum].cover;
              tCover.attr({cursor: tCursor});
              DG.RenderingUtilities.updateLine(tLine, {x: tLeft, y: tTop}, {x: tRight, y: tBottom});
              DG.RenderingUtilities.updateLine(tCover, {x: tLeft, y: tTop}, {x: tRight, y: tBottom});
            }
            tBoundaries[tBinNum].worldValue = tWorldValue;
            tBoundaries[tBinNum].lowerEdgeScreenCoord = tLowerEdgeScreenCoord;
          }
          while (tBoundaries.length > tNumBins) {
            var tSpec = tBoundaries.pop();
            tAdornmentLayer.prepareToMoveOrRemove(tSpec.boundary);
            tSpec.boundary.remove();
            if( tSpec.cover !== this_.elementBeingDragged) {
              tAdornmentLayer.prepareToMoveOrRemove(tSpec.cover);
              tSpec.cover.remove();
            }
            else
              this_.elementBeingDragged.shouldGoAway = true;  // So that it can be removed later in drag code

          }
        }

        arguments.callee.base.apply(this,arguments);

        this.computeBinParams();

        drawBinBoundaries();

        this.drawData();

        this.updateSelection();
      },

      /**
       We need to decide on the number of points in a row. To do so, we find the
       maximum number of points in a bin and choose so that this max number will
       fit within the length of a bin rect. If there are so many points that they don't fit
       even by using the full length of a bin rect, then we compute an overlap.
       */
      computeBinParams: function () {
        var tBinWidth = this.getPath('primaryAxisView.binWidth'),
            tBinHeight = this.getPath('secondaryAxisView.fullCellWidth') - 5,
            tMaxBinCount = this.getPath('model.maxBinCount'),
            tPointSize = 2 * this._pointRadius,
            tAllowedPointsPerColumn = Math.max(1, Math.floor(tBinHeight / tPointSize)),
            tAllowedPointsPerRow = Math.max(1, Math.floor(tBinWidth / tPointSize)),
            tNumPointsInRow = Math.max(1,
                Math.min(tAllowedPointsPerRow,
                    Math.ceil(tMaxBinCount / tAllowedPointsPerColumn))),
            tActualPointsPerColumn = Math.ceil(tMaxBinCount / tNumPointsInRow),
            tOverlap = Math.max(0, ((tActualPointsPerColumn + 1) * tPointSize - tBinHeight) /
                tActualPointsPerColumn);
        tOverlap = Math.min(tOverlap, tPointSize); // Otherwise points can stack downward

        if (!isFinite(tNumPointsInRow))
          tNumPointsInRow = 0;
        if (!isFinite(tOverlap))
          tOverlap = 0;

        this.beginPropertyChanges();
        this.setIfChanged('numPointsInRow', tNumPointsInRow);
        this.setIfChanged('overlap', tOverlap);
        this.endPropertyChanges();
      }

    });


/* >>>>>>>>>> BEGIN source/components/graph/plots/case_plot_model.js */
// ==========================================================================
//                          DG.CasePlotModel
//
//  This is the "empty" plot that shows one icon per case
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/plots/plot_model');

/** @class  DG.CasePlotModel

  @extends DG.PlotModel
*/
DG.CasePlotModel = DG.PlotModel.extend(
/** @scope DG.CasePlotModel.prototype */ 
{

  dataContextDidChange: function(iSource, iKey) {
    arguments.callee.base.apply(this,arguments);
    if( iKey === 'dataContext') {
      this.get('dataConfiguration').updateCaptionAttribute();
    }
  }.observes('*dataConfiguration.dataContext'),

  /**
   * @property{Array of {x: {Number} y: {Number}}
   */
  worldValues: null,

  /**
   *
   * @param iIndex {Number}
   * @return { x:{Number}, y:{Number} }
   */
  getWorldCoords: function( iIndex) {
    if( SC.none( this.worldValues))
      this.worldValues = [];

    var tWorldValues = this.worldValues;
    if( (iIndex >= tWorldValues.length) || SC.none( tWorldValues[ iIndex]))
      tWorldValues[ iIndex] = { x: Math.random(), y: Math.random() };

    return tWorldValues[ iIndex];
  },

  /**
   *
   * @param iIndex {Number}
   * @param { x:{Number}, y:{Number} }
   */
  setWorldCoords: function( iIndex, iWorldValues) {
    if( SC.none( this.worldValues))
      this.worldValues = [];

    this.worldValues[ iIndex] = iWorldValues;
  },

  /**
   * Assign new random values to the coordinates.
   */
  mixUp: function() {
    this.set('worldValues', []);
  },

  /**
   * Get an array of non-missing case counts in each axis cell.
   * Also cell index on primary and secondary axis, with primary axis as major axis.
   * @return {Array} [{count, primaryCell, secondaryCell},...] (all values are integers 0+).
   */
  getCellCaseCounts: function( iForSelectionOnly) {
    // assumes a single row and column axis cell and no missing cases
    var tValueArray = [];
    var tCases = iForSelectionOnly ? this.get('selection') : this.get('cases');
    var tNumCases = tCases.get('length');
    var tEntry = { primaryCell: 0, secondaryCell: 0 };
    if( iForSelectionOnly)
      tEntry.selectedCount = tNumCases;
    else
      tEntry.count = tNumCases;
    tValueArray.push( tEntry);
    return tValueArray;
   }

});


/* >>>>>>>>>> BEGIN source/components/graph/plots/case_plot_view.js */
// ==========================================================================
//                          DG.CasePlotView
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/plots/plot_view');

/** @class DG.CasePlotView - A plot of dots placed according to numeric values

 @extends DG.PlotView
 */
DG.CasePlotView = DG.PlotView.extend(
    /** @scope DG.CasePlotView.prototype */
    (function () {

      function dataToCoordinate(iValue, iMin, iMax, iMargin) {
        return iMin + iMargin + iValue * (iMax - iMin - 2 * iMargin);
      }

      function addHandlers(iView, iElOrPointSet) {
        function changeCaseValues(iIndex, iWorldValues) {
          iView.get('model').setWorldCoords(iIndex, iWorldValues);
        }

        var tIsDragging = false,
            kOpaque = 1,
            tInitialTransform = null;
        if (iElOrPointSet.events) {
          iElOrPointSet.events.forEach(function (iHandler) {
            iHandler.unbind();
          });
          iElOrPointSet.events.length = 0;
        }

        iElOrPointSet
            .hover(function (event) {  // over
                  // Note that Firefox can come through here repeatedly so we have to check for existence
                  if (!tIsDragging && SC.none(tInitialTransform)) {
                    tInitialTransform = this.transform();
                    this.animate({
                      opacity: kOpaque,
                      transform: DG.PlotUtilities.kDataHoverTransform
                    }, DG.PlotUtilities.kDataTipShowTime);
                    iView.showDataTip(this, this.index);
                  }
                },
                function (event) { // out
                  iView.hideDataTip();
                  if (!tIsDragging) {
                    this.stop();
                    this.animate({transform: tInitialTransform}, DG.PlotUtilities.kHighlightHideTime);
                    tInitialTransform = null;
                  }
                })
            .mousedown(function (iEvent) {
              iView.get('model').selectCaseByIndex(this.index, iEvent.shiftKey);
            })
            .drag(function (dx, dy) { // continue
                  // TODO: drag all selected cases, not just this case.
                  var tWorldX = iView.get('xAxisView').coordinateToData(this.ox + dx),
                      tWorldY = iView.get('yAxisView').coordinateToData(this.oy + dy),
                      tPoint = {x: tWorldX, y: tWorldY},
                      tRC = iView.createRenderContext(),
                      tCurrTransform = this.transform();
                  if (isFinite(tPoint.x) && isFinite(tPoint.y)) {
                    // Put the element into the initial transformed state so that changing case values
                    // will not be affected by the scaling in the current transform.
                    this.transform(tInitialTransform);
                    changeCaseValues(this.index, tPoint);
                    this.transform(tCurrTransform);
                  }
                  iView.setCircleCoordinate(tRC, iView.getPath('model.cases').at(this.index), this.index);
                },
                function (x, y) { // begin
                  tIsDragging = true;
                  this.ox = this.attr("cx");
                  this.oy = this.attr("cy");
                  this.animate({opacity: kOpaque}, DG.PlotUtilities.kDataTipShowTime, "bounce");
                  this.toFront();
                },
                function () {  // end
                  this.animate({transform: tInitialTransform}, DG.PlotUtilities.kHighlightHideTime);
                  tIsDragging = false;
                });
      }

      return {

        handlersMustBeInstalledToExistingElements: true,

        init: function () {
          arguments.callee.base.apply(this,arguments);
        },

        dataRangeDidChange: function (iSource, iQuestion, iKey, iChanges) {
          var this_ = this,
              tPlotElementLength = this.get('plottedElements').length,
              tCases = this.getPath('model.cases'),
              tRC = this.createRenderContext();

          // iChanges can be a single index or an array of indices
          var tChanges = (SC.typeOf(iChanges) === SC.T_NUMBER ? [iChanges] : iChanges);
          tChanges = tChanges || [];
          tChanges.forEach(function (iIndex) {
            var tCase = tCases.at(iIndex);
            if (iIndex >= tPlotElementLength)
              this_.callCreateElement(tCase, iIndex, this_._createAnimationOn);
            this_.setCircleCoordinate(tRC, tCase, iIndex);
          });
          arguments.callee.base.apply(this,arguments);
        },

        /**
         * Override because we do things a little differently
         * @param iElement
         * @param iIndex
         * @param iAnimate
         * @return {{events}|*}
         */
        assignElementAttributes: function (iElement, iIndex, iAnimate) {
          addHandlers( this, iElement);
          iElement.index = iIndex;
          if (iAnimate)
            DG.PlotUtilities.doCreateCircleAnimation(iElement);
          return iElement;
        },

        /**
         * Set the coordinates and other attributes of the case circle (a Rafael element in this.get('plottedElements')).
         * @param iRC {} case-invariant Render Context
         * @param iCase {DG.Case} the case data
         * @param iIndex {number} index of case in collection
         * @param iAnimate {Boolean} (optional) want changes to be animated into place?
         * @param iCallback {Function} Will be called when animation finished
         * @returns {cx {Number},cy {Number}} final coordinates or null if not defined (hidden plot element)
         */
        setCircleCoordinate: function (iRC, iCase, iIndex, iAnimate, iCallback) {
          DG.assert(iRC && iRC.xAxisView, 'incomplete render context');
          DG.assert(iCase, 'no case');
          DG.assert(DG.MathUtilities.isInIntegerRange(iIndex, 0, this.get('plottedElements').length),
              'out of bounds', 'Index for circle element');

          var tCircle = this.get('plottedElements')[iIndex],
              tRadius = this.radiusForCircleElement(tCircle),
              tWorldCoords = this.get('model').getWorldCoords(iIndex),
              tCoordX = dataToCoordinate(tWorldCoords.x,
                  iRC.xAxisView.get('pixelMin'), iRC.xAxisView.get('pixelMax'), tRadius),
              tCoordY = dataToCoordinate(tWorldCoords.y,
                  iRC.yAxisView.get('pixelMin'), iRC.yAxisView.get('pixelMax'), tRadius),
              tIsMissingCase = SC.none(tCoordX) || SC.none(tCoordY);

          // show or hide if needed, then update if shown.
          if (this.showHidePlottedElement(tCircle, tIsMissingCase, iIndex)) {
            var tAttrs = {
              cx: tCoordX,
              cy: tCoordY,
              r: tRadius,
              fill: iRC.calcCaseColorString(iCase),
              stroke: iRC.calcStrokeColorString(iCase),
              'fill-opacity': iRC.transparency,
              'stroke-opacity': iRC.strokeTransparency
            };
            this.updatePlottedElement(tCircle, tAttrs, iAnimate, iCallback);
            return {cx: tCoordX, cy: tCoordY, r: tRadius};
          }
          return null;
        },

        createElement: function (iDatum, iIndex, iAnimate) {

          var tPaper = this.get('paper'),
              tCircle = tPaper.circle(tPaper.width / 2, tPaper.height / 2, this._pointRadius)
                  .attr({cursor: "pointer"})
                  .addClass(DG.PlotUtilities.kDotClassName);
          tCircle.index = iIndex;
          tCircle.node.setAttribute('shape-rendering', 'geometricPrecision');
          addHandlers(this, tCircle);
          return tCircle;
        },

        /**
         We may clear and draw everything from scratch if required.
         */
        drawData: function () {
          var this_ = this;
          if (!this.get('paper') || !this.get('model') || !this.getPath('model.cases') || this.getPath('model.isAnimating'))
            return;

          if (this.handlersMustBeInstalledToExistingElements) {
            this.get('plottedElements').forEach(function (iElement) {
              addHandlers(this_, iElement);
            });
            this.handlersMustBeInstalledToExistingElements = false;
          }

          if (this.getPath('model.isAnimating'))
            return; // Points are animating to new position

          function createCircleDescription(iIndex) {
            var tWorldCoords = tModel.getWorldCoords(iIndex);
            return {
              type: 'circle',
              cx: dataToCoordinate(tWorldCoords.x, tXPixelMin, tXPixelMax, kMargin),
              cy: dataToCoordinate(tWorldCoords.y, tYPixelMin, tYPixelMax, kMargin),
              r: tR / 2,
              fill: 'yellow',
              stroke: tStrokeParams.strokeColor,
              'stroke-opacity': tStrokeParams.strokeTransparency,
              cursor: 'pointer'
            };
          }

          function doCreatePlotElements() {
            var tInc = 200,
                i,
                loop = function () {
                  if (tPlottedElements.length >= tNumCases)
                    return;
                  var tStart = tPlottedElements.length,
                      tDescriptions = [];
                  tXPixelMax = this_.getPath('xAxisView.pixelMax');
                  tYPixelMax = this_.getPath('yAxisView.pixelMin');
                  if (tXPixelMax < 30 || tYPixelMax < 30) {
                    this_.invokeLater(loop, 100);
                    return;
                  }
                  for (i = tStart; i < tStart + tInc && i < tNumCases; i++) {
                    tDescriptions.push(createCircleDescription(i));
                  }
                  tPointSet = this_.get('paper').add(tDescriptions).forEach(function (iElement, iIndex) {
                    tPlottedElements.push(iElement);
                    tLayer.push(iElement);
                    iElement.addClass(DG.PlotUtilities.kDotClassName);
                    iElement.index = tStart + iIndex;
                    iElement.node.setAttribute('shape-rendering', 'geometricPrecision');
                    return true;
                  });
                  addHandlers(this_, tPointSet);
                  this_.setPath('model.isAnimating', true);
                  tPointSet.animate({
                        r: tR,
                        fill: tColor
                      },
                      DG.PlotUtilities.kDefaultAnimationTime, '<>');
                  tStart += tInc;
                  tInc *= 2;
                  if (tStart < tNumCases) {
                    this_.invokeLater(loop, 10);
                  } else {
                    this_.setPath('model.isAnimating', false);
                    this_.updateSelection();
                  }
                  tPointSet.clear();
                }.bind(this_);
            loop();
            this_._elementOrderIsValid = false;
          }

          var tRC = this.createRenderContext(),
              tXPixelMin = this.getPath('xAxisView.pixelMin'),
              tXPixelMax = this.getPath('xAxisView.pixelMax'),
              tYPixelMax = this.getPath('yAxisView.pixelMin'),
              tYPixelMin = this.getPath('yAxisView.pixelMax'),

              tPointSet,
              tPlottedElements = this.get('plottedElements'),
              tModel = this.get('model'),
              tNumCases = tModel.get('cases').length(),
              tR = this.calcPointRadius(),
              kMargin = tR,
              tColor = tModel.getPointColor ? tModel.getPointColor() : DG.PlotUtilities.kDefaultPointColor,
              tStrokeParams = this.getStrokeParams(),
              tLayer = this.getPath('layerManager.' + DG.LayerNames.kPoints);
          if (!tPlottedElements || tPlottedElements.length < tNumCases) {
            doCreatePlotElements();
          } else if (tPlottedElements.length > 0 && !this.getPath('model.isAnimating')) {
            if (tPlottedElements.length > tNumCases) {
              var tLayerManager = this.get('layerManager');
              for (var index = tNumCases; index < tPlottedElements.length; index++) {
                if (!SC.none(tPlottedElements[index])) {
                  tPlottedElements[index].stop();
                  tLayerManager.removeElement(tPlottedElements[index]);
                  DG.PlotUtilities.doHideRemoveAnimation(tPlottedElements[index], tLayerManager);
                }
              }
              tPlottedElements.length = tNumCases;
            }
            tPlottedElements.forEach(function (iCircle, iIndex) {
              var tCoords = tModel.getWorldCoords(iIndex);
              iCircle.attr({
                fill: tColor,
                'fill-opacity': tRC.transparency,
                'opacity': tRC.transparency,
                r: tR
              });
              iCircle.show();
              iCircle.animate({
                cx: dataToCoordinate(tCoords.x, tXPixelMin, tXPixelMax, kMargin),
                cy: dataToCoordinate(tCoords.y, tYPixelMin, tYPixelMax, kMargin)
              }, DG.PlotUtilities.kDefaultAnimationTime, '<>');
            });
          }
        },

        /**
         Generate the svg needed to display the plot
         */
        doDraw: function doDraw() {
          arguments.callee.base.apply(this,arguments);

          this.drawData();

          this.updateSelection();

        },

        /**
         * The array object my model uses to store world coords has been swapped out. We want to animate to new positions.
         */
        worldValuesChanged: function () {
          var tPlottedElements = this.get('plottedElements'),
              tLastIndex = tPlottedElements.length - 1,
              kMargin = this.calcPointRadius(),
              tXPixelMin = this.getPath('xAxisView.pixelMin'),
              tXPixelMax = this.getPath('xAxisView.pixelMax'),
              tYPixelMax = this.getPath('yAxisView.pixelMin'),
              tYPixelMin = this.getPath('yAxisView.pixelMax'),
              tModel = this.get('model');
          tModel.set('isAnimating', true);
          tPlottedElements.forEach(function (iElement, iIndex) {
                var tCoords = tModel.getWorldCoords(iIndex);
                iElement.animate({
                      cx: dataToCoordinate(tCoords.x, tXPixelMin, tXPixelMax, kMargin),
                      cy: dataToCoordinate(tCoords.y, tYPixelMin, tYPixelMax, kMargin)
                    },
                    DG.PlotUtilities.kDefaultAnimationTime, '<>',
                    iIndex === tLastIndex ? function () {
                      tModel.set('isAnimating', false);
                    } : null);
              }
          );
          this._isRenderingValid = false;

          // this.displayDidChange();
        }.observes('.model.worldValues')
      };
    }()));

/* >>>>>>>>>> BEGIN source/components/graph/plots/computed_bar_chart_model.js */
// ==========================================================================
//                          DG.ComputedBarChartModel
//
//  Author:   Kirk Swenson
//
//  Copyright (c) 2020 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/plots/bar_chart_base_model');

/** @class  DG.ComputedBarChartModel - The model for a bar chart with computed height of bars

 @extends DG.BarChartBaseModel
 */
DG.ComputedBarChartModel = DG.BarChartBaseModel.extend(
  /** @scope DG.ComputedBarChartView.prototype */
  {
    isBarHeightComputed: true,

    expression: '',

    formula: null,

    formulaContext: null,

    _editInProgress: false,
    _receivedInitialExpression: false,

    init: function() {
      arguments.callee.base.apply(this,arguments);
    },

    destroy: function() {
      this.destroyFormula();
      DG.BarChartFormulaEditContext.destroyFormulaEditContext( DG.Debug.scObjectID(this));
      arguments.callee.base.apply(this,arguments);
    },

    /**
     * We don't allow undo of the initial creation of the formula
     * @param iIsUndoable {boolean}
     */
    editFormula: function(iIsUndoable) {
      iIsUndoable = SC.none( iIsUndoable) ? true : iIsUndoable;
      DG.ComputedBarChartView.createFormulaEditView(this, iIsUndoable);
      this._editInProgress = true;
    },

    createFormula: function() {
      var id = DG.Debug.scObjectID(this),
          type = 'computedBarChart',
          owner = { type: type, id: id, name: type + id },
          attrID = this.get('primaryVarID'),
          attr = attrID && DG.Attribute.getAttributeByID(attrID),
          collection = attr && attr.get('collection');
      this.formulaContext = DG.BarChartFormulaContext.create({
        ownerSpec: owner,
        plotModel: this,
        collection: collection
      });

      this.set('formula', DG.Formula.create({ context: this.formulaContext, source: this.get('expression') }));
      // this.setPath( 'formula.id', id);
    },

    expressionDidChange: function() {
      this.destroyFormula();
      this.createFormula();
      this._editInProgress = false;
      this._receivedInitialExpression = true;
    }.observes('expression'),

    destroyFormula: function() {
      if( this.formula)
        this.formula.destroy();
    },

    /**
     *
     * @param iPlace {DG.GraphTypes.EPlace}
     * @return { class }
     */
    getDesiredAxisClassFor: function( iPlace) {
      if(iPlace === this.get('secondaryAxisPlace'))
        return DG.FormulaAxisModel;
      return arguments.callee.base.apply(this,arguments);
    },

    /**
      @return{ {min:{Number}, max:{Number} isDataInteger:{Boolean}} }
      */
    getDataMinAndMaxForDimension: function (iPlace) {
      var tMin = Infinity,
          tMax = -Infinity,
          tPrimaryVarID = this.get('primaryVarID');
      this.get('validCachedCells').forEach(function (iPrimary) {
        var tPrimaryName = iPrimary[0][0].theCase.getValue(tPrimaryVarID),
            tCellValue = this.getBarHeight( tPrimaryName);
        tMin = Math.min( tMin, tCellValue);
        tMax = Math.max( tMax, tCellValue);
      }.bind( this));
      if( tMin < 0 && tMax < 0)
        tMax = 0;
      else if(tMin > 0 && tMax > 0)
        tMin = 0;
      return {
        min: tMin,
        max: tMax,
        isDataInteger: false
      };
    },

    /**
     *
     * @param iPrimaryName
     * @return {number} in world coordinates
     */
    getBarHeight: function(iPrimaryName) {
      // TODO: create/update formula when attribute configuration or expression changes
      if( SC.empty( this.get('expression')) && !this._receivedInitialExpression) {
        this.invokeLater( function() {
          if( !this._editInProgress) {
            this.editFormula(false /* not undoable */);
          }
        }.bind( this), 100);
        return 0;
      }
      if (!this.get('formula')) this.createFormula();
      var formula = this.get('formula'),
          evalContext = iPrimaryName ? { _groupID_: iPrimaryName } : {},
          result = NaN;

      try {
        if (formula)
          result = Number(formula.evaluate(evalContext));
      }
      catch(e) {
        // Propagate errors to return value
        result = e;
      }

      return (typeof result === 'number') ? result : 0;
    },

    /**
     * @return {Object} the saved data.
     */
    createStorage: function () {
      var tStorage = arguments.callee.base.apply(this,arguments);

      tStorage.expression = this.expression;

      return tStorage;
    },

    /**
     * @param iStorage
     */
    restoreStorage: function (iStorage) {
      arguments.callee.base.apply(this,arguments);
      if (!SC.none(iStorage.expression)) {
        this.set( 'expression', iStorage.expression);
      }
    }


  }
);

/* >>>>>>>>>> BEGIN source/components/graph/plots/computed_bar_chart_view.js */
// ==========================================================================
//                          DG.ComputedBarChartView
//
//  Author:   Kirk Swenson
//
//  Copyright (c) 2020 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/plots/bar_chart_base_view');

/** @class  DG.BarChartView, a plot of rectangles, one for each category. Each rectangle is made of
 * thinner rectangles, one for each case.

 @extends DG.ComputedBarChartView
 */
DG.ComputedBarChartView = DG.BarChartBaseView.extend(
  /** @scope DG.ComputedBarChartView.prototype */
  {
    /**
     * Return the class of the count axis with the x or y to put it on.
     * @return {[{}]}
     */
    getAxisViewDescriptions: function () {
      var tDescriptions = arguments.callee.base.apply(this,arguments),
          tNumericKey = this.getPath('model.orientation') === DG.GraphTypes.EOrientation.kVertical ? 'y' : 'x';
      tDescriptions.push( {
        axisKey: tNumericKey,
        axisClass: DG.FormulaAxisView
      });
      return tDescriptions;
    },

    /**
     * We have to set things up for animation
     */
    formulaDidChange: function() {
      var tModel = this.get('model');
      // Store the current element coordinates for use in animation
      this.set('transferredElementCoordinates', this.getElementPositionsInParentFrame());
      var tSecondaryAxisModel = tModel.get('secondaryAxisModel'),
          tStashedBounds = {
            lower: tSecondaryAxisModel.get('lowerBound'),
            upper: tSecondaryAxisModel.get('upperBound')
          };
      // Set axis to final position so final positions of rectangles can be computed
      tModel.doRescaleAxesFromData([tModel.get('secondaryAxisPlace')], true, false, false);
      this.animateFromTransferredElements();
      // Put axis back where it was so it can animate
      tSecondaryAxisModel.setDataMinAndMax(tStashedBounds.lower, tStashedBounds.upper, true);
      // Cause plot view to animate
      this.notifyPropertyChange('plotDisplayDidChange');
      // Simultaneously cause axis to animate
      tModel.doRescaleAxesFromData([tModel.get('secondaryAxisPlace')], true, true, false);
    }.observes('model.formula'),

    getBarHeight: function(iPrimaryName, iCount, iTotal) {
      var model = this.get('model'),
          barHeight = model && model.getBarHeight(iPrimaryName);
      return model && barHeight * iCount / iTotal;
    },

    /**
     * The primaryAxisView needs to be told that its tick marks and labels are to be centered in each cell.
     */
    setupAxes: function () {
      var tAxisModel = this.getPath('secondaryAxisView.model');
      tAxisModel.set('drawZeroLine', true);
      tAxisModel.set('expressionSource', this.get('model'));
    },

    drawData: function drawData() {
      var model = this.get('model');
      model._buildCache();
      arguments.callee.base.apply(this,arguments);
    },

    /**
     *
     * @param iRC {*}
     * @param iCase {DG.Case}
     * @param iIndex {Integer}
     * @param iCellIndices {{primaryCell, secondaryCell, indexInCell}}
     * @param iAnimate {Boolean}
     * @param iCallback {Function}
     */
    privSetElementCoords: function (iRC, iCase, iIndex, iCellIndices, iAnimate, iCallback) {
      DG.assert(iRC && iRC.xAxisView);
      DG.assert(iCase);
      DG.assert(DG.MathUtilities.isInIntegerRange(iIndex, 0, this.get('plottedElements').length));
      var tRect = this.get('plottedElements')[iIndex];

      // It can happen that we don't have cell indices yet. Bail for now cause we'll be back later.
      if( !iCellIndices)
        return;

      var tCellHalfWidth = iRC.barWidth,
          // tFullBarWorldHeight = this.get('model').
          tBarSliceHeight = iRC.barSliceHeights[iCellIndices.primaryCell],
          tIndexInCell = iCellIndices.indexInCell,
          tEdge = iRC.primaryAxisView.cellToCoordinate(iCellIndices.primaryCell) -
              tCellHalfWidth / 2,
          tTop, tCoordX, tCoordY, tWidth, tHeight;

      if (iRC.isVerticalOrientation) {
        tTop = tBarSliceHeight < 0 ? iRC.zeroOnSecondaryAxis - tIndexInCell * tBarSliceHeight :
            iRC.zeroOnSecondaryAxis - (tIndexInCell + 1) * tBarSliceHeight;
        tCoordX = tEdge;
        tCoordY = tTop;
        tWidth = tCellHalfWidth;
        tHeight = Math.abs(tBarSliceHeight);
      }
      else {
        if( tBarSliceHeight < 0) {
          tTop = iRC.zeroOnSecondaryAxis + (tIndexInCell + 1) * tBarSliceHeight;
          tCoordX = tTop;
        }
        else {
          tTop = iRC.zeroOnSecondaryAxis + (tIndexInCell + 1) * tBarSliceHeight;
          tCoordX = tTop - tBarSliceHeight;
        }
        tCoordY = tEdge;
        tWidth = Math.abs(tBarSliceHeight);
        tHeight = tCellHalfWidth;
      }
      var tNewAttrs = {
        x: tCoordX, y: tCoordY, r: 0.1, width: tWidth, height: tHeight,
        fill: iRC.calcCaseColorString(iCase),
        'fill-opacity': iRC.transparency,
        'stroke-opacity': 0
      };
      if (iAnimate) {
        tRect.animate(tNewAttrs, DG.PlotUtilities.kDefaultAnimationTime, '<>', iCallback);
      }
      else {
        tRect.attr(tNewAttrs);
      }
      return tRect;
    },

    /**
     * We compute the height of each slice, corresponding to each case in a cell. These differ from cell to
     * cell since the total height of a bar depends on evaluation of the formula for that cell.
     * Slice heights are in display coordinates. Negative heights indicate a bar that descends downward
     * from zero.
     */
    computeCellParams: function () {
      var tPrimaryVarID = this.getPath('model.primaryVarID'),
          tSecondaryAxisView = this.get('secondaryAxisView'),
          tSecondaryIsHorizontal = tSecondaryAxisView.get('orientation') === 'horizontal',
          tZeroCoord = tSecondaryAxisView.dataToCoordinate(0),
          tSliceHeights = [],
          tModel = this.get('model');
      tModel.get('validCachedCells').forEach( function( iPrimary, iPrimaryIndex) {
        var tPrimaryName = iPrimary[0][0].theCase.getValue(tPrimaryVarID),
            tCellValue = tModel.getBarHeight( tPrimaryName),
            tNumInCell = iPrimary.reduce(function( iAccCount, iSecondary) {
              return iAccCount + iSecondary.length;
            }, 0),
            tSliceHeight =  (tZeroCoord - tSecondaryAxisView.dataToCoordinate( tCellValue)) / tNumInCell;
        if(tSecondaryIsHorizontal)
          tSliceHeight = -tSliceHeight;
        tSliceHeights.push( tSliceHeight);
      });
      this.setIfChanged('barSliceHeights', tSliceHeights);
    },

    /**
     * Base class returns empty string. Subclasses override to compute an informative string.
     * @param iPrimaryName {String}
     * @param iCategoryName {String}
     * @param iTotalNumCases {Number}
     * @param iElement  {Element} Has cell specific properties we need: caseIndices and numCasesInContainingCell
     * @return {String} "<primary> has value of <number>"
     */
    getToolTipText: function(iPrimaryName, iCategoryName, iTotalNumCases, iElement) {
      var tPrecision = DG.PlotUtilities.findFractionDigitsForAxis( this.get('secondaryAxisView')),
          tNumFormat = DG.Format.number().fractionDigits( 0, tPrecision).group('');
      return "DG.ComputedBarChartModel.cellTip".loc( iPrimaryName,
          tNumFormat(this.get('model').getBarHeight(iPrimaryName)));
    }

  }
);

DG.ComputedBarChartView.createFormulaEditView = function(iPlotModel, iIsUndoable) {
  var tFormulaEditContext = DG.BarChartFormulaEditContext.getFormulaEditContext(iPlotModel);
  tFormulaEditContext.set('clientOptions', {
    isUndoable: iIsUndoable,
    attrNamePrompt: 'DG.BarChartFunction.namePrompt',
    formulaPrompt: 'DG.BarChartFunction.formulaPrompt',
    formulaHint: 'DG.BarChartFunction.formulaHint',
    commandName: 'graph.editBarChartFunction',
    undoString: 'DG.Undo.graph.changeBarChartFunction',
    redoString: 'DG.Redo.graph.changeBarChartFunction',
    logMessage: 'Change bar chart function: "%@1" to "%@2"'
  });
  tFormulaEditContext.openFormulaEditorDialog();
};


/* >>>>>>>>>> BEGIN source/components/graph/plots/dot_chart_model.js */
// ==========================================================================
//                          DG.DotChartModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/plots/chart_model');

/** @class  DG.DotChartModel - The model for a plot with categorical axes

 @extends DG.ChartModel
 */
DG.DotChartModel = DG.ChartModel.extend(
    /** @scope DG.DotChartModel.prototype */
    {
      /**
       * Override
       * @property {Boolean}
       */
      displayAsBarChart: false,

      /**
       *
       * @param iPlace {DG.GraphTypes.EPlace}
       * @return { class }
       */
      getDesiredAxisClassFor: function( iPlace) {
        if( iPlace === this.get('primaryAxisPlace'))
          return DG.CellAxisModel;
        else if(iPlace === this.get('secondaryAxisPlace')) {
          return SC.none( this.get('secondaryVarID')) ? DG.AxisModel : DG.CellAxisModel;
        }
        else return arguments.callee.base.apply(this,arguments);
      },

      lastValueControls: function () {

        var tControls = arguments.callee.base.apply(this,arguments),
            this_ = this,
            kControlValues = {
              row: 'DG.Inspector.graphRow'.loc(),
              column: 'DG.Inspector.graphColumn'.loc(),
              cell: 'DG.Inspector.graphCell'.loc()
            },
            tNumOnX = this.getPath('xAxis.numberOfCells'),
            tNumOnY = this.getPath('yAxis.numberOfCells');

        function changePercentKind(iKind) {

          function doChangePercentKind(iPlot) {
            iPlot.setPath('plottedCount.percentKind', iKind);
          }

          doChangePercentKind(this_);
          this_.get('siblingPlots').forEach(doChangePercentKind);
        }

        function mapValueToPercentKind(iValue) {
          var tKind = -1;
          switch (iValue) {
            case kControlValues.row:
              tKind = DG.Analysis.EPercentKind.eRow;
              break;
            case kControlValues.column:
              tKind = DG.Analysis.EPercentKind.eColumn;
              break;
            case kControlValues.cell:
              tKind = DG.Analysis.EPercentKind.eCell;
          }
          return tKind;
        }

        function mapPercentKindToValue(iPercentKind) {
          var tValue = '';
          switch (iPercentKind) {
            case DG.Analysis.EPercentKind.eRow:
              tValue = kControlValues.row;
              break;
            case DG.Analysis.EPercentKind.eColumn:
              tValue = kControlValues.column;
              break;
            case DG.Analysis.EPercentKind.eCell:
              tValue = kControlValues.cell;
              break;
          }
          return tValue;
        }

        if (tNumOnX > 1 && tNumOnY > 1) {
          tControls.push(
              SC.RadioView.create({
                items: [kControlValues.row, kControlValues.column, kControlValues.cell],
                value: 'DG.Inspector.graphRow'.loc(),
                layoutDirection: SC.LAYOUT_VERTICAL,
                layout: {height: 65},
                classNames: 'dg-inspector-radio'.w(),
                valueDidChange: function () {
                  changePercentKind(mapValueToPercentKind(this.value));
                }.observes('value'),
                init: function () {
                  arguments.callee.base.apply(this,arguments);
                  this_.addObserver('plottedCount', this, this.addIsShowingPercentObserver);
                  this.addIsShowingPercentObserver();
                },
                addIsShowingPercentObserver: function () {
                  var tPlottedCount = this_.get('plottedCount'),
                      tPercentKind;
                  if (tPlottedCount) {
                    tPlottedCount.addObserver('isShowingPercent', this, this.isShowingPercentChanged);
                    tPercentKind = tPlottedCount.get('percentKind');
                    this.set('value', mapPercentKindToValue(tPercentKind));
                  }
                  this.isShowingPercentChanged();
                },
                isShowingPercentChanged: function () {
                  this.set('isEnabled', this_.getPath('plottedCount.isShowingPercent'));
                },
                destroy: function () {
                  var tPlottedCount = this_.get('plottedCount');
                  if (tPlottedCount)
                    tPlottedCount.removeObserver('isShowingPercent', this, this.isShowingPercentChanged);
                  this_.removeObserver('plottedCount', this, this.addIsShowingPercentObserver);
                }
              })
          );
        }
        return tControls;
      }.property('plot'),

    });


/* >>>>>>>>>> BEGIN source/components/graph/plots/dot_chart_view.js */
// ==========================================================================
//                          DG.DotChartView
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/plots/chart_view');

/** @class  DG.DotChartView, a plot of dots each placed according to categorical values

 @extends DG.ChartView
 */
DG.DotChartView = DG.ChartView.extend(
    /** @scope DG.DotChartView.prototype */
    {
      displayProperties: ['numPointsInRow', 'overlap'],

      /**
       @property{Number}
       */
      numPointsInRow: 1,

      /**
       @property{Number}
       */
      overlap: 0,

      /**
       Note: There's a lot of redundancy here with plotLayer::dataDidChange. But it's difficult to
       refactor further because of the need to deal with positioning points via
       privSetElementCoords.
       */
      updateElements: function () {
        // It's possible to get here before didCreateLayer() creates the get('paper').
        if (!this.get('paper'))
          return;
        arguments.callee.base.apply(this,arguments);
        var this_ = this,
            tModel = this.get('model'),
            tCases = this.getPath('model.cases'),
            tRC = this.createRenderContext(),
            tDataLength = tCases && tCases.get('length'),
            tPlottedElements = this.get('plottedElements'),
            tPlotElementLength = tPlottedElements.length,
            tCandidateRadius = this.calcPointRadius(),
            tWantNewPointRadius = (this._pointRadius !== tCandidateRadius),
            tLayerManager = this.get('layerManager'),
            tIndex, tCellIndices;
        // update the point radius before creating or updating plotted elements
        if (tWantNewPointRadius)
          this._pointRadius = tCandidateRadius;

        // for any new cases
        if (tDataLength > tPlotElementLength) {
          if (tWantNewPointRadius) {
            // update the point radius for existing plotted elements
            for (tIndex = 0; tIndex < tPlotElementLength; tIndex++) {
              tCellIndices = tModel.lookupCellForCaseIndex(tIndex);
              // tCellIndices may come out null if the case has empty values
              // Note that we don't animate here because things can happen during the
              // animation that change the destination.
              this.privSetElementCoords(tRC, tCases.at(tIndex), tIndex, tCellIndices);
            }
          }
          // add plot elements for added cases
          for (tIndex = tPlotElementLength; tIndex < tDataLength; tIndex++) {
            this.callCreateElement(tCases.at(tIndex), tIndex, this.animationIsAllowable());
            tCellIndices = tModel.lookupCellForCaseIndex(tIndex);
            this.privSetElementCoords(tRC, tCases.at(tIndex), tIndex, tCellIndices);
          }
        }
        // Get rid of plot elements for removed cases and update all coordinates
        if (tDataLength < tPlotElementLength) {
          for (tIndex = tDataLength; tIndex < tPlotElementLength; tIndex++) {
            // It can happen during closing of a document that the elements no longer exist, so we have to test
            if (!SC.none(tPlottedElements[tIndex])) {
              tPlottedElements[tIndex].stop();
              DG.PlotUtilities.doHideRemoveAnimation(tPlottedElements[tIndex], tLayerManager);
            }
          }
          // update all coordinates because we don't know which cases were deleted
          tCases.forEach(function (iCase, iIndex) {
            tCellIndices = tModel.lookupCellForCaseIndex(iIndex);
            this_.privSetElementCoords(tRC, iCase, iIndex, tCellIndices);
          });
        }
        this._isRenderingValid = false;
      },

      dataRangeDidChange: function (iSource, iQuestion, iKey, iChanges) {
        var this_ = this,
            tCases = this.getPath('model.cases'),
            tPlottedElements = this.get('plottedElements'),
            tRC = this.createRenderContext(),
            tChanges = (SC.typeOf(iChanges) === SC.T_NUMBER ? [iChanges] : iChanges);
        tChanges = tChanges || [];

        this.model.invalidateCaches();
        this.computeCellParams();

        tChanges.forEach(function (iIndex) {
          // We can get in here after a delete, in which case, iChanges can be referring to
          // a plot element that no longer exists.
          //DG.assert( this.get('plottedElements')[ iIndex], "dataRangeDidChange: missing plotted element!");
          if (!tPlottedElements[iIndex])
            this_.callCreateElement(tCases.at(iIndex), iIndex, this_._createAnimationOn);
          var tCellIndices = this_.get('model').lookupCellForCaseIndex(iIndex);
          this_.privSetElementCoords(tRC, tCases.at(iIndex), iIndex, tCellIndices);
        });
        arguments.callee.base.apply(this,arguments);
      },

      /**
       * Set the coordinates and other attributes of the case circle (a Rafael element in this.get('plottedElements')).
       * @param iRC {} case-invariant Render Context
       * @param iCase {DG.Case} the case data
       * @param iIndex {number} index of case in collection
       * @param iAnimate {Boolean} (optional) want changes to be animated into place?
       * @returns {cx {Number},cy {Number}} final coordinates or null if not defined (hidden plot element)
       */
      setCircleCoordinate: function setCircleCoordinate(iRC, iCase, iIndex, iAnimate, iCallback) {
        var tCellIndices = this.get('model').lookupCellForCaseIndex(iIndex);
        this.privSetElementCoords(iRC, iCase, iIndex, tCellIndices, iAnimate, iCallback);
      },

      privGetElementCoordAttrs: function (iElement, iRC, iCase, iIndex, iCellIndices) {
        var tCellHalfWidth = iRC.cellHalfWidth,
            tNumInRow = this.get('numPointsInRow'),
            tOverlap = this.get('overlap'),
            tRow = Math.floor(iCellIndices.indexInCell / tNumInRow),
            tCol = iCellIndices.indexInCell - tRow * tNumInRow,
            tRadius = this._pointRadius,
            tPointSize = 2 * tRadius,
            tPrimaryCoord = iRC.primaryAxisView.cellToCoordinate(iCellIndices.primaryCell) -
                (tNumInRow - 1) * tPointSize / 2 + tCol * tPointSize,
            tSecondaryCoord = iRC.secondaryAxisView.cellToCoordinate(iCellIndices.secondaryCell),
            tOffset = ((tRow + 0.5) * (tPointSize - tOverlap) + 1 + tOverlap / 2),
            tCoordX, tCoordY;

        DG.assert(DG.isFinite(tPrimaryCoord) && DG.isFinite(tSecondaryCoord), 'tPrimaryCoord & tSecondaryCoord');

        if (iRC.isVerticalOrientation) {
          tCoordX = tPrimaryCoord;
          tCoordY = tSecondaryCoord + tCellHalfWidth - tOffset;
        }
        else {
          tCoordX = tSecondaryCoord - tCellHalfWidth + tOffset;
          tCoordY = tPrimaryCoord;
        }
        DG.assert(isFinite(tCoordX) && isFinite(tCoordY));

        var tAttrs = {
          cx: tCoordX, cy: tCoordY, r: this.radiusForCircleElement(iElement),
          fill: iRC.calcCaseColorString(iCase), stroke: iRC.calcStrokeColorString( iCase),
          'fill-opacity': iRC.transparency, 'stroke-opacity': iRC.strokeTransparency
        };

        return tAttrs;
      },

      /**
       We set the coordinates of the points.
       Note the tricky computation for secondary coordinate: the 0.5 is to left the center up half a point size.
       the "1" is to lift the center far enough that the circle border doesn't get cut off.
       */
      privSetElementCoords: function (iRC, iCase, iIndex, iCellIndices, iAnimate, iCallback) {

        DG.assert(iRC && iRC.xAxisView);
        DG.assert(iCase);
        DG.assert(DG.MathUtilities.isInIntegerRange(iIndex, 0, this.get('plottedElements').length));
        var tElement = this.get('plottedElements')[iIndex],
            tIsMissingCase = SC.none(iCellIndices);

        // show or hide if needed, then update if shown.
        if (this.showHidePlottedElement(tElement, tIsMissingCase, iIndex)) {
          var tAttrs = this.privGetElementCoordAttrs({_selected: false}, iRC, iCase, iIndex, iCellIndices);
          this.updatePlottedElement(tElement, tAttrs, iAnimate, iCallback);
        }
      },

      /**
       * Return the class of the count axis with the x or y to put it on.
       * @return {[{}]}
       */
      getAxisViewDescriptions: function () {
        var tDescriptions = arguments.callee.base.apply(this,arguments),
            tAxisKey = this.getPath('model.orientation') === DG.GraphTypes.EOrientation.kVertical ? 'y' : 'x';
        tDescriptions.push({
          axisKey: tAxisKey,
          axisClass: (this.getPath('model.dataConfiguration.' + tAxisKey + 'AttributeDescription.isNull')) ?
              DG.AxisView : DG.CellAxisView
        });
        return tDescriptions;
      },

      assignElementAttributes: function (iElement, iIndex, iAnimate) {
        arguments.callee.base.apply(this,arguments);

        var this_ = this,
            tInitialTransform = null,
            kOpaque = 1,
            tBackground = this.get('paperSource');

        function startMarquee(iWindowX, iWindowY, iEvent) {
          tBackground.prepareMarquee();
          var tStartPt = tBackground.startMarquee(iWindowX, iWindowY, iEvent, true /* don't deselect */),
              tPtRadius = this.attr('r');
          // Adjust start point so we're more likely to encompass the case represented by this element
          tStartPt.x -= tPtRadius;
          tStartPt.y -= tPtRadius;
        }

        iElement.hover(function (event) {
              // Note that Firefox can come through here repeatedly so we have to check for existence
              if (SC.none(tInitialTransform)) {
                tInitialTransform = '';
                this.animate({
                  opacity: kOpaque,
                  transform: DG.PlotUtilities.kDataHoverTransform
                }, DG.PlotUtilities.kDataTipShowTime);
                this_.showDataTip(this, iIndex);
              }
            },
            function (event) { // out
              this.stop();
              this.animate({
                opacity: DG.PlotUtilities.kDefaultPointOpacity,
                transform: tInitialTransform
              }, DG.PlotUtilities.kHighlightHideTime);
              tInitialTransform = null;
              this_.hideDataTip();
            })
            .drag(tBackground.continueMarquee, startMarquee, tBackground.endMarquee);

        return iElement;
      },

      /**
       * @param iCase
       * @param iIndex
       * @param iAnimate
       */
      createElement: function (iCase, iIndex, iAnimate) {
        // Can't create circles if we don't have paper for them
        if (!this.get('paper')) return;
        var tCircle = this.get('paper').circle(0, 0, this._pointRadius)
        // Note: we have to set cx and cy offscreen here rather than in creation because for some unknown
        // reason, when we do it in creation, they end up zero rather than offscreen.
            .attr({
              cursor: "pointer", cx: -1000, cy: -1000
            });
        tCircle.node.setAttribute('shape-rendering', 'geometricPrecision');
        return this.assignElementAttributes(tCircle, iIndex, iAnimate);
      },

      /**
       We override the base class implementation
       */
      animateFromTransferredElements: function () {
        var this_ = this,
            tModel = this.get('model'),
            tCases = tModel.get('cases'),
            tPaper = this.get('paper'),
            tRC = this.createRenderContext(),
            tDefaultR = this.calcPointRadius(),
            tFrame = this.get('frame'), // to convert from parent frame to this frame
            tOldElementAttrs = this.get('transferredElementCoordinates'),
            tNewElementAttrs = [], // used if many-to-one animation (parent to child collection)
            tNewToOldCaseMap = [],
            tOldToNewCaseMap = [];
        if (!tCases)
          return;

        function caseLocationSimple(iIndex) {
          // assume a 1 to 1 correspondence of the current case indices to the new cases
          return tOldElementAttrs[iIndex];
        }

        function caseLocationViaMap(iIndex) {
          // use our case index map to go from current case index to previous case index
          return tOldElementAttrs[tNewToOldCaseMap[iIndex]];
        }

        DG.sounds.playMixup();
        tModel.set('isAnimating', false);
        this._getTransferredElementsToCasesMap(tNewToOldCaseMap, tOldToNewCaseMap);
        var hasElementMap = tNewToOldCaseMap.length > 0,
            hasVanishingElements = tOldToNewCaseMap.length > 0,
            getCaseCurrentLocation = (hasElementMap ? caseLocationViaMap : caseLocationSimple),
            tElementsWereRects = tOldElementAttrs.length > 0 && tOldElementAttrs[0].type === 'rect',
            tRects = [],
            tTransAttrs;

        this.prepareToResetCoordinates();
        this.computeCellParams();
        tOldElementAttrs.forEach(function (iElement, iIndex) {
          // adjust old coordinates from parent frame to this view
          // In case they are circles
          iElement.cx -= tFrame.x;
          iElement.cy -= tFrame.y;
          // In case they are rects
          iElement.x -= tFrame.x;
          iElement.y -= tFrame.y;
        });
        if (tElementsWereRects) {
          this.removePlottedElements(true);
        }

        var eachCaseFunc = function (iCase, iIndex) {
              var tCurrAttrs = getCaseCurrentLocation(iIndex),
                  tCellIndices = tModel.lookupCellForCaseIndex(iIndex),
                  tNewElement;
              if (tElementsWereRects) {
                var tRectAttrs = tOldElementAttrs[iIndex];
                tNewElement = tPaper.rect(0, 0, 0, 0);
                tNewElement.attr( tRectAttrs);
                var tCircleAttrs = this.privGetElementCoordAttrs(tNewElement, tRC, iCase, iIndex, tCellIndices);
                tTransAttrs = {
                  x: tCircleAttrs.cx - tCircleAttrs.r,
                  y: tCircleAttrs.cy - tCircleAttrs.r,
                  width: 2 * tCircleAttrs.r,
                  height: 2 * tCircleAttrs.r,
                  r: tCircleAttrs.r,
                  fill: (tCurrAttrs && tCurrAttrs.fill) || DG.PlotUtilities.kDefaultPointColor,
                  stroke: (tCurrAttrs && tCurrAttrs.stroke) || DG.PlotUtilities.kDefaultStrokeColor
                };
                tNewElement.animate(tTransAttrs, DG.PlotUtilities.kDefaultAnimationTime);
                tRects.push(tNewElement);
              }
              else {
                tNewElement = this_.callCreateElement(iCase, iIndex);
                if (!SC.none(tCurrAttrs)) {
                  tTransAttrs = {
                    r: DG.isFinite(tCurrAttrs.r) && tCurrAttrs.r > 0 ? tCurrAttrs.r : tDefaultR,
                    cx: DG.isFinite(tCurrAttrs.cx) ? tCurrAttrs.cx : tCurrAttrs.x + tCurrAttrs.width / 2,
                    cy: DG.isFinite(tCurrAttrs.cy) ? tCurrAttrs.cy : tCurrAttrs.y + tCurrAttrs.height / 2,
                    fill: tCurrAttrs.fill,
                    stroke: tCurrAttrs.stroke
                  };
                  tNewElement.attr(tTransAttrs);
                }
                this_.privSetElementCoords(tRC, iCase, iIndex, tCellIndices, true /* animate */);
                if (hasVanishingElements) {
                  tNewElementAttrs.push(tCurrAttrs);
                }
              }
              return tModel.get('isAnimating');
            }.bind(this),

            finallyFunc = function () {
              if (hasVanishingElements) {
                // create a vanishing element for each old point that needs one (used if many-to-one animation)
                tOldElementAttrs.forEach(function (iOldAttrs, iIndex) {
                  var tNewIndex = tOldToNewCaseMap[iIndex],
                      tNewAttrs = tNewElementAttrs[tNewIndex];
                  if (SC.none(tNewIndex) || SC.none(tNewAttrs) || (iOldAttrs.r === 0))
                    return; // no vanishing element, if (1) element persists or (2) new circle hidden or (3) old circle hidden
                  this_.vanishPlottedElement(iOldAttrs, tNewAttrs);
                });
              }
              this.set('transferredElementCoordinates', null);
            }.bind(this);

        tModel.set('isAnimating', true);
        tCases.forEachWithInvokeLater(eachCaseFunc, finallyFunc);
        SC.Timer.schedule({
          action: function () {
            if (tElementsWereRects) {
              tRects.forEach(function (iRect) {
                iRect.remove();
              });
              tCases.forEach(function (iCase, iIndex) {
                var tElement = this_.callCreateElement(iCase, iIndex),
                    tCellIndices = tModel.lookupCellForCaseIndex(iIndex);
                tElement.attr(this_.privGetElementCoordAttrs(tElement, tRC, iCase, iIndex, tCellIndices));
              }.bind(this));
            }
            tModel.set('isAnimating', false);
            this_.displayDidChange(); // Force redisplay in correct position
          }, interval: DG.PlotUtilities.kDefaultAnimationTime
        });
      },

      /**
       We need to decide on the number of points in a row. To do so, we find the
       maximum number of points in a cell and choose so that this max number will
       fit within the length of a cell rect. If there are so many points that they don't fit
       even by using the full length of a cell rect, then we compute an overlap.
       */
      computeCellParams: function () {
        var tCellWidth = this.getPath('primaryAxisView.cellWidth'),
            tCellHeight = this.getPath('secondaryAxisView.fullCellWidth') - 5,
            tMaxInCell = this.getPath('model.maxInCell'),
            tPointSize = 2 * this._pointRadius,
            tAllowedPointsPerColumn = Math.max(1, Math.floor(tCellHeight / tPointSize)),
            tAllowedPointsPerRow = Math.max(1, Math.floor(tCellWidth / tPointSize)),
            tNumPointsInRow = Math.max(1,
                Math.min(tAllowedPointsPerRow,
                    Math.ceil(tMaxInCell / tAllowedPointsPerColumn))),
            tActualPointsPerColumn = Math.ceil(tMaxInCell / tNumPointsInRow),
            tOverlap = Math.max(0, ((tActualPointsPerColumn + 1) * tPointSize - tCellHeight) /
                tActualPointsPerColumn);
        tOverlap = Math.min(tOverlap, tPointSize); // Otherwise points can stack downward

        // Note: Bill points out that 1 is a better default here, but using 1 doesn't fix the bug
        // I'm working on. This may have to do with making sure a notification goes out when
        // 'numPointsInRow' later changes to 1 when the chart becomes valid.
        if (!isFinite(tNumPointsInRow))
          tNumPointsInRow = 0;
        if (!isFinite(tOverlap))
          tOverlap = 0;

        this.beginPropertyChanges();
        this.setIfChanged('numPointsInRow', tNumPointsInRow);
        this.setIfChanged('overlap', tOverlap);
        this.endPropertyChanges();
      }

    });


/* >>>>>>>>>> BEGIN source/components/graph/plots/dot_plot_model.js */
// ==========================================================================
//                            DG.DotPlotModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/plots/univariate_adornment_base_model');

/** @class  DG.DotPlotModel The model for a dot plot.

 @extends SC.PlotModel
 */
DG.DotPlotModel = DG.UnivariateAdornmentBaseModel.extend(
    /** @scope DG.DotPlotModel.prototype */
    {
      displayAsBinned: false,

      /**
       *
       * @param iPlace {DG.GraphTypes.EPlace}
       * @return { class }
       */
      getDesiredAxisClassFor: function( iPlace) {
        if( iPlace === this.get('primaryAxisPlace'))
          return DG.CellLinearAxisModel;
        else if(iPlace === this.get('secondaryAxisPlace')) {
          return SC.none( this.get('secondaryVarID')) ? DG.AxisModel : DG.CellAxisModel;
        }
        else return arguments.callee.base.apply(this,arguments);
      },

      /**
       Each axis should rescale based on the values to be plotted with it.
       * @param {boolean} iAllowScaleShrinkage
       * @param {boolean} iAnimatePoints
       * @param {boolean} iLogIt
       * @param {boolean} iUserAction
       */
      rescaleAxesFromData: function (iAllowScaleShrinkage, iAnimatePoints, iLogIt, iUserAction) {
        if (iAnimatePoints === undefined)
          iAnimatePoints = true;
        this.doRescaleAxesFromData([this.get('primaryAxisPlace')], iAllowScaleShrinkage, iAnimatePoints, iUserAction);
        if (iLogIt)
          DG.logUser("rescaleDotPlot");
      },

      /**
       @param{ {x: {Number}, y: {Number} } } iFixedPoint
       @param{Number} iFactor
       */
      dilate: function (iFixedPoint, iFactor) {
        this.doDilation([this.get('primaryAxisPlace')], iFixedPoint, iFactor);
      },

    });

/**
 class method called before plot creation to make sure roles are correct
 @param {DG.GraphDataConfiguration}
 */
DG.DotPlotModel.configureRoles = function (iConfig) {
  // Base class has method for this
  DG.UnivariatePlotModel.configureRoles( iConfig);
};

/* >>>>>>>>>> BEGIN source/components/graph/plots/univariate_adornment_base_view.js */
// ==========================================================================
//                          DG.UnivariateAdornmentBaseView
//
//  Author:   William Finzer
//
//  Copyright (c) 2023 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/plots/univariate_plot_view');

/** @class  DG.UnivariateAdornmentBaseView - Serves as a base for views that allow the full set of univariate
 * adornments.
 @extends DG.UnivariatePlotView
 */
DG.UnivariateAdornmentBaseView = DG.UnivariatePlotView.extend(
    /** @scope DG.UnivariateAdornmentBaseView.prototype */
    {
      autoDestroyProperties: ['multipleMovableValuesAdorn', 'plottedValueAdorn',
        'plottedMeanAdorn', 'plottedMedianAdorn', 'plottedStDevAdorn', 'plottedStErrAdorn', 'plottedNormalAdorn',
        'plottedMadAdorn', 'plottedBoxPlotAdorn', 'plottedNormalAdorn'],

      /** @property {DG.MultipleMovableValuesAdornment} */
      multipleMovableValuesAdorn: null,

      /** @property {DG.PlottedMeanAdornment} */
      plottedMeanAdorn: null,

      /** @property {DG.PlottedMedianAdornment} */
      plottedMedianAdorn: null,

      /** @property {DG.plottedStDevAdorn} */
      plottedStDevAdorn: null,

      /** @property {DG.plottedStErrAdorn} */
      plottedStErrAdorn: null,

      /** @property {DG.plottedMadAdorn} */
      plottedMadAdorn: null,

      /** @property {DG.plottedBoxPlotAdorn} */
      plottedBoxPlotAdorn: null,

      /** @property {DG.plottedNormalAdorn} */
      plottedNormalAdorn: null,

      primaryAxisViewDidChange: function () {
        arguments.callee.base.apply(this,arguments);
        var tMultMovableValuesAdorn = this.get('multipleMovableValuesAdorn');
        if (tMultMovableValuesAdorn)
          tMultMovableValuesAdorn.set('valueAxisView', this.get('primaryAxisView'));
      },

      /**
       * Update the plot when cases have been added or removed.
       */
      dataDidChange: function () {
        if (!this.getPath('model.dataConfiguration'))
          return; // happens during destroy of plot
        arguments.callee.base.apply(this,arguments); // base class handles almost everything
        if (SC.none(this.get('paper')))
          return;   // not ready to create elements yet
        this.updateAverages();
      },

      /**
       * Update the plot when case values have changed.
       */
      dataRangeDidChange: function (iSource, iQuestion, iKey, iChanges) {
        var tCases = this.getPath('model.cases');

        this.notifyPropertyChange('plotDisplayDidChange');

        this.updateAverages();
        this.rescaleOnParentCaseCompletion(tCases);
        arguments.callee.base.apply(this,arguments);
      },

      numberOfCellsDidChange: function () {
        ['plottedMeanAdorn', 'plottedMedianAdorn', 'plottedStDevAdorn', 'plottedStErrAdorn', 'plottedMadAdorn',
          'plottedBoxPlotAdorn', 'plottedNormalAdorn'].forEach(function (iKey) {
          if (this.getPath(iKey + '.model')) {
            this.getPath(iKey + '.model').setComputingNeeded();
          }
        }.bind(this));
      }.observes('*secondaryAxisView.model.numberOfCells'),

      /**
       Called when the order of the categories on an axis changes (e.g. cells are dragged)
       */
      categoriesDidChange: function () {
        this.updateAverages();
      }.observes('model.colorMap'),

      initializeAdornments: function () {
        arguments.callee.base.apply(this,arguments);
        this.setOffsetsForAverages();
      },

      setOffsetsForAverages: function () {
        var tOffset = 0;
        ['plottedMeanAdorn', 'plottedMedianAdorn', 'plottedStDevAdorn', 'plottedStErrAdorn',
          'plottedNormalAdorn', 'plottedMadAdorn'].forEach(
            function (iKey) {
              if (this.getPath(iKey + '.model.isVisible')) {
                if (this.getPath(iKey + '.offset') !== tOffset)
                  this.setPath(iKey + '.offset', tOffset);
                tOffset++;
              }
            }.bind(this)
        );
      },

      /**
       * Invalidate and update the averages adornments.
       * To be called when cases or plot configuration
       * changes, that the averages depend upon.
       * @param iAnimate {Boolean}[optional] animate change to averages.
       */
      updateAverages: function (iAnimate) {
        function updateOneAdorn(ioAdorn) {
          if (ioAdorn) {
            var adornModel = ioAdorn.get('model');
            if (adornModel) {
              adornModel.setComputingNeeded();
              ioAdorn.updateToModel(iAnimate);
            }
          }
        }

        if (!this.getPath('model.dataConfiguration'))
          return; // because we can get here during destroy

        updateOneAdorn(this.plottedMeanAdorn);
        updateOneAdorn(this.plottedMedianAdorn);
        updateOneAdorn(this.plottedStDevAdorn);
        updateOneAdorn(this.plottedStErrAdorn);
        updateOneAdorn(this.plottedMadAdorn);
        updateOneAdorn(this.plottedBoxPlotAdorn);
        updateOneAdorn(this.plottedNormalAdorn);
        updateOneAdorn(this.multipleMovableValuesAdorn);

        if (this.plottedValueAdorn) {
          this.plottedValueAdorn.updateToModel();
        }

        this.setOffsetsForAverages();
      },

      /**
       Generate the svg needed to display the plot
       */
      doDraw: function doDraw() {

        function updateAverageAdorn(a) {
          if (!SC.none(a) && a.wantVisible()) {
            a.get('model').setComputingNeeded();
            a.updateToModel();
          }
        }

        arguments.callee.base.apply(this,arguments);

        this.drawData();

        this.updateSelection();

        ['plottedMeanAdorn', 'plottedMedianAdorn', 'plottedStDevAdorn', 'plottedStErrAdorn', 'plottedMadAdorn',
          'plottedBoxPlotAdorn', 'plottedNormalAdorn'].forEach(
            function (iKey) {
              updateAverageAdorn(this[iKey]);
            }.bind(this)
        );

        if (!SC.none(this.plottedValueAdorn))
          this.plottedValueAdorn.updateToModel();
        if (!SC.none(this.multipleMovableValuesAdorn))
          this.multipleMovableValuesAdorn.updateToModel();
      },

      /**
       Presumably our model has created a movable value. We need to create our adornment.
       */
      movableValueChanged: function () {
        var tPlotModel = this.get('model'),
            tMultipleMovableValues = tPlotModel && tPlotModel.getAdornmentModel('multipleMovableValues'),
            tMultipleMovableValuesAdorn = this.get('multipleMovableValuesAdorn');
        if (tMultipleMovableValues) {
          if (tMultipleMovableValuesAdorn) {
            tMultipleMovableValuesAdorn.set('parentView', this);
            tMultipleMovableValuesAdorn.set('model', tMultipleMovableValues);
            tMultipleMovableValuesAdorn.set('paperSource', this.get('paperSource'));
          } else {
            tMultipleMovableValuesAdorn = DG.MultipleMovableValuesAdornment.create({
              parentView: this, model: tMultipleMovableValues,
              paperSource: this.get('paperSource'),
              layerName: DG.LayerNames.kAdornments,
              valueAxisView: this.get('primaryAxisView')
            });
            this.set('multipleMovableValuesAdorn', tMultipleMovableValuesAdorn);
          }
          tMultipleMovableValuesAdorn.updateToModel();
        }
      }.observes('*model.valuesDidChange', '*model.multipleMovableValues'),

      /**
       Presumably our model has created a plotted mean. We need to create our adornment.
       */
      plottedMeanChanged: function () {
        this.adornmentDidChange('plottedMean', 'plottedMeanAdorn', DG.PlottedMeanAdornment);
      }.observes('*model.plottedMean'),

      /**
       Presumably our model has created a plotted mean. We need to create our adornment.
       */
      plottedMedianChanged: function () {
        this.adornmentDidChange('plottedMedian', 'plottedMedianAdorn', DG.PlottedMedianAdornment);
      }.observes('*model.plottedMedian'),

      /**
       Presumably our model has created a plotted St.Dev. We need to create our adornment.
       */
      plottedStDevChanged: function () {
        this.adornmentDidChange('plottedStDev', 'plottedStDevAdorn', DG.PlottedStDevAdornment);
      }.observes('*model.plottedStDev'),

      /**
       Presumably our model has created a plotted StErr. We need to create our adornment.
       */
      plottedStErrChanged: function () {
        this.adornmentDidChange('plottedStErr', 'plottedStErrAdorn', DG.PlottedStErrAdornment);
      }.observes('*model.plottedStErr'),

      /**
       Presumably our model has created a plotted MAD. We need to create our adornment.
       */
      plottedMadChanged: function () {
        this.adornmentDidChange('plottedMad', 'plottedMadAdorn', DG.PlottedMeanAbsDevAdornment);
      }.observes('*model.plottedMad'),

      /**
       Presumably our model has created a box plot. We need to create our adornment.
       */
      plottedBoxPlotChanged: function () {
        this.adornmentDidChange('plottedBoxPlot', 'plottedBoxPlotAdorn', DG.PlottedBoxPlotAdornment);
      }.observes('*model.plottedBoxPlot'),

      /**
       Presumably our model has created a plotted IQR. We need to create our adornment.
       */
      plottedNormalChanged: function () {
        this.adornmentDidChange('plottedNormal', 'plottedNormalAdorn', DG.PlottedNormalAdornment);
      }.observes('*model.plottedNormal'),

      /**
       Update an adornment after a change to its corresponding adornment model.
       @param    {String}    iAdornmentKey -- e.g. 'plottedMean' or 'plottedMedian'
       @param    {String}    iAdornmentProperty -- e.g. 'plottedMeanAdorn' or 'plottedMedianAdorn'
       @param    {Object}    iAdornmentClass -- e.g. DG.PlottedMeanAdornment or DG.PlottedMedianAdornment
       */
      adornmentDidChange: function (iAdornmentKey, iAdornmentProperty, iAdornmentClass) {
        var tPlotModel = this.get('model'),
            tAdornmentModel = tPlotModel && tPlotModel.getAdornmentModel(iAdornmentKey),
            tAdornment = this[iAdornmentProperty];
        if (tAdornmentModel) {
          if (tAdornment) {
            // These can get out of sync in undo
            tAdornment.set('parentView', this);
            tAdornment.set('model', tAdornmentModel);
            tAdornment.set('paperSource', this.get('paperSource'));
          } else {
            tAdornment = iAdornmentClass.create({
              parentView: this, model: tAdornmentModel, paperSource: this.get('paperSource'),
              layerName: DG.LayerNames.kAdornments, shadingLayerName: DG.LayerNames.kIntervalShading
            });
            this[iAdornmentProperty] = tAdornment;
          }
          tAdornment.updateToModel();
        } else if (tAdornment) {  // We can't have an adornment without a model
          tAdornment.destroy();
          delete this[iAdornmentProperty];
        }
        this.setOffsetsForAverages();
      },

    });

/* >>>>>>>>>> BEGIN source/components/graph/plots/dot_plot_view.js */
// ==========================================================================
//                          DG.DotPlotView
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/plots/univariate_adornment_base_view');

/** @class  DG.DotPlotView - A plot of dots piled up along a numeric axis

 @extends DG.UnivariateAdornmentBaseView
 */
DG.DotPlotView = DG.UnivariateAdornmentBaseView.extend(
    /** @scope DG.DotPlotView.prototype */
    {
      displayProperties: ['primaryAxisView.model.lowerBound', 'primaryAxisView.model.upperBound'],

      /**
       The bins stretch from numeric axis' lower to upper bounds and have width 2 * point radius.
       Initially each bin is zero, but we increment its count each time a point is computed to
       display in that bin.
       It's a two-dimensional array where the first index corresponds to the cell number and the second
       index corresponds to the bin number
       @property {Array of Array of {Number}}
       */
      binArrays: null,

      /** @property {Number} */
      overlap: 0, // pixels of overlap between dots so that dots will fit in available space

      /** Used by normal curve adornment as a multipler of normal density function.
       * @property {Number} */
      binWidthInWorldCoordinates: function() {
        var tNumericAxisView = this.get('primaryAxisView'),
            tRadius = this.calcPointRadius();
        return Math.abs(tNumericAxisView.coordinateToData(2 * tRadius) - tNumericAxisView.coordinateToData(0));
      }.property(),

      primaryAxisViewDidChange: function () {
        arguments.callee.base.apply(this,arguments);
        var tMultMovableValuesAdorn = this.get('multipleMovableValuesAdorn');
        if (tMultMovableValuesAdorn)
          tMultMovableValuesAdorn.set('valueAxisView', this.get('primaryAxisView'));
      },

      /**
       * Return the classes of the desired axis views and the x or y to put them on.
       * @return {[{}]}
       */
      getAxisViewDescriptions: function () {
        var tDescriptions = arguments.callee.base.apply(this,arguments),
            tAxisKey = this.getPath('model.orientation') === DG.GraphTypes.EOrientation.kVertical ? 'x' : 'y';
        tDescriptions.push({
          axisKey: tAxisKey,
          axisClass: DG.CellLinearAxisView
        });
        return tDescriptions;
      },

      /**
       Before we recompute coordinates, we need to zero out the bin array.
       */
      prepareToResetCoordinates: function () {
        this.zeroBinArray();
      },

      /**
       * Called from animateFromTransferredElements to create animatable elements.
       * @param {DG.Case} iCase
       * @param {number} iIndex
       * @param {Object} iOldEltAttrs
       */
      createAnimatingElement: function (iCase, iIndex, iOldEltAttrs) {
        var tNumericAxisIsHorizontal = this.getPath('primaryAxisView.orientation') === 'horizontal',
            tOldElementIsRect = iOldEltAttrs && iOldEltAttrs.type === 'rect',
            tOldElementIsNegativeBar = iOldEltAttrs && iOldEltAttrs.isNegativeBar,
            tElement = this.callCreateElement(iCase, iIndex, false);
        if (iOldEltAttrs) {
          var tCX = tOldElementIsRect ? iOldEltAttrs.x : iOldEltAttrs.cx,
              tCY = tOldElementIsRect ? iOldEltAttrs.y : iOldEltAttrs.cy,
              attrs;
          if (tOldElementIsRect) {
            tCX += tNumericAxisIsHorizontal ?
                (tOldElementIsNegativeBar ? 0 : iOldEltAttrs.width) : iOldEltAttrs.width / 2;
            tCY += tNumericAxisIsHorizontal ? iOldEltAttrs.height / 2 :
                (tOldElementIsNegativeBar ? iOldEltAttrs.height : 0);
          }
          attrs = iOldEltAttrs && {
            r: tOldElementIsRect
                ? Math.min(iOldEltAttrs.width, iOldEltAttrs.height) / 2
                : iOldEltAttrs.r || this._pointRadius,
            cx: tCX,
            cy: tCY,
            fill: iOldEltAttrs.fill,
            stroke: iOldEltAttrs.stroke
          };
          attrs && tElement.attr(attrs);
        }
        return tElement;
      },

      /**
       * Set the coordinates and other attributes of the case circle (a Rafael element in this.get('plottedElements')).
       * @param {{}} iRC case-invariant Render Context
       * @param {DG.Case} iCase the case data
       * @param {number} iIndex index of case in collection
       * @param {Boolean} iAnimate (optional) want changes to be animated into place?
       * @param {function} iCallback
       * @returns {{cx:{Number},cy:{Number}}} final coordinates or null if not defined (hidden plot element)
       */
      setCircleCoordinate: function (iRC, iCase, iIndex, iAnimate, iCallback) {
        var tPlottedElements = this.get('plottedElements');
        DG.assert(iCase, 'There must be a case');
        DG.assert(DG.MathUtilities.isInIntegerRange(iIndex, 0, tPlottedElements.length),
            'index %@ out of bounds for plottedElements of length %@'.loc(iIndex, tPlottedElements.length));
        var tCircle = tPlottedElements[iIndex],
            tWorld = iCase.getForcedNumericValue(iRC.primaryVarID),
            tScreenCoord = iRC.primaryAxisView.dataToCoordinate(tWorld),
            tIsMissingCase = (!DG.isFinite(tScreenCoord) || iRC.primaryAxisPlace === DG.GraphTypes.EPlace.eUndefined);

        // show or hide if needed, then update if shown.
        if (this.showHidePlottedElement(tCircle, tIsMissingCase, iIndex) && iRC.categoryAxisModel) {

          var tCellNumber = iRC.categoryAxisModel.cellNameToCellNumber(iCase.getStrValue(iRC.categoryVarID)),
              tCellCoord = SC.none(tCellNumber) ? 0 : iRC.categoryAxisView.cellToCoordinate(tCellNumber),
              tCellHalfWidth = iRC.categoryAxisView.get('fullCellWidth') / 2,
              tRadius = this._pointRadius,
              tBinArrays = this.get('binArrays'),
              tBinArray = tBinArrays && (tCellNumber < tBinArrays.length) && tBinArrays[tCellNumber],
              tCoordX, tCoordY;

          var tBin = Math.round(tScreenCoord / (2 * tRadius)),
              tBinsInCell = (tBinArray && tBinArray.length) || 0,
              tRow = (tBinArray && tBin >= 0 && tBin < tBinsInCell) ? tBinArray[tBin].counter++ : 0,
              tOverlap = this.get('overlap'),
              tStackCoord = tRadius + (2 * tRadius - tOverlap) * tRow + 1;

          // Express coordinates in terms of x and y
          switch (iRC.primaryAxisPlace) {
            case DG.GraphTypes.EPlace.eX:
              tCoordX = tScreenCoord;
              tCoordY = tCellCoord - tStackCoord + tCellHalfWidth;
              break;
            case DG.GraphTypes.EPlace.eY:
              tCoordX = tCellCoord + tStackCoord - tCellHalfWidth;
              tCoordY = tScreenCoord;
              break;
          }

          var tAttrs = {
            cx: tCoordX,
            cy: tCoordY,
            r: this.radiusForCircleElement(tCircle),
            fill: iRC.calcCaseColorString(iCase),
            stroke: iRC.calcStrokeColorString(iCase),
            'fill-opacity': iRC.transparency,
            'stroke-opacity': iRC.strokeTransparency
          };
          this.updatePlottedElement(tCircle, tAttrs, iAnimate, iCallback);
          return {cx: tCoordX, cy: tCoordY, r: tRadius};
        }
        return null;
      },

      assignElementAttributes: function (iElement, iIndex, iAnimate) {
        arguments.callee.base.apply(this,arguments);

        var this_ = this,
            tNumericPlace = this.getPath('model.primaryAxisPlace'),
            tIsDragging = false,
            kOpaque = 1,
            tInitialTransform = null,
            tSelectedCases;

        function changeCaseValues(iDelta) {
          var tPrimaryVarID = this_.getPath('model.primaryVarID'),
              tChange = {
                operation: 'updateCases',
                cases: [],
                attributeIDs: [tPrimaryVarID],
                values: [[]],
                dirtyDocument: false
              },
              tDataContext = this_.get('dataContext');
          if (!tDataContext) return;
          // Note that we have to get the cases dynamically rather than have a variable
          // declared in the closure. The array pointed to by such a closure is not updated!
          this_.getPath('model.casesController.selection').forEach(function (iCase) {
            var tValue = iCase.getForcedNumericValue(tPrimaryVarID) + iDelta;
            if (this_.getPath('primaryAxisView.isDateTime')) {
              tValue = DG.createDate(tValue);
            }
            tChange.cases.push(iCase);
            tChange.values[0].push(tValue);
          });
          tDataContext.applyChange(tChange);
        }

        function returnCaseValuesToStart(iCaseIndex, iStartWorldCoord, iSelectedCases) {
          if (!SC.none(iStartWorldCoord)) {
            var tCase = this_.getPath('model.cases').unorderedAt(iCaseIndex),
                tPrimaryVarID = this_.getPath('model.primaryVarID'),
                tDelta = tCase.getForcedNumericValue(tPrimaryVarID) - iStartWorldCoord;
            this_.get('model').animateSelectionBackToStart([tPrimaryVarID], [tDelta], iSelectedCases);
          }
        }

        iElement.hover(function (event) {  // over
              // Note that Firefox can come through here repeatedly so we have to check for existence
              if (!tIsDragging && SC.none(tInitialTransform)) {
                tInitialTransform = '';
                this.animate({
                  opacity: kOpaque,
                  transform: DG.PlotUtilities.kDataHoverTransform
                }, DG.PlotUtilities.kDataTipShowTime);
                this_.showDataTip(this, iIndex);
              }
            },
            function (event) { // out
              if (!tIsDragging) {
                this.stop();
                this.animate({
                  opacity: DG.PlotUtilities.kDefaultPointOpacity,
                  transform: tInitialTransform
                }, DG.PlotUtilities.kHighlightHideTime);
                tInitialTransform = null;
                this_.hideDataTip();
              }
            })
            .drag(function (dx, dy) { // continue
                  if (dx !== 0 || dy !== 0) {
                    var tNewCoord = (tNumericPlace === DG.GraphTypes.EPlace.eX) ?
                            this.ox + dx : this.oy + dy,
                        tNewWorld = this_.get('primaryAxisView').coordinateToData(tNewCoord),
                        tOldWorld = this_.getPath('model.cases').unorderedAt(this.index).getForcedNumericValue(this_.getPath('model.primaryVarID')),
                        tCurrTransform = this.transform();
                    if (isFinite(tNewWorld)) {
                      // Put the element into the initial transformed state so that changing case values
                      // will not be affected by the scaling in the current transform.
                      SC.run(function () {
                        this.transform(tInitialTransform);
                        changeCaseValues(tNewWorld - tOldWorld);
                        this.transform(tCurrTransform);
                      }.bind(this));
                    }
                  }
                },
                function (x, y) { // begin
                  if (!tIsDragging) {
                    // Save the initial screen coordinates
                    this.ox = this.attr("cx");
                    this.oy = this.attr("cy");
                    // Save the initial world coordinate
                    this.w = this_.getPath('model.cases').unorderedAt(this.index).getForcedNumericValue(this_.getPath('model.primaryVarID'));
                    this.attr({opacity: kOpaque});
                    tSelectedCases = DG.copy(this_.getPath('model.selection'));
                    tIsDragging = true;
                  }
                },
                function () {  // end
                  if (tIsDragging) {
                    this.animate({transform: tInitialTransform}, DG.PlotUtilities.kHighlightHideTime);
                    returnCaseValuesToStart(this.index, this.w, tSelectedCases);
                    tIsDragging = false;
                  }
                  this.ox = this.oy = this.w = undefined;
                });
        return iElement;
      },

      zeroBinArray: function () {
        var tBinWidth = this._pointRadius === 0 ? 10 : 2 * this._pointRadius;
        this._zeroBinArray(tBinWidth);
      },

      /**
       Initialize binArray so it is ready to be used in drawing a complete set of points.
       */
      _zeroBinArray: function (iBinWidth) {
        var this_ = this,
            tNumericAxisView = this.get('primaryAxisView'),
            tCategoricalAxisView = this.get('secondaryAxisView');

        // We can get here because of a cleanupFunc call during destroy
        if (!tNumericAxisView || !tCategoricalAxisView)
          return;

        var tCategoricalAxisModel = tCategoricalAxisView.get('model'),
            tNumCells = tCategoricalAxisModel.get('numberOfCells'),
            tNumBins = Math.round(Math.abs(tNumericAxisView.get('pixelMax') -
                tNumericAxisView.get('pixelMin')) / iBinWidth) + 1;

        function computeOverlap() {
          var tCases = this_.getPath('model.cases'),
              tNumericVarID = this_.getPath('model.primaryVarID'),
              tCategoricalVarID = this_.getPath('model.secondaryVarID'),
              tRadius = iBinWidth / 2,
              tBinArrays = this_.get('binArrays'),
              tMaxStackHeight = tCategoricalAxisView.get('fullCellWidth'),
              // The '-1' in the following is to ensure at least one point's worth of space between cells
              tMaxThatFit = Math.round(tMaxStackHeight / (2 * tRadius)) - 1,
              tOverlap = 0,
              tMaxInBin, tPixelsOutside;
          tCases = tCases.filter(function (iCase) {
            return DG.isFinite(iCase.getForcedNumericValue(tNumericVarID));
          });

          if (tMaxThatFit <= 0) // If things are really tight, overlap points directly on top of each other
            return iBinWidth;

          tCases.forEach(function (iCase) {
            var tNumericCoord = tNumericAxisView.dataToCoordinate(iCase.getForcedNumericValue(tNumericVarID)),
                tBin = Math.round(tNumericCoord / (2 * tRadius)),
                tCellNumber = tCategoricalAxisModel.cellNameToCellNumber(iCase.getStrValue(tCategoricalVarID));
            // Note that we can get a valid cell number for which we have not yet allocated a
            // bin array. We choose to ignore that cell for the purposes of computing overlap. The
            // desired bin array will be created the next time we draw.
            if ((tBin >= 0) && !SC.none(tCellNumber) &&
                (tCellNumber >= 0) && (tCellNumber < tBinArrays.length) &&
                (tBin < tBinArrays[tCellNumber].length))
              tBinArrays[tCellNumber][tBin].total++;
          });
          tMaxInBin = DG.MathUtilities.max(tBinArrays.map(function (iBinArray) {
            return DG.MathUtilities.max(iBinArray.map(function (iBin) {
              return iBin.total;
            }));
          }));
          if (tMaxInBin > tMaxThatFit) {
            tPixelsOutside = (tMaxInBin - tMaxThatFit) * 2 * tRadius;
            tOverlap = tPixelsOutside / (tMaxInBin - 1);
          }
          return tOverlap;
        } // computeOverlap()

        // Fill arrays with zeroes
        this.set('binArrays', DG.MathUtilities.range(tNumCells).map(function () {
          return DG.MathUtilities.range(tNumBins).map(function () {
            return {total: 0, counter: 0};
          });
        }));
        this.set('overlap', computeOverlap());
      },

      /**
       Used by both handleBackgroundClick and handleBackgroundDblClick
       @param {SC.Event}
       */
      zoom: function (iEvent) {
        var tAxisKey = (this.getPath('model.primaryAxisPlace') === DG.GraphTypes.EPlace.eX) ? 'x' : 'y',
            tNumericAxisView = this.get('primaryAxisView'),
            tWorldPoint = {},
            tFactor = iEvent.shiftKey ? 2 : 0.5,
            tViewPoint = DG.ViewUtilities.windowToViewCoordinates({x: iEvent.clientX, y: iEvent.clientY}, this);
        tWorldPoint[tAxisKey] = tNumericAxisView.coordinateToData(tViewPoint[tAxisKey]);
        this.get('model').dilate(tWorldPoint, tFactor);
      },

      /**
       Alt key triggers zoom.
       @param {SC.Event}
       */
      handleBackgroundClick: function (iEvent) {
        if (iEvent.altKey) {
          this.zoom(iEvent);
        }
      },

      /**
       Zoom at the mouse point
       @param {SC.Event}
       */
      handleBackgroundDblClick: function (iEvent) {
        this.zoom(iEvent);
      }

    });

/* >>>>>>>>>> BEGIN source/components/graph/plots/histogram_view.js */
// ==========================================================================
//                          DG.HistogramView
//
//  Author:   William Finzer
//
//  Copyright (c) 2020 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/plots/univariate_adornment-base_view');

/** @class  DG.HistogramView, a plot of dots each placed according to numeric value bins

 @extends DG.UnivariateAdornmentBaseView
 */
DG.HistogramView = DG.UnivariateAdornmentBaseView.extend(
    /** @scope DG.HistogramView.prototype */
    {
      kLineSlideHCur: DG.Browser.customCursorStr('../../../../static/dg/de/cert/resources/cursors/LineSlideH.cur', 8, 8),
      kLineSlideVCur: DG.Browser.customCursorStr('../../../../static/dg/de/cert/resources/cursors/LineSlide.cur', 8, 8),

      /**
       * Expected type of plotted elements
       */
      plottedElementType: 'rect',

      /**
       * @property {[{coverRect: Element, draggableEdge: Element,
       *            lowerEdgeWorldValue: Number, lowerEdgeScreenCoord: Number }]}
       */
      barElements: null,

      _barToolTip: null,
      barToolTip: function() {
        if( !this._barToolTip) {
          this._barToolTip = DG.ToolTip.create( { paperSource: this,
            layerName: 'dataTip' });
        }
        return this._barToolTip;
      }.property(),
      /**
       * @property { Boolean }
       */
      dragInProgress: false,

      /**
       * @property {Element}
       */
      elementBeingDragged: null,

      init: function () {
        arguments.callee.base.apply(this,arguments);
        this.barElements = [];
      },

      destroy: function () {
        var tLayerManager = this.get('layerManager'),
            tPlottedElements = this.get('plottedElements');
        tPlottedElements.forEach( function( iElement) {
          tLayerManager.removeElement( iElement, true /* callRemove */);
        });
        tPlottedElements.length = 0;

        this.barElements.forEach(function (iElement) {
          ['coverRect', 'draggableEdge'].forEach( function( iProp) {
            tLayerManager.removeElement(iElement[iProp]);
            iElement[iProp].remove();
          });
        });

        arguments.callee.base.apply(this,arguments);
      },

      /**
       * We don't show counts or percents.
       */
      modelDidChange: function() {
        var tCountModel = this.getPath('model.plottedCount');
        if( tCountModel) {
          tCountModel.beginPropertyChanges();
          tCountModel.set('isVisible', false);
          tCountModel.set('isShowingCount', false);
          tCountModel.set('isShowingPercent', false);
          tCountModel.endPropertyChanges();
        }
      }.observes('model'),

      /**
       * Return the class of the count axis with the x or y to put it on.
       * @return {[{}]}
       */
      getAxisViewDescriptions: function () {
        var tDescriptions = [], // Don't call base class because it wants to add categorical axis view
            tCountKey = this.getPath('model.orientation') === DG.GraphTypes.EOrientation.kVertical ? 'y' : 'x',
            tNumericKey = tCountKey === 'x' ? 'y' : 'x';
        tDescriptions.push( {
          axisKey: tCountKey,
          axisClass: DG.CountAxisView
        });
        tDescriptions.push( {
          axisKey: tNumericKey,
          axisClass: DG.CellLinearAxisView
        });
        return tDescriptions;
      },

      /**
       * @property {DG.Layer}
       */
      _coverRectsLayer: null,
      coverRectsLayer: function () {
        if (!this._coverRectsLayer && this.getPath('paperSource.layerManager')) {
          this._coverRectsLayer = this.getPath('paperSource.layerManager.' + DG.LayerNames.kCoverRects);
        }
        return this._coverRectsLayer;
      }.property(),

      /**
       * Make sure the count axis has the correct upper bounds
       */
      setupAxes: function () {
        arguments.callee.base.apply(this,arguments);
        var tCountAxisView = this.get('secondaryAxisView'),
            tAttributeAxisView = this.get('primaryAxisView'),
            tWidth = this.getPath('model.width');
        // If the axes already have bounds, don't change them
        if (tCountAxisView && SC.none(tCountAxisView.getPath('model.lowerBound'))) {
          tCountAxisView.get('model').setLowerAndUpperBounds(0, 1.05 * this.getPath('model.maxBinCount'));
        }
        if (tAttributeAxisView && SC.none( tAttributeAxisView.getPath('model.lowerBound'))) {
          tAttributeAxisView.get('model').setLowerAndUpperBounds(this.getPath('model.leastBinEdge') - tWidth,
              this.getPath('model.maxBinEdge') + tWidth);
        }
      },

      /**
       * Construct and return a new render context
       * used for setCircleCoordinate()
       * @return {*}
       */
      createRenderContext: function () {
        var tRC = arguments.callee.base.apply(this,arguments),
            tModel = this.get('model');
        if(!tRC)
          return null;
        tRC.isVerticalOrientation = this.getPath('model.orientation') === DG.GraphTypes.EOrientation.kVertical;
        tRC.countAxisView = this.get('secondaryAxisView');
        tRC.leastBinEdgeWorld = tModel.get('leastBinEdge');
        tRC.leastBinEdgePixels = tRC.primaryAxisView.dataToCoordinate( tRC.leastBinEdgeWorld);
        tRC.barWidthWorld = tModel.get('width');
        tRC.barWidthPixels = Math.abs(tRC.primaryAxisView.dataToCoordinate( tRC.barWidthWorld) -
            tRC.primaryAxisView.dataToCoordinate( 0));
        tRC.sliceHeightPixels =  Math.abs(tRC.countAxisView.dataToCoordinate( 1) -
            tRC.countAxisView.dataToCoordinate( 0));

        return tRC;
      },

      /**
       * @param iCase
       * @param iIndex
       * @param iAnimate
       */
      createElement: function (iCase, iIndex, iAnimate) {
        // Can't create rects if we don't have paper for them
        if (!this.get('paper')) return;

        var tRect = this.get('paper').rect(-1000, -1000, 0, 0)
            .attr({
              fill: DG.PlotUtilities.kDefaultPointColor,
              stroke: 'none'
            });
        tRect.node.setAttribute('shape-rendering', 'geometricPrecision');
        /*
                if (iAnimate)
                  DG.PlotUtilities.doCreateRectAnimation(tRect);
        */
        return tRect;
      },

      updateAllCoordinates: function (iAnimate, iCallback) {
        var tModel = this.get('model'),
            tRC = this.createRenderContext(),
            tCases = this.getPath('model.cases'),
            tDataLength = tCases && tCases.get('length');
        tCases.forEach(function (iCase, iIndex) {
          var tCallback = iIndex === tDataLength - 1 ? iCallback : null,
              tCaseInfo = tModel.infoForCase(iIndex);
          this.privSetElementCoords(tRC, iCase, iIndex, tCaseInfo, iAnimate, tCallback);
        }.bind(this));
      },

      /**
       @param iAnimate { Boolean }
       @param iCallback { Function }
       */
      updateElements: function (iAnimate, iCallback) {
        // It's possible to get here before didCreateLayer() creates the get('paper').
        if (!this.get('paper'))
          return;
        arguments.callee.base.apply(this,arguments);
        this.computeCellParams();
        var tModel = this.get('model'),
            tCases = this.getPath('model.cases'),
            tRC = this.createRenderContext(),
            tDataLength = tCases && tCases.get('length'),
            tPlottedElements = this.get('plottedElements'),
            tPlotElementLength = tPlottedElements.length,
            tLayerManager = this.get('layerManager'),
            tIndex, tCellIndices;

        // for any new cases
        if (tDataLength > tPlotElementLength) {
          // add plot elements for added cases
          for (tIndex = tPlotElementLength; tIndex < tDataLength; tIndex++) {
            this.callCreateElement(tCases.at(tIndex), tIndex, this.animationIsAllowable());
            tCellIndices = tModel.lookupCellForCaseIndex(tIndex);
            this.privSetElementCoords(tRC, tCases.at(tIndex), tIndex, tCellIndices, iAnimate, iCallback);
          }
        }
        // Get rid of plot elements for removed cases and update all coordinates
        if (tDataLength < tPlotElementLength) {
          for (tIndex = tDataLength; tIndex < tPlotElementLength; tIndex++) {
            // It can happen during closing of a document that the elements no longer exist, so we have to test
            if (!SC.none(tPlottedElements[tIndex])) {
              tPlottedElements[tIndex].stop();
              DG.PlotUtilities.doHideRemoveAnimation(tPlottedElements[tIndex], tLayerManager);
            }
          }
          // update all coordinates because we don't know which cases were deleted
          this.updateAllCoordinates(iAnimate, iCallback);
        }
        this._isRenderingValid = false;
      },

      modelWidthOrAlignmentDidChange: function() {
        this.displayDidChange();
      }.observes('model.changed'),

      markBinParamsChange: function( iInitialAlignment, iInitialBinWidth) {
        var this_ = this,
            tNewAlignment = this.getPath('model.alignment'),
            tNewBinWidth = this.getPath('model.width');
        DG.UndoHistory.execute(DG.Command.create({
          name: 'graph.drag.binBoundary',
          undoString: 'DG.Undo.graph.dragBinBoundary',
          redoString: 'DG.Redo.graph.dragBinBoundary',
          log: "dragBinBoundary from { alignment: %@, width: %@ } to { alignment: %@, width: %@ }".
                  fmt(iInitialAlignment, iInitialBinWidth, tNewAlignment, tNewBinWidth),
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'drag bin boundary',
              type: 'DG.GraphView'
            }
          },
          execute: function() { },
          undo: function() {
            this_.setPath('model.alignment', iInitialAlignment);
            this_.setPath('model.width', iInitialBinWidth);
          },
          redo: function() {
            this_.setPath('model.alignment', tNewAlignment);
            this_.setPath('model.width', tNewBinWidth);
          }
        }));
      },

      /**
       Override base class because we're dealing with rectangles, not points.
       @return {Array of {x:{Number}, y:{Number}, width:{Number}, height:{Number}, cx:{Number}, cy:{Number}, r:{Number}, fill:{String}}}
       */
      getElementPositionsInParentFrame: function() {
        var tFrame = this.get('frame');
        return this.get('plottedElements').map( function( iElement) {
          var tX = iElement.attr('x') + tFrame.x,
              tY = iElement.attr('y') + tFrame.y,
              tWidth = iElement.attr('width'),
              tHeight = iElement.attr('height'),
              tR = 0, //Math.min( tWidth, tHeight) / 2,
              tCx = tX + tWidth / 2,
              tCy = tY + tHeight / 2,
              tResult = { x: tX, y: tY, width: tWidth, height: tHeight, cx: tCx, cy: tCy, r: tR,
                fill: iElement.attr('fill'), type: 'rect', stroke: iElement.attr('stroke'),
                'stroke-opacity': iElement.attr('stroke-opacity')
              };
          return tResult;
        });
      },

      /**
       We override the base class implementation to animate the circles that we're given from a binned
       plot view into rectangles.
       */
      animateFromTransferredElements: function () {
        var this_ = this,
            tModel = this.get('model'),
            tCases = tModel.get('cases'),
            tRC = this.createRenderContext(),
            tFrame = this.get('frame'), // to convert from parent frame to this frame
            tOldElementAttrs = this.get('transferredElementCoordinates'),
            tOldElementsAreCircles = tOldElementAttrs[0] && tOldElementAttrs[0].type === 'circle';
        if (!tCases)
          return;

        function turnOffAnimation() {
          tModel.set('isAnimating', false);
          this_.get('plottedElements').forEach( function( iElement) {
            iElement.stop();
          });
          this_.displayDidChange(); // Force redisplay in correct position
        }

        DG.sounds.playMixup();
        var tPlottedElements = this.get('plottedElements'),
            tTransAttrs;

        this.prepareToResetCoordinates();
        this.removePlottedElements();
        // Normally we leave the elements (circles) for re-use. But since we want rects, we have let go of the circles.
        tPlottedElements.forEach( function( iElement) {
          iElement.remove();
        });
        tPlottedElements.length = 0;
        tOldElementAttrs.forEach(function (iElement, iIndex) {
          // adjust old coordinates from parent frame to this view
          // In case it's a point
          iElement.cx -= tFrame.x;
          iElement.cy -= tFrame.y;
          // in case it's a rect
          iElement.x -= tFrame.x;
          iElement.y -= tFrame.y;
        });
        tCases.forEach(function (iCase, iIndex) {
          var tOldElement = tOldElementAttrs[iIndex],
              tCaseInfo = tModel.infoForCase(iIndex),
              tElement = this_.callCreateElement(iCase, iIndex, false);
          if (!SC.none(tOldElement)) {
            tTransAttrs = {
              r: tOldElementsAreCircles ? tOldElement.r : 0,
              x: tOldElementsAreCircles ? tOldElement.cx - tOldElement.r : tOldElement.x,
              y: tOldElementsAreCircles ? tOldElement.cy - tOldElement.r : tOldElement.y,
              width: tOldElementsAreCircles ? 2 * tOldElement.r : tOldElement.width,
              height: tOldElementsAreCircles ? 2 * tOldElement.r : tOldElement.height,
              fill: tOldElement.fill,
              stroke: tOldElement.fill
            };
            tElement.attr(tTransAttrs);
          }
          tElement = this_.privSetElementCoords(tRC, iCase, iIndex, tCaseInfo, true /* animate */);
        });
        this.set('transferredElementCoordinates', null);

        tModel.set('isAnimating', true);
        SC.Timer.schedule({action: turnOffAnimation, interval: DG.PlotUtilities.kDefaultAnimationTime});
      },

      resetCoordinates: function (iCases, iRC) {
        var tPlotElementLength = this.get('plottedElements').length,
            tModel = this.get('model');
        this.prepareToResetCoordinates();
        iCases.forEach(function (iCase, iIndex) {
          if (iIndex >= tPlotElementLength)
            this.callCreateElement(iCase, iIndex, true, iRC.isVisible);
          this.privSetElementCoords(iRC, iCase, iIndex, tModel.infoForCase( iIndex));
        }.bind(this));
        this._mustMoveElementsToNewCoordinates = false;
      },

      /**
       * This is a shim so we can handle assumption that elements are circles
       * @param iRC
       * @param iCase
       * @param iIndex
       */
      setCircleCoordinate: function( iRC, iCase, iIndex) {
        this.privSetElementCoords( iRC, iCase, iIndex, this.get('model').infoForCase( iIndex));
      },

      /**
       *
       * @param iRC {*}
       * @param iCase {DG.Case}
       * @param iIndex {Number}
       * @param iCaseInfo { {value: {Number}, cell: {Number}, bin: { Number}, indexInBin: {Number}} }
       * @param iAnimate {Boolean}
       * @param iCallback {Function}
       */
      privSetElementCoords: function (iRC, iCase, iIndex, iCaseInfo, iAnimate, iCallback) {
        DG.assert(iRC && iRC.xAxisView);
        DG.assert(iCase);
        DG.assert(DG.MathUtilities.isInIntegerRange(iIndex, 0, this.get('plottedElements').length));
        var tRect = this.get('plottedElements')[iIndex];

        // It can happen that we don't have case info yet. Bail for now cause we'll be back later.
        if( !iCaseInfo)
          return;

        var tTop = iRC.countAxisView.dataToCoordinate(iCaseInfo.indexInBin + 1),
            tEdge = iRC.primaryAxisView.dataToCoordinate(iRC.leastBinEdgeWorld + (iCaseInfo.bin) * iRC.barWidthWorld),
            tCoordX, tCoordY, tWidth, tHeight;

        if (iRC.isVerticalOrientation) {
          tCoordX = tEdge;
          tCoordY = tTop;
          tWidth = iRC.barWidthPixels;
          tHeight = iRC.sliceHeightPixels;
        }
        else {
          tCoordX = tTop - iRC.sliceHeightPixels;
          tCoordY = tEdge - iRC.barWidthPixels;
          // todo: How to disable lint for these two lines?
          tWidth = iRC.sliceHeightPixels;
          tHeight = iRC.barWidthPixels;
        }
        var tNewAttrs = {
          x: tCoordX, y: tCoordY, r: 0.1, width: tWidth, height: tHeight,
          fill: iRC.calcCaseColorString(iCase),
          'fill-opacity': iRC.transparency,
          'stroke-opacity': 0,
          opacity: 1
        };
        if (iAnimate) {
          tRect.show();
          tRect.animate(tNewAttrs, DG.PlotUtilities.kDefaultAnimationTime, '<>', iCallback);
        }
        else {
          tRect.attr(tNewAttrs);
          tRect.show();
        }
        return tRect;
      },

      /**
       * Each bar of the histogram gets covered by a rectangle so that hovering produces a data tip
       * with information about the cases represented by that bar.
       */
      drawCoverRectsAndBoundaries: function() {

        function makeARect( iBar, iIndex) {
          var tDigits = DG.PlotUtilities.findFractionDigitsForAxis( tPrimaryAxisView),
              tNumFormat = DG.Format.number().fractionDigits( 0, tDigits),
              tRect = tPaper.rect( 0, 0, 0, 0)
                  .attr({stroke: DG.PlotUtilities.kBinBorderLineColor,
                    fill: 'white', 'fill-opacity': 0.001, cursor: 'pointer'})
                  .hover(function (iEvent) {
                        var tTotalCount = this_.getPath('model.totalCount');
                        if( this_.dragInProgress)
                          return;
                        this.animate({
                          'fill-opacity': 0.4
                        }, DG.PlotUtilities.kDataTipShowTime);
                        tWidth = this_.getPath('model.width');
                        tLeastEdge = this_.getPath('model.leastBinEdge');
                        tToolTip = this_.get('barToolTip');
                        tTemplate = iBar.count > 1 ? "DG.HistogramView.barTipNoLegendPlural" :
                            "DG.HistogramView.barTipNoLegendSingular";
                        tToolTipText = tTemplate.loc(
                            this.indices.length,
                            tTotalCount,
                            Math.round(1000 * (this.indices.length) / tTotalCount) / 10,
                            tNumFormat( tLeastEdge + iIndex * tWidth),
                            tNumFormat( tLeastEdge + (iIndex + 1) * tWidth)
                        );
                        tToolTip.set('text', tToolTipText);
                        tToolTip.set('tipOrigin', {x: iEvent.layerX, y: iEvent.layerY});
                        tToolTip.show();
                      },
                      function (event) { // out
                        this.stop();
                        this.animate({
                          'fill-opacity': 0.001
                        }, DG.PlotUtilities.kHighlightHideTime);
                        if(tToolTip)
                          tToolTip.hide();
                      }
                  )
                  .mousedown(function (iEvent) {
                    SC.run(function () {
                      this_.get('model').selectCasesWithIndices(this.indices, iEvent.shiftKey);
                    }.bind( this));
                  });
          tRect.indices = iBar.indices;
          return tRect;
        }

        function updateCoverRect( iCoverRect, iBar, iIndex) {
          var tX = tIsVertical ? tPrimaryAxisView.dataToCoordinate( tLeastEdge + iIndex * tWidth) : 0,
              tY = tIsVertical ? tCountAxisView.dataToCoordinate( iBar.count) :
                  tPrimaryAxisView.dataToCoordinate( tLeastEdge + (iIndex + 1) * tWidth),
              tRectWidth = tIsVertical ? tWidthPixels : tCountAxisView.dataToCoordinate( iBar.count),
              tRectHeight = tIsVertical ? tCountAxisView.get('pixelMin') - tCountAxisView.dataToCoordinate( iBar.count) :
                  tWidthPixels;
          iCoverRect.indices = iBar.indices;
          iCoverRect.attr( { x: tX, y: tY, width: tRectWidth, height: tRectHeight});
        }

        function makeADraggableEdge( iBar, iIndex) {
          var tModel = this_.get('model'),
              kMinBinWidth = 10,
              tInitialAlignment, tWorldWidth, tInitialWorldWidth,
              tWidthIncrement, tWorldPerPixel, tBinWidthAtStartOfDrag, tNewBinAlignment;

          function beginTranslate(iWindowX, iWindowY) {
            this_.dragInProgress = true;
            this_.elementBeingDragged = this;
            tInitialAlignment = tModel.get('alignment');
            tWorldWidth = tModel.get('width');
            tInitialWorldWidth = tModel.get('width');
            tWidthIncrement = tModel.get('widthIncrement');
            tWidthPixels = Math.abs(tPrimaryAxisView.dataToCoordinate( tWidth) - tPrimaryAxisView.dataToCoordinate( 0));
            tWorldPerPixel = tWorldWidth / tWidthPixels;
            tBinWidthAtStartOfDrag = Math.abs( tPrimaryAxisView.dataToCoordinate(tWorldWidth) -
                tPrimaryAxisView.dataToCoordinate(0));
            this_.set('binNumBeingDragged', iIndex);
            tNewBinAlignment = this.lowerEdgeWorld;
            tModel.set('alignment', tNewBinAlignment);
          }

          function continueTranslate(idX, idY) {
            var tDelta = tIsVertical ? idX : -idY,
                tNewWorldWidth = (tBinWidthAtStartOfDrag + tDelta) * tWorldPerPixel;
            tNewWorldWidth = Math.round(tNewWorldWidth / tWidthIncrement) * tWidthIncrement;
            if( tBinWidthAtStartOfDrag + tDelta >= kMinBinWidth) {
              SC.run( function() {
                tModel.set('width', tNewWorldWidth);
              });
            }
          }

          function endTranslate(idX, idY) {
            var tNewWidth = tModel.get('width');
            if( tNewBinAlignment !== tInitialAlignment || tInitialWorldWidth !== tNewWidth) {
              this_.markBinParamsChange( tInitialAlignment, tInitialWorldWidth);
            }
            this_.set('binNumBeingDragged', null);
            this_.dragInProgress = false;
            if( this_.elementBeingDragged.shouldGoAway) {
              tCoverLayer.prepareToMoveOrRemove(this_.elementBeingDragged);
              this_.elementBeingDragged.remove();
              this_.elementBeingDragged = null;
            }
            this_.displayDidChange();
          }

          var tLineCover = tPaper.line(0, 0, 0, 0)
                  .drag(continueTranslate, beginTranslate, endTranslate);
          tLineCover.binNum = iIndex;
          return tLineCover.attr({
            'stroke-width': 6, stroke: DG.RenderingUtilities.kSeeThrough,
            cursor: tCursor, title: tTitle
          });
        }

        function updateDraggableEdge( iLine, iBar, iIndex) {
          var tX1 = tIsVertical ? tPrimaryAxisView.dataToCoordinate( tLeastEdge + (iIndex + 1) * tWidth) : 0,
              tY1 = tIsVertical ? tCountAxisView.dataToCoordinate( iBar.count) :
                  tPrimaryAxisView.dataToCoordinate( tLeastEdge + (iIndex + 1) * tWidth),
              tX2 = tIsVertical ? tX1 : tCountAxisView.dataToCoordinate( iBar.count),
              tY2 = tIsVertical ? tCountAxisView.get('pixelMin') : tY1;
          iLine.count = iBar.count;
          iLine.binNum = iIndex;
          iLine.lowerEdgeWorld = iBar.lowerEdgeWorld;
          DG.RenderingUtilities.updateLine( iLine, { x: tX1, y: tY1 }, { x: tX2, y: tY2});
        }

        var this_ = this,
            tPaper = this.get('paper'),
            tPrimaryAxisView = this.get('primaryAxisView'),
            tCountAxisView = this.get('secondaryAxisView'),
            tIsVertical = this.getPath('model.orientation') === DG.GraphTypes.EOrientation.kVertical,
            tCoverLayer = this.get('coverRectsLayer'),
            tLeastEdge = this.getPath('model.leastBinEdge'),
            tWidth = this.getPath('model.width'),
            tWidthPixels = Math.abs(tPrimaryAxisView.dataToCoordinate( tWidth) - tPrimaryAxisView.dataToCoordinate( 0)),
            tBarElements = this.get('barElements'),
            tBars = this.getPath('model.bars'),
            tNumBars = tBars.length,
            tCursor = tIsVertical ? this_.kLineSlideHCur : this_.kLineSlideVCur,
            tTitle = 'DG.BinnedPlotModel.dragBinTip'.loc(),
            tTemplate, tToolTipText, tToolTip;
        tBars.forEach( function( iBar, iIndex) {
          if( !tBarElements[ iIndex]) {
            tBarElements[ iIndex] = {
              coverRect: makeARect( iBar, iIndex),
              draggableEdge: makeADraggableEdge( iBar, iIndex)
            };
            tCoverLayer.push( tBarElements[ iIndex].coverRect);
            tCoverLayer.push( tBarElements[ iIndex].draggableEdge);
          }
          else {
            updateCoverRect( tBarElements[ iIndex].coverRect, iBar, iIndex);
            updateDraggableEdge( tBarElements[ iIndex].draggableEdge, iBar, iIndex);
          }
        });

        while (tBarElements.length > tNumBars) {
          var tElement = tBarElements.pop();
          // eslint-disable-next-line no-loop-func
          ['coverRect', 'draggableEdge'].forEach( function( iProp) {
            if( tElement[iProp] !== this_.elementBeingDragged) {
              tCoverLayer.prepareToMoveOrRemove(tElement[iProp]);
              tElement[iProp].remove();
            }
            else
              this_.elementBeingDragged.shouldGoAway = true;  // So that it can be removed later in drag code
          });
        }

        tBarElements.forEach( function( iElement) {
          tCoverLayer.bringToFront( iElement.draggableEdge);
        });
      },

      /**
       Generate the svg needed to display the plot
       */
      doDraw: function doDraw() {

        arguments.callee.base.apply(this,arguments);

        this.drawData();

        this.drawCoverRectsAndBoundaries();

        // this.updateSelection();
      }

    });

/* >>>>>>>>>> BEGIN source/components/graph/plots/line-plot-model.js */
// ==========================================================================
//                            DG.LinePlotModel
//
//  Author:   Kirk Swenson
//
//  Copyright (c) 2020 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/plots/dot_plot_model');

/** @class  DG.LinePlotModel The model for a line/bar plot.

 @extends SC.LinePlotModel
 */
DG.LinePlotModel = DG.DotPlotModel.extend(
  /** @scope DG.LinePlotModel.prototype */
  {
    /**
     * Originally a boolean; extended to support line/bar plot
     * @property {Boolean | "bars"}
     */
    displayAsBinned: "bars",

    handleDataConfigurationChange: function(iKey) {
      // override to prevent unnecessary call to rescaleAxesFromData() by base class
      this.updateAdornmentModels();
    }
  }
);

/**
 class method called before plot creation to make sure roles are correct
 @param {DG.GraphDataConfiguration}
 */
DG.LinePlotModel.configureRoles = function(iConfig) {
  // Base class has method for this
  DG.UnivariatePlotModel.configureRoles(iConfig);
};

/* >>>>>>>>>> BEGIN source/components/graph/plots/line-plot-view.js */
// ==========================================================================
//                          DG.LinePlotView
//
//  Author:   Kirk Swenson
//
//  Copyright (c) 2020 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/plots/dot_plot_view');

/** @class  DG.LinePlotView - A line/bar for each case

  @extends DG.DotPlotView
*/
DG.LinePlotView = DG.DotPlotView.extend(
/** @scope DG.LinePlotView.prototype */
{
  /**
   * Expected type of plotted elements
   */
  plottedElementType: 'rect',

  /**
   * Array of { caseCount: number, indexMap: { caseIndexInCollection: caseIndexInCell } } per cell
   */
  cellCaseInfo: null,

  /**
   * Max number of cases in a cell
   */
  maxCaseCountInCell: 0,

  /**
   * Configure axes
   */
  setupAxes: function () {
    arguments.callee.base.apply(this,arguments);

    this.setPath('primaryAxisView.model.preferZeroLowerBound', true);
    this.setPath('primaryAxisView.model.drawZeroLine', true);

    this.setPath('secondaryAxisView.centering', true);

    var model = this.get('model');
    model && model.rescaleAxesFromData(true);
  },

  /**
   * Update the cell counts.
   */
  updateCellCaseInfo: function() {
    var categoryAxisModel = this.getPath('secondaryAxisView.model');
    if (!categoryAxisModel) return;
    var cellCount = categoryAxisModel.get('numberOfCells'),
        cellCaseInfo = new Array(cellCount),
        maxCaseCountInCell = 0;
    for (var i = 0; i < cellCount; ++i) {
      // map from index in collection to index in cell
      cellCaseInfo[i] = {
        caseCount: 0,
        indexMap: {}
      };
    }
    var tCases = this.getPath('model.cases'),
        tCategoryVarID = this.getPath('model.secondaryVarID');
    if (tCases) {
      tCases.forEach(function(iCase, iCaseIndex) {
        var cellIndex = categoryAxisModel.cellNameToCellNumber(iCase.getStrValue(tCategoryVarID));
        if (cellIndex >= 0) {
          var cellInfo = cellCaseInfo[cellIndex];
          if (cellInfo) {
            cellInfo.indexMap[iCaseIndex] = cellInfo.caseCount;
            if (++cellInfo.caseCount > maxCaseCountInCell)
              maxCaseCountInCell = cellInfo.caseCount;
          }
        }
      });
    }
    this.set('cellCaseInfo', cellCaseInfo);
    this.set('maxCaseCountInCell', maxCaseCountInCell);
  },

  /**
    Before we recompute coordinates, we need to compute the cell counts.
   */
  prepareToResetCoordinates: function() {
    arguments.callee.base.apply(this,arguments);
    this.updateCellCaseInfo();
  },

  /**
   * @param iCase
   * @param iIndex
   * @param iAnimate
   */
  createElement: function (iCase, iIndex, iAnimate) {
    // Can't create rects if we don't have paper for them
    if (!this.get('paper')) return;

    var tRect = this.get('paper').rect(-1000, -1000, 0, 0)
        .attr({
          fill: DG.PlotUtilities.kDefaultPointColor,
          stroke: 'none'
        });
    tRect.node.setAttribute('shape-rendering', 'geometricPrecision');
    /*
            if (iAnimate)
              DG.PlotUtilities.doCreateRectAnimation(tRect);
    */
    return tRect;
  },

  /**
    For use in transferring current element positions of this plot to a new plot about
    to take its place.
    @return {[{cx:{Number}, cy:{Number}, r: {Number}, fill: {String} ]}
  */
  getElementPositionsInParentFrame: function() {
    var tFrame = this.get('frame'),
        tPlottedElements = this.get('plottedElements');
    DG.assert(tPlottedElements.length === 0 || tPlottedElements[0][0].constructor === SVGRectElement,
              'Expecting rectangle');
    return tPlottedElements.map( function( iElement) {
        var tX = iElement.attr('x') + tFrame.x,
            tY = iElement.attr('y') + tFrame.y,
            tWidth = iElement.isHidden() ? 0 : iElement.attr('width'),    // use 0 for hidden plot element
            tHeight = iElement.isHidden() ? 0 : iElement.attr('height');  // use 0 for hidden plot element
            return {
              x: tX,
              y: tY,
              width: tWidth,
              height: tHeight,
              fill: iElement.attr('fill'),
              stroke: iElement.attr('stroke'),
              type: 'rect',
              isNegativeBar: iElement._isNegativeBar};
      });
  },

  /**
   * Called from animateFromTransferredElements to create animatable elements.
   * @param {DG.Case} iCase
   * @param {number} iIndex
   * @param {Object} iOldEltAttrs
   */
  createAnimatingElement: function(iCase, iIndex, iOldEltAttrs) {
    var tOldElementIsCircle = iOldEltAttrs && iOldEltAttrs.type === 'circle',
        tElement = this.callCreateElement(iCase, iIndex, false),
        attrs = iOldEltAttrs && {
          r: tOldElementIsCircle ? iOldEltAttrs.r : 0,
          x: tOldElementIsCircle ? iOldEltAttrs.cx - iOldEltAttrs.r : iOldEltAttrs.x,
          y: tOldElementIsCircle ? iOldEltAttrs.cy - iOldEltAttrs.r : iOldEltAttrs.y,
          width: tOldElementIsCircle ? 2 * iOldEltAttrs.r : iOldEltAttrs.width,
          height: tOldElementIsCircle ? 2 * iOldEltAttrs.r : iOldEltAttrs.height,
          fill: iOldEltAttrs.fill,
          stroke: iOldEltAttrs.stroke
        };
    attrs && tElement.attr(attrs);
    return tElement;
  },

  /**
   * Set the coordinates and other attributes of the case rectangle (a Rafael element in this.get('plottedElements')).
   * @param {{}} iRC case-invariant Render Context
   * @param {DG.Case} iCase the case data
   * @param {number} iIndex index of case in collection
   * @param {Boolean} iAnimate (optional) want changes to be animated into place?
   * @param {function} iCallback
   * @returns {{cx:{Number},cy:{Number}}} final coordinates or null if not defined (hidden plot element)
   */
  setCircleCoordinate: function( iRC, iCase, iIndex, iAnimate, iCallback ) {
    var tPlottedElements = this.get('plottedElements');
    DG.assert( iCase, 'There must be a case' );
    DG.assert( DG.MathUtilities.isInIntegerRange( iIndex, 0, tPlottedElements.length ),
        'index %@ out of bounds for plottedElements of length %@'.loc(iIndex, tPlottedElements.length));
    var tRect = tPlottedElements[iIndex],
        tWorld = iCase.getForcedNumericValue(iRC.primaryVarID),
        tScreenCoord = iRC.primaryAxisView.dataToCoordinate(tWorld),
        tZeroCoord = iRC.primaryAxisView.dataToCoordinate(0),
        tIsMissingCase = !DG.isFinite(tScreenCoord) || (iRC.primaryAxisPlace === DG.GraphTypes.EPlace.eUndefined);
    // For animation purposes, record whether the bar is negative
    tRect._isNegativeBar = tWorld < 0;
    // show or hide if needed, then update if shown.
    if( this.showHidePlottedElement(tRect, tIsMissingCase, iIndex) && iRC.categoryAxisModel) {

      var tCellNumber = iRC.categoryAxisModel.cellNameToCellNumber(iCase.getStrValue(iRC.categoryVarID )),
          tMaxCaseCountInCell = this.get('maxCaseCountInCell'),
          tCellCaseInfo = this.get('cellCaseInfo')[tCellNumber],
          tIndexInCell = tCellCaseInfo ? tCellCaseInfo.indexMap[iIndex] : 0,
          tCasesInCell = tCellCaseInfo ? tCellCaseInfo.caseCount : 0,
          tCellCoord = SC.none(tCellNumber) ? 0 : iRC.categoryAxisView.cellToCoordinate(tCellNumber),
          tCellWidth = iRC.categoryAxisView.get('fullCellWidth'),
          tCellStart = tCellCoord - tCellWidth / 2,
          tBarWidth = tCellWidth / (tMaxCaseCountInCell + 1), // +1 for half bar-width padding on either side
          tCellPadding = (tMaxCaseCountInCell - tCasesInCell) * tBarWidth / 2,
          tCoordX, tCoordY, tWidth, tHeight;

      // Express coordinates in terms of x and y
      switch(iRC.primaryAxisPlace) {
        case DG.GraphTypes.EPlace.eX:
          tCoordX = tWorld < 0 ? tScreenCoord : tZeroCoord;
          tCoordY = tCellStart + tCellWidth - (tCellPadding + (tIndexInCell + 1.5) * tBarWidth);
          tWidth = Math.abs(tScreenCoord - tZeroCoord);
          tHeight = tBarWidth;
          break;
        case DG.GraphTypes.EPlace.eY:
          tCoordX = tCellStart + tCellPadding + (tIndexInCell + 0.5) * tBarWidth;
          tCoordY = tWorld < 0 ? tZeroCoord : tScreenCoord;
          tWidth = tBarWidth;
          tHeight = Math.abs(tScreenCoord - tZeroCoord);
          break;
      }

      var tAttrs = {x: tCoordX, y: tCoordY, width: tWidth, height: tHeight, r: 0.1,
                    fill: iRC.calcCaseColorString( iCase ),
                    stroke: iRC.calcStrokeColorString( iCase), 'fill-opacity': iRC.transparency, 'stroke-opacity': iRC.strokeTransparency};
      this.updatePlottedElement( tRect, tAttrs, iAnimate, iCallback);
      return { x: tCoordX, y: tCoordY, width: tWidth, height: tHeight };
    }
    return null;
  },

  showDataTip: function (iElement, iIndex, event) {
    if (DG.NO_DATA_TIP_PREF || this.getPath('paperSource.tempDisallowDataTips'))
      return;
    this.get('dataTip').show(event.offsetX, event.offsetY, 8, iIndex);
  },

  assignElementAttributes: function( iElement, iIndex, iAnimate) {
    var this_ = this,
        kOpaque = 1;

    // duplicated from DG.PlotLayer
    // Remove event handlers
    if (iElement.events) {
      iElement.events.forEach(function (iHandler) {
        iHandler.unbind();
      });
      iElement.events.length = 0;
    }
    iElement.addClass(DG.PlotUtilities.kColoredDotClassName)
        .attr({cursor: 'pointer'})
        .mousedown(function (iEvent) {
          SC.run(function () {
            this_.get('model').selectCaseByIndex(iIndex, iEvent.shiftKey);
          });
        });
    iElement.index = iIndex;

    iElement.hover(
      function (event) {  // over
        this.animate({
          opacity: kOpaque,
        }, DG.PlotUtilities.kHighlightHideTime);
        this_.showDataTip(this, iIndex, event);
      },
      function (event) { // out
        this.stop();
        this.animate({
          opacity: DG.PlotUtilities.kDefaultPointOpacity,
        }, DG.PlotUtilities.kHighlightHideTime);
        this_.hideDataTip();
      });
    return iElement;
  }

});

/* >>>>>>>>>> BEGIN source/components/graph/plots/number_toggle_model.js */
// ==========================================================================
//                          DG.NumberToggleModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class DG.NumberToggleModel - The model for the parent cases that are available for toggling hide and show.

  @extends SC.Object
*/
DG.NumberToggleModel = SC.Object.extend( (function() {
/** @scope DG.NumberToggleModel.prototype */

  function reduceCase(prevCases, newCase) {
    prevCases.push(newCase);
    return prevCases;
  }

  function hideShowCases(iConfig, iCases, iShow) {
    var casesToHideShow = [];
    iCases.reduce(reduceCase, casesToHideShow);

    // recursively hide/show children
    iCases.forEach(function(iCase) {
      var tChildren = iCase.get('children');
      if (tChildren && tChildren.length)
        tChildren.reduce(reduceCase, casesToHideShow);
    });

    if (iShow)
      iConfig.showCases(casesToHideShow);
    else
      iConfig.hideCases(casesToHideShow);
  }

return {
  /**
    Assigned by the graph model that owns me.
    @property { DG.GraphDataConfiguration }
  */
  dataConfiguration: null,

  hiddenCasesBinding: '*dataConfiguration.hiddenCases',

  /**
   * Whether we are in show last parent case only mode
   * @property {Boolean}
   */
  lastMode: false,

  _cachedCaseCount: null,
  _cachedParentCases: null,

  invalidate: function() {
    this._cachedCaseCount = this._cachedParentCases = this._isHierarchical = null;

    // 'caseCount' is used as a proxy to indicate that some change occurred
    // GraphView.handleNumberToggleDidChange() observes 'caseCount'
    // not clear why invokeOnceLater() is (or was) required
    this.invokeOnceLater( this.propertyDidChange, 1, 'caseCount');
  },

  isEnabledDidChange: function() {
    // sync up with any changes that occurred while disabled
    if (this.get('isEnabled'))
      this.invalidate();
  }.observes('isEnabled'),

  /**
   * @property{SC.Array of DG.Case}
   */
  parentCases: function() {
    var tParents = [],
        tCases = this.getPath('dataConfiguration.allCases' ),
        isHierarchical = false;
    if( !tCases)
      return [];
    tCases = tCases.slice();

    function getUltimateParent(iCase) {
      var lastCase;
      while(iCase) {
        lastCase = iCase;
        iCase = iCase.get('parent');
        if (iCase) isHierarchical = true;
      }
      return lastCase;
    }

    // This check for whether we can use the cached parents isn't completely foolproof because
    // cases could come and go leaving us with the same number between calls.
    if( tCases.get('length') === this._cachedCaseCount) {
      tParents = this._cachedParentCases;
    }
    else {
      tCases.forEach( function( iCase) {
        var tParent = getUltimateParent(iCase);
        if( tParent && tParents.indexOf( tParent ) < 0 ) {
          tParents.push( tParent );
        }
      });
      this._cachedCaseCount = tCases.get('length');
      this._cachedParentCases = tParents;
      this._isHierarchical = isHierarchical;
    }
    return tParents;
  }.property(),
  parentCasesDidChange: function() {
    this.notifyPropertyChange('parentCases');
  }.observes('*dataConfiguration.cases'),

  getFirstParentAttribute: function() {
    var dataContext = this.getPath('dataConfiguration.dataContext'),
        collectionClient = dataContext && dataContext.getCollectionAtIndex(0),
        attrs = collectionClient && collectionClient.getPath('collection.attrs');
    return attrs && attrs[0];
  },

  getParentLabel: function(iIndex) {
    var cases = this.get('parentCases'),
        tCase = cases && cases[iIndex],
        attr = this.getFirstParentAttribute(),
        caseAttrValue = tCase && attr && tCase.getStrValue(attr.get('id'));
    return !SC.empty(caseAttrValue) ? caseAttrValue : (iIndex + 1).toString();
  },

  getParentTooltip: function(iIndex) {
    return SC.String.loc('DG.NumberToggleView.indexTooltip');
  },

  /**
   * @property {Number}
   */
  numberOfParents: function() {
    return this.get('parentCases' ).length;
  }.property('parentCases'),

  /**
   * True if cases have parents
   * @property{Integer}
   */
  indicesRepresentChildren: function() {
    this.get('parentCases');
    return this._isHierarchical;
  }.property('numberOfParents'),

  /**
   * Return the number of indices that should be displayed
   * @property{Integer}
   */
  numberOfToggleIndices: function() {
    var dataConfiguration = this.get('dataConfiguration'),
      allCases = (dataConfiguration && dataConfiguration.get('allCases')),
      allCasesLength = allCases? allCases.length(): 0;
    if( this.get('indicesRepresentChildren'))
      return this.get('numberOfParents');
    else // There are no parents, so each case gets an index
      return allCasesLength;
  }.property(),
  numberOfToggleIndicesDidChange: function() {
    this.notifyPropertyChange('numberOfToggleIndices');
  }.observes('*dataConfiguration.allCases'),

  /**
   * Return the children of the parent with the given index.
   *
   * @param iIndex {Number}
   * @return {Array} of DG.Case
   */
  childrenOfParent: function( iIndex) {
    var tParents = this.get('parentCases' ),
        tParent = (iIndex < tParents.length) ? tParents[ iIndex] : null,
        tChildren = tParent ? tParent.get('children').slice() : [];
    // use for-loop since tChildren is modified recursively
    for (var i = 0; i < tChildren.get('length'); ++i) {
      var child = tChildren.objectAt(i),
          descendants = child.get('children');
      if (descendants && descendants.get('length')) {
        descendants.forEach(function(iCase) {
          tChildren.push(iCase);
        });
      }
    }
    return tChildren;
  },

  /**
   * @return{Boolean}
   */
  allCasesAreVisible: function() {
    var hiddenCases = this.get('hiddenCases');
    return !hiddenCases || !hiddenCases.length;
  },

  /*
   * For tracking whether we are in the process of making visibility changes.
   * Allows differential response to visibility changes caused by others.
   */
  _isChangingVisibility: 0,

  beginVisibilityChanges: function() {
    ++ this._isChangingVisibility;
  },

  endVisibilityChanges: function() {
    // use invokeLater() so notifications have a chance to propagate
    this.invokeLater(function() {
      -- this._isChangingVisibility;
    }.bind(this));
  },

  isChangingVisibility: function() {
    return this._isChangingVisibility > 0;
  },

  /**
   * If any cases are hidden, show them. Otherwise hide all cases
   *
   */
  changeAllCaseVisibility: function() {
    var tConfig = this.get('dataConfiguration' );
    this.beginVisibilityChanges();
    if( this.allCasesAreVisible()) {
      hideShowCases(tConfig, tConfig.get('cases'), false);
    }
    else {
      hideShowCases(tConfig, tConfig.get('hiddenCases'), true);
    }
    this.endVisibilityChanges();
  },

  getCasesForIndex: function(iIndex) {
    var tConfig = this.get('dataConfiguration'),
        tResultCases;

    if (this.get('indicesRepresentChildren')) {
      tResultCases = this.childrenOfParent(iIndex);
    }
    else {
      var tAllCases = tConfig ? tConfig.get('allCases') : [],
          tCasesArray = tAllCases ? tAllCases.slice() : [],
          tCase = (tCasesArray.length > iIndex) ? tCasesArray[iIndex] : null;
      tResultCases = tCase ? [tCase] : null;
    }
    return tResultCases;
  },

  /**
   * If any cases that are children of the parent with the given index are visible, hide them.
   * Otherwise, unhide all cases that are children of the parent with the given index.
   *
   * @param iIndex {Number}
   */
  toggleChildrenVisibility: function( iIndex) {
    var tChildren = this.childrenOfParent( iIndex ),
        tConfig = this.get('dataConfiguration');

    this.beginVisibilityChanges();
    hideShowCases(tConfig, tChildren, this.allChildrenAreHidden(iIndex));
    this.endVisibilityChanges();
  },

  /**
   * Whether we toggle visibility of children or a single parent depends what the indices represent
   * @param iIndex
   */
  toggleVisibility: function( iIndex) {
    if( this.get('indicesRepresentChildren')) {
      this.toggleChildrenVisibility( iIndex);
    }
    else {
      var tConfig = this.get('dataConfiguration'),
          tAllCasesArray = tConfig ? tConfig.get('allCases').slice() : [],
          tHidden = tConfig ? tConfig.get('hiddenCases' ) : [],
          tCase = (tAllCasesArray.length > iIndex) ? tAllCasesArray[iIndex] : null;
      this.beginVisibilityChanges();
      hideShowCases(tConfig, [tCase], tHidden.indexOf(tCase) >= 0);
      this.endVisibilityChanges();
    }
  },

  /**
   * Hide/show the children of the specified parent case
   * @param {Number}  iIndex - parent case index
   * @param {Boolean} iVisible - true to show; false to hide
   */
  setVisibility: function(iIndex, iVisible) {
    var tConfig = this.get('dataConfiguration'),
        tCasesToHideShow = this.getCasesForIndex(iIndex);

    if (tCasesToHideShow) {
      this.beginVisibilityChanges();
      hideShowCases(tConfig, tCasesToHideShow, iVisible);
      this.endVisibilityChanges();
    }
  },

  /**
   * Observer function for 'lastMode' changes
   * Enabling 'lastMode' hides all but the last parent case.
   * Disabling 'lastMode' exits the mode but doesn't change case visibility.
   */
  lastModeDidChange: function() {
    var lastMode = this.get('lastMode');
    if (lastMode) {
      this.showOnlyLastParentCase();
    }
  }.observes('lastMode'),

  /**
   * Show the last parent case and hide all the other parent cases.
   */
  showOnlyLastParentCase: function() {
    var toggleIndex, toggleCount = this.get('numberOfToggleIndices'),
        casesToHide = [], toggleCases;

    this.beginVisibilityChanges();

    // accumulate cases to hide so they can be hidden all at once
    for (toggleIndex = 0; toggleIndex < toggleCount - 1; ++toggleIndex) {
      toggleCases = this.getCasesForIndex(toggleIndex);
      // append toggleCases to casesToHide without duplicating any arrays
      toggleCases.reduce(reduceCase, casesToHide);
    }
    // hide all cases in one fell swoop
    if (casesToHide && casesToHide.length)
      hideShowCases(this.get('dataConfiguration'), casesToHide, false);
    // show the last parent case
    this.setVisibility(toggleIndex, true);

    this.endVisibilityChanges();
  },

  /**
   * Show the cases for the parents with the given indices and hide all others.
   * @param iParentIndices {[Number]}
   */
  maintainCurrentParentVisibility: function(iParentIndices) {
    var toggleIndex, toggleCount = this.get('numberOfToggleIndices'),
        casesToHide = [], toggleCases;

    this.beginVisibilityChanges();

    // accumulate cases to hide so they can be hidden all at once
    for (toggleIndex = 0; toggleIndex < toggleCount; ++toggleIndex) {
      if( iParentIndices.indexOf( toggleIndex) < 0) {
        toggleCases = this.getCasesForIndex(toggleIndex);
        // append toggleCases to casesToHide without duplicating any arrays
        toggleCases.reduce(reduceCase, casesToHide);
      }
    }
    // hide all cases in one fell swoop
    if (casesToHide && casesToHide.length)
      hideShowCases(this.get('dataConfiguration'), casesToHide, false);

    this.endVisibilityChanges();
  },

  /**
   *
   * @param iIndex
   * @return {Boolean}
   */
  allChildrenAreHidden: function( iIndex) {
    var tChildren = this.childrenOfParent( iIndex ),
        tPlotted = this.getPath('dataConfiguration.cases'),
        tHidden = this.get('hiddenCases'),
        tPlottedMap = {},
        tHiddenMap = {};

    // Note: Ideally, these maps should be cached, as they're currently being created for
    // each parent case independently, but figuring out the right time to invalidate the
    // caches is non-trivial, and so is left as a potential future optimization.

    // id map of all plotted cases (does not include cases not plotted due to missing values)
    (tPlotted || []).forEach(function(iCase) { tPlottedMap[iCase.get('id')] = true; });
    // id map of all hidden cases
    (tHidden || []).forEach(function(iCase) {
      if(iCase)
        tHiddenMap[iCase.get('id')] = true;
    });

    return !tChildren.some(function(iCase) {
                            var caseID = iCase.get('id');
                            // to be visible cases must be plotted and not hidden
                            return tPlottedMap[caseID] && !tHiddenMap[caseID];
                          });
  },

/**
   *
   * @param iIndex
   * @return {Boolean}
   */
  allChildrenAreVisible: function( iIndex) {
    var tChildren = this.childrenOfParent( iIndex ),
        tPlotted = this.getPath('dataConfiguration.cases'),
        tHidden = this.get('hiddenCases'),
        tPlottedMap = {},
        tHiddenMap = {};

    // Note: Ideally, these maps should be cached, as they're currently being created for
    // each parent case independently, but figuring out the right time to invalidate the
    // caches is non-trivial, and so is left as a potential future optimization.

    // id map of all plotted cases (does not include cases not plotted due to missing values)
    (tPlotted || []).forEach(function(iCase) { tPlottedMap[iCase.get('id')] = true; });
    // id map of all hidden cases
    (tHidden || []).forEach(function(iCase) {
      if(iCase)
        tHiddenMap[iCase.get('id')] = true;
    });

    return tChildren.every(function(iCase) {
                            var caseID = iCase.get('id');
                            // All children are visible if none are hidden
                            return !tHiddenMap[caseID];
                          });
  },

  /**
   * Depends on what indices represent
   * @param iIndex
   * @return {Boolean}
   */
  casesForIndexAreHidden: function( iIndex) {
    if( this.get('indicesRepresentChildren')) {
      return this.allChildrenAreHidden( iIndex);
    }
    else {
      var tConfig = this.get('dataConfiguration'),
          tAllCasesArray = tConfig ? tConfig.get('allCases').slice() : [],
          tHidden = tConfig ? tConfig.get('hiddenCases' ) : [],
          tCase = (tAllCasesArray.length > iIndex) ? tAllCasesArray[iIndex] : null;
      return( tHidden.indexOf( tCase) >= 0);
    }
  },

  /**
   * Note: returns true if no cases are hidden when there are no cases
   * @return {Boolean}
   */
  allCasesAreHidden: function() {
    return this.get('dataConfiguration' ).getCaseCount() === 0;
  },

  /**
   * Respond to shown/hidden cases
   */
  hiddenCasesDidChange: function() {
    // if user hides/shows cases via other means, exit lastMode
    if (this.get('lastMode') && !this.isChangingVisibility())
      this.set('lastMode', false);
  }.observes('hiddenCases'),

  /**
   * Return true if there is more than one parent and not all are marked to show children.
   * @return {{parentIndices [Integer]}}
   */
  shouldMaintainCurrentParentVisbility: function(ioResult) {
    var tToggleCount = this.get('numberOfToggleIndices') - 1,
        tNumberForWhichAllAreShowing = 0,
        tIndex = 0;
    ioResult.parentIndices = [];
    if( tToggleCount > 1) {
      while( tIndex < tToggleCount) {
        if( this.allChildrenAreVisible( tIndex)) {
          tNumberForWhichAllAreShowing++;
          ioResult.parentIndices.push( tIndex);
        }
        tIndex++;
      }
    }
    return tNumberForWhichAllAreShowing > 0 && tNumberForWhichAllAreShowing < tToggleCount;
  },

  isAffectedByChange: function(iChange) {

    function isRelevantChange(iChange) {
      var operations = ['createCollection', 'deleteCollection', 'moveCases', 'moveAttribute',
                          'createCases', 'createCase', 'deleteCases', 'createAttributes',
                          'updateAttributes', 'deleteAttributes'];
      return operations.indexOf(iChange.operation) >= 0;
    }

    var isToggleAttributeChange = function(iChange) {
      if (iChange.operation === 'updateCases') {
        var toggleAttr = this.getFirstParentAttribute(),
            toggleAttrID = toggleAttr && toggleAttr.get('id');
        if (iChange.attributeIDs) {
          if (iChange.attributeIDs.indexOf(toggleAttrID) >= 0)
            return true;
        }
      }
      return false;
    }.bind(this);

    return isRelevantChange(iChange) || isToggleAttributeChange(iChange);
  },

  /**
   * When the data context changes we notify
   */
  handleDataContextNotification: function(iNotifier, iChange) {
    var tIsCreateCase = iChange.operation.indexOf('createCase') === 0,
        tParentsToMaintain = { parentIndices: null };
    if (this.get('isEnabled')) {
      // if cases are created while in lastMode, ensure only last parent is visible
      if (this.get('lastMode') && tIsCreateCase) {
        this.invokeOnce(function() { this.showOnlyLastParentCase(); }.bind(this));
      }
      else if( tIsCreateCase && this.shouldMaintainCurrentParentVisbility( tParentsToMaintain)) {
        this.invokeOnce(function() { this.maintainCurrentParentVisibility(tParentsToMaintain.parentIndices); }.bind(this));
      }
      else if( this.isAffectedByChange(iChange)) {
        this.invalidate();
      }
    }
  }

};

})());

/* >>>>>>>>>> BEGIN source/components/graph/plots/number_toggle_view.js */
// ==========================================================================
//                            DG.NumberToggleView
//
// Shown when cases have more than one parent in order to provide an interface for hiding and showing
// cases belonging to a particular parent.
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('views/raphael_base');
sc_require('utilities/rendering_utilities');

/** @class  DG.NumberToggleView - The base class view for a graph legend.

  @extends DG.RaphaelBaseView
*/
DG.NumberToggleView = DG.RaphaelBaseView.extend(

  (function()
  {
    var kLabelFontFamily = 'Montserrat-Regular, sans-serif',
        kLabelFontSize = '11px',
        kCheckFontSize = '18px',
        kArrowWidth = 33,
      ArrowButton = SC.Object.extend({
        paper: null,
        url: null,
        depressedUrl: null,
        action: null,
        target: null,
        arrow: null,
        depressedArrow: null,
        _position: null,
        _state: null,
        kHeight: 19,

        init: function() {
          arguments.callee.base.apply(this,arguments);

          var tClickHandling = false,
              this_ = this;
          this._position = { x: 0, y: 0 };
          this.arrow = this.paper.image( this.url, 0, 0, kArrowWidth, this.kHeight)
            .hide()
            .attr( { cursor: 'pointer' })
            // Use mousedown/mouseup here rather than click so that touch will work
            .mousedown( function() {
              tClickHandling = true;
              this_._state = 'depressed';
              this_.show();
            });
          this.depressedArrow = this.paper.image( this.depressedUrl, 0, 0, kArrowWidth, this.kHeight)
            .hide()
            .mouseup( function() {
              if( tClickHandling && this_.action)
                this_.action.call( this_.target);
              tClickHandling = false;
              this_._state = 'normal';
              this_.show();
            } );
        },

          /**
           * @param {String} 'position'
           * @param { Object {x: {Number}, y: {Number}}
           */
        position: function( iKey, iValue) {
          if( iValue) {
            this._position = iValue;
            if( this.arrow)
              this.arrow.attr( this._position);
            if( this.depressedArrow)
              this.depressedArrow.attr( this._position);
          }
          return this._position;
        }.property(),

        show: function() {
          if( !this._state)
            this._state = 'normal';
          switch( this._state) {
            case 'normal':
              this.arrow.show();
              this.depressedArrow.hide();
              break;
            case 'depressed':
              this.depressedArrow.show();
              this.arrow.hide();
              break;
          }
          return this;
        },

        hide: function() {
          this.arrow.hide();
          this.depressedArrow.hide();
          return this;
        }
      }
    );

    /** @scope DG.NumberToggleView.prototype */
    return {

      displayProperties: ['lastMode', 'firstDisplayedIndex', 'lastDisplayedIndex'],

      classNames: 'dg-number-toggle'.w(),

      /**
        The model on which this view is based.
        @property { DG.NumberToggleModel }
      */
      model: null,

      isVisibleBinding: SC.Binding.oneWay('*model.isEnabled'),

      lastModeBinding: '*model.lastMode',

      layout: { left: 0, top: 0, right: 0, height: DG.RenderingUtilities.kCaptionFontHeight },

      /**
       * Zero unless there are more indices than fit in the space in which case it is the index of the leftmost
       * parent.
       * @property{Number}
       */
      firstDisplayedIndex: 0,

      /**
       * Normally the index of the last parent, but if the parent indices don't all fit, the index of the last
       * parent displayed. This gets precedence in display.
       * @property{Number}
       */
      lastDisplayedIndex: 0,

      _leftArrow: null,
      _rightArrow: null,

      /**
       * Lazy initialization of images since they may not be needed.
       * @property {ArrowButton}
       */
      leftArrow: function() {
        if( this._paper && !this._leftArrow ) {
          this._leftArrow = ArrowButton.create( { paper:this._paper, url: '../../../../static/dg/de/cert/source/resources/images/arrow_left.png',
            depressedUrl: '../../../../static/dg/de/cert/source/resources/images/arrow_left_depressed.png', action: this.scrollLeft, target: this } );
        }
        return this._leftArrow;
      }.property(),

      /**
       * Lazy initialization of images since they may not be needed.
       * @property {ArrowButton}
       */
      rightArrow: function() {
        if( this._paper && !this._rightArrow ) {
          this._rightArrow = ArrowButton.create( { paper:this._paper, url: '../../../../static/dg/de/cert/source/resources/images/arrow_right.png',
            depressedUrl: '../../../../static/dg/de/cert/source/resources/images/arrow_right_depressed.png', action: this.scrollRight, target: this } );
        }
        return this._rightArrow;
      }.property(),

      /**
       * We always just need room for one line of text. Return its height.
       *
        @property { Number }
      */
      desiredExtent: function() {
        return DG.RenderingUtilities.kCaptionFontHeight;
      }.property(),

      init: function() {
        arguments.callee.base.apply(this,arguments);
        this.lastDisplayedIndex = this.getPath('model.numberOfToggleIndices') - 1;
      },

      doDraw: function doDraw() {
        var toggleNumber = function( iElement) {
            DG.logUser( "Show parent: %@", iElement.toggleIndex + 1);
            SC.run(function() {
              this.set('lastMode', false);
              this.get('model').toggleVisibility(iElement.toggleIndex);
            }.bind(this));
          }.bind( this ),

          changeAllCaseVisibility = function() {
            var tModel = this.get('model');
            SC.run(function() {
              this.set('lastMode', false);
              tModel.changeAllCaseVisibility();
            }.bind(this));
            if( tModel.allCasesAreHidden())
              DG.logUser( "Hide all:");
            else
              DG.logUser( "Show all:");
          }.bind( this ),

          toggleLastMode = function() {
            SC.run(function() {
              var lastMode = this.get('lastMode');
              this.set('lastMode', !lastMode);
            }.bind(this));
          }.bind(this),

          createShowAllElement = function() {
            var tClickHandling = false,
                showHideAllLabel = tModel.allCasesAreVisible()
                                      ? 'DG.NumberToggleView.hideAll'.loc()
                                      : 'DG.NumberToggleView.showAll'.loc(),
                showHideAllTooltip = tModel.allCasesAreVisible()
                                        ? 'DG.NumberToggleView.hideAllTooltip'.loc()
                                        : 'DG.NumberToggleView.showAllTooltip'.loc(),
                kLeftMargin = 6;
            return this._paper.text(kLeftMargin, 0, showHideAllLabel)
                      .attr({ 'font-family': kLabelFontFamily, 'font-size': kLabelFontSize,
                              cursor: 'pointer', 'text-anchor': 'start',
                              fill: 'black', title: showHideAllTooltip })
                      // Use mousedown/mouseup here rather than click so that touch will work
                      .mousedown( function() {
                        tClickHandling = true;
                      })
                      .mouseup( function() {
                        if( tClickHandling)
                          changeAllCaseVisibility();
                        tClickHandling = false;
                      } );
          }.bind( this ),

          createLastElements = function() {
            var isLastMode = this.get('lastMode'),
                lastCheck = isLastMode
                              ? 'DG.NumberToggleView.lastChecked'.loc()
                              : 'DG.NumberToggleView.lastUnchecked'.loc(),
                lastLabel= 'DG.NumberToggleView.lastLabel'.loc(),
                lastTooltip = isLastMode
                                ? 'DG.NumberToggleView.disableLastModeTooltip'.loc()
                                : 'DG.NumberToggleView.enableLastModeTooltip'.loc(),
                tClickHandling = false,
                lastDashElt = this._paper.text(-9999, 0, 'DG.NumberToggleView.lastDash'.loc())
                                .attr({ 'font-family': kLabelFontFamily, 'font-size': kLabelFontSize,
                                        cursor: 'pointer', 'text-anchor': 'start', fill: 'black' }),
                checkElt = this._paper.text(-9999, 0, lastCheck)
                            .attr({ 'font-family': kLabelFontFamily, 'font-size': kCheckFontSize,
                                    cursor: 'pointer', 'text-anchor': 'start',
                                    fill: 'black', title: lastTooltip })
                        // Use mousedown/mouseup here rather than click so that touch will work
                        .mousedown(function() {
                          tClickHandling = true;
                        })
                        .mouseup(function() {
                          if (tClickHandling)
                            toggleLastMode();
                          tClickHandling = false;
                        }),
                lastElt = this._paper.text(-9999, 0, lastLabel)
                            .attr({ 'font-family': kLabelFontFamily, 'font-size': kLabelFontSize,
                                    cursor: 'pointer', 'text-anchor': 'start',
                                    fill: 'black', title: lastTooltip })
                        // Use mousedown/mouseup here rather than click so that touch will work
                        .mousedown(function() {
                          tClickHandling = true;
                        })
                        .mouseup(function() {
                          if (tClickHandling)
                            toggleLastMode();
                          tClickHandling = false;
                        });
            var lastElements = [lastDashElt, checkElt, lastElt];
            lastElements.forEach(function(elt) {
              elt.width = elt.getBBox().width;
            });
            return lastElements;
          }.bind(this),

          createNumberElements = function(lastElements) {
            // Create the number elements and stash their widths
            var tIndex, tClickHandling = false;

            function doMouseDown( iEvent) {
              tClickHandling = true;
            }

            function doMouseUp( iEvent) {
              if( tClickHandling)
                toggleNumber(this);
              tClickHandling = false;
            }

            var addElement = function(elt) {
              tNumberElements.push(elt);
              tTotalNumberWidth += elt.width + kSpace;
              this._elementsToClear.push(elt);
            }.bind(this);

            var tElement;
            for( tIndex = 0; tIndex < tNumParents; tIndex++ ) {
              var tLabel = tModel.getParentLabel(tIndex),
                  tTooltip = tModel.getParentTooltip(tIndex),
                  tFill = tModel.casesForIndexAreHidden( tIndex) ? 'lightGray' : 'black';
              tElement = this._paper.text(-9999, tY, tLabel)
                .attr({ 'font-family': kLabelFontFamily, 'font-size': kLabelFontSize,
                        cursor: 'pointer', 'text-anchor': 'start', fill: tFill, title: tTooltip })
                .mousedown( doMouseDown)
                .mouseup( doMouseUp);

              tElement.width = tElement.getBBox().width;  // Assigning new properties to Raphael element for convenience
              tElement.toggleIndex = tIndex;
              addElement(tElement);
            }
            // Put "Last" elements in array with number elements
            if (lastElements)
              lastElements.forEach(function(elt) { addElement(elt); });
          }.bind( this ),

          positionNumberElements = function() {
            var tX = tFirstX,
                tIndex, tLastIndex = tNumParents;
            if( tNeedLeftArrow) {
              tLeftArrow = this.get('leftArrow').show();
              tLeftArrow.set('position', { x: tX, y: 0 });
              tX += kArrowWidth;
            }
            else
              this.get('leftArrow' ).hide();

            for( tIndex = this.firstDisplayedIndex; tIndex <= this.lastDisplayedIndex; tIndex++) {
              tNumberElements[ tIndex].attr({ x: tX });
              tX += tNumberElements[ tIndex].width + kSpace;
            }

            if( tNeedRightArrow) {
              tRightArrow = this.get('rightArrow').show();
              tRightArrow.set('position', { x: tX - kSpace, y: 0 });
              tX += kArrowWidth;
            }
            else
              this.get('rightArrow' ).hide();

            for (var i = tLastIndex; i < tNumberElements.length; ++i) {
              if (tNumberElements[i]) {
                // adjust placement of checkbox
                var yOffset = i === tNumberElements.length - 2 ? -1 : 0;
                // adjust spacing between checkbox and "Last"
                if (i === tNumberElements.length - 1)
                  tX -= 5;
                tNumberElements[i].attr({ x: tX, y: tY + yOffset });
                tX += tNumberElements[i].width + kSpace;
              }
            }
          }.bind( this);

        // Start of doDraw
        if (!this.get('isVisible')) return;

        var kSpace = 5,
            tModel = this.get('model' ),
            tNumParents = tModel.get('numberOfToggleIndices' ),
            tNameElement = createShowAllElement(),
            tNameBox = tNameElement.getBBox(),
            tLastElements = createLastElements(),
            tY = 2 + tNameBox.height / 2,
            tFirstX = tNameBox.x + tNameBox.width + kSpace,
            tLastElementsWidth = tLastElements.reduce(function(sum, elt) {
                                                        return sum + elt.width + kSpace;
                                                      }, 0),
            tFixedSpace = tFirstX + kSpace + tLastElementsWidth + kSpace,
            tNumberDisplayWidth = this._paper.width - tFixedSpace,
            tNeedRightArrow, tNeedLeftArrow,
            tRightArrow, tLeftArrow,
            tNumberElements = [],
            tTotalNumberWidth = 0,
            tIndex, tCumWidth, tEltWidth;
        this._elementsToClear.push( tNameElement);
        if( !DG.isFinite(tFirstX) || !DG.isFinite(tY))
          return; // Apparently not ready to draw yet
        if( tY === 0) {
          // getBBox didn't return a valid value, so we try again later
          this.invokeLast( this.displayDidChange);
          return;
        }

        tNameElement.attr({ y: tY });

        createNumberElements(tLastElements);

        // In this block we compute tNeedLeftArrow, tNeedRightArrow, firstDisplayedIndex, and lastDisplayedIndex
        if( tTotalNumberWidth <= tNumberDisplayWidth) {
          tNeedRightArrow = tNeedLeftArrow = false;
          this.firstDisplayedIndex = 0;
          this.lastDisplayedIndex = tNumParents - 1;
        }
        else  {
          tNeedRightArrow = this.lastDisplayedIndex < tNumParents - 1;
          tNeedLeftArrow = true;  // assume we'll need it initially
          tCumWidth = kArrowWidth + (tNeedRightArrow ? kArrowWidth : 0);

          // fit as many as possible on the left
          tIndex = this.lastDisplayedIndex + 1;
          while( tIndex > 0) {
            tEltWidth = tNumberElements[tIndex-1].width + kSpace;
            if ((tCumWidth + tEltWidth < tNumberDisplayWidth) || (tIndex === this.lastDisplayedIndex + 1)) {
              tIndex--;
              tCumWidth += tEltWidth;
            }
            else break;
          }
          // would the rest fit without the left arrow?
          var i, tRemainingWidth = 0;
          for (i = 0; i < tIndex; ++i) {
            tRemainingWidth += tNumberElements[i].width + kSpace;
          }
          if (tCumWidth + tRemainingWidth - kArrowWidth < tNumberDisplayWidth) {
            tIndex = 0;
            tCumWidth += tRemainingWidth;
          }

          this.firstDisplayedIndex = tIndex;
          if (this.firstDisplayedIndex === 0) {
            tNeedLeftArrow = false;
            tCumWidth -= kArrowWidth;
          }

          // see if we can fit more on the right
          if (tNeedRightArrow) {
            tIndex = this.lastDisplayedIndex + 1;
            while( tIndex < tNumParents) {
              tEltWidth = tNumberElements[tIndex].width + kSpace;
              if (tCumWidth + tEltWidth < tNumberDisplayWidth) {
                this.lastDisplayedIndex = tIndex++;
                tCumWidth += tEltWidth;
              }
              else break;
            }
            // would the rest fit without the right arrow?
            tRemainingWidth = 0;
            for (i = this.lastDisplayedIndex + 1; i < tNumParents; ++i) {
              tRemainingWidth += tNumberElements[i].width + kSpace;
            }
            if (tCumWidth + tRemainingWidth - kArrowWidth < tNumberDisplayWidth) {
              this.lastDisplayedIndex = tNumParents - 1;
              tNeedRightArrow = false;
            }
          }

          // With certain label combinations it is possible to get stuck.
          // For example, when showing two short labels that just fit and scrolling
          // to the left would reveal a very long label that doesn't fit, the left
          // moving loop won't include the long label (because it doesn't fit), but
          // then the right moving loop will decide that there's room for the other
          // short label, leaving the user in their original state. This code
          // detects such situations by detecting when a scroll action results in
          // the same state as before the scroll, and forcibly scrolls in the
          // intended direction, even though the result may not fit.
          if (this._prevScroll && this._prevScroll.scrollBy &&
              (this.firstDisplayedIndex === this._prevScroll.first) &&
              (this.lastDisplayedIndex === this._prevScroll.last)) {
            if (this._prevScroll.scrollBy < 0) {
              -- this.firstDisplayedIndex;
              -- this.lastDisplayedIndex;
            }
            else {
              ++ this.firstDisplayedIndex;
              ++ this.lastDisplayedIndex;
            }
            tNeedLeftArrow = this.firstDisplayedIndex > 0;
            tNeedRightArrow = this.lastDisplayedIndex < tNumParents - 1;
          }
        }

        this._prevScroll = null;

        positionNumberElements();
      },  // end of doDraw

      /**
       * Left arrow has been pressed.
       * Decrement lastDisplayedIndex so that lower numbered indices will be displayed.
       * The amount to decrement by is the lesser of the firstDisplayedIndex or the difference between
       * the first and last displayed indices.
       */
      scrollLeft: function() {
        var tFirst = this.get('firstDisplayedIndex' ),
            tLast = this.get('lastDisplayedIndex' ),
            tRangeStep = (tLast - tFirst) || 1,
            tScrollBy = Math.min( tFirst, tRangeStep);
        this._prevScroll = { first: tFirst, last: tLast, scrollBy: -tScrollBy };
        this.decrementProperty( 'lastDisplayedIndex', tScrollBy);
      },

      /**
       * Right arrow has been pressed.
       * Increment lastDisplayedIndex so that higher numbered indices will be displayed.
       * The amount to increment by is the lesser of the number of undisplayed higher indices or the difference between
       * the first and last displayed indices.
       */
      scrollRight: function() {
        var tFirst = this.get('firstDisplayedIndex' ),
            tLast = this.get('lastDisplayedIndex' ),
            tRangeStep = (tLast - tFirst) || 1,
            tNumber = this.getPath('model.numberOfToggleIndices' ),
            tScrollBy = Math.min( tNumber - tLast - 1, tRangeStep);
        this._prevScroll = { first: tFirst, last: tLast, scrollBy: tScrollBy };
        this.incrementProperty( 'lastDisplayedIndex', tScrollBy);
      },

      /**
       * @return {Boolean}
       */
      shouldShow: function() {
        return this.getPath('model.isEnabled');
      },

      /**
       * If the case count changes we need to redisplay, but we can wait awhile
       */
      handleCaseCountChange: function() {
        this.set('lastDisplayedIndex', this.getPath('model.numberOfToggleIndices') - 1);
        this.displayDidChange();  // Use displayDidChange so that doDraw doesn't get called too often
      }.observes('model.caseCount'),

      /**
       * If the hidden cases change we need to redisplay, but we can wait awhile
       */
      handleHiddenCasesChange: function() {
        this.displayDidChange();
      }.observes('model.hiddenCases')

    };
  }()));


/* >>>>>>>>>> BEGIN source/components/graph/plots/plot_background_view.js */
// ==========================================================================
//                            DG.PlotBackgroundView
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/utilities/graph_drop_target');
sc_require('views/raphael_base');

/** @class  DG.PlotBackgroundView - The base class view for a plot.

  @extends DG.RaphaelBaseView
*/
DG.PlotBackgroundView = DG.RaphaelBaseView.extend(DG.GraphDropTarget,

    /** @scope DG.PlotBackgroundView.prototype */
    (function () {
      var marqueeInfo;

      return {
        autoDestroyProperties: ['_backgroundForClick'],

        displayProperties: [
          'xAxisView.model.lowerBound', 'xAxisView.model.upperBound', 'xAxisView.model.drawZeroLine',
          'yAxisView.model.lowerBound', 'yAxisView.model.upperBound', 'yAxisView.model.drawZeroLine',
          'xAxisView.model.attributeDescription.attributeStats.categoricalStats.numberOfCells',
          'yAxisView.model.attributeDescription.attributeStats.categoricalStats.numberOfCells',
          'graphModel.plotBackgroundColor', 'graphModel.plotBackgroundOpacity',
          'messages'
        ],

        classNames: 'dg-plot-view'.w(),
        classNameBindings: ['graphModel.isTransparent:dg-plot-view-transparent'],

        /**
         * @property {DG.GraphModel}
         */
        graphModel: null,

        /**
         @property { DG.AxisView}
         */
        xAxisView: null,
        /**
         @property { DG.AxisView }
         */
        yAxisView: null,

        /**
         * Which of the split plots do I correspond to?
         * @property (Number}
         */
        rowIndex: 0,

        /**
         * Which of the split plots do I correspond to?
         * @property (Number}
         */
        colIndex: 0,

        /**
         * Dynamically set to true/false during episodes such as marquee select
         * @property {Boolean}
         */
        tempDisallowDataTips: false,

        // Private properties
        _backgroundForClick: null,  // We make this once and keep it sized properly.

        _backgroundImage: null,

        /**
         * If true, darken the background slightly (useful for grid of plots)
         * @property {Boolean}
         */
        darkenBackground: false,

        /**
         * @property {string[]}
         */
        messages: null,
        /**
         * @private {element[]}
         */
        _messageElements: null,

        colorDidChange: function () {
          var tStoredColor = this.getPath('graphModel.plotBackgroundColor') || 'white',
              tStoredOpacity = this.getPath('graphModel.plotBackgroundOpacity'),
              tNewColor = tStoredColor ? SC.Color.from(tStoredColor) : null;
          if (!tNewColor)
            return;
          if (this.get('darkenBackground'))
            tNewColor = tNewColor.sub(SC.Color.from('#101010'));
          if (!SC.none(tStoredOpacity))
            tNewColor.set('a', tStoredOpacity);
          this.set('backgroundColor', tNewColor.get('cssText'));
        }.observes('.graphModel.plotBackgroundColor', '.graphModel.plotBackgroundOpacity'),

        backgroundImageDidChange: function () {
          var tImage = this.getPath('graphModel.plotBackgroundImage');
          if (tImage === null)
            tImage = '';
          if (this._backgroundImage.attr('src') !== tImage) {
            this._backgroundImage.attr('src', tImage);
          }
        }.observes('.graphModel.plotBackgroundImage'),

        /**
         * Additional setup after creating the view
         */
        didCreateLayer: function () {
          var tGraphView = this.get('parentView');
          arguments.callee.base.apply(this,arguments);
          tGraphView.getPlotViewArray(this.get('rowIndex'), this.get('colIndex')).forEach(function (iPlotView) {
            iPlotView.didCreateLayer();
          });
          tGraphView.drawPlots();
        },

        init: function () {
          arguments.callee.base.apply(this,arguments);
          this.set('backgroundColor', 'white');
          this.colorDidChange();
          this.messages = [];
          this._messageElements = [];
        },

        /**
         * Subclasses can override calling arguments.callee.base.apply(this,arguments) and then adding layers at will.
         */
        initLayerManager: function () {
          arguments.callee.base.apply(this,arguments);

          // if base class wasn't able to initialize the layer manager, e.g. because we
          // don't have paper yet, then this.get('layerManager') leads to an infinite loop.
          // For now, we avoid the infinite loop by testing the private _layerManager.
          if (!this._layerManager) return;

          var ln = DG.LayerNames;
          this.get('layerManager').addNamedLayer(ln.kBackgroundImage)
              .addNamedLayer(ln.kBackground)
              .addNamedLayer(ln.kGrid)
              .addNamedLayer(ln.kIntervalShading)
              .addNamedLayer(ln.kClick)
              .addNamedLayer(ln.kGhost)
              .addNamedLayer(ln.kConnectingLines)
              .addNamedLayer(ln.kPoints)
              .addNamedLayer(ln.kSelectedPoints)
              .addNamedLayer(ln.kAdornments)
              .addNamedLayer(ln.kDataTip)
              .addNamedLayer(ln.kCoverRects);

          this._backgroundImage = this._paper.image('', 0, 0, this._paper.width, this._paper.height);
          this.getPath('layerManager.' + DG.LayerNames.kBackgroundImage).push(this._backgroundImage);
        },

        prepareMarquee: function() {
          marqueeInfo = {
            this_: this,
            marquee: null,
            lastRect: null,
            startPt: null,
            needToDeselectAll: null,
            baseSelection: []
          };
        },

        startMarquee: function (iWindowX, iWindowY, iEvent, iDontDeselect) {
          if (iEvent.altKey)
            return; // Alt key has a different meaning
          marqueeInfo.needToDeselectAll = true;
          marqueeInfo.this_.set('tempDisallowDataTips', true);

          if (iEvent.shiftKey || iDontDeselect) {
            marqueeInfo.baseSelection = marqueeInfo.this_.getPath('graphModel.selection').toArray();

            marqueeInfo.needToDeselectAll = false;
          }
          // Only deselect everything if we are the currently selected component
          else if (DG.ComponentView.isComponentViewForViewSelected(marqueeInfo.this_)) {
            marqueeInfo.needToDeselectAll = false;
            SC.run(function () {
              marqueeInfo.this_.get('graphModel').selectAll(false);
            });
          }
          marqueeInfo.startPt = DG.ViewUtilities.windowToViewCoordinates(
              {x: iWindowX, y: iWindowY}, marqueeInfo.this_);
          marqueeInfo.marquee = marqueeInfo.this_._paper.rect(marqueeInfo.startPt.x, marqueeInfo.startPt.y, 0, 0)
              .attr({
                fill: DG.PlotUtilities.kMarqueeColor,
                stroke: DG.RenderingUtilities.kTransparent
              });
          marqueeInfo.lastRect = {x: marqueeInfo.startPt.x, y: marqueeInfo.startPt.y, width: 0, height: 0};
          marqueeInfo.this_.getPath('layerManager.' + DG.LayerNames.kAdornments).push(marqueeInfo.marquee);
          marqueeInfo.this_.get('parentView').prepareToSelectPoints();
          return marqueeInfo.startPt; // So it can be adjusted if necessary
        },

        continueMarquee: function (idX, idY) {
          if (SC.none(marqueeInfo.marquee))
            return; // Alt key was down when we started
          var tX = (idX > 0) ? marqueeInfo.startPt.x : marqueeInfo.startPt.x + idX,
              tY = (idY > 0) ? marqueeInfo.startPt.y : marqueeInfo.startPt.y + idY,
              tWidth = Math.abs(idX),
              tHeight = Math.abs(idY),
              tRect = {x: tX, y: tY, width: tWidth, height: tHeight};
          marqueeInfo.marquee.attr(tRect);
          if (marqueeInfo.needToDeselectAll) {
            SC.run(function () {  // Needs to be in a run loop because invokeLast will be called
              marqueeInfo.this_.get('graphModel').selectAll(false);
              marqueeInfo.needToDeselectAll = false;
            });
          }
          SC.run(function () {
            marqueeInfo.this_.get('parentView').selectPointsInRect(tRect, marqueeInfo.baseSelection, marqueeInfo.lastRect,
                marqueeInfo.this_.get('rowIndex'), marqueeInfo.this_.get('colIndex'));
          });
          marqueeInfo.lastRect = tRect;
        },

        endMarquee: function (idX, idY) {
          marqueeInfo.this_.set('tempDisallowDataTips', false);

          if (SC.none(marqueeInfo.marquee))
            return; // Alt key was down when we started

          marqueeInfo.this_.getPath('layerManager').removeElement(marqueeInfo.marquee, true);
          marqueeInfo.marquee = null;
          marqueeInfo.baseSelection = [];

          var tNumCases = marqueeInfo.this_.getPath('graphModel.casesController.selection.length');
          if (tNumCases > 0)  // We must have something > 0
            DG.logUser("marqueeSelection: %@", tNumCases);
          SC.run(function () {
            marqueeInfo.this_.get('parentView').completeSelection();
          });
        },

        /**
         We just have the background to draw. But it has a marquee behavior and a background click
         behavior to install.
         */
        doDraw: function doDraw() {
          var this_ = this,
              tFrame = this.get('frame'),
              tXAxisView = this.get('xAxisView'),
              tYAxisView = this.get('yAxisView'),
              tDrawXZeroLine = tXAxisView.getPath('model.drawZeroLine'),
              tDrawYZeroLine = tYAxisView.getPath('model.drawZeroLine'),
              tBackgroundLayer = this.getPath('layerManager.' + DG.LayerNames.kBackground),
              tGridLayer = this.getPath('layerManager.' + DG.LayerNames.kGrid),
              tBothWaysNumeric = (tXAxisView.get('isNumeric') && tYAxisView.get('isNumeric')),
              tY2AttributeID = this.getPath('graphModel.dataConfiguration.y2AttributeID'),
              tHasY2Attribute = tY2AttributeID && (tY2AttributeID !== DG.Analysis.kNullAttribute);

          function updateBackgroundImage() {
            if (!this_._paper)
              return; // not yet ready
            var tBackgroundImage = this_.getPath('graphModel.plotBackgroundImage'),
                tLockInfo = this_.getPath('graphModel.plotBackgroundImageLockInfo');
            if (tBackgroundImage === null)
              tBackgroundImage = '';
            if (this_._backgroundImage.attr('src') !== tBackgroundImage) {
              this_._backgroundImage.attr('src', tBackgroundImage);
            }
            if (tLockInfo && tLockInfo.locked) {
              var tXAxisView = this_.get('xAxisView'),
                  tYAxisView = this_.get('yAxisView'),
                  tLeft = tXAxisView.dataToCoordinate(tLockInfo.xAxisLowerBound),
                  tRight = tXAxisView.dataToCoordinate(tLockInfo.xAxisUpperBound),
                  tTop = tYAxisView.dataToCoordinate(tLockInfo.yAxisUpperBound),
                  tBottom = tYAxisView.dataToCoordinate(tLockInfo.yAxisLowerBound);
              this_._backgroundImage.attr({
                x: tLeft, y: tTop,
                width: tRight - tLeft, height: tBottom - tTop
              });
            }
            else {
              this_._backgroundImage.attr({width: this_._paper.width, height: this_._paper.height});
            }
          }

          function createRulerLines() {

            function vLine(iX, iColor, iWidth) {
              tGridLayer.push(
                  this_._paper.line(iX, tFrame.height, iX, 0)
                      .attr({stroke: iColor, 'stroke-width': iWidth}));
            }

            function hLine(iY, iColor, iWidth) {
              tGridLayer.push(
                  this_._paper.line(0, iY, tFrame.width, iY)
                      .attr({stroke: iColor, 'stroke-width': iWidth}));
            }

            function drawVRule(iValue, iX) {
              vLine(iX, DG.PlotUtilities.kRuleColor, DG.PlotUtilities.kRuleWidth);
            }

            function drawHRule(iValue, iY) {
              hLine(iY, DG.PlotUtilities.kRuleColor, DG.PlotUtilities.kRuleWidth);
            }

            function drawZeroLines(iDrawXLine, iDrawYLine, iColor) {

              function drawLine(iAxisView, iDrawingFunc) {
                var tZeroCoord = iAxisView.get('zeroPixel'),
                    tColor = iColor || DG.PlotUtilities.kZeroLineColor;
                if ((tZeroCoord != null) && !iAxisView.get('isDateTime'))
                  iDrawingFunc(tZeroCoord, tColor, DG.PlotUtilities.kZeroLineWidth);
              }

              iDrawXLine && drawLine(tXAxisView, vLine);
              iDrawYLine && drawLine(tYAxisView, hLine);
            }

            if (tBothWaysNumeric) {
              tXAxisView.forEachTickDo(drawVRule);
              if (!tHasY2Attribute)
                tYAxisView.forEachTickDo(drawHRule);
              drawZeroLines(true, true);
            } // else suppress numeric grid lines for dot plots (numeric only on one axis), because it interferes with mean/median lines, etc.
            else if (tDrawXZeroLine || tDrawYZeroLine) {
              drawZeroLines(tDrawXZeroLine, tDrawYZeroLine, DG.PlotUtilities.kRuleColor);
            }
          } // createRulerLines

          function showCursor(iEvent) {
            if (iEvent.altKey) {
              var magnifyPlusCursorUrl = '../../../../static/dg/de/cert/resources/cursors/MagnifyPlus.cur',
                  magnifyMinusCursorUrl = '../../../../static/dg/de/cert/resources/cursors/MagnifyMinus.cur',
                  cursorUrl = iEvent.shiftKey ? magnifyMinusCursorUrl : magnifyPlusCursorUrl;
              this.attr({cursor: DG.Browser.customCursorStr(cursorUrl, 8, 8)});
            }
            else
              this.attr({cursor: 'auto'});
          }

          /*
              function destroyZoomTip() {
                if( tToolTip) {
                  tToolTip.hide();
                  tToolTip.destroy();
                  tToolTip = null;
                }
              }
          */

          /*
              function mouseOver( iEvent) {
                if( !tHaveShowZoomTip) {
                  var tZoomTipText = 'DG.GraphView.zoomTip'.loc();
                  tToolTip = DG.ToolTip.create( { paperSource: this_,
                                                      text: tZoomTipText,
                                                      tipOrigin: {x: iEvent.layerX, y: iEvent.layerY},
                      layerName: 'dataTip' });
                  tToolTip.show();
                  tHaveShowZoomTip = true;
                  this_.invokeLater( destroyZoomTip, 5000);
                }
              }
          */

          var drawCellBands = function () {
            var tPaper = this.get('paper'),
                tXView = this.get('xAxisView'),
                tAllowVertical = tXView.get('allowCellBoundaries'),
                tYView = this.get('yAxisView'),
                tAllowHorizontal = tYView.get('allowCellBoundaries'),
                tNumXCells = tXView.getPath('model.numberOfCells'),
                tNumYCells = tYView.getPath('model.numberOfCells'),
                tXCellWidth = tXView.get('fullCellWidth'),
                tYCellWidth = tYView.get('fullCellWidth'),
                kIgnoreDragging = true,
                tIndex,
                tXCoord, tYCoord, tLeft, tTop;
            if (SC.none(tPaper))
              return;

            var drawVerticalLines = function () {
                  var tHeight = tYCellWidth * tNumYCells;
                  tYCoord = tYView.cellToCoordinate(tNumYCells - 1);
                  tTop = tYCoord - tYCellWidth / 2;
                  for (tIndex = 1; tIndex < tNumXCells; tIndex++) {
                    var tLine;
                    tXCoord = tXView.cellToCoordinate(tIndex, kIgnoreDragging);
                    tLeft = tXCoord - tXCellWidth / 2;
                    tLine = tPaper.line(tLeft, tTop, tLeft, tTop + tHeight);
                    tBackgroundLayer.push(
                        tLine.attr({stroke: DG.PlotUtilities.kRuleColor, 'stroke-width': 1}));
                  }
                }.bind(this),

                drawHorizontalLines = function () {
                  var tWidth = tXCellWidth * tNumXCells;
                  tXCoord = tXView.cellToCoordinate(0);
                  tLeft = tXCoord - tXCellWidth / 2;
                  for (tIndex = 1; tIndex < tNumYCells; tIndex++) {
                    var tLine;
                    tYCoord = tYView.cellToCoordinate(tIndex, kIgnoreDragging);
                    tTop = tYCoord - tYCellWidth / 2;
                    tLine = tPaper.line(tLeft, tTop + tYCellWidth, tLeft + tWidth, tTop + tYCellWidth);
                    tBackgroundLayer.push(
                        tLine.attr({stroke: DG.PlotUtilities.kRuleColor, 'stroke-width': 1}));
                  }
                }.bind(this);
            if (tAllowVertical)
              drawVerticalLines();
            if (tAllowHorizontal)
              drawHorizontalLines();

          }.bind(this); // drawCellBands

          function startMarquee(iWindowX, iWindowY, iEvent) {
            this_.prepareMarquee();
            this_.startMarquee(iWindowX, iWindowY, iEvent);
          }

          tGridLayer.clear();
          tBackgroundLayer.clear();

          updateBackgroundImage();

          createRulerLines();

          drawCellBands();

          this.displayMessages();

          if (SC.none(this._backgroundForClick)) {
            this._backgroundForClick = this.getPath('layerManager.' + DG.LayerNames.kClick).push(
                this._paper.rect(0, 0, 0, 0)
                    .attr({
                      fill: DG.RenderingUtilities.kSeeThrough,
                      stroke: DG.RenderingUtilities.kTransparent
                    })
                    .click(function (iEvent) {
                      this_.get('parentView').handleBackgroundClick(iEvent);
                    })
                    .dblclick(function (iEvent) {
                      this_.get('parentView').handleBackgroundDblClick(iEvent);
                    })
                    .drag(this_.continueMarquee, startMarquee, this_.endMarquee)
                    .mousemove(showCursor)
                // The mouseover hint is annoying, and probably not useful.
                /*.mouseover( mouseOver)*/);
          }

          this._backgroundForClick.attr({
            width: this.get('drawWidth'),
            height: this.get('drawHeight')
          });

        },

        // We override to customize our dropHintString based on whether there are attributes or not
        dragStarted: function (iDrag) {
          // Call our mixin method first because it sets dropHintString
          DG.GraphDropTarget.dragStarted.call(this, iDrag);

          // Override mixin's setting
          var tDataConfig = this.getPath('graphModel.dataConfiguration'),
              tIsNotEmpty = tDataConfig && (tDataConfig.get('xAttributeID') ||
                  tDataConfig.get('yAttributeID') || tDataConfig.get('legendAttributeID')),
              tHintString = (tIsNotEmpty ? 'DG.GraphView.dropInPlot' : 'DG.GraphView.addToEmptyX')
                  .loc(iDrag.data.attribute.get('name'));
          this.set('dropHintString', tHintString);
        },

        /**
         * Display the given strings centered
         * @param iMessages {string[]}
         */
        displayMessages: function() {
          var tMessages = this.get('messages'),
              tNumStrings = tMessages.length,
              tPaper = this.get('paper'),
              tMessageElements = this._messageElements;

          function removeExistingMessageElements() {
            tMessageElements.forEach( function( iElement) {
              tLayer.prepareToMoveOrRemove(iElement);
              iElement.remove();
            });
          }

          if( !tPaper)
            return;
          var tLayer = this.getPath('layerManager.' + DG.LayerNames.kDataTip);
          removeExistingMessageElements();
          if( tNumStrings > 0) {
            var tMsg = tPaper.text(0, 0, tMessages[0]);
            tMsg.attr('font-size', 12);
            var tTextHeight = DG.RenderingUtilities.getExtentForTextElement(tMsg).height,
                tY = (tPaper.height - tNumStrings * tTextHeight) / 2;
            tMsg.remove();
            tMessages.forEach(function (iMsg, iIndex) {
              var tText = tPaper.text(tPaper.width / 2, tY + iIndex * tTextHeight, iMsg);
              tText.attr('font-size', 12);
              tLayer.push(tText);
              tMessageElements.push(tText);
            });
          }
        }

      }; // object returned closure
    }()) // function closure
);

/* >>>>>>>>>> BEGIN source/components/graph/plots/scatter_plot_model.js */
// ==========================================================================
//                        DG.ScatterPlotModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/plots/plot_model');
sc_require('components/graph/plots/numeric_plot_model_mixin');

/** @class  DG.ScatterPlotModel

 @extends DG.PlotModel
 */
DG.ScatterPlotModel = DG.PlotModel.extend(DG.NumericPlotModelMixin,
    /** @scope DG.ScatterPlotModel.prototype */
    {
      /**
       *
       * @param iPlace {DG.GraphTypes.EPlace}
       * @return { class }
       */
      getDesiredAxisClassFor: function( iPlace) {
        if( iPlace === DG.GraphTypes.EPlace.eX || iPlace === DG.GraphTypes.EPlace.eY)
          return DG.CellLinearAxisModel;
        else if(iPlace === DG.GraphTypes.EPlace.eY2) {
          return (this.getPath('dataConfiguration.y2AttributeID') === DG.Analysis.kNullAttribute) ?
              DG.AxisModel : DG.CellLinearAxisModel;
        }
      },

      /**
       @property { DG.MovablePointModel }
       */
      movablePoint: null,

      /**
       @property { Boolean }
       */
      isMovablePointVisible: function () {
        return !SC.none(this.movablePoint) && this.movablePoint.get('isVisible');
      }.property(),
      isMovablePointVisibleDidChange: function() {
        this.notifyPropertyChange('isMovablePointVisible');
      }.observes('*movablePoint.isVisible'),

      /**
       @property { DG.MovableLineModel }
       */
      movableLine: null,

      /**
       @property { Boolean, read only }
       */
      isMovableLineVisible: function () {
        return !SC.none(this.movableLine) && this.movableLine.get('isVisible');
      }.property(),
      isMovableLineVisibleDidChange: function() {
        this.notifyPropertyChange('isMovableLineVisible');
      }.observes('*movableLine.isVisible'),

      /**
       @property { DG.MultipleLSRLsModel }
       */
      multipleLSRLs: null,

      /**
       @property { Boolean, read only }
       */
      isLSRLVisible: function () {
        return !SC.none(this.multipleLSRLs) && this.multipleLSRLs.get('isVisible');
      }.property(),
      isLSRLVisibleDidChange: function() {
        this.notifyPropertyChange('isLSRLVisible');
      }.observes('*multipleLSRLs.isVisible'),

      /**
       @property { Boolean }
       */
      isInterceptLocked: function ( iKey, iValue) {
        if( !SC.none( iValue)) {
          this.setPath('movableLine.isInterceptLocked', iValue);
          this.setPath('multipleLSRLs.isInterceptLocked', iValue);
        }
        return !SC.none(this.movableLine) && this.movableLine.get('isInterceptLocked') ||
            !SC.none(this.multipleLSRLs) && this.multipleLSRLs.get('isInterceptLocked');
      }.property(),
      isInterceptLockedDidChange: function() {
        this.notifyPropertyChange('isInterceptLocked');
      }.observes('*movableLine.isInterceptLocked', '*multipleLSRLs.isInterceptLocked'),

      /**
       @property { Boolean }
       */
      areSquaresVisible: false,

      /**
       * Used for notification
       * @property{}
       */
      squares: null,

      init: function() {
        arguments.callee.base.apply(this,arguments);
        this.addObserver('movableLine.slope',this.lineDidChange);
        this.addObserver('movableLine.intercept',this.lineDidChange);
      },

      destroy: function() {
        this.removeObserver('movableLine.slope',this.lineDidChange);
        this.removeObserver('movableLine.intercept',this.lineDidChange);
        arguments.callee.base.apply(this,arguments);
      },

      dataConfigurationDidChange: function() {
        arguments.callee.base.apply(this,arguments);
        var tDataConfiguration = this.get('dataConfiguration');
        if( tDataConfiguration) {
          tDataConfiguration.set('sortCasesByLegendCategories', false);
          // This is a cheat. The above line _should_ bring this about, but I couldn't make it work properly
          tDataConfiguration.invalidateCaches();
        }
      }.observes('dataConfiguration'),

      /**
       Returns true if the plot is affected by the specified change such that
       a redraw is required, false otherwise.
       @param    {Object}    iChange -- The change request to/from the DataContext
       @returns  {Boolean}   True if the plot must redraw, false if it is unaffected
       */
      isAffectedByChange: function (iChange) {
        if (!iChange || !iChange.operation) return false;
        return arguments.callee.base.apply(this,arguments) ||
            (this.isAdornmentVisible('connectingLine') &&
                (iChange.operation === 'moveAttribute' || iChange.operation === 'moveCases'));
      },

      /**
       * Used for notification
       */
      lineDidChange: function () {
        SC.run(function() {
          this.notifyPropertyChange('squares');
        }.bind(this));
      },

      /**
       * Utility function to create a movable line when needed
       */
      createMovablePoint: function () {
        if (SC.none(this.movablePoint)) {
          this.beginPropertyChanges();
          this.set('movablePoint', DG.MovablePointModel.create( {
            plotModel: this
          }));
          this.movablePoint.recomputeCoordinates(this.get('xAxis'), this.get('yAxis'));
          this.endPropertyChanges();
        }
      },

      /**
       * Utility function to create a movable line when needed
       */
      createMovableLine: function () {
        if (SC.none(this.movableLine)) {
          this.beginPropertyChanges();
          this.set('movableLine', DG.MovableLineModel.create( {
            plotModel: this,
            showSumSquares: this.get('areSquaresVisible')
          }));
          this.movableLine.recomputeSlopeAndIntercept(this.get('xAxis'), this.get('yAxis'));
          this.endPropertyChanges();
        }
      },

      squaresVisibilityChanged: function() {
        var tMovableLine = this.get('movableLine'),
            tMultipleLSRLs = this.get('multipleLSRLs'),
            tSquaresVisible = this.get('areSquaresVisible');
        if( tMovableLine)
            tMovableLine.set('showSumSquares', tSquaresVisible);
        if( tMultipleLSRLs)
            tMultipleLSRLs.set('showSumSquares', tSquaresVisible);
      }.observes('areSquaresVisible'),

      enableMeasuresForSelectionDidChange: function(){
        arguments.callee.base.apply(this,arguments);
        this.setPath('multipleLSRLs.enableMeasuresForSelection', this.get('enableMeasuresForSelection'));
      }.observes('enableMeasuresForSelection'),

      /**
       If we need to make a movable line, do so. In any event toggle its visibility.
       */
      toggleMovablePoint: function () {
        var this_ = this;

        function toggle() {

          function doToggle( iPlot) {
            if (SC.none(iPlot.movablePoint)) {
              iPlot.createMovablePoint(); // Default is to be visible
            }
            else {
              iPlot.movablePoint.recomputePositionIfNeeded(iPlot.get('xAxis'), iPlot.get('yAxis'));
              iPlot.movablePoint.set('isVisible', !iPlot.movablePoint.get('isVisible'));
            }
          }

          doToggle( this_);
          this_.get('siblingPlots').forEach( doToggle);
        }

        var willShow = !this.movablePoint || !this.movablePoint.get('isVisible');
        DG.UndoHistory.execute(DG.Command.create({
          name: "graph.toggleMovablePoint",
          undoString: (willShow ? 'DG.Undo.graph.showMovablePoint' : 'DG.Undo.graph.hideMovablePoint'),
          redoString: (willShow ? 'DG.Redo.graph.showMovablePoint' : 'DG.Redo.graph.hideMovablePoint'),
          log: "toggleMovablePoint: %@".fmt(willShow ? "show" : "hide"),
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'toggle movable point',
              type: 'DG.GraphView'
            }
          },
          execute: function () {
            toggle();
          },
          undo: function () {
            toggle();
          }
        }));
      },

      /**
       If we need to make a movable line, do so. In any event toggle its visibility.
       */
      toggleMovableLine: function () {
        var this_ = this;

        function toggle() {

          function doToggle(iPlot) {
            if (SC.none(iPlot.movableLine)) {
              iPlot.createMovableLine(); // Default is to be visible
            }
            else {
              iPlot.movableLine.recomputeSlopeAndInterceptIfNeeded(iPlot.get('xAxis'), iPlot.get('yAxis'));
              iPlot.movableLine.set('isVisible', !iPlot.movableLine.get('isVisible'));
            }
          }

          doToggle( this_);
          this_.get('siblingPlots').forEach( doToggle);
        }

        var willShow = !this.movableLine || !this.movableLine.get('isVisible');
        DG.UndoHistory.execute(DG.Command.create({
          name: "graph.toggleMovableLine",
          undoString: (willShow ? 'DG.Undo.graph.showMovableLine' : 'DG.Undo.graph.hideMovableLine'),
          redoString: (willShow ? 'DG.Redo.graph.showMovableLine' : 'DG.Redo.graph.hideMovableLine'),
          log: "toggleMovableLine: %@".fmt(willShow ? "show" : "hide"),
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'toggle movable line',
              type: 'DG.GraphView'
            }
          },
          execute: function () {
            toggle();
          },
          undo: function () {
            toggle();
          }
        }));
      },

      /**
       * Utility function to create the multipleLSRLs object when needed
       */
      createLSRLLines: function () {
        if (SC.none(this.multipleLSRLs)) {
          this.set('multipleLSRLs', DG.MultipleLSRLsModel.create( {
            plotModel: this,
            showSumSquares: this.get('areSquaresVisible'),
            isInterceptLocked: this.get('isInterceptLocked'),
            enableMeasuresForSelection: this.get('enableMeasuresForSelection')
          }));
          this.setPath('multipleLSRLs.isVisible', true);
        }
      },

      /**
       If we need to make a movable line, do so. In any event toggle its visibility.
       */
      toggleLSRLLine: function () {
        var this_ = this;

        function toggle() {

          function doToggle( iPlot) {
            if (SC.none(iPlot.get('multipleLSRLs'))) {
              iPlot.createLSRLLines();
            }
            else {
              iPlot.setPath('multipleLSRLs.isVisible', !iPlot.getPath('multipleLSRLs.isVisible'));
            }
          }

          doToggle( this_);
          this_.get('siblingPlots').forEach( doToggle);
        }

        var willShow = !this.multipleLSRLs || !this.multipleLSRLs.get('isVisible');
        DG.UndoHistory.execute(DG.Command.create({
          name: "graph.toggleLSRLLine",
          undoString: (willShow ? 'DG.Undo.graph.showLSRL' : 'DG.Undo.graph.hideLSRL'),
          redoString: (willShow ? 'DG.Redo.graph.showLSRL' : 'DG.Redo.graph.hideLSRL'),
          log: "toggleLSRL: %@".fmt(willShow ? "show" : "hide"),
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'toggle LSRL',
              type: 'DG.GraphView'
            }
          },
          execute: function () {
            toggle();
          },
          undo: function () {
            toggle();
          }
        }));
      },

      /**
       If we need to make a movable line, do so. In any event toggle whether its intercept is locked.
       */
      toggleInterceptLocked: function () {
        var this_ = this;

        function toggle() {

          function doToggle( iPlot) {
            if (!SC.none(iPlot.movableLine)) {
              iPlot.movableLine.toggleInterceptLocked();
              iPlot.movableLine.recomputeSlopeAndInterceptIfNeeded(iPlot.get('xAxis'), iPlot.get('yAxis'));
            }
            if (!SC.none(iPlot.multipleLSRLs)) {
              iPlot.multipleLSRLs.toggleInterceptLocked();
            }
          }

          doToggle( this_);
          this_.get('siblingPlots').forEach( doToggle);
        }

        function gatherUndoData() {

          function doGatherUndoData( iPlot) {
            tResult.push( {
              movableLine: iPlot.movableLine ? iPlot.movableLine.createStorage() : null,
              lsrlStorage: iPlot.multipleLSRLs ? iPlot.multipleLSRLs.createStorage() : null
            });
          }

          var tResult = [];
          doGatherUndoData( this_);
          this_.get('siblingPlots').forEach( doGatherUndoData);
          return tResult;
        }

        function restoreFromUndoData( iUndoData) {

          function doRestoreFromUndoData( iPlot, iIndexMinusOne) {
            var tUndoData = iUndoData[ iIndexMinusOne + 1];
            if( iPlot.movableLine)
              iPlot.movableLine.restoreStorage(tUndoData.movableLine);
            if( iPlot.multipleLSRLs)
              iPlot.multipleLSRLs.restoreStorage(tUndoData.lsrlStorage);
          }

          doRestoreFromUndoData( this_, -1);
          this_.get('siblingPlots').forEach( doRestoreFromUndoData);
        }

        var willLock = (this.movableLine && !this.movableLine.get('isInterceptLocked')) ||
                      (this.multipleLSRLs && !this.multipleLSRLs.get('isInterceptLocked'));
        DG.UndoHistory.execute(DG.Command.create({
          name: "graph.toggleLockIntercept",
          undoString: (willLock ? 'DG.Undo.graph.lockIntercept' : 'DG.Undo.graph.unlockIntercept'),
          redoString: (willLock ? 'DG.Redo.graph.lockIntercept' : 'DG.Redo.graph.unlockIntercept'),
          log: "lockIntercept: %@".fmt(willLock),
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'toggle lock intercept',
              type: 'DG.GraphView'
            }
          },
          execute: function () {
            this._undoData = gatherUndoData();
            toggle();
          },
          undo: function () {
            restoreFromUndoData( this._undoData);
            this._undoData = null;
          }
        }));
      },

      /**
       If we need to make a plotted function, do so. In any event toggle its visibility.
       */
      togglePlotFunction: function () {
        var this_ = this;

        function toggle() {

          function doToggle( iPlot) {
            iPlot.toggleAdornmentVisibility('plottedFunction', 'togglePlotFunction');
          }

          this_.get('siblingPlots').forEach( doToggle);
          doToggle( this_);
        }

        function connectFunctions() {
          var tSiblingPlots = this_.get('siblingPlots'),
              tMasterPlottedFunction = this_.getAdornmentModel('plottedFunction');
          tMasterPlottedFunction.set('siblingPlottedFunctions',
              tSiblingPlots.map( function( iPlot) {
                return iPlot.getAdornmentModel( 'plottedFunction');
              }));
        }

        var willShow = !this.isAdornmentVisible('plottedFunction');
        DG.UndoHistory.execute(DG.Command.create({
          name: "graph.togglePlotFunction",
          undoString: (willShow ? 'DG.Undo.graph.showPlotFunction' : 'DG.Undo.graph.hidePlotFunction'),
          redoString: (willShow ? 'DG.Redo.graph.showPlotFunction' : 'DG.Redo.graph.hidePlotFunction'),
          log: "togglePlotFunction: %@".fmt(willShow ? "show" : "hide"),
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'toggle plot function',
              type: 'DG.GraphView'
            }
          },
          execute: function () {
            toggle();
            connectFunctions();
          },
          undo: function () {
            toggle();
            this_.getAdornmentModel('plottedFunction').set('siblingPlottedFunctions', null);
          }
        }));
      },

      /**
       If we need to make a connecting line, do so. In any event toggle its visibility.
       */
      toggleConnectingLine: function () {
        var this_ = this;

        function toggle() {

          function doToggle( iPlot) {
            var tAdornModel = iPlot.toggleAdornmentVisibility('connectingLine', 'toggleConnectingLine');
            if (tAdornModel && tAdornModel.get('isVisible'))
              tAdornModel.recomputeValue(); // initialize
          }

          doToggle( this_);
          this_.get('siblingPlots').forEach( doToggle);
        }

        var willShow = !this.isAdornmentVisible('connectingLine');
        DG.UndoHistory.execute(DG.Command.create({
          name: "graph.toggleConnectingLine",
          undoString: (willShow ? 'DG.Undo.graph.showConnectingLine' : 'DG.Undo.graph.hideConnectingLine'),
          redoString: (willShow ? 'DG.Redo.graph.showConnectingLine' : 'DG.Redo.graph.hideConnectingLine'),
          log: "toggleConnectingLine: %@".fmt(willShow ? "show" : "hide"),
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'toggle connecting line',
              type: 'DG.GraphView'
            }
          },
          execute: function () {
            toggle();
          },
          undo: function () {
            toggle();
          }
        }));
      },

      /**
       * Toggle where the squares drawn from points to lines and functions are being shown
       */
      toggleShowSquares: function () {
        var this_ = this;

        function toggle() {

          function doToggle( iPlot) {
            iPlot.set('areSquaresVisible', !iPlot.get('areSquaresVisible'));
          }

          doToggle( this_);
          this_.get('siblingPlots').forEach( doToggle);
        }

        var willShow = !this.get('areSquaresVisible');
        DG.UndoHistory.execute(DG.Command.create({
          name: "graph.toggleShowSquares",
          undoString: (willShow ? 'DG.Undo.graph.showSquares' : 'DG.Undo.graph.hideSquares'),
          redoString: (willShow ? 'DG.Redo.graph.showSquares' : 'DG.Redo.graph.hideSquares'),
          log: "toggleShowSquares: %@".fmt(willShow ? "show" : "hide"),
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'toggle show squares',
              type: 'DG.GraphView'
            }
          },
          execute: function () {
            toggle();
          },
          undo: function () {
            toggle();
          }
        }));
      },

      handleDataConfigurationChange: function (iKey) {
        arguments.callee.base.apply(this,arguments);
        this.rescaleAxesFromData(iKey !== 'hiddenCases', /* allow scale shrinkage */
            true /* do animation */);

        var adornmentModel = this.getAdornmentModel('connectingLine');
        if (adornmentModel) {
          adornmentModel.setComputingNeeded();  // invalidate if axis model/attribute change
        }
      },

      /**
       Each axis should rescale based on the values to be plotted with it.
       @param{Boolean} Default is false
       @param{Boolean} Default is true
       @param{Boolean} Default is false
       */
      rescaleAxesFromData: function (iAllowScaleShrinkage, iAnimatePoints, iLogIt, isUserAction) {
        if (iAnimatePoints === undefined)
          iAnimatePoints = true;
        this.doRescaleAxesFromData([DG.GraphTypes.EPlace.eX, DG.GraphTypes.EPlace.eY, DG.GraphTypes.EPlace.eY2],
            iAllowScaleShrinkage, iAnimatePoints, isUserAction);
        if (iLogIt && !isUserAction)
          DG.logUser("rescaleScatterplot");
      },

      /**
       @param{ {x: {Number}, y: {Number} } }
       @param{Number}
       */
      dilate: function (iFixedPoint, iFactor) {
        this.doDilation([DG.GraphTypes.EPlace.eX, DG.GraphTypes.EPlace.eY], iFixedPoint, iFactor);
      },

      /**
       * Return a list of objects { key, class, useAdornmentModelsArray, storage }
       * Subclasses should override calling sc_super first.
       * @return {[Object]}
       */
      getAdornmentSpecs: function() {
        var tSpecs = arguments.callee.base.apply(this,arguments),
        this_ = this;
        ['movablePoint', 'movableLine', 'multipleLSRLs'].forEach( function( iKey) {
          var tAdorn = this_.get( iKey);
          if (tAdorn)
            tSpecs.push({
              key: iKey,
              "class": tAdorn.constructor,
              useAdornmentModelsArray: false,
              storage: tAdorn.createStorage()
            });
        });
        DG.ObjectMap.forEach( this._adornmentModels, function( iKey, iAdorn) {
          tSpecs.push( {
            key: iKey,
            "class": iAdorn.constructor,
            useAdornmentModelsArray: true,
            storage: iAdorn.createStorage()
          });
        });
        return tSpecs;
      },

      /**
       * Base class will do most of the work. We just have to finish up setting the axes.
       * @param {DG.PlotModel} iSourcePlot
       */
      installAdornmentModelsFrom: function( iSourcePlot) {
        arguments.callee.base.apply(this,arguments);
        var tMovablePoint = this.get('movablePoint');
        if (tMovablePoint) {
          tMovablePoint.set('xAxis', this.get('xAxis'));
          tMovablePoint.set('yAxis', this.get('yAxis'));
          tMovablePoint.recomputeCoordinates(this.get('xAxis'), this.get('yAxis'));
        }
        var tMultipleLSRLs = this.get('multipleLSRLs');
        if (tMultipleLSRLs) {
          tMultipleLSRLs.recomputeSlopeAndInterceptIfNeeded(this.get('xAxis'), this.get('yAxis'));
        }
      },

      checkboxDescriptions: function () {

        function isLSRLVisible() {
          return this_.get('isLSRLVisible');
        }

        function showConfidenceBandsCheckboxShouldBeEnabled() {
          return isLSRLVisible() && !this_.getPath('multipleLSRLs.isInterceptLocked');
        }

        function createLsrlToggle() {
          var kMargin = 20,
             kLeading = 5,
             kRowHeight = 20,
             tShowSECheckbox = SC.CheckboxView.create( {
               layout: { height: kRowHeight },
               localize: true,
               flowSpacing: { left: kMargin },
               title: 'DG.Inspector.graphLSRLSlopeCI',
               value: this_.getPath('multipleLSRLs.showConfidenceBands') && !this_.getPath('multipleLSRLs.isInterceptLocked'),
               classNames: 'dg-graph-LSRLSlopeCI-check'.w(),
               valueDidChange: function () {
                 this_.get('multipleLSRLs').toggleProperty('showConfidenceBands');
                 this_.get('multipleLSRLs').setComputingNeeded();
               }.observes('value')
             }),
             tLSRLCheckbox = SC.CheckboxView.create( {
               layout: { height: kRowHeight },
               localize: true,
               title: 'DG.Inspector.graphLSRL',
               value: isLSRLVisible(),
               classNames: 'dg-graph-lsrl-check'.w(),
               valueDidChange: function () {
                 this_.toggleLSRLLine();
                 tShowSECheckbox.set('isEnabled', showConfidenceBandsCheckboxShouldBeEnabled());
               }.observes('value')
             });

          var tComposite =  SC.View.create( SC.FlowedLayout,
             {
               layoutDirection: SC.LAYOUT_VERTICAL,
               isResizable: false,
               isClosable: false,
               layout: {height: 2 * (kRowHeight + kLeading)},
               defaultFlowSpacing: {bottom: kLeading},
               canWrap: false,
               align: SC.ALIGN_TOP,
               init: function() {
                 arguments.callee.base.apply(this,arguments);
                 tShowSECheckbox.set('isEnabled', showConfidenceBandsCheckboxShouldBeEnabled());
                 this.appendChild( tLSRLCheckbox);
                 this.appendChild(tShowSECheckbox);
               }
             });
          return tComposite;
        }

        var this_ = this;
        return arguments.callee.base.apply(this,arguments).concat([
          {
            title: 'DG.Inspector.graphConnectingLine',
            value: this_.isAdornmentVisible('connectingLine'),
            classNames: 'dg-graph-connectingLine-check'.w(),
            valueDidChange: function () {
              this_.toggleConnectingLine();
            }.observes('value')
          },
          {
            title: 'DG.Inspector.graphMovablePoint',
            value: this_.get('isMovablePointVisible'),
            classNames: 'dg-graph-movablePoint-check'.w(),
            valueDidChange: function () {
              this_.toggleMovablePoint();
            }.observes('value')
          },
          {
            title: 'DG.Inspector.graphMovableLine',
            value: this_.get('isMovableLineVisible'),
            classNames: 'dg-graph-movableLine-check'.w(),
            valueDidChange: function () {
              this_.toggleMovableLine();
            }.observes('value')
          },
          { control: createLsrlToggle()},
          {
            title: 'DG.Inspector.graphInterceptLocked',
            classNames: 'dg-graph-interceptLocked-check'.w(),
            _changeInProgress: true,
            valueDidChange: function () {
              if( !this._changeInProgress)
                this_.toggleInterceptLocked();
            }.observes('value'),
            lineVisibilityChanged: function() {
              this._changeInProgress = true;
              var tLineIsVisible = this_.get('isMovableLineVisible') || this_.get('isLSRLVisible');
              if( !tLineIsVisible)
                this_.set('isInterceptLocked', false);
              this.set('value', this_.get('isInterceptLocked'));
              this.set('isEnabled', tLineIsVisible);
              this._changeInProgress = false;
            },
            init: function() {
              arguments.callee.base.apply(this,arguments);
              this.lineVisibilityChanged();
              this_.addObserver('isMovableLineVisible', this, 'lineVisibilityChanged');
              this_.addObserver('isLSRLVisible', this, 'lineVisibilityChanged');
              this._changeInProgress = false;
            },
            destroy: function() {
              this_.removeObserver('isMovableLineVisible', this, 'lineVisibilityChanged');
              this_.removeObserver('isLSRLVisible', this, 'lineVisibilityChanged');
              arguments.callee.base.apply(this,arguments);
            }
          },
          {
            title: 'DG.Inspector.graphPlottedFunction',
            value: this_.isAdornmentVisible('plottedFunction'),
            classNames: 'dg-graph-plottedFunction-check'.w(),
            valueDidChange: function () {
              this_.togglePlotFunction();
            }.observes('value')
          },
          {
            title: 'DG.Inspector.graphPlottedValue',
            value: this_.isAdornmentVisible('plottedValue'),
            classNames: 'dg-graph-plottedValue-check'.w(),
            valueDidChange: function () {
              this_.togglePlotValue();
            }.observes('value')
          },
          {
            title: 'DG.Inspector.graphSquares',
            value: this_.get('areSquaresVisible'),
            classNames: 'dg-graph-squares-check'.w(),
            lineVisibilityChanged: function() {
              var tLineIsVisible = this_.get('isMovableLineVisible') || this_.get('isLSRLVisible');
              this.set('isEnabled', tLineIsVisible);
              if( this_.get('areSquaresVisible') && !tLineIsVisible)
                this.set('value', false);
            },
            init: function() {
              arguments.callee.base.apply(this,arguments);
              this.lineVisibilityChanged();
              this_.addObserver('isMovableLineVisible', this, 'lineVisibilityChanged');
              this_.addObserver('isLSRLVisible', this, 'lineVisibilityChanged');
            },
            destroy: function() {
              this_.removeObserver('isMovableLineVisible', this, 'lineVisibilityChanged');
              this_.removeObserver('isLSRLVisible', this, 'lineVisibilityChanged');
            },
            valueDidChange: function () {
              this_.toggleShowSquares();
            }.observes('value')
          }
        ]);
      }.property(),

      /**
       * When making a copy of a plot (e.g. for use in split) the returned object
       * holds those properties that should be assigned to the copy.
       * @return {{}}
       */
      getPropsForCopy: function() {
        var tResult = arguments.callee.base.apply(this,arguments);
        return $.extend( tResult, {
          areSquaresVisible: this.get('areSquaresVisible')
        });
      },

      /**
       * @return { Object } with properties specific to a given subclass
       */
      createStorage: function () {
        var tStorage = arguments.callee.base.apply(this,arguments),
            tMovablePoint = this.get('movablePoint'),
            tMovableLine = this.get('movableLine'),
            tLSRL = this.get('multipleLSRLs');
        if (!SC.none(tMovablePoint))
          tStorage.movablePointStorage = tMovablePoint.createStorage();
        if (!SC.none(tMovableLine))
          tStorage.movableLineStorage = tMovableLine.createStorage();
        if (!SC.none(tLSRL) && tLSRL.get('isVisible'))
          tStorage.multipleLSRLsStorage = tLSRL.createStorage();
        if (this.get('areSquaresVisible'))
          tStorage.areSquaresVisible = true;
        if (this.get('isLSRLVisible'))
          tStorage.isLSRLVisible = true;

        return tStorage;
      },

      /**
       * @param { Object } with properties specific to a given subclass
       */
      restoreStorage: function (iStorage) {

        /*  Older documents stored adornments individually in the plot model
         *  that used them, e.g. movable lines and function plots were stored
         *  here with the scatter plot model. In newer documents, there is an
         *  'adornments' property in the base class (plot model) which stores
         *  all or most of the adornments. To preserve file format compatibility
         *  we move the locally stored storage objects into the base class
         *  'adornments' property where the base class will process them when
         *  we call arguments.callee.base.apply(this,arguments).
         */
        this.moveAdornmentStorage(iStorage, 'movableLine', iStorage.movableLineStorage);
        this.moveAdornmentStorage(iStorage, 'multipleLSRLs', iStorage.multipleLSRLsStorage);
        this.moveAdornmentStorage(iStorage, 'plottedFunction', iStorage.plottedFunctionStorage);

        arguments.callee.base.apply(this,arguments);

        if (iStorage.movablePointStorage) {
          if (SC.none(this.movablePoint))
            this.createMovablePoint();
          this.get('movablePoint').restoreStorage(iStorage.movablePointStorage);
        }
        if (iStorage.movableLineStorage) {
          if (SC.none(this.movableLine))
            this.createMovableLine();
          this.get('movableLine').restoreStorage(iStorage.movableLineStorage);
        }
        this.areSquaresVisible = iStorage.areSquaresVisible;
        if (iStorage.multipleLSRLsStorage) {
          if (SC.none(this.multipleLSRLs))
            this.createLSRLLines();
          this.get('multipleLSRLs').restoreStorage(iStorage.multipleLSRLsStorage);
        }

        // Legacy document support
        if (iStorage.plottedFunctionStorage) {
          if (SC.none(this.plottedFunction))
            this.set('plottedFunction', DG.PlottedFunctionModel.create());
          this.get('plottedFunction').restoreStorage(iStorage.plottedFunctionStorage);
        }
      },

      onRescaleIsComplete: function () {
        if (!SC.none(this.movableLine))
          this.movableLine.recomputeSlopeAndInterceptIfNeeded(this.get('xAxis'), this.get('yAxis'));
        if (!SC.none(this.movablePoint))
          this.movablePoint.recomputePositionIfNeeded(this.get('xAxis'), this.get('yAxis'));
      },

      /**
       * Get an array of non-missing case counts in each axis cell.
       * Also cell index on primary and secondary axis, with primary axis as major axis.
       * @return {Array} [{count, primaryCell, secondaryCell},...] (all values are integers 0+).
       */
      getCellCaseCounts: function ( iForSelectionOnly) {
        var tCases = iForSelectionOnly ? this.get('selection') : this.get('cases'),
            tXVarID = this.get('xVarID'),
            tYVarID = this.get('yVarID'),
            tCount = 0,
            tValueArray = [];

        if (!( tXVarID && tYVarID )) {
          return tValueArray; // too early to recompute, caller must try again later.
        }

        // compute count and percent cases in each cell, excluding missing values
        tCases.forEach(function (iCase, iIndex) {
          var tXVal = iCase.getForcedNumericValue(tXVarID),
              tYVal = iCase.getForcedNumericValue(tYVarID);
          if (isFinite(tXVal) && isFinite(tYVal)) ++tCount;
        });

        // initialize the values for the single 'cell' of the scatterplot
        var tCell = { primaryCell: 0, secondaryCell: 0 };
        if( iForSelectionOnly)
          tCell.selectedCount = tCount;
        else
          tCell.count = tCount;
        tValueArray.push(tCell);
        return tValueArray;
      }

    });


/* >>>>>>>>>> BEGIN source/components/graph/plots/scatter_plot_view.js */
// ==========================================================================
//                        DG.ScatterPlotView
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/plots/plot_view');

/** @class DG.ScatterPlotView - A plot of dots placed according to numeric values

 @extends DG.PlotView
 */
DG.ScatterPlotView = DG.PlotView.extend(
    /** @scope DG.ScatterPlotView.prototype */
    {
      displayProperties: ['xAxisView.model.lowerBound', 'xAxisView.model.upperBound',
        'yAxisView.model.lowerBound', 'yAxisView.model.upperBound',
        'xAxisView.pixelMin', 'xAxisView.pixelMax',
        'yAxisView.pixelMin', 'yAxisView.pixelMax',
        'model.areSquaresVisible', 'model.squares'],

      autoDestroyProperties: ['movablePointAdorn', 'movableLineAdorn', 'functionAdorn', 'connectingLineAdorn', 'multipleLSRLsAdorn'],


      /** @property {DG.ConnectingLineAdornment} */
      connectingLineAdorn: null,

      numPlotsOrIndexChanged: function () {
        // update connecting lines
        if (this.connectingLineAdorn) {
          this.connectingLineChanged();
        }
      }.observes('numPlots', 'plotIndex'),

      /**
       Required for some adornments like DG.PlottedCountAdornment.
       @property{DG.CellLinearAxisView}
       */
      primaryAxisView: function () {
        return this.get('xAxisView');
      }.property('xAxisView'),

      /**
       Required for some adornments like DG.PlottedCountAdornment.
       @property{DG.CellLinearAxisView}
       */
      secondaryAxisView: function () {
        return this.get('yAxisView');
      }.property('yAxisView'),

      /**
       @property {DG.MovablePointAdornment}
       */
      movablePointAdorn: null,

      /**
       @property {DG.MovableLineAdornment}
       */
      movableLineAdorn: null,

      /**
       @property {DG.MultipleLSRLsAdornment}
       */
      multipleLSRLsAdorn: null,

      /**
       @property {DG.PlottedFunctionAdornment}
       */
      functionAdorn: null,

      /**
       * More than one scatterplot can be displayed in a graph. We need to know if we're not the
       * first one so that we can allocate our own plotted points if not.
       * @property {Boolean}
       */
      isFirstPlot: true,

      isFirstPlotChanged: function () {
        if (this.isFirstPlot) {
          if (SC.isArray(this._myPlottedElements)) {
            var tLayerManager = this.get('layerManager');
            this._myPlottedElements.forEach(function (iElement) {
              tLayerManager.removeElement(iElement);
              iElement.remove();
            });
            this._myPlottedElements = [];
          }
        }
        this.get('plottedElements').forEach(function (iElement, iIndex) {
          this.assignElementAttributes(iElement, iIndex);
        }.bind(this));
      }.observes('isFirstPlot'),

      /**
       * @property {Array of Element}
       */
      _squares: null,

      /**
       * If defined, this function gets called after cases have been added or values changed, but only once,
       * and only after a sufficient time has elapsed.
       * @property { Function }
       */
      cleanupFunc: function () {
        var tAdorn = this.get('connectingLineAdorn');
        if (tAdorn)
          tAdorn.updateToModel();
      },

      init: function () {
        arguments.callee.base.apply(this,arguments);
        var tModel = this.get('model');
        if (tModel && tModel.getAdornmentModel('connectingLine'))
          this.connectingLineChanged();
      },

      /**
       Destruction method
       */
      destroy: function () {
        var model = this.get('model');
        if (model) model.removeObserver('squares', this, 'squaresDidChange');
        if (model) model.removeObserver('areSquaresVisible', this, 'squaresDidChange');
        var tLayerManager = this.get('layerManager');
        if (this._squares) {
          this._squares.forEach(function (iElement) {
            tLayerManager.removeElement(iElement, true /* callRemove */);
          });
        }
        var tFunctionEditView = this.get('functionEditView');
        if (tFunctionEditView) {
          this.get('parentView').removeChild(tFunctionEditView);
        }
        if (SC.isArray(this._myPlottedElements)) {
          this._myPlottedElements.forEach(function (iElement) {
            tLayerManager.removeElement(iElement);
            iElement.remove();
          });
          this._myPlottedElements = [];
        }

        arguments.callee.base.apply(this,arguments);
      },

      /**
       Observation method called when the model changes.
       Hooks up necessary observers.
       */
      modelDidChange: function () {
        arguments.callee.base.apply(this,arguments);

        var model = this.get('model');
        if (model) {
          model.addObserver('squares', this, 'squaresDidChange');
          model.addObserver('areSquaresVisible', this, 'squaresDidChange');
          this.connectingLineChanged(); // Synch up the connecting line
        }
      },

      /**
       Observation function called when data values added/removed.
       */
      dataDidChange: function () {
        if (!this.getPath('model.dataConfiguration'))
          return; // happens during destroy of plot
        arguments.callee.base.apply(this,arguments);

        // update connecting lines
        if (this.connectingLineAdorn) {
          this.connectingLineAdorn.invalidateModel();
          this.connectingLineAdorn.updateToModel();
        }
        this.updateAdornments();
      },

      /**
       Observation function called when data values change.
       Method name is legacy artifact of SproutCore range observer implementation.
       */
      dataRangeDidChange: function (iSource, iQuestion, iKey, iChanges) {
        var tCases = this.getPath('model.cases');

        this.notifyPropertyChange('plotDisplayDidChange');

        // If we are displaying squares then we invalidate the display so squares will be updated
        if (this.getPath('model.areSquaresVisible'))
          this.squaresDidChange();

        // update connecting lines
        if (this.connectingLineAdorn) {
          this.connectingLineAdorn.invalidateModel();
          this.connectingLineAdorn.updateToModel();
        }

        this.updateAdornments();

        this.rescaleOnParentCaseCompletion(tCases);

        arguments.callee.base.apply(this,arguments);
      },

      /**
       * Connecting line adornment, if any, will need updating
       */
      handleUpdateConnectingLine: function () {
        if (this.connectingLineAdorn && this.connectingLineAdorn.wantVisible()) {
          this.connectingLineAdorn.invalidateModel();
          this.connectingLineAdorn.updateToModel(true /* animate */);
        }
      },

      /**
       * Connecting line adornment, if any, will need updating
       */
      handleMoveAttribute: function () {
        this.handleUpdateConnectingLine();
      },

      /**
       * Connecting line adornment, if any, will need updating
       */
      handleMoveCases: function () {
        arguments.callee.base.apply(this,arguments);
        this.handleUpdateConnectingLine();
      },

      updateAdornments: function () {
        arguments.callee.base.apply(this,arguments);

        var tLsrlsAdorn = this.get('multipleLSRLsAdorn'),
            tMovableLineAdorn = this.get('movableLineAdorn'),
            tSquaresAreShowing = this.getPath('model.areSquaresVisible');
        if (tLsrlsAdorn) {
          tLsrlsAdorn.get('model').setComputingNeeded();
          tLsrlsAdorn.updateToModel();
        }
        if (tMovableLineAdorn && tSquaresAreShowing) {
          tMovableLineAdorn.get('model').slopeOrInterceptChanged();  // Forces recomputation of sum of squares of residuals
        }
        // update plotted function
        if (this.functionAdorn)
          this.functionAdorn.updateToModel();
      },

      /**
       * If we're connecting points with lines, we override to make the points much less important than the lines
       */
      calcPointRadius: function () {
        var tRadius = arguments.callee.base.apply(this,arguments);
        if (this.connectingLineAdorn && this.connectingLineAdorn.wantVisible())
          tRadius = tRadius / 2;
        return tRadius;
      },

      /**
       * Set the coordinates and other attributes of the case circle (a Rafael element in this.get('plottedElements')).
       * @param iRC {} case-invariant Render Context
       * @param iCase {DG.Case} the case data
       * @param iIndex {number} index of case in collection
       * @param iAnimate {Boolean} (optional) want changes to be animated into place?
       * @returns {cx {Number},cy {Number}} final coordinates or null if not defined (hidden plot element)
       */
      setCircleCoordinate: function (iRC, iCase, iIndex, iAnimate, iCallback) {
        DG.assert(iRC && iRC.xAxisView);
        DG.assert(iCase);
        DG.assert(DG.MathUtilities.isInIntegerRange(iIndex, 0, this.get('plottedElements').length));
        var tCircle = this.get('plottedElements')[iIndex],
            tCoordX = iRC.xAxisView.dataToCoordinate(iCase.getForcedNumericValue(iRC.xVarID)),
            tCoordY = iRC.yAxisView.dataToCoordinate(iCase.getForcedNumericValue(iRC.yVarID)),
            tIsMissingCase = !DG.isFinite(tCoordX) || !DG.isFinite(tCoordY);

        // show or hide if needed, then update if shown.
        if (this.showHidePlottedElement(tCircle, tIsMissingCase, iIndex)) {
          var tAttrs = {
            cx: tCoordX,
            cy: tCoordY,
            r: this.radiusForCircleElement(tCircle),
            fill: iRC.calcCaseColorString(iCase),
            stroke: iRC.calcStrokeColorString(iCase),
            'fill-opacity': iRC.transparency,
            'stroke-opacity': iRC.strokeTransparency
          };
          this.updatePlottedElement(tCircle, tAttrs, iAnimate, iCallback);
          return {cx: tCoordX, cy: tCoordY, r: this._pointRadius};
        }
        return null;
      },

      assignElementAttributes: function (iElement, iIndex, iAnimate) {
        arguments.callee.base.apply(this,arguments);
        var this_ = this;

        function getVarIDs() {
          var tXVarID = this_.getPath('model.xVarID'),
              tYPath = 'model.' + (this_.getPath('model.verticalAxisIsY2') ? 'y2VarID' : 'yVarID'),
              tYVarID = this_.getPath(tYPath);
          return {x: tXVarID, y: tYVarID};
        }

        function changeCaseValues(iDeltaValues) {

          function getProperValue(iCase, iDelta, iAxisKey) {
            var tValue = iCase.getForcedNumericValue(this_.getPath('model.' + iAxisKey + 'VarID')) + iDelta;
            if (this_.getPath(iAxisKey + 'AxisView.isDateTime')) {
              tValue = DG.createDate(tValue);
            }
            return tValue;
          }

          var tVarIDs = getVarIDs(),
              tChange = {
                operation: 'updateCases',
                cases: [],
                attributeIDs: [tVarIDs.x, tVarIDs.y],
                values: [[], []],
                dirtyDocument: false
              },
              tDataContext = this_.get('dataContext');
          if (!tDataContext) return;
          // Note that we have to get the cases dynamically rather than have a variable
          // declared in the closure. The array pointed to by such a closure is not updated!
          this_.getPath('model.casesController.selection').forEach(function (iCase) {
            tChange.cases.push(iCase);
            tChange.values[0].push(getProperValue(iCase, iDeltaValues.x, 'x'));
            tChange.values[1].push(getProperValue(iCase, iDeltaValues.y, 'y'));
          });
          tDataContext.applyChange(tChange);
        }

        function returnCaseValuesToStart(iCaseIndex, iStartWorldCoords) {
          if (!SC.none(iStartWorldCoords.x) && !SC.none(iStartWorldCoords.y)) {
            var tCase = this_.getPath('model.cases').unorderedAt(iCaseIndex),
                tVarIDs = getVarIDs(),
                tDeltaX = tCase.getForcedNumericValue(tVarIDs.x) - iStartWorldCoords.x,
                tDeltaY = tCase.getForcedNumericValue(tVarIDs.y) - iStartWorldCoords.y;
            if ((tDeltaX !== 0) || (tDeltaY !== 0))
              this_.get('model').animateSelectionBackToStart([tVarIDs.x, tVarIDs.y], [tDeltaX, tDeltaY]);
          }
        }

        function completeHoverAnimation() {
          this.hoverAnimation = null;
        }

        var tIsDragging = false,
            kOpaque = 1,
            tInitialTransform = null;
        iElement.hover(function (event) {  // over
              if (!tIsDragging && SC.none(tInitialTransform)) {
                tInitialTransform = '';
                if (this.hoverAnimation)
                  this.stop(this.hoverAnimation);
                this.hoverAnimation = Raphael.animation({
                      opacity: kOpaque,
                      transform: DG.PlotUtilities.kDataHoverTransform
                    },
                    DG.PlotUtilities.kDataTipShowTime,
                    '<>', completeHoverAnimation);
                this.animate(this.hoverAnimation);
                this_.showDataTip(this, iIndex);
              }
            },
            function (event) { // out
              if (!tIsDragging) {
                if (this.hoverAnimation)
                  this.stop(this.hoverAnimation);
                this.hoverAnimation = Raphael.animation({transform: tInitialTransform},
                    DG.PlotUtilities.kHighlightHideTime,
                    '<>', completeHoverAnimation);
                this.animate(this.hoverAnimation);
                tInitialTransform = null;
                this_.hideDataTip();
              }
            })
            .drag(function (dx, dy) { // continue
                  SC.run(function () {
                    var tNewX = this_.get('xAxisView').coordinateToData(this.ox + dx),
                        tNewY = this_.get('yAxisView').coordinateToData(this.oy + dy),
                        tVarIDs = getVarIDs(),
                        tCase = this_.getPath('model.cases').unorderedAt(this.index),
                        tOldX = tCase.getForcedNumericValue(tVarIDs.x),
                        tOldY = tCase.getForcedNumericValue(tVarIDs.y),
                        tCurrTransform = this.transform();
                    // Note that we ignore invalid values. Matt managed to convert some dragged values
                    // to NaNs during testing, which then couldn't animate back to their original
                    // positions. This should have the effect of leaving points that would otherwise
                    // have become NaNs in their last-known-good positions.
                    if (isFinite(tNewX) && isFinite(tNewY)) {
                      // Put the element into the initial transformed state so that changing case values
                      // will not be affected by the scaling in the current transform.
                      this.transform(tInitialTransform);
                      changeCaseValues({x: tNewX - tOldX, y: tNewY - tOldY});
                      this.transform(tCurrTransform);
                    }
                  }, this);
                },
                function (x, y) { // begin
                  if (tIsDragging)
                    return;
                  var tCase = this_.getPath('model.cases').unorderedAt(this.index),
                      tVarIDs = getVarIDs();
                  tIsDragging = true;
                  // Save the initial screen coordinates
                  this.ox = this.attr("cx");
                  this.oy = this.attr("cy");
                  // Save the initial world coordinates
                  this.wx = tCase.getForcedNumericValue(tVarIDs.x);
                  this.wy = tCase.getForcedNumericValue(tVarIDs.y);
                  this.attr({opacity: kOpaque});
                },
                function () {  // end
                  this.animate({transform: tInitialTransform}, DG.PlotUtilities.kHighlightHideTime);
                  tInitialTransform = null;
                  returnCaseValuesToStart(this.index, {x: this.wx, y: this.wy});
                  tIsDragging = false;
                  delete this.ox;
                  delete this.oy;
                  delete this.wx;
                  delete this.wy;
                  this_.hideDataTip();
                });
        return iElement;
      },

      createElement: function (iCase, iIndex, iAnimate) {
        var tCircle = this.get('paper').circle(-100, -100, this._pointRadius);
        tCircle.node.setAttribute('shape-rendering', 'geometricPrecision');

        //return this.assignElementAttributes( tCircle, iIndex);  // Redundant I hope
        return tCircle;
      },

      /**
       We may clear and draw everything from scratch if required.
       */
      drawData: function drawData() {
        // Note that only the 'first plot' view animates but it shares its model with other plots
        if (this.getPath('model.isAnimating') && this.get('isFirstPlot'))
          return; // Points are animating to new position

        if (!SC.none(this.get('transferredElementCoordinates'))) {
          this.animateFromTransferredElements();
          return;
        }

        // base drawData() creates and updates points,
        // removes any extra points, to sync case circles with cases.
        arguments.callee.base.apply(this,arguments);
      },

      /**
       Generate the svg needed to display the plot
       */
      doDraw: function doDraw(iIndex, iNumPlots, iChangedProperty) {
        var this_ = this;

        function drawSquares() {

          function showSquaresForLine(iLine, iColor) {
            var tSlope = iLine.get('slope'),
                tIntercept = iLine.get('intercept'),
                tCasesForLine = tCases,
                tCategory = iLine.get('categoryName'),
                tLegendAttrDesc = this_.getPath('model.dataConfiguration.legendAttributeDescription'),
                tLegendAttrID = tLegendAttrDesc.getPath('attribute.id');
            if (!SC.none(tLegendAttrID) && !SC.none(tCategory)) {
              tCasesForLine = tCases.filter(function (iCase) {
                return tCategory === iCase.getValue(tLegendAttrID);
              });
            }
            tCasesForLine.forEach(function (iCase) {
              if(iCase.hasValue(tXVarID) && iCase.hasValue(tYVarID)) {
                var tWorldX = iCase.getForcedNumericValue(tXVarID),
                    tWorldY = iCase.getForcedNumericValue(tYVarID),
                    tPtX = tXAxisView.dataToCoordinate(tWorldX),
                    tPtY = tYAxisView.dataToCoordinate(tWorldY),
                    tLineY = tYAxisView.dataToCoordinate(tSlope * tWorldX + tIntercept),
                    tLineX = tPtX + tPtY - tLineY,
                    tX = Math.min(tPtX, tLineX),
                    tY = Math.min(tPtY, tLineY),
                    tSide = Math.abs(tLineY - tPtY),
                    tRectString = DG.RenderingUtilities.pathForFrame({
                      x: tX, y: tY,
                      width: tSide, height: tSide
                    }),
                    tRect = tPaper.path(tRectString)
                        .attr({stroke: iColor});
                if (tAnimateShow) {
                  tRect.attr({'stroke-opacity': 0})
                      .animate({'stroke-opacity': 1}, DG.PlotUtilities.kDefaultAnimationTime, '<>');
                }
                this_._squares.push(tRect);
                tAdornmentLayer.push(tRect);
              }
            });
          }

          var kRemoveFromPaper = true,
              tVisible = this_.getPath('model.areSquaresVisible'),
              tAnimateRemove = !tVisible && this_._squares && (this_._squares.length > 0),
              tAnimateShow = tVisible && (!this_._squares || (this_._squares.length === 0)),
              tLayerManager = this_.get('layerManager'),
              tAdornmentLayer = tLayerManager[DG.LayerNames.kAdornments];
          if (!this_._squares)
            this_._squares = [];
          this_._squares.forEach(function (iElement) {
            if (tAnimateRemove) {
              iElement.animate({'stroke-opacity': 0}, DG.PlotUtilities.kDefaultAnimationTime, '<>',
                  function () {
                    tLayerManager.removeElement(iElement, kRemoveFromPaper);
                  });
            } else
              tLayerManager.removeElement(iElement, kRemoveFromPaper);
          });
          this_._squares = [];
          if (!tVisible)
            return;
          var tCases = this_.getPath('model.cases'),
              tXVarID = this_.getPath('model.xVarID'),
              tYVarID = this_.getPath('model.yVarID'),
              tXAxisView = this_.get('xAxisView'),
              tYAxisView = this_.get('yAxisView'),
              tPaper = this_.get('paper');
          if (this_.getPath('model.isMovableLineVisible')) {
            showSquaresForLine(this_.getPath('model.movableLine'), DG.PlotUtilities.kDefaultMovableLineColor);
          }
          if (this_.getPath('model.isLSRLVisible')) {
            this_.getPath('multipleLSRLsAdorn.lsrlAdornments').forEach(function (iLineAdorn) {
              showSquaresForLine(iLineAdorn.get('model'), iLineAdorn.get('lineColor'));
            });
          }
        }

        arguments.callee.base.apply(this,arguments);

        this.drawData();

        this.updateSelection();

        if (!SC.none(this.connectingLineAdorn) && this.connectingLineAdorn.wantVisible()) {
          if (iChangedProperty === 'pointColor')
            this.connectingLineAdorn.invalidateModel();
          this.connectingLineAdorn.updateToModel();
        }

        if (!SC.none(this.movablePointAdorn))
          this.movablePointAdorn.updateToModel();

        if (!SC.none(this.movableLineAdorn))
          this.movableLineAdorn.updateToModel();

        if (!SC.none(this.multipleLSRLsAdorn))
          this.multipleLSRLsAdorn.updateToModel();

        if (!SC.none(this.functionAdorn))
          this.functionAdorn.updateToModel();

        drawSquares();
      },

      /**
       * If we have a connecting line adornment, give it a chance to update selection.
       */
      updateSelection: function () {
        arguments.callee.base.apply(this,arguments);
        var tConnectingLineAdorn = this.get('connectingLineAdorn');
        if (tConnectingLineAdorn && tConnectingLineAdorn.wantVisible()) {
          if (this.getPath('model.dataConfiguration.displayOnlySelected')) {
            tConnectingLineAdorn.get('model').setComputingNeeded();
          }
          this.connectingLineAdorn.updateSelection();
        }
      },

      /**
       Presumably our model has created a movable point. We need to create our adornment.
       */
      movablePointChanged: function () {
        if (!this.readyToDraw())
          return;
        var tMovablePoint = this.getPath('model.movablePoint'),
            tMovablePtAdorn = this.get('movablePointAdorn');
        if (tMovablePoint) {
          if (tMovablePtAdorn) {
            tMovablePtAdorn.set('parentView', this);
            tMovablePtAdorn.set('model', tMovablePoint);
            tMovablePtAdorn.set('paperSource', this.get('paperSource'));
          } else {
            tMovablePtAdorn = DG.MovablePointAdornment.create({
              parentView: this, model: tMovablePoint, paperSource: this.get('paperSource')
            });
            tMovablePtAdorn.createElements();
            this.set('movablePointAdorn', tMovablePtAdorn);
          }
          this.movablePointAdorn.updateVisibility();
        } else if (tMovablePtAdorn) {
          // No model, so get rid of it
          tMovablePtAdorn.destroy();
          this.set('movablePointAdorn', null);
        }
      }.observes('*model.movablePoint.isVisible'),

      /**
       Presumably our model has created a movable line. We need to create our adornment.
       */
      movableLineChanged: function () {
        if (!this.readyToDraw())
          return;
        var tMovableLine = this.getPath('model.movableLine'),
            tMovableLineAdorn = this.get('movableLineAdorn');
        if (tMovableLine) {
          if (tMovableLineAdorn) {
            tMovableLineAdorn.set('parentView', this);
            tMovableLineAdorn.set('model', tMovableLine);
            tMovableLineAdorn.set('paperSource', this.get('paperSource'));
          } else {
            tMovableLineAdorn = DG.MovableLineAdornment.create({
              parentView: this, model: tMovableLine, paperSource: this.get('paperSource'),
              layerName: DG.LayerNames.kAdornments
            });
            tMovableLineAdorn.createElements();
            this.set('movableLineAdorn', tMovableLineAdorn);
          }
          tMovableLineAdorn.updateVisibility();
        } else if (tMovableLineAdorn) {
          // No model, so get rid of it
          tMovableLineAdorn.destroy();
          this.set('movableLineAdorn', null);
        }
        this.updateSquaresVisibility();
        this.displayDidChange();
      }.observes('*model.movableLine.isVisible'),

      /**
       Presumably our model has created an lsr line. We need to create our adornment.
       */
      lsrlChanged: function () {
        if (!this.readyToDraw())
          return;
        var tMultipleLSRLs = this.getPath('model.multipleLSRLs'),
            tMultipleLSRLsAdorn = this.get('multipleLSRLsAdorn');
        // Rather than attempt to reconnect an existing adornment, we throw out the old and rebuild.
        if (tMultipleLSRLs) {
          if (tMultipleLSRLsAdorn) {
            tMultipleLSRLsAdorn.set('parentView', this);
            tMultipleLSRLsAdorn.set('model', tMultipleLSRLs);
            tMultipleLSRLsAdorn.set('paperSource', this.get('paperSource'));
          } else {
            tMultipleLSRLsAdorn = DG.MultipleLSRLsAdornment.create({
              parentView: this, model: tMultipleLSRLs, paperSource: this.get('paperSource'),
              layerName: DG.LayerNames.kAdornments
            });
            this.set('multipleLSRLsAdorn', tMultipleLSRLsAdorn);
          }
          tMultipleLSRLsAdorn.updateVisibility();
        } else if (tMultipleLSRLsAdorn) {
          // No model, so get rid of it
          tMultipleLSRLsAdorn.destroy();
          this.set('multipleLSRLsAdorn', null);
        }
        this.updateSquaresVisibility();
        this.displayDidChange();
      }.observes('*model.multipleLSRLs.isVisible'),

      /**
       Our model has created a connecting line. We need to create our adornment. We don't call adornmentDidChange
       because we don't want to destroy the adornment.
       */
      connectingLineChanged: function () {

        var updateConnectingLine = function () {
              if (tAdorn) {
                tAdorn.updateToModel(true /*animate*/);
                //    this.adornmentDidChange('connectingLine', 'connectingLineAdorn', DG.ConnectingLineAdornment);
                this.updatePointSize();
                this._elementOrderIsValid = false;
                this.updateSelection();
              }
            }.bind(this),

            hasGrouping = function () {
              var tLegendCollection = this.getPath('model.dataConfiguration.legendAttributeDescription.attribute.collection'),
                  tXCollection = this.getPath('model.dataConfiguration.xAttributeDescription.attribute.collection'),
                  tYCollection = this.getPath('model.dataConfiguration.yAttributeDescription.attribute.collection');
              return !SC.none(tLegendCollection) && tLegendCollection.get('id') !== tXCollection.get('id') &&
                  tLegendCollection.get('id') !== tYCollection.get('id');
            }.bind(this),

            isOneOfMany = function () {
              return this.get('numPlots') > 1;
            }.bind(this);

        var tPlotModel = this.get('model'),
            tAdornModel = tPlotModel && tPlotModel.getAdornmentModel('connectingLine'),
            tAdorn = this.get('connectingLineAdorn'),
            tLineColorFunc = hasGrouping() || !isOneOfMany() ? this.getPointColor : this.getAttributeColor;
        if (tAdornModel) {
          if (tAdorn) {
            tAdorn.set('parentView', this);
            tAdorn.set('model', tAdornModel);
            tAdorn.set('paperSource', this.get('paperSource'));
          } else {
            tAdorn = DG.ConnectingLineAdornment.create({
              parentView: this, model: tAdornModel,
              paperSource: this.get('paperSource'),
              layerName: DG.LayerNames.kConnectingLines
            });
            this.set('connectingLineAdorn', tAdorn);
          }
          tAdornModel.set('getLineColorFunc', tLineColorFunc.bind(this));
          tAdornModel.setComputingNeeded();
        } else if (tAdorn) {
          // No model, so get rid of it
          tAdorn.destroy();
          this.set('connectingLineAdorn', null);
        }

        this.invokeLast(updateConnectingLine); // So that we're ready
      }.observes('*model.connectingLine'),

      /**
       Observation method called when the squares need to be redrawn.
       */
      squaresDidChange: function () {
        // This will force a complete redraw.
        // We may be able to get away with less at some point.
        this._isRenderingValid = false;
        this.displayDidChange();
      },

      /**
       * If squares are visible, but neither line is visible, we have to hide the squares.
       */
      updateSquaresVisibility: function () {
        if (this.getPath('model.areSquaresVisible') && !this.getPath('model.multipleLSRLs.isVisible') &&
            !this.getPath('model.movableLine.isVisible')) {
          this.setPath('model.areSquaresVisible', false);
        }
      },

      /**
       The visibility of the model's plotted function has changed. We respond accordingly.
       */
      plottedFunctionChanged: function () {
        var model = this.get('model'),
            tPlottedFunction = model && model.getAdornmentModel('plottedFunction'),
            tPlottedFunctionAdorn = this.get('functionAdorn'),
            tFunctionEditView = this.get('functionEditView');

        if (tPlottedFunction) {
          if (!tFunctionEditView) {
            tFunctionEditView = DG.PlottedFunctionAdornment.createFormulaEditView(tPlottedFunction);
            this.set('functionEditView', tFunctionEditView);
            this.get('parentView').set('functionEditorView', tFunctionEditView);
          }
          tFunctionEditView.set('isVisible', tPlottedFunction.get('isVisible'));
          tFunctionEditView.set('formulaExpression', tPlottedFunction.get('expression'));

          if (tPlottedFunctionAdorn) {
            tPlottedFunctionAdorn.set('parentView', this);
            tPlottedFunctionAdorn.set('model', tPlottedFunction);
            tPlottedFunctionAdorn.set('parentView', this.get('paperSource'));
          } else {
            tPlottedFunctionAdorn = DG.PlottedFunctionAdornment.create({
              parentView: this, model: tPlottedFunction, paperSource: this.get('paperSource'),
              layerName: DG.LayerNames.kAdornments
            });
            this.set('functionAdorn', tPlottedFunctionAdorn);
          }
          tPlottedFunctionAdorn.updateVisibility();
        } else if (tPlottedFunctionAdorn) {
          // No model, so get rid of it
          tPlottedFunctionAdorn.destroy();
          this.set('functionAdorn', null);
          if (tFunctionEditView)
            tFunctionEditView.set('isVisible', false);
        }

      }.observes('*model.plottedFunction'),

      /**
       Give us a chance to update adornments on creation.
       */
      didCreateLayer: function () {
        arguments.callee.base.apply(this,arguments);
        this.movablePointChanged();
        this.movableLineChanged();
        this.lsrlChanged();
        this.plottedFunctionChanged();
      },

      /**
       * Used by both handleBackgroundClick and handleBackgroundDblClick
       * @param iEvent
       */
      zoom: function (iEvent) {
        var tFactor = iEvent.shiftKey ? 2 : 0.5,
            tViewPoint = DG.ViewUtilities.windowToViewCoordinates({x: iEvent.clientX, y: iEvent.clientY}, this),
            tWorldPoint = {
              x: this.get('xAxisView').coordinateToData(tViewPoint.x),
              y: this.get('yAxisView').coordinateToData(tViewPoint.y)
            };
        this.get('model').dilate(tWorldPoint, tFactor);
      },

      /**
       Alt key triggers zoom.
       @param {SC.Event}
       */
      handleBackgroundClick: function (iEvent) {
        if (iEvent.altKey) {
          this.zoom(iEvent);
        }
      },

      /**
       Double-click triggers zoom.
       @param {SC.Event}
       */
      handleBackgroundDblClick: function (iEvent) {
        this.zoom(iEvent);
      }

    });


/* >>>>>>>>>> BEGIN source/components/graph/selected_info_view.js */
// ==========================================================================
//                              DG.SelectedInfoView
//
//  Author:   William Finzer
//
//  Copyright (c) 2020 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class  DG.SelectedInfoView - Only visible when "Show Measures for Selection" is enabled
 * in a graph. It displays something like: Showing measures for <nn> selected.


 @extends SC.LabelView
 */
DG.SelectedInfoView = SC.LabelView.extend(
    /** @scope DG.SelectedInfoView.prototype */
    (function () {
      return {

        classNames: 'dg-selected-info-view'.w(),

        graphModel: null,   // DG.GraphModel

        desiredExtent: function() {
          return this.get('isVisible') ? DG.RenderingUtilities.kCaptionFontHeight : 0;
        }.property('isVisible'),

        init: function() {
          arguments.callee.base.apply(this,arguments);
          this.enableMeasuresForSelectionDidChange();
        },

        enableMeasuresForSelectionDidChange: function() {
          if( this.getPath('graphModel.enableMeasuresForSelection')) {
            this.set('isVisible', true);
            this.selectionDidChange();
          } else {
            this.set('isVisible', false);
          }
        }.observes('graphModel.enableMeasuresForSelection'),

        selectionDidChange: function() {
          if( this.get('isVisible')) {
            var tNumSelected = this.getPath('graphModel.selection').length,
                tValueString = tNumSelected === 1 ? 'DG.SelectedInfoView.infoSing' :
                    'DG.SelectedInfoView.infoPlural';
            this.set('value', tValueString.loc(tNumSelected));
          }
        }.observes('graphModel.dataConfiguration.selection')
      };
    }()));


/* >>>>>>>>>> BEGIN source/components/graph/utilities/graph_animator.js */
// ==========================================================================
//                          DG.GraphAnimator
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class  DG.GraphAnimator - controls the animation of a graph from one state to the next.

  @extends SC.Object
*/
DG.GraphAnimator = SC.Object.extend(
/** @scope DG.GraphAnimator.prototype */ 
{
  /**
    @property {Boolean}
  */
  isAnimating: false,

  /**
    The time that the animation started.
    @property { Number }
  */
  startTime: null,

  /**
    @property {DG.PlotModel}
  */
  plot: null,

  /**
    The axis to be animated and its new bounds. Pass this in on creation
    @property { Array of { axis: {DG.CellLinearAxis}, newBounds: {lower: {Number}, upper: {Number}} } }
  */
  axisInfoArray: null,

  /**
    We make a copy of the above axisInfoArray before we start animation so we can hold onto the
      information we need to end the animation in case another animation starts before we're done.
    @property { Array of { axis: {DG.CellLinearAxis}, newBounds: {lower: {Number}, upper: {Number}} } }
  */
  savedAxisInfoArray: null,

  /**
   * destroy - break loops that prevent garbage collection
   */
  destroy: function() {
    this.endAnimation();
    this.plot = null;
    this.axisInfoArray = null;
    this.savedAxisInfoArray = null;
    arguments.callee.base.apply(this,arguments);
  },

  /**
    We assume that my properties have been set to the aspects of the plot that are to
    be animated. If there is an animation already in progress, we end it.
    @param {Function} To be called when animation completes.
  */
  animate: function( iTarget, iCompletionFunc) {
    var this_ = this,
        kInterval = 50, // milliseconds
        kTargetDuration = DG.PlotUtilities.kDefaultAnimationTime; //milliseconds

    // animationLoop - This function is called up to 20 times per second. With each call
    //  it moves the animation to the position appropriate for the amount of time that
    //  has passed since the animation was initiated. Note that it schedules itself using
    //  an SC.Timer until the animation is complete.
    function animationLoop() {
      var tCurrTime = (new Date()).valueOf(),
          tCurrProportion = (tCurrTime - this_.startTime) / kTargetDuration,
          tAnimationProportion;

      // getAnimationProportion - Return DefaultAnimationTween for the given proportion
      //  with a bit of bounds checking.
      function getAnimationProportion( iProportion) {
        if( iProportion >= 1)
          return 1;
        else
          return DG.AnimationMath.DefaultAnimationTween( iProportion);
      }

      // tween - Simple tween using iAnimationProportion
      function tween( iStart, iEnd, iAnimationProportion) {
        return iStart + iAnimationProportion * (iEnd - iStart);
      }

      // moveAxisBounds - We're gradually changing the axis domain by tween from its
      //  oldBounds to its newBounds
      function moveAxisBounds( iInfo) {
        var tLower = tween( iInfo.oldBounds.lower,
                  iInfo.newBounds.lower, tAnimationProportion),
            tUpper = tween( iInfo.oldBounds.upper,
                    iInfo.newBounds.upper, tAnimationProportion);
        iInfo.axis.setLowerAndUpperBounds( tLower, tUpper);
      }

      tAnimationProportion = getAnimationProportion( tCurrProportion);

      this_.axisInfoArray.forEach( moveAxisBounds);

      if( tCurrProportion < 1) {
        DG.assert( !this_.animationTimer.get( 'isPaused'));
      }
      else {
        this_.endAnimation( iTarget, iCompletionFunc);
      }
    } // animationLoop

    function setupAxis( iAxisInfo) {
      iAxisInfo.oldBounds = { lower: iAxisInfo.axis.get('lowerBound'),
                  upper: iAxisInfo.axis.get('upperBound') };
    }

    var noAxisHasAnimatableScale = function() {
      var tSomeCanAnimate = this.axisInfoArray.some( function( iAxisInfo) {
        return iAxisInfo.axis.get('scaleCanAnimate');
      });
      return !tSomeCanAnimate;
    }.bind( this);

    if( this.isAnimating) {
      this.endAnimation();
    }
    this.isAnimating = true;

    this.savedAxisInfoArray = this.axisInfoArray; // so new caller won't wipe it out.

    this.axisInfoArray.forEach( setupAxis);

    if( noAxisHasAnimatableScale()) {
      this.endAnimation();
      return; // We're only animating axes so no animation to do
    }

    this.startTime = (new Date()).valueOf();

    if( SC.none( this.animationTimer))
      this.animationTimer = SC.Timer.schedule( { action: animationLoop, interval: kInterval,
                    repeats: YES, until: false });
    this.animationTimer.set( 'isPaused', NO);

    animationLoop();
  },

  /**
   * Called when we want to cancel any pending animations
   */
  reset: function() {
    this.animationTimer.set( 'isPaused', YES);
    if( !SC.none( this.plot))
      this.setPath('plot.isAnimating', false);
    this.isAnimating = false;
  },

  /**
    We assume that my properties have been set to the aspects of the plot that are to
    be animated. If there is an animation already in progress, we end it.
  */
  endAnimation: function( iTarget, iCompletionFunc) {
    if( this.animationTimer)
      this.animationTimer.set( 'isPaused', YES);
    if( !SC.none( this.plot))
      this.setPath('plot.isAnimating', false);
    this.savedAxisInfoArray.forEach( function( iInfo) {
      iInfo.axis.setLowerAndUpperBounds( iInfo.newBounds.lower, iInfo.newBounds.upper);
    });
    this.isAnimating = false;

    if( !SC.none( iCompletionFunc))
      iCompletionFunc.call( iTarget);
  }

});


/* >>>>>>>>>> BEGIN source/components/graph/utilities/plot_case_array.js */
// ==========================================================================
//                            DG.PlotCaseArray
//
//  DG.PlotUtilities is comprised of functions generally useful in plots.
//
//  Copyright (c) 2018 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/**
 * PlotCaseArray functions _like_ an array of cases, but the order is determined by a mapping of indices.
 */

DG.PlotUtilities.PlotCaseArray = SC.Object.extend( {
  /**
   * @property [DG.Case]
   */
  _cases: null,
  /**
   * @property [Number]
   */
  _map: null,

  init: function() {
    arguments.callee.base.apply(this,arguments);
    this._cases = this._cases || [];
    this._map = this._map || [];
  },

  length: function() {
    return this._map.length;
  }.property( '_map'),

  at: function( iIndex) {
    return this._cases[this._map[iIndex]];
  },

  /**
   * Return the case at the given index in the original array
   * @param iIndex {Number}
   * @return {DG.Case}
   */
  unorderedAt: function( iIndex) {
    return this._cases[iIndex];
  },

  push: function( iCase) {
    this._cases.push( iCase);
    this._map.push( this._cases.length - 1);
  },

  indexOf: function( iCase) {
    return this._cases.indexOf( iCase);
  },

  /**
   * Call the given function once for each case in the order specified by the indices in the _map array.
   * @param iDoF {Function} Signature is (case, index in the original array, index in the map array)
   *      Third parameter seldom (if ever) used.
   */
  forEach: function( iDoF) {
    this._map.forEach( function( iMapValue, iIndex) {
      iDoF( this._cases[iMapValue], iMapValue, iIndex);
    }.bind( this));
  },

  /**
   *
   * @param iDoF {Function} Called once for each case with signature (case, index in mapped order, boolean
   *    for whether the invocation is that last one. Returns true if the looping should continue or false
   *    if the looping should stop
   * @param iEndF {Function} Optional. Called after all looping invocations had ended. No parameters.
   */
  forEachWithInvokeLater: function( iDoF, iEndF) {
    var tLoopIndex = 0,
        tNumCases = this.length(),
        // Get a bit happening early with two iterations.
        tFirstIncrement = Math.min(200, tNumCases / 20),
        tCountdown = (tNumCases > 1000) ? 5 : 0,
        tIncrement = tNumCases - tCountdown * tFirstIncrement,
        tContinue = true,

        loop = function () {
          var tStopIndex = tLoopIndex + (tCountdown > 0 ? tFirstIncrement : tIncrement);
          tCountdown--;
          if (tLoopIndex < tNumCases) {
            for (; tContinue && tLoopIndex < tNumCases && tLoopIndex < tStopIndex; tLoopIndex++) {
              if (iDoF)
                tContinue = iDoF(this._cases[this._map[tLoopIndex]], this._map[tLoopIndex],
                    tLoopIndex === tNumCases - 1);
            }
            if (tContinue)
              this.invokeLater(loop, 100);
          }
          else {
            if (iEndF)
              iEndF();
          }
        }.bind(this);

    loop();
  },

  map: function( iTransF) {
    var tResult = DG.PlotUtilities.PlotCaseArray.create();
    this.forEach( function( iCase, iMapIndex) {
        tResult._cases[ iMapIndex] = iTransF( iCase, iMapIndex);
        tResult._map.push( iMapIndex);
      });
    return tResult;
  },

  filter: function( iBoolF) {
    var tResult = DG.PlotUtilities.PlotCaseArray.create();
    this.forEach( function( iCase, iMapIndex) {
      if( iBoolF( iCase, iMapIndex)) {
        var tCaseIndex = tResult._cases.length;
        tResult._cases.push( iCase);
        tResult._map.push( tCaseIndex);
      }
    }.bind( this));
    return tResult;
  },

  reduce: function( iReduceFunc, accumulator) {
    return this._cases.reduce(iReduceFunc, accumulator);
  },

  toArray: function() {
    return this._cases.slice();
  }
});
/* >>>>>>>>>> BEGIN source/components/graph/utilities/ruler_group_view.js */
// ==========================================================================
//                          DG.RulerGroupView
//
//  Author:   William Finzer
//
//  Copyright (c) 2024 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class  DG.RulerGroupView - Serves as a base for views that allow the full set of univariate
 * adornments.
 @extends SC.View
 */

var kMargin = 0,
   kLeading = 5,
   kPaddingRight = 5;

DG.RulerGroupView = SC.View.extend(SC.FlowedLayout,
    /** @scope DG.RulerGroupView.prototype */
{
  visibilityStateProperty: '',
  localizable: true,
  layoutDirection: SC.LAYOUT_VERTICAL,
  isResizable: false,
  isClosable: false,
  defaultFlowSpacing: {left: kMargin, bottom: kLeading},
  canWrap: false,
  align: SC.ALIGN_TOP,
  layout: {top: kLeading, right: kPaddingRight},
  childViews: 'toggleView'.w(),
  toggleView: SC.DisclosureView.design({
    classNames: 'dg-disclosure'.w(),
    layout: { width: 200, height: 18 },
    value: false,
  }),
  init: function() {
    var this_ = this;
    arguments.callee.base.apply(this,arguments);
    this.setPath('toggleView.title', this.get('title'));
    // By default the toggleView's value is false. The desired value is stored in the
    // DG.UnivariateAdornmentBaseModel.rulerState hash, but we wait to set it until
    // to avoid SC layout problems with SC.ButtonView's.
    this.invokeLater( function() {
      this_.setPath('toggleView.value',
         DG.UnivariateAdornmentBaseModel.rulerState[this.get('visibilityStateProperty')]);
    }, 100);
  },
  forEachControlView: function( iDoF) {
    var tToggleView = this.get('toggleView');
    this.get('childViews').forEach( function( iChildView) {
      iChildView !== tToggleView && iDoF( iChildView);
    });
  },
  syncChildViewVisibility: function() {
    var this_ = this;
    this.forEachControlView( function( iChildView) {
      iChildView.set('isVisible', this_.getPath('toggleView.value'));
    });
  },
  toggleViewValueDidChange: function() {
    this.syncChildViewVisibility();
    DG.UnivariateAdornmentBaseModel.rulerState[this.get('visibilityStateProperty')] = this.getPath('toggleView.value');
  }.observes('.toggleView.value'),
});

/* >>>>>>>>>> BEGIN source/components/graph_map_common/drag_label_handler.js */
// ==========================================================================
//                            DG.DragLabelHandler
//
//  Author:   William Finzer
//
//  Copyright ©2016 Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class  DG.DragLabelHandler - A small object that can hold onto information needed to drag an axis or legend
 * label and initiate the drag that SproutCore expects.

 @extends SC.Object
 */
DG.DragLabelHandler = SC.Object.extend(
    (function () {
    var kMinDrag = 5; // minimum distance in pixels to enable a drag

  /** @scope DG.DragLabelHandler.prototype */
  return {
    /**
     * @property{LabelNode}
     */
    labelNode: null,

    /**
     * @property{SC.View}
     */
    labelView: null,

    /**
     * @property{SC.View}
     */
    viewToAddTo: null,

    /**
     * @property{DG.AttributePlacementDescription
     */
    attributeDescription: null,

    /**
     * @property {String}
     */
    attributeName: null,

    attributeDidChange: function() {
      this.set('attributeName', this.getPath('attributeDescription.attribute.name'));
    }.observes('attributeDescription.attribute'),

    /**
     * @property{DG.DataContext}
     */
    dataContext: null,

    receivedStartDrag: false,
    receivedDoDrag: false,

    /**
     * @param iX {number} x coordinate of pointer
     * @param iY {number} y coordinate of pointer
     * @param iEvent
     */
    handleStartDrag: function( iX, iY, iEvent) {
      var tDragView = this.labelView,
          tAttributeName = this.get('attributeName');
      SC.run(function () {
        // Make sure dragView is in front. Won't actually happen without this runloop.
        tDragView.set('value', tAttributeName);
        this.viewToAddTo.removeChild(tDragView);
        this.viewToAddTo.appendChild(tDragView);
      }.bind( this));

      this.receivedStartDrag = true;
      this.receivedDoDrag = false;
    },

    /**
     * Handles a drag movement.
     * @param idX {number} delta x from initial position
     * @param idY delta y from initial position
     * @param iX {number}
     * @param iY {number}
     * @param iEvent {Event}
     */
    handleDoDrag: function( idX, idY, iX, iY, iEvent) {
      var dist;
      if( this.receivedStartDrag && !this.receivedDoDrag ) {
        dist = Math.sqrt( (idX * idX) + (idY * idY) );
        if (dist < kMinDrag) {
          return;
        }
        this.receivedDoDrag = true;
        var tDragView = this.labelView,
            tAttributeName = this.get('attributeName'),
            tAttrDesc = this.attributeDescription,
            tAttribute = tAttrDesc.attributeNamed( tAttributeName),
            tCollectionClient = tAttrDesc.get('collectionClient'),
            tContext = this.dataContext;
        if( !tAttribute)
            return;
        this.labelNode.ignoreTouchEnd();
        // Initiate a drag
        SC.run( function() {
          DG.Drag.start({
            event: iEvent,
            source: this.viewToAddTo,
            dragView: tDragView,
            ghost: YES,
            ghostActsLikeCursor: YES,
            slideBack: YES,
            origin: {x: iEvent.clientX, y: iEvent.clientY},
            data: {
              context: tContext,
              collection: tCollectionClient.get('collection'),
              attribute: tAttribute,
              text: tAttributeName
            }  // For use by clients like the text box
          });
        }.bind(this));
      }
    },

    handleEndDrag: function() {
      this.receivedStartDrag = false;
      this.receivedDoDrag = false;
      this.labelNode.reinstateTouchEnd();
    }
  };
}()) );


/* >>>>>>>>>> BEGIN source/components/graph_map_common/info_tip.js */
// ==========================================================================
//                            DG.InfoTip
//
//  Author:   William Finzer
//
//  Copyright (c) 2016 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('utilities/tool_tip');

/** @class DG.InfoTip A simple adornment-like class that displays and updates a data tip that shows
 *        at the behest of the owner

  @extends DG.DataTip
*/
DG.InfoTip = DG.DataTip.extend(
/** @scope DG.InfoTip.prototype */
{
  layerName: 'dataTip',
  getDataTipText: function () {
    var tResult = '';
    if (this.info) {
      tResult = this.info.tipString.loc(this.info.tipValue);
    }
    return tResult;
  },

  show: function (iInfo) {
    this.tipOrigin = {x: iInfo.x, y: iInfo.y};
    this.info = {tipString: iInfo.tipString, tipValue: iInfo.tipValue};

    arguments.callee.base.apply(this,arguments);
  }

});

/* >>>>>>>>>> BEGIN source/components/graph_map_common/label_node.js */
// ==========================================================================
//                            DG.LabelNode
//
//  Author:   William Finzer
//
//  Copyright ©2016 Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class  DG.LabelNode - Displays a label for an axis or legend. Expects to be hooked up with a
 * DragLabelHandler.

 @extends SC.Object
 */
DG.LabelNode = SC.Object.extend(
  /** @scope DG.LabelNode.prototype */
    {
      paper: null,// supplied by creator
      clickCallback: null,  // supplied by creator
      text: null,
      description: null,
      labelIndex: 0,        // supplied by creator
      colorIndex: 0,        // supplied by creator
      numColors: 1,
      rotation: 0,
      priorNode: null,
      loc: null,  // {x, y}
      _circleElement: null,
      _textElement: null,
      kCircleRadius: 6,
      anchor: 'middle',
      touchEndHandler: null,
      getPointColor: null,  // May be set by creator to an accessor function

      bBox: function() {
        return this._textElement.getBBox();
      }.property('text'),

      init: function() {

        this._textElement = this.paper.text(0, 0, '')
            .attr( 'text-anchor', this.anchor);
        DG.RenderingUtilities.rotateText(this._textElement, this.rotation, 0, 0);
        this.numColorsChanged();
      },

      destroy: function() {
        var tHandler = this.get('touchEndHandler');
        this._textElement.undrag();
        this.unmousedown(tHandler);
        arguments.callee.base.apply(this,arguments);
      },

      hide: function() {
        this._textElement.hide();
        if( this._circleElement)
          this._circleElement.hide();
      },

      show: function() {
        this._textElement.show();
        if( this._circleElement)
          this._circleElement.show();
      },

      numColorsChanged: function() {
        var tTextColor = 'blue',
            tPointColor = 'lightblue';
        this._textElement.addClass('dg-axis-label');
        this._textElement.removeClass('dg-axis-label-empty-graph');
        switch( this.numColors) {
          case 0:
            tTextColor = DG.PlotUtilities.kEmptyPromptColor;
            this._textElement.removeClass('dg-axis-label');
            this._textElement.addClass('dg-axis-label-empty-graph');
            break;
          case 1:
            tTextColor = 'blue';
            tPointColor = 'lightblue';
            break;
          default:
            if (this.colorIndex === 0) {
              tTextColor = this.getPointColor ? this.getPointColor() : DG.PlotUtilities.kDefaultPointColor;
            }
            else {
              tTextColor = DG.ColorUtilities.calcAttributeColorFromIndex(this.colorIndex, this.numColors);
            }
            tPointColor = tTextColor;
        }
        this._textElement.attr('fill', tTextColor);

        if((this.numColors > 1) && !this._circleElement) {
          this._circleElement = this.paper.circle(0, 0, this.kCircleRadius)
              .addClass('dg-axis-dot');
        }
        else if((this.numColors <= 1) && this._circleElement) {
          this._circleElement.remove();
          this._circleElement = null;
        }
        if( this._circleElement)
          this._circleElement.attr('fill', tPointColor);
      }.observes('numColors'),

      textChanged: function() {
        this._textElement.attr('text', this.text);
      }.observes('text'),

      descriptionChanged: function() {
        this._textElement.attr('title', this.description);
      }.observes('description'),

      locChanged: function() {
        var tYOffset = this._circleElement ? this.kCircleRadius / 2 : 0;
        this._textElement.attr({ x: this.loc.x, y: this.loc.y - tYOffset });
        DG.RenderingUtilities.rotateText(this._textElement, this.rotation, this.loc.x, this.loc.y - tYOffset);
        if( this._circleElement) {
          var tBox = this._textElement.getBBox(),
              tCenter;
          if (this.rotation !== 0) {
            tCenter = { cx: this.loc.x + 1, cy: this.loc.y - tYOffset + tBox.height / 2 + this.kCircleRadius + 2 };
          }
          else {
            tCenter = { cx: this.loc.x - (tBox.width / 2 + this.kCircleRadius + 2), cy: this.loc.y };
          }
          this._circleElement.attr( tCenter);
        }
      }.observes('loc'),

      extent: function() {
        var tResult = this._textElement.getBBox();
        if( this._circleElement) {
          tResult.width += (this.rotation === 0) ? 2 * this.kCircleRadius + 2 : 0;
          tResult.height += (this.rotation !== 0) ? 2 * this.kCircleRadius + 2 : 0;
        }
        return tResult;
      },

      mousedown: function( iHandler) {
        this._textElement.click( iHandler);
        this._textElement.touchend( iHandler);
        this.set('touchEndHandler', iHandler);
        this._circleElement && this._circleElement.click( iHandler);
      },

      unmousedown: function( iHandler) {

        function unbindElement(iElement) {
          var tEvents = iElement && iElement.events;
          if( SC.isArray( tEvents)) {
            var l = tEvents.length;
            while (l--){
              if (tEvents[l].name === 'click' || tEvents[l].name === 'touchend') {
                tEvents[l].unbind();
                tEvents.splice(l, 1);
                !tEvents.length && delete iElement.events;
              }
            }
          }
        }
/*
        this._textElement.unclick( iHandler);
        this._textElement.untouchend( iHandler);
        this._circleElement && this._circleElement.unclick( iHandler);
*/
        unbindElement( this._textElement);
        unbindElement( this._circleElement);
        this.set('touchEndHandler', null);
      },

      ignoreTouchEnd: function() {
        this._textElement.untouchend();
      },

      reinstateTouchEnd: function() {
        this._textElement.touchend( this.get('touchEndHandler'));
      },

      /**
       *
       * @param {DG.DragLabelHandler}
       * @returns {LabelNode}
       */
      setDragLabelHandler: function( iHandler) {
        this._textElement.drag( iHandler.handleDoDrag, iHandler.handleStartDrag, iHandler.handleEndDrag,
            iHandler, iHandler, iHandler);
        //this._circleElement && this._circleElement.drag( null, iHandler.handleDrag, null, null, iHandler);
        return this;
      },

      remove: function() {
        this._textElement.remove();
        this._circleElement && this._circleElement.remove();
      }
    }
 );


/* >>>>>>>>>> BEGIN source/components/graph_map_common/legend/categories_view.js */
// ==========================================================================
//                            DG.CategoriesView
//
//  Author:   William Finzer
//
//  Copyright (c) 2018 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('views/raphael_base');

/** @class  DG.CategoriesView - View of portion of legend that displays squares for each category of
 * a legend. The squares are selectable and can be dragged to change order.

 @extends DG.RaphaelBaseView
 */
DG.CategoriesView = DG.RaphaelBaseView.extend(
    (function () {
          var kMaxWidth = 150, // of a cell. Used to determine how many columns
              kMinWidth = 20,
              kDefaultRectSize = 14;

          var CategoryKey = SC.Object.extend({
            model: null,
            paper: null,

            /**
             * @property { String}
             */
            cellName: null,

            /**
             * Function set on initialization. Returns integer.
             */
            coordinatesToCellNum: null,

            // @property { Raphael Element }
            keyRect: null,
            // @property { Raphael Element }
            keyText: null,
            color: null,

            left: 0,
            top: 0,
            rectSize: 0,
            spaceForText: 0,

            containingView: null,

            init: function () {
              var this_ = this,
                  tView = this.containingView,
                  tStartingCellnames, tInitialCell, tDragStartCoord, tCellBeingDragged, tOffset,
                  rectHover = function( iEvent) {
                    this.transform('s1.2');
                  },
                  rectUnhover = function( iEvent) {
                    this.transform('');
                  },
                  selectCasesInCell = function (iEvent) {
                    SC.run(function () {
                      this_.get('model').selectCasesInCell(this_.cellName, iEvent.shiftKey);
                    }.bind(this));
                  },
                  beginDrag = function (iWindowX, iWindowY) {
                    tStartingCellnames = this_.getPath('model.cellNames');
                    tDragStartCoord = DG.ViewUtilities.windowToViewCoordinates({x: iWindowX, y: iWindowY}, tView);
                    tInitialCell = tCellBeingDragged = this_.coordinatesToCellNum(tDragStartCoord);
                    tOffset = {
                      x: this_.left - tDragStartCoord.x,
                      y: this_.top - tDragStartCoord.y
                    };
                  },
                  doDrag = function (iDeltaX, iDeltaY, iWindowX, iWindowY) {
                    var tModel = this_.get('model'),
                        tCurrentCoord = {
                          x: tDragStartCoord.x + iDeltaX,
                          y: tDragStartCoord.y + iDeltaY
                        },
                        tCategoryInCurrentCell = this_.coordinatesToCellNum(tCurrentCoord);
                    // Todo Touch is currently returning NaN for window coordinates. Fix this
                    if (isNaN(tCurrentCoord.x) || isNaN(tCurrentCoord.y) || isNaN(tCategoryInCurrentCell))
                      return;
                    SC.run(function () {
                      if (tCategoryInCurrentCell !== tCellBeingDragged) {
                        tCellBeingDragged = swapCategories( tModel.get('attributeDescription'),
                            tCategoryInCurrentCell, tCellBeingDragged);
                      }
                      tView.set('dragInfo', {
                        cellBeingDragged: tCellBeingDragged,
                        offset: tOffset,
                        position: tCurrentCoord
                      });
                      tView.displayDidChange();
                      tView.propertyDidChange('categoriesDragged');
                    });
                  },
                  endDrag = function (iEvent) {
                    SC.run(function () {
                      tView.set('dragInfo', null);
                      tView.displayDidChange();
                      tView.propertyDidChange('categoriesDragged');
                      tView.updateLayerIfNeeded();
                    });
                    if( tInitialCell !== tCellBeingDragged) {
                      var tCat1 = tStartingCellnames[tInitialCell],
                          tCat2 = tStartingCellnames[tCellBeingDragged];
                      DG.UndoHistory.execute(DG.Command.create({
                        name: 'swapCategories',
                        undoString: 'DG.Undo.graph.swapCategories',
                        redoString: 'DG.Redo.graph.swapCategories',
                        log: 'Moved category %@ into position of %@'.fmt(tCat1, tCat2),
                        _initialCell: tInitialCell,
                        _finalCell: tCellBeingDragged,
                        _legendModel: this_.get('model'),
                        execute: function () {
                        },
                        undo: function () {
                          swapCategories( this._legendModel.get('attributeDescription'),
                              this._initialCell, this._finalCell);
                          var temp = this._initialCell;
                          this._initialCell = this._finalCell;
                          this._finalCell = temp;
                        },
                        redo: function () {
                          this.undo();
                        }
                      }));
                    }
                  },
              swapCategories = function( iAttributeDescription, iCat1, iCat2) {
                var tSign = Math.sign(iCat1 - iCat2),
                    tCellToSwap = iCat2 + tSign;
                // Insist on pairwise swaps until we get one beyond iCat1
                while (tCellToSwap !== iCat1 + tSign) {
                  DG.PlotUtilities.swapCategoriesByIndex(iAttributeDescription, iCat2, tCellToSwap);
                  tCellToSwap += tSign;
                  iCat2 += tSign;
                }
                return iCat2;
              };

              this.keyRect = this.paper.rect(0, 0, this.rectSize, this.rectSize)
                  .attr({fill: this.color})
                  .addClass(DG.PlotUtilities.kLegendKey)
                  .mouseover(rectHover)
                  .mouseout( rectUnhover)
                  .mousedown(selectCasesInCell)
                  .drag(doDrag, beginDrag, endDrag);
              this.keyText = this.paper.text(0, 0, this.cellName)
                  .attr({'text-anchor': 'start'})
                  .addClass(DG.PlotUtilities.kLegendKeyName)
                  .mousedown(selectCasesInCell)
                  .drag(doDrag, beginDrag, endDrag);
            },

            destroy: function () {
              this.keyRect.remove();
              this.keyText.remove();
              this.containingView = null;

              arguments.callee.base.apply(this,arguments);
            },

            draw: function (iAnimate) {
              // body of draw
              var tRectAttrs = {
                    x: this.left,
                    y: this.top,
                    width: this.rectSize,
                    height: this.rectSize,
                    fill: this.color
                  },
                  tTextAttrs = {
                    x: this.left + this.rectSize + 5,
                    y: this.top + this.rectSize - 5,
                  };
              if (iAnimate) {
                this.keyRect.animate(tRectAttrs, 100, '<>');
                this.keyText.animate(tTextAttrs, 100, '<>');
              }
              else {
                this.keyRect.attr(tRectAttrs);
                this.keyText.attr(tTextAttrs);
              }
              this.keyText.attr('text', this.cellName);
              DG.RenderingUtilities.elideToFit( this.keyText, this.spaceForText);
            }
          });

          /** @scope DG.CategoriesView.prototype */
          return {
            displayProperties: ['model.attributeDescription.attribute',
              'model.attributeDescription.attributeStats.categoricalStats.numberOfCells',
              'model.updateCases'],

            /**
             Set by owning LegendView on creation
             @property { DG.LegendModel }
             */
            model: null,

            /**
             * Hash of category names to CategoryKey
             * @property { Object }
             */
            categoryKeys: null,

            /**
             * @property {Object}
             */
            dragInfo: null,

            // These are used during a drag of a categoryKey to compute current cell of mouse
            colWidth: null,
            rowHeight: null,
            numColumns: 2,

            init: function () {
              arguments.callee.base.apply(this,arguments);
              this.categoryKeys = {};
            },

            maxCellNameExtent: function () {
              var tMaxExtent = 0,
                  tPaper = this.get('paper'),
                  tCellNames = this.getPath('model.cellNames');
              if (!tPaper || !tCellNames)
                return kMaxWidth;
              tCellNames.forEach(function (iName) {
                tMaxExtent = Math.max(tMaxExtent,
                    DG.RenderingUtilities.textExtent( iName).x);
              });
              return tMaxExtent + kDefaultRectSize + 10;
            },

            desiredExtent: function (iRowHeight) {

              var tCellWidth = Math.max(kMinWidth, Math.min(kMaxWidth, this.maxCellNameExtent())),
                  tWidth = this.getPath('frame.width') || tCellWidth,
                  tNumColumns = Math.max(2, Math.floor(tWidth / tCellWidth)),
                  tNumCells = this.model ? this.getPath('model.numberOfCells') : 0,
                  tNumRows = Math.ceil(tNumCells / tNumColumns);
              return tNumRows * iRowHeight;
            },

            doDraw: function doDraw() {
              if( !this.get('isVisible'))
                return;
              var tAttrDesc = this.getPath('model.attributeDescription'),
                  tWidth = this._paper.width,
                  tHeight = this._paper.height,
                  tColWidth = Math.max(kMinWidth, Math.min(kMaxWidth, this.maxCellNameExtent()+5)),
                  tNumColumns = Math.max(2, Math.floor(tWidth / tColWidth)),
                  tNumCells = this.getPath('model.numberOfCells'),
                  tNumRows = Math.ceil(tNumCells / tNumColumns),
                  tRowHeight = tHeight / tNumRows,
                  tCellIndex,
                  tCellNames = this.getPath('model.cellNames'),
                  tCategoryKeys = this.get('categoryKeys'),
                  coordinatesToCellNum = function (iCoords) {
                    var tCol = Math.min( this.numColumns - 1, Math.max(0, Math.floor(iCoords.x / this.colWidth))),
                        tRow = Math.min( this.numRows - 1, Math.max(0, Math.floor(iCoords.y / this.rowHeight))),
                        tCellNum = Math.min( this.numCells - 1, tCol + tRow * this.numColumns);
                    return tCellNum;
                  }.bind(this);
              // Stash the quantities we will need when coordinatesToCellNum is called
              this.set('rowHeight', tRowHeight);
              this.set('colWidth', tColWidth);
              this.set('numColumns', tNumColumns);
              this.set('numRows', tNumRows);
              this.set('numCells', tNumCells);
              // Mark them all as unused so we can get rid of ones no longer present
              DG.ObjectMap.forEach(tCategoryKeys, function (iName, iKey) {
                iKey.set('inUse', false);
              });

              for (tCellIndex = 0; tCellIndex < tNumCells && tCellIndex < tCellNames.length; tCellIndex++) {
                var tName = tCellNames[tCellIndex],
                    tColor = DG.ColorUtilities.calcCaseColor(tName, tAttrDesc),
                    tRow = Math.floor(tCellIndex / tNumColumns),
                    tCol = tCellIndex % tNumColumns,
                    tCategoryKey = tCategoryKeys[tName],
                    tIsDraggedCell = this.dragInfo && this.dragInfo.cellBeingDragged === tCellIndex;
                tColor = tColor.colorString || tColor;
                if (!tCategoryKey) {
                  tCategoryKeys[tName] = tCategoryKey = CategoryKey.create({
                    model: this.get('model'),
                    paper: this.get('paper'),
                    containingView: this,
                    coordinatesToCellNum: coordinatesToCellNum
                  });
                }
                if (tIsDraggedCell) {
                  tCategoryKey.set('left', this.dragInfo.position.x + this.dragInfo.offset.x);
                  tCategoryKey.set('top', this.dragInfo.position.y + this.dragInfo.offset.y);
                } else {
                  tCategoryKey.set('left', tCol * tWidth / tNumColumns + 2);
                  tCategoryKey.set('top', tRow * tRowHeight + 2);
                }
                tCategoryKey.set('rectSize', tRowHeight - 5);
                tCategoryKey.set('spaceForText', tWidth / tNumColumns - (tRowHeight - 5) - 8);
                tCategoryKey.set('color', tColor);
                tCategoryKey.set('cellName', tName);
                tCategoryKey.set('inUse', true);
                tCategoryKey.draw(!tIsDraggedCell);
              }

              // Those that are unused get destroyed
              DG.ObjectMap.forEach(tCategoryKeys, function (iName, iKey) {
                if (!iKey.inUse) {
                  iKey.destroy();
                  delete tCategoryKeys[iName];
                }
              });

            },

            selectionDidChange: function() {
              var tSelectionMap = this.getPath('model.selectionMap'),
                  tCategoryKeys = this.get('categoryKeys');
              if (SC.none(tSelectionMap) || SC.none(tCategoryKeys))
                return;
              DG.ObjectMap.forEach(tCategoryKeys, function (iCategory, iCatKey) {
                if (tSelectionMap[iCategory]) {
                  iCatKey.keyRect.addClass(DG.PlotUtilities.kLegendKeySelected);
                }
                else {
                  iCatKey.keyRect.removeClass(DG.PlotUtilities.kLegendKeySelected);
                }
              });
            }.observes('*model.selectionMap')

          };
        }()
    ))
;


/* >>>>>>>>>> BEGIN source/components/graph_map_common/legend/choropleth_view.js */
// ==========================================================================
//                            DG.ChoroplethView
//
//  Author:   William Finzer
//
//  Copyright (c) 2016 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('views/raphael_base');

/** @class  DG.ChoroplethView - View of portion of legend that displays a segmented rectangle
 *            of colors for an attribute. Gives user control over segment number and boundaries.

 @extends DG.RaphaelBaseView
 */
DG.ChoroplethView = DG.RaphaelBaseView.extend(
    (function () {
      var kRectHeight = 16,
          kTickLength = 3; // pixels

      /** @scope DG.ChoroplethView.prototype */
      return {
        displayProperties: ['model.attributeDescription.attribute',
          'model.numericRange', 'model.dataConfiguration.legendQuantilesAreLocked'],

        /**
         Set by owning LegendView on creation
         @property { DG.LegendModel }
         */
        model: null,

        desiredExtent: function ( iRowHeight) {
          return kRectHeight + kTickLength + iRowHeight;
        },

        doDraw: function doDraw() {
          var kStrokeWidth = 0.5,
              tAttrDesc = this.getPath('model.attributeDescription'),
              tAttrType = tAttrDesc.get('attributeType'),
              tWidth = this._paper.width - 2,
              tQuantiles = this.getPath('model.dataConfiguration.legendQuantiles'),
              tQuantileN = tQuantiles.length - 1;

          var drawScale = function () {
                var tMinMax = {min: tQuantiles[0], max: tQuantiles[tQuantileN]},
                    tMin, tMax;
                if( tAttrType === DG.Analysis.EAttributeType.eNumeric) {
                  var tMinFormatter = DG.Format.number().fractionDigits(0, 2),
                      tMaxFormatter = DG.Format.number().fractionDigits(0, 2);
                  if (tMinMax.min < 2500)
                    tMinFormatter.group('');
                  if (tMinMax.max < 2500)
                    tMaxFormatter.group('');
                  tMin = tMinFormatter(tMinMax.min);
                  tMax = tMaxFormatter(tMinMax.max);
                }
                else if( tAttrType === DG.Analysis.EAttributeType.eDateTime) {
                  tMin = DG.formatDate( tMinMax.min);
                  tMax = DG.formatDate( tMinMax.max);
                }
                var tTextY = kRectHeight + kTickLength + DG.RenderingUtilities.kDefaultFontHeight / 2;
                this._elementsToClear.push(this._paper.text(kStrokeWidth, tTextY, tMin)
                    .attr({'text-anchor': 'start'}));
                this._elementsToClear.push(this._paper.text(tWidth - 2 * kStrokeWidth, tTextY, tMax)
                    .attr({'text-anchor': 'end'}));
              }.bind(this),

              drawQuantiles = function () {

                var tMinMax = {min: 0, max: 1},
                    tCategoryMap = tAttrDesc.getPath('attribute.categoryMap'),
                    tAttrColor = DG.ColorUtilities.calcAttributeColor( tAttrDesc),
                    tSpectrumEnds = DG.ColorUtilities.getAttributeColorSpectrumEndsFromColorMap(tCategoryMap, tAttrColor);
                tQuantiles.forEach(function (iStartValue, iIndex) {
                  if ((typeof iStartValue === 'number') && iIndex < tQuantileN) {
                    var tStopValue = tQuantiles[iIndex + 1],
                        tLeft = tWidth * iIndex / tQuantileN,
                        tRight = tLeft + tWidth * (iIndex +1) / tQuantileN,
                        tColor = DG.ColorUtilities.calcGradientColor(tMinMax, tSpectrumEnds.low, tSpectrumEnds.high,
                            (iIndex + 1)/ tQuantileN),
                        tTitle = tAttrType === DG.Analysis.EAttributeType.eNumeric ?
                            '%@ – %@'.fmt( Math.round(iStartValue * 100) / 100,
                                Math.round(tStopValue * 100) / 100) :
                            '%@ – %@'.fmt(DG.formatDate(iStartValue), DG.formatDate(tStopValue)),
                        tRect = this._paper.rect(tLeft, 0, 0, 0)
                            .attr({
                              width: tRight - tLeft, height: kRectHeight,
                              fill: tColor.colorString || tColor,
                              'stroke-width': kStrokeWidth,
                              title: tTitle
                            })
                            .addClass('dg-choro-rect')
                            .click( function( iEvent) {
                              this.selectCasesBetween( iStartValue, tStopValue, iEvent.shiftKey);
                            }.bind( this));
                    this._elementsToClear.push( tRect);
                  }
                }.bind(this));
              }.bind(this);

          if (!tAttrDesc || tAttrDesc.get('attribute') === null)
            return;
          drawScale();
          drawQuantiles();

        },

        selectCasesBetween: function( iLower, iUpper, iExtend) {
          var tAttrID = this.getPath('model.attributeDescription.attribute.id'),
              tCases = this.getPath('model.dataConfiguration.cases'),
              tAttrName = this.getPath('model.attributeDescription.attribute.name'),
              tChange = {
                operation: 'selectCases',
                collection: this.getPath('dataConfiguration.collectionClient'),
                cases: [],
                select: true,
                extend: iExtend
              };
          if( SC.none( tAttrID) || SC.none( tCases))
              return;
          tCases.forEach( function( iCase) {
            var tValue = iCase.getNumValue( tAttrID);
            if( tValue >= iLower && tValue <= iUpper)
                tChange.cases.push( iCase);
          });
          this.getPath('model.dataConfiguration.dataContext').applyChange( tChange);
          DG.logUser("caseSelected with values of: %@ between %@ and %@", tAttrName, iLower, iUpper);

        }

      };
    }()));


/* >>>>>>>>>> BEGIN source/components/graph_map_common/legend/legend_model.js */
// ==========================================================================
//                          DG.LegendModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class DG.LegendModel - The model for a graph legend.

  @extends SC.Object
*/
DG.LegendModel = SC.Object.extend(
/** @scope DG.LegendModel.prototype */ 
{
  /**
   * @property { DG.PlotDataConfiguration }
   */
  dataConfiguration: null,

  /**
   *
    @property { DG.AttributePlacementDescription }
  */
  attributeDescription: null,

  /**
   * Has properties corresponding to categories for which each of the corresponding
   * cases are selected. Value of property is true.
   * @property {Object}
   */
  selectionMap: null,

  /**
   * isNumeric
   * @property {Boolean}
   */
  isNumeric: function() {
    return this.getPath('attributeDescription.isNumeric');
  }.property(),

  isNumericDidChange: function() {
    this.notifyPropertyChange('isNumeric');
  }.observes('*attributeDescription.isNumeric'),

  /**
    The string that will be used to label the legend.
    @property { String }
  */
  label: function() {
    var tResult = '',
        tDesc = this.get('attributeDescription'),
        tAttr = SC.none( tDesc) ? DG.Analysis.kNullAttribute : tDesc.get('attribute'),
        tName = tAttr && tAttr.get('name' ),
        tUnit = tAttr && tAttr.get('unit' );
    if( tAttr !== DG.Analysis.kNullAttribute)
        tResult = tName + (!SC.empty( tUnit) ? ' (' + tUnit + ')' : '');
    return tResult;
  }.property(),
  labelDidChange: function() {
    this.notifyPropertyChange('label');
  }.observes('*attributeDescription.attribute'),

  /**
   * Some property of the attribute with the given ID has changed, typically its name or unit
   * @param iAttrID {Number}
   */
  handleUpdateAttribute: function( iAttrID) {
    this.labelDidChange();
  },

  /**
   Determined by asking attributeStats
   @property{Number}  >= 0
   */
  numberOfCells: function () {
    var tNumCells = this.getPath('attributeDescription.attributeStats.numberOfCells');
    return DG.MathUtilities.isFinite( tNumCells) ? Math.max(1, tNumCells) : 0;
  }.property(),

  numberOfCellsDidChange: function() {
    this.notifyPropertyChange('numberOfCells');
  }.observes('*attributeDescription.attributeStats.numberOfCells'),

  cellMapDidChange: function() {
    this.updateSelection();
  }.observes('attributeDescription.attributeStats.categoricalStats.cellMap'),

  /**
    Determined by asking attributeStats
    @property{min: {Number}, max: {Number}}
  */
    numericRange: function() {
      return this.getPath('attributeDescription.attributeStats.numericRange');
    }.property(),

    numericRangeDidChange: function() {
      this.notifyPropertyChange('numericRange');
    }.observes('*attributeDescription.attributeStats.numericRange'),

  /**
    Determined by asking attributeStats
    @property{[{String}]}
  */
  cellNames: function() {
    return this.getPath('attributeDescription.cellNames');
  }.property(),
  cellNamesDidChange: function() {
    this.notifyPropertyChange('cellNames');
  }.observes('*attributeDescription.attributeStats.cellMap'),

  /**
   * Select the cases whose value for the legend attribute places them in the given cell.
   * @param iCellIndex{Number}
   */
  selectCasesInCell: function( iCellName, iExtend) {
    var tCollection = this.getPath('attributeDescription.collectionClient'),
        tContext = tCollection && DG.DataContext.getContextFromCollection( tCollection),
        tCases = this.get('attributeDescription').casesForCategory( iCellName),
        tChange = {
                    operation: 'selectCases',
                    collection: tCollection,
                    cases: tCases,
                    select: true,
                    extend: iExtend
                  };
    if( tContext && tCases)
      tContext.applyChange( tChange);
  },

  /**
   * If the newly assigned attribute is categorical, make sure it has a categoryMap so that
   * colors won't change willy nilly.
   */
  attributeDidChange: function() {
    var tAttrDesc = this.get('attributeDescription'),
        tAttribute = tAttrDesc.get('attribute'),
        tColormap = tAttribute && (tAttribute !== DG.Analysis.kNullAttribute) && tAttribute.get('categoryMap');
    if( !tAttribute || (tAttribute === DG.Analysis.kNullAttribute) || tAttrDesc.get('isNumeric'))
      return; // Nothing assigned or the attribute is numeric
    tColormap = tColormap || {};
    this.get('cellNames').forEach( function( iName) {
      var tColorProp = tColormap[ iName];
      if( !tColorProp) {
        tColormap[ iName] = DG.ColorUtilities.calcCaseColor( iName, tAttrDesc,
            DG.ColorUtilities.kMissingValueCaseColor);
      }
    });
    tAttribute.set('categoryMap', tColormap);
  }.observes('attributeDescription.attribute'),

  handleOneDataContextChange: function( iNotifier, iChange) {
    var tOperation = iChange && iChange.operation;

    switch (tOperation) {
      case 'createCases':
      case 'deleteCases':
      case 'updateCases':
      case 'dependentCases':
        // Changes to categorical legends are handled via numberOfCellsDidChange()
        // and cellMapDidChange() notifications which bubble up from the AttributeStats.
        // In code review with Bill we decided to leave the handling of numerical
        // legend changes here for now. At some point, either both numeric and
        // categorical should be handled here (and the observers of AttributeStats
        // could potentially be removed) or the AttributeStats notification should
        // be fixed so that the numeric case works that way as well and this code
        // could potentially be removed.
        if (this.get('isNumeric'))
          this.numericRangeDidChange();
        else
          this.notifyPropertyChange('updateCases');
        break;
      case 'selectCases':
        this.updateSelection();
        break;
    }
  },

  /**
   * Our selectionMap needs to be updated such that it has properties with value true for each
   * category for which all cases are selected.
   */
  updateSelection: function() {
    var tSelectionMap = {},
        tSelection = this.getPath('dataConfiguration.collectionClient.casesController.selection'),
        tCellMap = this.getPath('attributeDescription.attributeStats.cellMap');
    DG.ObjectMap.forEach( tCellMap, function( iKey, iCell) {
      if( (iCell.cases.length > 0) &&
          iCell.cases.every(function( iCase) {
            return tSelection.containsObject( iCase);
          })) {
        tSelectionMap[ iKey] = true;
      }
    });
    this.set( 'selectionMap', tSelectionMap);
  },

});


/* >>>>>>>>>> BEGIN source/components/graph_map_common/legend/legend_view.js */
// ==========================================================================
//                            DG.LegendView
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/utilities/graph_drop_target');
sc_require('views/raphael_base');

/** @class  DG.LegendView - The base class view for a graph legend.
  
  @extends DG.RaphaelBaseView
*/
DG.LegendView = DG.RaphaelBaseView.extend( DG.GraphDropTarget,

  (function()
  {
    var kVMargin = 3,
        kHMargin = 6;
    
    /** @scope DG.LegendView.prototype */
    return {
      displayProperties: ['model.attributeDescription.attribute', 'model.attributeDescription.attribute.categoryMap'],

      classNames: ['dg-legend-view'],

      /**
        The model on which this view is based.
        @property { DG.LegendModel }
      */
      model: null,

      /**
        A legend view is neither horizontal or vertical. Distinguish it from axes
        @property { String }
      */
      orientation: DG.GraphTypes.EOrientation.kNone,

      /**
       * @property {DG.CategoriesView}
       */
      categoriesView: null,

      /**
       * @property {DG.ChoroplethView}
       */
      choroplethView: null,

      modelDidChange: function() {
        this.setPath('categoriesView.model', this.get('model'));
        this.setPath('choroplethView.model', this.get('model'));
      }.observes('model'),

      /**
       * @property {DG.Attribute}
       */
      plottedAttribute: function() {
        return this.getPath('model.attributeDescription.attribute');
      }.property(),

      /**
       * For a numeric legend we just need a single row for the color gradient rectangle.
       * For a categorical legend, we'll put two categories in each row.
       *
        @property { Number }
      */
      desiredExtent: function() {
        var tLabelHeight = this.get('labelExtent').y,
            tExtent = tLabelHeight + (tLabelHeight === 0 ? 0 : 2 * kVMargin);
        switch( this.get('attributeType')) {
          case DG.Analysis.EAttributeType.eNumeric:
          case DG.Analysis.EAttributeType.eDateTime:
            tExtent += this.get('choroplethView').desiredExtent( tLabelHeight);
            break;
          case DG.Analysis.EAttributeType.eCategorical:
            tExtent += this.get('categoriesView').desiredExtent( tLabelHeight);
            break;
          case DG.Analysis.EAttributeType.eColor:
            // Only the label displays
            break;
        }
        return tExtent;
      }.property(),
      desiredExtentDidChange: function() {
        this.notifyPropertyChange('desiredExtent');
      }.observes('labelNode', '*model.numberOfCells',
          'model.attributeDescription.attributeStats.attributeType'),

      /**
      Return the extent of the label
        @property {Point as in { x, y }}
      */
      labelExtent: function() {
        var	kMinHeight = DG.RenderingUtilities.kCaptionFontHeight,
            tLabelNode = this.get('labelNode'),
            tBox;
        if( !SC.none( tLabelNode)) {
          tBox = tLabelNode.get('bBox');
          return { x: isNaN(tBox.width) ? kMinHeight : Math.max( kMinHeight, tBox.width),
                   y: isNaN(tBox.height) ? kMinHeight : Math.max( kMinHeight, Math.ceil( tBox.height / 2) * 2) };
        }
        return { x: 0, y: 0};
      }.property('labelNode').cacheable(),

      /**
      The Raphael element used to display the label.
        @property {Raphael element}
      */
      labelNode: function() {
        var tChangeHappened = false,
            tText, tDescription;
        if( SC.none( this._paper))
          return;

        if( SC.none( this._labelNode)) {
          this._labelNode = DG.LabelNode.create({ paper: this._paper, rotation: 0,
            colorIndex: 0, numColors: 1,
            anchor: 'start'});
          this._labelNode.setDragLabelHandler( DG.DragLabelHandler.create({
            labelNode: this._labelNode,
            labelView: this._hiddenDragView,
            viewToAddTo: this,
            attributeDescription: this.getPath('model.attributeDescription'),
            attributeName: this.getPath('model.attributeDescription.attribute.name'),
            dataContext: this.getPath('model.dataConfiguration.dataContext')
          }) );

          tChangeHappened = true;
        }
        tText = this.getPath('model.label');
        // If the text has changed, we set it and notify
        if( tText !== this._labelNode.get('text')) {
          this._labelNode.set('text', tText );
          tChangeHappened = true;
        }
        tDescription = this.getPath('model.attributeDescription.attribute.description') + '—' +
                                    'DG.LegendView.attributeTooltip'.loc();
        if( tDescription !== this._labelNode.get('description')) {
          this._labelNode.set('description', tDescription );
          tChangeHappened = true;
        }
        if( tChangeHappened)
          this.notifyPropertyChange( 'labelNode', this._labelNode);

        if( SC.empty( tText))
          return null;
        else
          return this._labelNode;
      }.property(),

      labelNodeDidChange: function() {
        this.notifyPropertyChange('labelNode');
      }.observes('*model.label'),

      /**
       * Clients expect to be able to get an array, even though we only ever have one labelNode.
       * @return {Array}
       */
      labelNodes: function() {
        var tLabelNode = this.get('labelNode');
        if( tLabelNode)
          return [ tLabelNode ];
        else
          return [];
      }.property('labelNode'),

      /**
       * @private
       * @property {Raphael element}
       */
      _labelNode: null,

      /**
       * @private
       * @property {Raphael element} Used to display continuous scale as a color gradient
       */
      _hiddenDragView: null,

      init: function() {
        arguments.callee.base.apply(this,arguments);

        this.categoriesView = DG.CategoriesView.create( {
          classNames: 'dg-categories'.w(),
          layout: { left: kHMargin, right: kHMargin, top: kVMargin, bottom: kVMargin },
          isVisible: false,
          model: this.get('model'),
          rowHeight: DG.RenderingUtilities.kDefaultFontHeight
        });
        this.appendChild( this.categoriesView);

        this.choroplethView = DG.ChoroplethView.create( {
          classNames: 'dg-choropleth'.w(),
          layout: { left: kHMargin, right: kHMargin, top: kVMargin, bottom: kVMargin },
          isVisible: false,
          model: this.get('model')
        });
        this.appendChild( this.choroplethView);

        this._hiddenDragView = SC.LabelView.create({
          classNames: 'dg-drag-label'.w(),
          layout: {width: 100, height: 20, top: -50, left: 0},
          value: ''
        });
        this.appendChild( this._hiddenDragView);

        this.addObserver('model.dataConfiguration.cases', this, 'displayDidChange');
        this.addObserver('model.dataConfiguration.hiddenCases', this, 'displayDidChange');
      },

      destroy: function() {
        this.removeObserver('model.dataConfiguration.cases', this, 'displayDidChange');
        this.removeObserver('model.dataConfiguration.hiddenCases', this, 'displayDidChange');
        arguments.callee.base.apply(this,arguments);
      },

      displayDidChange: function() {
        arguments.callee.base.apply(this,arguments);
        this.get('choroplethView').displayDidChange();
        this.get('categoriesView').displayDidChange();
      },

      doDraw: function doDraw() {

        /**
         * renderLabel - Render the attribute name centered
         */
        var renderLabel = function() {
          var tLabelNode = this.get('labelNode'),
              tLabelExtent = this.get('labelExtent'),
              tDescription = this.getPath('model.attributeDescription.attribute.description') + '—' +
                  'DG.LegendView.attributeTooltip'.loc();
          if( SC.none( tLabelNode))
            return;

          tLabelNode.get('_textElement').attr({ text: this.getPath('model.label'),
                            x: kHMargin, y: tLabelExtent.y / 2});
          tLabelNode.get('_textElement').attr({ title: tDescription});
        }.bind( this);

        var tCategoriesView = this.get('categoriesView'),
            tChoroplethView = this.get('choroplethView');
        renderLabel();
        switch( this.get('attributeType')) {
          case DG.Analysis.EAttributeType.eNumeric:
          case DG.Analysis.EAttributeType.eDateTime:
            tChoroplethView.set('isVisible', true);
            tCategoriesView.set('isVisible', false);
            tChoroplethView.adjust('top', kVMargin + this.get('labelExtent').y);
            break;
          case DG.Analysis.EAttributeType.eCategorical:
            tCategoriesView.adjust('top', kVMargin + this.get('labelExtent').y);
            tCategoriesView.set('isVisible', true);
            tChoroplethView.set('isVisible', false);
            break;
        }
      },

      /**
        Graph controller observes this property to detect that a drag has taken place.
        @property {collection:{DG.CollectionRecord}, attribute:{DG.Attribute}, text:{String}}
      */
        dragData: null,

      /**
        Attempt to assign the given attribute to this legend view.
        @param {SC.Drag} 'data' property contains 'collection', 'attribute', 'text' properties
        @param {SC.DRAG_LINK}
      */
      performDragOperation: function( iDragObject, iDragOp) {
        this.hideDropHint();
        this.set('dragData', iDragObject.data);
        return SC.DRAG_LINK;
      },

      /**
        @property { Number }  Takes into account any borders the parent views may have
        [SCBUG]
      */
      drawWidth: function() {
        return Math.max( 0, this.get('frame').width - 2 * DG.ViewUtilities.kBorderWidth);
      }.property('frame'),

      /**
       * isNumeric
       * @property {Boolean}
       */
      isNumeric: function() {
        return this.getPath('model.isNumeric');
      }.property(),

      isNumericDidChange: function() {
        // TODO: Check whether this function is necessary.
        // Is anyone listening for 'isNumeric' notifications from the view?
        // If so, they should be listening to the model instead.
        this.notifyPropertyChange('isNumeric');
      }.observes('*model.isNumeric'),

      /**
       * attributeType
       * @property {DG.Analysis.EAttributeType}
       */
      attributeType: function() {
        return this.getPath('model.attributeDescription.attributeType');
      }.property(),

      attributeTypeDidChange: function() {
        this.notifyPropertyChange('attributeType');
        this.displayDidChange();
      }.observes('*model.attributeDescription.attributeStats.attributeType')

    };
  }()));


/* >>>>>>>>>> BEGIN source/components/guide/guide_configuration_view.js */
// ==========================================================================
//                        DG.GuideConfigurationView
// 
//  Implements a modal dialog used to configure the Guide menu in the tool shelf
//  
//  Authors:  William Finzer
//
//  Copyright ©2014 Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

  Implements a modal dialog used to configure the Guide menu in the tool shelf

 @extends SC.PalettePane
 */
DG.GuideConfigurationView = SC.PalettePane.extend(
  /** @scope DG.GuideConfigurationView.prototype */ {

    itemRow: SC.View.extend({
      blurAction: null,
      blurTarget: null,
      childViews: 'itemTitle itemURL'.w(),
        itemTitle: SC.TextFieldView.design({
          hint: 'DG.GuideConfigView.itemTitleHint'
        }),
        itemURL: SC.TextFieldView.design({
          hint: 'DG.GuideConfigView.itemURLHint'
        }),
      init: function() {
        arguments.callee.base.apply(this,arguments);
        var tBlurAction = this.get('blurAction' ),
            tBlurTarget = this.get('blurTarget');
        this.setPath( 'itemTitle.layout', { left: 5, width: 140 });
        this.setPath( 'itemURL.layout', { left: 150, right: 5 });
        this.get('childViews' ).forEach( function( iView) {
          iView.set('fieldDidBlur', function() {
            if( tBlurAction)
              tBlurAction.call( tBlurTarget);
          });
        });
      },
      rowObject: function() {
        var tTitle = this.getPath('itemTitle.value' ),
            tURL = this.getPath('itemURL.value' );
        if(!SC.empty(tTitle) || !SC.empty( tURL)) {
          return { itemTitle: tTitle, url: tURL};
        }
        return null;
      }.property(),

      /**
       *
       * @param iItem {Object {itemTitle: {String} url: {String}}
       */
      setItem: function( iItem) {
        if( iItem) {
          this.setPath('itemTitle.value', iItem.itemTitle);
          this.setPath('itemURL.value', iItem.url);
        }
      }
    }),

    model: null,

    isModal: YES,

    layout: { width: 400, height: 400, centerX: 0, centerY: 0 },

    contentView: SC.View.extend( {
      childViews: 'titleField menuItems okButton cancel warning'.w(),
      titleField: SC.TextFieldView.design( {
        layout: { top: 5, left: 5, right: 25, height: 24 },
        value: '',
        spellCheckEnabled: true,
        hint: 'DG.GuideConfigView.titleHint',
        leftAccessoryView: SC.LabelView.create( {
          layout: { left: 1, width: 95, height: 22, centerY: 0 },
          value: 'DG.GuideConfigView.titlePrompt',  // "Guide Title"
          backgroundColor: 'lightgray',
          localize: true
        } )
      } ),
      menuItems: SC.View.design( {
        layout: { left: 5, right: 5, top: 34, bottom: 34 },
        backgroundColor: 'white'
      } ),
      okButton: SC.ButtonView.design( {
        layout: { bottom: 5, right: 5, height: 24, width: 90 },
        titleMinWidth: 0,
        title: 'DG.GuideConfigView.okBtnTitle', // "OK"
        toolTip: 'DG.GuideConfigView.okBtnToolTip',
        target: null,
        action: null,
        localize: true,
        isDefault: true
      } ),
      cancel: SC.ButtonView.design( {
        layout: { bottom: 5, right: 115, height: 24, width: 90 },
        titleMinWidth: 0,
        title: 'DG.GuideConfigView.cancelBtnTitle',  // "Cancel"
        target: null,
        action: null,
        toolTip: 'DG.GuideConfigView.cancelBtnTooltip',  // "Dismiss the dialog without making any changes"
        localize: true,
        isCancel: true
      } ),
      warning: SC.LabelView.design( {
        value: 'DG.GuideConfigView.httpWarning',  // "The URL must start with either http:// or https://"
        classNames: 'dg-guide-alert',
        isVisible: false,
        transitionShow: SC.View.FADE_IN,
        localize: true
      } )
    } ),

    title: function() {
      return this.getPath('contentView.titleField.value');
    }.property(),

    items: function() {
      return this.get('rowObjects');
    }.property(),

    addMenuItemRow: function( iItem) {
      var tMenuItemsView = this.getPath('contentView.menuItems' ),
          tNumRows = this.get('rowViews' ).length,
          tTop = 5 + tNumRows * 27,
          tSection = this.itemRow.create({
            layout: { border: 1, left: 5, right: 5, top: tTop + 5, height: 22 },
            blurAction: this.configureRows,
            blurTarget: this
          });
      tSection.setItem( iItem);
      tMenuItemsView.appendChild( tSection);
    },

    rowViews: function() {
      return this.getPath('contentView.menuItems.childViews' );
    }.property(),

    rowObjects: function() {
      return this.get('rowViews' )
        .map( function( iRowView) {
                return iRowView.get('rowObject');
              } )
        .filter( function( iObject) {
                  return !!iObject;
                });
    }.property(),

    configureRows: function() {

      var checkURLs = function() {
        var tRowObjects = this.get('rowObjects'),
            tWarning = this.getPath('contentView.warning'),
            tTitleLayout = this.getPath('contentView.titleField.layout');
        tWarning.set('isVisible', false);
        tRowObjects.forEach( function( iObject, iIndex) {
          var tUrl = SC.empty(iObject.url) ? '' : iObject.url.toLowerCase();
          if( !SC.empty( tUrl) && (tUrl.indexOf('http://') !== 0) && (tUrl.indexOf('https://') !== 0)) {
            var tItemLayout = this.get('rowViews')[iIndex].get('layout'),
                tItemViewBottom = tTitleLayout.top + tTitleLayout.height + tItemLayout.top + tItemLayout.height - 3;
            tWarning.set('layout', { left: 160, top: tItemViewBottom, height: 12 });
            tWarning.set('isVisible', true);
          }
        }.bind( this));
      }.bind( this);

      var tNumRowViews = this.get('rowViews' ).length,
          tNumRowObjects = this.get('rowObjects').length;

      checkURLs();

      while( tNumRowViews < tNumRowObjects + 1) {
        this.addMenuItemRow();
        tNumRowViews++;
      }
    },

    /**
     *
     * @param iModel {DG.GuideModel}
     */
    setupFromModel: function( iModel) {
      var tModel = this.get('model');
      this.setPath('contentView.titleField.value', tModel.get('title'));
      tModel.get('items' ).forEach( function( iItem) {
        this.addMenuItemRow( iItem);
      }.bind( this));
    },

    /**
     Initialization function.
     */
    init: function () {
      arguments.callee.base.apply(this,arguments);
      this.setPath( 'contentView.cancel.target', this );
      this.setPath( 'contentView.cancel.action', 'close' );
      this.setupFromModel();
      this.configureRows();
    },

    /**
     Close the dialog.
     */
    close: function () {
      this.remove();
      this.destroy();
    }
  } );

DG.CreateGuideConfigurationView = function ( iProperties ) {
  var tDialog = DG.GuideConfigurationView.create( iProperties ),
      tContentView = tDialog.get('contentView' ),
      tEditView = tDialog.getPath( 'contentView.titleField' );

  tContentView.setPath('okButton.target', iProperties.okTarget);
  tContentView.setPath('okButton.action', iProperties.okAction);
  tDialog.append();
  tEditView.becomeFirstResponder();

  return tDialog;
};

/* >>>>>>>>>> BEGIN source/utilities/string_utilities.js */
// ==========================================================================
//                          DG.StringUtilities
//
//  Author:   William Finzer
//
//  Copyright ©2014 Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

DG.StringUtilities = {

  // from http://stackoverflow.com/a/6969486
  escapeRegExpRE: /[\-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/g,

  escapeRegExp: function(str) {
    return str.replace(DG.StringUtilities.escapeRegExpRE, "\\$&");
  },

  createEscapedRegExp: function(str, flags) {
    return new RegExp(DG.StringUtilities.escapeRegExp(str), flags);
  },

  /**
   * The returned string is guaranteed to begin with iPrefix.
   * @param iString {String}
   * @param iPrefix {String}
   * @returns  {String}
   */
  guaranteePrefix: function( iString, iPrefix) {
    return (iString.indexOf(iPrefix) === 0) ? iString : iPrefix + iString;
  },

  /**
   * Returns a set of regexp results arrays from matches within the string.
   * If iResultsMapper is defined, then it returns a set of return values from that function.
   * @param iString {String}
   * @param iRegexp {RegExp}
   * @param iResultsMapper {Function} (optional)
   */
  scan: function ( iString, iRegexp, iResultsMapper ) {
    if (!iRegexp.global) throw "regexp must have global flag set";
    var m, results = [];
    while ((m = iRegexp.exec(iString)) !== null) {
      if (iResultsMapper === null) {
        results.push(m);
      } else {
        results.push(iResultsMapper.call(window, m));
      }
    }
    return results;
  }
};


/* >>>>>>>>>> BEGIN source/components/guide/guide_controller.js */
// ==========================================================================
//                        DG.GuideController
//
//  Copyright ©2014 Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('controllers/component_controller');
sc_require('utilities/string_utilities');

/** @class

  Coordinates save and restore for the GuideModel singleton.

  @extends DG.ComponentController
*/
DG.GuideController = DG.ComponentController.extend(
/** @scope DG.GuideController.prototype */ {

    /**
     *  @property {DG.GuideModel}
     */
    guideModel: null,

    guideButton: null,

    guideMenuPane: null,

    reset: function() {
      this.guideModel.reset();
      this.set('view', null); // because it gets destroyed in closeAllComponents, so we don't want to hang onto it
    },

    updateViewTitle: function() {
      var tTitle = this.getPath('guideModel.title');
      this.setPath('view.title', tTitle);
    }.observes('guideModel.title'),

    modelContentsDidChange: function() {
      var tTitle = this.getPath('guideModel.title' ),
          tItems = this.getPath('guideModel.items' ),
          tIconMenuItems = this.get('iconMenuItems' ),
          tButton = this.get('guideButton' ),
          tPane = this.get('guideMenuPane' ),
          tHasContent = !SC.empty( tTitle) || (tItems.length > 0),
          tCurrentURL = this.getPath('guideModel.currentURL');
      if( tButton)
        tButton.set('isVisible', tHasContent);
      if( tPane) {
        var tShowGuide = 'DG.ToolButtonData.guideMenu.showGuide'.loc(),
            tMenuItems = [ { title: tShowGuide, isEnabled: true, target: this, action: 'showGuide' },
                          { isSeparator: true }];
        tPane.set('items', tMenuItems.concat( tIconMenuItems));
      }
      // Set the currentURL to the first in the list
      if( (tIconMenuItems.length > 0) && SC.empty( tCurrentURL)) {
        var tFirstItem = tIconMenuItems[ 0];
        this.setPath('guideModel.currentURL', tFirstItem.url);
        this.setPath('guideModel.currentItemTitle', tFirstItem.title);
      }
    }.observes('guideModel.title', 'guideModel.items'),

    isVisibleDidChange: function () {
      var tComponentView = this.get('view');
      var visibility = this.getPath('guideModel.isVisible');
      if (!SC.none(visibility) && tComponentView) {
        if (visibility) {
          tComponentView.set('isVisible', true);
          tComponentView.select();
          tComponentView.scrollToVisible();
        }
        else {
          tComponentView.set('isVisible', false);
        }
      }
    }.observes('guideModel.isVisible'),

    willCloseComponent: function () {
      this.setPath('guideModel.isVisible', false);
    },

    showGuide: function() {
      DG.UndoHistory.execute(DG.Command.create({
        name: 'guide.show',
        undoString: 'DG.Undo.guide.show',
        redoString: 'DG.Redo.guide.show',
        log: 'Show guide',
        execute: function() {
          this.setPath('guideModel.isVisible', true);
        }.bind(this),
        undo: function() {
          this.setPath('guideModel.isVisible', false);
        }.bind(this)
      }));
    },

    guideNavigation: function() {
      var this_ = this,
          tUrl = this_.getPath('guideMenuPane.selectedItem.url' ),
          tItemTitle = this_.getPath('guideMenuPane.selectedItem.title' ),
          tItemIndex = this_.getPath('guideMenuPane.selectedItem.index' );

      DG.UndoHistory.execute(DG.Command.create({
        name: 'guide.navigate',
        undoString: 'DG.Undo.guide.navigate',
        redoString: 'DG.Redo.guide.navigate',
        _previous: {
          index: this_.getPath('guideModel.currentItemIndex'),
          wasVisible: this_.getPath('view.isVisible')
        },
        execute: function() {
          // Guides are singletons that are never destroyed, so it's ok to reference the view directly
          this_.setPath('guideModel.currentItemIndex', tItemIndex);
          this_.showGuide();
          this.log = "Guide icon navigation: { Title: %@, itemTitle: %@, url: %@ }".fmt(this_.getPath('guideModel.title'), tItemTitle, tUrl);
        },
        undo: function() {
          this_.setPath('guideModel.currentItemIndex', this._previous.index);
          this_.setPath('view.isVisible', this._previous.wasVisible);
        }
      }));
    },

    /**
    Get the menu items from the graph and its components.
      @property { Array of menu items }
    */
    iconMenuItems: function() {
      var tItems = this.getPath('guideModel.items' ),
          tMenuItems = [],
          kAction = 'guideNavigation';
      tItems.forEach( function( iItem, ix) {
                tMenuItems.push({ title: iItem.itemTitle, url: iItem.url,
                                  index: ix, target: this, action: kAction });
              }.bind( this));
      return tMenuItems;
    }.property(),

    viewDidChange: function() {
      if( !SC.none( this.tempIsVisible))
        this.setPath('view.isVisible', this.tempIsVisible);
      this.tempIsVisible = undefined;
      this.updateViewTitle();
    }.observes('view'),

    createComponentStorage:function () {
      var tStorage = this.get('guideModel' ).createComponentStorage();
      tStorage.isVisible = this.getPath('guideModel.isVisible' );
      return tStorage;
    },

    restoreComponentStorage:function ( iComponentStorage ) {
      arguments.callee.base.apply(this,arguments);
      this.get('guideModel' ).restoreComponentStorage( iComponentStorage);
    }

});


/* >>>>>>>>>> BEGIN source/components/guide/guide_model.js */
// ==========================================================================
//                            DG.GuideModel
//
//  Author:   William Finzer
//
//  Copyright ©2014 Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class  DG.GuideModel - The GuideModel singleton stores what is needed to
 * construct the Guide menu in the tool shelf.

 @extends SC.Object
 */
DG.GuideModel = SC.Object.extend(
  /** @scope DG.GuideModel.prototype */
  {
    /**
     @property { String }
     */
    title: '',

    /**
     @property { Array of { itemTitle: {String}, url: {String} }
     */
    items: null,

    /**
     * @property { Boolean }
     */
    isVisible: false,

    /**
     * @property {String}
     */
    currentURL: function () {
      var item = this.get('currentItem');
      return !SC.none(item) && item.url;
    }.property('currentItem', 'currentItemIndex'),

    /**
     * @property {String}
     */
    currentItemTitle: function () {
      var item = this.get('currentItem');
      return !SC.none(item) && item.url;
    }.property('currentItem', 'currentItemIndex'),

    currentItemIndex: null,

    currentItem: function () {
      var ix = this.get('currentItemIndex');
      if (ix && this.items && (ix >= this.items.length)) {
        ix = this.items.length && this.items.length - 1;
        this.set('currentItemIndex', ix);
        this.notifyPropertyChange('currentURL');
      }
      if (!SC.none(ix) && this.items) {
        return this.items[ix];
      }
    }.property('items', 'currentItemIndex'),

    init: function() {
      arguments.callee.base.apply(this,arguments);
      this.reset();
    },

    reset: function() {
      this.beginPropertyChanges();
        this.set('title', '');
        this.set('items', []);
      this.endPropertyChanges();
    },

    createComponentStorage: function() {
      return { title: this.title, items: this.items,
        currentItemIndex: this.currentItemIndex };
    },

    restoreComponentStorage: function( iStorage) {
    // For a while we had an invokeLater wrapping the following because it improved
    // Chromes ability to load iframes. But we think fixed that in a better way
      this.beginPropertyChanges();
        if (iStorage.currentItemIndex) {
          this.set('currentItemIndex', iStorage.currentItemIndex);
        }
        if (iStorage.isVisible)
          this.set('isVisible', iStorage.isVisible);
        if( iStorage.title)
          this.set('title', iStorage.title);
        if( iStorage.items)
          this.set('items', iStorage.items);
      this.endPropertyChanges();
    },

    itemsDidChange: function () {
      if (!this.items) {
        return;
      }
      var currentItemIndex = this.get('currentItemIndex');
      if (SC.none(currentItemIndex)) {
        if (this.items.length > 0) {
          this.set('currentItemIndex', 0);
        }
      }
      this.notifyPropertyChange('currentURL');
    }.observes('items')

  } );


/* >>>>>>>>>> BEGIN source/components/guide/guide_view.js */
// ==========================================================================
//                            DG.GuideView
//
//  Author:   William Finzer
//
//  Copyright ©2014 Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class  DG.GuideView - Not much more than an SC.WebView. Exists as a singleton.

 @extends SC.WebView
 */
DG.GuideView = SC.WebView.extend(
  /** @scope DG.GuideView.prototype */
  (function() {

    return {
      /**
       The model on which this view is based.
       @property { DG.GuideModel }
       */
      guideModel: null,

      realURL: function() {
        // We require the author to specify either http:// or https:// so that there is no ambiguity
        return this.getPath('guideModel.currentURL');
      }.property(),

      realURLDidChange: function () {
        this.notifyPropertyChange('realURL');
      }.observes('*guideModel.currentURL'),

      init: function() {
        arguments.callee.base.apply(this,arguments);
        DG.assert( !SC.none( this.get( 'guideModel' ) ) );
        this.currentURLDidChange(); // So that the model's currentURL can be installed
      },

      currentURLDidChange: function() {
      // For a while we had an invokeLater wrapping the following because it improved
      // Chromes ability to load the iframe. But we think fixed that in a better way
        this.set('value', this.get('realURL'));
      }.observes('guideModel.currentURL')

    };
  }()) );


/* >>>>>>>>>> BEGIN source/components/image_component/image_component_controller.js */
// ==========================================================================
//                        DG.WebViewController
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('controllers/component_controller');

/** @class

  Coordinates save and restore for web views.

  @extends DG.ComponentController
*/
DG.ImageComponentController = DG.ComponentController.extend(
/** @scope DG.ImageComponentController.prototype */ {

  /**
   *  The URL the WebView is viewing.
   *  This property is bound to the 'value' property of the WebView.
   *  @property {String}
   */
  theURL: function (k, v) {
    if (!SC.none(v)) {
      this.setPath('model.content.URL', v);
    }
    return this.getPath('model.content.URL');
  }.property(),

  theURLDidChange: function () {
    this.notifyPropertyChange('theURL');
  }.observes('model.content.URL'),

  title: 'DG.ImageComponent.defaultTitle'.loc(),

  /**
   *
   * @returns {Array}
   */
  createInspectorButtons: function() {
    var tButtons = arguments.callee.base.apply(this,arguments);
    tButtons.push(DG.IconButton.create({
          layout: {width: 32},
          classNames: 'dg-web-view-url'.w(),
          iconClass: 'moonicon-icon-mediaTool',
          showBlip: false,
          target: this,
          action: 'editURL',
          toolTip: 'DG.Inspector.webViewEditURL.toolTip',
          localize: true
        })
    );
    return tButtons;
  },

  editURL: function() {

    var this_ = this,
        tDialog = null;

    function setURL() {
      // User has pressed OK: can only do so if non-empty
      var tURL = tDialog.get('value');
      tDialog.close();
      this_.set('theURL', tURL);
    }

    tDialog = DG.CreateSingleTextDialog( {
                    prompt: 'DG.DocumentController.enterURLPrompt',
                    textValue: this_.get('theURL'),
                    textHint: 'URL',
                    okTarget: null,
                    okAction: setURL,
                    okTooltip: DG.DocumentController.enterViewWebPageOKTip
                  });
  },

  createComponentStorage:function () {
    var tURL = this.get('theURL'),
      tStorage = {
        title: this.title
      };
    if( !SC.empty( tURL))
      tStorage.URL = tURL;
    return tStorage;
  },

  restoreComponentStorage:function ( iComponentStorage ) {
    var tURL = iComponentStorage.URL || "";
    this.set('theURL', tURL);
    this.set('title', iComponentStorage.title);
  },

  /**
   *  Called when the view is connected to the controller.
   */
  viewDidChange: function() {
    // Bind the contents of the webView to our 'theURL' property.
    var tView = this.getPath('view.containerView.contentView');
    if( tView) {
      if( SC.empty( this.theURL)) // then it's safe to stuff it with the web view's URL
        this.set('theURL', tView.get('value'));
      tView.bind('value', this, 'theURL');
      tView.set('controller', this);
    }
  }.observes('view.containerView.contentView')

});


/* >>>>>>>>>> BEGIN source/components/image_component/image_component_view.js */
// ==========================================================================
//                          DG.WebView
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class
 * Implements a view of an image that presents a loading message
 * and an error message, if the load fails. In particular, if the load of a
 * page from another origin fails, the underlying message will be visible. We
 * won't be able to interrogate the IFrame, so the error message will be the
 * only indication the user has of the failure.
 * @extends SC.View
 */
DG.ImageComponentView = SC.View.extend(
/** @scope DG.WebView.prototype */ {
    classNames: ['dg-web-view'],
    childViews: ['imageView'],

    isTextSelectable: YES,

    /**
     * The URL provided.
     * @type {String}
     */
    value: '',

    /**
     * The URL to load.
     *
     * We load protocol relative URLs to maximize the likelihood of success.
     * See: https://www.paulirish.com/2010/the-protocol-relative-url/
     *
     * @type {String}
     */
    _url: function () {
      return this.get('value').replace(/^https?:/, '');
    }.property('value'),

    imageView: SC.ImageView.extend({
      classNames: ['dg-web-view-frame'],

      value: function () {
        return this.getPath('parentView._url');
      }.property(),

      valueDidChange: function () {
        this.notifyPropertyChange('value');
      }.observes('parentView._url'),

      scale: SC.BEST_FIT,

    })
});

/* >>>>>>>>>> BEGIN source/components/map/base_map_view.js */
// ==========================================================================
//                            DG.BaseMapView
//
//  Author:   William Finzer
//
//  Copyright ©2013 KCP Technologies, Inc., a McGraw-Hill Education Company
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/* global L */
/** @class  DG.BaseMapView

 A view on a map.

 We're using Leaflet as our map library.
 See: http://leafletjs.com/index.html

 @extends SC.Object
 */
DG.BaseMapView = SC.View.extend(
    /** @scope DG.BaseMapView.prototype */ {

      model: null,

      _layerID: null,

      _map: null,

      map: function () {
        return this._map;
      }.property('_map'),

      baseMapLayer: null,
      baseMapLabels: null,

      didCreateMap: function (iMap) {
      },

      /**
       * Property that can be observed by parent view
       */
      displayChangeCount: 0,

      /**
       * Set along with displayChangeCount so that event can be logged
       * @property(String}
       */
      lastEventType: null,

      /**
       * Property that can be observed by parent view
       */
      clickCount: 0,

      /**
       * Property that can be observed by parent view, counts times the map returns to idle
       */
      idleCount: 0,

      init: function () {
        arguments.callee.base.apply(this,arguments);
      },

      /**
       * Provide an element on which we can draw.
       * @param ctx
       * @param first
       */
      render: function (ctx, first) {
        if (first) {
          this._layerID = ctx.push(
              '<div></div>'
          ).id();
        }
      },

      didAppendToDocument: function() {
        if (!this._map) {
          this._createMap();
        }
        else {
          this.viewDidResize();
        }
      },

      _createMap: function () {

        var onLayerAdd = function (iLayerEvent) {
              var tParentView = this.get('parentView');
              this._map.off('layeradd', onLayerAdd);
              this.invokeLater( function() {
                // invokeLater is needed to insure that the parent view has its legendViewCallback
                tParentView.addPointLayers();
                tParentView.addPolygonLayers();
                tParentView.adjustLayout();
              });
            }.bind(this),

            onDisplayChangeEvent = function (iEvent) {
              SC.run(function() {
                this.set('lastEventType', iEvent.type);
                this.incrementProperty('displayChangeCount');
              }.bind(this));
            }.bind(this),

            onClick = function (iEvent) {
              SC.run(function() {
                this.incrementProperty('clickCount');
              }.bind(this));
            }.bind(this),

            onMousedown = function( iEvent) {
              SC.run(function() {
                // Passing this event to the top will cause any extant picker panes to be removed
                DG.mainPage.mainPane.sendEvent('mouseDown', iEvent, this);
              }.bind(this));
            }.bind(this);

        if (this._map) {
          // May need to resize here
        } else {
          this._map = L.map(this._layerID, {
            scrollWheelZoom: false,
            zoomSnap: 0,
            trackResize: true
          }).setView(this.getPath('model.center'), this.getPath('model.zoom'));
          this._map.on('layeradd', onLayerAdd)
              .on('dragstart', onDisplayChangeEvent)
              .on('dragend', onDisplayChangeEvent)
              .on('moveend', onDisplayChangeEvent)
              .on('click', onClick)
              .on('mousedown', onMousedown)
              .on('dragstart drag move', function () {
                this._clearIdle();
              }.bind(this))
              .on('dragend zoomend moveend', function (iEvent) {
                this._setIdle(iEvent.type);
              }.bind(this));
          this.backgroundChanged(); // will initialize baseMap
        }
      },

      centerDidChange: function () {
        this.get('map').setView(this.getPath('model.newCenter'), this.getPath('model.newZoom'), {animate: true});
      }.observes('model.newCenter', 'model.newZoom'),

      viewDidResize: function () {
        var tMap = this.get('map');
        if (tMap) {
          tMap.invalidateSize();
        }
      },

      _idleTimeout: null,
      _clearIdle: function () {
        if (this._idleTimeout) {
          clearTimeout(this._idleTimeout);
          this._idleTimeout = null;
        }
      },
      _setIdle: function (eventType) {
        // console.log('eventType = %@, _idleTimeout = %@'.loc( eventType, this._idleTimeout));
        if(!this._idleTimeout) {
          this._clearIdle();
          this._idleTimeout = setTimeout(function () {
            this._idleTimeout = null;
            this.set('lastEventType', eventType); // So observers can act conditionally on event
            this.incrementProperty('idleCount');
            this.set('lastEventType', null);
          }.bind(this), 100);
        }
      },

      backgroundChanged: function () {
        var tMap = this.get('map'),
            tLayerOpacity = this.getPath('model.baseMapLayerIsVisible') ? 1.0 : 0.0,
            tNewLayerName = this.getPath('model.baseMapLayerName'),
            tNewLayer;

        if (!tNewLayerName)
          return;
        if (this.get('baseMapLayer'))
          tMap.removeLayer(this.get('baseMapLayer'));
        if (this.get('baseMapLabels'))
          tMap.removeLayer(this.get('baseMapLabels'));
        tNewLayer = L.esri.basemapLayer(tNewLayerName, {crossOrigin:true, opacity: tLayerOpacity});
        this._map.addLayer(tNewLayer, true /*add at bottom */);
        //this._map.addLayer( L.esri.basemapLayer(tBasemap + 'Labels'));
        this.set('baseMapLayer', tNewLayer);
      }.observes('model.baseMapLayerName')

    }
);

/* >>>>>>>>>> BEGIN source/components/map/grids/map_grid_layer.js */
// ==========================================================================
//                        DG.MapGridLayer
//
//  Author:   William Finzer
//
//  Copyright ©2014 Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
/* global L */
/** @class DG.MapGridLayer - A plot of dots placed according to numeric values

  @extends SC.Object
*/
DG.MapGridLayer = SC.Object.extend(
/** @scope DG.MapGridLayer.prototype */ 
{
  /**
   * {@property DG.MapGridModel}
   */
  model: null,

  mapSource: null,

  /**
   * paperSource is the same as mapSource
   */
  paperSource: function() {
    return this.get('mapSource');
  }.property( 'mapSource'),

  map: function() {
    return this.getPath('mapSource.mapLayer.map');
  }.property(),

  /**
   * {@property L.rectangle[]}
   */
  grid: null,

  _infoTip: null,
  infoTip: function () {
    if (!this._infoTip) {
      var this_ = this;
      this._infoTip = DG.InfoTip.create({
        paperSource: function () {
          return this_.get('paperSource');
        }.property(),
      });
    }
    return this._infoTip;
  }.property(),

  showTips: false,

  /**
   * @property {Boolean}
   */
  isInMarqueeMode: false,

  marqueeContext: null,

  isVisible: function() {
    return this.getPath('model.isVisible');
  }.property(),

  init: function() {
    arguments.callee.base.apply(this,arguments);
    this.visibilityHasChanged();
  },

  /**
    Draw the grid cells
  */
  addGridLayer: function() {
    var this_ = this,
        tMap = this.get('map'),
        tModel = this.get('model');
    if( !tMap || !tModel)
      return;
    var tOptions = { color: 'white', fillColor: 'red', weight: 1 },
        tRectangles = [],
        tMaxCount = tModel.get('rectArray').maxCount,
        tDataContext = tModel.getPath('dataConfiguration.dataContext'),
        tCollection = tModel.getPath('dataConfiguration.collectionClient'),
        tRect;
    tModel.forEachRect( function( iRect, iLongIndex, iLatIndex) {
      var handleClick = function( iEvent) {
            var tExtend = iEvent.originalEvent.shiftKey || iEvent.originalEvent.metaKey;
            // Below is the Leaflet Way to stop the click from propagating.
            L.DomEvent.stopPropagation(iEvent);
            SC.run(function () {
              tModel.selectCasesInRect( iLongIndex, iLatIndex, tExtend);
            });
            return false;
          }.bind( this),

          handleMouseover = function( iEvent) {
            var tLegendAttrID = tModel.getPath('dataConfiguration.legendAttributeDescription.attributeID');
            tRect = tModel.get('rectArray').getRect( iLongIndex, iLatIndex);
            if( (tRect.count === 0) || !this.get('showTips'))
              return;
            var tTipString = SC.none( tLegendAttrID) ?
                tDataContext.getCaseCountString(tCollection, tRect.count) :
                tModel.getCategoryBreakdownString( tRect.cases, tLegendAttrID),
                tCoords = this_.get('map').latLngToContainerPoint(tRect.rect[0]);
            this_.get('infoTip').show({
              x: tCoords.x, y: tCoords.y,
              tipString: tTipString
            });
          }.bind(this),

          handleMouseout = function( iEvent) {
            this_.get('infoTip').hide();
          }.bind( this);

      tOptions.fillOpacity = iRect.count / tMaxCount;
      var tLeafRect = L.rectangle( iRect.rect, tOptions)
                        .on('click', handleClick)
                        .on('mouseover', handleMouseover)
                        .on('mouseout', handleMouseout);
      tRectangles.push(tLeafRect);
    }.bind( this));

    this.set('grid', tRectangles);
  },

  show: function() {
    if( this.getPath('model.isVisible'))
      this.addGridToMap();
  },

  hide: function() {
    if( this.getPath('model.isVisible'))
      this.removeGridFromMap();
  },

  selectionDidChange: function() {
    var tIndex = 0,
        tRectangles = this.get('grid');
    if( !tRectangles || // We haven't been asked to construct them yet
        !this.getPath('model.isVisible'))
      return;
    this.get('model').forEachRect( function( iRect, iLongIndex, iLatIndex) {
      var tLeafRect = tRectangles[ tIndex],
          tSelected = iRect.selected;
      tLeafRect.setStyle( { color: tSelected ? 'black' : 'white',
                            weight: tSelected ? 2 : 1});
      if( tSelected)
        tLeafRect.bringToFront();
      tIndex++;
    });
  }.observes('model.selection'),

  /**
   * Add each rectangle to the map
   */
  addGridToMap: function() {
    var tMap = this.get('map'),
        tRectangles = this.get('grid');
    if( !tRectangles) {
      this.addGridLayer();
      tRectangles = this.get('grid');
    }
    tRectangles.forEach( function( iRect) {
      iRect.addTo( tMap);
    });
  },

  /**
   * Add each rectangle to the map
   */
  removeGridFromMap: function() {
    var tMap = this.get('map'),
        tRectangles = this.get('grid');
    if( tRectangles) {
      tRectangles.forEach(function (iRect) {
        tMap.removeLayer(iRect);
      });
    }
  },

  visibilityHasChanged: function() {
    if( this.getPath('model.isVisible')) {
      if(!this.get('grid'))
        this.addGridLayer();
      this.addGridToMap();
    }
    else {
      if(this.get('grid'))
        this.removeGridFromMap();
    }
  }.observes('model.isVisible'),

  gridRectArrayChanged: function() {
    this.removeGridFromMap();
    this.addGridLayer();
    this.visibilityHasChanged();
  }.observes('model.rectArray')

});


/* >>>>>>>>>> BEGIN source/components/map/grids/map_grid_model.js */
// ==========================================================================
//                            DG.MapGridModel
//
//  Author:   William Finzer
//
//  Copyright ©2014 Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class  DG.MapGridModel - The model for a grid being displayed on a map.

 @extends SC.Object
 */
DG.MapGridModel = SC.Object.extend((function () // closure
/** @scope DG.MapGridModel.prototype */ {

  /**
   *
   * @param [[south,west][north, east]]
   * @constructor
   */
  function RectRecord(iRect) {
    this.rect = iRect;
    this.count = 0;
    this.cases = [];
    this.selected = false;
  }

  /**
   * A 2-dim sparse array of RectRecords, each of which shows up at the view level as a colored rectangle.
   * @constructor
   */
  function RectArray() {
    this.maxCount = 0;

    this.rectangles = [
      []
    ];
    this.getRect = function (iLongIndex, iLatIndex) {
      if(this.rectangles[iLongIndex] && !SC.none( this.rectangles[ iLongIndex][iLatIndex])) {
        return this.rectangles[iLongIndex][iLatIndex];
      }
      else
        return null;
    };
    this.setRect = function(iLongIndex, iLatIndex, iRect) {
      if(!this.rectangles[iLongIndex])
        this.rectangles[iLongIndex] = [];
      this.rectangles[iLongIndex][iLatIndex] = iRect;
    };

    this.forEachRect = function( iFunc) {
      this.rectangles.forEach( function(iLongArray, iLongIndex) {
        iLongArray.forEach( function( iRect, iLatIndex) {
          if( iRect)
            iFunc( iRect, iLongIndex, iLatIndex);
        });
      });
    };

    this.addCaseToRect = function( iLongIndex, iLatIndex, iCase) {
      var tRect = this.getRect( iLongIndex, iLatIndex);
      if( tRect) {
        tRect.cases.push(iCase);
        // todo: We no longer need this count because we have the array
        tRect.count++;
        this.maxCount = Math.max(this.maxCount, tRect.count);
      }
    };

    this.deleteZeroRects = function() {
      this.rectangles.forEach( function(iLongArray, iLongIndex) {
        iLongArray.forEach( function( iRect, iLatIndex) {
          if( iRect.count === 0)
            iLongArray[ iLatIndex] = undefined;
        });
      });
    };
  }

  /**
   * The grid has a width and height measured in degrees
   * These are private variables used to compute actual grid width and height
   */
  var _gridWidth, // Number (degrees)
      _gridHeight, // Number (degrees)
      kGridCellCount = 20;

  /**
   * Start of MapGridModel
   */
  return {
    /**
     * Here we get access to the cases being plotted so we can determine how many points are in a grid rectangle
     * {@property DG.MapPointDataConfiguration}
     */
    dataConfiguration: null,

    /**
     * This number is multiplied times _gridWidth and _gridHeight to get the actual width and height
     */
    gridMultiplier: 1,  // Number [.1-2]

    gridWidth: function() {
      return _gridWidth * this.gridMultiplier;
    }.property('gridMultiplier'),

    gridHeight: function() {
      return _gridHeight * this.gridMultiplier;
    }.property('gridMultiplier'),

    startWest: null, // Number (degrees) - Left edge of grid
    startSouth: null, // Number (degrees) - Bottom edge of grid

    /**
     * A 2-dimensional array of objects, each of which consists of a rectangle and a count
     * {@property {[][]}
     */
    rectArray: null,

    maxCount: function() {
      var tRectArray = this.get('rectArray');
      return tRectArray ? tRectArray.maxCount : 0;
    }.property(),

    /**
     * {@property Boolean}
     */
    isVisible: false,

    forEachRect: function( iFunc) {
      var tRectArray = this.get('rectArray');
      if( tRectArray)
        tRectArray.forEachRect( iFunc);
    },

    initializeRectArray: function() {

      var tCases = this.getPath('dataConfiguration.cases'),
          tStartSouth, tStartWest;

      var setupRectangles = function() {
        var tRectArray = this.get('rectArray'),
            tBounds = this.get('dataConfiguration').getLatLongBounds(),
            tCenter = tBounds.getCenter(),
            tRefLong = tCenter.lng,
            tRefLat = tCenter.lat,
            tWest = tBounds.getWest(),
            tEast = tBounds.getEast(),
            tSouth = tBounds.getSouth(),
            tNorth = tBounds.getNorth();

        if( tWest === tEast) {
          tWest -= 5; // arbitrary offset
          tEast += 5;
        }
        if( tNorth === tSouth) {
          tNorth += 5; // arbitrary offset
          tSouth -= 5;
        }

        _gridWidth = Math.min((tEast - tWest) / kGridCellCount, (tNorth - tSouth) / kGridCellCount);
        _gridHeight = _gridWidth;

        var tGridWidth = this.get('gridWidth'),
            tNumToWest = Math.ceil((tRefLong - tWest) / tGridWidth);
        tStartWest = tRefLong - tGridWidth * tNumToWest;

        var tGridHeight = this.get('gridHeight'),
            tNumToSouth = Math.ceil((tRefLat - tSouth) / tGridHeight),
            tLatIndex, tLongIndex;
        tStartSouth = tRefLat - tGridHeight * tNumToSouth;

        for (tLongIndex = 0; tLongIndex < 2 * tNumToWest; tLongIndex++) {
          for (tLatIndex = 0; tLatIndex < 2 * tNumToSouth; tLatIndex++) {
            tRectArray.setRect(tLongIndex, tLatIndex, new RectRecord([
              [tStartSouth + (tLatIndex + 1) * tGridHeight, tStartWest + tLongIndex * tGridWidth],
              [tStartSouth + tLatIndex * tGridHeight, tStartWest + (tLongIndex + 1) * tGridWidth]
            ]));
          }
        }
      }.bind(this);

      var computeCounts = function(){

        var zeroCounts = function() {
          this.get('rectArray').forEachRect( function( iRect) {
            iRect.count = 0;
          });
          this.get('rectArray').maxCount = 0;
        }.bind(this);

        var tGridWidth = this.get('gridWidth'),
            tGridHeight = this.get('gridHeight'),
            tLongVarID = this.getPath('dataConfiguration.xAttributeDescription.attributeID'),
            tLatVarID = this.getPath('dataConfiguration.yAttributeDescription.attributeID'),
            tRectArray = this.get('rectArray');
        zeroCounts();
        tCases.forEach( function( iCase) {
          var tLongVal = iCase.getNumValue( tLongVarID),
              tLatVal = iCase.getNumValue( tLatVarID),
              tLongIndex = Math.floor( (tLongVal - tStartWest) / tGridWidth),
              tLatIndex = Math.floor( (tLatVal - tStartSouth) / tGridHeight);
          tRectArray.addCaseToRect( tLongIndex, tLatIndex, iCase);
        });
      }.bind(this);

      var tBounds = this.get('dataConfiguration').getLatLongBounds();
      this.beginPropertyChanges();
        this.set('rectArray', new RectArray());
        if(tCases.get('length') > 0 && tBounds && tBounds.isValid()) {
          setupRectangles();
          computeCounts();
          this.get('rectArray').deleteZeroRects();
        }
      this.endPropertyChanges();
    },

    /**
     * Called to remove the grid rectangles
     */
    clear: function() {
      this.set('rectArray', new RectArray());
    },

    _selectCasesInRect: function( iLongIndex, iLatIndex, iSelect, iExtend) {
      var tDataContext = this.getPath('dataConfiguration.dataContext'),
          tCollectionClient = this.getPath('dataConfiguration.collectionClient'),
          tRect = this.get('rectArray').getRect( iLongIndex, iLatIndex),
          tSelectChange = {
            operation: 'selectCases',
            collection: tCollectionClient,
            cases: tRect.cases,
            select: iSelect,
            extend: iExtend
          };
      tDataContext.applyChange( tSelectChange);
    },

    selectCasesInRect: function( iLongIndex, iLatIndex, iExtend) {
      if( !iExtend) {
        this.forEachRect( function( iRect) {
          iRect.selected = false;
        });
      }
      this._selectCasesInRect( iLongIndex, iLatIndex, true, iExtend);
    },

    deselectCasesInRect: function( iLongIndex, iLatIndex) {
      this._selectCasesInRect( iLongIndex, iLatIndex, false, true);
    },

    /**
     * Deselect all cases
     */
    deselectAll: function() {
      var tDataConfig = this.get('dataConfiguration'),
          tContext = tDataConfig.get('dataContext'),
          tChange = {
            operation: 'selectCases',
            collection: tDataConfig.get('collectionClient'),
            cases: null,
            select: false
          };
      if (tContext) {
        tContext.applyChange(tChange);
      }
    },

    updateSelection: function() {
      var tSelection = this.getPath('dataConfiguration.collectionClient.casesController.selection');
      this.forEachRect( function( iRect) {
        iRect.selected = iRect.cases.every( function( iCase) {
          return tSelection.containsObject( iCase);
        });
      });
      this.notifyPropertyChange('selection');
    },

    /**
     * We have to recompute the rectArray
     * TODO: Handle change in the number of cases and changes in values of cases
     */
    rectArrayMustChange: function() {
      if( this.getPath('dataConfiguration.hasLatLongAttributes'))
        this.initializeRectArray();
    }.observes('gridMultiplier', 'dataConfiguration.hiddenCases'),

    /**
     * The resulting string is used in a data tip
     * @param iCases {[DG.Case]}
     * @param iLegendAttrID {Number}
     */
    getCategoryBreakdownString: function( iCases, iLegendAttrID) {
      var tTotalCount = 0,
          tCategories = {},
          tResult = '';
      iCases.forEach( function( iCase) {
        var tValue = iCase.getStrValue( iLegendAttrID);
        if( !SC.empty( tValue)) {
          tTotalCount++;
          if( !tCategories[ tValue]) {
            tCategories[ tValue] = 0;
          }
          tCategories[ tValue]++;
        }
      });
      DG.ObjectMap.forEach( tCategories, function( iCat, iCount) {
        if( !SC.empty( tResult)) {
          tResult += '\n';
        }
        tResult += iCat + ': ' + iCount + ' (' + (Math.round(1000 * iCount/tTotalCount) / 10) + '%)';
      });
      return tResult;
    },

    handleDataContextChange: function( iChange) {
      var operation = iChange && iChange.operation;

      switch( operation) {
        case 'createCase':
        case 'createCases':
        case 'deleteCases':
        case 'createCollection':
        case 'resetCollections':
          this.rectArrayMustChange();
          break;
        case 'selectCases':
          this.updateSelection();
          break;
      }
    },

    /**
     *
     * @returns {{}}
     */
    createStorage: function () {
      var tStorage = {};
      tStorage.gridMultiplier = this.get('gridMultiplier');
      tStorage.isVisible = this.get('isVisible');

      return tStorage;
    },

    /**
     *
     * @param iStorage
     */
    restoreStorage: function (iStorage) {
      if (iStorage) {
        this.beginPropertyChanges();
        this.set('gridMultiplier', iStorage.gridMultiplier ? iStorage.gridMultiplier : 1);
        this.set('isVisible', iStorage.isVisible);
        this.endPropertyChanges();
      }
    }
  };
})()); // end closure

/* >>>>>>>>>> BEGIN source/components/map/map_constants.js */
// ==========================================================================
//                            DG.MapModel
//
//  Author:   William Finzer
//
//  Copyright ©2014 Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class  DG.MapConstants

 */
DG.MapConstants =
    {
      kLatNames: ['latitude', 'lat', 'latitud', 'breitengrad', '緯度','عرض جغرافیایی'],
      kLongNames: ['longitude', 'long', 'lng', 'lon', 'longitud', 'längengrad', '経度', 'طول جغرافیایی'],
      kPolygonNames: ['boundary', 'boundaries', 'polygon', 'polygons', 'grenze', '境界','مرز']
    };

/* >>>>>>>>>> BEGIN source/components/map/map_controller.js */
// ==========================================================================
//                          DG.MapController
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/* global tinycolor */
sc_require('components/graph_map_common/data_display_controller');

/** @class

    DG.MapController provides controller functionality, for maps.

 @extends SC.DataDisplayController
 */
DG.MapController = DG.DataDisplayController.extend(
    /** @scope DG.MapController.prototype */
    (function () {

      /*
          function getCollectionClientFromDragData( iContext, iDragData) {
            var collectionID = iDragData.collection && iDragData.collection.get('id');
            return iContext && !SC.none( collectionID) && iContext.getCollectionByID( collectionID);
          }
      */

      return {
        mapModel: function () {
          return this.get('dataDisplayModel');
        }.property('dataDisplayModel'),
        mapView: function() {
          return this.get('contentView');
        }.property('contentView'),

        mapViewDidChange: function () {
          this.setPath('mapView.legendViewCreationCallback', this.setUpLegendView.bind(this));
          this.setPath('mapView.controller', this);
        }.observes('mapView'),

        init: function() {
          arguments.callee.base.apply(this,arguments);

          // We respond to changes in the number data contexts
          DG.currDocumentController().addObserver('contextsLength', this, this.handleDataContextChange);
          DG.currDocumentController().notificationManager.addObserver('mostRecentDataContextChanges', this,
              this.dataContextDidChange);
        },

        destroy: function() {
          var tDocController = DG.currDocumentController(),
              tNotificationManager = tDocController && tDocController.notificationManager;
          tDocController && tDocController.removeObserver('contextsLength', this, this.handleDataContextChange);
          tNotificationManager && tNotificationManager.removeObserver('mostRecentDataContextChanges', this,
              this.dataContextDidChange);

          arguments.callee.base.apply(this,arguments);
        },

        handleDataContextChange: function() {
          this.invokeLater( function() {
            SC.run( function() {
              this.get('mapModel').adaptToNewOrRemovedContexts();
              this.destroyInspectorButtons();
            }.bind( this));
          }.bind( this), 100);
        },

        /**
         *
         * @param iNotificationManager {DG.NotificationManager}
         */
        dataContextDidChange: function( iNotificationManager) {
          var tChanges = iNotificationManager.get('mostRecentDataContextChanges'),
              tMeaningfulChange = false;
          if (!tChanges) { return; }
          tChanges.forEach( function( iChange) {
            switch (iChange.operation) {
              case 'updateAttributes':
              case 'createAttributes':
                tMeaningfulChange = true;
                break;
            }
          });
          if( tMeaningfulChange)
            this.handleDataContextChange();
        },

        /**
         * A MapView may have multiple legend views. The Label of each needs to be configured
         * properly to show its menu on mouseDown.
         * @param iLegendView {DG.LegendView}
         */
        setUpLegendView: function (iLegendView) {
          this.addAxisHandler(iLegendView);
          iLegendView.addObserver('labelNode', this,
              function () {
                this.addAxisHandler(iLegendView);
              }.bind(this));
        },

        /**
         * We must store information for the mapModel.
         * @return {Object}
         */
        createComponentStorage: function () {
          var storage = arguments.callee.base.apply(this,arguments);

          storage.mapModelStorage = this.get('mapModel').createStorage();
          return storage;
        },

        restoreComponentStorage: function (iStorage, iDocumentID) {
          arguments.callee.base.apply(this,arguments);

          this.get('dataDisplayModel').restoreStorage(iStorage);
        },

        /**
         * We override here just so we can be observing things that make sense.
         * But superclass can do the work regardless.
         */
        plotOrLegendViewDidAcceptDrop: function (iView, iKey, iDragData) {
          arguments.callee.base.apply(this,arguments);
        }.observes('*mapView.dragData'),

        /**
         * The content of the values pane depends on what plot is showing; e.g. a scatterplot will have a checkbox
         * for showing a movable line, while a univariate dot plot will have one for showing a movable value.
         */
        showHideValuesPane: function () {
          var this_ = this,
              kTitleHeight = 26,
              kMargin = 5,
              kLeading = 5,
              kRowHeight = 20;
          if (DG.InspectorPickerPane.close(this.kValuesPaneIconClass)) {
            return; // don't reopen if we just closed
          }
          this.valuesPane = DG.InspectorPickerPane.create(
              {
                buttonIconClass: this.kValuesPaneIconClass,
                classNames: 'dg-inspector-picker'.w(),
                layout: {width: 200, height: 260},
                contentView: SC.View.extend(SC.FlowedLayout,
                    {
                      layoutDirection: SC.LAYOUT_VERTICAL,
                      isResizable: false,
                      isClosable: false,
                      defaultFlowSpacing: {left: kMargin, bottom: kLeading},
                      canWrap: false,
                      align: SC.ALIGN_TOP,
                      // layout: {right: 22},
                      childViews: 'title'.w(),
                      title: DG.PickerTitleView.extend({
                        layout: {height: kTitleHeight},
                        flowSpacing: {left: 0, bottom: kLeading},
                        title: 'DG.Inspector.values',
                        localize: true,
                        iconURL: '../../../../static/dg/de/cert/resources/images/icon-values.svg'
                      }),
                      init: function () {
                        arguments.callee.base.apply(this,arguments);
                        this_.getPath('mapModel.mapLayerModels').forEach(function (iLayerModel) {
                          var tCheckboxDescriptions = iLayerModel.get('checkboxDescriptions');
                          if (tCheckboxDescriptions.length > 0) {
                            var tControlsView = SC.View.create(SC.FlowedLayout,
                                {
                                  layoutDirection: SC.LAYOUT_VERTICAL,
                                  isResizable: false,
                                  isCloseable: false,
                                  defaultFlowSpacing: {left: kMargin, bottom: kLeading},
                                  canWrap: false,
                                  align: SC.ALIGN_TOP,
                                  // layout: {right: 22},
                                  childViews: 'layerName'.w(),
                                  layerName: SC.LabelView.extend({
                                    classNames: 'dg-inspector-layer-title'.w(),
                                    layout: {left: 0, height: kRowHeight },
                                    value: iLayerModel.getPath('dataConfiguration.collectionClient.name')
                                  })
                                });
                            tCheckboxDescriptions.forEach(function (iDesc) {
                              iDesc.layout = {left: 20, height: kRowHeight};
                              iDesc.localize = true;
                              tControlsView.appendChild(SC.CheckboxView.create(iDesc));
                            }.bind(this));
                            this.appendChild(tControlsView);
                          }
                        }.bind(this));
                        this_.getPath('dataDisplayModel.lastValueControls').forEach(function (iControl) {
                          this.appendChild(iControl);
                        }.bind(this));
                      }
                    })
              });
          this.valuesPane.popup(this.get('inspectorButtons')[2], SC.PICKER_POINTER);
        },

        /**
         * If I'm displaying points, then my superclass returns the right thing. But if I'm displaying boundaries,
         * I have to do my own thing.
         */
        styleControls: function () {
          var tMapLayerModels = this.getPath('mapModel.mapLayerModels');

          // For maps, we now have multiple vis-layer configurations with a single shared Base layer.
          // This result is iterated and placed in a vertical flowed layout.
          var tResultArray = [],
              createBaseLayer = function () {
                var tBaseLayer = SC.View.create(SC.FlowedLayout, {
                  layoutDirection: SC.LAYOUT_HORIZONTAL,
                  layout: {right: 0},
                  isResizable: false,
                  isClosable: false,
                  canWrap: false,
                  align: SC.ALIGN_TOP
                });

                tBaseLayer.appendChild(SC.CheckboxView.create({
                  layout: {height: 25, width: 50},
                  title: 'Base',
                  value: this.getPath('mapModel.baseMapLayerIsVisible'),
                  localize: false,
                  valueDidChange: function (iThisView) {
                    this.setPath('mapModel.baseMapLayerIsVisible', iThisView.get('value'));
                    var tMapLayer = this.getPath('mapView.mapLayer');
                    tMapLayer.getPath('backgroundChanged').call(tMapLayer);
                  }.bind(this).observes('value')
                }));

                var tItems = [
                  SC.Object.create({
                    label: 'Oceans',
                    value: 'Oceans', id: 'dg-map-oceans-background-button'
                  }),
                  SC.Object.create({
                    label: 'Topo',
                    value: 'Topographic', id: 'dg-map-topographic-background-button'
                  }),
                  SC.Object.create({
                    label: 'Streets',
                    value: 'Streets', id: 'dg-map-streets-background-button'
                  })
                ];

                tBaseLayer.appendChild(SC.SegmentedView.create({
                  controlSize: SC.SMALL_CONTROL_SIZE,
                  layout: {width: 170, height: 18, top: 5, right: 5},
                  items: tItems,
                  value: this.getPath('mapView.model.baseMapLayerName'),
                  itemTitleKey: 'label',
                  itemValueKey: 'value',
                  itemLayerIdKey: 'id',
                  action: 'changeBaseMap', // Defined below
                  target: this
                }));

                return tBaseLayer;
              }.bind(this);

          tResultArray.push(createBaseLayer());

          tMapLayerModels.forEach(function (iMapLayerModel) {
            var currentOpenSession = null,
                this_ = this,
                tDataConfig = iMapLayerModel.get('dataConfiguration'),
                tLegendAttrDesc = tDataConfig.get('legendAttributeDescription');
            if( !tLegendAttrDesc)
              return; // No legend indicates this layer model has nothing to contribute
            var tCategoryMap = tLegendAttrDesc.getPath('attribute.categoryMap'),
                tAttrColor = !tLegendAttrDesc.get('isNull') ? DG.ColorUtilities.calcAttributeColor(tLegendAttrDesc) : null,
                kRowHeight = 20,
                setCategoryColor = function (iColor, iColorKey) {
                  currentOpenSession = currentOpenSession || Math.random();
                  DG.UndoHistory.execute(DG.Command.create({
                    name: 'data.style.categoryColorChange',
                    undoString: 'DG.Undo.graph.changePointColor',
                    redoString: 'DG.Redo.graph.changePointColor',
                    log: "Changed categorical point color",
                    executeNotification: {
                      action: 'notify',
                      resource: 'component',
                      values: {
                        operation: 'change point color',
                        type: 'DG.MapView'
                      }
                    },
                    execute: function () {
                      this.reduceKey = this.name + iColorKey + currentOpenSession;
                      this._beforeStorage = {
                        color: tCategoryMap[iColorKey],
                        alpha: iMapLayerModel.getPath('transparency')
                      };
                      tCategoryMap[iColorKey] = iColor.toHexString();
                      iMapLayerModel.setPath('transparency', iColor.getAlpha());
                      iMapLayerModel.propertyDidChange('pointColor');
                      if( tLegendAttrDesc.get('attribute'))
                        tLegendAttrDesc.get('attribute').propertyDidChange('categoryMap');
                    },
                    undo: function () {
                      tCategoryMap[iColorKey] = this._beforeStorage.color;
                      iMapLayerModel.setPath('transparency', this._beforeStorage.alpha);
                      iMapLayerModel.propertyDidChange('pointColor');
                    },
                    reduce: function (previous) {
                      if (previous.reduceKey === this.reduceKey) {
                        this._beforeStorage = previous._beforeStorage;
                        return this;
                      }
                    }
                  }));
                },
                createSetColorAndAlphaCommand = function (name, colorAttr, alphaAttr, iColor) {
                  return DG.Command.create({
                    name: 'data.style.' + name,
                    undoString: 'DG.Undo.graph.' + name,
                    redoString: 'DG.Redo.graph.' + name,
                    log: "Changed point color",
                    executeNotification: {
                      action: 'notify',
                      resource: 'component',
                      values: {
                        operation: 'change ' + name,
                        type: 'DG.MapView'
                      }
                    },
                    execute: function () {
                      SC.run(function () {
                        this.reduceKey = this.name + currentOpenSession;
                        this._beforeStorage = {
                          color: iMapLayerModel.getPath(colorAttr),
                          alpha: iMapLayerModel.getPath(alphaAttr)
                        };
                        iMapLayerModel.setPath(colorAttr, iColor.toHexString());
                        iMapLayerModel.setPath(alphaAttr, iColor.getAlpha());
                      }.bind(this));
                    },
                    undo: function () {
                      iMapLayerModel.setPath(colorAttr, this._beforeStorage.color);
                      iMapLayerModel.setPath(alphaAttr, this._beforeStorage.alpha);
                    },
                    reduce: function (previous) {
                      if (previous.reduceKey === this.reduceKey) {
                        this._beforeStorage = previous._beforeStorage;
                        return this;
                      }
                    }
                  });
                },
                createSetAttributeColorCommand = function (name, end, alphaAttr, iColor) {
                  return DG.Command.create({
                    name: 'data.style.' + name,
                    undoString: 'DG.Undo.graph.' + name,
                    redoString: 'DG.Redo.graph.' + name,
                    log: "Changed " + end + " attribute color",
                    executeNotification: {
                      action: 'notify',
                      resource: 'component',
                      values: {
                        operation: 'change attribute color',
                        type: 'DG.MapView'
                      }
                    },
                    execute: function () {
                      this.reduceKey = this.name + currentOpenSession;
                      this._beforeStorage = {
                        color: tCategoryMap[end + '-attribute-color'],
                        alpha: iMapLayerModel.getPath(alphaAttr)
                      };
                      tCategoryMap[end + '-attribute-color'] = iColor.toHexString();
                      iMapLayerModel.setPath(alphaAttr, iColor.getAlpha());
                      iMapLayerModel.propertyDidChange('pointColor');
                      if( tLegendAttrDesc.get('attribute'))
                        tLegendAttrDesc.get('attribute').propertyDidChange('categoryMap');
                    },
                    undo: function () {
                      tCategoryMap['attribute-color'] = this._beforeStorage.color;
                      iMapLayerModel.setPath(alphaAttr, this._beforeStorage.alpha);
                    },
                    reduce: function (previous) {
                      if (previous.reduceKey === this.reduceKey) {
                        this._beforeStorage = previous._beforeStorage;
                        return this;
                      }
                    }
                  });
                },
                setLowColor = function (iColor) {
                  currentOpenSession = currentOpenSession || Math.random();
                  DG.UndoHistory.execute(createSetAttributeColorCommand("changeAttributeColor", "low",
                      "transparency", iColor));
                },
                setHighColor = function (iColor) {
                  currentOpenSession = currentOpenSession || Math.random();
                  DG.UndoHistory.execute(createSetAttributeColorCommand("changeAttributeColor", "high",
                      "transparency", iColor));
                },
                getStylesLayer = function () {
                  return this_.stylesPane.layer();
                },
                tControlView, tSpectrumEnds, tLowEndColor, tHighEndColor,
                tContentView, tScrollView
            ;

            // E.g., Points and grid layers associated to a data collection.
            var tDataCollectionLayer = SC.View.create(SC.FlowedLayout, {
              layoutDirection: SC.LAYOUT_VERTICAL,
              // layout: {height: 110},
              isResizable: false,
              isClosable: false,
              canWrap: false,
              align: SC.ALIGN_CENTER
            });

            // layer toggle
            tDataCollectionLayer.appendChild(SC.CheckboxView.create({
              layout: {right: 0, height: 20},
              title: tDataConfig.getPath('collectionClient.name'),
              value: iMapLayerModel.get('isVisible'),
              localize: false,
              valueDidChange: function (iThisView) {
                iMapLayerModel.set('isVisible', iThisView.get('value'));
              }.bind(this).observes('value')
            }));

            tResultArray.push(tDataCollectionLayer);

            // Below the toggle we have controls for points or polygons
            var tDataCollectionLayerControls = SC.View.create(SC.FlowedLayout, {
              classNames: 'dg-inspector-map-color-controls'.w(),
              layoutDirection: SC.LAYOUT_VERTICAL,
              // layout: {top: 16, left: 16, right: 0},
              isResizable: false,
              isClosable: false,
              canWrap: false,
              align: SC.ALIGN_LEFT
            });

            tDataCollectionLayer.appendChild(tDataCollectionLayerControls);

            if (iMapLayerModel.get('hasLatLongAttributes')) {
              var setCategoryColorFinalized = function () {
                    currentOpenSession = null;
                  },
                  setColor = function (iColor) {
                    currentOpenSession = currentOpenSession || Math.random();
                    DG.UndoHistory.execute(createSetColorAndAlphaCommand("changePointColor",
                        "pointColor", "transparency", iColor));
                  },
                  setColorFinalized = function () {
                    currentOpenSession = null;
                  },
                  setStroke = function (iColor) {
                    currentOpenSession = currentOpenSession || Math.random();
                    DG.UndoHistory.execute(createSetColorAndAlphaCommand("changeStrokeColor",
                        "strokeColor", "strokeTransparency", iColor));
                  },
                  setStrokeFinalized = function () {
                    currentOpenSession = null;
                  },
                  tResult = [
                    DG.PickerControlView.create({
                      layout: {height: kRowHeight},
                      label: 'DG.Inspector.pointSize',
                      controlView: SC.SliderView.create({
                        layout: {left: 80, right: 25},
                        classNames: 'dg-map-pointSize-slider'.w(),
                        controlSize: SC.SMALL_CONTROL_SIZE,
                        value: iMapLayerModel.getPath('pointSizeMultiplier'),
                        minimum: 0, maximum: 3, step: 0,
                        valueChanged: function () {
                          var picker = this;
                          DG.UndoHistory.execute(DG.Command.create({
                            name: 'data.style.pointSizeChanged',
                            undoString: 'DG.Undo.graph.changePointSize',
                            redoString: 'DG.Redo.graph.changePointSize',
                            log: "Changed point size",
                            executeNotification: {
                              action: 'notify',
                              resource: 'component',
                              values: {
                                operation: 'change point size',
                                type: 'DG.MapView'
                              }
                            },
                            execute: function () {
                              this._beforeStorage = iMapLayerModel.getPath('pointSizeMultiplier');
                              iMapLayerModel.setPath('pointSizeMultiplier', picker.get('value'));
                            },
                            undo: function () {
                              iMapLayerModel.setPath('pointSizeMultiplier', this._beforeStorage);
                            },
                            reduce: function (previous) {
                              if (previous.name === this.name) {
                                this._beforeStorage = previous._beforeStorage;
                                return this;
                              }
                            }
                          }));
                        }.observes('value')
                      })
                    })
                  ];

              if (tLegendAttrDesc.get('isNull')) {
                var tInitialColor = tinycolor(iMapLayerModel.getPath('pointColor'))
                    .setAlpha(iMapLayerModel.getPath('transparency'));
                tResult.push(
                    DG.PickerControlView.create({
                      layout: {height: 2 * kRowHeight},
                      label: 'DG.Inspector.color',
                      controlView: DG.PickerColorControl.create({
                        layout: {left: 80, right: 0},
                        classNames: 'dg-graph-point-color'.w(),
                        initialColor: tInitialColor,
                        setColorFunc: setColor,
                        closedFunc: setColorFinalized,
                        appendToLayerFunc: getStylesLayer
                      })
                    })
                );
              }
              else if (tLegendAttrDesc.get('isNumeric')) {
                if (tCategoryMap && SC.none(tCategoryMap['attribute-color'])) {
                  var tColor = DG.ColorUtilities.calcAttributeColor(tLegendAttrDesc);
                  tCategoryMap['attribute-color'] = tColor.colorString || tColor;
                }

                tAttrColor = tCategoryMap && tCategoryMap['attribute-color'];

                tControlView = SC.View.create(SC.FlowedLayout,
                    {
                      layoutDirection: SC.LAYOUT_HORIZONTAL,
                      layout: {width: 120, right: 20},
                      isResizable: false,
                      isClosable: false,
                      //defaultFlowSpacing: {right: 5},
                      canWrap: false,
                      align: SC.ALIGN_TOP
                    }
                );
                tSpectrumEnds = DG.ColorUtilities.getAttributeColorSpectrumEndsFromColorMap(tCategoryMap, tAttrColor);
                tLowEndColor = tinycolor(tSpectrumEnds.low.colorString)
                    .setAlpha(iMapLayerModel.getPath('transparency'));
                tHighEndColor = tinycolor(tSpectrumEnds.high.colorString)
                    .setAlpha(iMapLayerModel.getPath('transparency'));
                tControlView.appendChild(DG.PickerColorControl.create({
                      layout: {width: 60},
                      classNames: 'dg-graph-point-color'.w(),
                      initialColor: tLowEndColor,
                      setColorFunc: setLowColor,
                      closedFunc: setColorFinalized,
                      appendToLayerFunc: getStylesLayer
                    })
                );
                tControlView.appendChild(DG.PickerColorControl.create({
                      layout: {width: 60},
                      classNames: 'dg-graph-point-color'.w(),
                      initialColor: tHighEndColor,
                      setColorFunc: setHighColor,
                      closedFunc: setColorFinalized,
                      appendToLayerFunc: getStylesLayer
                    })
                );
                tResult.push(
                    DG.PickerControlView.create({
                      layout: {height: 2 * kRowHeight},
                      label: 'DG.Inspector.legendColor',
                      controlView: tControlView
                    })
                );
                tResult.push(SC.CheckboxView.create({
                  layout: {height: 25},
                  title: 'DG.Inspector.lockLegendQuantiles',
                  toolTip: 'DG.Inspector.lockLegendQuantilesTooltip',
                  value: tDataConfig.get('legendQuantilesAreLocked'),
                  classNames: 'dg-graph-lockLegendQuantiles-check'.w(),
                  localize: true,
                  valueDidChange: function () {
                    var quantilesAreLocked = !tDataConfig.get('legendQuantilesAreLocked'),
                       logMessage = "Set quantilesAreLocked to " + quantilesAreLocked;
                    DG.UndoHistory.execute(DG.Command.create({
                      name: 'legend.quantilesAreLockedChange',
                      undoString: quantilesAreLocked ? 'DG.Undo.legend.lockQuantiles' : 'DG.Undo.legend.unlockQuantiles',
                      redoString: quantilesAreLocked ? 'DG.Redo.legend.lockQuantiles' : 'DG.Redo.legend.unlockQuantiles',
                      log: logMessage,
                      execute: function () {
                        tDataConfig.toggleProperty('legendQuantilesAreLocked');
                      }.bind(this),
                      undo: function () {
                        tDataConfig.toggleProperty('legendQuantilesAreLocked');
                      }.bind(this)
                    }));
                  }.bind(this).observes('value')
                }));
              }
              tResult.push(
                  DG.PickerControlView.create({
                    layout: {height: 2 * kRowHeight},
                    label: 'DG.Inspector.stroke',
                    controlView: DG.PickerColorControl.create({
                      layout: {left: 80, right: 0},
                      classNames: 'dg-graph-stroke-color'.w(),
                      initialColor: tinycolor(iMapLayerModel.get('strokeColor'))
                          .setAlpha(iMapLayerModel.get('strokeTransparency')),
                      setColorFunc: setStroke,
                      closedFunc: setStrokeFinalized,
                      appendToLayerFunc: getStylesLayer
                    })
                  })
              );
              tResult.push(SC.CheckboxView.create({
                layout: {height: 25},
                title: 'DG.Inspector.strokeSameAsFill',
                value: iMapLayerModel.get('strokeSameAsFill'),
                classNames: 'dg-graph-strokeSameAsFill-check'.w(),
                localize: true,
                valueDidChange: function () {
                  var becomingSameAsFill = !iMapLayerModel.get('strokeSameAsFill'),
                      logMessage = "Made stroke color " + (becomingSameAsFill ? "same as fill" : "independent of fill");
                  DG.UndoHistory.execute(DG.Command.create({
                    name: 'map.strokeSameAsFillChange',
                    undoString: becomingSameAsFill ? 'DG.Undo.graph.makeStrokeSameAsFill' : 'DG.Undo.graph.makeStrokeIndependent',
                    redoString: becomingSameAsFill ? 'DG.Redo.graph.makeStrokeSameAsFill' : 'DG.Redo.graph.makeStrokeIndependent',
                    log: logMessage,
                    executeNotification: {
                      action: 'notify',
                      resource: 'component',
                      values: {
                        operation: 'toggle stroke same as fill',
                        type: 'DG.MapView'
                      }
                    },
                    execute: function () {
                      iMapLayerModel.toggleProperty('strokeSameAsFill');
                    }.bind(this),
                    undo: function () {
                      iMapLayerModel.toggleProperty('strokeSameAsFill');
                    }.bind(this)
                  }));
                }.bind(this).observes('value')
              }));
              if (tLegendAttrDesc.get('isCategorical')) {
                tContentView = SC.View.create(SC.FlowedLayout,
                    {
                      layoutDirection: SC.LAYOUT_VERTICAL,
                      isResizable: false,
                      isClosable: false,
                      defaultFlowSpacing: {bottom: 5},
                      canWrap: false,
                      align: SC.ALIGN_TOP
                    }
                );
                tScrollView = SC.ScrollView.create({
                  layout: {height: 100},
                  hasHorizontalScroller: false,
                  contentView: tContentView
                });
                var tAttribute = tLegendAttrDesc.get('attribute');
                tAttribute.forEachCategory(function (iCategory) {
                  var tCalcColor = DG.ColorUtilities.calcCaseColor(iCategory, tLegendAttrDesc),
                      tInitialColor = tCategoryMap[iCategory] ?
                      tCategoryMap[iCategory] :
                          tCalcColor.colorString || tCalcColor;
                  tInitialColor = tinycolor(tInitialColor.colorString || tInitialColor).setAlpha(iMapLayerModel.getPath('transparency'));
                  tContentView.appendChild(DG.PickerControlView.create({
                    layout: {height: 2 * kRowHeight},
                    label: iCategory,
                    controlView: DG.PickerColorControl.create({
                      layout: {width: 80, right: 0},
                      classNames: 'dg-graph-point-color'.w(),
                      initialColor: tInitialColor,
                      colorKey: iCategory,
                      setColorFunc: setCategoryColor,
                      closedFunc: setCategoryColorFinalized,
                      appendToLayerFunc: getStylesLayer
                    })
                  }));
                }.bind(this));
                tResult.push(tScrollView);
              }

              tResult.forEach(function (iLayerComponent) {
                tDataCollectionLayerControls.appendChild(iLayerComponent);
              });
            }
            else if (iMapLayerModel.get('hasPolygonAttribute')) {
              var tPickerArray = [],

                  setAreaColor = function (iColor) {
                    iMapLayerModel.setPath('areaColor', iColor.toHexString());
                    iMapLayerModel.setPath('areaTransparency', iColor.getAlpha());
                  }.bind(this),
                  setAreaStroke = function (iColor) {
                    iMapLayerModel.setPath('areaStrokeColor', iColor.toHexString());
                    iMapLayerModel.setPath('areaStrokeTransparency', iColor.getAlpha());
                  }.bind(this);

              if (tLegendAttrDesc.get('isNull')) {
                tPickerArray.push(
                    DG.PickerControlView.create({
                      layout: {height: 2 * kRowHeight},
                      label: 'DG.Inspector.color',
                      controlView: DG.PickerColorControl.create({
                        layout: {left: 80, right: 0},
                        classNames: 'dg-map-fill-color'.w(),
                        initialColor: tinycolor(iMapLayerModel.getPath('areaColor'))
                            .setAlpha(iMapLayerModel.getPath('areaTransparency')),
                        setColorFunc: setAreaColor,
                        appendToLayerFunc: getStylesLayer
                      })
                    })
                );
              }
              else if (tLegendAttrDesc.get('isNumeric')) {
                tControlView = SC.View.create(SC.FlowedLayout,
                    {
                      layoutDirection: SC.LAYOUT_HORIZONTAL,
                      layout: {right: 0},
                      isResizable: false,
                      isClosable: false,
                      //defaultFlowSpacing: {right: 5},
                      canWrap: false,
                      align: SC.ALIGN_TOP
                    }
                );
                tSpectrumEnds = DG.ColorUtilities.getAttributeColorSpectrumEndsFromColorMap(tCategoryMap, tAttrColor);
                tLowEndColor = tinycolor(tSpectrumEnds.low.colorString)
                    .setAlpha(iMapLayerModel.getPath('transparency'));
                tHighEndColor = tinycolor(tSpectrumEnds.high.colorString)
                    .setAlpha(iMapLayerModel.getPath('transparency'));
                tControlView.appendChild(DG.PickerColorControl.create({
                      layout: {width: 60},
                      classNames: 'dg-graph-point-color'.w(),
                      initialColor: tLowEndColor,
                      setColorFunc: setLowColor,
                      //closedFunc: setColorFinalized,
                      appendToLayerFunc: getStylesLayer
                    })
                );
                tControlView.appendChild(DG.PickerColorControl.create({
                      layout: {width: 60},
                      classNames: 'dg-graph-point-color'.w(),
                      initialColor: tHighEndColor,
                      setColorFunc: setHighColor,
                      //closedFunc: setColorFinalized,
                      appendToLayerFunc: getStylesLayer
                    })
                );
                tPickerArray.push(
                    DG.PickerControlView.create({
                      layout: {height: 2 * kRowHeight},
                      label: 'DG.Inspector.legendColor',
                      controlView: tControlView
                    })
                );
                tPickerArray.push(SC.CheckboxView.create({
                  layout: {height: 25},
                  title: 'DG.Inspector.lockLegendQuantiles',
                  toolTip: 'DG.Inspector.lockLegendQuantilesTooltip',
                  value: tDataConfig.get('legendQuantilesAreLocked'),
                  classNames: 'dg-graph-lockLegendQuantiles-check'.w(),
                  localize: true,
                  valueDidChange: function () {
                    var quantilesAreLocked = !tDataConfig.get('legendQuantilesAreLocked'),
                       logMessage = "Set quantilesAreLocked to " + quantilesAreLocked;
                    DG.UndoHistory.execute(DG.Command.create({
                      name: 'legend.quintilesAreLockedChange',
                      undoString: quantilesAreLocked ? 'DG.Undo.legend.lockQuantiles' : 'DG.Undo.legend.unlockQuantiles',
                      redoString: quantilesAreLocked ? 'DG.Redo.legend.lockQuantiles' : 'DG.Redo.legend.unlockQuantiles',
                      log: logMessage,
                      execute: function () {
                        tDataConfig.toggleProperty('legendQuantilesAreLocked');
                      }.bind(this),
                      undo: function () {
                        tDataConfig.toggleProperty('legendQuantilesAreLocked');
                      }.bind(this)
                    }));
                  }.bind(this).observes('value')
                }));
              }
              else if (tLegendAttrDesc.get('isCategorical')) {
                tContentView = SC.View.create(SC.FlowedLayout,
                    {
                      layoutDirection: SC.LAYOUT_VERTICAL,
                      isResizable: false,
                      isClosable: false,
                      defaultFlowSpacing: {bottom: 5},
                      canWrap: false,
                      align: SC.ALIGN_TOP
                    }
                );
                tScrollView = SC.ScrollView.create({
                  layout: {height: 100},
                  hasHorizontalScroller: false,
                  contentView: tContentView
                });
                var tLegendAttribute = tLegendAttrDesc.get('attribute');
                tLegendAttribute.forEachCategory(function (iCategory) {
                  var tCalcColor = DG.ColorUtilities.calcCaseColor(iCategory, tLegendAttrDesc),
                      tInitialColor = tCategoryMap[iCategory] ?
                      tCategoryMap[iCategory] :
                          tCalcColor.colorString || tCalcColor;
                  tInitialColor = tinycolor(tInitialColor.colorString || tInitialColor).setAlpha(iMapLayerModel.get('transparency'));
                  tContentView.appendChild(DG.PickerControlView.create({
                    layout: {height: 2 * kRowHeight},
                    label: iCategory,
                    controlView: DG.PickerColorControl.create({
                      layout: {width: 80, right: 0},
                      classNames: 'dg-graph-point-color'.w(),
                      initialColor: tInitialColor,
                      colorKey: iCategory,
                      setColorFunc: setCategoryColor,
                      //closedFunc: setCategoryColorFinalized,
                      appendToLayerFunc: getStylesLayer
                    })
                  }));
                }.bind(this));
                tPickerArray.push(tScrollView);
              }
              tPickerArray.push(DG.PickerControlView.create({
                layout: {height: 2 * kRowHeight},
                label: 'DG.Inspector.stroke',
                controlView: DG.PickerColorControl.create({
                  layout: {left: 80, right: 0},
                  classNames: 'map-areaStroke-color'.w(),
                  initialColor: tinycolor(iMapLayerModel.getPath('areaStrokeColor'))
                      .setAlpha(iMapLayerModel.getPath('areaStrokeTransparency')),
                  setColorFunc: setAreaStroke,
                  appendToLayerFunc: getStylesLayer
                })
              }));

              tPickerArray.push(SC.CheckboxView.create({
                layout: {height: 25},
                title: 'DG.Inspector.strokeSameAsFill',
                value: iMapLayerModel.get('strokeSameAsFill'),
                classNames: 'dg-graph-strokeSameAsFill-check'.w(),
                localize: true,
                valueDidChange: function () {
                  var becomingSameAsFill = !iMapLayerModel.get('strokeSameAsFill'),
                      logMessage = "Made stroke color " + (becomingSameAsFill ? "same as fill" : "independent of fill");
                  DG.UndoHistory.execute(DG.Command.create({
                    name: 'map.strokeSameAsFillChange',
                    undoString: becomingSameAsFill ? 'DG.Undo.graph.makeStrokeSameAsFill' : 'DG.Undo.graph.makeStrokeIndependent',
                    redoString: becomingSameAsFill ? 'DG.Redo.graph.makeStrokeSameAsFill' : 'DG.Redo.graph.makeStrokeIndependent',
                    log: logMessage,
                    executeNotification: {
                      action: 'notify',
                      resource: 'component',
                      values: {
                        operation: 'toggle stroke same as fill',
                        type: 'DG.MapView'
                      }
                    },
                    execute: function () {
                      iMapLayerModel.toggleProperty('strokeSameAsFill');
                    }.bind(this),
                    undo: function () {
                      iMapLayerModel.toggleProperty('strokeSameAsFill');
                    }.bind(this)
                  }));
                }.bind(this).observes('value')
              }));

              // Instead of returning tPickerArray...
              tPickerArray.forEach(function (item) {
                tDataCollectionLayerControls.appendChild(item);
              });
            }
          }.bind(this));

          return tResultArray;

        }.property(),

        /**
         * Called from inspector rescale button
         */
        rescaleFunction: function () {
          this.get('mapView').fitBounds();
        },

        // Copied and modified from map_view.js so it calls back the original and updates its value
        changeBaseMap: function (iSegmentedView) {
          this.getPath('mapView').changeBaseMap(iSegmentedView.get('value'));
        }
      };

    }()) // function closure
);


/* >>>>>>>>>> BEGIN source/components/map/map_data_configuration.js */
// ==========================================================================
//                      DG.MapDataConfiguration
//
//  Author:   William Finzer
//
//  Copyright ©2014 Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
sc_require('components/graph_map_common/plot_data_configuration');

/** @class  DG.MapDataConfiguration - The object that describes the manner in which attributes are
 assigned to places in a map.

 @extends DG.PlotDataConfiguration
 */
DG.MapDataConfiguration = DG.PlotDataConfiguration.extend(
    /** @scope DG.MapDataConfiguration.prototype */
    {
      /**
       * Subclasses will override
       */
      collectionClient: function () {
        return null;
      }.property(),

      /**
       * @property {SC.Array of DG.Case} All cases, both hidden and visible
       */
      allCases: function () {
        return [];
      }.property(),

      hasLatLongAttributes: false,

      hasPolygonAttribute: false

    });


/* >>>>>>>>>> BEGIN source/components/map/map_layer_model.js */
// ==========================================================================
//                            DG.MapModel
//
//  Author:   William Finzer
//
//  Copyright ©2014 Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph_map_common/data_layer_model');

/** @class  DG.MapLayerModel - The model for a layer in a map.

 @extends DG.DataLayerModel
 */
DG.MapLayerModel = DG.DataLayerModel.extend(
    /** @scope DG.MapLayerModel.prototype */
    {
      isVisible: true,

      init: function() {
        arguments.callee.base.apply(this,arguments);
      },

      somethingIsSelectable: function() {
        return false;
      }.property(),

      gridIsVisible: function() {
        return false;
      }.property(),

      /**
       * Base class returns false
       * @return {boolean}
       */
      hasValidMapAttributes: function() {
        return false;
      },

      handleLegendAttrChange: function() {
        var tLegendAttrDesc = this.getPath('dataConfiguration.legendAttributeDescription');
        if( tLegendAttrDesc) {
          tLegendAttrDesc.set('offsetMinProportion', DG.PlotUtilities.kMapColorRangeOffset);
          tLegendAttrDesc.invalidateCaches();
        }
      }.observes('dataConfiguration.legendAttributeDescription.attribute'),

      handleLegendCategoryMapChange: function() {
        this.notifyPropertyChange('colorMap');
      }.observes('dataConfiguration.legendAttributeDescription.attribute.categoryMap'),

      handleOneDataContextChange: function( iNotifier, iChange) {
        arguments.callee.base.apply(this,arguments);

        var tDataConfiguration = this.get('dataConfiguration'),
            tOperation = iChange && iChange.operation;

        if( !tDataConfiguration)
          return; // Occurs when a notification was queued up before a destroy took place

        if (tOperation === 'deleteCases')
          this.get('dataConfiguration').synchHiddenCases();
        if (tOperation === 'selectCases')
          this.notifyPropertyChange('selection');

        // We must invalidate before we build indices because the change may
        // have affected the set of included cases, which affects indices.
        // It would be better not to be dealing with indices at all, but
        // that refactoring is left for another day.
        this.get('dataConfiguration').invalidateCaches( null, iChange);
        iChange.indices = this.buildIndices( iChange);
        this.dataRangeDidChange( this, 'revision', this, iChange.indices);
        this.set('lastChange', iChange);
      },

      /**
       * One or more of the attributes belonging to the collection used by this layer has been changed;
       * e.g. by having its name changed.
       * @param iChange {Object}
       */
      handleUpdateAttributes: function( iChange) {
        if( this.isAffectedByChange( iChange)) {
          this.notifyPropertyChange('attributeUpdated');
          var tAssignedAttr = this.getPath( 'dataConfiguration.legendAttributeDescription.attribute'),
              tAssignedAttrID = tAssignedAttr && tAssignedAttr.get('id');
          if( !SC.none(tAssignedAttrID)) {
            var tSubModel = this.get('legend');
            if (tSubModel)
              tSubModel.handleUpdateAttribute(tAssignedAttrID);
          }
        }
      },

      /**
       * This method is called when an area, latitude, or longitude attribute is deleted from the data context currently
       * being used by this map. Our job is to reconfigure our data configuration so there will no longer be any attempt
       * to plot data
       *
       * @param iDescKey {String}
       */
      removeAttribute: function( iDescKey) {
        var tDescription = this.getPath('dataConfiguration.' + iDescKey);
        if( tDescription) {
          tDescription.removeAllAttributes();
          this.notifyPropertyChange('attributeRemoved');
        }
      },

      /**
       @param {CaseModel} iCase The case to be selected.
       @param {Boolean} iExtend Should the current selection be extended?
       */
      selectCase: function( iCase, iExtend) {
        var tSelection = this.get('selection'),
            tChange = {
              operation: 'selectCases',
              collection: this.get('collectionClient'),
              cases: [ iCase ],
              select: true,
              extend: iExtend
            };

        if( tSelection.get('length') !== 0) {
          if( tSelection.contains( iCase)) {  // Case is already selected
            if( iExtend) {
              tChange.select = false;
            }
            // clicking on a selected case leaves it selected
            else return;
          }
          else {
            tChange.select = true;
          }
        }

        this.get('dataContext').applyChange( tChange);
      },

      /**
       * Not yet. Compare with dot chart <==> bar chart
       * @property {Boolean}
       */
      canSupportConfigurations: function() {
        return false;
      }.property(),

      /**
       * Returns true if the specified change could affect the current map
       * @param     {object}  - iChange
       * @returns   {boolean} - true if the change could affect the plot; false otherwise
       */
      isAffectedByChange: function( iChange) {
        var attrs, i, collChange, collChanges, collChangeCount;

        // returns true if the specified list of attribute IDs contains any
        // that are being displayed in the map in any graph place
        var containsMappedAttrs = function(iAttrIDs) {
          var mappedAttrs = this.getPath('dataConfiguration.placedAttributeIDs'),
              attrCount = iAttrIDs && iAttrIDs.length,
              i, attrID;
          for (i = 0; i < attrCount; ++i) {
            attrID = iAttrIDs[i];
            if (mappedAttrs.indexOf(attrID) >= 0)
              return true;
          }
          return false;
        }.bind(this);

        switch (iChange.operation) {
          case 'createCases':
          case 'deleteCases':
            return true;
          case 'updateCases':
            attrs = iChange.attributeIDs;
            if (!attrs) return true;  // all attributes affected
            return containsMappedAttrs(attrs);
          case 'dependentCases':
            collChanges = iChange.changes;
            collChangeCount = collChanges ? collChanges.length : 0;
            for (i = 0; i < collChangeCount; ++i) {
              collChange = collChanges[i];
              if (collChange) {
                attrs = collChange.attributeIDs;
                if (attrs && containsMappedAttrs(attrs))
                  return true;
              }
            }
            return false;
          case 'updateAttributes':
            attrs = iChange.attrPropsArray.map( function( iProp) {
              return iProp.id;
            });
            return containsMappedAttrs(attrs);
        }

        // For now, we'll assume all other changes affect us
        return true;
      },

      checkboxDescriptions: function() {
        return [];
      }.property(),

      lastValueControls: function() {
        return [];
      }.property(),

      _observedDataConfiguration: null,

      /**
       * Store the information needed to put my data configuration back together.
       * @return {Object}
       */
      createStorage: function () {
        var tStorage = {},
            tDataContext = this.get('dataContext'),
            tDataConfiguration = this.get('dataConfiguration'),
            tHiddenCases = tDataConfiguration && tDataConfiguration.get('hiddenCases');

        tStorage._links_ = {};
        if (tHiddenCases) {
          tStorage._links_.hiddenCases = tHiddenCases
              .filter(function (iCase) {
                return !!iCase;
              })
              .map(function (iCase) {
                return iCase.toLink();
              });
        }

        if (tDataContext)
          tStorage._links_.context = tDataContext.toLink();

        tDataConfiguration.addToStorageForDimension( tStorage, 'legend');
        tStorage.isVisible = this.get('isVisible');


        return tStorage;
      },

      restoreStorage: function( iStorage) {
        // This is our chance to restore the proper data context. We can't do it at a higher level because
        // each of our layers can have a different one
        var tContextID = DG.ArchiveUtils.getLinkID( iStorage, 'context');
        if( !SC.none( tContextID)) {
          this.beginPropertyChanges();  // So that polygon layer will only clear once
          var tDataContext = DG.currDocumentController().getContextByID(tContextID);
          this.set('dataContext', tDataContext);
          this.endPropertyChanges();
        }

        arguments.callee.base.apply(this,arguments);
        var tLegendAttrRef = this.instantiateAttributeRefFromStorage(iStorage, 'legendColl', 'legendAttr'),
            tDataConfig = this.get('dataConfiguration');
        tDataConfig.setAttributeAndCollectionClient('legendAttributeDescription', tLegendAttrRef,
            iStorage.legendRole, iStorage.legendAttributeType);
        if( !SC.none( iStorage.isVisible))
          this.set('isVisible', iStorage.isVisible);
      }
    });
/* >>>>>>>>>> BEGIN source/components/map/map_model.js */
// ==========================================================================
//                            DG.MapModel
//
//  Author:   William Finzer
//
//  Copyright ©2014 Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class  DG.MapModel - The model for a map.

 @extends DG.Object
 */
DG.MapModel = SC.Object.extend(
    /** @scope DG.MapModel.prototype */
    (function () {
      var kDefaultLocation = [45.4408, 12.3155];

      return {
        /**
         * These two properties are from the Leaflet Map and are kept in synch for save and restore
         * by my view.
         */
        center: null,
        zoom: null,
        newCenter: null,
        newZoom: null,

        /**
         * This is the name of the layer used as an argument to L.esri.basemapLayer
         * {@property String}
         */
        baseMapLayerName: null,

        /**
         * Changes the visibility of the layer in Leaflet with the opacity parameter.
         * {@property Boolean}
         */
        baseMapLayerIsVisible: true,

        /**
         * An array of layer models such as mapPointLayerModel and mapPolygonLayerModel
         * @property {[DG.MapLayerModel]}
         */
        mapLayerModels: null,

        /**
         * Set to true during restore as flag to use to know whether to fit bounds or not
         */
        centerAndZoomBeingRestored: false,

        _addLayersForCollection: function (iContext, iCollection) {
          var tLatName, tLongName, tPolygonName,
              tMapLayerModel, tDataConfiguration,
              tLegend,
              tLayerWasAdded = false,
              tAttrNames = (iCollection && iCollection.getAttributeNames()) || [],
              // Make a copy, all lower case. We will need the original if we find a match.
              tLowerCaseNames = tAttrNames.map(function (iAttrName) {
                return iAttrName.toLowerCase();
              }),
              configureLayer = function (iInitializer, iDataConfigClass, iLayerModelClass) {
                tDataConfiguration = iDataConfigClass.create({
                  initializer: iInitializer
                });
                tLegend = DG.LegendModel.create({
                  dataConfiguration: tDataConfiguration,
                  attributeDescription: tDataConfiguration.get('legendAttributeDescription')
                });
                tLegend.addObserver('attributeDescription.attribute', this, this.legendAttributeDidChange);
                tLegend.addObserver('attributeDescription.attributeStats.attributeType',
                    this, this.legendAttributeDidChange);
                tMapLayerModel = iLayerModelClass.create({
                  dataConfiguration: tDataConfiguration,
                  legend: tLegend
                });
                tMapLayerModel.addObserver('somethingIsSelectable', this, this.somethingIsSelectableDidChange);
                tMapLayerModel.addObserver('gridIsVisible', this, this.gridIsVisibleDidChange);
                tMapLayerModel.addObserver('attributeRemoved', this, this.removeMapLayerModel);
                tMapLayerModel.addObserver('attributeUpdated', this, this.handleAttributeUpdated);
                this.mapLayerModels.push(tMapLayerModel);
                tMapLayerModel.invalidate();
              }.bind(this),

              contextAndAttributesAlreadyPresent = function () {
                return this.get('mapLayerModels').some(function (iLayerModel) {
                  var tDataConfig = iLayerModel.get('dataConfiguration'),
                      tExistingContext = tDataConfig.get('dataContext'),
                      tExistingLatID = tDataConfig.get('latAttributeID'),
                      tExistingLongID = tDataConfig.get('longAttributeID'),
                      tExistingPolygonID = tDataConfig.get('polygonAttributeID');
                  if (iContext === tExistingContext) {
                    var tProposedLatID = tLatName && iCollection.getAttributeByName(tLatName).get('id'),
                        tProposedLongID = tLongName && iCollection.getAttributeByName(tLongName).get('id'),
                        tProposedPolygonID = tPolygonName && iCollection.getAttributeByName(tPolygonName).get('id');
                    return (tExistingLatID === tProposedLatID && tExistingLongID === tProposedLongID) ||
                        tExistingPolygonID === tProposedPolygonID;
                  } else return false;
                });
              }.bind(this);

          function pickOutName(iKNames) {
            return tAttrNames.find(function (iAttrName, iIndex) {
              return iKNames.find(function (iKName) {
                return (iKName === tLowerCaseNames[iIndex]);
              });
            });
          }

          tLatName = pickOutName(DG.MapConstants.kLatNames);
          tLongName = pickOutName(DG.MapConstants.kLongNames);
          tPolygonName = pickOutName(DG.MapConstants.kPolygonNames);
          if (!tPolygonName) {  // Try for an attribute that has a boundary type
            ((iCollection && iCollection.get('attrs')) || []).some(function (iAttr) {
              if (iAttr.get('type') === 'boundary') {
                tPolygonName = iAttr.get('name');
                return true;
              } else {
                return false;
              }
            });
          }
          if (!contextAndAttributesAlreadyPresent()) {
            if (tLatName && tLongName) {
              tLayerWasAdded = true;
              configureLayer({
                    context: iContext, collection: iCollection,
                    latName: tLatName, longName: tLongName
                  },
                  DG.MapPointDataConfiguration, DG.MapPointLayerModel);
            }
            if (tPolygonName) {
              tLayerWasAdded = true;
              configureLayer({
                    context: iContext, collection: iCollection,
                    polygonName: tPolygonName
                  },
                  DG.MapPolygonDataConfiguration, DG.MapPolygonLayerModel);
            }
          }
          return tLayerWasAdded;
        },

        _processDocumentContexts: function () {
          var tLayerWasAdded = false;
          DG.currDocumentController().get('contexts').forEach(function (iContext) {
            iContext.get('collections').forEach(function (iCollection) {
              if (this._addLayersForCollection(iContext, iCollection))
                tLayerWasAdded = true;
            }.bind(this));
          }.bind(this));
          return tLayerWasAdded;
        },

        /**
         * Called during init. If we have been given a context and a legendAttributeName, we attempt
         * to add a legend. Then we can delete the two temporary properties.
         * @private
         */
        _processPossibleLegend: function () {
          var tContext = this.get('context'),
              tAttributeName = this.get('legendAttributeName');
          if( tContext && tAttributeName) {
            var tAttribute = tContext.getAttributeByName(tAttributeName),
                tCollClient = tContext.getCollectionForAttribute(tAttribute);
            this.changeAttributeForLegend(tContext, {attribute: tAttribute, collection: tCollClient});
          }
          delete this.context;
          delete this.legendAttributeName;
        },

        /**
         Prepare dependencies.
         */
        init: function () {
          arguments.callee.base.apply(this,arguments);

          this.mapLayerModels = [];

          var layerWasAdded = this._processDocumentContexts();

          this._processPossibleLegend();

          this.set('center', kDefaultLocation); //
          this.set('zoom', 1);  // Reasonable default
          if (!layerWasAdded) {
            if (navigator.geolocation && navigator.geolocation.getCurrentPosition) {
              navigator.geolocation.getCurrentPosition(
                  function (pos) {
                    var coords = pos.coords;
                    this.set('newCenter', [coords.latitude, coords.longitude]);
                    this.set('newZoom', 8);
                  }.bind(this)
              );
            }
          }
          this.set('baseMapLayerName', 'Topographic');

        },

        destroy: function () {
          this.get('mapLayerModels').forEach(function (iLayerModel) {
            this.destroyMapLayer(iLayerModel);
          }.bind(this));
          this.set('mapLayerModels', null);
          arguments.callee.base.apply(this,arguments);
        },

        /**
         * Called during destroy and also when a given layer is no longer relevant due to an attribute
         * being deleted.
         * @param iLayerModel
         */
        destroyMapLayer: function (iLayerModel) {
          iLayerModel.removeObserver('somethingIsSelectable', this, this.somethingIsSelectableDidChange);
          iLayerModel.removeObserver('gridIsVisible', this, this.gridIsVisibleDidChange);
          iLayerModel.removeObserver('attributeRemoved', this, this.removeMapLayerModel);
          iLayerModel.removeObserver('attributeUpdated', this, this.handleAttributeUpdated);
          var tLegend = iLayerModel.get('legend');
          tLegend && tLegend.removeObserver('attributeDescription.attribute',
              this, this.legendAttributeDidChange);
          tLegend && tLegend.removeObserver('attributeDescription.attributeStats.attributeType',
              this, this.legendAttributeDidChange);
          iLayerModel.destroy();
        },

        /**
         * Called by MapController when the document's count of data contexts changes.
         * Run through our list of contexts looking for any that are no longer present.
         *  For each of those, remove corresponding layer(s).
         * For any newly encountered contexts, check to see if each contains map attributes and, if so,
         *  add a layer for each.
         */
        adaptToNewOrRemovedContexts: function () {
          var tDocumentContexts = DG.currDocumentController().get('contexts'),
              tLayerModelsToRemove = [],
              tLayerModelWasAdded = false,
              tLayerModels = this.get('mapLayerModels');
          tLayerModels.forEach(function (iLayerModel) {
            var tLayerContext = iLayerModel.getPath('dataConfiguration.dataContext');
            if (tLayerContext && tDocumentContexts.indexOf(tLayerContext) < 0) {
              // Previously valid context has gone away
              tLayerModelsToRemove.push(iLayerModel);
            }
          });
          tLayerModelsToRemove.forEach(function (iLayerModel) {
            this.destroyMapLayer(iLayerModel);
            var tIndex = tLayerModels.indexOf(iLayerModel);
            tLayerModels.splice(tIndex, 1);
          }.bind(this));
          tLayerModelWasAdded = this._processDocumentContexts();
          if (tLayerModelsToRemove.length > 0 || tLayerModelWasAdded)
            this.notifyPropertyChange('mapLayerModelsChange');
        },

        legendAttributeDidChange: function () {
          this.notifyPropertyChange('legendAttributeChange');
        },

        handleDroppedContext: function (iContext) {
          // Nothing to do since contexts get dealt with at the MapLayerModel
        },

        /**
         * An attribute critical to the given layer model has been removed.
         * This means we should delete this layer model and notify so the view layer
         * can update
         * @param iMapLayerModel {DG.MapLayerModel}
         */
        removeMapLayerModel: function (iMapLayerModel) {
          var tMapLayerModels = this.get('mapLayerModels'),
              tIndex = tMapLayerModels.indexOf(iMapLayerModel);
          tMapLayerModels.splice(tIndex, 1);
          this.destroyMapLayer(iMapLayerModel);
          this.notifyPropertyChange('mapLayerModelsChange');
        },

        /**
         * An attribute critical to the given layer model has been updated, (e.g. its name was changed).
         * We ask the layer model whether the attributes assigned to it still work. If not,
         * @param iMapLayerModel {DG.MapLayerModel}
         */
        handleAttributeUpdated: function (iMapLayerModel) {
          if (!iMapLayerModel.hasValidMapAttributes())
            this.removeMapLayerModel(iMapLayerModel);
        },

        /** create a menu item that removes the attribute on the given legend */
        createRemoveAttributeMenuItem: function (iLegendView) {
          var tAttribute = iLegendView.getPath('model.attributeDescription.attribute') || DG.Analysis.kNullAttribute,
              tName = (tAttribute === DG.Analysis.kNullAttribute) ? '' : tAttribute.get('name'),
              tTitle = ('DG.DataDisplayMenu.removeAttribute_legend').loc(tName);
          return {
            title: tTitle,
            target: this,
            itemAction: this.removeLegendAttribute,
            isEnabled: (tAttribute !== DG.Analysis.kNullAttribute),
            log: "attributeRemoved: { attribute: %@, axis: %@ }".fmt(tName, 'legend'),
            args: [iLegendView.getPath('model.dataConfiguration')]
          };
        },

        createChangeAttributeTypeMenuItem: function (iLegendView) {
          var tDescription = iLegendView.getPath('model.attributeDescription'),
              tAttribute = tDescription && tDescription.get('attribute'),
              tAttributeName = tAttribute && (tAttribute !== -1) ? tAttribute.get('name') : '',
              tIsNumeric = tDescription && tDescription.get('isNumeric'),
              tTitle = (tIsNumeric ? 'DG.DataDisplayMenu.treatAsCategorical' : 'DG.DataDisplayMenu.treatAsNumeric').loc();
          return {
            title: tTitle,
            target: this,
            itemAction: this.changeAttributeType, // call with args, toggling 'numeric' setting
            isEnabled: (tAttribute !== DG.Analysis.kNullAttribute),
            log: "plotAxisAttributeChangeType: { axis: legend, attribute: %@, numeric: %@ }".fmt(tAttributeName, !tIsNumeric),
            args: [iLegendView.getPath('model.dataConfiguration'), !tIsNumeric]
          };
        },

        removeLegendAttribute: function (iDataConfiguration) {
          iDataConfiguration.setAttributeAndCollectionClient('legendAttributeDescription', null);
        },

        changeAttributeType: function (iDataConfiguration, iTreatAsNumeric) {
          iDataConfiguration.setAttributeType('legendAttributeDescription', iTreatAsNumeric);
        },

        /**
         Sets the attribute for the legend for the layer that uses the given context
         @param  {DG.DataContext}      iDataContext -- The data context for this graph
         @param  {Object}              iAttrRefs -- The attribute to set for the axis
         {DG.CollectionClient} iAttrRefs.collection -- The collection that contains the attribute
         {DG.Attribute}        iAttrRefs.attribute -- Array of attributes to set for the legend
         */
        changeAttributeForLegend: function (iDataContext, iAttrRefs) {
          this.get('mapLayerModels').forEach(function (iLayerModel) {
            if (iDataContext === iLayerModel.get('dataContext')) {
              iLayerModel.changeAttributeForLegend(iDataContext, iAttrRefs);
            }
          });
        },

        someLayerReturnsTrue: function (iPropName) {
          var tResult = this.get('mapLayerModels').some(function (iLayerModel) {
            var tLayerResult = iLayerModel.get(iPropName);
            return tLayerResult;
          });
          return tResult;
        },

        somethingIsSelectable: function () {
          return this.someLayerReturnsTrue('somethingIsSelectable');
        }.property(),
        somethingIsSelectableDidChange: function () {
          this.notifyPropertyChange('somethingIsSelectable');
        },

        /**
         * When changed by user action, value is passed to all grid models
         * @property {Number}
         */
        gridMultiplier: 1,
        gridMultiplerDidChange: function () {
          this.get('mapLayerModels').forEach(function (iLayerModel) {
            iLayerModel.setPath('gridModel.gridMultiplier', this.get('gridMultiplier'));
          }.bind(this));
        }.observes('gridMultiplier'),

        gridIsVisible: function () {
          return this.someLayerReturnsTrue('gridIsVisible');
        }.property(),
        gridIsVisibleDidChange: function () {
          this.notifyPropertyChange('gridIsVisible');
        },

        /**
         * Override superclass
         * @returns {boolean}
         */
        wantsInspector: function () {
          return this.someLayerReturnsTrue('wantsInspector');
        },

        hasLatLongAttributes: function () {
          return this.someLayerReturnsTrue('hasLatLongAttributes');
        }.property(),

        hasPolygonAttribute: function () {
          return this.someLayerReturnsTrue('hasPolygonAttribute');
        }.property('dataConfiguration'),

        /**
         * We can rescale if we have some data to rescale to.
         * @return {Boolean}
         */
        canRescale: function () {
          return this.someLayerReturnsTrue('canRescale');
        }.property('hasNumericAxis', 'plot'),

        /**
         * Not yet. Compare with dot chart <==> bart chart
         * @property {Boolean}
         */
        canSupportConfigurations: function () {
          return false;
        }.property(),

        selectAll: function (iBool) {
          this.get('mapLayerModels').forEach(function (iMapLayerModel) {
            iMapLayerModel.selectAll(iBool);
          });
        },

        /**
         * Returns true if the specified change could affect the current map
         * @param     {object}  - iChange
         * @returns   {boolean} - true if the change could affect the plot; false otherwise
         */
        isAffectedByChange: function (iChange) {
          var attrs, i, collChange, collChanges, collChangeCount;

          // returns true if the specified list of attribute IDs contains any
          // that are being displayed in the map in any graph place
          var containsMappedAttrs = function (iAttrIDs) {
            var mappedAttrs = this.getPath('dataConfiguration.placedAttributeIDs'),
                attrCount = iAttrIDs && iAttrIDs.length,
                i, attrID;
            for (i = 0; i < attrCount; ++i) {
              attrID = iAttrIDs[i];
              if (mappedAttrs.indexOf(attrID) >= 0)
                return true;
            }
            return false;
          }.bind(this);

          switch (iChange.operation) {
            case 'createCases':
            case 'deleteCases':
              return true;
            case 'updateCases':
              attrs = iChange.attributeIDs;
              if (!attrs) return true;  // all attributes affected
              return containsMappedAttrs(attrs);
            case 'dependentCases':
              collChanges = iChange.changes;
              collChangeCount = collChanges ? collChanges.length : 0;
              for (i = 0; i < collChangeCount; ++i) {
                collChange = collChanges[i];
                if (collChange) {
                  attrs = collChange.attributeIDs;
                  if (attrs && containsMappedAttrs(attrs))
                    return true;
                }
              }
              return false;
          }

          // For now, we'll assume all other changes affect us
          return true;
        },

        _observedDataConfiguration: null,

        firstDataConfiguration: function () {
          var tMapLayerModels = this.get('mapLayerModels');
          if (tMapLayerModels.length > 0)
            return tMapLayerModels[0].get('dataConfiguration');
          else return null;
        }.property(),

        lastValueControls: function () {
          var tControls = [];
          this.get('mapLayerModels').forEach(function (iMapLayerModel) {
            tControls = tControls.concat(iMapLayerModel.get('lastValueControls'));
          });
          return tControls;
        }.property(),

        createHideShowSelectionMenuItems: function () {
          var getSelectionSpecs = function () {
            var tSpecs = {
              numSelected: 0,
              numUnSelected: 0,
              numHidden: 0,
              selectionData: [/*{
                           dataConfig: null,
                           cases: null,
                           selected: null
                         }*/]
            };
            this.get('mapLayerModels').forEach(function (iLayerModel) {
              var tConfig = iLayerModel.get('dataConfiguration');
              if (!tSpecs.selectionData.find(function (iSpec) {
                return iSpec.dataConfig === tConfig;
              })) {
                var tData = {
                  dataConfig: tConfig,
                  cases: tConfig.get('cases').toArray(),
                  selected: tConfig.get('selection').toArray(),
                  hidden: tConfig.get('hiddenCases').toArray()
                };
                tSpecs.numSelected += tData.selected.length;
                tSpecs.numUnSelected += (tData.cases.length - tData.selected.length);
                tSpecs.numHidden += tData.hidden.length;
                tSpecs.selectionData.push(tData);
              }
            });
            return tSpecs;
          }.bind(this);

          var tSelectionSpecs = getSelectionSpecs(),
              tSomethingIsSelected = tSelectionSpecs.numSelected > 0,
              tSomethingIsUnselected = tSelectionSpecs.numUnSelected > 0,
              tSomethingHidden = tSelectionSpecs.numHidden > 0,
              tHideSelectedNumber = tSelectionSpecs.numSelected > 1 ? 'Plural' : 'Sing',
              tHideUnselectedNumber = tSelectionSpecs.numUnSelected > 1 ? 'Plural' : 'Sing';

          function hideSelectedCases() {
            DG.UndoHistory.execute(DG.Command.create({
              name: 'graph.display.hideSelectedCases',
              undoString: 'DG.Undo.hideSelectedCases',
              redoString: 'DG.Redo.hideSelectedCases',
              log: "Hide %@ selected cases".fmt(tSelectionSpecs.numSelected.length),
              executeNotification: {
                action: 'notify',
                resource: 'component',
                values: {
                  operation: 'hide selected cases',
                  type: 'DG.MapView'
                }
              },
              execute: function () {
                this._undoData = tSelectionSpecs;
                tSelectionSpecs.selectionData.forEach(function (iData) {
                  iData.dataConfig.hideCases(iData.selected);
                });
              },
              undo: function () {
                this._undoData.selectionData.forEach(function (iData) {
                  iData.dataConfig.showCases(iData.selected);
                });
              }
            }));
          }

          function hideUnselectedCases() {
            DG.UndoHistory.execute(DG.Command.create({
              name: 'graph.display.hideUnselectedCases',
              undoString: 'DG.Undo.hideUnselectedCases',
              redoString: 'DG.Redo.hideUnselectedCases',
              log: "Hide %@ unselected cases".fmt(tSelectionSpecs.numCases - tSelectionSpecs.numSelected),
              executeNotification: {
                action: 'notify',
                resource: 'component',
                values: {
                  operation: 'hide unselected cases',
                  type: 'DG.MapView'
                }
              },
              execute: function () {
                this._undoData = tSelectionSpecs;
                tSelectionSpecs.selectionData.forEach(function (iData) {
                  var tUnselected = DG.ArrayUtils.subtract(iData.cases, iData.selected,
                      function (iCase) {
                        return iCase.get('id');
                      });
                  iData.dataConfig.hideCases(tUnselected);
                });
              },
              undo: function () {
                this._undoData.selectionData.forEach(function (iData) {
                  var tUnselected = DG.ArrayUtils.subtract(iData.cases, iData.selected,
                      function (iCase) {
                        return iCase.get('id');
                      });
                  iData.dataConfig.showCases(tUnselected);
                });
              }
            }));
          }

          function showAllCases() {
            DG.UndoHistory.execute(DG.Command.create({
              name: 'graph.display.showAllCases',
              undoString: 'DG.Undo.showAllCases',
              redoString: 'DG.Redo.showAllCases',
              log: "Show all cases",
              executeNotification: {
                action: 'notify',
                resource: 'component',
                values: {
                  operation: 'show all cases',
                  type: 'DG.MapView'
                }
              },
              execute: function () {
                this._undoData = tSelectionSpecs;
                tSelectionSpecs.selectionData.forEach(function (iData) {
                  iData.dataConfig.showAllCases();
                });
              },
              undo: function () {
                this._undoData.selectionData.forEach(function (iData) {
                  iData.dataConfig.hideCases(iData.hidden);
                });
              }
            }));
          }

          return [
            // Note that these 'built' string keys will have to be specially handled by any
            // minifier we use
            {
              title: ('DG.DataDisplayMenu.hideSelected' + tHideSelectedNumber), isEnabled: tSomethingIsSelected,
              target: this, action: hideSelectedCases },
            { title: ('DG.DataDisplayMenu.hideUnselected' + tHideUnselectedNumber), isEnabled: tSomethingIsUnselected,
              target: this, action: hideUnselectedCases },
            { title: 'DG.DataDisplayMenu.showAll', isEnabled: tSomethingHidden,
              target: this, action: showAllCases
            }
          ];
        },

        createStorage: function () {
          var tStorage = {};
          tStorage.center = this.get('center');
          tStorage.zoom = this.get('zoom');
          tStorage.baseMapLayerName = this.get('baseMapLayerName');
          tStorage.gridMultiplier = this.get('gridMultiplier');
          tStorage.layerModels = this.get('mapLayerModels').map(function (iLayerModel) {
            return iLayerModel.createStorage();
          });

          return tStorage;
        },

        restoreStorage: function (iStorage) {
          if (iStorage.mapModelStorage) {
            // The following two 'new' properties cause the base map to respond
            this.set('newCenter', iStorage.mapModelStorage.center);
            this.set('newZoom', iStorage.mapModelStorage.zoom);
            this.set('center', iStorage.mapModelStorage.center);
            this.set('zoom', iStorage.mapModelStorage.zoom);
            this.set('baseMapLayerName', iStorage.mapModelStorage.baseMapLayerName);
            if (!SC.none(iStorage.mapModelStorage.gridMultiplier))
              this.set('gridMultiplier', iStorage.mapModelStorage.gridMultiplier);
            this.set('centerAndZoomBeingRestored', true);
            this.get('mapLayerModels').forEach(function (iLayerModel, iIndex) {
              if (iStorage.mapModelStorage.layerModels && iIndex < iStorage.mapModelStorage.layerModels.length) {
                var tLayerStorage = SC.isArray(iStorage.mapModelStorage.layerModels) ?
                    iStorage.mapModelStorage.layerModels[iIndex] : iStorage;
                iLayerModel.restoreStorage(tLayerStorage);
              }
            });
          }
        }

      };

    }()) // function closure
);


/* >>>>>>>>>> BEGIN source/components/map/map_view.js */
// ==========================================================================
//                            DG.MapView
//
//  Author:   William Finzer
//
//  Copyright ©2014 Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================


/** @class  DG.MapView

 A view on a map and plotted data.

 @extends SC.View
 */
DG.MapView = SC.View.extend(DG.GraphDropTarget,
    /** @scope DG.MapView.prototype */ {

      displayProperties: ['model.dataConfiguration.attributeAssignment',
        'model.dataConfiguration.legendQuantilesAreLocked'],

      kPadding: [10, 10],

      /**
       * @property {DG.MapModel}
       */
      model: null,

      /**
       A map view is neither horizontal or vertical. Distinguish it from axes
       @property { String }
       */
      orientation: DG.GraphTypes.EOrientation.kNone,

      /**
       * @property {DG.Attribute}
       */
      plottedAttribute: function() {
        var tLegendViews = this.get('legendViews');
        return tLegendViews.length === 1 ? tLegendViews[0].get('plottedAttribute') : null;
      }.property(),

      /**
       * @property {DG.BaseMapView}
       */
      mapLayer: null,
      mapBinding: '.mapLayer.map',

      /**
       * @property [{DG.MapPolygonLayer}]
       */
      mapPolygonLayers: null,

      /**
       * @property {DG.MapPointView}
       */
      mapPointView: null,

      /**
       * @property {DG.MapGridLayer}
       */
      mapGridLayer: null,

      /**
       * @property [{DG.LegendView}]
       */
      legendViews: null,

      /**
       * Assigned on creation. Called with newly created LegendView.
       * @property {Function}
       */
      legendViewCreationCallback: null,

      /**
       * SC.SliderView
       */
      gridControl: null,

      /**
       * SC.ImageButtonView
       */
      marqueeTool: null,

      selection: null,
      selectionBinding: '*model.casesController.selection',

      _ignoreMapDisplayChanges: false,
      _fitBoundsInProgress: false,
      _mapDisplayChangeInProgress: false,
      _mapDisplayChange: null,

      paper: function () {
        return this.getPath('mapPointView.paper');
      }.property(),

      layerManager: function () {
        return this.getPath('mapPointView.layerManager');
      }.property(),

      dataConfiguration: function() {
        return this.getPath('model.firstDataConfiguration');
      }.property(),

      init: function () {
        arguments.callee.base.apply(this,arguments);
        var tMapLayer = DG.BaseMapView.create({model: this.get('model')});

        this.set('mapLayer', tMapLayer);
        this.appendChild(tMapLayer);

        this.legendViews = [];

        this.gridControl = SC.SliderView.create({
          controlSize: SC.SMALL_CONTROL_SIZE,
          layout: {width: 40, height: 16, top: 16, right: 58},
          toolTip: 'DG.MapView.gridControlHint'.loc(),
          classNames: ['dg-map-grid-slider'],
          minimum: 0.1,
          maximum: 2.0,
          step: 0,
          value: this.getPath('model.gridMultiplier'),
          persistedValue: this.getPath('model.gridMultiplier'),
          previousPersistedValue: this.getPath('model.gridMultiplier'),
          isVisible: false,
          mouseUp: function (iEvent) {
            arguments.callee.base.apply(this,arguments);
            if (this.get('value') !== this.get('persistedValue')) {
              this.set('previousPersistedValue', this.get('persistedValue'));
              this.set('persistedValue', this.get('value'));
              DG.logUser('changeGridMultiplier: %@', this.get('value'));
            }
          }
        });
        this.appendChild(this.gridControl);

        this.marqueeTool = SC.ImageButtonView.create({
          buttonBehavior: SC.PUSH_BEHAVIOR,
          layout: {right: 10, top: 9, width: 32, height: 32},
          toolTip: 'DG.MapView.marqueeHint'.loc(),
          image: 'dg-map-marquee',
          action: 'setMarqueeMode',
          isVisible: false
        });
        this.appendChild(this.marqueeTool);

        // Don't trigger undo events until the map has settled down initially
        this._ignoreMapDisplayChanges = true;
        tMapLayer._setIdle();

        DG.globalsController.addObserver('globalValueChanges', this, 'globalValueDidChange');
      },

      destroy: function () {
        this._ignoreMapDisplayChanges = true; // So we don't install an idleTask in response to layout changes
        this.model.destroy(); // so that it can unlink observers
        DG.globalsController.removeObserver('globalValueChanges', this, 'globalValueDidChange');
        this.get('legendViews').forEach( function( iLegendView) {
          iLegendView.removeObserver('dragData', this, this.legendDidAcceptDrop);
        });
        arguments.callee.base.apply(this,arguments);
      },

      setMarqueeMode: function () {
        var tMapPointView = this.get('mapPointView'),
            tMapGridLayer = this.get('mapGridLayer');
        if (tMapPointView && tMapPointView.get('isVisible')) {
          tMapPointView.set('isInMarqueeMode', true);
        }
        else if (tMapGridLayer && tMapGridLayer.get('isVisible')) {
          tMapGridLayer.set('isInMarqueeMode', true);
        }
        DG.logUser('marqueeToolSelect');
      },

      marqueeModeChanged: function () {
        var tGridInMarqueeMode = this.getPath('mapGridLayer.isInMarqueeMode'),
            tImage = (this.getPath('mapPointView.isInMarqueeMode') || tGridInMarqueeMode) ?
                'dg-map-marquee-selected' :
                'dg-map-marquee';
        this.setPath('marqueeTool.image', tImage);
      }.observes('mapPointView.isInMarqueeMode', 'mapGridLayer.isInMarqueeMode'),

      changeBaseMap: function (iNewValue) {
        var tOldBackground = this.getPath('model.baseMapLayerName');
        DG.UndoHistory.execute(DG.Command.create({
          name: "map.changeBaseMap",
          undoString: 'DG.Undo.map.changeBaseMap',
          redoString: 'DG.Redo.map.changeBaseMap',
          log: 'Map base layer changed: %@'.fmt(iNewValue),
          _componentId: this.getPath('controller.model.id'),
          _controller: function () {
            return DG.currDocumentController().componentControllersMap[this._componentId];
          },
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'change base map',
              type: 'DG.MapView'
            }
          },
          execute: function () {
            this._controller().setPath('view.contentView.model.baseMapLayerName', iNewValue);
          },
          undo: function () {
            this._controller().setPath('view.contentView.model.baseMapLayerName', tOldBackground);
            this._controller().setPath('view.contentView.backgroundControl.value', [tOldBackground]);
          },
          redo: function () {
            this._controller().setPath('view.contentView.model.baseMapLayerName', iNewValue);
            this._controller().setPath('view.contentView.backgroundControl.value', [iNewValue]);
          }
        }));
      },

      changeGridSize: function () {
        var tControlValue = this.gridControl.get('value');
        this.setPath('model.gridMultiplier', tControlValue);
      }.observes('gridControl.value'),

      changePersistedGridSize: function () {
        var tControlValue = this.gridControl.get('persistedValue'),
            tPreviousControlValue = this.gridControl.get('previousPersistedValue');

        DG.UndoHistory.execute(DG.Command.create({
          name: "map.changeGridSize",
          undoString: 'DG.Undo.map.changeGridSize',
          redoString: 'DG.Redo.map.changeGridSize',
          log: "Map grid size changed: {from: %@, to: %@}".fmt(tPreviousControlValue, tControlValue),
          _componentId: this.getPath('controller.model.id'),
          _controller: function () {
            return DG.currDocumentController().componentControllersMap[this._componentId];
          },
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'change grid size',
              type: 'DG.MapView'
            }
          },
          execute: function () {
          },
          undo: function () {
            this._controller().setPath('view.contentView.model.gridMultiplier', tPreviousControlValue);
            this._controller().setPath('view.contentView.gridControl.value', tPreviousControlValue);
          },
          redo: function () {
            this._controller().setPath('view.contentView.model.gridMultiplier', tControlValue);
            this._controller().setPath('view.contentView.gridControl.value', tControlValue);
          }
        }));
      }.observes('gridControl.persistedValue'),

      addPointLayers: function () {
        if (!this.get('mapPointView')) {

          var tMapPointView = DG.MapPointView.create(
              {
                mapLayer: this.get('mapLayer'),
                model: this.get('model')
              });

          this.set('mapPointView', tMapPointView);
          this.appendChild(tMapPointView);
        }
        else {
          this.get('mapPointView').addMapPointLayers();
        }

        var tAlreadyUsedMapPointLegends = this.get('legendViews').map(function (iLegendView) {
              return iLegendView.get('model');
            }),
            tUnusedMapPointLayers = this.getPath('mapPointView.mapPointLayers').filter( function( iLayer) {
              return tAlreadyUsedMapPointLegends.indexOf( iLayer.getPath('model.legend')) < 0;
            });
        tUnusedMapPointLayers.forEach(function (iMapPointLayer) {
          var tNewLegendView = DG.LegendView.create( { model: iMapPointLayer.getPath('model.legend')});
          this.observeLegendView( tNewLegendView);
          this.appendChild(tNewLegendView);
          this.legendViewCreationCallback(tNewLegendView);
          this.get('legendViews').push( tNewLegendView);
        }.bind( this));

        this.adjustLayout(this.renderContext(this.get('tagName')));
        this.updateMarqueeToolVisibility();
        this.updateGridControlVisibility();
      },

      numberOfLayerModelsChanged: function () {

        function processLayerArray( iLayerArray) {
          iLayerArray.filter( function( iLayer) {
            return tMapLayerModels.indexOf( iLayer.get('model')) < 0;
          }).forEach( function( iLayerToRemove) {
            iLayerArray.splice( iLayerArray.indexOf( iLayerToRemove) , 1);
            iLayerToRemove.destroy();
          });
        }

        var tMapLayerModels = this.getPath( 'model.mapLayerModels'),
            tPolygonLayers = this.get('mapPolygonLayers'),
            tPointLayers = this.getPath('mapPointView.mapPointLayers');
        if( tMapLayerModels.length > tPolygonLayers.length + tPointLayers.length) {
          // The routines to add point and polygon layers check to avoid duplicates, so we can just call them both.
          this.addPointLayers();
          this.addPolygonLayers();
          this.displayDidChange();
          this.fitBounds();
        }
        else {
          processLayerArray( tPolygonLayers);
          processLayerArray( tPointLayers);
          this.displayDidChange();
        }
        this.updateMarqueeToolVisibility();
      }.observes('model.mapLayerModelsChange'),

      updateMarqueeToolVisibility: function () {
        this.setPath('marqueeTool.isVisible', this.getPath('model.somethingIsSelectable'));
      },

      somethingIsSelectableDidChange: function() {
        this.updateMarqueeToolVisibility();
      }.observes('model.somethingIsSelectable'),

      updateGridControlVisibility: function () {
        this.setPath('gridControl.isVisible', this.getPath('model.gridIsVisible'));
      },

      gridIsVisibleDidChange: function() {
        this.updateGridControlVisibility();
      }.observes('model.gridIsVisible'),

      addPolygonLayers: function () {
        var tNewLayerAdded = false;
        if (!this.get('mapPolygonLayers')) {
          this.set('mapPolygonLayers', []);
        }
        var tLegendViews = this.get('legendViews'),
            tPolygonLayers = this.get('mapPolygonLayers'),
            tModelsForExistingLayers = tPolygonLayers.map(function (iLayer) {
              return iLayer.get('model');
            });
        this.getPath('model.mapLayerModels').forEach(function (iLayerModel) {
          if (iLayerModel.constructor === DG.MapPolygonLayerModel &&
              tModelsForExistingLayers.indexOf(iLayerModel) < 0) {
            var tNewLayer = DG.MapPolygonLayer.create(
                {
                  mapSource: this,
                  model: iLayerModel
                });
            tPolygonLayers.push(tNewLayer);
            tNewLayer.addFeatures();
            var tLegendView = DG.LegendView.create({model: iLayerModel.get('legend')});
            this.observeLegendView( tLegendView);
            this.appendChild(tLegendView);
            tLegendViews.push(tLegendView);
            this.legendViewCreationCallback(tLegendView);
            tNewLayerAdded = true;
          }
        }.bind(this));
        if (!this.getPath('model.centerAndZoomBeingRestored') && tNewLayerAdded) {
          this.fitBounds();
        }
      },

      /**
       * Cause the map to shrink or expand to encompass the data
       */
      fitBounds: function () {
        var tPolygonLayers = this.get('mapPolygonLayers'),
            tPointView = this.get('mapPointView'),
            tBounds = tPointView ? tPointView.getBounds() : null;
        if (tPolygonLayers) {
          tPolygonLayers.forEach(function (iLayer) {
            if( iLayer.getPath('model.isVisible')) {
              var tPolyBounds = iLayer.getBounds();
              if (!SC.none(tPolyBounds)) {
                if (!tBounds)
                  tBounds = tPolyBounds;
                else
                  tBounds.extend(tPolyBounds);
              }
            }
          });
        }
        if (tBounds && tBounds.isValid()) {
          this._fitBoundsInProgress = true;
          this.getPath('mapLayer.map').fitBounds(tBounds, {padding: this.kPadding, animate: true});
          this.get('mapLayer')._setIdle();
        }
      },

      observeLegendView: function( iLegendView) {
        iLegendView.addObserver('dragData', this, this.legendDidAcceptDrop);
      },

      /**
       * We pass the notification along to our controller by setting dragData as though the drop
       * had been received by us.
       * @param iView
       * @param iKey
       */
      legendDidAcceptDrop: function(iView, iKey) {
        this.set('dragData', iView.get('dragData'));
      },

      viewDidResize: function () {
        arguments.callee.base.apply(this,arguments);
        this.adjustLayout(this.renderContext(this.get('tagName')));
      },

      /**
       Set the layout (view position) for our subviews.
       @returns {void}
       */
      adjustLayout: function (context, firstTime) {
        var tMapLayer = this.get('mapLayer'),
            tMapPointView = this.get('mapPointView'),
            tLegendHeight = 0;

        if (this._isRenderLayoutInProgress || !tMapPointView)
          return;
        this._isRenderLayoutInProgress = true;

        this.get('legendViews').forEach(function (iLegendView) {
          var tHeight = iLegendView.get('desiredExtent');
          iLegendView.set('layout', {bottom: tLegendHeight, height: tHeight});
          tLegendHeight += tHeight;
        }.bind(this));

        // adjust() method avoids triggering observers if layout parameter is already at correct value.
        tMapPointView.adjust('bottom', tLegendHeight);
        tMapLayer.adjust('bottom', tLegendHeight);

        this._isRenderLayoutInProgress = false;
        // The polygons in the map, if any, may now be exposed, so give it a nudge so that they will repaint.
        this.invokeLast( function() {
          this.getPath('mapLayer.map').invalidateSize({pan: false});
        }.bind(this));
      }.observes('model.legendAttributeChange'),

      /**
       * Private property to prevent recursive execution of renderLayout. Seems most important in Firefox.
       */
      _isRenderLayoutInProgress: false,

      /**
       * This is our chance to add the features to the area layer
       */
      createVisualization: function () {
        var tPolygonLayers = this.get('mapPolygonLayers');
        if (tPolygonLayers) {
          tPolygonLayers.forEach(function (iLayer) {
            iLayer.createVisualization();
          });
        }
      },

      /**
       Called when the value of a global value changes (e.g. when a slider is dragged).
       */
      globalValueDidChange: function () {
        var tPolygonLayers = this.get('mapPolygonLayers');
        if (tPolygonLayers) {
          tPolygonLayers.forEach(function (iLayer) {
            iLayer.refreshComputedLegendColors();
          });
        }
      },

      handleMapLayerDisplayChange: function () {
        var tMapPointView = this.get('mapPointView'),
            tLastEventType = this.getPath('mapLayer.lastEventType');
        if (tMapPointView) {
          if (tLastEventType === 'dragstart') {
            tMapPointView.set('isVisible', false);
          }
          else if (tLastEventType === 'moveend') {
            tMapPointView.doDraw();
            tMapPointView.set('isVisible', true);
          }
          tMapPointView.updateConnectingLines();
        }

        var tMap = this.getPath('mapLayer.map'),
            tCenter = tMap.getCenter(),
            tZoom = tMap.getZoom();

        // Record the current values, which will be applied in handleIdle()
        this._mapDisplayChangeInProgress = true;
        this._mapDisplayChange = {
          center: tCenter,
          zoom: tZoom
        };

        this.setPath('mapLayer.lastEventType', null);
      }.observes('mapLayer.displayChangeCount'),

      /**
       * Clicks have to be handled carefully because we don't want a click on the map background to deselect
       * everything if the click is the click that first selects the map component.
       * So didBecomeSelected sets a temporary flag that remains set for a brief time so we can use it to
       * decide whether we should deselect everything.
       */
      handleClick: function () {
        if (!this.justSelected)
          this.get('model').selectAll(false);
      }.observes('mapLayer.clickCount'),

      didBecomeSelected: function() {
        this.justSelected = true;
        this.invokeLater( function() {
          this.justSelected = false;
        }, 500);
      }.observes('parentView.parentView.isSelected'),

      handleIdle: function () {
        var tModel = this.get('model'),
            oldCenter = tModel.get('center'),
            oldZoom = tModel.get('zoom');

        if (this._ignoreMapDisplayChanges) {
          this._ignoreMapDisplayChanges = false;
          this._mapDisplayChange = null;
          this._mapDisplayChangeInProgress = false;
          return;
        }

        if (this._mapDisplayChange) {
          var newCenter = this._mapDisplayChange.center,
              newZoom = this._mapDisplayChange.zoom,
              centerChanged = !newCenter.equals(oldCenter),
              zoomChanged = newZoom !== oldZoom;

          if (this._mapDisplayChangeInProgress && (centerChanged || zoomChanged)) {
            var change = 'change';
            if (this._fitBoundsInProgress || (centerChanged && zoomChanged)) {
              change = 'fitBounds';
              this._fitBoundsInProgress = false;
            } else if (centerChanged) {
              change = 'pan';
            } else {
              change = 'zoom';
            }
            DG.UndoHistory.execute(DG.Command.create({
              name: "map." + change,
              undoString: 'DG.Undo.map.' + change,
              redoString: 'DG.Redo.map.' + change,
              causedChange: this.getPath('mapLayer.lastEventType') !== 'moveend',
              log: 'mapEvent: %@ at {center: %@, zoom: %@}'.fmt(change, newCenter, newZoom),
              _componentId: this.getPath('controller.model.id'),
              _controller: function () {
                return DG.currDocumentController().componentControllersMap[this._componentId];
              },
              executeNotification: {
                action: 'notify',
                resource: 'component',
                values: {
                  operation: 'change map coordinates',
                  type: 'DG.MapView'
                }
              },
              execute: function () {
                var view = this._controller().getPath('view.contentView');
                view.setPath('model.center', newCenter);
                view.setPath('model.zoom', newZoom);
              },
              undo: function () {
                // Tell the map to change, but also ignore any events until those changes are done...
                var controller = this._controller(),
                    view = controller.getPath('view.contentView'),
                    map = view.getPath('mapLayer.map');
                view._ignoreMapDisplayChanges = true;
                map.setView(oldCenter, oldZoom);
                view.setPath('model.center', oldCenter);
                view.setPath('model.zoom', oldZoom);
              },
              redo: function () {
                // Tell the map to change, but also ignore any events until those changes are done...
                var controller = this._controller(),
                    view = controller.getPath('view.contentView'),
                    map = view.getPath('mapLayer.map');
                view._ignoreMapDisplayChanges = true;
                map.setView(newCenter, newZoom);
                view.setPath('model.center', newCenter);
                view.setPath('model.zoom', newZoom);
              }
            }));
          }
          this._mapDisplayChangeInProgress = false;
        }
      }.observes('mapLayer.idleCount'),

      /**
       * Override the two mixin methods because the drop target view is mapPointView
       */
      dragStarted: function () {
        if(this.get('dataConfiguration')) {
          DG.GraphDropTarget.dragStarted.apply(this, arguments);
          if (!this.getPath('model.hasLatLongAttributes'))
            this.setPath('mapPointView.isVisible', true);
        }
      },

      dragEntered: function() {
        if(this.get('dataConfiguration')) {
          DG.GraphDropTarget.dragEntered.apply(this, arguments);
        }
      },

      dragExited: function() {
        if(this.get('dataConfiguration')) {
          DG.GraphDropTarget.dragExited.apply(this, arguments);
        }
      },

      dragEnded: function () {
        if(this.get('dataConfiguration')) {
          DG.GraphDropTarget.dragEnded.apply(this, arguments);
        }
      },

      /**

       */
      selectionDidChange: function () {
        var tAdorn = this.get('connectingLineAdorn');
        if (tAdorn) {
          tAdorn.updateSelection();
        }
      }.observes('selection'),

      /**
       * We've animated to our initial position and along the way lost our bounds.
       */
      didReachInitialPosition: function () {
        this.fitBounds();
      }

    }
);

/* >>>>>>>>>> BEGIN source/components/map/points/map_connecting_line_adornment.js */
// ==========================================================================
//                          DG.MapConnectingLineAdornment
//
//  Author:   William Finzer
//
//  Copyright (c) 2015 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph/adornments/connecting_line_adornment');

/**
 * @class  Extension of ConnectingLineAdornment that can draw on maps
 * @extends DG.ConnectingLineAdornment
 */
DG.MapConnectingLineAdornment = DG.ConnectingLineAdornment.extend(
    /** @scope DG.MapConnectingLineAdornment.prototype */
    {

      /**
       * @property {DG.MapView}
       */
      mapSource: null,
      map: function () {
        return this.getPath('mapSource.mapLayer.map');
      }.property(),
      mapDidChange: function() {
        this.propertyDidChange('map');
      }.observes('mapSource.mapLayer.map'),

      init: function () {
        arguments.callee.base.apply(this,arguments);
        if (this.getPath('model.isVisible')) {
          this.updateToModel();
        }
      },

      /**
       * Create or update our lines, one for each parent present.
       * @param iAnimate {Boolean} [optional] if true then animate to new symbol location.
       */
      updateLine: function (iAnimate) {
        var tMap;

        var getCoords = function (iX, iY) {
          if (!tMap)
            tMap = this.get('map');
          return tMap.latLngToContainerPoint([iY, iX]);
        }.bind(this);

        this.doUpdateLine(iAnimate, getCoords);
      }

    });



/* >>>>>>>>>> BEGIN source/components/map/points/map_point_data_configuration.js */
// ==========================================================================
//                      DG.MapPointDataConfiguration
//
//  Author:   William Finzer
//
//  Copyright ©2018 Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
/* global L */
sc_require('components/map/map_data_configuration');

/** @class  DG.MapPointDataConfiguration - The object that describes the manner in which latitude and
 *  longitude attributes are assigned to places in a map.

 @extends DG.MapDataConfiguration
 */
DG.MapPointDataConfiguration = DG.MapDataConfiguration.extend(
    /** @scope DG.MapPointDataConfiguration.prototype */
    {
      /**
       * It is in initialization that we specialize from base class
       */
      init: function () {

        var attributeDescriptions = {
              caption: DG.AttributePlacementDescription.create(),
              x: DG.AttributePlacementDescription.create(),
              y: DG.AttributePlacementDescription.create(),
              legend: DG.AttributePlacementDescription.create(),
            },
            tPlace,
            tCaptionName,
            tCaptionAttr, tLatAttr, tLongAttr;

        arguments.callee.base.apply(this,arguments);

        var configureAttributeDescriptions = function () {

          var configAttrDesc = function (iAttrPrefix, iAttr, iCollectionClient) {
            var attrDesc = attributeDescriptions[iAttrPrefix],
                tType;

            DG.assert(attrDesc);

            // Configure the attribute description for the specified default attribute
            if (iAttr) {
              // Must set collection before attribute for attribute stats to be configured properly
              attrDesc.set('collectionClient', iCollectionClient);
              attrDesc.set('attribute', iAttr);
              switch (iAttrPrefix) {
                case 'x':
                case 'y':
                  tType = DG.Analysis.EAttributeType.eNumeric;
                  break;
                case 'caption':
                  tType = DG.Analysis.EAttributeType.eCategorical;
                  break;
              }
              if (tType)
                attrDesc.setPath('attributeStats.attributeType', tType);
            }
            // Null out the attribute description when no map attribute is specified.
            else {
              attrDesc.set('collectionClient', null);
              attrDesc.removeAllAttributes();
            }

            // We must set these up manually, because the infrastructure isn't in place by
            // the time arguments.callee.base.apply(this,arguments) (i.e. SC.Object.init()) is called.
            attrDesc.addObserver('collectionClient', this, iAttrPrefix + 'CollectionDidChange');
            attrDesc.addObserver('collection', this, 'collectionDidChange');
          }.bind(this);

          // When called we are given an initializer with info we need to be valid
          var tMapContext = this.initializer.context,
              tMapCollection = this.initializer.collection,
              tMapCollectionClient = tMapContext && tMapContext.getCollectionByID(tMapCollection.get('id'));
          if (tMapCollection && tMapCollectionClient) {
            tCaptionName = tMapCollection.getAttributeNames()[0];
            tCaptionAttr = tCaptionName && tMapCollection.getAttributeByName(tCaptionName);
            tLatAttr = this.initializer.latName && tMapCollection.getAttributeByName(this.initializer.latName);
            tLongAttr = this.initializer.longName && tMapCollection.getAttributeByName(this.initializer.longName);

            configAttrDesc('caption', tCaptionAttr, tMapCollectionClient);
            configAttrDesc('x', tLongAttr, tMapCollectionClient);
            configAttrDesc('y', tLatAttr, tMapCollectionClient);
            configAttrDesc('legend', null, tMapCollectionClient);
          }
        }.bind(this);

        // -- main routine of init
        configureAttributeDescriptions();

        // Prepare the attributes array. It has as many elements as there are places,
        //  and, initially, those elements are empty arrays.
        this.attributesByPlace = [];
        for (tPlace = 0; tPlace < DG.GraphTypes.EPlace.eNumPlaces; tPlace++)
          this.attributesByPlace[tPlace] = [];

        // Actually, during this coding transition, we're going to stash the previously
        // initialized attribute descriptions in attributesByPlace.
        this.attributesByPlace[DG.GraphTypes.EPlace.eCaption][0] = attributeDescriptions.caption;
        this.attributesByPlace[DG.GraphTypes.EPlace.eX][0] = attributeDescriptions.x;
        this.attributesByPlace[DG.GraphTypes.EPlace.eY][0] = attributeDescriptions.y;
        this.attributesByPlace[DG.GraphTypes.EPlace.eLegend][0] = attributeDescriptions.legend;

        this.set('dataContext', this.initializer.context);

        delete this.initializer;  // We don't need it any more
      },

      /**
       * Override because we only exist if there is an x (long) attribute description
       */
      collectionClient: function () {
        return this.getPath('xAttributeDescription.collectionClient');
      }.property(),

      /**
       * @property {SC.Array of DG.Case} All cases, both hidden and visible
       */
      allCases: function () {
        var tSource = this.get('collectionClient');
        return tSource ? tSource.getPath('casesController.arrangedObjects') : null;
      }.property(),

      longAttributeDescription: function() {
        return this.get('xAttributeDescription');
      }.property('xAttributeDescription'),

      latAttributeDescription: function() {
        return this.get('yAttributeDescription');
      }.property('yAttributeDescription'),

      latAttributeID: function () {
        return this.getPath('yAttributeDescription.attributeID');
      }.property(),
      latAttributeIDDidChange: function () {
        this.notifyPropertyChange('latAttributeID');
      }.observes('*yAttributeDescription.attributeID'),

      longAttributeID: function () {
        return this.getPath('xAttributeDescription.attributeID');
      }.property(),
      longAttributeIDDidChange: function () {
        this.notifyPropertyChange('longAttributeID');
      }.observes('*xAttributeDescription.attributeID'),

      // These two bindings help us with API for connecting line model
      xVarIDBinding: '.longAttributeID',
      yVarIDBinding: '.latAttributeID',

      hasLatLongAttributes: function () {
        return !SC.none(this.get('latAttributeID')) && !SC.none(this.get('longAttributeID'));
      }.property('latAttributeID', 'longAttributeID'),

      /**
       @property { DG.AttributePlacementDescription }
       */
      captionAttributeDescription: function (iKey, iValue) {
        return this.attributeDescriptionForPlace(iKey, iValue, DG.GraphTypes.EPlace.eCaption);
      }.property(),

      captionCollectionDidChange: function () {
        this.notifyPropertyChange('captionCollectionClient');
      },

      captionCollectionClient: function () {
        return this.getPath('captionAttributeDescription.collectionClient');
      }.property(),
      captionCollectionClientDidChange: function () {
        this.notifyPropertyChange('captionCollectionClient');
      }.observes('*captionAttributeDescription.collectionClient'),

      captionAttributeID: function () {
        return this.getPath('captionAttributeDescription.attributeID');
      }.property(),
      captionAttributeIDDidChange: function () {
        this.notifyPropertyChange('captionAttributeID');
      }.observes('*captionAttributeDescription.attributeID'),

      getLatLongBounds: function () {

        var getRationalLongitudeBounds = function () {
              var tLongID = this.getPath('xAttributeDescription.attribute.id'),
                  tLongs = [];
              this.get('cases').forEach(function (iCase) {
                var tLong = iCase.getNumValue(tLongID);
                if (isFinite(tLong) && tLong >= -360 && tLong <= 360)
                  tLongs.push(tLong);
              });
              tLongs.sort(function (iV1, iV2) {
                return iV1 - iV2;
              });
              var tLength = tLongs.length,
                  tMin = tLongs[0],
                  tMax = tLongs[tLength - 1],
                  tMedian;
              while (tMax - tMin > 180) {
                tMin = Math.min(tMin, tLongs[0]);
                tMax = Math.max(tMax, tLongs[tLength - 1]);
                tMedian = tLongs[Math.floor(tLength / 2)];
                if (tMax - tMedian > tMedian - tMin) {
                  tMax -= 360;
                  if (tMax < tLongs[tLength - 2]) {
                    tMin = Math.min(tMin, tMax);
                    tMax = tLongs[tLength - 2];
                    tLongs.pop();
                  }
                }
                else {
                  tMin += 360;
                  if (tMin > tLongs[1]) {
                    tMax = Math.max(tMax, tMin);
                    tMin = tLongs[1];
                    tLongs.shift();
                  }
                }
                tLength = tLongs.length;
                if (tMax < tMin) {
                  var tTemp = tMax;
                  tMax = tMin;
                  tMin = tTemp;
                }
              }
              return {min: tMin, max: tMax};
            }.bind(this),

            isValid = function (iMinMax) {
              return DG.isFinite(iMinMax.min) && DG.isFinite(iMinMax.max);
            };

        var tLatMinMax = this.getPath('yAttributeDescription.attributeStats.minMax'),
            tLngMinMax = this.getPath('xAttributeDescription.attributeStats.minMax');

        if (tLngMinMax.max - tLngMinMax.min > 180)
          tLngMinMax = getRationalLongitudeBounds();

        var tSouthWest = [tLatMinMax.min, tLngMinMax.min],
            tNorthEast = [tLatMinMax.max, tLngMinMax.max],
            tBounds = (isValid(tLatMinMax) && isValid(tLngMinMax)) ? L.latLngBounds([tSouthWest, tNorthEast]) : null;
        return tBounds;
      }

    });


/* >>>>>>>>>> BEGIN source/components/map/points/map_point_layer.js */
// ==========================================================================
//                        DG.MapPointLayer
//
//  Author:   William Finzer
//
//  Copyright ©2014 Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/graph_map_common/plot_layer');

/** @class DG.MapPointLayer - A plot of dots placed according to numeric values

 @extends DG.PlotLayer
 */
DG.MapPointLayer = DG.PlotLayer.extend(
    /** @scope DG.MapPointLayer.prototype */
    {
      autoDestroyProperties: [],

      /**
       * @property {DG.MapModel}
       */
      model: null,

      mapSource: null,

      dataConfiguration: null,

      map: function () {
        return this.getPath('mapSource.mapLayer.map');
      }.property(),

      isInMarqueeMode: false, // Set by parent during marquee select to allow us to suppress data tips

      /**
       * @property { DG.MapGridLayer }
       */
      gridLayer: null,

      /**
       * @property {DG.MapConnectingLineAdornment}
       */
      connectingLinesAdorn: null,

      init: function () {
        arguments.callee.base.apply(this,arguments);
        this.setPath('dataTip.showOnlyLegendData', true);
        this.addGridLayer();
        this.lineVisibilityChanged();
      },

      destroy: function() {
        var tPlottedElements = this.get('plottedElements');
        arguments.callee.base.apply(this,arguments);
        // Since our plotted elements are not going to be reused, we have to fully remove them.
        tPlottedElements.forEach(function (iElement) {
          iElement.hide();
        });
      },

      /**
       * Augment my base class by checking to make sure we have the attributes we need.
       * @returns {boolean}
       */
      readyToDraw: function () {
        return !SC.none(this.getPath('dataConfiguration.yAttributeDescription.attributeID')) &&
            !SC.none(this.getPath('dataConfiguration.xAttributeDescription.attributeID'));
      },

      /**
       * Computing this context once at beginning of display loop speeds things up
       * @return {*}
       */
      createRenderContext: function () {
        var tModel = this.get('model');
        if (!tModel)
          return; // not ready yet
        var tConfig = this.get('dataConfiguration'),
            tLegendDesc = tConfig.get('legendAttributeDescription'),
            tLegendVarID = tLegendDesc && tLegendDesc.get('attributeID'),
            tLegendAttrType = tLegendDesc.get('attributeType'),
            tStrokeParams = this.getStrokeParams(),
            tQuantileValues = (tLegendDesc && tLegendDesc.get('isNumeric')) ?
                tConfig.get('legendQuantiles') : [];
        return {
          // render needs (set all to true for now, maybe later we can optimize by not doing all of them?)
          casesAdded: true,
          casesRemoved: true,
          updatedColors: true,

          layer: this.getPath('layerManager.' + DG.LayerNames.kPoints),
          map: this.get('map'),
          westBound: this.get('map').getBounds().getWest(),
          eastBound: this.get('map').getBounds().getEast(),
          latVarID: tModel.getPath('dataConfiguration.latAttributeID'),
          longVarID: tModel.getPath('dataConfiguration.longAttributeID'),
          legendDesc: tLegendDesc,
          legendVarID: tLegendVarID,
          legendVarType: tLegendAttrType,
          updatedPositions: true,
          pointsShouldBeVisible: this.getPath('model.pointsShouldBeVisible'),
          isVisible: this.getPath( 'model.isVisible') && this.getPath('model.pointsShouldBeVisible'),

          pointColor: tModel.get('pointColor') || DG.PlotUtilities.kDefaultPointColor,
          transparency: tModel.get('transparency') || DG.PlotUtilities.kDefaultPointOpacity,
          strokeTransparency: tStrokeParams.strokeSameAsFill ?
              (tModel.get('transparency') || DG.PlotUtilities.kDefaultPointOpacity) :
              tStrokeParams.strokeTransparency,

          calcCaseColorString: function (iCase) {
            if (!this.legendVarID)
              return this.pointColor;

            DG.assert(iCase);
            var tColorValue = (this.legendVarType === DG.Analysis.EAttributeType.eDateTime) ?
                             iCase.getForcedNumericValue(this.legendVarID) : iCase.getValue(this.legendVarID),
                tCaseColor = DG.ColorUtilities.calcCaseColor(tColorValue, this.legendDesc,
                    this.pointColor, tQuantileValues);
            return tCaseColor.colorString || tCaseColor;
          },

          calcStrokeColorString: function (iCase) {
            if( tStrokeParams.strokeSameAsFill)
              return this.calcCaseColorString( iCase);
            else return tStrokeParams.strokeColor;
          }
        };
      },

      /**
       Observation function called when data values change.
       Method name is legacy artifact of SproutCore range observer implementation.
       */
      dataRangeDidChange: function (iSource, iQuestion, iKey, iChanges) {
        if (!this.readyToDraw())
          return;

        var this_ = this,
            tPlotElementLength = this.get('plottedElements').length,
            tCases = this.getPath('model.cases'),
            tRC = this.createRenderContext(),
            // iChanges can be a single index or an array of indices
            tChanges = (SC.typeOf(iChanges) === SC.T_NUMBER ? [iChanges] : iChanges);
        tChanges = tChanges || [];
        tChanges.forEach(function (iIndex) {
          if (iIndex >= tPlotElementLength)
            this_.callCreateElement(tCases.at(iIndex), iIndex, this_._createAnimationOn);
          this_.setCircleCoordinate(tRC, tCases.at(iIndex), iIndex);
        });

        arguments.callee.base.apply(this,arguments);
      },

      /**
       * Override base class because we don't want to set this flag if we don't have
       * both lat and long attributes.
       */
      caseOrderDidChange: function () {
        if (!SC.none(this.getPath('model.dataConfiguration.latAttributeID') &&
            !SC.none(this.getPath('model.dataConfiguration.longVarID'))))
          this._mustMoveElementsToNewCoordinates = true;
      },

      /**
       * Set the coordinates and other attributes of the case circle (a Raphael element in this.get('plottedElements')).
       * Todo: Reinstate animation if possible
       * @param iRC {} case-invariant Render Context
       * @param iCase {DG.Case} the case data
       * @param iIndex {number} index of case in collection
       * @param iAnimate {Boolean} (optional) want changes to be animated into place?
       */
      setCircleCoordinate: function (iRC, iCase, iIndex, iAnimate, iCallback) {
        DG.assert(iRC && iRC.map && iRC.latVarID && iRC.longVarID);
        DG.assert(iCase);
        DG.assert(DG.MathUtilities.isInIntegerRange(iIndex, 0, this.get('plottedElements').length));
        var tCircle = this.get('plottedElements')[iIndex],
            tLat = iCase.getNumValue(iRC.latVarID),
            tLong = iCase.getNumValue(iRC.longVarID);
        if (tLong < iRC.westBound) {
          tLong += Math.ceil((iRC.westBound - tLong) / 360) * 360;
        }
        else if (tLong > iRC.eastBound) {
          tLong -= Math.ceil((tLong - iRC.eastBound) / 360) * 360;
        }

        var tValid = !(Number.isNaN(tLat) || Number.isNaN(tLong)),
            tCoords = tValid ? iRC.map.latLngToContainerPoint([tLat, tLong]) : null,
            tCoordX = tCoords && tCoords.x,
            tCoordY = tCoords && tCoords.y,
            tIsMissingCase = !DG.isFinite(tCoordX) || !DG.isFinite(tCoordY);

        // show or hide if needed, then update
        if (!tIsMissingCase) {
          var tAttrs = {
            cx: tCoordX, cy: tCoordY, r: this.radiusForCircleElement(tCircle),
            fill: iRC.calcCaseColorString(iCase),
            stroke: iRC.calcStrokeColorString( iCase), 'fill-opacity': iRC.transparency, 'stroke-opacity': iRC.strokeTransparency
          };
          this.updatePlottedElement(tCircle, tAttrs, iAnimate, iCallback);
          if( iRC.isVisible) {
            this.assignElementAttributes( tCircle, iIndex, false, true);
            iRC.layer.push( tCircle);
            tCircle.show();
            tCircle.attr({opacity: 1});
          }
          else {
            tCircle.hide( );
          }
        }
        tCircle['case'] = iCase;  // Because sorting the cases messes up any correspondence between index and case
      },

      assignElementAttributes: function (iElement, iIndex, iAnimate, iIsVisible) {
        /*
            function changeCaseValues( iDeltaValues) {
              var tXVarID = this_.getPath('model.xVarID'),
                  tYVarID = this_.getPath('model.yVarID'),
                  tChange = {
                    operation: 'updateCases',
                    cases: [],
                    attributeIDs: [ tXVarID, tYVarID],
                    values: [ [], [] ]
                  },
                  tDataContext = this_.get('dataContext');
              if( !tDataContext) return;
              // Note that we have to get the cases dynamically rather than have a variable
              // declared in the closure. The array pointed to by such a closure is not updated!
              this_.getPath('model.casesController.selection').forEach( function( iCase) {
                tChange.cases.push( iCase);
                tChange.values[0].push( iCase.getNumValue( tXVarID) + iDeltaValues.x);
                tChange.values[1].push( iCase.getNumValue( tYVarID) + iDeltaValues.y);
              });
              tDataContext.applyChange( tChange);
            }
        */

        /*
            function returnCaseValuesToStart( iCaseIndex, iStartWorldCoords) {
              var tCase = this_.getPath('model.cases')[ iCaseIndex],
                  tXVarID = this_.getPath('model.xVarID'),
                  tYVarID = this_.getPath('model.yVarID'),
                  tDeltaX = tCase.getNumValue( tXVarID) - iStartWorldCoords.x,
                  tDeltaY = tCase.getNumValue( tYVarID) - iStartWorldCoords.y;
              this_.get('model').animateSelectionBackToStart([ tXVarID, tYVarID], [ tDeltaX, tDeltaY]);
            }
        */

        function completeHoverAnimation() {
          this.hoverAnimation = null;
        }

        var this_ = this,
            tIsDragging = false,
            kOpaque = 1,
            tInitialTransform = null;
        iElement.addClass(DG.PlotUtilities.kColoredDotClassName)
            .attr({cursor: 'pointer'})
            .hover(function (event) {  // over
                  if (!tIsDragging && SC.none(tInitialTransform) && !this_.get('isInMarqueeMode')) {
                    tInitialTransform = '';
                    if (this.hoverAnimation)
                      this.stop(this.hoverAnimation);
                    this.hoverAnimation = Raphael.animation({
                          opacity: kOpaque,
                          transform: DG.PlotUtilities.kDataHoverTransform
                        },
                        DG.PlotUtilities.kDataTipShowTime,
                        '<>', completeHoverAnimation);
                    this.animate(this.hoverAnimation);
                    this_.showDataTip(this, iIndex);
                  }
                },
                function (event) { // out
                  if (!tIsDragging) {
                    if (this.hoverAnimation)
                      this.stop(this.hoverAnimation);
                    this.hoverAnimation = Raphael.animation({transform: tInitialTransform},
                        DG.PlotUtilities.kHighlightHideTime,
                        '<>', completeHoverAnimation);
                    this.animate(this.hoverAnimation);
                    tInitialTransform = null;
                    this_.hideDataTip();
                  }
                })
            .mousedown(function (iEvent) {
              SC.run(function () {
                this_.get('model').selectCase(this['case'], iEvent.shiftKey || iEvent.metaKey);
              }.bind(this));
            })
//        .drag(function (dx, dy) { // continue
//                SC.run( function() {
//                  var tNewX = this_.get('xAxisView').coordinateToData( this.ox + dx),
//                      tNewY = this_.get('yAxisView').coordinateToData( this.oy + dy),
//                      tCase = this_.getPath('model.cases')[ this.index],
//                      tOldX = tCase.getNumValue( this_.getPath('model.xVarID')),
//                      tOldY = tCase.getNumValue( this_.getPath('model.yVarID')),
//                      tCurrTransform = this.transform();
//                  // Note that we ignore invalid values. Matt managed to convert some dragged values
//                  // to NaNs during testing, which then couldn't animate back to their original
//                  // positions. This should have the effect of leaving points that would otherwise
//                  // have become NaNs in their last-known-good positions.
//                  if( isFinite( tNewX) && isFinite( tNewY)) {
//                    // Put the element into the initial transformed state so that changing case values
//                    // will not be affected by the scaling in the current transform.
//                    this.transform( tInitialTransform);
//                    changeCaseValues( { x: tNewX - tOldX, y: tNewY - tOldY });
//                    this.transform( tCurrTransform);
//                  }
//                }, this);
//            },
//            function (x, y) { // begin
//              var tCase = this_.getPath('model.cases')[ this.index];
//              tIsDragging = true;
//              // Save the initial screen coordinates
//              this.ox = this.attr("cx");
//              this.oy = this.attr("cy");
//              // Save the initial world coordinates
//              this.wx = tCase.getNumValue( this_.getPath('model.xVarID'));
//              this.wy = tCase.getNumValue( this_.getPath('model.yVarID'));
//              this.animate({opacity: kOpaque }, DG.PlotUtilities.kDataTipShowTime, "bounce");
//            },
//            function() {  // end
//              this.animate( {transform: tInitialTransform }, DG.PlotUtilities.kHighlightHideTime);
//              tInitialTransform = null;
//              returnCaseValuesToStart( this.index, { x: this.wx, y: this.wy });
//              tIsDragging = false;
//              this.ox = this.oy = this.wx = this.wy = undefined;
//              this_.hideDataTip();
//            })
        ;
        iElement.index = iIndex;
        if (iAnimate && iIsVisible)
          DG.PlotUtilities.doCreateCircleAnimation(iElement);
        else if( !iIsVisible) {
          iElement.attr( {opacity: 0 });
          iElement.hide();
        }
        return iElement;
      },

      createElement: function (iCase, iIndex, iAnimate) {
        var tCircle = this.get('paper').circle(-100, -100, this._pointRadius);
        tCircle['case'] = iCase;
        tCircle.node.setAttribute('shape-rendering', 'geometricPrecision');
        return tCircle;
      },

      /**
       Generate the svg needed to display the plot
       */
      doDraw: function () {
        if (this.readyToDraw()) {
          this.drawData();
          this.updateSelection();
          this.updateConnectingLine();
        }
      }.observes('plotDisplayDidChange', 'model.pointColor', 'model.strokeColor', 'model.pointSizeMultiplier',
          'model.transparency', 'model.strokeTransparency', 'model.pointsShouldBeVisible', 'model.strokeSameAsFill',
          'model.colorMap', 'model.selection', 'model.dataConfiguration.legendQuantilesAreLocked'),

      updateSelection: function () {
        if (SC.none(this.get('map')))
          return;
        arguments.callee.base.apply(this,arguments);
      },

      /**
       * Defer to dataConfiguration.
       * @return { L.LatLngBounds | null }
       */
      getBounds: function() {
          return this.get('dataConfiguration').getLatLongBounds();
      },

      /**
       * When the model changes visibility, we show or hide everything.
       * But, if we're showing, we respect the isVisible flag of grid and lines and points.
       */
      isVisibleChanged: function() {
        var tIsVisible = this.getPath('model.isVisible'),
            tGrid = this.get('gridLayer'),
            tLines = this.get('connectingLinesAdorn');
        if( tIsVisible) {
          tGrid && tGrid.show();
          tLines && tLines.show();
        }
        else {
          tGrid && tGrid.hide();
          tLines && tLines.hide();
        }
      }.observes('model.isVisible'),

      updateConnectingLine: function() {
        var tConnectingLinesAdorn = this.get('connectingLinesAdorn');
        if( tConnectingLinesAdorn) {
          tConnectingLinesAdorn.invalidateModel();
          tConnectingLinesAdorn.updateToModel( false /* do not animate */);
        }
      },

      /**
       * Something about the points (aside from visibility or case order) changed. Take appropriate action.
       */
      pointsDidChange: function() {
        if( this.getPath( 'model.isVisible')) {
          var tGridModel = this.getPath('gridLayer.model');
          if (tGridModel)
            tGridModel.rectArrayMustChange();
          this.updateConnectingLine();
        }
      }.observes('pointsDidChange', 'model.dataConfiguration.hiddenCases', 'model.lastChange'),

      /**
       * Case order has changed. Sort the plottedElements to the new order
       */
      casesDidReorder: function() {
        if( this.getPath( 'model.isVisible')) {
          var tCases = this.getPath('model.cases'),
              tMapCaseIdToIndex = {},
              tPlottedElements = this.get('plottedElements');
          tCases.forEach( function( iCase, iIndex) {
            tMapCaseIdToIndex[iCase.get('id')] = iIndex;
          });
          tPlottedElements.sort( function( iEl1, iEl2) {
            return tMapCaseIdToIndex[iEl1['case'].get('id')] - tMapCaseIdToIndex[iEl2['case'].get('id')];
          });
          this.updateConnectingLine();
        }
      }.observes('model.casesDidReorder'),

      addGridLayer: function () {
        if( this.get('gridLayer'))
          return;

        var tGridModel = this.getPath('model.gridModel');
        tGridModel.initializeRectArray();

        this.set('gridLayer', DG.MapGridLayer.create(
            {
              mapSource: this.get('mapSource'),
              model: tGridModel,
              showTips: true /* !this.getPath('model.pointsShouldBeVisible') */
            }));
      },

      /**
       Our model has created a connecting line. We need to create our adornment. We don't call adornmentDidChange
       because we don't want to destroy the adornment.
       */
      lineVisibilityChanged: function() {
        var tLineModel = this.getPath( 'model.connectingLinesModel' ),
            tLinesAreVisible = tLineModel.get('isVisible'),
            tLineAdorn = this.get('connectingLinesAdorn');
        if( tLineModel && tLinesAreVisible && !tLineAdorn) {
          tLineAdorn = DG.MapConnectingLineAdornment.create({ model: tLineModel, paperSource: this,
            mapSource: this.get('mapSource'), layerName: DG.LayerNames.kConnectingLines,
            unselectedLineWidth: 1, selectedLineWidth: 3, parentView: this.get('mapSource') });
          this.set('connectingLinesAdorn', tLineAdorn);
        }

        this.invokeLast( function() {
          if( tLineAdorn) {
            tLineAdorn.updateVisibility();
            // this.updateMarqueeToolVisibility();
          }
        }.bind( this));
      }.observes('.model.connectingLinesModel.isVisible'),

    });


/* >>>>>>>>>> BEGIN source/components/map/points/map_point_layer_model.js */
// ==========================================================================
//                            DG.MapModel
//
//  Author:   William Finzer
//
//  Copyright ©2014 Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/map/map_layer_model');

/** @class  DG.MapPointLayerModel - The model for a points displayed on a map.

 @extends DG.MapLayerModel
 */
DG.MapPointLayerModel = DG.MapLayerModel.extend(
    /** @scope DG.MapPointLayerModel.prototype */
    {
      /**
       * Reflects (and determines) whether the points show
       * {@property Boolean}
       */
      pointsShouldBeVisible: true,

      caseValueAnimator: null,  // Used to animate points back to start

      latVarID: function () {
        return this.getPath('dataConfiguration.latAttributeID');
      }.property(),
      latVarIDDidChange: function () {
        this.notifyPropertyChange('latVarID');
      }.observes('*dataConfiguration.latAttributeID'),

      longVarID: function () {
        return this.getPath('dataConfiguration.longAttributeID');
      }.property(),
      longVarIDDidChange: function () {
        this.notifyPropertyChange('longVarID');
      }.observes('*dataConfiguration.longAttributeID'),

      xVarID: function () {
        return this.get('longVarID');
      }.property('longVarID'),

      yVarID: function () {
        return this.get('latVarID');
      }.property('latVarID'),

      /**
       * @property {DG.MapGridModel }
       */
      gridModel: null,

      /**
       * @property {DG.connectingLinesModel }
       */
      connectingLinesModel: null,

      init: function () {
        arguments.callee.base.apply(this,arguments);

        this.gridModel = DG.MapGridModel.create({
          dataConfiguration: this.get('dataConfiguration')
        });

        this.connectingLinesModel = DG.ConnectingLineModel.create({
          plotModel: this,
          isVisible: false
        });
      },

      handleOneDataContextChange: function (iNotifier, iChange) {
        arguments.callee.base.apply(this,arguments);

        var tGridModel = this.get('gridModel');
        if (tGridModel)
          tGridModel.handleDataContextChange(iChange);

        if( iChange.operation === 'moveCases')
          this.notifyPropertyChange('casesDidReorder');
      },

      /**
       * Override superclass
       * @returns {boolean}
       */
      wantsInspector: function () {
        return true;
      },

      hasLatLongAttributes: true,

      /**
       * We can rescale if we have some data to rescale to.
       */
      canRescale: true,

      /**
       * @override
       * @return {boolean}
       */
      hasValidMapAttributes: function() {
        var tDataConfiguration = this.get('dataConfiguration'),
            kAttrPrefixes = ['Lat', 'Long'];
        return kAttrPrefixes.every( function( iPrefix) {
          var tLowerCasePrefix = iPrefix.toLowerCase(),
              tAttrName = tDataConfiguration.getPath( tLowerCasePrefix + 'AttributeDescription.attribute.name'),
              tCandidates = DG.MapConstants['k' + iPrefix + 'Names'];
          return tCandidates.indexOf( tAttrName.toLowerCase()) >= 0;
        });
      },

      animateSelectionBackToStart: function (iAttrIDs, iDeltas) {
        if (SC.none(this.caseValueAnimator))
          this.caseValueAnimator = DG.CaseValueAnimator.create();
        else  // We must end the animation before setting animator properties
          this.caseValueAnimator.endAnimation();

        this.caseValueAnimator.set('dataContext', this.get('dataContext'));
        this.caseValueAnimator.set('cases', DG.copy(this.get('selection')));
        this.caseValueAnimator.set('attributeIDs', iAttrIDs);
        this.caseValueAnimator.set('deltas', iDeltas);

        this.caseValueAnimator.animate();
      },

      checkboxDescriptions: function () {
        var this_ = this,
            tItems = [];
        if (this.getPath('dataConfiguration.hasLatLongAttributes')) {
          tItems = tItems.concat([
            {
              title: 'DG.Inspector.mapGrid',
              value: this_.getPath('gridModel.isVisible'),
              classNames: 'dg-map-grid-check'.w(),
              valueDidChange: function () {
                this_.toggleGrid();
              }.observes('value')
            },
            {
              title: 'DG.Inspector.mapPoints',
              value: this_.get('pointsShouldBeVisible'),
              classNames: 'dg-map-points-check'.w(),
              valueDidChange: function () {
                this_.togglePoints();
              }.observes('value')
            },
            {
              title: 'DG.Inspector.mapLines',
              value: this_.getPath('connectingLinesModel.isVisible'),
              classNames: 'dg-map-lines-check'.w(),
              valueDidChange: function () {
                this_.toggleLines();
              }.observes('value')
            }
          ]);
        }
        return tItems;
      }.property(),

      togglePoints: function () {
        var tMapLayerModel = this;
        DG.UndoHistory.execute(DG.Command.create({
          name: "map.togglePoints",
          _firstTime: true,
          execute: function () {
            var tPointsVisible = tMapLayerModel.get('pointsShouldBeVisible');
            if (tPointsVisible !== false)
              tPointsVisible = true;

            tMapLayerModel.set('pointsShouldBeVisible', !tPointsVisible);

            this.log = 'mapAction: {mapAction: %@}'.fmt(tMapLayerModel.get('pointsShouldBeVisible') ? 'showPoints' : 'hidePoints');
            if (this._firstTime) {
              this._firstTime = false;
              this.set('name', !tPointsVisible ? 'map.showPoints' : 'map.hidePoints');
              this.set('undoString', !tPointsVisible ? 'DG.Undo.map.showPoints' : 'DG.Undo.map.hidePoints');
              this.set('redoString', !tPointsVisible ? 'DG.Redo.map.showPoints' : 'DG.Redo.map.hidePoints');
            }
          },
          undo: function () {
            this.execute();
          }
        }));
      },

      toggleGrid: function () {
        var tMapLayerModel = this;
        DG.UndoHistory.execute(DG.Command.create({
          name: "map.toggleGrid",
          _firstTime: true,
          execute: function () {
            var tGridIsVisible = tMapLayerModel.getPath('gridModel.isVisible');
            // if (tGridIsVisible !== true)
            //   tGridIsVisible = false;

            tMapLayerModel.setPath('gridModel.isVisible', !tGridIsVisible);

            this.log = 'mapAction: {mapAction: %@}'.fmt(tMapLayerModel.getPath('gridModel.isVisible') ? 'showGrid' :
                'hideGrid');
            if (this._firstTime) {
              this._firstTime = false;
              this.set('name', !tGridIsVisible ? 'map.showGrid' : 'map.hideGrid');
              this.set('undoString', !tGridIsVisible ? 'DG.Undo.map.showGrid' : 'DG.Undo.map.hideGrid');
              this.set('redoString', !tGridIsVisible ? 'DG.Redo.map.showGrid' : 'DG.Redo.map.hideGrid');
            }
          },
          undo: function () {
            this.execute();
          }
        }));
      },

      toggleLines: function () {
        var tMapLayerModel = this;
        DG.UndoHistory.execute(DG.Command.create({
          name: "map.toggleLines",
          _firstTime: true,
          execute: function () {
            var tLinesAreVisible = tMapLayerModel.getPath('connectingLinesModel.isVisible');
            if (tLinesAreVisible !== false)
              tLinesAreVisible = true;

            tMapLayerModel.setPath('connectingLinesModel.isVisible', !tLinesAreVisible);

            this.log = 'mapAction: {mapAction: %@}'.fmt(tMapLayerModel.getPath('connectingLinesModel.isVisible') ?
                'showLines' : 'hideLines');
            if (this._firstTime) {
              this._firstTime = false;
              this.set('name', !tLinesAreVisible ? 'map.showLines' : 'map.hideLines');
              this.set('undoString', !tLinesAreVisible ? 'DG.Undo.map.showLines' : 'DG.Undo.map.hideLines');
              this.set('redoString', !tLinesAreVisible ? 'DG.Redo.map.showLines' : 'DG.Redo.map.hideLines');
            }
          },
          undo: function () {
            this.execute();
          }
        }));
      },

      somethingIsSelectable: function () {
        return this.get('isVisible') && (this.get('pointsShouldBeVisible') || this.getPath('gridModel.isVisible') ||
            this.getPath('connectingLinesModel.isVisible'));
      }.property(),
      somethingIsSelectableDidChange: function() {
        this.notifyPropertyChange('somethingIsSelectable');
      }.observes('isVisible', 'pointsShouldBeVisible', 'gridModel.isVisible', 'connectingLinesModel.isVisible'),

      gridIsVisible: function() {
        return this.get('isVisible') && this.getPath('gridModel.isVisible');
      }.property(),
      gridIsVisibleDidChange: function() {
        this.notifyPropertyChange('gridIsVisible');
      }.observes( 'isVisible', 'pointsShouldBeVisible', 'gridModel.isVisible', 'connectingLinesModel.isVisible'),

      createStorage: function () {
        var tStorage = arguments.callee.base.apply(this,arguments),
            tDataConfiguration = this.get('dataConfiguration'),
            tPointsVisible = this.get('pointsShouldBeVisible'),
            tGridModel = this.get('gridModel'),
            tConnectingLinesModel = this.get('connectingLinesModel');
        tDataConfiguration.addToStorageForDimension(tStorage, 'legend');
        tStorage.pointColor = this.get('pointColor');
        tStorage.strokeColor = this.get('strokeColor');
        tStorage.pointSizeMultiplier = this.get('pointSizeMultiplier');
        tStorage.transparency = this.get('transparency');
        tStorage.strokeTransparency = this.get('strokeTransparency');
        tStorage.strokeSameAsFill = this.get('strokeSameAsFill');

        if (tPointsVisible !== null)
          tStorage.pointsShouldBeVisible = tPointsVisible;
        tStorage.linesShouldBeVisible = this.get('linesShouldBeVisible');
        if (tGridModel)
          tStorage.grid = tGridModel.createStorage();
        if (tConnectingLinesModel)
          tStorage.connectingLines = tConnectingLinesModel.createStorage();
        return tStorage;
      },

      restoreStorage: function (iStorage) {
        arguments.callee.base.apply(this,arguments);

        var tStorage = iStorage.mapModelStorage || iStorage,
            tGridModel = this.get('gridModel'),
            tConnectingLinesModel = this.get('connectingLinesModel');

        if (!SC.none(tStorage.pointsShouldBeVisible))
          this.set('pointsShouldBeVisible', tStorage.pointsShouldBeVisible);
        if (!SC.none(tStorage.linesShouldBeVisible))
          this.set('linesShouldBeVisible', tStorage.linesShouldBeVisible);

        if (tGridModel)
          tGridModel.restoreStorage(tStorage.grid);
        if (tConnectingLinesModel)
          tConnectingLinesModel.restoreStorage(tStorage.connectingLines);
      }
    });
/* >>>>>>>>>> BEGIN source/components/map/points/map_point_view.js */
// ==========================================================================
//                            DG.MapPointView
//
//  Author:   William Finzer
//
//  Copyright ©2014 Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('views/raphael_base');

/** @class  DG.MapPointView - Subview of MapView that manages map layers and point layers

  @extends DG.RaphaelBaseView
*/
DG.MapPointView = DG.RaphaelBaseView.extend(
/** @scope DG.MapPointView.prototype */
{
  autoDestroyProperties: [ ],

  displayProperties: ['model.dataConfiguration.attributeAssignment',
                      'model.dataConfiguration.legendAttributeDescription.attributeStats.attributeType',
                      'model.dataConfiguration.legendQuantilesAreLocked'],

  classNames: ['dg-map-layer'],
  // When we go into marquee-mode we add this class which makes us translucent and able receive mousedown events.
  classNameBindings: ['isInMarqueeMode:dg-marquee-mode'],

  /**
   * @property {DG.MapModel}
   */
  model: null,

  /**
   * @property {DG.MapPointLayer}
   */
  mapPointLayers: null,

  /**
   * @property {DG.BaseMapView}
   */
  mapLayer: null,

  /**
   * @property {Boolean}
   */
  isInMarqueeMode: false,

  marqueeContext: null,

  /**
   * We should be able to accomplish the following with binding, but it didn't work,
   * possibly because of the classNameBindings. So we use brute force.
   */
  marqueeModeDidChange: function() {
    this.get('mapPointLayers').forEach( function( iLayer) {
      iLayer.set('isInMarqueeMode', this.get('isInMarqueeMode'));
    }.bind( this));
  }.observes('isInMarqueeMode'),

  /**
   * Subclasses can override calling arguments.callee.base.apply(this,arguments) and then adding layers at will.
   */
  initLayerManager: function() {
    arguments.callee.base.apply(this,arguments);

    // if base class wasn't able to initialize the layer manager, e.g. because we
    // don't have paper yet, then this.get('layerManager') leads to an infinite loop.
    // For now, we avoid the infinite loop by testing the private _layerManager.
    if (!this._layerManager) return;

    var ln = DG.LayerNames;
    this.get('layerManager').addNamedLayer( ln.kBackground )
                  .addNamedLayer( ln.kConnectingLines )
                  .addNamedLayer( ln.kPoints )
                  .addNamedLayer( ln.kSelectedPoints )
                  .addNamedLayer( ln.kAdornments )
                  .addNamedLayer( ln.kDataTip );
  },

  /**
   * Go through each of the mapPointLayers and merge their separate LatLongBounds into one
   * @return {L.LatLngBounds | null}
   */
  getBounds: function() {
    var tBounds,
        tPointLayers = this.get('mapPointLayers');
    if( tPointLayers) {
      tPointLayers.forEach( function( iLayer) {
        if( iLayer.getPath('model.isVisible')) {
          var tPointBounds = iLayer.getBounds();
          if (!SC.none(tPointBounds)) {
            if (!tBounds)
              tBounds = tPointBounds;
            else
              tBounds.extend(tPointBounds);
          }
        }
      });
    }
    return tBounds;
  },

  /**
   * Handles a marquee mouse down.
   * @param {{clientX:number, clientY:number}} iEvent
   * @returns {boolean}
   */
  mouseDown: function( iEvent) {
    DG.ViewUtilities.componentViewForView( this).select();
    if (!this.get('isInMarqueeMode')) {
      return false;
    }
    this.marqueeContext = {};
    this.marqueeContext.startPt = DG.ViewUtilities.windowToViewCoordinates(
        { x: iEvent.clientX - 5, y: iEvent.clientY - 5 }, this);
    this.marqueeContext.marquee = this._paper.rect(
      this.marqueeContext.startPt.x, this.marqueeContext.startPt.y, 0, 0)
        .attr( { fill: DG.PlotUtilities.kMarqueeColor,
          stroke: DG.RenderingUtilities.kTransparent });
    this.getPath('layerManager.' + DG.LayerNames.kAdornments )
      .push( this.marqueeContext.marquee);
    DG.logUser('marqueeDrag: start');
    this.marqueeContext.lastRect = {x:0, y:0, width: 0, height: 0};
    this.get('mapPointLayers').forEach( function( iLayer) {
      iLayer.preparePointSelection();
      var tDataContext = iLayer.getPath('model.dataContext'),
          tCollection = iLayer.getPath('model.collectionClient');
      tDataContext.applyChange({
        operation: 'selectCases',
        collection: tCollection,
        cases: null,
        select: false
      });
    });
    return true;
  },

  mouseMoved: function( iEvent) {
    if( !this.get('marqueeContext'))
      return false;

    var tBaseSelection = [],
        tCurrPt = DG.ViewUtilities.windowToViewCoordinates(
                      { x: iEvent.clientX - 5, y: iEvent.clientY - 5 }, this),
        tX = Math.min( this.marqueeContext.startPt.x, tCurrPt.x),
        tY = Math.min( this.marqueeContext.startPt.y, tCurrPt.y),
        tWidth = Math.abs( this.marqueeContext.startPt.x - tCurrPt.x),
        tHeight = Math.abs( this.marqueeContext.startPt.y - tCurrPt.y),
        tRect = { x: tX, y: tY, width: tWidth, height: tHeight},
        tLast = this.marqueeContext.lastRect;
    this.marqueeContext.marquee.attr( tRect);
    this.marqueeContext.lastRect = tRect;
    this.selectPointsInRect( tRect, tBaseSelection, tLast);
    return true;
  },

  selectPointsInRect: function( iRect, iBaseSelection, iLast) {
    iBaseSelection = iBaseSelection || [];

    this.get('mapPointLayers' ).forEach( function( iLayer) {
      var tDataContext = iLayer.getPath('model.dataContext'),
          tCollection = iLayer.getPath('model.collectionClient');
      if( SC.none( tDataContext))
        return;
      var tSelection = iLayer.getCasesForDelta( iRect, iLast),
          tDeselection = iLayer.getCasesForDelta(iLast, iRect),
          tSelectChange = {
            operation: 'selectCases',
            collection: tCollection,
            cases: iBaseSelection.concat( tSelection),
            select: true,
            extend: true
          },
          tDeselectChange = {
            operation: 'selectCases',
            collection: tCollection,
            cases: iBaseSelection.concat( tDeselection),
            select: false,
            extend: true
          };

      if (tSelectChange.cases.length !== 0) {
        tDataContext.applyChange( tSelectChange);
      }
      if (tDeselectChange.cases.length !== 0) {
        tDataContext.applyChange( tDeselectChange);
      }
    });
  },

  mouseUp: function( iEvent) {
    if( !this.get('marqueeContext'))
      return false;
    this.get('layerManager').removeElement( this.marqueeContext.marquee, true /* callRemove*/ );
    this.marqueeContext = null;
    this.set('isInMarqueeMode', false);
    DG.logUser('marqueeDrag: end');
    this.get('mapPointLayers').forEach( function( iLayer) {
      iLayer.cleanUpPointSelection();
    });

    return true;
  },

  init: function() {
    var tVisibleAtZoomStart;

    var handleZoomStart = function() {
          SC.run(function() {
            tVisibleAtZoomStart = this.get('isVisible');
            if (tVisibleAtZoomStart)
              this.set('isVisible', false);
          }.bind(this));
        }.bind(this),

        handleZoomEnd = function() {
          SC.run(function() {
            if( tVisibleAtZoomStart)
              this.set('isVisible', true);
          }.bind(this));
        }.bind(this);

    arguments.callee.base.apply(this,arguments);

    this.mapPointLayers = [];
    this.addMapPointLayers();

    // When the underlying map zooms, we want to be hidden during the zoom so user doesn't see
    // points momentarily in wrong place.
    this.getPath('mapLayer.map')
        .on('zoomstart', handleZoomStart)
        .on('zoomend', handleZoomEnd);
  },

  /** For each mapLayerModel that has lat/long attributes, if we don't already have a corresponding
   *  mapPointLayer, make one and stash it.
   */
  addMapPointLayers: function() {
    var tMapPointLayers = this.get('mapPointLayers'),
        tExistingMapPointLayerModels = tMapPointLayers.map( function( iLayer) {
          return iLayer.get('model');
        });
    this.getPath('model.mapLayerModels').forEach(function (iMapLayerModel, iIndex) {
      var tDataConfig = iMapLayerModel.get('dataConfiguration');
      if (tDataConfig.get('hasLatLongAttributes') && tExistingMapPointLayerModels.indexOf( iMapLayerModel) < 0) {
        var tLayer = DG.MapPointLayer.create({
          paperSource: this,
          model: iMapLayerModel,
          mapSource: this,
          dataConfiguration: tDataConfig,
          plotLayerNumber: iIndex,
        });
        tLayer.addObserver('plotDisplayDidChange', this, function () {
          this.invokeLast(this.plottedPointsDidChange);
        }.bind(this));
        tMapPointLayers.push(tLayer);
      }
    }.bind(this));
  },

  /**
   *
   * @return {[DG.LegendView]}
   */
  createLegendViews: function() {
    var tViews = this.get('mapPointLayers').map( function( iLayer) {
      return DG.LegendView.create( { model: iLayer.getPath('model.legend')});
    });
    return tViews;
  },

  /**
   * Something about the points changed. Let my dependents know.
   */
  plottedPointsDidChange: function() {
    this.notifyPropertyChange('pointsDidChange');
  },

  modelDidChange: function () {
    // this.setPath('mapPointLayers.model', this.get('model'));
  }.observes('model'),

  shouldDraw: function() {
    // The actual map is created in an invokeLast, so we may not be ready yet
    return !SC.none( this.getPath('mapLayer.map'));
  },

  doDraw: function() {
    this.get('mapPointLayers').forEach( function( iLayer) {
      iLayer.doDraw();
    });
  },

  updateConnectingLines: function() {
    this.get('mapPointLayers').forEach( function( iLayer) {
      iLayer.updateConnectingLine();
    });
  },

  clear: function() {
    this.get('mapPointLayers').forEach( function( iLayer) {
      iLayer.clear();
    });
  }

});


/* >>>>>>>>>> BEGIN source/components/map/polygons/map_polygon_data_configuration.js */
// ==========================================================================
//                      DG.MapPolygonDataConfiguration
//
//  Author:   William Finzer
//
//  Copyright ©2018 Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
/* global L */
sc_require('components/map/map_data_configuration');

/** @class  DG.MapPolygonDataConfiguration - The object that describes the manner in which attributes are
 assigned to places in a map.

 @extends DG.MapDataConfiguration
 */
DG.MapPolygonDataConfiguration = DG.MapDataConfiguration.extend(
    /** @scope DG.MapPolygonDataConfiguration.prototype */
    {
      /**
       * It is in initialization that we specialize from base class
       */
      init: function () {

        var attributeDescriptions = {
              caption: DG.AttributePlacementDescription.create(),
              legend: DG.AttributePlacementDescription.create(),
              polygon: DG.AttributePlacementDescription.create()
            },
            tPlace,
            tCaptionName,
            tCaptionAttr, tPolygonAttr;

        arguments.callee.base.apply(this,arguments);

        var configureAttributeDescriptions = function () {

          var configAttrDesc = function (iAttrPrefix, iAttr, iCollectionClient) {
            var attrDesc = attributeDescriptions[iAttrPrefix],
                tType;

            DG.assert(attrDesc);

            // Configure the attribute description for the specified default attribute
            if (iAttr) {
              // Must set collection before attribute for attribute stats to be configured properly
              attrDesc.set('collectionClient', iCollectionClient);
              attrDesc.set('attribute', iAttr);
              switch (iAttrPrefix) {
                case 'polygon':
                  tType = DG.Analysis.EAttributeType.eBoundary;
                  break;
                case 'caption':
                  tType = DG.Analysis.EAttributeType.eCategorical;
                  break;
              }
              if (tType)
                attrDesc.setPath('attributeStats.attributeType', tType);
            }
            // Null out the attribute description when no map attribute is specified.
            else {
              attrDesc.set('collectionClient', null);
              attrDesc.removeAllAttributes();
            }

            // We must set these up manually, because the infrastructure isn't in place by
            // the time arguments.callee.base.apply(this,arguments) (i.e. SC.Object.init()) is called.
            attrDesc.addObserver('collectionClient', this, iAttrPrefix + 'CollectionDidChange');
            attrDesc.addObserver('collection', this, 'collectionDidChange');
          }.bind(this);

          // When called we are given an initializer with info we need to be valid
          var tMapContext = this.initializer.context,
              tMapCollection = this.initializer.collection,
              tMapCollectionClient = tMapContext && tMapContext.getCollectionByID(tMapCollection.get('id'));
          if (tMapCollection && tMapCollectionClient) {
            tCaptionName = tMapCollection.getAttributeNames()[0];
            tCaptionAttr = tCaptionName && tMapCollection.getAttributeByName(tCaptionName);
            tPolygonAttr = this.initializer.polygonName && tMapCollection.getAttributeByName(this.initializer.polygonName);

            configAttrDesc('caption', tCaptionAttr, tMapCollectionClient);
            configAttrDesc('legend', null, tMapCollectionClient);
            configAttrDesc('polygon', tPolygonAttr, tMapCollectionClient);
          }
        }.bind(this);

        // -- main routine of init
        configureAttributeDescriptions();

        // Prepare the attributes array. It has as many elements as there are places,
        //  and, initially, those elements are empty arrays.
        this.attributesByPlace = [];
        for (tPlace = 0; tPlace < DG.GraphTypes.EPlace.eNumPlaces; tPlace++)
          this.attributesByPlace[tPlace] = [];

        // Actually, during this coding transition, we're going to stash the previously
        // initialized attribute descriptions in attributesByPlace.
        this.attributesByPlace[DG.GraphTypes.EPlace.eCaption][0] = attributeDescriptions.caption;
        this.attributesByPlace[DG.GraphTypes.EPlace.eLegend][0] = attributeDescriptions.legend;
        this.attributesByPlace[DG.GraphTypes.EPlace.ePolygon][0] = attributeDescriptions.polygon;

        this.set('dataContext', this.initializer.context);

        delete this.initializer;  // We don't need it any more
      },

      /**
       * Override to return use the source that is used by either the polygon attribute or one of the lat/long attributes.
       * Note that we are assuming that _either_ the polygon attribute _or_ the xAttribute have a collection client. If
       * they both have collection clients and those are different, this won't be adequate.
       */
      collectionClient: function () {
        var tKeys = ['polygonAttributeDescription', 'xAttributeDescription'],
            tSource;
        tKeys.forEach(function (iAttrKey) {
          var tAttrDesc = this.get(iAttrKey);
          if (tAttrDesc && tAttrDesc.collectionClient)
            tSource = tAttrDesc.collectionClient;
        }.bind(this));
        return tSource;
      }.property(),

      /**
       * @property {SC.Array of DG.Case} All cases, both hidden and visible
       */
      allCases: function () {
        if( this.get('hasPolygonAttribute')) {
          var tSource = this.get('collectionClient');
          return tSource ? tSource.getPath('casesController.arrangedObjects') : [];
        }
        else return [];
      }.property(),

      /**
       @property { DG.AttributePlacementDescription }
       */
      polygonAttributeDescription: function (iKey, iValue) {
        return this.attributeDescriptionForPlace(iKey, iValue, DG.GraphTypes.EPlace.ePolygon);
      }.property(),

      polygonCollectionDidChange: function () {
        this.notifyPropertyChange('polygonCollectionClient');
      },

      polygonCollectionClient: function () {
        return this.getPath('polygonAttributeDescription.collectionClient');
      }.property().cacheable(),
      polygonCollectionClientDidChange: function() {
        this.notifyPropertyChange('polygonCollectionClient');
      }.observes('*polygonAttributeDescription.collectionClient'),

      polygonAttributeID: function () {
        return this.getPath('polygonAttributeDescription.attributeID');
      }.property(),
      polygonAttributeIDDidChange: function() {
        this.notifyPropertyChange('polygonAttributeID');
      }.observes('*polygonAttributeDescription.attributeID'),

      hasPolygonAttribute: function () {
        return !SC.none(this.get('polygonAttributeID'));
      }.property('polygonAttributeID'),

      /**
       @property { DG.AttributePlacementDescription }
       */
      captionAttributeDescription: function (iKey, iValue) {
        return this.attributeDescriptionForPlace(iKey, iValue, DG.GraphTypes.EPlace.eCaption);
      }.property(),

      captionCollectionDidChange: function () {
        this.notifyPropertyChange('captionCollectionClient');
      },

      captionCollectionClient: function () {
        return this.getPath('captionAttributeDescription.collectionClient');
      }.property(),
      captionCollectionClientDidChange: function() {
        this.notifyPropertyChange('captionCollectionClient');
      }.observes('*captionAttributeDescription.collectionClient'),

      captionAttributeID: function () {
        return this.getPath('captionAttributeDescription.attributeID');
      }.property(),
      captionAttributeIDDidChange: function() {
        this.notifyPropertyChange('captionAttributeID');
      }.observes('*captionAttributeDescription.attributeID'),

      /**
       * If there is an polygon attribute, go through its values, finding the rectangle that encompases all
       * the coordinates.
       * @returns {*[]}
       */
      getPolygonBounds: function () {
        var tCases = this.get('cases'),
            tPolygonID = this.get('polygonAttributeID'),
            tMinWest = 180, tMaxEast = -180, tMinSouth = 90, tMaxNorth = -90;
        if (!tPolygonID)
          return null;

        function processArrayOfCoords(iArrayOfCoords) {
          iArrayOfCoords.forEach(function (iPoint) {
            tMinSouth = Math.min(tMinSouth, iPoint[1]);
            tMaxNorth = Math.max(tMaxNorth, iPoint[1]);
            tMinWest = Math.min(tMinWest, iPoint[0]);
            tMaxEast = Math.max(tMaxEast, iPoint[0]);
          });
        }

        tCases.forEach(function (iCase) {
          try {
            var tFeature = JSON.parse(iCase.getValue(tPolygonID)),
                tCoords = tFeature.geometry.coordinates,
                tType = tFeature.geometry.type;
            tCoords.forEach(function (iArray) {
              switch (tType) {
                case 'Polygon':
                  processArrayOfCoords(iArray);
                  break;
                case 'MultiPolygon':
                  iArray.forEach(function (iSubArray) {
                    processArrayOfCoords(iSubArray);
                  });
                  break;
              }
            });
          }
          catch (er) {
            console.log(er);
          }
        });

        return L.latLngBounds([[tMinSouth, tMinWest], [tMaxNorth, tMaxEast]]);
      }

    });


/* >>>>>>>>>> BEGIN source/components/map/polygons/map_polygon_layer.js */
// ==========================================================================
//                        DG.MapPolygonLayer
//
//  Author:   William Finzer
//
//  Copyright ©2014 Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
/* global L */
sc_require('components/graph_map_common/plot_layer');


/** @class DG.MapPolygonLayer - A plot of dots placed according to numeric values

  @extends DG.PlotLayer
*/
DG.MapPolygonLayer = DG.PlotLayer.extend(
/** @scope DG.MapPolygonLayer.prototype */
{
  displayProperties: [],

  autoDestroyProperties: [],

  mapSource: null,

  _areFeaturesAdded: false,
  _featuresRemainingToFetch: 0,
  features: null,

  map: function() {
    return this.getPath('mapSource.mapLayer.map');
  }.property(),

  init: function() {
    arguments.callee.base.apply(this,arguments);

    this.features = [];
  },

  destroy: function() {
    var tMap = this.get('map');
    this.features.forEach( function( iFeature) {
      tMap.removeLayer( iFeature);
    });
    this.features = null;

    arguments.callee.base.apply(this,arguments);
  },

  /**
   * Augment my base class by checking to make sure we have the attributes we need.
   * @returns {boolean}
   */
  readyToDraw: function() {
    var tModel = this.get('model');
    return tModel && !SC.none(tModel.getPath('dataConfiguration.polygonAttributeDescription.attributeID'));
  },

  /**
   * Computing this context once at beginning of display loop speeds things up
   * @return {*}
   */
  createRenderContext: function() {
    var tModel = this.get('model');
    if( !tModel)
      return; // not ready yet
    var tConfig = tModel.get('dataConfiguration'),
        tLegendDesc = tModel.getPath('dataConfiguration.legendAttributeDescription'),
        tStrokeColorIsDefault = this.get('areaStrokeColor') === DG.PlotUtilities.kDefaultMapStrokeColor,
        tStrokeSameAsFill = tModel.get('strokeSameAsFill'),
        tIsNumeric = tLegendDesc && tLegendDesc.get('isNumeric'),
        tQuantileValues = tConfig.get('legendQuantiles');
    return {
      map: this.get('map' ),
      polygonVarID: tModel.getPath('dataConfiguration.polygonAttributeDescription.attributeID'),
      legendDesc: tLegendDesc,
      legendVarID: tLegendDesc && tLegendDesc.get('attributeID'),
      legendName: tLegendDesc && tLegendDesc.getPath('attribute.name'),
      areaTransparency: tModel.get('areaTransparency'),
      areaStrokeColor: tModel.get('areaStrokeColor'),
      areaStrokeColorIsDefault: tStrokeColorIsDefault,
      areaStrokeTransparency: tStrokeSameAsFill ?
          tModel.get('areaTransparency') :
          tModel.get('areaStrokeTransparency'),
      calcCaseColorString: function( iCase ) {
        if( !this.legendVarID)
          return tModel.get('areaColor');

        DG.assert( iCase );
        var tColorValue = tIsNumeric ? iCase.getForcedNumericValue(this.legendVarID) : iCase.getValue( this.legendVarID),
            tCaseColor = tColorValue ?
                DG.ColorUtilities.calcCaseColor( tColorValue, this.legendDesc, null, tQuantileValues) :
                DG.ColorUtilities.kMapMissingValueCaseColor;
        return tCaseColor.colorString || tCaseColor;
      },
      calcStrokeColorString: function( iCase ) {
        if( tStrokeSameAsFill)
          return this.calcCaseColorString( iCase);
        else return this.areaStrokeColor;
      }
    };
  },

  calcTooltip: function( iCase) {

    function formatValue( iCase, iAttrDesc) {

      function getDigits() {
        return DG.PlotUtilities.findFractionDigitsForRange(iAttrDesc.getPath('attributeStats.minMax'));
      }

      return DG.PlotUtilities.getFormattedCaseValue( iCase, iAttrDesc, getDigits);
    }

    var tCaptionDesc = this.getPath('model.dataConfiguration.captionAttributeDescription'),
        tCaptionVarID = tCaptionDesc.get('attributeID'),
        tCaptionName = tCaptionDesc.getPath('attribute.name'),
        tLegendDesc = this.getPath('model.dataConfiguration.legendAttributeDescription'),
        tLegendVarID = tLegendDesc && tLegendDesc.get('attributeID'),
        tLegendName = tLegendDesc.getPath('attribute.name'),
        tTip = tCaptionName + ': ' + iCase.getValue( tCaptionVarID);
    if( tLegendVarID && (tLegendVarID !== tCaptionVarID)) {
      tTip += '<br>' + tLegendName + ': ' + formatValue(iCase, tLegendDesc);
    }
    return tTip;
  },

  handleAttributeChange: function() {
    this.dataDidChange();
  }.observes('model.dataConfiguration.attributeAssignment',
     'model.dataConfiguration.legendQuantilesAreLocked'),

  /**
   We should only have to worry about the fill color and fill opacity
   */
  doDraw: function() {
    if( !this.readyToDraw())
      return;   // not ready to create elements yet
    var tCases = this.getPath('model.cases'),
        tRC = this.createRenderContext();
    if( tCases.get('length') !== this.features.length) {
      this.clear();
      this.addFeatures();
    }
    tCases.forEach( function( iCase, iIndex) {
      var tColorString = tRC.calcCaseColorString( iCase),
          tStrokeColorString = tRC.calcStrokeColorString( iCase),
          tFeature = this.features[ iIndex];
      if( tFeature) {
        tFeature.setStyle({
          fillColor: tColorString,
          color: tStrokeColorString,
          opacity: tRC.areaStrokeTransparency,
          fillOpacity: tRC.areaTransparency
        });
      }
    }.bind( this));
    this.updateSelection();
  }.observes('model.areaColor', 'model.areaTransparency', 'model.areaStrokeColor', 'model.areaStrokeTransparency',
      'model.strokeSameAsFill', 'model.pointColor', 'model.colorMap'),

  /**
   * Remove all features.
   */
  clear: function() {
    this._areFeaturesAdded = false;
    var tMap = this.get('map');
    this.features.forEach( function( iFeature) {
      tMap.removeLayer( iFeature);
    });
    this.features = [];
  },

  isVisibleChanged: function() {
    var tIsVisible = this.getPath('model.isVisible'),
        tMap = this.get('map');
    this.features.forEach( function( iFeature) {
      var tHasLayer = tMap.hasLayer( iFeature);
      if( tIsVisible && !tHasLayer) {
        tMap.addLayer( iFeature);
      }
      else if( !tIsVisible && tHasLayer) {
        tMap.removeLayer( iFeature);
      }
    });
  }.observes('model.isVisible'),

  hasLegendWithFormula: function () {
    return this.getPath('model.dataConfiguration.legendAttributeDescription.attribute.hasFormula');
  },

  /**
   Handle changes in assignment of legend attribute.
   */
  dataDidChange: function() {
    this.doDraw();
  },

  refreshComputedLegendColors: function() {
    if( this.hasLegendWithFormula())
      this.doDraw();
  },

  /**
    Observation function called when data values change.
    Method name is legacy artifact of SproutCore range observer implementation.
   */
  dataRangeDidChange: function( iSource, iQuestion, iKey, iChanges) {
    this.doDraw();
  },

  mustClearBecauseDataContextDidChange: function() {
    this.clear(); // So fresh features will get correct cases as option
  }.observes('model.dataContext'),

  /**
   For each case, set the fill of its corresponding point to show its selection state
   */
  updateSelection: function() {
    if( !this.get('model'))
      return;   // because this can get called by pending changes after I have been destroyed

    // Use long path for selection because we can call this before bindings have happened
    // There must be a better way?
    var tSelection = this.getPath('model.dataConfiguration.collectionClient.casesController.selection'),
    // Points are 'colored' if there is a legend or if there is more than one plot
        tHasLegend = (this.getPath('model.dataConfiguration.legendAttributeDescription.attribute') !==
            DG.Analysis.kNullAttribute),
        tCases = this.getPath('model.dataConfiguration.allCases'),
        tRC = this.createRenderContext();

    if(!tCases)
      return;

    tCases.forEach( function( iCase) {
      var tFeature = this.features.find( function (iFeature) {
              return iFeature && iFeature.options['case'] === iCase;
            }),
          tIsSelected = tSelection.containsObject( iCase),
          tFillColor = (tIsSelected && !tHasLegend) ? DG.PlotUtilities.kMapAreaNoLegendSelectedColor :
                      tRC.calcCaseColorString(iCase);
      if (!tFeature)
        return;
      if( tIsSelected) {
        tFeature.setStyle( {
          fillColor: tFillColor,
          color: tHasLegend ? DG.PlotUtilities.kMapAreaWithLegendSelectedBorderColor :
              DG.PlotUtilities.kMapAreaNoLegendSelectedBorderColor,
          fillOpacity: tHasLegend ? DG.PlotUtilities.kMapAreaWithLegendSelectedOpacity :
              DG.PlotUtilities.kMapAreaNoLegendSelectedOpacity,
          weight: DG.PlotUtilities.kMapAreaSelectedBorderWeight
        });
        if( !tHasLegend) {
          tFeature.setStyle( {
            fillColor: tFillColor
          });
        }
      }
      else {
        tFeature.setStyle( {
          color: tRC.calcStrokeColorString( iCase),
          opacity: tRC.areaStrokeTransparency,
          fillOpacity: tHasLegend ? DG.PlotUtilities.kMapAreaWithLegendUnselectedOpacity :
              tRC.areaTransparency,
          weight: DG.PlotUtilities.kMapAreaUnselectedBorderWeight,
          fillColor: tFillColor
        });
        tFeature.bringToBack();
      }
    }.bind( this));
  },

  selectionDidChange: function() {
    this.updateSelection();
  }.observes('model.selection'),

  addFeatures: function() {
    if( this._areFeaturesAdded || this._featuresRemainingToFetch > 0)
      return;

    this._featuresRemainingToFetch = 0;
    var tRC = this.createRenderContext(),
        tModel = this.get('model'),
        tCases = tModel.getPath( 'dataConfiguration.cases'),
        tIsVisible = tModel.get('isVisible');//,
        //tCaptionID = tModel.getPath('dataConfiguration.captionAttributeDescription.attributeID'),
        //tCaptionName = tModel.getPath('dataConfiguration.captionAttributeDescription.attribute.name');
    tCases.forEach( function( iCase, iIndex) {
      var tPopup,

          stashFeature = function( iJson, iError) {
            if( !iJson) {
              DG.logWarn( iError);
              return;
            }
            if( this._featuresRemainingToFetch > 0)
              this._featuresRemainingToFetch--;
            this.features[iIndex] = L.geoJson(iJson, {
              style: function (feature) {
                return {
                  color: 'yellow',
                  weight: 2,
                  fillColor: DG.PlotUtilities.kMapAreaNoLegendColor,
                  smoothFactor: 2
                };
              },
              'case': iCase // Stashes reference in features[iIndex].options.case
            })
                .on('click', handleClick) // unable to use 'mousedown' for unknown reason
                .on('mouseover', handleMouseover)
                .on('mouseout', handleMouseout)
                .addTo(tRC.map);
            if( !tIsVisible) {
              tRC.map.removeLayer( this.features[iIndex]);
            }
            else {
              this.features[iIndex].bringToBack();
            }
          }.bind( this),

          handleClick = function( iEvent) {
            SC.run(function() {
              this.get('model').selectCase(iCase, iEvent.originalEvent.shiftKey || iEvent.originalEvent.metaKey);
            }.bind(this));
          }.bind( this),

          handleMouseover = function( iEvent) {
            var tFeature = this.features[ iIndex];
            tPopup = L.popup({
                  closeButton: false,
                  autoPan: false,
                  offset: L.point(0, -20)
                },
                tFeature);
            tPopup.setContent( this.calcTooltip( iCase));
            SC.Timer.schedule( { target: this,
                                action: function() {
                                          if( tPopup)
                                            tFeature.bindPopup( tPopup).openPopup();
                                        },
                                interval: 500 });

          }.bind(this),

          handleMouseout = function( iEvent) {
            if( tPopup) {
              tPopup._close();
              tPopup = null;
            }
          }.bind( this);

      try {
        var tBoundaryValue = iCase.getValue(tRC.polygonVarID);
        if (!tBoundaryValue) return;
        if( tBoundaryValue instanceof Error) {
          stashFeature( null, tBoundaryValue.message);
        }
        else if( typeof tBoundaryValue === 'object') {
          if (tBoundaryValue.jsonBoundaryObject)
            tBoundaryValue = tBoundaryValue.jsonBoundaryObject;
          stashFeature( tBoundaryValue);
        }
        else if (tBoundaryValue.startsWith('http')) {
          this._featuresRemainingToFetch++;
          $.ajax({
            url: tBoundaryValue,
            context: this,
            data: '',
            success: stashFeature,
            error: function( iJqXHR, iStatus, iError) {
              console.log('Request for boundary failed. Status: ' + iStatus + ' Error: ' + iError);
            },
            dataType: 'json'
          });
        }
        else if(tBoundaryValue.startsWith('{')) // Assume it's the geojson itself
        {
          stashFeature( JSON.parse(tBoundaryValue));
        }
      }
      catch(er) {
        DG.logWarn("Invalid JSON for map area, reported from DG.MapPolygonLayer.addFeatures()");
      }
    }.bind( this));
    this._areFeaturesAdded = true;
  },

  /**
   * Return LatLngBounds of the geoJSON layer
   * @return {L.LatLngBounds}
   */
  getBounds: function() {
    var tMap = this.get('map'),
        tBounds;
    tMap.eachLayer( function( iLayer) {
      if( iLayer.getBounds) {
        var tLayerBounds = iLayer.getBounds();
        if (!tBounds)
          tBounds = tLayerBounds;
        else
          tBounds.extend(tLayerBounds);
      }
    });

    return tBounds;
  }

});


/* >>>>>>>>>> BEGIN source/components/map/polygons/map_polygon_layer_model.js */
// ==========================================================================
//                            DG.MapModel
//
//  Author:   William Finzer
//
//  Copyright ©2014 Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('components/map/map_layer_model');

/** @class  DG.MapPolygonLayerModel - The model for polygons on a map.

 @extends DG.MapLayerModel
 */
DG.MapPolygonLayerModel = DG.MapLayerModel.extend(
    /** @scope DG.MapLayerModel.prototype */
    {
      areaColor: DG.PlotUtilities.kMapAreaNoLegendColor,
      areaTransparency: DG.PlotUtilities.kDefaultMapFillOpacity,
      areaStrokeColor: DG.PlotUtilities.kDefaultMapStrokeColor,
      areaStrokeTransparency: DG.PlotUtilities.kDefaultMapStrokeOpacity,

      init: function() {
        arguments.callee.base.apply(this,arguments);
      },

      polygonVarID: function() {
        return this.getPath('dataConfiguration.polygonAttributeDescription.attributeID');
      }.property(),
      polygonVarIDDidChange: function() {
        this.notifyPropertyChange('polygonVarID');
      }.observes('*dataConfiguration.polygonAttributeDescription.attributeID'),

      /**
       * Override superclass
       * @returns {boolean}
       */
      wantsInspector: true,

      hasPolygonAttribute: true,

      /**
       * We can rescale if we have some data to rescale to.
       * @return {Boolean}
       */
      canRescale: true,

      /**
       * @override
       * @return {*|Number|boolean}
       */
      hasValidMapAttributes: function() {
        var tMapAttribute = this.getPath( 'dataConfiguration.polygonAttributeDescription.attribute'),
            tAttrName = tMapAttribute && tMapAttribute.get('name'),
            tAttrType = tMapAttribute && tMapAttribute.get('type');
        return tAttrName && (DG.MapConstants.kPolygonNames.indexOf( tAttrName.toLowerCase()) >= 0 ||
            tAttrType === DG.Analysis.EAttributeType.eBoundary || tAttrType === 'boundary');
      },

      createStorage: function() {
        var tStorage = arguments.callee.base.apply(this,arguments);
        tStorage.areaColor = this.get('areaColor');
        tStorage.areaTransparency = this.get('areaTransparency');
        tStorage.areaStrokeColor = this.get('areaStrokeColor');
        tStorage.areaStrokeTransparency = this.get('areaStrokeTransparency');
        tStorage.strokeSameAsFill = this.get('strokeSameAsFill');

        return tStorage;
      },

      restoreStorage: function( iStorage) {
        arguments.callee.base.apply(this,arguments);

        var tStorage = iStorage.mapModelStorage || iStorage;

        if (tStorage.areaColor)
          this.set('areaColor', tStorage.areaColor);
        if (tStorage.areaTransparency)
          this.set('areaTransparency', tStorage.areaTransparency);
        if (tStorage.areaStrokeColor)
          this.set('areaStrokeColor', tStorage.areaStrokeColor);
        if (tStorage.areaStrokeTransparency)
          this.set('areaStrokeTransparency', tStorage.areaStrokeTransparency);
        if (tStorage.strokeSameAsFill)
          this.set('strokeSameAsFill', tStorage.strokeSameAsFill);
      }
    });
/* >>>>>>>>>> BEGIN source/components/slider/slider_controller.js */
// ==========================================================================
//                        DG.SliderController
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('controllers/component_controller');

/** @class

    Coordinating controller for slider components.

 @extends DG.ComponentController
 */
DG.SliderController = DG.ComponentController.extend(
    /** @scope DG.SliderController.prototype */ {

      sliderModel: null,

      axisModel: null,

      sliderView: null,

      axisView: function() {
        return this.getPath('view.contentView.axisView');
      }.property(),

      /**
       Used to animate the mode's value.
       @property { DG.ValueAnimator }
       */
      valueAnimator: null,

      /**
       A record of the animation direction.
       @property { Number }
       */
      animationSign: 1,

      isAnimating: function () {
        // !! guarantees a boolean return for null, undefined, etc.
        return !!this.getPath('valueAnimator.isAnimating');
      }.property(),

      isAnimatingDidChange: function() {
        this.notifyPropertyChange('isAnimating');
      }.observes('*valueAnimator.isAnimating'),

      modelDidChange: function () {
        var sliderModel = this.getPath('model.content');
        this.set('sliderModel', sliderModel);
        if (sliderModel)
          this.set('axisModel', sliderModel.get('axis'));
      }.observes('model'),

      /**
       * Called as action of startButton
       */
      toggleAnimation: function () {

        var beginAnimation = function() {
          var tAxisModel = this.get('axisModel'),
              tLower = tAxisModel && tAxisModel.get('lowerBound'),
              tUpper = tAxisModel && tAxisModel.get('upperBound'),
              tAxisView = this.get('axisView'),
              tValue = tSliderModel.get('value'),
              tInc = this.getPath('sliderModel.restrictToMultiplesOf') ||
                  (tAxisView && tAxisView.get('increment'));
          if (tDirection === DG.SliderTypes.EAnimationDirection.eLowToHigh && (tValue + tInc >= tUpper)) {
            tSliderModel.set('value', tLower);
          }
          else if (tDirection === DG.SliderTypes.EAnimationDirection.eHighToLow && (tValue - tInc <= tLower)) {
            tSliderModel.set('value', tUpper);
          }
          tAnimator.set('maxPerSecond', this.getPath('sliderModel.maxPerSecond'));
          tAnimator.animate();
          DG.logUser("sliderBeginAnimation: %@", this.getPath('sliderModel.name'));
        }.bind(this);

        var tAnimator = this.get('valueAnimator'),
            tSliderModel = this.get('sliderModel'),
            tDirection = tSliderModel.get('animationDirection');
        if (tDirection === DG.SliderTypes.EAnimationDirection.eLowToHigh)
          this.set('animationSign', 1);
        else if (tDirection === DG.SliderTypes.EAnimationDirection.eHighToLow)
          this.set('animationSign', -1);
        if (SC.none(tAnimator)) {
          tAnimator = DG.ValueAnimator.create({
            valueHolder: tSliderModel,
            incrementProvider: this
          });
          this.set('valueAnimator', tAnimator);
        }

        if (tAnimator.get('isAnimating')) {
          tAnimator.endAnimation();
          DG.logUser("sliderEndAnimation: %@", this.getPath('sliderModel.name'));
        }
        else {
          beginAnimation();
        }
        DG.dirtyCurrentDocument();
      },

      stopAnimation: function () {
        var tAnimator = this.get('valueAnimator');
        if (tAnimator && tAnimator.get('isAnimating')) {
          tAnimator.endAnimation();
          DG.dirtyCurrentDocument();
        }
      },

      /**
       * Called typically by a ValueAnimator to get the amount to increment a value displayed along the axis
       * @property {Number}
       */
      increment: function () {
        var tSliderModel = this.get('sliderModel'),
            tAxisModel = this.get('axisModel'),
            tAxisView = this.get('axisView'),
            tRestrictToMultiplesOf = tSliderModel.get('restrictToMultiplesOf'),
            tInc = tRestrictToMultiplesOf || (tAxisView && tAxisView.get('increment')),
            tLower = tAxisModel && tAxisModel.get('lowerBound'),
            tUpper = tAxisModel && tAxisModel.get('upperBound'),
            tValue = tSliderModel.get('value'),
            tDirection = tSliderModel.get('animationDirection'),
            tMode = tSliderModel.get('animationMode'),
            tTrial = tValue + this.get('animationSign') * tInc;
        switch (tDirection) {
          case DG.SliderTypes.EAnimationDirection.eBackAndForth:
            if (tTrial > tUpper) {
              this.set('animationSign', -1);
              tInc = tTrial - tUpper;
            }
            else if (tTrial < tLower) {
              this.set('animationSign', 1);
              tInc = tLower - tTrial;
            }
            break;
          case DG.SliderTypes.EAnimationDirection.eLowToHigh:
            if (tTrial > tUpper) {
              if (tMode === DG.SliderTypes.EAnimationMode.eOnceOnly) {
                if( !DG.isNumeric(tRestrictToMultiplesOf))
                  tSliderModel.set('value', tUpper);
                tInc = 0;
                this.stopAnimation();
              }
              else
                tSliderModel.set('value', tLower);
            }
            break;
          case DG.SliderTypes.EAnimationDirection.eHighToLow:
            if (tTrial < tLower) {
              if( !DG.isNumeric(tRestrictToMultiplesOf))
                tSliderModel.set('value', tLower);
              if (tMode === DG.SliderTypes.EAnimationMode.eOnceOnly) {
                tInc = 0;
                this.stopAnimation();
              }
              else
                tSliderModel.set('value', tUpper);
            }
            break;
        }
        return this.animationSign * tInc;
      }.property(),

      incrementDidChange: function() {
        this.notifyPropertyChange('increment');
      }.observes('*axisView.increment', '*axisModel.lowerBound', '*axisModel.upperBound', '*sliderModel.value'),

      /**
       *
       * @returns {Array}
       */
      createInspectorButtons: function() {
        var tButtons = arguments.callee.base.apply(this,arguments);
        tButtons.push(DG.IconButton.create({
              layout: {width: 32},
              classNames: 'dg-slider-values'.w(),
              iconClass: 'moonicon-icon-values',
              showBlip: true,
              target: this,
              action: 'showValuesPane',
              toolTip: 'DG.Inspector.sliderValues.toolTip',
              localize: true
            })
        );
        return tButtons;
      },

      showValuesPane: function () {
        var this_ = this;

        var
            noTypeCheck = function( iValue) {
              return iValue;
            },

            typeCheck = function (iValue) {
              if (!DG.isNumeric(iValue) || iValue === 0)
                iValue = null;
              else
                iValue = Number(iValue);
              return iValue;
            },

            setupAction = function (iSpecs) {
              var params = Object.assign(iSpecs, {
                name: 'slider.change',
                _newValue: null,
                _prevValue: null,
                executeNotification: {
                  action: 'notify',
                  resource: 'component',
                  values: {
                    operation: 'change slider value',
                    type: 'DG.SliderView'
                  }
                },
                execute: function () {
                  this._prevValue = this_.getPath(this.valueKey);
                  this._newValue = this.typeCheckFunc( this.controlView.get('value'));
                  if (this._newValue === this._prevValue) {
                    this.causedChange = false;
                  }
                  this_.setPath(this.valueKey, this._newValue);
                },
                undo: function () {
                  this_.setPath(this.valueKey, this._prevValue);
                },
                redo: function () {
                  this_.setPath(this.valueKey, this._newValue);
                }
              });
              DG.UndoHistory.execute(DG.Command.create(params));
            };

        DG.InspectorPickerPane.create({
          classNames: 'dg-inspector-picker'.w(),
          layout: {width: 275, height: 100},
          contentView: SC.View.extend(SC.FlowedLayout,
              {
                layoutDirection: SC.LAYOUT_VERTICAL,
                isResizable: false,
                isClosable: false,
                defaultFlowSpacing: {bottom: 10},
                canWrap: false,
                align: SC.ALIGN_TOP,
                childViews: 'title multiples maxPerSecond directionControl modeControl'.w(),
                title: DG.PickerTitleView.extend({
                  title: 'DG.Inspector.values',
                  localize: true,
                  iconURL: '../../../../static/dg/de/cert/resources/images/icon-values.svg'
                }),
                multiples: SC.View.extend(SC.FlowedLayout, {
                  layoutDirection: SC.LAYOUT_HORIZONTAL,
                  isResizable: false,
                  isClosable: false,
                  defaultFlowSpacing: {right: 10},
                  canWrap: false,
                  align: SC.ALIGN_LEFT,
                  layout: {height: 24},
                  childViews: 'label input'.w(),
                  label: SC.LabelView.create({
                    layout: {width: 132},
                    value: 'DG.Slider.multiples'.loc(),
                    classNames: 'dg-inspector-picker-tag'.w(),
                  }),
                  input: SC.TextFieldView.create({
                    layout: {width: 80},
                    type: 'number',
                    classNames: 'dg-inspector-input'.w(),
                    applyImmediately: false,
                    value: this.getPath('sliderModel.restrictToMultiplesOf'),
                    valueChanged: function () {
                      setupAction({
                        controlView: this,
                        undoString: 'DG.Undo.slider.changeMultiples',
                        redoString: 'DG.Redo.slider.changeMultiples',
                        log: "sliderMaxPerSecond: { \"name\": \"%@\", \" restrictMultiplesOf to\": \"%@\" }".
                        loc(this_.getPath('sliderModel.name'), this.get('value')),
                            valueKey: 'sliderModel.restrictToMultiplesOf',
                        typeCheckFunc: typeCheck
                      });
                    }.observes('value')
                  })
                }),
                maxPerSecond: SC.View.extend(SC.FlowedLayout, {
                  layoutDirection: SC.LAYOUT_HORIZONTAL,
                  isResizable: false,
                  isClosable: false,
                  defaultFlowSpacing: {right: 10},
                  canWrap: false,
                  align: SC.ALIGN_LEFT,
                  layout: {height: 24},
                  childViews: 'label input'.w(),
                  label: SC.LabelView.create({
                    layout: {width: 190},
                    value: 'DG.Slider.maxPerSecond'.loc(),
                    classNames: 'dg-inspector-picker-tag'.w(),
                  }),
                  input: SC.TextFieldView.create({
                    layout: {width: 60},
                    type: 'number',
                    classNames: 'dg-inspector-input'.w(),
                    applyImmediately: false,
                    value: this.getPath('sliderModel.maxPerSecond'),
                    valueChanged: function () {
                      setupAction({
                        controlView: this,
                        undoString: 'DG.Undo.slider.changeSpeed',
                        redoString: 'DG.Redo.slider.changeSpeed',
                        log: "sliderMaxPerSecond: { \"name\": \"%@\", \"maxPerSecond to\": \"%@\" }".
                              loc(this_.getPath('sliderModel.name'), this.get('value')),
                        valueKey: 'sliderModel.maxPerSecond',
                        typeCheckFunc: typeCheck
                      });
                    }.observes('value')
                  })
                }),
                directionControl: DG.PickerControlView.extend({
                  layout: {height: 24},
                  label: 'DG.Slider.direction',
                  controlView: SC.SelectView.extend({
                    classNames: 'dg-inspector-picker-select dg-slider-direction'.w(),
                    layout: {right: 10, width: 130},
                    localize: true,
                    value: this_.getPath('sliderModel.animationDirection'),
                    valueChanged: function () {
                      setupAction({
                        controlView: this,
                        undoString: 'DG.Undo.slider.changeDirection',
                        redoString: 'DG.Redo.slider.changeDirection',
                        log: "sliderAnimationDirection: { \"name\": \"%@\", \"to\": \"%@\" }".loc(this_.getPath('sliderModel.name'),
                            DG.SliderTypes.directionToString(this.get('value'))),
                        valueKey: 'sliderModel.animationDirection',
                        typeCheckFunc: noTypeCheck
                      });
                    }.observes('value'),
                    itemTitleKey: 'title',
                    itemValueKey: 'value',
                    items: [
                      {title: 'DG.Slider.lowToHigh', value: DG.SliderTypes.EAnimationDirection.eLowToHigh},
                      {title: 'DG.Slider.backAndForth', value: DG.SliderTypes.EAnimationDirection.eBackAndForth},
                      {title: 'DG.Slider.highToLow', value: DG.SliderTypes.EAnimationDirection.eHighToLow}
                    ]
                  })
                }),
                modeControl: DG.PickerControlView.extend({
                  layout: {height: 24},
                  label: 'DG.Slider.mode',
                  controlView: SC.SelectView.extend({
                    classNames: 'dg-inspector-picker-select dg-slider-mode'.w(),
                    layout: {right: 10, width: 130},
                    localize: true,
                    value: this_.getPath('sliderModel.animationMode'),
                    valueChanged: function () {
                      setupAction({
                        controlView: this,
                        undoString: 'DG.Undo.slider.changeRepetition',
                        redoString: 'DG.Redo.slider.changeRepetition',
                        log: "sliderRepetitionMode: { \"name\": \"%@\", \"to\": \"%@\" }".loc(this_.getPath('sliderModel.name'),
                            DG.SliderTypes.modeToString(this.get('value'))),
                        valueKey: 'sliderModel.animationMode',
                        typeCheckFunc: noTypeCheck
                      });
                    }.observes('value'),
                    itemTitleKey: 'title',
                    itemValueKey: 'value',
                    items: [
                      {title: 'DG.Slider.onceOnly', value: DG.SliderTypes.EAnimationMode.eOnceOnly},
                      {title: 'DG.Slider.nonStop', value: DG.SliderTypes.EAnimationMode.eNonStop}
                    ]
                  })
                })
              }),
          transitionIn: SC.View.SCALE_IN
        }).popup(this.get('inspectorButtons')[0], SC.PICKER_POINTER);
      },

      createComponentStorage: function () {
        var storage = {},
            sliderModel = this.get('sliderModel'),
            axisModel = this.get('axisModel');
        if (sliderModel) {
          this.addLink(storage, 'model', sliderModel);
          if (axisModel) {
            storage.lowerBound = axisModel.get('lowerBound');
            storage.upperBound = axisModel.get('upperBound');
          }
          storage.animationDirection = sliderModel.get('animationDirection');
          storage.animationMode = sliderModel.get('animationMode');
          storage.restrictToMultiplesOf = sliderModel.get('restrictToMultiplesOf');
          storage.maxPerSecond = sliderModel.get('maxPerSecond');
          storage.userTitle = sliderModel.get('userChangedTitle');
        }
        return storage;
      },

      restoreComponentStorage: function (iComponentStorage, iDocumentID) {
        arguments.callee.base.apply(this,arguments);
        var sliderModel = this.getPath('model.content');
        if (sliderModel) {
          var modelID = this.getLinkID(iComponentStorage, 'model');
          if (modelID) {
            var globalValue = DG.store.find(DG.GlobalValue, modelID);
            if (globalValue) {
              DG.globalsController.registerGlobalValue(globalValue);
              sliderModel.set('content', globalValue);
            }
          }
          sliderModel.set('animationDirection', iComponentStorage.animationDirection);
          sliderModel.set('animationMode', iComponentStorage.animationMode);
          sliderModel.set('restrictToMultiplesOf', iComponentStorage.restrictToMultiplesOf);
          sliderModel.set('maxPerSecond', iComponentStorage.maxPerSecond);
          sliderModel.set('userChangedTitle', iComponentStorage.userChangedTitle);
          var axisModel = sliderModel.get('axis');
          if (axisModel && !SC.none( iComponentStorage.lowerBound) && !SC.none( iComponentStorage.upperBound))
            axisModel.setLowerAndUpperBounds(iComponentStorage.lowerBound, iComponentStorage.upperBound);
        }
      }

    });


/* >>>>>>>>>> BEGIN source/components/slider/slider_model.js */
// ==========================================================================
//                            DG.SliderModel
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

DG.SliderTypes = {

  EAnimationDirection: {
    eBackAndForth: 0,
    eLowToHigh: 1,
    eHighToLow: 2
  },

  directionToString: function( iDirection) {
    switch( iDirection) {
      case this.EAnimationDirection.eBackAndForth:
        return 'DG.Slider.backAndForth'.loc();
      case this.EAnimationDirection.eLowToHigh:
        return 'DG.Slider.lowToHigh'.loc();
      case this.EAnimationDirection.eHighToLow:
        return 'DG.Slider.highToLow'.loc();
    }
  },

  EAnimationMode: {
    eNonStop: 0,
    eOnceOnly: 1
  },

  modeToString: function( iMode) {
    switch( iMode) {
      case this.EAnimationMode.eNonStop:
        return 'DG.Slider.nonStop'.loc();
      case this.EAnimationMode.eOnceOnly:
        return 'DG.Slider.onceOnly'.loc();
    }
  }

};

/** @class  DG.SliderModel - The model for a slider. Holds onto a global value.

 @extends SC.Object
 */
DG.SliderModel = SC.Object.extend(
  /** @scope DG.SliderModel.prototype */
  {
    /**
     @property { DG.AxisCellLinearModel }
     */
    axis: null,

    /**
     @property { DG.GlobalValue }
     */
    content: null,
  
    id: null,
    idBinding: '*content.id',
  
    name: function (key, value) {
      if (!SC.none(value)) {
        this.setPath('content.name', value);
      }
      return this.getPath('content.name');
    }.property(),
  
    defaultTitle: function() {
      return this.getPath('content.name');
    }.property(),

    defaultTitleDidChange: function () {
      this.notifyPropertyChange('defaultTitle');
    }.observes('*content.name'),

    _title: null,
    title: function (key, value) {
      if (!SC.none(value)) {
        this._title = value;
      }
      return this._title || this.get('defaultTitle');
    }.property(),

    titleDidChange: function () {
      this.set('userChangedTitle', true);
    }.observes('title'),

    value: null,
    valueBinding: '*content.value',

    animationDirection: DG.SliderTypes.EAnimationDirection.eLowToHigh,
    animationMode: DG.SliderTypes.EAnimationMode.eOnceOnly,
    restrictToMultiplesOf: null,
    maxPerSecond: null,
    userChangedTitle: false, // user changed the title

    /**
     * DG.GraphAnimator
     */
    animator: null,

    /**
     Prepare dependencies.
     */
    init: function() {
      arguments.callee.base.apply(this,arguments);

      var axisModel = DG.CellLinearAxisModel.create();
      axisModel.setDataMinAndMax( 0, 10);
      this.set('axis', axisModel);
    },

    destroy: function() {
      DG.globalsController.destroyGlobalValue( this.get('content'));
      arguments.callee.base.apply(this,arguments);
    },

    applyRestriction: function() {
      var tOldValue = this.get( 'value'),
          tRestriction = this.get('restrictToMultiplesOf'),
          tMultiplier = (DG.isNumeric( tRestriction) && tRestriction !== 0) ?
              Math.round( tOldValue / tRestriction) : null;
      if( DG.isNumeric( tMultiplier))
        this.setIfChanged('value', tRestriction * tMultiplier);
    }.observes('restrictToMultiplesOf'),

    valueChanged: function() {
      this.applyRestriction();
    }.observes('value'),

    /**
     * Make sure the axis bounds encompass the current value. If they don't, use animation in the rescaling.
     */
    encompassValue: function() {
      var tAxis = this.get('axis'),
          tLower = tAxis.get('lowerBound'),
          tUpper = tAxis.get('upperBound'),
          tValue = this.get('value');
      if( (tValue < tLower) || (tValue > tUpper)) {
        var tNewLower = tLower,
            tNewUpper = tUpper,
            tAxisInfoArray = [];
        if( tValue < tLower)
          tNewLower = tValue - (tUpper - tValue) / 10;
        else
          tNewUpper = tValue + (tValue - tLower) / 10;
        if( SC.none( this.get('animator')))
          this.set('animator', DG.GraphAnimator.create());
        tAxisInfoArray.push ( { axis: tAxis, newBounds: { lower: tNewLower, upper: tNewUpper } });
        DG.sounds.playDrag();
        this.get('animator').set('axisInfoArray', tAxisInfoArray)
                            .animate();
      }
    },

    /**
     * The axis bounds have been changed such that the thumb is no longer visible; i.e. the value is no longer
     * within these bounds. Bring them back in.
     */
    bringValueInBounds: function() {
      // If the axis is animating, it's probably animating so that it will
      // encompass the new value. Wait until it's finished before trying
      // to adjust the value so it fits within the axis bounds.
      if( this.getPath('animator.isAnimating'))
        return;
      var tAxis = this.get('axis'),
          tLower = tAxis.get('lowerBound'),
          tUpper = tAxis.get('upperBound'),
          tValue = this.get('value');
      if( tValue < tLower)
        this.set('value', tLower);
      else if( tValue > tUpper)
        this.set('value', tUpper);
    }.observes('.axis.lowerBound', '.axis.upperBound'),
    
    toLink: function() {
      var content = this.get('content');
      return content ? content.toLink() : null;
    }
    
  } );


/* >>>>>>>>>> BEGIN source/components/slider/slider_view.js */
// ==========================================================================
//                            DG.SliderView
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class  DG.SliderView - The top level view for a slider

 @extends DG.View
 */
DG.SliderView = SC.View.extend(
  /** @scope DG.SliderView.prototype */
  (function() {
    var kWidth = 32,
        kThumbHeight = 36,
        kAxisHeight = 20,
        kButtonHeight = 18,
        kButtonWidth = 20,
        kGap = 5,
        tMouseDownInfo,
        tDraggingThumb = false;

    return {
      backgroundColor: "white",

      /**
       The model on which this view is based.
       @property { DG.SliderModel }
       */
      model: null,

      /**
       The model on which this view is based.
       @property { DG.CellLinearAxisView }
       */
      axisView: null,

      /**
       Subview that displays draggable thumb.
       @property { SC.ImageView }
       */
      thumbView: null,

      /**
       Subview that displays slider name and value.
       @property { SC.IconButton }
       */
      startButton: null,

      /**
       Subview that displays slider name and value.
       @property { SC.LabelView }
       */
      valueView: null,

      /**
       * SC.View styled to be vertical tic mark at end of axis
       */
      leftMarker: null,
      rightMarker: null,

      /**
       Set to true when user editing of valueView begins
       @property {Boolean}
       */
      userEdit: false,

      /**
       Stores the value of the slider before a mousedrag begins
       @property { Number }
       */
      _previousValue: 0,

      /**
       My model's value if there is one.
       @property { Number }
       */
      value: function() {
        return this.getPath('model.value');
      }.property('model').cacheable(),

      valueDidChange: function() {
        this.notifyPropertyChange('value');
      }.observes('*model.value'),

      /**
       The name of my model's global value
       @property { String }
       */
      name: function() {
        return this.getPath('model.name');
      }.property('model').cacheable(),

      nameDidChange: function() {
        this.notifyPropertyChange('name');
      }.observes('*model.name', '*model.content.name'),

      /**
       The screen coordinate of the model value.
       @property { Number }
       */
      thumbCoord: function() {
        var tValue = this.get('value'),
            tAxisView = this.get('axisView');
        return (SC.none( tValue) || SC.none( tAxisView)) ? null : tAxisView.dataToCoordinate( tValue);
      }.property('value'),

      thumbCoordDidChange: function() {
        this.notifyPropertyChange('thumbCoord');
      }.observes('*axisView.model.lowerBound', '*axisView.model.upperBound'),

      init: function() {
        // Notice that we are explicitly creating and laying out our subviews. This is because
        // when we tried doing it through childViews (the usual way), something about the dependencies
        // wouldn't work. (Might be worth figuring out.)
        arguments.callee.base.apply(this,arguments);
        DG.assert( !SC.none( this.get( 'model' ) ) );

        this.set('valueView',
            SC.LabelView.create(DG.MouseAndTouchView, {
              layout: { left: kButtonWidth + kGap, top: 3, bottom: kAxisHeight + 16 },
              classNames: 'dg-slider-label'.w(),
              isEditable: true,
              isTextSelectable: YES,
              exampleNode: null,
              // override MouseAndTouchView because we're not worried about enabling dragging in parentView
              mouseDown: function (evt) {
                if (!this.get('isMouseDown')) {
                  this.set('isMouseDown', YES);
                  this.set('isActive', YES);
                }
                return YES; // so we get other events
              },
              inlineEditorWillBeginEditing: function( iEditor, iValue, iEditable) {
                arguments.callee.base.apply(this,arguments);
                var tFrame = this.get('frame'),
                    kXGap = 4, kYGap = 5,
                    tOrigin = DG.ViewUtilities.viewToWindowCoordinates( { x: kXGap - 2, y: kYGap - 7 }, this);

                this.parentView.set('userEdit', true);

                // SC 1.10 introduced a new inline editor model in which
                // an 'exampleNode' is used to adjust inline editor style.
                var exampleNode = this.get('exampleNode');
                if(!exampleNode) {
                  var parentNode = this.getPath('parentView.layer');
                  exampleNode = this.get('layer').cloneNode(false);
                  exampleNode.id = exampleNode.id + "-clone";
                  exampleNode.style.visibility = 'hidden';
                  parentNode.appendChild(exampleNode);
                  this.set('exampleNode', exampleNode);
                }
                exampleNode.style.left = 0 + 'px';
                exampleNode.style.top = 9 + 'px';

                iEditor.set({ exampleElement: exampleNode,
                  exampleFrame: { x: tOrigin.x, y: tOrigin.y,
                    width: tFrame.width - 2 * kXGap,
                    height: tFrame.height - 2 * kYGap }});
              },
              doIt: function() {
                this.beginEditing();
              }
            }));
        this.appendChild( this.valueView );

        this.set( 'axisView', DG.CellLinearAxisView.create(
          { layout: { left: kWidth / 2, right: kWidth / 2, height: kAxisHeight, bottom: 0 },
            orientation: DG.GraphTypes.EOrientation.kHorizontal, isDropTarget: false } ) );
        this.appendChild( this.axisView );
        this.setPath( 'axisView.model', this.getPath( 'model.axis' ) );

        this._previousValue = this.getPath('model.value');

        this.set('thumbView',
            DG.IconButton.create( {
              layout: { bottom: kAxisHeight, width: kWidth, height: kThumbHeight },
              iconExtent: { width: kWidth, height: kThumbHeight },
              iconClass: 'dg-thumb-icon',
              classNames: 'dg-display-styles'.w(),
              toolTip: 'DG.SliderView.thumbView.toolTip', // "Start/stop animation"
              localize: true,
              touchPriority: true,
              mouseDown: function() { return NO; },
              touchStart: function() {
                return this.mouseDown();
              }
            }));
        this.appendChild( this.thumbView );

        this.set('startButton',

          DG.IconButton.create( {
            layout: {top: kGap + 2, left: 2, width: kButtonWidth + 2, height: kButtonHeight + 2},
            iconExtent: { width: kButtonWidth, height: kButtonHeight },
            iconClass: 'dg-play-icon',
            classNames: 'dg-display-styles'.w(),
            target: this,
            action: 'toggleAnimation',
            toolTip: 'DG.SliderView.startButton.toolTip', // "Start/stop animation"
            localize: true
          }));

        this.appendChild( this.startButton );

        this.set('leftMarker',
            SC.View.create({
              classNames: 'dg-slider-marker'.w(),
              layout: { left: 15, bottom: 12, width: 2, height: 15 }
            }));
        this.appendChild( this.leftMarker);
        this.set('rightMarker',
            SC.View.create({
              classNames: 'dg-slider-marker'.w(),
              layout: { right: 14, bottom: 12, width: 2, height: 15 }
            }));
        this.appendChild( this.rightMarker);
      },

      _destroy: function () {
        var controller = this.get('controller');
        if( controller)
          controller.stopAnimation();
        this.model.destroy(); // so that it can unlink observers
      },

      willDestroy: function() {
        console.log('SliderView.willDestroy');
        arguments.callee.base.apply(this,arguments);
      },

      destroy: function () {
        console.log('SliderView.destroy');
        this._destroy();
        arguments.callee.base.apply(this,arguments);
      },
      
      viewDidResize: function() {
        arguments.callee.base.apply(this,arguments);
        this.positionThumb();
      },

      /**
       * Use the value to position the thumbView.
       */
      positionThumb: function() {
        var tCoord = this.get('thumbCoord');
        if( DG.isFinite( tCoord)) {
          var thumbView = this.get('thumbView');
          if( thumbView)
            thumbView.adjust({left: Math.round( tCoord)});
        }
      }.observes('thumbCoord'),

      /**
       * Update the text that displays the value
       */
      updateValueView: function() {
        var tAxis = this.get('axisView'),
            tDelta = tAxis.coordinateToData( 1) - tAxis.coordinateToData( 0),
            tLogDelta = Math.log( tDelta) / Math.LN10,
            tMaxDecimals = Math.ceil( -tLogDelta),
            tModel = this.get('model'),
            tName = SC.none( tModel) ? '' : tModel.get('name'),
            tNumber = SC.none( tModel) ? '' : DG.Format.number().group('').fractionDigits( 0, tMaxDecimals)( tModel.get('value'));

        this.setPath('valueView.value', tName + ' = ' + tNumber);
      }.observes('thumbCoord', 'name'),

      mouseDown: function( iEvent) {
        DG.globalEditorLock.commitCurrentEdit();
        var tThumbFrame = this.getPath('thumbView.frame');
        tMouseDownInfo = {
          pagePoint: { x: iEvent.pageX, y: iEvent.pageY },
          viewPoint: DG.ViewUtilities.windowToViewCoordinates( { x: iEvent.pageX, y: iEvent.pageY }, this),
          thumbCoord: this.get('thumbCoord')
        };
        if( DG.ViewUtilities.ptInRect( tMouseDownInfo.viewPoint, tThumbFrame)) {
          this._previousValue = this.getPath('model.value');
          tDraggingThumb = true;
          return YES;  // We handled it
        }
        else
          // Let other event handling proceed - especially double-click
          return YES;
      },

      mouseDragged: function( iEvent) {
        if( tDraggingThumb) {
          var tUpperBound = this.getPath('axisView.model.upperBound'),
              tLowerBound = this.getPath('axisView.model.lowerBound'),
              tDelta = iEvent.pageX - tMouseDownInfo.pagePoint.x,
              tNewCoord = tMouseDownInfo.thumbCoord + tDelta,
              tNewValue;
          tNewValue = Math.min( Math.max( this.get('axisView').coordinateToData( tNewCoord),
              tLowerBound), tUpperBound);
          this.setPath('model.value', tNewValue);
        }
      },

      mouseUp: function() {
        if( tDraggingThumb) {
          var this_ = this;
          DG.UndoHistory.execute(DG.Command.create({
            name: 'slider.change',
            undoString: 'DG.Undo.slider.change',
            redoString: 'DG.Redo.slider.change',
            log: "sliderThumbDrag: { \"name\": \"%@\", \"newValue\": %@ }".fmt(this_.getPath('model.name'), this_.getPath('model.value')),
            _componentId: this_.getPath('controller.model.id'),
            _newValue: this_.getPath('model.value'),
            _prevValue: this_._previousValue,
            executeNotification: {
              action: 'notify',
              resource: 'component',
              values: {
                operation: 'change slider value',
                type: 'DG.SliderView'
              }
            },
            execute: function() {
              this_.get('model').encompassValue();
              if (this._newValue === this._prevValue) {
                this.causedChange = false;
              }
            },
            undo: function() {
              this_.setPath('model.value', this._prevValue);
              this_.get('model').encompassValue();
            },
            redo: function() {
              this_.setPath('model.value', this._newValue);
              this_.get('model').encompassValue();
            }
          }));
        }
        tDraggingThumb = false;
      },

      touchStart: function(evt){
        return this.mouseDown(evt);
      },
      touchEnd: function(evt){
        return this.mouseUp(evt);
      },
      touchesDragged: function( evt, touches) {
        return this.mouseDragged( evt);
      },

      toggleAnimation: function() {
        var controller = this.get('controller');
        if( controller)
          controller.toggleAnimation();
      },

      /**
       * Updates the start button appearance
       */
      isAnimatingDidChange: function() {
        var startButton = this.get('startButton');
        if( !this.getPath('controller.isAnimating')) {
          startButton.set('iconClass', 'dg-play-icon');
        }
        else {
          startButton.set('iconClass', 'dg-pause-icon');
        }
      }.observes('*controller.isAnimating'),

      /**
       * Parses the user-edited contents of valueView. If it can identify a variable name and value,
       * the global value name and value will be set accordingly.
       */
      valueViewWasEdited: function() {
        // regular expression for matching 'variable = value'
        // TODO: Do better with white space
        // TODO: Handle scientific notation? Thousands separators? Internationalization?
        var kMatchExp = /^\s*([a-zA-Z_][\w]*)\s*=\s*([+\-]?[0-9.]+)/,
            tResult, tNewValue, tNewName;
        // We only want to parse the expression if the user actually edited it
        if( this.get('userEdit')) {
          var tNewString = this.getPath('valueView.value');
          tNewString = tNewString.replace('\u2212', '-');
          this.set('userEdit', false);
          tResult = kMatchExp.exec( tNewString);
          DG.logUser("sliderEdit: { expression: '%@', result: %@ }",
                                      tNewString, !SC.none( tResult) ? "success" : "failure");
          if( !SC.none( tResult)) {
            tNewValue = parseFloat( tResult[ 2]);
            tNewName = tResult[ 1];
            this.setPathIfChanged('model.value', tNewValue);
            this.setPathIfChanged('model.name', tNewName);
            this.get('model').encompassValue();
          }
          else
            this.updateValueView();
        }
      }.observes('.valueView.value')

    };
  }()) );


/* >>>>>>>>>> BEGIN source/components/text/file_import_view.js */
// ==========================================================================
//                            DG.FileImportView
//
//  Author:   Jonathan Sandoe
//
//  Copyright (c) 2014-2015 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/**
  @class DG.FileImportView

  A file import element presents a interactive element for selecting a
  file from the local file system for upload.

  @extends SC.TextFieldView
 */
DG.FileImportView = SC.TextFieldView.extend(
  /** @scope SC.TextFieldView.prototype */ {

  classNames: ['dg-file-import-view'],


  // ..........................................................
  // PROPERTIES
  //

  /**
    When `applyImmediately` is turned on, every keystroke will set the value
    of the underlying object. Turning it off will only set the value on blur.

    @type String
    @default NO
   */
  applyImmediately: NO,

  /**
    The type attribute of the input.

    @type String
    @default "file"
   */
  type: 'file',


  /**
    Whether the browser should automatically correct the input.

    When `autoCorrect` is set to `null`, the browser will use
    the system defaults.

    @type Boolean
    @default YES
   */
  autoCorrect: NO,

  /**
    Whether the browser should automatically capitalize the input.

    When `autoCapitalize` is set to `null`, the browser will use
    the system defaults.

    @type Boolean
    @default YES
   */
  autoCapitalize: NO,

  /**
    Whether to show the hint while the field has focus.
    If `YES`, it will disappear as soon as any character is in the field.

    @type Boolean
    @default YES
   */
  hintOnFocus: NO,

  /**
    This property will enable disable HTML5 spell checking if available on the
    browser. As of today Safari 4+, Chrome 3+ and Firefox 3+ support it.

    @type Boolean
    @default YES
   */
  spellCheckEnabled: NO,
  /**
     Whether to render a border or not.

     @type Boolean
     @default YES
  */
  shouldRenderBorder: NO,

    /**
     * Callback invoked when the view focuses.
      */
  stateChangeAction: function () {
    if (this.action && this.get('isEditing')) {
      this.action();
    }
  }.observes('isEditing'),

  files: function() {
    var v =this.$input().prop('files');
    if (v) {
      console.log('Files: ' + Array.prototype.map.call(v, function(f) {return f.name;}));
    }
    return v;
  }.property()

});

/* >>>>>>>>>> BEGIN source/components/text/text_controller.js */
// ==========================================================================
//                          DG.TextComponentController
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('controllers/component_controller');

/** @class

  Coordinating controller for the DG text component.

  @extends SC.Object
*/
DG.TextComponentController = DG.ComponentController.extend(
/** @scope DG.TextComponentController.prototype */ {

  /**
   *  The "raw" contents of the text editor.
   *  This property is bound in (viewDidChange) to the 'editorValue' property of the DG.TextView.
   *  Setting this property to null causes the editor to use 'theText'/'value' property instead.
   *  This property changes frequently since it includes selection/focus information.
   *  @property {String}
   */
  theValue: null,

  /**
   *  The serializable contents of the text editor.
   *  This property is bound in (viewDidChange) to the 'value' property of the DG.TextView.
   *  This property changes only when the content changes as it does not contain selection.
   *  @property {String}
   */
  theText: function (k, v) {
    if (!SC.none(v)) {
      // this gets called when the editView changes the value because of the binding
      this.setPath('model.content.text', v);
    }
    return this.getPath('model.content.text');
  }.property(),


  theTextDidChange: function () {
    this.notifyPropertyChange('theText');
  }.observes('model.content.text'),

  /**
   *  Listen for the text to be changed via API and handle it appropriately.
   */
  apiTextDidChange: function () {
    var apiText = this.getPath('model.content.apiText');
    if (!SC.none(apiText)) {
      try {
        this.setTheText(JSON.parse(apiText));
      } catch(ex) {
        this.setTheText(apiText);
      }
      this.setPath('model.content.apiText', null);
    }
  }.observes('model.content.apiText'),

  /**
   *  Pushes its argument to the editor's content. This is accomplished by
   *  setting the editor's 'value' property (via binding) to the desired
   *  value and then setting the editor's 'editorValue' property (also via
   *  binding) to null so that the editor will use the 'value' property.
   *  @param {Object} value -- The editor value to push to the editor
   */
  setTheText: function(value) {
    this._isUpdatingText = true;
    this.beginPropertyChanges();
    this.set('theText', value);
    // clearing 'theValue' tells editView to use 'theText'
    this.set('theValue', null);
    this.endPropertyChanges();
    this.invokeLater(function() {
      SC.run(function() {
        this._isUpdatingText = false;
      }.bind(this));
    });
  },

  previousValue: null,
  _session: null,

  /**
   *  Returns the object to be JSONified for storage.
   *  @returns  {Object}
   */
  createComponentStorage: function() {
    var theText = this.get('theText'),
        theStorage = {};
    if( !SC.empty( theText)) {
      if (typeof theText === 'string') {
        theStorage.text = theText;
      } else {
        theStorage.text = JSON.stringify(theText);
      }
    }
    return theStorage;
  },

  /**
   *  Copies the contents of iComponentStorage to the model.
   *  @param {Object} iComponentStorage -- Properties restored from document.
   *  @param {String} iDocumentID --       ID of the component's document.
   */
  restoreComponentStorage: function( iComponentStorage, iDocumentID) {
    arguments.callee.base.apply(this,arguments);
    var theText = iComponentStorage.text || iComponentStorage.apiText || "",
        parsed;
    try {
      parsed = JSON.parse(theText);
      // if it doesn't look like a Slate value, treat as plain text
      if (!parsed || !parsed.object || (parsed.object !== "value"))
        parsed = theText;
    }
    catch(e) {
      // if it's not JSON, treat as plain text
      parsed = theText;
    }
    this.setTheText(parsed);
    this.set('previousValue', parsed);
  },

  onTextUpdate: function() {
    if (this._isUpdatingText) return;

    var value = JSON.stringify(this.get("theText") || "");
    this._session = this._session || Math.random();

    function parseValue(v) {
      var parsed = "";
      try {
        parsed = JSON.parse(v);
      }
      catch(e) {
        parsed = "";
      }
      return parsed;
    }

    DG.UndoHistory.execute(DG.Command.create({
      name: 'textComponent.edit',
      undoString: 'DG.Undo.textComponent.edit',
      redoString: 'DG.Redo.textComponent.edit',
      //log: "Edited text component: '%@'".fmt(value),
      _componentId: this.getPath('model.id'),
      _controller: function() {
        return DG.currDocumentController().componentControllersMap[this._componentId];
      },
      _reduceKey: 'textComponent.edit' + this._session,
      executeNotification: {
        action: 'notify',
        resource: 'component',
        values: {
          operation: 'edit text',
          type: 'DG.TextView'
        }
      },
      execute: function () {
        this._beforeStorage = this._controller().get('previousValue');
        this._afterStorage = value;
        this._controller().set('previousValue', value);
      },
      undo: function () {
        // can no longer merge once it's been undone
        this._reduceKey = Math.random();
        this._controller().setTheText(parseValue(this._beforeStorage));
        this._controller().set('previousValue', this._beforeStorage);
      },
      redo: function () {
        this._controller().setTheText(parseValue(this._afterStorage));
        this._controller().set('previousValue', this._afterStorage);
      },
      reduce: function(previous) {
        if (previous._reduceKey === this._reduceKey) {
          this._beforeStorage = previous._beforeStorage;
          return this;
        }
      }
    }));
  }.observes('theText'),

  commitEditing: function() {
    // prevents further undo merging
    this._session = null;
    DG.currDocumentController().notificationManager.sendNotification({
      action: 'notify',
      resource: 'component',
      values: {
        operation: 'commitEdit',
        type: this.getPath('model.type'),
        id: this.getPath('model.id'),
        title: this.getPath('model.title'),
        text: JSON.stringify(this.get("theText") || "")
      }
    });
  },

  willCloseComponent: function() {
    arguments.callee.base.apply(this,arguments);
    this.commitEditing();
  },

  getEditView: function() {
    return this.getPath('view.containerView.contentView.editView');
  },

  /**
   *  Called when the view is connected to the controller.
   */
  viewDidChange: function() {
    var editView = this.getEditView();
    if (editView) {
      // set the initial value
      var theText = this.get('theText');
      theText && editView.set('value', theText);
      // bind the raw and serializable properties
      editView.bind('editorValue', this, 'theValue');
      editView.bind('value', this, 'theText');
    }
  }.observes('*view.containerView.contentView')

});

/* >>>>>>>>>> BEGIN source/components/text/text_model.js */
// ==========================================================================
//                            DG.TextModel
//
//  Author:   Kirk Swenson
//
//  Copyright (c)2020 The Concord Consortium
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class  DG.TextModel

 @extends SC.Object
 */
DG.TextModel = SC.Object.extend(
  /** @scope DG.TextModel.prototype */
  {
    /**
     The serialized content of the text object. Prior to build 0535 this was simple text.
     As of 0535 it is a JSON representation of the rich text content. If a newer build
     encounters plain text here it will be converted to the rich text format.
     This build is mapped to the 'theText' function property of the DG.TextController,
     which is in turn mapped via SproutCore binding to the 'value' property of DG.TextView.
     @property { Object }
     */
    text: null,

    _apiText: null,

    /**
     This property is intended for use by the data interactive (plugin) API. When referenced
     it returns the contents of the local '_apiText' property, if one has been set, or the
     'text' property otherwise. When written it notifies that it has changed, which triggers
     the DG.TextController to synchronize this `apiText` value to its 'theText' and 'theValue'
     properties in a way that signals the DG.TextView to load the new value.
     @property { Object }
     */
    apiText: function(k, v) {
      if (v != null) {
        this._apiText = v;
      }
      return this._apiText || this.get('text');
    }.property(),

    init: function() {
      arguments.callee.base.apply(this,arguments);
    }

  });

/* >>>>>>>>>> BEGIN source/components/text/text_view.js */
// ==========================================================================
//                            DG.TextView
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/* global ReactDOM, SlateEditor */

/** @class  DG.TextView

 A wrapper for a TextFieldView that gives user a place to type notes.

 @extends SC.View
 */
DG.TextView = SC.View.extend((function() {
    /** @scope DG.TextView.prototype */

    var kWantsEventsClasses = ' dg-wants-mouse dg-wants-touch dg-wants-keys dg-wants-select';

    return {
      backgroundColor: 'white',

      childViews: ['editView'],
      editView: SC.View.design({
        // without 'allow-select' Safari prevents focusing the editor
        classNames: ['dg-text-view-edit-view', 'allow-select'],

        layout: { left: 2, right: 2, top: 2, bottom: 2 },

        // editor instance
        _editor: null,

        // "raw" editor value including selection, etc.
        // bound to TextController 'theValue' property
        editorValue: null,

        // editor document content, suitable for storage
        // property name retained from pre-slate usage
        // bound to TextController 'theText' property
        value: null,

        _slatePlugins: null,

        init: function() {
          arguments.callee.base.apply(this,arguments);

          // Slate plugin example - plugins can extend editor behavior, e.g. by
          // implementing a new format type for displaying a CODAP global value.
          var onCommandPlugin = {
            onCommand: function(command, editor, next) {
              var result = next();
              // console.log("TextView.onCommandPlugin", "type:", command.type);
              return result;
            }.bind(this)
          };
          this._slatePlugins = [onCommandPlugin];
        },

        /**
         * Retrieve the "raw" value to be passed to the underlying editor. Usually,
         * this will be the 'editorValue' property most recently saved by the editor
         * itself, but when restoring from a saved document or with undo/redo this
         * can be serialized content from an external source, including plain text
         * if dealing with legacy document content.
         */
        getValueForEditor: function() {
          // use full slate value if we have one
          var editorValue = this.get('editorValue');
          if (editorValue) return editorValue;
          var exchangeValue = this.get('value');
          // convert from string value if necessary
          if (typeof exchangeValue === "string") return SlateEditor.textToSlate(exchangeValue);
          // start with empty value if appropriate
          if (!exchangeValue) return SlateEditor.textToSlate("");
          // deserialize serialized content
          return SlateEditor.deserializeValue(exchangeValue);
        },

        /**
         * Whether the underlying editor selection model is currently focused.
         */
        isEditorFocused: function() {
          return !!(this._editor && this._editor.value && this._editor.value.selection &&
                    this._editor.value.selection.isFocused);
        },

        /**
         * Re-render when the editor value changes.
         */
        editorValueDidChange: function() {
          this.renderEditor();
          this.renderToolbar();
        }.observes('editorValue'),

        getComponentView: function() {
          return this.getPath('parentView.parentView.parentView');
        },

        isComponentSelected: function() {
          return this.getPath('parentView.parentView.parentView.isSelected');
        },

        /**
         * Synchronize editor focus/blur with component selection
         */
        isComponentSelectedDidChange: function() {
          var isComponentSelected = this.isComponentSelected(),
              isEditingTitlebar = this.getPath('parentView.parentView.titlebar.userEdit'),
              isEditorFocused = this.isEditorFocused();
          if (!isComponentSelected && isEditorFocused) {
            this._editor && this._editor.blur();
          }
          else if (isComponentSelected && !isEditingTitlebar && !isEditorFocused) {
            this._editor && this._editor.focus();
          }
          // renderToolbar renders the inspector panel, if not visible, but
          // hides it if it is.
          this.renderToolbar();
        }.observes('.parentView.parentView.parentView.isSelected'),

        didCreateLayer: function() {
          this._controller = this.getPath('parentView.parentView.parentView.controller');

          this.reactEditorDiv = document.createElement('div');
          this.reactEditorDiv.className = 'dg-text-view-react-root' + kWantsEventsClasses;
          this.get('layer').appendChild(this.reactEditorDiv);
          this.reactToolbarDiv = document.createElement('div');
          this.reactToolbarDiv.className = 'dg-text-view-react-portal';
          this.reactToolbarDiv.style.position = "absolute";
          DG.mainPage.mainPane.scrollView.contentView.get('layer').appendChild(this.reactToolbarDiv);
          this.reactModalDiv = document.createElement('div');
          this.reactModalDiv.className = 'dg-text-view-modal-portal';
          DG.mainPage.mainPane.scrollView.contentView.get('layer').appendChild(this.reactModalDiv);
          this.renderEditor();
          this.renderToolbar();
        },

        willDestroyLayer: function() {
          ReactDOM.unmountComponentAtNode(this.reactEditorDiv);
          ReactDOM.unmountComponentAtNode(this.reactToolbarDiv);
          DG.mainPage.mainPane.scrollView.contentView.get('layer').removeChild(this.reactToolbarDiv);
        },

        /**
         * Keep toolbar positioned alongside component.
         */
        positionToolbar: function() {
          var componentView = this.getComponentView(),
              frame = componentView && componentView.computeFrameWithParentFrame();
          if (frame && this.reactToolbarDiv) {
            this.reactToolbarDiv.style.left = (frame.x + frame.width) + "px";
            this.reactToolbarDiv.style.top = frame.y + "px";
          }
        }.observes('.parentView.parentView.parentView.frame'),

        renderToolbar: function() {
          var props = {
                modalPortalRoot: this.reactModalDiv,
                modalCoverClassName: 'codap-ccrte-cover' + kWantsEventsClasses,
                modalDialogClassName: 'codap-ccrte-modal' + kWantsEventsClasses,
                className: 'codap-ccrte-toolbar' + kWantsEventsClasses,
                orientation: 'vertical',
                colors: {
                  buttonColors: { fill: "#ffffff", background: "#177991" },
                  selectedColors: { fill: "#177991", background: "#72bfca" }
                },
                buttonsPerRow: 9,
                order: [
                    //column 1
                  "fontDecrease",
                  "bold",
                  "underlined",
                  "superscript",
                  "ordered-list",
                  "heading1",
                  "heading3",
                  "color",
                  "link",

                    //column 2
                  "fontIncrease",
                  "italic",
                  "deleted",
                  "subscript",
                  "bulleted-list",
                  "heading2",
                  "block-quote",
                  "image"
                ],
                editor: this._editor,
                show: this.isComponentSelected()
              };
          ReactDOM.render(DG.React.SlateToolbar(props), this.reactToolbarDiv);
        },

        renderEditor: function() {
          var value = this.getValueForEditor();
          if (value && !this.get('editorValue')) {
            // sync 'value' => 'editorValue'
            this.set('editorValue', value);
          }
          var props = {
                className: 'codap-ccrte-editor',
                plugins: this._slatePlugins,
                value: value,
                history: false,
                onEditorRef: function(editor) {
                  this._editor = editor;
                }.bind(this),
                onValueChange: function(value) {
                  SC.run(function() {
                    this.set('editorValue', value);
                  }.bind(this));
                }.bind(this),
                onContentChange: function(content) {
                  SC.run(function() {
                    this.set('value', SlateEditor.serializeValue(content));
                  }.bind(this));
                }.bind(this),
                onFocus: function() {
                  if (!this.isComponentSelected()) {
                    SC.run(function() {
                      // Apparently the mouse down is captured, so we need to
                      // manually close any inspector panels that are open.
                      DG.mainPage.mainPane.hideInspectorPicker();
                      var componentView = this.getComponentView();
                      componentView && componentView.select();
                    }.bind(this));
                  }
                }.bind(this),
                onBlur: function() {
                  SC.run(function() {
                    // emulate SC.View's 'commitOnBlur' property
                    this.commitEditing();
                  }.bind(this));
                }.bind(this)
              };
          ReactDOM.render(DG.React.SlateEditor(props), this.reactEditorDiv);
        },

        commitEditing: function () {
          this._controller.commitEditing();
        },

        /**
         * Prevent drop into text edit area from propagating to the CODAP workspace
         * where it would be interpreted as a CSV drop.
         * @param ev {MouseEvent}
         */
        dataDragDropped: function (ev) {
          var dt = ev.dataTransfer;
          if (dt && !dt.files.length) {
            ev.stopPropagation();
          } else {
            return false;
          }
        }
      }),

      defaultFirstResponder: function () {
        return this.get('editView');
      }.property(),

      /**
       * We've animated to our initial position and along the way lost editing focus.
       */
      didReachInitialPosition: function() {
        this.beginEditing();
      },

      beginEditing: function() {
        setTimeout(function() {
          var editView = this.get('editView'),
              editor = editView && editView._editor;
          editor && editor.focus();
        }.bind(this));
      }

    };
  })()
);

/* >>>>>>>>>> BEGIN source/config.js */
// ==========================================================================
//                               DG.config
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

// This stores data which is specific to each development environment.  Variables which cannot be stored because of
// one reason or another(e.g. security), are to be replaced here.
DG.config = (function() {
  return {
  };
}());

/**
  @private
  Map from feature ID (e.g. 'docSavePermissions') to a function
  which returns a boolean value indicating whether the specified
  feature is supported in this configuration. Feature functions
  can use features of the URL, the logged-in user, debug state,
  etc. to determine whether a given feature should be supported.
  Clients should call the DG.supports() function rather than
  accessing this map directly.
 */
DG.supportFuncs = {

  /**
    Enable case table column header menus.
   */
  caseTableHeaderMenus: function() {
    return true;
  }

};

/**
  Returns true if the specified feature is supported in the current
  configuration, false otherwise.
  @param  {String}  iFeatureID -- e.g. 'docSavePermissions'
  @returns {Boolean}  True if the feature is supported, false otherwise
 */
DG.supports = function( iFeatureID) {
  var featureFunc = DG.supportFuncs[ iFeatureID];
  return featureFunc ? featureFunc() : false;
};

/* >>>>>>>>>> BEGIN source/controllers/document_helper.js */
// ==========================================================================
//                        DG.DocumentHelper
//
//  Author:   Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

///* global Promise */
/**
 * @class DocumentHelper
 *
 * Coordinates streaming of documents and document elements. Deals with documents
 * as streamable entities in contrast to the Document Controller that
 * provides operational coordination of document elements. This class addresses
 * how to get documents in and out of CODAP predictably and the Document
 * Controller deals with Documents while they are being presented and
 * interacted with within CODAP.
 *
 * This class, at this point, has no state. It
 * functions, more or less, as a mixin to the App Controller, providing
 * a logically related collection of utility methods.
 *
 * @extends SC.Object
 */

DG.DocumentHelper = SC.Object.extend(
    /** @scope DG.DocumentHelper.prototype */ {

      /**
       * Tests the JSON text for validity as a possible document.
       *
       * The following assertions are tested:
       *
       * (1) The document is valid JSON. that is: it parses correctly
       * (2) The document looks like a valid CODAP document. It has all mandatory
       * top level elements and no unexpected top level elements.
       * (3) all internal links can be resolved.
       *
       * @param    {String}    iDocument -- The JSON-formatted document text
       * @returns  {[String]}   An array of error messages, zero length, if none.
       */
      isValidJsonDocument: function (iDocument) {
        function visit(key, value, fn) {
          var rtn = fn(key, value);
          if (rtn !== false) {
            if (Array.isArray(value)) {
              value.forEach(function (item) {
                visit(key, item, fn);
              });
            } else if (typeof value === 'object') {
              DG.ObjectMap.forEach(value, function (key, item) {
                visit(key, item, fn);
              });
            }
          }
        }

        function validateInternalRefs(iDocument) {
          var parts = subDocs.copy(false);
          var symbols = [];
          var references = [];
          parts.unshift(iDocument);
          parts.forEach(function (documentPart) {
            visit('doc', documentPart, function (key, value) {
              if (key === 'guid') {
                // store guids in symbol table
                symbols.push(Number(value));
                return true;
              } else if (key === '_links_') {
                // store links as references
                visit(key, value, function (k, v) {
                  if (k === 'id') {
                    references.push(Number(v));
                  }
                  return true;
                });
                return false;
              } else if (key === 'parent') {
                // store parents as references
                references.push(Number(value));
                return true;
              } else if (key === 'contextStorage') {
                // context storage is private to data interactive
                return false;
              }

            });
          });
          references.forEach(function (ref) {
            // verify link is resolved
            if (symbols.indexOf(Number(ref)) < 0) {
              errors.push('DG.AppController.validateDocument.unresolvedID'.loc(ref));
            }
          });
        }

        var expectedProperties = [
          'appBuildNum',
          'appName',
          'appVersion',
          'changeCount',
          'components',
          'contexts',
          'globalValues',
          'guid',
          'metadata',
          'name',
          '_permissions',
          '_openedFromSharedDocument' // this is an annotation we may create in
                                      // CodapCommonStorage
        ];
        var requiredProperties = [
          'name'
        ];
        var errors = [];
        var doc;
        var subDocs = [];

        if (typeof iDocument === 'string') {
          try {
            doc = JSON.parse(iDocument);
          } catch (ex) {
            errors.push('DG.AppController.validateDocument.parseError'.loc(ex));
          }
        } else {
          doc = iDocument;
        }

        if (doc) {
          requiredProperties.forEach(function (prop) {
                if (!doc.hasOwnProperty(prop)) {
                  errors.push('DG.AppController.validateDocument.missingRequiredProperty'.loc(prop));
                }
              }
          );
          DG.ObjectMap.keys(doc).forEach(function (prop) {
                if (expectedProperties.indexOf(prop) < 0) {
                  // log unexpected properties but don't fail to open
                  DG.log('DG.AppController.validateDocument.unexpectedProperty'.loc(prop));
                }
              }
          );
          validateInternalRefs(doc);
        }
        DG.log('Document validation: ' + (errors.length ? JSON.stringify(errors) : 'No Errors'));
        return errors;
      },

      /**
       * We create a very simple document as a wrapper on the provided Data
       * Interactive URL and open it.
       *
       * @param iURL - URL of data interactive
       * @returns {DG.Document}
       */
      createNewDocumentWithDataInteractives: function (iURLs) {
        var tComponents = (iURLs || [])
            .map(function (url) {
              return {
                "type": "DG.GameView",
                "componentStorage": {
                  "currentGameName": "",
                  "currentGameUrl": url
                }
              };
            });
        var tDoc = {
          name: 'DG.Document.defaultDocumentName'.loc(),
          guid: 1,
          isNewDocument: true, // mark this document as not having been saved and restored.
                               // this property will not be persisted with the document.
          components: tComponents,
          appName: DG.APPNAME,
          appVersion: DG.VERSION,
          appBuildNum: DG.BUILD_NUM,
          globalValues: []
        };

        return DG.Document.createDocument(tDoc);
      },

      updateDataContext: function (iResources, iValues) {
        var context = iResources.dataContext;
        if (context) {
          ['managingController', 'title', 'description', 'preventReorg', 'metadata', 'rerandomize', 'sort']
              .forEach(function (prop) {
                var existingMetadata;
                if (!SC.none(iValues[prop])) {
                  if (prop === 'metadata') {
                    if (typeof iValues[prop] === 'object') {
                      existingMetadata = context.getPath('model.metadata') || {};
                      context.setPath('model.metadata', Object.assign(existingMetadata, iValues[prop]));
                    }
                  } else if (prop === 'rerandomize' && !!iValues[prop]) {
                    context.doRerandomizeAll();
                  } else if (prop === 'sort') {
                    var controllersMap = DG.currDocumentController().get('componentControllersMap');
                    var tableAdapters = [];
                    for (var key in controllersMap) {
                      if (controllersMap[key].hasOwnProperty('caseTableAdapters')) {
                        tableAdapters.push(controllersMap[key]);
                        break;
                      }
                    }
                    tableAdapters.forEach(function (tableController) {
                      var tableContext = tableController.get('dataContext');
                      var attribute = typeof(iValues[prop].attr) === "string"
                                        ? context.getAttributeByName(iValues[prop].attr).id
                                        : iValues[prop].attr;
                      if (tableContext.get('id') === context.get('id')) {
                        var isDescending = iValues[prop].isDescending;
                        tableController.sortAttribute(attribute, isDescending);
                      }
                    });
                  }
                  else {
                    context.set(prop, iValues[prop]);
                  }
                }
              });
        }
        return {
          success: true
        };
      },

      deleteCollection: function( iResources, iRequesterID) {
        var context = iResources.dataContext;
        var collection = iResources.collection;

        if (!collection) {
          return {success: false, values: {error: 'Collection not found'}};
        }

        return context.applyChange({
          operation: 'deleteCollection',
          collection: collection,
          requester: iRequesterID
        });
      },

      createCollection: function(iResources, iValues, iID) {
        // returns a collection for the appropriate parent name, if any.
        function mapParent (context, parentName) {
          var parentKey;
          var collections;
          var collection;

          if (SC.none(parentName)) {
            collections = context.get('collections');
            if (collections && collections.length > 0) {
              parentKey = collections[collections.length - 1].get('id');
            }
          } else if (typeof parentName === 'number') {
            parentKey = parentName;
          } else if (parentName === '_root_') {
            parentKey = null;
          } else {
            collection = context.getCollectionByName(parentName);
            parentKey = collection ? collection.get('id') : null;
          }
          return (!SC.none(parentKey))? context.getCollectionByID(parentKey).collection: null;
        }

        // returns a success indicator and ids.
        function createOneCollection(iContext, iCollectionSpec, iContextID) {
          var change = {
            operation: 'createCollection',
            properties: iCollectionSpec,
            attributes: ( iCollectionSpec && iCollectionSpec.attributes ),
            requester: iContextID
          };
          iCollectionSpec.parent = mapParent(iContext, iCollectionSpec.parent);
          var changeResult = iContext.applyChange(change);
          var success = (changeResult && changeResult.success);
          var ids = changeResult.collection && {
            id: changeResult.collection.get('id'),
            name: changeResult.collection.get('name')
          };
          return {
            success: success,
            values: ids
          };
        }

        var context = iResources.dataContext;
        var success = true;
        var collectionIdentifiers = [];

        if (!context) {
          return {success: false, values: {error: "no context"}};
        }

        if (!Array.isArray(iValues)) {
          iValues = [iValues];
        }

        iValues.every(function (iCollectionSpec) {
          var rslt = createOneCollection(context, iCollectionSpec, iID);
          success = success && rslt.success;
          if (success) {
            collectionIdentifiers.push(rslt.values);
          }
          return success;
        });

        return {success: success, values: collectionIdentifiers};
      },

      applyChangeAndProcessResult: function(context, change, metadata) {
        if (metadata && metadata.dirtyDocument === false)
          change.dirtyDocument = false;
        var changeResult = context.applyChange(change),
            resultAttrs = changeResult && changeResult.attrs,
            returnAttrs = DG.DataInteractiveUtils.mapAttributeProperties(resultAttrs, change.attrPropsArray),
            returnResult = {success: changeResult && changeResult.success};
        if (returnAttrs)
          returnResult.values = { attrs: returnAttrs };
        return returnResult;
      },

      /**
       *
       * @param iResources
       * @param iValues
       * @param iMetadata
       */
      createAttribute: function (iResources, iValues, iMetadata, iRequesterID) {
        if (!iResources.dataContext) {
          return {success: false, values: {error: "no context"}};
        }
        if (!iResources.collection) {
          return {success: false, values: {error: 'Collection not found'}};
        }
        var context = iResources.dataContext;
        var attrSpecs = SC.clone(Array.isArray(iValues) ? iValues : [iValues]);
        if (attrSpecs.some(function(spec) { return !spec.name; })) {
          return {success: false, values: {error: "Create attribute: name required"}};
        }
        attrSpecs.forEach(function(attrSpec) {
          attrSpec.clientName = attrSpec.name;
          attrSpec.name = context.canonicalizeName(attrSpec.name + ' ');
        });
        var change = {
          operation: 'createAttributes',
          collection: context.getCollectionByID( iResources.collection.get('id')),
          attrPropsArray: attrSpecs,
          requester: iRequesterID,
          position: iResources.position
        };
        return this.applyChangeAndProcessResult(context, change, iMetadata);
      },

      /**
       *
       * @param iResources
       * @param iValues
       * @param iMetadata
       */
      updateAttribute: function (iResources, iValues, iMetadata) {

        var context = iResources.dataContext;
        if (!iResources.collection) {
          return {success: false, values: {error: 'Collection not found'}};
        }
        if (!iResources.attribute) {
          return {success: false, values: {error: 'Attribute not found'}};
        }
        if (!iValues.id && iResources.attribute.id)
          iValues.id = iResources.attribute.id;
        if (!iValues.name && iResources.attribute.name)
          iValues.name = iResources.attribute.name;
        else if (iValues.name) {
          iValues.clientName = iValues.name;
          iValues.name = context.canonicalizeName(iValues.name + ' ');
        }
        var change = {
          operation: 'updateAttributes',
          collection: iResources.collection,
          attrPropsArray: [iValues],
          requester: this.get('id')
        };
        return this.applyChangeAndProcessResult(context, change, iMetadata);
      },

      updateAttributeLocation: function(iResources, iValues, iMetadata) {
        var context = iResources.dataContext;
        if (!context) {
          return {
            success: false,
            values: {error: 'context not found'}
          };
        }
        var change = {
          operation: 'moveAttribute',
          requester: this.get('id'),
          attr: iResources.attributeLocation
        };
        if (iValues && !SC.none(iValues.collection)) {
          change.toCollection = context.getCollectionByName(iValues.collection) ||
              context.getCollectionByID(iValues.collection);
          if (!change.toCollection) {
            return {
              success: false,
              values: {error: 'Target collection not found'}
            };
          }
        }
        if (iValues && !SC.none(iValues.position)) {
          change.position = iValues.position;
        }
        return context.applyChange(change);
      },

      createCases: function( iResources, iValues, iRequesterID) {

        function convertDate( iValue) {
          if (iValue instanceof Date) {
            iValue.valueOf = function () {
              return Date.prototype.valueOf.apply(this) / 1000;
            };
          }
        }

        function fixDates(iCase) {
          if( Array.isArray( iCase.values)) {
            iCase.values.forEach(function (iValue) {
              convertDate( iValue);
            });
          }
          else if ( typeof iCase.values === 'object') {
            DG.ObjectMap.forEach( iCase.values, function( iKey, iValue) {
              convertDate( iValue);
            });
          }
        }

        function createOrAppendRequest(iCase) {
          fixDates(iCase);
          var parent = iCase.parent;
          var values = iCase.values;
          var req = requests.find(function (request) {
            return request.properties.parent === parent;
          });
          if (!req) {
            req = {
              operation: 'createCases',
              collection: collection,
              properties: {
                parent: parent
              },
              values: [],
              requester: requester
            };
            requests.push(req);
          }
          req.values.push(values);
        }
        if (!iResources.collection) {
          return {success: false, values: {error: 'Collection not found'}};
        }
        // ------------------createCases-----------------
        var success = true;
        var context = iResources.dataContext;
        var collection = iResources.collection;
        var cases = Array.isArray(iValues)?iValues: [iValues];
        var IDs = [];
        var requester = iRequesterID;
        var requests = [];

        // We wish to minimize the number of change requests submitted,
        // but create case change requests are not structured like cases.
        // we must reformat the Plugin API create/case to some number of
        // change requests, one for each parent referred to in the create/case
        // object.
        cases.forEach(createOrAppendRequest);
        requests.forEach(function (req) {
          var changeResult = context.applyChange(req);
          var success = success && (changeResult && changeResult.success);
          var index;
          if (changeResult.success) {
            for (index = 0; index < changeResult.caseIDs.length; index++) {
              var caseid = changeResult.caseIDs[index];
              var itemid = (index <= changeResult.itemIDs.length) ? changeResult.itemIDs[index] : null;
              IDs.push({id: caseid, itemID: itemid});
            }
          }
        });
        return {success: success, values: IDs};
      },

      /**
       * The current document will be made to conform to the information in the given JSON object.
       * @param iDocObject {Object}
       * @return {boolean}
       */
      updateDocument: function (iDocObject, updateDataContextFunc) {
        var tDocController = DG.currDocumentController(),
            tComponentControllers = tDocController.get('componentControllersMap') || [],
            tComponentsStorage = iDocObject.components || [];

        function notifyDocumentChange(operation) {
          tDocController.notificationManager.sendNotification({
            action: 'notify',
            resource: 'documentChangeNotice',
            values: {
              operation: operation
            }
          }, function (response) {
            DG.log('Sent notification for document change: ' + operation);
            DG.log('Response: ' + JSON.stringify(response));
          });
        }

        function deleteComponentsNotInDocObject() {
          var tIDsOfStoredComponents = tComponentsStorage.map(
              function (iCompStorage) {
                return Number(iCompStorage.guid);
              });
          DG.ObjectMap.forEach(tComponentControllers, function (iGuid, iController) {
            var tFoundStorage = tIDsOfStoredComponents.indexOf(Number(iGuid)) >= 0;
            if (!tFoundStorage) {
              DG.closeComponent(iGuid);
            }
          });
        }

        function deleteDataContextsNotInDocObject() {
          var tExistingContexts = tDocController.get('contextRecords') || [],
              tIDsOfStoredContexts = iDocObject.contexts ? iDocObject.contexts.map(
                  function (iContext) {
                    return Number(iContext.guid);
                  }) : [];
          DG.ObjectMap.forEach(tExistingContexts, function (iGuid, iContext) {
            var tFoundStorage = tIDsOfStoredContexts.indexOf(Number(iGuid)) >= 0;
            if (!tFoundStorage) {
              tDocController.destroyDataContext(iGuid);
            }
          });
        }

        function createOrUpdateDataContexts() {
          var tExistingContexts = tDocController.get('contextRecords'),
              tNewDocContexts = iDocObject.contexts || [];  // The ones we're moving toward

          tNewDocContexts.forEach(function (iNewDocContext) {
            var tDocContextID = iNewDocContext.guid,
                tExistingDataContextRecord;
            DG.ObjectMap.forEach(tExistingContexts, function (iGuid, iContext) {
              if (Number(iGuid) === tDocContextID)
                tExistingDataContextRecord = iContext;
            });
            if (tExistingDataContextRecord) {  // We found an existing context with the same ID
              // We don't want a difference in selected cases (contained in contextStorage) to count as a difference
              var tArchiveOfFoundExistingDocContext = tExistingDataContextRecord.toArchive(true /* fullData */),
                  tNewContextStorage = iNewDocContext.contextStorage;
              delete iNewDocContext.contextStorage;
              delete tArchiveOfFoundExistingDocContext.contextStorage;
              // Is the one we found identical to the one we're moving toward?
              if (JSON.stringify(iNewDocContext) !== JSON.stringify(tArchiveOfFoundExistingDocContext)) {
                // Something's different.
                iNewDocContext.contextStorage = tNewContextStorage; // Restore this
                tDocController.destroyDataContext(tDocContextID);
                tDocController.createNewDataContext(iNewDocContext);
              }
              else
                iNewDocContext.contextStorage = tNewContextStorage; // So selection will be restored
            }
            else {
              tDocController.createNewDataContext(iNewDocContext);
            }
          });
        }

        function createOrUpdateComponents() {
          tComponentsStorage.forEach(function (iCompStorage) {
            var tComponentController = tComponentControllers[iCompStorage.guid];
            if (tComponentController) {
              var tComponentView = tComponentController.get('view'),
                  tViewIsMinimized = tComponentView.get('isMinimized');
              tComponentController.restoreComponentStorage(iCompStorage.componentStorage);
              if((tViewIsMinimized && SC.none(iCompStorage.savedHeight))||
                  (!tViewIsMinimized && !SC.none(iCompStorage.savedHeight))) {
                tComponentView.toggleMinimization();
              }
              else if(iCompStorage.layout.isVisible) {
                if( !tComponentView.get('isVisible')) {
                  tComponentView.adjust({left: 0, top: 0, width: 10, height: 10});
                  tComponentView.set('isVisible', true);
                }
                tComponentView.adjust({zIndex: iCompStorage.layout.zIndex,
                    isVisible: iCompStorage.layout.isVisible });
                delete iCompStorage.layout.zIndex;
                delete iCompStorage.layout.isVisible;
                tComponentView.animate(iCompStorage.layout, {duration: 0.4, timing: 'ease-in-out'});
              }
              else {
                tComponentView.set('isVisible', false);
              }
            }
            else {
              // Sometimes the controller no longer exits by the component does. This prevents an assert
              DG.store.deregister(iCompStorage.id);
              iCompStorage.document = DG.activeDocument;
              iCompStorage.allowMoreThanOne = true; // defaults to false and not stored
              var tComponent = DG.Component.createComponent(iCompStorage);
              tDocController.createComponentAndView(tComponent);
            }
          });
        }

        // Global values are not stored in slider components so we have to reinstate them separately
        function reinstateGlobalValues() {
          if( iDocObject.globalValues)
            iDocObject.globalValues.forEach(function (iValue) {
            var tValueInDoc = DG.globalsController.getGlobalValueByID(iValue.guid);
            if (tValueInDoc) {
              tValueInDoc.set('value', iValue.value);
              tValueInDoc.set('name', iValue.name);
            }
            else {
              DG.globalsController.createGlobalValue( {name: iValue.name, value: iValue.value, guid: iValue.guid});
            }
          });
        }

        function reinstateSelection() {
          var tDocContexts = tDocController.get('contexts');
          if( iDocObject.contexts)
            iDocObject.contexts.forEach(function (iContext) {
            var tDocContext = tDocContexts.find(function (iDocContext) {
              return iDocContext.getPath('model.id') === iContext.guid;
            });
            if (tDocContext) {
              var tSelectedCases = iContext.contextStorage._links_.selectedCases.map(function (iLink) {
                return tDocContext.getCaseByID(iLink.id);
              });
              // allow for a render cycle
              tDocContext.invokeOnceLater(function () {
                tDocContext.applyChange({
                  operation: 'selectCases',
                  select: true,
                  cases: tSelectedCases
                });
              }, 200);
            }
          });
        }

        // Begin updateDocument
        var tResult = true;

        notifyDocumentChange('updateDocumentBegun');

        deleteComponentsNotInDocObject();

        deleteDataContextsNotInDocObject();

        reinstateGlobalValues();

        createOrUpdateDataContexts();

        createOrUpdateComponents();

        reinstateSelection();

        // The 500ms timeout here gives the document time to settle down.
        // Especially any changes to center and zoom of a map
        setTimeout( function() {
          DG.UndoHistory.clearUndoRedoHistory();
          notifyDocumentChange('updateDocumentEnded');
        }, 500);


        return tResult;
      }

    }
);

/* >>>>>>>>>> BEGIN source/models/document_model.js */
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
/*
 * Created by jsandoe on 10/17/14.
 */
sc_require('models/model_store');
sc_require('models/base_model');
/**
 * @class
 *
 * A describes the momentary state of a user interaction with CODAP components
 * and collections of data in the CODAP workspace.
 *
 * The document provides view and controller objects with access to data contexts,
 * components, and global values. In a running instance of CODAP there is always
 * exactly one active document. It can create contexts and destroy itself
 * and its dependent objects. Documents can be serialized and deserialized. This
 * permits them to be stored to filesystems or databases.
 *
 * @extends DG.baseModel
 */
DG.Document = DG.BaseModel.extend(
  /** @scope DG.Document.prototype */ {
    type: 'DG.Document',
    id: null,
    name: '', // String
    appName: '', // String
    appVersion: '', // String
    appBuildNum: '', // String
    components: null,
    contexts: null,
    globalValues: null,

    init: function () {
      this.components = {};
      this.contexts = {};
      this.globalValues = {};
      arguments.callee.base.apply(this,arguments);
    },
    verify: function () {
      if (SC.empty(this.name)) {
        DG.logWarn('Unnamed document: ' + this.id);
      }
    },
    getGlobalValueByName: function (name) {
      return DG.globalsController.getGlobalValueByName(name);
    },
    // init: function () {},
    destroy: function () {
      arguments.callee.base.apply(this,arguments);
    },
    createContext: function(iProperties) {
      if( SC.none( iProperties)) iProperties = {};
      iProperties.document = this;
      return DG.DataContextRecord.createContext( iProperties);
    },
    /**
     * Prepare to save record. Set the current app information, potentially
     * overriding original document information.
     */
    willSaveRecord: function() {
      this.set('appName', DG.APPNAME);
      this.set('appVersion', DG.VERSION);
      this.set('appBuildNum', DG.BUILD_NUM);
    },

    toArchive: function(fullData) {
      var obj = {
          name: this.name,
          guid: this.id,
          id: this.id,
          components: [],
          contexts: [],
          globalValues: [],
          appName: DG.APPNAME,
          appVersion: DG.VERSION,
          appBuildNum: DG.BUILD_NUM,
          lang: SC.Locale.currentLanguage,
          idCount: DG.store._idCount      // Saved so that on restore we can start at this idCount
        };
      DG.ObjectMap.forEach(this.globalValues, function (globalKey) {
        var globalValue = this.globalValues[globalKey];
        if (globalValue.get('archivable'))
          obj.globalValues.push(globalValue.toArchive());
      }.bind(this));
      DG.ObjectMap.forEach(this.components, function (componentKey) {
        obj.components.push(this.components[componentKey].toArchive());
      }.bind(this));
      DG.ObjectMap.forEach(this.contexts, function (contextKey) {
        obj.contexts.push(this.contexts[contextKey].toArchive(fullData));
      }.bind(this));

      return obj;
    }
  });

DG.Document.createDocument = function( iProperties) {

  var tDocument,
    tProperties = iProperties || {};

  /* A store must exist to create a document */
  DG.store = DG.ModelStore.create( {
    _idCount: SC.none( iProperties.idCount) ? 0 : iProperties.idCount
  });
  tDocument =  DG.Document.create(tProperties);

  DG.activeDocument = tDocument;

  if (tProperties.globalValues) {
    tProperties.globalValues.forEach( function (gv) {
      gv.document = tDocument;
      DG.globalsController.createGlobalValue(gv);
    });
  }
  if (tProperties.components) {
    tProperties.components.forEach(function (component) {
      component.document = tDocument;
      DG.Component.createComponent(component);
    });
  }
  if (tProperties.contexts) {
    tProperties.contexts.forEach(function (context) {
      context.document = tDocument;
      DG.DataContextRecord.createContext(context);
    });
  }
  DG.log('Create document: ' + [tDocument.name, tDocument.appName].join(', '));

  return tDocument;
};

DG.Document.destroyDocument = function( iDocument) {
  if( iDocument) {
    iDocument.destroy();
  }
  DG.activeDocument = null;
  DG.store = null;
  DG.Case._itemCaseMaps = {};
};

/* >>>>>>>>>> BEGIN source/models/global_value_model.js */
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
/**
 * Created by jsandoe on 10/17/14.
 */
sc_require('models/base_model');

/**
 * @class
 *
 * A GlobalValue is a named, user created value that can be employed in
 * formulas. Sliders control global values.
 *
 * @extends DG.BaseModel
 */
DG.GlobalValue = DG.BaseModel.extend(/** @scope DG.GlobalValue.prototype */ {

  /**
   * The name of the global value
   * @property {String}
   */
  name: '',

  /**
   * The "native" storage of the value is a number for now.
   * Eventually, this will need to be a more general notion of value.
   * @property {Number}
   */
  value: '',

  valueDidChange: function () {
    var v = this.get('value');
    DG.currDocumentController().notificationManager.sendNotification({
      action: 'notify',
      resource: 'global[%@]'.loc(this.name),
      values: {
        globalValue: (typeof v === 'object' || typeof v === 'function')? v.toString(): v
      }
    });
  }.observes('value'),

  /**
   * A relational link back to the document.
   * @property {DG.Document}
   */
  document: null,

  init: function() {
    arguments.callee.base.apply(this,arguments);
  },

  destroy: function () {
    if (this.document) {
      delete this.document.globalValues[this.id];
    }
    arguments.callee.base.apply(this,arguments);
  },

  verify: function () {
    if (SC.empty(this.document) && !this.get('allowDetached')) {
      DG.logWarn('Unattached global value: ' + this.id);
    }
    if (typeof this.document === 'number') {
      DG.logWarn('Unresolved reference to document id, ' + this.document +
        ', in global value: ' + this.id);
    }
  },

  archivable: true,

  toArchive: function () {
    return {
      name: this.get('name'),
      value: this.get('value'),
      guid: this.get('id')
    };
  }
});

DG.GlobalValue.createGlobalValue = function (iProperties) {
  var tProperties = iProperties || {},
    tGlobal = DG.GlobalValue.create(tProperties);
  if (iProperties.document) {
    tProperties.document.globalValues[tGlobal.get('id')] = tGlobal;
  }
  return tGlobal;
};

DG.GlobalValue.destroyGlobalValue = function (iGlobalValue) {
  iGlobalValue.destroy();
};

/* >>>>>>>>>> BEGIN source/models/remote_resource.js */
// ==========================================================================
//                          DG.RemoteResource
//
//  Author:   Kirk Swenson
//
//  Copyright (c) 2017 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('models/global_value_model');


/** @class DG.PendingRequest

  "Error" class for pending requests.

  @extends Error
*/
DG.PendingRequest = function() {
  this.name = 'DG.Formula.PendingRequest.name'.loc();
  this.message = 'DG.Formula.PendingRequest.message'.loc();
  this.description = 'DG.Formula.PendingRequest.description'.loc();
};
DG.PendingRequest.prototype = new Error();
DG.PendingRequest.prototype.constructor = DG.PendingRequest;


/** @class DG.FailedRequest

  "Error" class for failed requests.

  @extends Error
*/
DG.FailedRequest = function(error) {
  this.name = 'DG.Formula.FailedRequest.name'.loc();
  this.message = 'DG.Formula.FailedRequest.message'.loc(error);
  this.description = 'DG.Formula.FailedRequest.description'.loc(error);
};
DG.FailedRequest.prototype = new Error();
DG.FailedRequest.prototype.constructor = DG.FailedRequest;


DG.RemoteResource = DG.GlobalValue.extend({

  url: null,

  format: null,

  archivable: false,

  pendingValue: new DG.PendingRequest(),

  _value: null,

  init: function() {
    arguments.callee.base.apply(this,arguments);
  },

  destroy: function() {
    arguments.callee.base.apply(this,arguments);
  },

  value: function() {
    if (this._value != null)
      return this._value;

    this._load();
  }.property(),

  _load: function() {
    this._value = this.get('pendingValue');
    this.notifyPropertyChange('value');

    $.ajax({
      url: this.url,
      context: this,
      dataType: 'json',
      success: function(data, status, jqXHR) {
        SC.run(function() {
          this._value = this._handleSuccess(data, status, jqXHR);
          this.notifyPropertyChange('value');
        }.bind(this));
      }.bind(this),
      error: function (jqXHR, status, error) {
        SC.run(function() {
          this._value = this._handleError(jqXHR, status, error);
          this.notifyPropertyChange('value');
        }.bind(this));
      }
    });
  },

  _handleSuccess: function(data) {
    return data;
  },

  _handleError: function(jqXHR, status, error) {
    return new DG.FailedRequest(error || status);
  }

});

/* >>>>>>>>>> BEGIN source/models/remote_boundaries.js */
// ==========================================================================
//                          DG.RemoteBoundaries
//
//  Author:   Kirk Swenson
//
//  Copyright (c) 2017 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('models/remote_resource');
sc_require('controllers/document_controller');


/** @class DG.PendingBoundaries

  "Error" class for pending boundaries.

  @extends PendingRequest
*/
DG.PendingBoundaries = function() {
  this.name = 'DG.Formula.PendingBoundaries.name'.loc();
  this.message = 'DG.Formula.PendingBoundaries.message'.loc();
  this.description = 'DG.Formula.PendingBoundaries.description'.loc();
};
DG.PendingBoundaries.prototype = new DG.PendingRequest();
DG.PendingBoundaries.prototype.constructor = DG.PendingBoundaries;


/** @class DG.FailedBoundaries

  "Error" class for failed boundary requests.

  @extends FailedRequest
*/
DG.FailedBoundaries = function(error) {
  this.name = 'DG.Formula.FailedBoundaries.name'.loc();
  this.message = 'DG.Formula.FailedBoundaries.message'.loc(error);
  this.description = 'DG.Formula.FailedBoundaries.description'.loc(error);
};
DG.FailedBoundaries.prototype = new DG.FailedRequest();
DG.FailedBoundaries.prototype.constructor = DG.FailedBoundaries;


DG.RemoteBoundaries = DG.RemoteResource.extend({

  pendingValue: new DG.PendingBoundaries(),

  init: function() {
    arguments.callee.base.apply(this,arguments);
  },

  destroy: function() {
    arguments.callee.base.apply(this,arguments);
  },

  _handleSuccess: function(data) {
    var tBoundariesObject,
        tBoundariesCollection,
        tBoundariesIDIndex = {},
        tIndexCollection,
        mapValues = new DG.BoundaryMap();

    tBoundariesObject = data.contexts[0];
    tBoundariesObject.collections.forEach(function (iCollection) {
      switch (iCollection.name) {
        case 'boundaries':
          tBoundariesCollection = iCollection;
          break;
        case 'index':
          tIndexCollection = iCollection;
          break;
      }
    });
    tBoundariesCollection.cases.forEach(function (iCase) {
      tBoundariesIDIndex[iCase.guid] = iCase.values.boundary;
    });

    tIndexCollection.cases.forEach(function (iKeyCase) {
      var boundaryKey = iKeyCase && iKeyCase.values && iKeyCase.values.key &&
                          iKeyCase.values.key.toLowerCase(),
          boundaryData = null;

      try {
        boundaryData = JSON.parse(tBoundariesIDIndex[iKeyCase.parent]);
      }
      catch(e) {
        boundaryData = new DG.FailedBoundaries('JSON boundary');
      }

      mapValues.map[boundaryKey] = { jsonBoundaryObject: boundaryData };
    }.bind( this));

    return mapValues;
  },

  _handleError: function(jqXHR, status, error) {
    return new DG.FailedBoundaries(error || status);
  }
});

// determines whether boundaries are cached across document loads
DG.enableBoundariesCache = false;

DG.RemoteBoundaries.addBoundaries = function(boundaries) {
  DG.globalsController.registerGlobalValue(boundaries);
  if (DG.activeDocument) {
    boundaries.set('document', DG.activeDocument);
    DG.activeDocument.globalValues[boundaries.get('id')] = boundaries;
  }
};

DG.RemoteBoundaries.registerDefaultBoundaries = function() {
  var specsURL = DG.get('boundarySpecsUrl');
  var baseURL = specsURL && specsURL.replace(/\/[^\/]*$/, '/');
  if (!DG.currDocumentController().get('ready')) return;

  function addBoundaries() {
    if( DG.activeDocument.remoteBoundaries) {
      DG.activeDocument.remoteBoundaries.forEach(function(remoteBoundary) {
        DG.RemoteBoundaries.addBoundaries(remoteBoundary);
      });
    }
  }

  // first time - create internal array of boundaries
  if (DG.activeDocument && !DG.activeDocument.remoteBoundaries) {
    $.ajax({
      url: DG.get('boundarySpecsUrl'),
      context: this,
      dataType: 'json',
      success: function (boundarySpecs, status, jqXHR) {
        DG.activeDocument.remoteBoundaries = [];
        var boundaryID = 100000000;
        boundarySpecs.forEach(function (spec) {
          // in an abundance of caution, make sure the ID is unassigned.
          var obj = DG.store.find(boundaryID);
          while (obj) {
            boundaryID++;
            obj = DG.store.find(boundaryID);
          }
          spec.guid = boundaryID++;
          var url = spec.url;
          if (!(url.startsWith('http://') || url.startsWith('https://') || url.startsWith('//'))) {
            spec.url = baseURL + url;
          }
          // eliminate unattached global warning
          var boundarySpec = $.extend({ allowDetached: true }, spec);
          DG.activeDocument.remoteBoundaries.push(DG.RemoteBoundaries.create(boundarySpec));
        });
        addBoundaries();
      }.bind(this),
      error: function (jqXHR, status, error) {
        console.log('Unable to read boundary specs: ' + error);
      }
    });
  }

};


/* >>>>>>>>>> BEGIN source/models/component_model.js */
// ==========================================================================
//                              DG.Component
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('models/model_store');
sc_require('models/base_model');

/** @class

    Represents an individual component of a DG.Document.

 @extends DG.BaseModel
 */
DG.Component = DG.BaseModel.extend(
    /** @scope DG.Component.prototype */ {

      /**
       * A relational link back to the parent DG.Document
       * @property {DG.Document}
       */
      document: null,

      /**
       * The title of this component. Can be edited by user.
       * @property {String}
       */
      _title: null,
      title: function( iKey, iValue) {
        if( iValue !== undefined) {
          this._title = iValue;
          if (this.getPath('content.title')) {
            this.setPath('content.title', iValue);
          }
        }
        else if (SC.none(this._title)) {
          this._title = this.getPath('content.title') || this.getPath('content.defaultTitle');
        }
        return this._title;
      }.property(),

      userSetTitle: false,

      titleChanged: function () {
        // clear local cache when content title changes
        this._title = null;
        this.notifyPropertyChange('title');
      }.observes('*content.title', '*content.defaultTitle'),

      /*
       * The width and height of this component in pixels to be used in layout.
       * @property {Object}
       */
      dimensions: function() {
        return this.getPath('content.dimensions');
      }.property(),

      contentDimensionsChanged: function() {
        this.notifyPropertyChange('dimensions');
      }.observes('*content.dimensions'),

      /**
       * This property is transient. The Plugin api uses it to convey position
       * to the view, which, in turn updates the layout. We persist the layout.
       * Of layout properties, only left and top can be set.
       *
       * @param value {{left: number, top: number}}
       */
      _position: null,
      position: function (key, value) {
        if (value && typeof value === 'object') {
          if (SC.none(this._position)) {
            this._position = {};
          }
          this._position.left = value.left;
          this._position.top = value.top;
        }
        return this._position;
      }.property(),

      /*
       * An arbitrary version string to be presented in the header.
       * @property {string}
       */
      version: function() {
        return this.getPath('content.version');
      }.property(),

      contentVersionChanged: function() {
        this.notifyPropertyChange('version');
      }.observes('*content.version'),

      /**
       * If true, the close button will not show in the component title bar.
       * @property {Boolean}
       */
      _cannotClose: false,
      cannotClose: function (iKey, iValue) {
        if (!SC.none(iValue)) {
          this._cannotClose = iValue;
        }
        return this._cannotClose;
      }.property('_cannotClose'),

      /**
       * @property {{width:{boolean}, height: {boolean}}}
       */
      _isResizable: null,
      /**
       * @property {boolean}
       */
      isResizable: function( iKey, iValue) {
        if(!SC.empty(iValue)) {
          if( typeof iValue === 'object')
            this._isResizable = iValue;
          else if( typeof iValue === 'boolean')
            this._isResizable = { width: iValue, height: iValue };
        }
        return this._isResizable.width && this._isResizable.height;
      }.property(),

      /**
       * @property {boolean}
       */
      isWidthResizable: function(iKey, iValue) {
        if( !SC.empty(iValue) && typeof iValue === 'boolean')
          this._isResizable.width = iValue;
        return this._isResizable.width;
      }.property(),

      /**
       * @property {boolean}
       */
      isHeightResizable: function(iKey, iValue) {
        if( !SC.empty(iValue) && typeof iValue === 'boolean')
          this._isResizable.height = iValue;
        return this._isResizable.height;
      }.property(),

      /**
       * Content is an arbitrary javascript object, serializable, and defined
       * by the Component.
       * @property {object}
       */
      content: function (iKey, iValue) {
        if (iValue !== undefined) {
          DG.Component.setContent(this, iValue);
        }
        return DG.Component.getContent(this);
      }.property(),


      /**
       * The type of the component (e.g. 'DG.CaseTable', 'DG.Graph', 'DG.Calculator', ...)
       * @property {String}
       */
      type: '',

      /**
       * The bounds of the component in the document stored as an SC.Layout-formatted object.
       * @property {Object}
       */
      layout: null,

      /**
       * Is only a value when we are minimized
       * If we are not minimized, this is null
       * When we are minimized, this is the height of the component to return to when unminimized
       * @property {Number}
       */
      savedHeight: null,

      /**
       * Per-component storage, in a component specific format.
       * @property {object} must be serializable
       */
      componentStorage: null,

      init: function() {
        arguments.callee.base.apply(this,arguments);
        this._isResizable = { width: true, height: true };  // default
        var tStorage = this.get('componentStorage');
        if (tStorage) {
          if( tStorage.title) {
            this.set('title', tStorage.title);
          }
          if( tStorage.name) {
            this.set('name', tStorage.name);
          }
          if( tStorage.userSetTitle) {
            this.set('userSetTitle', tStorage.userSetTitle);
          }
          if (!SC.none(tStorage.cannotClose)) {
            this.set('cannotClose', tStorage.cannotClose);
          }
        }
      },

      destroy: function () {
        var document = DG.currDocumentController().content;
        if (document) {
          delete document.get('components')[this.id];
        }
        arguments.callee.base.apply(this,arguments);
      },

      toArchive: function () {

        function populateLayout( iLayout) {
          // The problem is that we can get here with only some of the layout parameters we need defined.
          // Particularly we can get here without right and/or bottom.
          // We correct that unusal situation heuristically
          iLayout.left = iLayout.left || 0;
          iLayout.top = iLayout.top || 0;
          iLayout.width = iLayout.width || 300;
          iLayout.height = iLayout.height || 300;
          iLayout.right = iLayout.right || iLayout.left + iLayout.width;
          iLayout.bottom = iLayout.bottom || iLayout.top + iLayout.height;
          return iLayout;
        }

        var obj = {},
            tStorage = this.get('componentStorage'),
            tCannotClose = this.get('cannotClose'),
            tPopulatedLayout;
        if( tStorage) {
          tStorage.title = this.get('title') || tStorage.title;
          tStorage.name = tStorage.name || this.get('name');
          tStorage.userSetTitle = tStorage.userSetTitle || this.get('userSetTitle');
          tStorage.cannotClose = SC.none(tCannotClose)? tStorage.cannotClose: tCannotClose;
        }
        tPopulatedLayout = populateLayout( this.layout);
        obj = {
          type: this.type,
          guid: this.id,
          id: this.id,
          componentStorage: tStorage,
          layout: tPopulatedLayout,
          savedHeight: this.get('savedHeight')
        };
        return obj;
      },

      verify: function () {
        if (SC.empty(this.document)) {
          DG.logWarn('Unattached component: ' + this.id);
        }
        if (typeof this.document === 'number') {
          DG.logWarn('Unresolved reference to document id, ' + this.document +
              ', in component: ' + this.id);
        }
      }


    });

/**
 Class-level map from DG.Component 'id's to content objects.

 Conceptually, the DG.Component owns a 'content' property. The fact that DG.Records get
 promiscuously cloned, however, makes it a bad idea to have potentially complicated
 content objects stored in top-level properties where they are likely to get cloned
 unnecessarily. Therefore, we use an object map. The computed 'content' property above
 insures that clients that get/set the 'content' property will be accessing the
 contents of this map rather than a simple property.
 */
DG.Component.contentMap = {};

DG.Component.clearContentMap = function () {
  DG.Component.contentMap = {};
};

/**
 Returns the content object associated with the specified component.
 @param  {DG.Component}  iComponent  The component whose content should be returned.
 @returns  {Object}  The content object associated with the specified component.
 */
DG.Component.getContent = function (iComponent) {
  var componentID = iComponent && iComponent.id;
  return componentID ? DG.Component.contentMap[componentID] : undefined;
};

/**
 Sets the content object associated with the specified component.
 @param  {DG.Component}  iComponent  The component whose content is being specified.
 @param  {Object}        iContent    The content object to associate with the component.
 */
DG.Component.setContent = function (iComponent, iContent) {
  // We must use DG.store.idFor() here because during creation, we can get
  // here with DG.store.idFor() having been updated appropriately, but
  // component.get('id') being stale.
  var componentID = iComponent && iComponent.id;
  if (!SC.none(componentID)) {
    if (iContent === undefined)
      delete DG.Component.contentMap[componentID];
    else DG.Component.contentMap[componentID] = iContent;
  }
};


DG.Component.createComponent = function (iProperties) {
  var tProperties = iProperties || {},
      tComponent;
  tComponent = DG.Component.create(tProperties);
  if (iProperties.document) {
    iProperties.document.components[tComponent.get('id')] = tComponent;
  }

  return tComponent;
};

DG.Component.destroyComponent = function (iComponent) {
  iComponent.destroy();
};

/* >>>>>>>>>> BEGIN source/controllers/document_controller.js */
// ==========================================================================
//                        DG.DocumentController
//
//  A controller for a single document.
//
//  Author:   Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('models/document_model');
sc_require('models/remote_boundaries');
sc_require('models/component_model');

/* globals Promise */

/** @class
 *
 * Coordinating controller for the document. This class centralizes access to
 * operations affecting the document that the user is viewing and interacting
 * with in CODAP. It provides the means to create new top level objects, such
 * as data contexts or components. One can destroy or find these objects. It
 * provides the ability to restore these objects accurately from a serializable
 * representation of these objects or to create a serializable representation,
 * but it does not provide the means to persist or restore them to or from
 * an external location.
 *
 * An instance of CODAP will only manage one document at a time, so this object
 * is effectively a singleton, though not managed as only. Any object can find
 * the current document by calling DG.currDocumentController.
 *
 * @extends SC.Object
 */
DG.DocumentController = SC.Object.extend(
    /** @scope DG.DocumentController.prototype */ {

      /**
       *  The document managed by this controller.
       *  @property {DG.Document}
       */
      content: null,

      /**
       *  The DataContexts which are managed by this controller.
       *  Bound to the document's 'contexts' property.
       *  @property {{contextID: DG.DataContextRecord}} A hash map mapping
       *  contextIDs to DataContext records
       */
      contextRecords: function () {
        return this.getPath('content.contexts');
      }.property(),

      /**
       * @property {[DG.DataContext]} Indexed sequentially.
       */
      contexts: null,

      /**
       *  The Components which are managed by this controller.
       *  Bound to the document's 'components' property.
       *  @property {Object} Hashmap of Components
       */
      components: function () {
        return this.getPath('content.components');
      }.property(),

      /**
       *  The current in-bounds mode scaling preferences.
       *  Bound to the document's 'inBoundsScaling' property.
       *  @property {Object} containing scaleFactor, scaleBoundsX, scaleBoundsY
       */
      _inBoundsScaling: null,
      inBoundsScaling: function () {
        return this._inBoundsScaling;
      }.property(),

      setInBoundsScaleFactor: function (sF) {
        if (this._inBoundsScaling && sF) {
          this._inBoundsScaling.scaleFactor = sF;
        }
      },

      setInBoundsScaleBounds: function (sX, sY) {
        if (this._inBoundsScaling && sX && sY) {
          this._inBoundsScaling.scaleBoundsX = sX;
          this._inBoundsScaling.scaleBoundsY = sY;
        }
      },

      setInBoundsScaling: function (sF, sX, sY) {
        if (!this._inBoundsScaling) {
          this._inBoundsScaling = {scaleFactor: sF, scaleBoundsX: sX, scaleBoundsY: sY};
        } else {
          this.setInBoundsScaleFactor(sF);
          this.setInBoundsScaleBounds(sX, sY);
        }
      },

      /**
       * Returns an array of the GameControllers defined in this document.
       */
      dataInteractives: function () {
        var componentControllers = this.get('componentControllersMap'),
            result = [];
        if (componentControllers) {
          DG.ObjectMap.forEach(componentControllers, function (key, component) {
            var type = component.getPath('model.type');
            if (type === 'DG.GameView') {
              result.push(component);
            }
          });
        }
        return result;
      }.property('componentControllersMap'),

      /**
       Map from component ID to the component's controller
       */
      componentControllersMap: null,

      /** @private
       * Maintain links to singleton component views
       *
       * @property {Object} Maps component type to DG.ComponentView
       */
      _singletonViews: null,

      /**
       * caseTable/Card views
       *
       * Handled like singleton views. We do not destroy them. We make them
       * invisible.
       *
       * @property {Object} Maps data context id to DG.ComponentView.
       */
      tableCardRegistry: DG.TableCardRegistry.create(),

      /**
       * The state of the document. The document is not ready during document load.
       */
      ready: true,

      /**
       * Set by singleton AppController on startup
       * @property {SC.MenuPane}
       */
      guideMenuPane: null,

      /**
       * Set by singleton MainPage on startup
       * @property {DG.IconButton}
       */
      guideButton: null,

      _guideModel: null,
      guideModel: function () {
        if (!this._guideModel) {
          this._guideModel = DG.GuideModel.create();
        }
        return this._guideModel;
      }.property(),

      _guideController: null,
      guideController: function () {
        if (!this._guideController) {
          this._guideController = DG.GuideController.create({
            guideModel: this.get('guideModel')
          });
        }
        return this._guideController;
      }.property(),

      _caseTableComponents: null,
      /**
       * Get or construct a case table component.
       *
       * Case tables need to retain their properties when closed, so we
       * keep them here. The reference in DocumentController.components may
       * come and go.
       * @param {DG.Component||null} originalComponent An existing component,
       *            if present. Will be provided if the component is already
       *            defined in a document.
       * @param {DG.DataContext} context
       * @param {object} properties
       * @returns {DG.Component}
       */
      getCaseTableComponent: function (originalComponent, context, properties) {
        if (SC.none(this._caseTableComponents)) {
          this._caseTableComponents = {};
        }
        var contextID = context && context.get('id');
        var component = originalComponent || this._caseTableComponents[contextID];
        var caseTableModel;
        if (SC.none(component)) {
          caseTableModel = DG.CaseTableModel.create({context: context});
          properties.document = this.content;
          properties.type = 'DG.TableView';
          component = DG.Component.createComponent(properties);
          component.set('content', caseTableModel);
        }
        this._caseTableComponents[contextID] = component;
        return component;
      },

      /**
       *  The ID of the document managed by this controller.
       *  @property {String}
       */
      documentID: function () {
        return this.getPath('content.id');
      }.property(),

      documentIDDidChange: function () {
        this.notifyPropertyChange('documentID');
      }.observes('*content.id'),

      /**
       *  The name of the document managed by this controller.
       *  @property {String}
       */
      documentName: function (iKey, iValue) {
        var content = this.get('content');
        if (!content) {
          return;
        }
        if (iValue !== undefined) {
          content.set('name', iValue);
          DG.store.commitRecords();
        }
        return content.get('name');
      }.property(),

      documentNameDidChange: function () {
        this.notifyPropertyChange('documentName');
      }.observes('*content.name'),

      setPageTitle: function () {
        if ((DG.get('componentMode') === 'yes') || (DG.get('embeddedMode') === 'yes')) {
          return;
        }
        var name = this.get('documentName');
        if (SC.empty(name)) {
          name = 'DG.Document.defaultDocumentName'.loc();
        }
        var nameString = 'DG.main.page.title'.loc(name, DG.USER_APPNAME);
        $('title').text(nameString);
      }.observes('documentName'),

      sharedMetadata: function (iKey, iSharedMetadata) {
        if (iSharedMetadata !== undefined) {
          var contentMetadata = this.getPath('content.metadata'),
              sharedMetadata = $.extend(true, {}, iSharedMetadata);
          if (contentMetadata != null) {
            contentMetadata.shared = sharedMetadata;
          } else {
            this.setPath('content.metadata', {shared: sharedMetadata});
          }
          // Currently, Concord Document Store requires '_permissions' at top-level
          this.setPath('content._permissions', sharedMetadata._permissions || 0);
          return this;
        }
        return this.getPath('content.metadata.shared');
      }.property(),

      /**
       The total number of document-dirtying changes.
       @property   {Number}
       */
      changeCount: 0,

      /**
       The number of document-dirtying changes that have been saved.
       If this is less than the total change count, then the document is dirty.
       @property   {Number}
       */
      savedChangeCount: 0,

      _changedObjects: null,
      _skipPatchNextTime: [],

      /**
       Object containing data interactive log monitor properties used in DG.DataInteractivePhoneHandler
       @property {Object} dataInteractiveLogMonitor
       {Array}  logMonitors -- array of active log monitors set in DG.DataInteractivePhoneHandler
       {Number} nextLogMonitorId -- incrementing id of log monitor instances
       */
      dataInteractiveLogMonitor: null,

      init: function () {
        arguments.callee.base.apply(this,arguments);

        this._singletonViews = {};
        this.tableCardRegistry = DG.TableCardRegistry.create();

        this.contexts = [];

        this.dataInteractiveLogMonitor = SC.Object.create({
          logMonitors: [],
          nextLogMonitorId: 1
        });

        this.clearChangedObjects();

        // If we were created with a 'content' property pointing to our document,
        // then use it; otherwise, create a new document.
        this.setDocument(this.get('content') || this.createDocument());

        if (DG.KEEP_IN_BOUNDS_PREF) {
          this.setInBoundsScaling(1, 0, 0);
        }
      },

      destroy: function () {
        this.closeDocument();
        arguments.callee.base.apply(this,arguments);
      },

      /**
       * Creates a DG.Document with the specified name.
       * If no name is passed in, uses the default document name.
       * @param    {String}  iName -- [Optional] The name of the newly created document
       * @returns  {DG.Document} --   The newly-created document
       *
       * TODO: Move to DocumentHelper. This seems like a suspect path for creating
       * TODO: a new document.
       */
      createDocument: function (iName) {
        var doc = DG.Document.createDocument({
          name: iName || SC.String.loc('DG.Document.defaultDocumentName'),
          isNewDocument: true // mark this document as not having been saved and restored.
                              // this property will not be persisted with the document.
        });
        if (SC.none(iName)) {
          doc.set('_isPlaceholder', true);
        }
        return doc;
      },

      /**
       * Sets the document to be managed by this controller.
       * @param    {DG.Document} iDocument -- The document to be associated with
       * this controller
       *
       * TODO: This method is part of a convoluted and solipsistic process to open
       * TODO: a new document. Shouldn't a document be created from outside itself?
       *
       */
      setDocument: function (iDocument) {

        try {
          this.set('ready', false);
          this.set('content', iDocument);

          if (DG.mainPage.mainPane.hideInspectorPicker)  // undefined if not fully initialized yet
            DG.mainPage.mainPane.hideInspectorPicker(); // we don't want it showing for new doc
          DG.Component.clearContentMap();
          this.componentControllersMap = {};
          this._caseTableComponents = {};

          this.notificationManager = DG.NotificationManager.create({});

          // Create the individual DataContexts
          this.restoreDataContexts();

          // Set guide index if query parameter set.
          // Bypass for new documents, because new Documents do not have guides.
          if (!iDocument.isNewDocument) {
            this.updateGuideFromURL();
          }

          // Create the individual component views
          SC.run(function () {
            this.restoreComponentControllersAndViews();
          }.bind(this));

          this.clearChangedObjects();
          this.set('changeCount', 0);
          this.updateSavedChangeCount();
          this.set('ready', true);

          this.invokeLater(function () {
            DG.RemoteBoundaries.registerDefaultBoundaries();
          });
        } catch (e) {
          DG.logError(e);
        }
      },

      /**
       Whether or not the document contains unsaved changes such that the user
       should be prompted to confirm when closing the document, for instance.
       Note that we only respond true if the user has the ability to save,
       since there's little reason to prompt the user if they can't actually
       save. On review, however, it was pointed out that the ability to cancel
       might be useful event without the ability to save for users who didn't
       mean to logout, close the document, etc., but for now we're going to
       assume that won't happen often enough to warrant consideration.
       @property   {Boolean}
       */
      hasUnsavedChanges: function () {
        // Game controller state affects the document state
        return this.get('changeCount') > this.get('savedChangeCount');
      }.property('changeCount', 'savedChangeCount'),

      /**
       Synchronize the saved change count with the full change count.
       This method should be called when a save occurs, for instance.
       */
      updateSavedChangeCount: function () {
        // Game controller state affects the document state
        this.dataInteractives().forEach(function (gameController) {
          gameController.updateSavedChangeCount();
        });
        this.set('savedChangeCount', this.get('changeCount'));
      },

      objectChanged: function (obj) {
        var changes = this.get('_changedObjects');
        if (changes.indexOf(obj) === -1) {
          changes.push(obj);
          this.set('_changedObjects', changes);
        }
      },

      clearChangedObjects: function () {
        this.set('_changedObjects', []);
      },

      clearChangedObject: function (obj) {
        var changes = this.get('_changedObjects');
        var idx = changes.indexOf(obj);
        if (idx !== -1) {
          changes.splice(idx, 1);
          this.set('_changedObjects', changes);
        }
      },

      objectHasUnsavedChanges: function (obj) {
        var changes = this.get('_changedObjects');
        return changes.indexOf(obj) !== -1;
      },

      getComponentControllerForModel: function (iComponentModel) {
        var id = iComponentModel && iComponentModel.get('id');
        return id && this.componentControllersMap[id];
      },

      /**
       Creates an appropriate DG.DataContext for the specified DG.DataContextRecord object.
       If no model is specified, creates the DG.DataContextRecord as well.
       @param    {DG.DataContextRecord}  iModel -- [Optional] The model for which to create the DG.DataContext.
       @param    {Object}                iProperties -- Constructor arguments for the new DG.DataContext.
       @returns  {DG.DataContext}                  The newly created DG.DataContext.
       */
      createDataContextForModel: function (iModel, iProperties) {
        // Create the model if one isn't passed in
        if (SC.none(iModel))
          iModel = DG.DataContextRecord.createContext({document: this.get('documentID')});
        if (!iProperties) iProperties = {};
        iProperties.type = iModel.get('type');
        iProperties.model = iModel;
        var context = DG.DataContext.factory(iProperties);
        this.get('contexts').pushObject(context);
        this.propertyDidChange('contextsLength');
        return context;
      },

      /**
       * Destroys the identified data context.
       * @param dataContextID
       * @return whether successful. That is whether there was a dataContext
       *    with the id to be destroyed.
       */
      destroyDataContext: function (dataContextID) {
        var dataContext = this.getContextByID(dataContextID);
        var dataContextIndex = this.contexts.findIndex(function (dc) {
          return dc === dataContext;
        });
        if (dataContext) {
          if (dataContextIndex >= 0) {
            dataContext.applyChange({operation: 'deleteDataContext'});
            this.contexts.splice(dataContextIndex, 1);
            this.propertyDidChange('contextsLength');
            this.tableCardRegistry.deregisterViews(dataContextID);

            // Send notification indicating which data context was deleted
            this.notificationManager.sendNotification({
              action: 'notify',
              resource: 'documentChangeNotice',
              values: {
                operation: 'dataContextDeleted',
                deletedContext: dataContext.get('name'),
              }
            }, function (response) {
              DG.log('Sent notification for deletion of context ' + dataContextID);
              DG.log('Response: ' + JSON.stringify(response));
            });
          } else {
            DG.logWarn('Attempt to destroy data context %@. Not known to document'.loc(dataContextID));
          }
        } else {
          return false;
        }
      },

      /**
       Creates an appropriate DG.DataContext for each DG.DataContextRecord in the document.
       Can be used after restoring a document, for instance.
       */
      restoreDataContexts: function () {
        var contextRecords = this.get('contextRecords') || [];
        DG.ObjectMap.forEach(contextRecords, function (key, iContextModel) {
          var newContext = this.createDataContextForModel(iContextModel);
          if (newContext) {
            newContext.restoreFromStorage(iContextModel.get('contextStorage'));
          }
        }.bind(this));
      },

      createNewDataContext: function (iProps) {
        var contextRecord = DG.DataContextRecord.createContext(iProps),
            context = this.createDataContextForModel(contextRecord);
        if (contextRecord.contextStorage) {
          context.restoreFromStorage(contextRecord.contextStorage);
        }
        return context;
      },

      /**
       * Creates the specified component and its associated view.
       * Clients should specify either iComponent or iComponentType.
       * @param iComponent     {DG.Component} [Optional] -- The restored component.
       *                                              Should be specified when restoring from document.
       * @param iComponentType {String}            [Optional] -- The type of component to create.
       * @param iArgs          {Object}            [Optional] -- parameters defining this object.
       *
       * @return {DG.ComponentView||[DG.CaseTableView]} In most instances we return
       * the view created. For backward compatibility, we can create one case table for
       * each data context that does not already have a case table. In this instance
       * we return an array of views.
       */
      createComponentAndView: function (iComponent, iComponentType, iArgs) {
        var docView = DG.mainPage.get('docView'),
            type = (iComponent && iComponent.get('type')) || iComponentType,
            tView = null,
            isInitialization = !(iArgs && iArgs.initiatedViaCommand);
        try {
          switch (type) {
            case 'DG.FlashView':  // For backward compatibility
              if (iComponent)
                iComponent.set('type', 'DG.GameView');
              /* jshint -W086 */  // Expected a 'break' statement before 'case'. (W086)
              // fallthrough intentional
            case 'DG.GameView':
              tView = this.addGame(docView, iComponent, isInitialization);
              break;
            case 'DG.TableView':
              if (iComponent && iComponent.componentStorage && iComponent.componentStorage._links_) {
                tView = this.addCaseTable(docView, iComponent);
              } else {
                tView = this.openCaseTablesForEachContext();
              }
              break;
            case 'DG.CaseCard':
              tView = this.addCaseCard(docView, null, null, iComponent);
              break;
            case 'DG.GraphView':
              // ToDo: pass iArgs along to other 'add' methods in addition to addGraph
              tView = this.addGraph(docView, iComponent, isInitialization, iArgs);
              break;
            case 'DG.SliderView':
              tView = this.addSlider(docView, iComponent, isInitialization);
              break;
            case 'DG.Calculator':
              this.toggleComponent(docView, 'calcView', iComponent);
              tView = this._singletonViews.calcView;
              break;
            case 'DG.TextView':
              tView = this.addText(docView, iComponent, isInitialization);
              break;
            case 'DG.MapView':
              tView = this.addMap(docView, iComponent, isInitialization);
              break;
            case 'SC.WebView':
            case 'DG.WebView':
              tView = this.addWebView(docView, iComponent, null, null, null, isInitialization);
              break;
            case 'DG.ImageComponentView':
              tView = this.addImageView(docView, iComponent, null, null, null, isInitialization);
              break;
            case 'DG.GuideView':
              tView = this.addGuideView(docView, iComponent, isInitialization);
              break;
            default:
              break;
          }
        } catch (e) {
          DG.logError(e);
        }

        if (iComponent)
          iComponent.didLoadRecord();

        return tView;
      },

      /**
       Creates an appropriate DG.ComponentView for each DG.Component in the document.
       Can be used after restoring a document, for instance.
       */
      restoreComponentControllersAndViews: function () {
        var components = this.get('components');
        if (components) {
          if (DG.KEEP_IN_BOUNDS_PREF) {
            this.setInBoundsScaling(1, 0, 0);
            this.computeScaleBounds();
            if (Object.keys(components).length) {
              this.computeScaleFactor();
            }
          }
          DG.ObjectMap.forEach(components, function (key, iComponent) {
            this.createComponentAndView(iComponent);
          }.bind(this));
        }
      },

      enforceViewBounds: function () {
        this.computeScaleFactor();
        DG.ObjectMap.forEach(this.componentControllersMap,
            function (iComponentID, iController) {
              if (iController) {
                var view = iController.get('view');
                if (view && !view.get('isStandaloneComponent')) {
                  view.enforceViewBounds();
                }
              }
            });
      },
      /**
       Sets scaleBoundsX and scaleBoundsY of inBoundsScaling property, these
       values are the target bounds of the component layout and used to determine
       when we need to scale and reposition components due to changes in the
       parent container size.
       Computed when we add, delete, move, resize component.
       @param iNewPos: a new position that will be included in the component
       list once the component creation is complete
       */
      computeScaleBounds: function (iNewPos) {
        var components = this.get('components');
        if (components) {
          var scaleBounds = {x: 0, y: 0},
              storedScaleFactor = this.get('inBoundsScaling').scaleFactor,
              scaleFactor = storedScaleFactor ? storedScaleFactor : 1;
          // Only compute new bounds if scaleFactor = 1, the max value.
          // In this case we are showing the components with original layout
          // and the container may include additional space where the bounds
          // can grow. If scaleFactor < 1, then the container edge has
          // already reached the boundary edge and there is no space for the
          // bounds to grow.
          if (scaleFactor === 1) {
            if (iNewPos) {
              scaleBounds.x = Math.max(scaleBounds.x, iNewPos.x + iNewPos.width);
              scaleBounds.y = Math.max(scaleBounds.y, iNewPos.y + iNewPos.height);
            }
            DG.ObjectMap.forEach(components, function (key, iComponent) {
              // If we have a valid, visible component, determine if its position and
              // size are determining factors in the computing the scaleBounds
              if (iComponent.type !== 'DG.GuideView' || !this.guideViewHidden()) {
                if (iComponent.get('isVisible') &&
                    iComponent.layout &&
                    ((iComponent.layout.left != null) &&
                        (iComponent.layout.width != null) &&
                        (iComponent.layout.top != null) &&
                        (iComponent.layout.height != null))) {

                  // Include the inspector size in scaleBounds calculation
                  var tInspectorDimensions = {width: 0, height: 0};
                  var controller = DG.currDocumentController().componentControllersMap[iComponent.get('id')];
                  if (controller) {
                    var view = controller.get('view');
                    if (view) {
                      tInspectorDimensions = view.getInspectorDimensions();
                    }
                  }
                  // Get the rightmost edge of the component
                  var unscaledRightEdge = (iComponent.layout.left + iComponent.layout.width);
                  if (tInspectorDimensions.width) {
                    unscaledRightEdge += tInspectorDimensions.width;
                  }
                  // Get the bottommost edge of the component
                  var unscaledBottomEdge = (iComponent.layout.top + iComponent.layout.height);
                  if (tInspectorDimensions.height && tInspectorDimensions.height > iComponent.layout.height) {
                    unscaledBottomEdge = iComponent.layout.top + tInspectorDimensions.height;
                  }
                  // Do the rightmost or bottommost edge determine new scaleBounds?
                  scaleBounds.x = Math.max(scaleBounds.x, unscaledRightEdge);
                  scaleBounds.y = Math.max(scaleBounds.y, unscaledBottomEdge);
                }
              }
            }.bind(this));
            this.setInBoundsScaleBounds(scaleBounds.x, scaleBounds.y);
          }
        }
      },
      /**
       Computed when we resize browser or load document.
       ScaleFactor is used to compute non-scaled position and size of components.
       */
      computeScaleFactor: function () {
        var docView = DG.mainPage.get('docView'),
            containerWidth = $('#codap').width(),
            containerHeight = $('#codap').height(),
            storedInBoundsScaling = this.get('inBoundsScaling'),
            scaleBoundsX = storedInBoundsScaling.scaleBoundsX,
            scaleBoundsY = storedInBoundsScaling.scaleBoundsY,
            scaleFactor = 1;
        if (!SC.none(docView)) {
          while (!SC.none(docView.parentView.parentView)) {
            docView = docView.parentView;
          }
          containerHeight -= docView.get('frame').y;
        }
        if (containerWidth < scaleBoundsX || containerHeight < scaleBoundsY) {
          scaleFactor = Math.min(containerWidth / scaleBoundsX, containerHeight / scaleBoundsY);
        }
        this.setInBoundsScaleFactor(scaleFactor);
      },

      /**
       The client is a GraphDataConfiguration that wants to know what data context to use to
       display points in a case plot when no attributes have yet been assigned. If there is
       exactly one data context we use it. If there is exactly one data context that has a case table
       or case card, we use it. Otherwise we use the default with null for all properties.
       @returns  {Object}  An Object whose properties specify usable defaults, e.g.
       {Object.dataContext} {DG.DataContext} Default data context to use
       {Object.collectionClient} {DG.CollectionClient} Default collection to use
       {Object.parentCollectionClient} {DG.CollectionClient} Default parent collection
       {Object.plotXAttr}  {DG.Attribute}  The attribute to plot on the X axis by default
       {Object.plotXAttrIsNumeric}  {Boolean}  Whether the default X axis attribute is numeric
       {Object.plotYAttr}  {DG.Attribute}  The attribute to plot on the Y axis by default
       {Object.plotYAttrIsNumeric}  {Boolean}  Whether the default Y axis attribute is numeric
       */
      collectionDefaults: function () {
        var tContexts = this.get('contexts'),
            tUsableContext = null;
        if (tContexts.length === 1)
          tUsableContext = tContexts[0];
        else {
          tContexts = tContexts.filter(function (iContext) {
            var tView = this.tableCardRegistry.getViewForContext(iContext);
            return tView && tView.get('isVisible');
          }.bind(this));
          if (tContexts.length === 1)
            tUsableContext = tContexts[0];
        }
        var tObject = (tUsableContext && tUsableContext.collectionDefaults()) || DG.DataContext.collectionDefaults();
        tObject.dataContext = tUsableContext;
        return tObject;
      },

      /**
       * Add a component to the 'components' list, if not already present.
       *
       * @param iComponent {DG.Component} The new component.
       */
      registerComponent: function (iComponent) {
        var registeredComponents = this.get('components');
        var componentID = iComponent.get('id');
        if (SC.none(registeredComponents[componentID])) {
          registeredComponents[componentID] = iComponent;
        }
      },

      /**
       Configures/initializes the specified component, using the specified params as options.
       If iComponent is not specified, it will be created. Whether the component is created
       or passed in, it will then be initialized, using the specified parameters. This allows
       initialization to be handled in common, whether components are newly created by the
       user or restored from document.
       @param  {DG.Component}  iComponent -- [Optional] The component to be initialized/configured.
       If not provided, it will be created.
       @param {Object}         iParams --  Initialization/configuration properties
       */
      configureComponent: function (iComponent, iParams) {
        var isRestoring = !SC.none(iComponent),
            documentID = this.get('documentID'),
            tComponent = iComponent,
            tController = iParams.controller;

        // If we're not restoring, then we must create it.
        if (!isRestoring) {
          var tComponentProperties = {type: iParams.componentClass.type, id: iParams.contentProperties.id};
          // If we create it, hook it up to the document.
          if (!SC.none(this.content))
            tComponentProperties.document = this.content;
          tComponent = DG.Component.createComponent(tComponentProperties);
          if (!SC.none(iParams.isResizable))
            tComponent.set('isResizable', iParams.isResizable);
        } else {
          this.registerComponent(tComponent);
        }

        // If client specified a model, associate it with the component in our map
        if (iParams.contentProperties && iParams.contentProperties.model)
          tComponent.set('content', iParams.contentProperties.model);

        // Hook up the controller to its model (the component)
        tController.set('model', tComponent);

        // Add the component controller to our registry of component controllers
        this.componentControllersMap[tComponent.get('id')] = tController;

        // If we're restoring, restore the archived contents
        if (isRestoring) {
          // restore from archive
          tController.didRestoreComponent(documentID);
        }

        return tComponent;
      },

      createComponentView: function (iComponent, iParams) {
        var tParams = $.extend({}, iParams, {layout: $.extend(true, {}, iParams.defaultLayout)}),
            isRestoring = !SC.none(iComponent),
            tComponent, tComponentView;

        DG.globalEditorLock.commitCurrentEdit();

        //
        // Configure/create the component and hook it up to the controller
        //
        tComponent = this.configureComponent(iComponent, iParams);
        tParams.model = tComponent;

        //
        // Configure/create the view and connect it to the controller
        //
        var tComponentLayout = tComponent.get('layout');
        if (tComponent && tComponentLayout && Object.keys(tComponentLayout).length > 0)
          tParams.layout = $.extend(true, {}, tComponentLayout);

        if (isRestoring) {
          var tRestoredTitle = iComponent.getPath('componentStorage.title');
          var tRestoredName = iComponent.getPath('componentStorage.name');
          iComponent.set('title', tRestoredTitle || tRestoredName);
          if (tRestoredName)
            iComponent.set('name', tRestoredName);
          if (DG.isStandaloneComponent(iComponent.get('name') || iComponent.get('title'), iComponent.get('type'))) {
            tParams.useLayout = true;
            tParams.layout = {};
            tParams.isStandaloneComponent = true;
          }
          tComponentView = DG.ComponentView.restoreComponent(tParams);
        } else {
          DG.sounds.playCreate();
          if (DG.isStandaloneComponent(iParams.name, iParams.componentClass.type)) {
            tParams.isStandaloneComponent = true;
          }
          tComponentView = DG.ComponentView.addComponent(tParams);
          var defaultFirstResponder = tComponentView && tComponentView.getPath('contentView.defaultFirstResponder');
          tComponent.set('title', iParams.title || iParams.name);
          tComponent.set('name', iParams.name || iParams.title);
          if (defaultFirstResponder) {
            if (defaultFirstResponder.beginEditing) {
              defaultFirstResponder.beginEditing();
            } else if (defaultFirstResponder.becomeFirstResponder) {
              defaultFirstResponder.becomeFirstResponder();
            }
          }
        }

        if (tComponentView) {
          // Tell the controller about the new view, whose layout we will need when archiving.
          if (iParams.controller) {
            iParams.controller.set('view', tComponentView);
          }
          tComponent.set('layout', tComponentView.get('layout'));
        }

        return tComponentView;
      },

      addGame: function (iParentView, iComponent, isInitialization) {
        // It should return a document name, e.g.:
        // /datagame/game.html => game
        // /datagame/game.html?param=abc.123 => game
        // /datagame/game?param=abc.123 => game
        function getNameFromURL(iUrl) {
          if (!iUrl) {
            return;
          }
          var a = document.createElement("a");
          a.href = iUrl;
          var doc = a.pathname.split("/").slice(-1)[0].split(".");
          // At this point doc could be equal to ["game", "html"] or ["game"] if .html was not present.
          return doc[0];
        }

        var tGameParams = {
              width: 300, height: 200
            },
            tLayout = iComponent && iComponent.layout,
            tIsVisible = tLayout && !SC.none(tLayout.isVisible) ? tLayout.isVisible : true,
            // if we are restoring a component from a document then it will have
            // a position in the hierarchy
            tIsRestoredComponent = tLayout && tLayout.zIndex,
            // 'di' URL param can override stored URL
            storedGameUrl = iComponent && iComponent.getPath('componentStorage.currentGameUrl'),
            tGameUrl = DG.finalGameUrl(storedGameUrl),
            tGameName = (iComponent && iComponent.getPath(
                    'componentStorage.currentGameName')) ||
                getNameFromURL(tGameUrl) ||
                'Unknown Game',
            tView;
        if (!DG.STANDALONE_MODE && iComponent.get('type') === 'DG.GameView'
            && iComponent.layout && !iComponent.layout.width) {
          iComponent.layout.width = tGameParams.width;
          iComponent.layout.height = tGameParams.height;
        }
        DG.UndoHistory.execute(DG.Command.create({
          name: 'game.create',
          undoString: 'DG.Undo.game.add',
          redoString: 'DG.Redo.game.add',
          log: 'addGame: {name: "%@", url: "%@"}'.fmt(tGameName, tGameUrl),
          isUndoable: !isInitialization,
          _component: null,
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'create game controller',
              type: 'DG.WebView'
            }
          },
          execute: function () {
            var tController = DG.GameController.create();
            tView = DG.currDocumentController().createComponentView(iComponent || this._component, {
              parentView: iParentView,
              controller: tController,
              componentClass: {
                type: 'DG.GameView',
                constructor: DG.GameView
              },
              contentProperties: {
                controller: tController,
                value: tGameUrl,
                model: DG.DataInteractiveModel.create({title: tGameName})
              },
              defaultLayout: {
                width: tGameParams.width,
                height: tGameParams.height
              },
              position: iComponent && iComponent.position,
              title: tGameName,
              useLayout: !!tLayout,
              positionOnCreate: true
            });
            if (!tIsVisible) {
              tView.set('isVisible', false);
            } else if (!tIsRestoredComponent) {
              tView.select();
            }
            this._component = tController.get('model');
          },
          undo: function () {
            var controller = DG.currDocumentController().componentControllersMap[this._component.get('id')],
                view = controller.get('view');
            controller.willSaveComponent();
            view.parentView.removeComponentView(view);
          }
        }));

        // Override default component view behavior.
        // Do nothing until we figure out how to prevent reloading of data interactive.
        //tView.select = function () {
        //};

        return tView;
      },

      /**
       * Adds a case table to the workspace view.
       *
       * When a document is restored, iComponent is the object restored from the
       * document component. Otherwise it is null.
       *
       * @param {SC.View} iParentView
       * @param {DG.Component||null} iComponent
       * @param {object||null} iProperties
       * @returns {DG.HierTableView}
       */
      addCaseTable: function (iParentView, iComponent, iProperties) {
        function resolveContextLink(iComponent) {
          var id = DG.ArchiveUtils.getLinkID(iComponent.componentStorage, 'context');
          if (id) {
            return DG.currDocumentController().get('contexts').find(function (context) {
              return context.get('id') === id;
            });
          }
        }

        if (SC.none(iProperties)) {
          iProperties = {};
        }
        var context = iProperties.dataContext || resolveContextLink(iComponent);
        var caseTableView = this.tableCardRegistry.getViewForContext(context);
        var component = this.getCaseTableComponent(iComponent, context, iProperties);
        var model = component.get('content') || DG.CaseTableModel.create({context: context});

        if (!caseTableView) {
          var controller = DG.CaseTableController.create(iProperties);
          var componentClassDef = {type: 'DG.TableView', constructor: DG.HierTableView};
          var props = {
            parentView: iParentView,
            controller: controller,
            componentClass: componentClassDef,
            contentProperties: {model: model, id: iProperties.id}, // Temporarily using context as model in order to get a title
            defaultLayout: {width: 500, height: 200},
            useLayout: iProperties.useLayout,
            position: iComponent ? iComponent.position : iProperties.position
          };
          caseTableView = this.createComponentView(component, props);
          if (iComponent && iComponent.layout && !iComponent.layout.isVisible) {
            caseTableView.savedLayout = iComponent.layout;
          }

        } else {
          caseTableView.set('isVisible', true);
        }

        if (caseTableView.get('isVisible')) {
          model.set('isActive', true);
        }
        this.tableCardRegistry.registerView(context, caseTableView);
        return caseTableView;
      },

      /**
       * Create a case table for each context if the components do not exist
       * already.
       *
       * This method is supported for backwards compatibility.
       *
       * @return {[DG.CaseTableView]} one for each case table created.
       */
      openCaseTablesForEachContext: function () {
        var docController = this,
            newViews = {};
        DG.UndoHistory.execute(DG.Command.create({
          name: 'caseTable.display',
          undoString: 'DG.Undo.caseTable.open',
          redoString: 'DG.Redo.caseTable.open',
          log: 'Create caseTable component',
          executeNotification: {
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'open case table',
              type: 'DG.CaseTable'
            }
          },
          execute: function () {
            var view;
            docController.contexts.forEach(function (context) {
              view = this.addCaseTable(DG.mainPage.get('docView'), null,
                  {dataContext: context, id: newViews[context]});
              newViews[context] = view.getPath('controller.model.id');
            }.bind(docController));
            if (newViews.length === 0) {
              this.causedChange = false;
            }
          },
          undo: function () {
            var view, controller, containerView;
            DG.ObjectMap.forEach(newViews, function (context, modelId) {
              controller = docController.componentControllersMap[modelId];
              view = controller.get('view');
              containerView = view.parentView;
              containerView.removeComponentView(view);
            });
          }
        }));
        return Object.values(newViews);
      },

      addGraph: function (iParentView, iComponent, isInitialization, iStorage) {
        var tView,
            this_ = this,
            tLayout = iStorage && iStorage.layout,
            tDefaultLayout = iComponent && iComponent.size ? iComponent.size :
                (tLayout ? tLayout : {width: 300, height: 300});
        iStorage = (iStorage && iStorage.componentStorage) || (iComponent && iComponent.componentStorage);

        DG.UndoHistory.execute(DG.Command.create({
          name: "graphComponent.create",
          undoString: 'DG.Undo.graphComponent.create',
          redoString: 'DG.Redo.graphComponent.create',
          executeNotification: DG.UndoHistory.makeComponentNotification('create', 'graph'),
          undoNotification: DG.UndoHistory.makeComponentNotification('delete', 'graph'),
          log: 'Create graph component',
          _component: null,
          isUndoable: !isInitialization,
          execute: function () {
            var tContextIds = DG.DataContext.contextIDs(null),
                tController = DG.GraphController.create();

            if ((SC.none(iComponent) && SC.none(this._component) || !(iStorage && iStorage.dataContext)) &&
                DG.ObjectMap.length(tContextIds) === 1) {
              tController.set('dataContext',
                  this_.getContextByID(tContextIds[0]));
            } else if (iStorage && iStorage.dataContext) {
              tController.set('dataContext', iStorage.dataContext);
            }
            tView = this_.createComponentView(iComponent, {
                  parentView: iParentView,
                  controller: tController,
                  componentClass: {type: 'DG.GraphView', constructor: DG.GraphView},
                  contentProperties: {
                    model: DG.GraphModel.create({
                      initialDataContext: iStorage && iStorage.dataContext,
                      xAttributeName: iStorage && iStorage.xAttributeName,
                      yAttributeName: iStorage && iStorage.yAttributeName,
                      y2AttributeName: iStorage && iStorage.y2AttributeName,
                      legendAttributeName: iStorage && iStorage.legendAttributeName,
                      enableNumberToggle: iStorage && iStorage.enableNumberToggle,
                      numberToggleLastMode: iStorage && iStorage.numberToggleLastMode,
                      enableMeasuresForSelection: iStorage && iStorage.enableMeasuresForSelection
                    })
                  },
                  defaultLayout: tDefaultLayout,
                  position: iComponent && iComponent.position,
                }
            );
            this._component = tView.getPath('controller.model');

            // add id's to notifications
            this.executeNotification.values.id = this.undoNotification.values.id = tView.getPath('controller.model.id');


          },
          undo: function () {
            var view = DG.currDocumentController().componentControllersMap[this._component.get('id')].get('view');
            view.parentView.removeComponentView(view);
          }
        }));
        return tView;
      },

      addText: function (iParentView, iComponent, isInitialization) {
        var tView, docController = this;

        DG.UndoHistory.execute(DG.Command.create({
          name: "textComponent.create",
          undoString: 'DG.Undo.textComponent.create',
          redoString: 'DG.Redo.textComponent.create',
          log: 'Create text component',
          isUndoable: !isInitialization,
          _component: null,
          executeNotification: DG.UndoHistory.makeComponentNotification('create', 'text'),
          undoNotification: DG.UndoHistory.makeComponentNotification('delete', 'text'),
          execute: function () {
            tView = docController.createComponentView(iComponent || this._component, {
                  parentView: iParentView,
                  controller: DG.TextComponentController.create(),
                  componentClass: {type: 'DG.TextView', constructor: DG.TextView},
                  contentProperties: {
                    hint: "Type some notes here…",
                    model: DG.TextModel.create({})
                  },
                  defaultLayout: {width: 300, height: 100},
                  position: iComponent && iComponent.position,
                  title: 'DG.DocumentController.textTitle'.loc(), // "Text"
                }
            );
            this._component = tView.getPath('controller.model');
          },
          undo: function () {
            var controller = DG.currDocumentController().componentControllersMap[this._component.get('id')],
                view = controller.get('view');
            controller.willSaveComponent();
            view.parentView.removeComponentView(view);
          }
        }));
        return tView;
      },

      addMap: function (iParentView, iComponent, isInitialization) {
        var tView, docController = this;

        DG.UndoHistory.execute(DG.Command.create({
          name: "map.create",
          undoString: 'DG.Undo.map.create',
          redoString: 'DG.Redo.map.create',
          log: 'Create map component',
          isUndoable: !isInitialization,
          _component: null,
          executeNotification: DG.UndoHistory.makeComponentNotification('create', 'map'),
          undoNotification: DG.UndoHistory.makeComponentNotification('delete', 'map'),
          execute: function () {
            var tProperties = (iComponent && iComponent.componentStorage) ? {
                      legendAttributeName: iComponent.componentStorage.legendAttributeName,
                      context: iComponent.componentStorage.context
                    } : {},
                tMapModel = DG.MapModel.create(tProperties),
                tMapController = DG.MapController.create();

            // map as component
            tView = docController.createComponentView(iComponent || this._component, {
                  parentView: iParentView,
                  controller: tMapController,
                  componentClass: {type: 'DG.MapView', constructor: DG.MapView},
                  contentProperties: {model: tMapModel},
                  defaultLayout: {width: 530, height: 360},
                  position: iComponent && iComponent.position,
                  title: 'DG.DocumentController.mapTitle'.loc(), // "Map"
                }
            );
            this._component = tView.getPath('controller.model');
          },
          undo: function () {
            var view = DG.currDocumentController().componentControllersMap[this._component.get('id')].get('view');
            view.parentView.removeComponentView(view);
          }
        }));
        return tView;
      },

      addSlider: function (iParentView, iComponent, isInitialization) {
        var tView, docController = this;

        DG.UndoHistory.execute(DG.Command.create({
          name: "sliderComponent.create",
          undoString: 'DG.Undo.sliderComponent.create',
          redoString: 'DG.Redo.sliderComponent.create',
          log: 'Create slider component',
          isUndoable: !isInitialization,
          _global: null,
          _componentId: null,
          executeNotification: DG.UndoHistory.makeComponentNotification('create', 'slider'),
          undoNotification: DG.UndoHistory.makeComponentNotification('delete', 'slider'),
          execute: function () {
            var globalName = iComponent && (iComponent.componentStorage.name || iComponent.componentStorage.title);
            this._global = this._global ||
                (iComponent && iComponent.componentStorage &&
                    DG.store.find(DG.GlobalValue, DG.ArchiveUtils.getLinkID(iComponent.componentStorage, 'model'))) ||
                docController.createGlobalValue({name: globalName});
            if (!DG.globalsController.getGlobalValueByID(Number(this._global.get('id')))) {
              DG.globalsController.registerGlobalValue(this._global);
            }

            var tSliderModel = DG.SliderModel.create({content: this._global});
            tView = docController.createComponentView(iComponent, {
                  parentView: iParentView,
                  controller: DG.SliderController.create(),
                  componentClass: {type: 'DG.SliderView', constructor: DG.SliderView},
                  contentProperties: {id: this._componentId, model: tSliderModel},
                  defaultLayout: {width: 300, height: 98},
                  position: iComponent && iComponent.position,
                  isResizable: {width: true, height: false}
                }
            );
            this._componentId = tView.getPath('controller.model.id');
          },
          undo: function () {
            var controller = DG.currDocumentController().componentControllersMap[this._componentId];
            var view = controller.get('view');
            view.parentView.removeComponentView(view);
            DG.globalsController.destroyGlobalValue(this._global);
          }
        }));
        return tView;
      },

      addCalculator: function (iParentView, iComponent) {
        // No Undo wrapping for this here, as it's handled in toggleComponent()
        var tView = this.createComponentView(iComponent, {
              parentView: iParentView,
              controller: DG.ComponentController.create(),
              componentClass: {type: 'DG.Calculator', constructor: DG.Calculator},
              contentProperties: {},
              defaultLayout: {},
              position: iComponent && iComponent.position,
              title: 'DG.DocumentController.calculatorTitle'.loc(), // "Calculator"
              isResizable: {width: false, height: false}
            }
        );
        this._singletonViews.calcView = tView;
        return tView;
      },

      addCaseCard: function (iParentView, iLayout, iContext, iComponent, iTitle) {

        function findPreexistingCaseCardComponentView() {
          return DG.mainPage.getPath('docView.childViews').find(function (iChildView) {
            return iChildView.contentIsInstanceOf && iChildView.contentIsInstanceOf(DG.CaseCardView) &&
                iChildView.getPath('contentView.context') === iContext;
          });
        }

        var tTableView = iContext && this.tableCardRegistry.getTableView(iContext);
        var tPreexistingCaseCard = findPreexistingCaseCardComponentView();
        if (tPreexistingCaseCard) { // We've already got one for this context. Only one allowed.
          return tPreexistingCaseCard;
        }
        var tNewComponent = !(iComponent || tPreexistingCaseCard);
        var tController = DG.CaseCardController.create({
              dataContext: iContext
            }),
            tTitle = iTitle || (iContext ? iContext.get('name') : 'DG.DocumentController.caseCardTitle'.loc()),
            tComponent = iComponent, tRestoredLayout = iLayout || {};
        if (!tComponent) {
          // creating component
          tComponent = this.configureComponent(iComponent, {
            controller: tController,
            componentClass: {type: 'DG.CaseCard'},
            contentProperties: {}
          });
          tComponent.set('content', DG.CaseCardModel.create({context: iContext}));
          tComponent.set('title', tTitle);
        } else {
          // restoring component
          var tRestoredTitle = tComponent.getPath('componentStorage.title'),
              tRestoredName = tComponent.getPath('componentStorage.name');
          tRestoredLayout = tComponent.get('layout');
          tComponent.set('content', DG.CaseCardModel.create({context: iContext}));
          tComponent.set('title', tRestoredTitle || tRestoredName);
          if (tRestoredName)
            tComponent.set('name', tRestoredName);
          tController.set('model', tComponent);
          this.componentControllersMap[tComponent.get('id')] = tController;
          tController.didRestoreComponent(this.get('documentID'));
          iContext = tController.get('dataContext');
        }
        var tComponentView = DG.ComponentView.create({
              layout: tRestoredLayout,
              isVisible: !SC.none(tRestoredLayout.isVisible) ? tRestoredLayout.isVisible : true,
              showTitleBar: true
            }),
            tContentView = DG.CaseCardView.create({
              classNames: 'dg-opaque'.w() /*dg-scrollable'.w()*/,
              model: tComponent.get('content'),
              isSelectedCallback: function () {
                return tComponentView.get('isSelected');
              }
            });
        tComponentView.set('model', tComponent);
        iParentView.appendChild(tComponentView);
        tComponentView.addContent(tContentView);
        tComponentView.set('contentView', tContentView);
        tComponentView.set('controller', tController);
        // If the case table has existed, our position has been determined by
        // its position, so we bypass the layout operation.
        if (tNewComponent && !tTableView) {
          iParentView.positionNewComponent(tComponentView);
        }
        tController.set('view', tComponentView);
        this.registerComponent(tComponent);
        if (tComponentView.get('isVisible')) {
          tComponent.setPath('content.isActive', true);
        }
        this.tableCardRegistry.registerView(iContext, tComponentView);

        return tComponentView;
      },

      /**
       * Puts a modal dialog with a place for a URL.
       * If user OK's, the URL is used for an added web view.
       */
      viewWebPage: function () {

        var tDialog = null;

        function createWebPage() {
          // User has pressed OK. tURL must have a value or 'OK' disabled.
          var tURL = tDialog.get('value');
          tDialog.close();
          // If url does not contain http:// or https:// at the beginning, append http://
          if (!/^https?:\/\//i.test(tURL)) {
            tURL = 'http://' + tURL;
          }
          DG.appController.importURL(tURL, "DG.WebView", tURL);
        }

        tDialog = DG.CreateSingleTextDialog({
          prompt: 'DG.DocumentController.enterURLPrompt',
          textValue: '',
          textHint: 'URL',
          okTarget: null,
          okAction: createWebPage,
          okTooltip: 'DG.DocumentController.enterViewWebPageOKTip'
        });
      },
      addWebView: function (iParentView, iComponent, iURL, iTitle, iLayout, isInitialization) {
        iURL = iURL || '';
        iTitle = iTitle || '';
        iLayout = iLayout || {width: 600, height: 400};
        var tView;
        DG.UndoHistory.execute(DG.Command.create({
          name: 'webView.show',
          undoString: 'DG.Undo.webView.show',
          redoString: 'DG.Redo.webView.show',
          log: 'Show webView: {title: "%@", url: "%@"}'.fmt(iTitle, iURL),
          isUndoable: !isInitialization,
          _component: null,
          model: SC.Object.create({
            defaultTitle: iTitle,
            URL: iURL
          }),
          executeNotification: DG.UndoHistory.makeComponentNotification('create', 'webView'),
          undoNotification: DG.UndoHistory.makeComponentNotification('delete', 'webView'),
          execute: function () {
            tView = DG.currDocumentController().createComponentView(iComponent || this._component, {
                  parentView: iParentView,
                  controller: DG.WebViewController.create({model: this.model}),
                  componentClass: {type: 'DG.WebView', constructor: DG.WebView},
                  contentProperties: {value: iURL, backgroundColor: 'white', model: this.model},
                  defaultLayout: iLayout,
                  position: iComponent && iComponent.position,
                  title: iTitle,
              // As a V2 patch, to fix a plugin api problem found by PhET team, we force useLayout to be false
              // unless the incoming layout is specified with a center or left coordinate. The bug was that
              // the plugin positioning was not being respected. This has been an error-prone area of the code.
              // We are trying to fix the bug without breaking other things. V3 will do better!
                  useLayout: /*!SC.none(iComponent) ||*/ !SC.none(iLayout.centerX) || !SC.none(iLayout.left)
                }
            );
            this._component = tView.getPath('controller.model');
          },
          undo: function () {
            var view = DG.currDocumentController().componentControllersMap[this._component.get('id')].get('view');
            view.parentView.removeComponentView(view);
          }
        }));
        return tView;
      },

      addImageView: function (iParentView, iComponent, iURL, iTitle, iLayout, isInitialization) {
        iURL = iURL || '';
        iTitle = iTitle || iURL || '';
        iLayout = iLayout || {width: 600, height: 400};
        var tView;
        DG.UndoHistory.execute(DG.Command.create({
          name: 'webView.show',
          undoString: 'DG.Undo.imageComponent.show',
          redoString: 'DG.Redo.imageComponent.show',
          log: 'Show webView: {title: "%@", url: "%@"}'.fmt(iTitle, iURL),
          isUndoable: !isInitialization,
          _component: null,
          model: SC.Object.create({
            defaultTitle: iTitle || 'DG.ImageComponent.defaultTitle'.loc(),
            URL: iURL
          }),
          executeNotification: DG.UndoHistory.makeComponentNotification('create', 'imageComponent'),
          undoNotification: DG.UndoHistory.makeComponentNotification('delete', 'imageComponent'),
          execute: function () {
            tView = DG.currDocumentController().createComponentView(iComponent || this._component, {
                  parentView: iParentView,
                  controller: DG.ImageComponentController.create({model: this.model}),
                  componentClass: {type: 'DG.ImageComponentView', constructor: DG.ImageComponentView},
                  contentProperties: {value: iURL, backgroundColor: 'white', model: this.model},
                  defaultLayout: iLayout,
                  position: iComponent && iComponent.position,
                  title: iTitle,
                  useLayout: true
                }
            );
            this._component = tView.getPath('controller.model');
          },
          undo: function () {
            var view = DG.currDocumentController().componentControllersMap[this._component.get('id')].get('view');
            view.parentView.removeComponentView(view);
          }
        }));
        return tView;
      },

      addGuideView: function (iParentView, iComponent, isInitialization) {
        if (this._singletonViews.guideView) {
          // only one allowed
          DG.UndoHistory.execute(DG.Command.create({
            name: 'guide.show',
            undoString: 'DG.Undo.guide.show',
            redoString: 'DG.Redo.guide.show',
            log: 'Show guide',
            isUndoable: !isInitialization,
            execute: function () {
              DG.currDocumentController()._singletonViews.guideView.set('isVisible', true);
            },
            undo: function () {
              DG.currDocumentController()._singletonViews.guideView.set('isVisible', false);
            }
          }));
        } else {
          var tModel = this.get('guideModel'),
              tController = this.get('guideController'),
              tView = this.createComponentView(iComponent, {
                    parentView: iParentView,
                    controller: tController,
                    componentClass: {type: 'DG.GuideView', constructor: DG.GuideView},
                    contentProperties: {
                      backgroundColor: 'white', guideModel: tModel, model: tModel,
                      controller: tController,
                      closeAction: {action: this.closeGuideView, target: this}
                    },
                    defaultLayout: {width: 400, height: 200},
                    position: iComponent && iComponent.position,
                    useLayout: true
                  }
              );
          this._singletonViews.guideView = tView;
        }
        return this._singletonViews.guideView;
      },

      /**
       * This gets called when the user 'closes' the guide view. Instead of removing the
       * component and its view, we just hide it for future use.
       */
      closeGuideView: function () {
        var tGuideComponentView = this._singletonViews.guideView;
        if (tGuideComponentView) {
          tGuideComponentView.set('isVisible', false);
        }
      },

      guideViewHidden: function () {
        var tGuideComponentView = this._singletonViews.guideView,
            guideHidden = false;
        if (tGuideComponentView) {
          guideHidden = !tGuideComponentView.get('isVisible');
        }
        return guideHidden;
      },

      /**
       * Puts a modal dialog with a place for a URL. If user OK's, the URL is used for an added web view.
       */
      configureGuide: function () {

        var this_ = this,
            tDialog = null,
            tGuideModel = this.get('guideModel'),  // guideModel is a singleton, so it's ok to reference it directly.

            storeGuideModel = function () {
              DG.UndoHistory.execute(DG.Command.create({
                name: 'guide.configure',
                undoString: 'DG.Undo.guide.configure',
                redoString: 'DG.Redo.guide.configure',
                log: 'Show guide',
                changedObject: tGuideModel,
                _oldValues: {
                  title: tGuideModel.get('title'),
                  items: tGuideModel.get('items'),
                  currentItemIndex: tGuideModel.get('currentItemIndex')
                },
                _newValues: {
                  title: tDialog.get('title'),
                  items: tDialog.get('items')
                },
                execute: function () {
                  if (tDialog) {
                    // Only do this the first time we're executed.
                    DG.currDocumentController().addGuideView(DG.mainPage.docView);  // Make sure we have one hooked up to model
                  }
                  tGuideModel.beginPropertyChanges();
                  tGuideModel.set('title', this._newValues.title);
                  tGuideModel.set('items', this._newValues.items);
                  tGuideModel.endPropertyChanges();
                  if (tDialog) {
                    tDialog.close();
                    tDialog = null;
                  }
                  if (!SC.empty(this._newValues.title) || this._newValues.items.length !== 0) {
                    // The configuration is such that we must make sure the guide is visible
                    this_._singletonViews.guideView.set('isVisible', true);
                  }
                },
                undo: function () {
                  tGuideModel.beginPropertyChanges();
                  tGuideModel.set('title', this._oldValues.title);
                  tGuideModel.set('items', this._oldValues.items);
                  tGuideModel.set('currentItemIndex', this._oldValues.currentItemIndex);
                  tGuideModel.endPropertyChanges();
                  if (SC.empty(this._oldValues.title) && this._oldValues.items.length === 0) {
                    // We're undoing the original making of the guide view just by hiding it
                    this_._singletonViews.guideView.set('isVisible', false);
                  }
                }
              }));
            };


        tDialog = DG.CreateGuideConfigurationView({
          okTarget: null,
          okAction: storeGuideModel,
          model: tGuideModel
        });
      },

      /**
       * If we have both a button and a menu pane, we can pass them to the guideController.
       */
      guideButtonOrMenuDidChange: function () {
        var tButton = this.get('guideButton'),
            tPane = this.get('guideMenuPane');
        if (tButton && tPane) {
          var tController = this.get('guideController');
          tController.set('guideButton', tButton);
          tController.set('guideMenuPane', tPane);
        }
      }.observes('guideButton', 'guideMenuPane'),

      /**
       * There is currently only one component that comes through here, 'CalcView'
       * @param iDocView
       * @param iComponentName
       */
      toggleComponent: function (iDocView, iComponentName, iComponent) {
        var componentView = this._singletonViews[iComponentName],
            componentArchive;
        // If it already exists, then delete it.
        if (componentView) {
          DG.UndoHistory.execute(DG.Command.create({
            name: 'component.toggle.delete',
            undoString: 'DG.Undo.toggleComponent.delete.' + iComponentName,
            redoString: 'DG.Redo.toggleComponent.delete.' + iComponentName,
            log: 'Remove toggle component: %@'.fmt(iComponentName),
            executeNotification: DG.UndoHistory.makeComponentNotification('hide', iComponentName),
            undoNotification: DG.UndoHistory.makeComponentNotification('show', iComponentName),
            execute: function () {
              componentArchive = this._archiveComponent(iComponentName);
              this._deleteComponent(iComponentName);
            }.bind(this),
            undo: function () {
              this._addCalcComponent(iComponentName, iDocView, componentArchive);
            }.bind(this),
            redo: function () {
              this._deleteComponent(iComponentName);
            }.bind(this)
          }));
        }
        // If it doesn't exist, then create it.
        else {
          DG.UndoHistory.execute(DG.Command.create({
            name: 'component.toggle.add',
            undoString: 'DG.Undo.toggleComponent.add.' + iComponentName,
            redoString: 'DG.Redo.toggleComponent.add.' + iComponentName,
            log: 'Add toggle component: %@'.fmt(iComponentName),
            executeNotification: DG.UndoHistory.makeComponentNotification('show', iComponentName),
            undoNotification: DG.UndoHistory.makeComponentNotification('hide', iComponentName),
            execute: function () {
              this._addCalcComponent(iComponentName, iDocView, iComponent);
            }.bind(this),
            undo: function () {
              componentArchive = this._archiveComponent(iComponentName);
              this._deleteComponent(iComponentName);
            }.bind(this),
            redo: function () {
              this._addCalcComponent(iComponentName, iDocView, componentArchive);
            }.bind(this)
          }));
        }
      },

      toggleTableToCard: function (iTableComponentView) {
        var kDefaultCardWidth = 200,
            kDefaultCardHeight = 400,
            tContext = iTableComponentView.getPath('controller.dataContext'),
            tCannotClose = iTableComponentView.getPath('model.cannotClose'),
            tTableLayout = iTableComponentView.get('layout'),
            tCardInitialLayout = {
              top: tTableLayout.top, left: tTableLayout.left,
              width: kDefaultCardWidth, height: DG.ViewUtilities.kTitleBarHeight
            },
            tCardFinalLayout = {
              height: kDefaultCardHeight
            },
            tCardComponentView;
        iTableComponentView.set('savedLayout', tTableLayout);
        // animate case table to default card width, then animate to closed height,
        // then toggle to case card and animate to final position
        iTableComponentView.animate({width: kDefaultCardWidth}, {duration: 0.3, timing: 'ease-in-out'});
        this.invokeLater(function () {
          iTableComponentView.animate({height: DG.ViewUtilities.kTitleBarHeight},
              {duration: 0.3, timing: 'ease-in-out'});
        }, 300);
        this.invokeLater(function () {
          iTableComponentView.set('isVisible', false);
          tTableLayout.isVisible = false;
          // restore position of invisible component, so it will come back to the right place.
          iTableComponentView.set('layout', tTableLayout);
          iTableComponentView.setPath('model.content.isActive', false);
          tCardComponentView = this.tableCardRegistry.getCardView(tContext) ||
              this.addCaseCard(iTableComponentView.get('parentView'),
                  tCardInitialLayout, tContext, null, iTableComponentView.get('title'));
          tCardComponentView.setPath('model.cannotClose', tCannotClose);
          tCardComponentView.set('layout', tCardInitialLayout);
          var tCardLayout = tCardComponentView.get('savedLayout') || tCardFinalLayout;
          if (!tCardComponentView.get('savedLayout')) {
            tCardComponentView.set('savedLayout', tCardLayout);
          }
          tCardComponentView.set('isVisible', true);

          tCardComponentView.select();
          tCardComponentView.setPath('model.content.isActive', true);
          this.tableCardRegistry.registerView(tContext, tCardComponentView);
        }.bind(this), 600);
      },

      toggleCardToTable: function (iCardComponentView) {
        var kDefaultCardWidth = 200,
            tCardLayout = iCardComponentView.get('layout'),
            tCannotClose = iCardComponentView.getPath('model.cannotClose'),
            tTableInitialLayout = {
              top: tCardLayout.top, left: tCardLayout.left,
              width: kDefaultCardWidth, height: DG.ViewUtilities.kTitleBarHeight
            },
            tContext = iCardComponentView.getPath('controller.dataContext');
        iCardComponentView.set('isAnimating', true);
        iCardComponentView.set('savedLayout', tCardLayout);
        // animate case card to default card width, then animate to closed height,
        // then toggle to case table and animate to final position
        iCardComponentView.animate({width: kDefaultCardWidth}, {duration: 0.3, timing: 'ease-in-out'},
            function () {
              iCardComponentView.animate({height: DG.ViewUtilities.kTitleBarHeight},
                  {duration: 0.3, timing: 'ease-in-out'},
                  function () {
                    iCardComponentView.set('isVisible', false);
                    iCardComponentView.set('isAnimating', false);
                    tCardLayout.isVisible = false;
                    iCardComponentView.set('layout', tCardLayout);
                    iCardComponentView.setPath('model.content.isActive', false);
                    var tTableComponentView = this.tableCardRegistry.getTableView(tContext) ||
                            this.addCaseTable(iCardComponentView.get('parentView'), null, {
                              dataContext: iCardComponentView.getPath('controller.dataContext'),
                              useLayout: true // use layout for position
                            }),
                        tTableLayout = tTableComponentView.get('savedLayout') || {width: 500, height: 200},
                        tAnimatableLayout = {
                          left: tTableLayout.left,
                          top: tTableLayout.top,
                          width: tTableLayout.width,
                          height: tTableLayout.height
                        };
                    tTableComponentView.setPath('model.cannotClose', tCannotClose);
                    tTableComponentView.set('layout', tTableInitialLayout);
                    tTableComponentView.set('isVisible', true);
                    tAnimatableLayout.height++;
                    tTableComponentView.animate(tAnimatableLayout, {duration: 0.3, timing: 'ease-in-out'},
                        function () {
                          SC.run(function () {
                            tTableComponentView.select();
                            tAnimatableLayout.height--;
                            tTableComponentView.adjust('height',
                                tAnimatableLayout.height);
                            this.invokeNext(function () {
                              tTableComponentView.get(
                                  'contentView').scrollSelectionToView();
                            }.bind(this));
                          }.bind(this));
                        });
                    tTableComponentView.setPath('model.content.isActive', true);
                    this.tableCardRegistry.registerView(tContext, tTableComponentView);
                  }.bind(this));
            }.bind(this));
      },

      /**
       * Helper for toggleComponent. Creates a new component and adds it to the view/document.
       * Though awkward, we currently only use this for DG.Calculator. The componentArchive parameter
       * can be missing, an archive object, or the model object. If it's the model object, we
       * check to make sure it is already stored and, if so, use it as the component.
       */
      _addCalcComponent: function (iComponentName, iDocView, componentArchive) {
        var tComponentID = componentArchive && componentArchive.get('id'),
            tStoredComponent = DG.store.find(tComponentID),
            component = (tStoredComponent && tStoredComponent === componentArchive) ? tStoredComponent :
                (componentArchive ? DG.Component.createComponent(componentArchive) : null);
        switch (iComponentName) {
          case 'calcView':
            this.addCalculator(iDocView, component);
            break;
        }
      },

      /**
       * Helper for toggleComponent. Saves a component's state in preparation for being deleted,
       * so we can restore it later.
       */
      _archiveComponent: function (iComponentName) {
        var component = this._singletonViews[iComponentName].getPath('controller.model'),
            componentArchive = component.toArchive();
        componentArchive.document = component.get('document');
        return componentArchive;
      },

      /**
       * Helper for toggleComponent. Finds the right component and removes it from the view/document.
       */
      _deleteComponent: function (iComponentName) {
        var componentView = this._singletonViews[iComponentName];
        this.removeComponentAssociatedWithView(componentView);
        componentView.destroy();
      },


      /**
       * Close the document in an orderly way.
       *
       * (a) stop any globals from animating.
       * (b) remove component controllers and components
       * (c) remove contexts
       * (d) remove globals
       *
       * Note: there are a number of singletons involved in, and complicating,
       * this process. We wish to get to a single singleton managing dynamic
       * objects, the app controller. The DG object should remain a singleton, but
       * for managing constants and class prototypes. There should only ever be
       * a single document controller, but a new one should be created with each
       * new document.
       */
      closeDocument: function () {
        /** stop any animation and then destroy globals */
        DG.globalsController.stopAnimation();
        DG.globalsController.reset();

        // Close components
        DG.mainPage.closeAllComponents();

        DG.ObjectMap.forEach(this.componentControllersMap,
            function (iComponentID, iController) {
              if (iController && iController.willDestroy) {
                iController.willDestroy();
              }
            });
        // We need to call closeAllComponents before destroying the controllers
        // Otherwise notifications do not happen that reset the guide button.
        this.closeAllComponents();
        DG.ObjectMap.forEach(this.componentControllersMap,
            function (iComponentID, iController) {
              if (iController && iController.constructor !== DG.GuideController) {
                iController.destroy();
              }
            });
        this.componentControllersMap = {};

        // remove dataContexts
        this.contexts = [];

        if (this.notificationManager) {
          this.notificationManager.destroy();
          this.notificationManager = null;
        }

        // remove document
        DG.Document.destroyDocument(DG.activeDocument);

        // clean up undo history.
        DG.UndoHistory.clearUndoRedoHistory();
      },

      closeAllComponents: function () {
        this._singletonViews = {};
        this.tableCardRegistry.reset();

        // Reset the guide
        if (this._guideController)
          this._guideController.reset();
      },

      findComponentsByType: function (iType) {
        var tResults = [];
        DG.ObjectMap.forEach(this.componentControllersMap, function (key, componentController) {
          if (componentController.constructor === iType && componentController.getPath('view.isVisible')) {
            tResults.push(componentController);
          }
        });
        return tResults;
      },

      removeComponentAssociatedWithView: function (iComponentView) {
        var tController = null,
            tComponentID = DG.ObjectMap.findKey(this.componentControllersMap,
                function (iComponentID, iController) {
                  if (iController.view === iComponentView) {
                    tController = iController;
                    return true;
                  }
                  return false;
                });

        // If this is a singleton view, clear its entry
        var tViewID = DG.ObjectMap.findValue(this._singletonViews, iComponentView);
        if (tViewID && this._singletonViews[tViewID])
          this._singletonViews[tViewID] = null;

        if (tController) {
          var model = tController.get('model');
          if (model)
            DG.Component.destroyComponent(model);
          delete this.componentControllersMap[tComponentID];
          if (tController.get('shouldDestroyOnComponentDestroy')) {
            tController.destroy();
          } else {
            tController.set('model', null);
            tController.set('view', null);
          }
        }
        // the view will be destroyed elsewhere
      },

      addFormulaObject: function (iParentView, iComponent, iTitle, iDescription, iOutputSymbol, iNameSpaceSymbols,
                                  iDescriptions, iAllowUserVariables) {
        var tView = this.createComponentView(iComponent, {
              parentView: iParentView,
              controller: DG.ComponentController.create({}),
              componentClass: {type: 'DG.FormulaObject', constructor: DG.FormulaObject},
              contentProperties: {
                description: iDescription,
                outputSymbol: iOutputSymbol,
                nameSpaceSymbols: iNameSpaceSymbols,
                variableDescriptions: iDescriptions,
                allow_user_variables: iAllowUserVariables
              },
              defaultLayout: {},
              position: iComponent && iComponent.position,
              title: iTitle,
              isResizable: true
            }
        );

        return tView;
      },

      createGlobalValue: function (iProperties) {
        iProperties = iProperties || {};
        iProperties.document = this.get('content');
        return DG.globalsController.createGlobalValue(iProperties);
      },

      /**
       * Retrieve data context by name.
       * @param {string} name
       * @returns {DG.DataContext}
       */
      getContextByName: function (name) {
        return this.contexts.find(function (context) {
          return context.get('name') === name;
        });
      },

      /**
       * Retrieve data context by name.
       * @param {string} name
       * @returns {DG.DataContext}
       */
      getContextByTitle: function (name) {
        return this.contexts.find(function (context) {
          return context.get('title') === name;
        });
      },

      /**
       * Retrieve data context by id.
       *
       * @param {number} id
       * @returns {DG.DataContext}
       */
      getContextByID: function (id) {
        var tID = Number(id);
        return this.contexts.find(function (context) {
          return context.get('id') === tID;
        });
      },

      /**
       * Retrieve component by name.
       * @param {string} name
       * @returns {DG.Component}
       */
      getComponentByName: function (name) {
        var components = DG.ObjectMap.values(DG.currDocumentController().get('components'));
        return components.find(function (c) {
          return c.get('name') === name;
        });
      },

      /**
       * Retrieve component by id.
       *
       */
      getComponentByID: function (id) {
        if (isNaN(id)) {
          return;
        }
        var components = DG.ObjectMap.values(DG.currDocumentController().get('components'));
        return components.find(function (c) {
          return Number(c.get('id')) === Number(id);
        });
      },

      /**
       * The guide index of a restored document can be modified with a URL query
       * parameter. This method performs that operation if the query parameter
       * is present. The method edits the component storage object. **It should,
       * thus, be called only before the component controller and view are
       * constructed.**
       */
      updateGuideFromURL: function () {
        var guideIndex = DG.get('initialGuideIndex');
        if (SC.empty(guideIndex)) return;
        DG.set('initialGuideIndex', '');
        var components = this.get('components');
        var guideComponentKey = Object.keys(components).find(function (iComponentKey) {
          var tComponent = components[iComponentKey];
          return tComponent.type === 'DG.GuideView';
        });
        var guideComponent = guideComponentKey && components[guideComponentKey];
        if (guideComponent && !Number.isNaN(guideIndex)) {
          guideComponent.componentStorage.isVisible = true;
          guideComponent.componentStorage.currentItemIndex = Number(guideIndex);
        }
      },
      /**
       * Ensures that the state of all components, data contexts and
       * data contexts are current and up-to-date.
       *
       * Saves the current state of all the current Data Interactives into the
       * 'savedGameState' property of the current game's context.
       * Getting state of interactives may be asynchronous, so returns a promise
       * that is fulfilled with a streamable archive.
       *
       * @param {boolean} fullData  Whether to make an archive of the full document
       *                            or to omit parts savable separately (e.g.
       *                            data contexts.
       *
       * @return {Promise} fulfilled when all data interactives have reported their
       * states. The promise is fulfilled with a return value of the streamable
       * document archive.
       */
      captureCurrentDocumentState: function (fullData) {
        var gameControllers = this.get('dataInteractives'),
            promises = [],
            returnPromise;
        if (gameControllers) {
          gameControllers.forEach(function (gameController) {
            // create an array of promises, one for each data interactive.
            // issue the request in the promise.
            promises.push(new Promise(function (resolve, reject) {
              try {
                if (gameController.saveGameState) {
                  gameController.saveGameState(function (result) {
                    if (!(result && result.success)) {
                      DG.log('Unable to retrieve plugin state');
                      result = {success: false};
                    }
                    resolve(result);
                  });
                } else {
                  // This would occur if there is no means of communicating with
                  // a data interactive. We immediately resolve.
                  resolve({success: true});
                }
              } catch (ex) {
                DG.logWarn("Exception saving game context: " + ex);
                resolve({success: false});
              }
            }));
          });
        }

        returnPromise = Promise.all(promises).then(function () {
          // Prepare the component-specific storage for saving
          DG.ObjectMap.forEach(this.componentControllersMap,
              function (iComponentID, iController) {
                iController.willSaveComponent();
              });

          this.contexts.forEach(function (iContext) {
            iContext.willSaveContext();
          });
          return Promise.resolve(this.get('content').toArchive(fullData));
        }.bind(this))/*.then(undefined, function (reason) { // should be 'catch', but eslint and yui-compressor complain
          console.warn(reason);
        })*/;

        return returnPromise;
      }
    }
);

DG.currDocumentController = function () {
  if (!DG._currDocumentController) {
    DG._currDocumentController = DG.DocumentController.create();
    DG._currDocumentController.set('guideMenuPane', DG.appController.get('guideMenuPane'));
  }
  return DG._currDocumentController;
}.property();

/**
 * A global convenience function for dirtying the document.
 *
 * @param changedObject The object that caused the document to be dirty
 * @param retainUndo (optional) If set, do not inform UndoHistory of the change,
 * avoiding stack truncation.
 */
DG.dirtyCurrentDocument = function (changedObject, retainUndo) {
  // Tell the UndoHistory that something changed the document.
  // If this didn't occur inside a Command.execute, then it will clear
  // the undo stack.
  if (!retainUndo) {
    DG.UndoHistory.documentWasChanged();
  }

  if (SC.none(changedObject)) {
    changedObject = DG.currDocumentController().get('content');
  }

  var update = function () {
    DG.currDocumentController().objectChanged(changedObject);
    DG.currDocumentController().incrementProperty('changeCount');
    //DG.log('changeCount = %@', DG.currDocumentController().get('changeCount'));
  };

  // Dirty the document after the current save finishes so that we don't miss sending to the server any changes that
  // didn't make it into this save cycle.
  var saveInProgress = DG.currDocumentController().get('saveInProgress');
  if (!SC.none(saveInProgress)) {
    saveInProgress.done(update);
  } else {
    update();
  }

  /* For a while in building the StoryBuilder/MomentBar plugin, we were sending our document to subscribers every
      time the document was dirtied. We may again encounter this need, so we leave this code commented out.
    if (DG.currDocumentController().notificationManager)
      DG.currDocumentController().notificationManager.sendDocumentToSubscribers();
  */
};

/* >>>>>>>>>> BEGIN source/utilities/menu_item.js */
// ==========================================================================
//                            DG.MenuItem
//
//  Author:   William Finzer
//
//  Copyright (c) 2015 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================


/** @class DG.MenuItem A simple extension of SC.MenuItem to display font icons
 *
 *   @extends SC.MenuItemView
 */
DG.MenuItem = SC.MenuItemView.extend(
    /** @scope DG.MenuItem.prototype */
    {

      init: function () {
        arguments.callee.base.apply(this,arguments);
      },
      displayProperties: ['title', 'toolTip', 'isEnabled', 'icon', 'isSeparator', 'shortcut', 'isChecked','rightIcon'],
      /** @private
       Overrides base class to display a font icon.

       @param context {SC.RenderContext}  the render context
       @param className {String} the classname that will show the icon
       @returns {void}
       */
      renderImage: function(context, image) {
        if (image && SC.ImageView.valueIsUrl(image)) {
          context.begin('img').addClass('image').setAttr('src', image).end();
        } else {
          context.begin('div').addClass(image).end() ;
        }
      },

      /** @private
       Fills the passed html-array with strings that can be joined to form the
       innerHTML of the receiver element.  Also populates an array of classNames
       to set on the outer element.

       @param {SC.RenderContext} context
       @param {Boolean} firstTime
       @returns {void}
       */
      render: function (context) {
        var    rightIcon = this.getContentProperty('itemRightIconKey');

        arguments.callee.base.apply(this,arguments);
        if (rightIcon) {
          this.renderRightIcon(context, rightIcon);
        }
      },

      /** @private
       Generates a right icon for the label based on the content.  This method will
       only be called if the menu item view has icons enabled.  You can override
       this method to display your own type of icon if desired.

       @param {SC.RenderContext} context the render context
       @param {String} icon a URL or class name.
       @returns {void}
       */
      renderRightIcon: function (context, icon) {
        // get a class name and url to include if relevant
        var url = null;
        var className = null;
        var toolTip = this.getContentProperty('itemRightToolTipKey');
        if (toolTip) { toolTip = toolTip.loc();}
        // DG.log('toolTip: ' + toolTip);
        var classArray = ['dg-right-icon'];
        // classArray = ['dg-right-icon', 'dg-trash-icon'];
        // context.begin('div')
        //     .addClass(classArray)
        //     .end();
        if (icon && SC.ImageView.valueIsUrl(icon)) {
          url = icon;
          className = '';
          context.begin('img')
              .addClass(classArray)
              .setAttr('src', url)
              .setAttr('title', toolTip)
              .end();
        } else {
          className = icon;
          classArray.push(className);
          url = SC.BLANK_IMAGE_URL;
          context.begin('div')
              .addClass(classArray)
              .setAttr('title', toolTip)
              .end();
        }

        // generate the img element...
      },
      mouseUp: function (evt) {
        // SproutCore's event system will deliver the mouseUp event to the view
        // that got the mouseDown event, but for menus we want to track the mouse,
        // so we'll do our own dispatching.
        var targetMenuItem = this.getPath('parentMenu.rootMenu.targetMenuItem'),
            rightIconAction = this.getContentProperty('itemRightActionKey');

        if ($(evt.target).hasClass('dg-right-icon') && rightIconAction) {
          this.performRightMenuAction();
        } else if (targetMenuItem) {
          targetMenuItem.performAction();
        }
        return YES;
      },

      performRightMenuAction: function () {
        var action = this.getContentProperty('itemRightActionKey'),
            target = this.getContentProperty('itemRightTargetKey'),
            rootMenu = this.getPath('parentMenu.rootMenu'),
            responder;

        // Close the menu
        rootMenu.remove();
        // We're no longer flashing
        rootMenu._isFlashing = NO;

        action = (action === undefined) ? rootMenu.get('action') : action;
        target = (target === undefined) ? rootMenu.get('target') : target;

        // Notify the root menu pane that the selection has changed
        //rootMenu.set('selectedItem', this.get('content'));

        // Legacy support for actions that are functions
        if (SC.typeOf(action) === SC.T_FUNCTION) {
          action.apply(target, [rootMenu]);
          

        } else {
          responder = this.getPath('pane.rootResponder') || SC.RootResponder.responder;

          if (responder) {
            // Send the action down the responder chain
            responder.sendAction(action, target, rootMenu);
          }
        }
      }

    });

/* >>>>>>>>>> BEGIN source/utilities/menu_pane.js */
// ==========================================================================
//                            DG.MenuPane
//
//  Author:   William Finzer
//
//  Copyright (c) 2015 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class DG.MenuPane A simple extension of SC.MenuPane to allow passing arguments
 *
 * There are two reasons for this override:
 *  1. We want to adjust the width of the menu before we display it.
 *  2. We want to pass arguments to the function being called.
 *
 *  Note that dgAction is the property of the menu item that will be used to invoke the
 *  the action of selecting the item from the menu.
 *
 *   @extends SC.Object
*/

sc_require('utilities/menu_item');

DG.MenuPane = SC.MenuPane.extend(
/** @scope DG.MenuPane.prototype */ 
{
  /**
   * @property {String | Function}
   */
  dgAction: null,

  exampleView: DG.MenuItem,

  getDesiredMenuWidth: function() {
    var tMaxCharCount = 0,
        kAvgCharWidth = 6,  // Use 6 pixels/character for estimation
        kWidthMargins = 60;
    this.get('items').forEach( function( iItem) {
      if (!iItem) {
        return;
      }
      var charCount = 0;
      if( iItem.title && (typeof iItem.title === 'string')) {
        charCount =  iItem.title.loc().length;
      }
      if (iItem.rightIcon) {
        charCount += 2;
      }
      tMaxCharCount = Math.max( tMaxCharCount, charCount);
    });
    // Note: Currently we use a heuristic. Eventually we will probably need
    // to measure the text more precisely.
    return tMaxCharCount * kAvgCharWidth + kWidthMargins;
  },

  selectedItemDidChange: function() {
    var tSelectedItem = this.get('selectedItem'),
        tArgs = tSelectedItem.get('args') || [],
        tAction = tSelectedItem.get( 'dgAction');
    if( typeof tAction === 'string') {
      tAction = tSelectedItem.target[tAction] || this[tAction];
    }
    if( tAction)
      tAction.apply( tSelectedItem.get( 'target'), tArgs);
    this.selectedItem = null;
  }.observes('selectedItem'),

  popup: function() {
    this.adjust('width', this.getDesiredMenuWidth());
    arguments.callee.base.apply(this,arguments);
  },

  /**
   The name of the property that contains the right icon for each item.

   @type String
   @default "icon"
   @commonTask Menu Item Properties
   */
  itemRightIconKey: 'rightIcon',
  itemRightTargetKey: 'rightTarget',
  itemRightActionKey: 'rightAction',
  itemRightToolTipKey: 'rightToolTip',
  menuItemKeys: ['rightIcon','rightTarget','itemRightAction','itemTitleKey', 'itemValueKey', 'itemToolTipKey', 'itemIsEnabledKey', 'itemIconKey', 'itemSeparatorKey', 'itemActionKey', 'itemCheckboxKey', 'itemShortCutKey', 'itemHeightKey', 'itemSubMenuKey', 'itemKeyEquivalentKey', 'itemTargetKey', 'itemLayerIdKey']

});


/* >>>>>>>>>> BEGIN source/controllers/app_controller.js */
// ==========================================================================
//                          DG.appController
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('controllers/document_helper');
sc_require('controllers/document_controller');
sc_require('utilities/menu_pane');
sc_require('utilities/clipboard_utilities');

/** @class

   Top-level coordinating controller for the DG application.

 @extends SC.Object
 */
DG.appController = SC.Object.create((function() // closure
   /** @scope DG.appController.prototype */ {

  return {  // return from closure

    /**
     * Options menu.
     * @property {DG.MenuPane}
     */
    optionMenuPane: null,

    /**
     * Guide menu.
     * @property {SC.MenuPane}
     */
    guideMenuPane: null,

    /**
     * Help menu.
     * @property {DG.MenuPane}
     */
    helpMenuPane: null,

    documentArchiver: DG.DocumentHelper.create({}),

    /**
     * Show the case table or case card for a data context.
     * @param iDataContext
     */
    showCaseDisplayFor: function(iMenuItem) {
      function removeCaseDisplay(componentID) {
        var controller = documentController.componentControllersMap[componentID];
        var view = controller.get('view');
        var containerView = view.parentView;
        containerView.removeComponentView(view);
      }

      function selectView(componentView) {
        if(componentView) {
          componentView.invokeLater(function() {
            componentView.showAndSelect();
          });
        }
      }

      // is there a data context? if so, is there a case table for it? If so,
      // select it. If not create it. If there is no data context, create a
      // new one.
      var dataContext = iMenuItem.dataContext;
      var action = iMenuItem.dgAction;
      var documentController = DG.currDocumentController();
      var foundView;
      var caseTable;
      // If no data context, we create a new one.
      if(SC.none(dataContext) && action === 'openCaseTableForNewContext') {
        DG.UndoHistory.execute(DG.Command.create({
          name: 'dataContext.create',
          undoString: 'DG.Undo.dataContext.create',
          redoString: 'DG.Redo.dataContext.create',
          log: 'createNewEmptyDataSet',
          isUndoable: false,
          execute: function() {
            dataContext = DG.appController.createMinimalDataContext(
               'DG.AppController.createDataSet.initialAttribute'.loc(), /*'AttributeName'*/
               'DG.AppController.createDataSet.name'.loc() /* 'New Dataset' */);
            caseTable = documentController.addCaseTable(
               DG.mainPage.get('docView'), null,
               { position: 'top', dataContext: dataContext });
            this.invokeLater(function() {
              caseTable.setFocusToComponentTitle();
            }, 1000);
          },
          undo: function() {
            documentController.destroyDataContext(dataContext.get('id'));
          },
          redo: function() {
            this.execute();
          }
        }));
      } else if(SC.none(dataContext) && action === 'openNewDataSetFromClipboard') {
        this.openNewDataSetFromClipboard();
      } else {
        foundView = documentController.tableCardRegistry.getViewForContext(dataContext);
        if(foundView) {
          // find its view and make it selected
          selectView(foundView);
        } else {
          DG.UndoHistory.execute(DG.Command.create({
            name: 'caseTable.open',
            undoString: 'DG.Undo.caseTable.open',
            redoString: 'DG.Redo.caseTable.open',
            log: 'openCaseTable: {name: "%@"}'.fmt(dataContext.get('name')),
            executeNotification: DG.UndoHistory.makeComponentNotification('create', 'table'),
            undoNotification: DG.UndoHistory.makeComponentNotification('delete', 'table'),
            execute: function() {
              caseTable = documentController.addCaseTable(
                 DG.mainPage.get('docView'), null,
                 { position: 'top', dataContext: dataContext });
              selectView(caseTable);
            },
            undo: function() {
              removeCaseDisplay(caseTable.getPath('model.id'));
            },
            redo: function() {
              this.execute();
            }
          }));
        }
      }
      return caseTable && caseTable.controller;
    },

    /**
     * Initialization function.
     */
    init: function() {
      arguments.callee.base.apply(this,arguments);

      // Without the SC.run() we get warnings about invokeOnce() being called
      // outside the run loop in SC 1.10. A better solution would probably be
      // to create these menus somewhere else, but for now we just wrap them
      // in a run loop to quiet the warnings.
      SC.run(function() {
        this.tileMenuPane = DG.MenuPane.create({
          showTileList: function(iAnchor) {
            this.set('items', DG.mainPage.mainPane.scrollView.contentView.get('tileMenuItems'));
            this.popup(iAnchor);
          },
          layout: { width: 150 },
          menuItemDidChange: function() {
            var tItemView = this.getPath('currentMenuItem.content.target'),
               tPrevItemView = this.getPath('previousMenuItem.content.target');
            if(tItemView) {
              tItemView.get('parentView').bringToFront(tItemView);
              tItemView.$().addClass('dg-component-view-staging');
              tItemView.scrollToVisible();
            }
            if(tPrevItemView && tPrevItemView !== tItemView)
              tPrevItemView.$().removeClass('dg-component-view-staging');
          }.observes('currentMenuItem', 'previousMenuItem'),
          willRemoveFromDocument: function() {
            var tItem = this.get('currentMenuItem'),
               tPrevItem = this.get('previousMenuItem');
            if(tItem)
              tItem.getPath('content.target').$().removeClass('dg-component-view-staging');
            if(tPrevItem)
              tPrevItem.getPath('content.target').$().removeClass('dg-component-view-staging');
          }
        });
        this.caseTableMenuPane = DG.MenuPane.create({
          showMenu: function(iAnchor) {
            this.set('items', DG.appController.get('caseTableMenuItems'));
            this.popup(iAnchor);
          },
          selectedItemDidChange: function() {
            DG.appController.showCaseDisplayFor(this.get('selectedItem'));
          }.observes('selectedItem'),
          itemLayerIdKey: 'id',
          layout: { width: 150 }
        });
        this.pluginMenuPane = DG.MenuPane.create({
          init: function() {
            arguments.callee.base.apply(this,arguments);
            var pluginMetadataURL = DG.get('pluginMetadataURL');
            if(!pluginMetadataURL) {
              DG.logWarn('Plugin metadata URL absent.');
            }
            // Retrieve plugin metadata for later reference
            $.ajax(pluginMetadataURL, {
              success: function(data) {
                SC.run(function() {
                  DG.set('pluginMetadata', data);
                  this.set('items', DG.appController.get('pluginMenuItems'));
                }.bind(this));
              }.bind(this),
              error: function() {
                DG.logError('Plugin Metadata Get failed: ' + pluginMetadataURL);
              }
            });
          },
          showMenu: function(iAnchor) {
            this.popup(iAnchor);
          },
          openStandardPlugin: function(pluginDef) {
            var doc = DG.currDocumentController();
            var tComponent = DG.Component.createComponent({
              type: "DG.GameView",
              document: doc.get('content'),
              componentStorage: {
                currentGameName: pluginDef.title,
                currentGameUrl: pluginDef.url,
                allowInitGameOverride: true
              }
            });
            doc.createComponentAndView(tComponent);
          },
          selectedItemDidChange: function() {
            var selectedItem = this.get('selectedItem');
            if(selectedItem) {
              this.openStandardPlugin(selectedItem);
              this.set('selectedItem', null);
            }
          }.observes('selectedItem'),
          itemLayerIdKey: 'id',
          layout: { width: 150 }
        });
        this.optionMenuPane = DG.MenuPane.create({
          items: this.get('optionMenuItems'),
          itemLayerIdKey: 'id',
          layout: { width: 150 }
        });
        this.guideMenuPane = SC.MenuPane.create({
          layout: { width: 250 }
        });
        this.helpMenuPane = DG.MenuPane.create({
          items: this.get('helpMenuItems'),
          itemLayerIdKey: 'id',
          layout: { width: 150 }
        });
      }.bind(this));

      // Give the user a chance to confirm/cancel before closing, reloading,
      // or navigating away from the page. The sites listed below provide some
      // information on the 'beforeunload' event and its handling, but the upshot
      // is that if you return a string, then the browser will provide a dialog
      // that should include the returned string (Firefox >= 4 chooses not to on
      // the grounds that there are security concerns).
      // https://developer.mozilla.org/en-US/docs/DOM/window.onbeforeunload
      // http://bytes.com/topic/javascript/insights/825556-using-onbeforeunload-javascript-event
      // https://bugzilla.mozilla.org/show_bug.cgi?id=588292 for discussion of Firefox functionality.
      // TODO: This confirmation message can cause an unescapable loop if
      // TODO: saving fails. Need a way out in these circumstances.
      window.onbeforeunload = function(iEvent) {
        if(DG.currDocumentController().get('hasUnsavedChanges') &&
           (DG.get('embeddedMode') === 'no') &&
           (DG.get('componentMode') === 'no')) {
          return 'DG.AppController.beforeUnload.confirmationMessage'.loc();
        }
      };
    },

    dataSetDeleteAgent: SC.Object.extend({
      deleteWithAlert: function(menu) {
        DG.AlertPane.warn({
          dataContext: this.dataContext,
          doDelete: function() {
            DG.currDocumentController().destroyDataContext(this.get('dataContext').get('id'));
          },
          message: 'DG.TableController.deleteDataSet.confirmMessage'.loc(
             this.get('dataContext').get('title')),
          description: 'DG.TableController.deleteDataSet.confirmDescription'.loc(),
          buttons: [{
            title: 'DG.TableController.deleteDataSet.okButtonTitle',
            action: 'doDelete',
            localize: YES
          }, {
            title: 'DG.TableController.deleteDataSet.cancelButtonTitle',
            localize: YES
          }],
          localize: false
        });
      }
    }),
    caseTableMenuItems: function() {
      var documentController = DG.currDocumentController();
      var dataContexts = documentController.get('contexts');
      var menuItems = dataContexts.map(function(dataContext) {
        var viewType = documentController.tableCardRegistry.getActiveViewTypeForContext(dataContext.get('id'));//'DG.CaseTable' || 'DG.CaseCard'
        return {
          localize: false,
          title: dataContext.get('title'),
          toolTip: 'DG.AppController.caseTableMenu.openCaseTableToolTip',
          target: DG.appController,
          icon: viewType === 'DG.CaseCard' ? 'tile-icon-card' : 'tile-icon-table',
          dataContext: dataContext,
          rightIcon: 'dg-trash-icon',
          rightTarget: this.dataSetDeleteAgent.create({ dataContext: dataContext }),
          rightAction: 'deleteWithAlert',
          rightToolTip: 'DG.AppController.caseTableMenu.deleteDataSetToolTip'
        };
      }.bind(this));
      menuItems.push({
        localize: true,
        title: 'DG.AppController.caseTableMenu.clipboardDataset',
        toolTip: 'DG.AppController.caseTableMenu.clipboardDatasetToolTip',
        target: DG.appController,
        isEnabled: DG.ClipboardUtilities.canPaste(),
        dgAction: 'openNewDataSetFromClipboard',
        icon: 'tile-icon-table'
      });
      menuItems.push({
        localize: true,
        title: 'DG.AppController.caseTableMenu.newDataSet',
        toolTip: 'DG.AppController.caseTableMenu.newDataSetToolTip',
        target: DG.mainPage,
        dgAction: 'openCaseTableForNewContext',
        icon: 'tile-icon-table'
      });
      return menuItems;
    }.property(),
    pluginMenuItems: function() {
      // DG.log('Making plugin menu items');
      var baseURL = DG.get('pluginURL');
      var pluginMetadata = DG.get('pluginMetadata');
      var items = pluginMetadata ? pluginMetadata.map(function(pluginData) {
        return {
          localize: true,
          title: pluginData["title-string"] ? pluginData["title-string"].loc() : pluginData.title,
          url: baseURL + pluginData.path,
          target: this,
          toolTip: pluginData["description-string"] ? pluginData["description-string"].loc() : pluginData.description,
          dgAction: 'openPlugin',
          dimensions: {
            width: pluginData.width || 400,
            height: pluginData.height || 300
          },
          icon: pluginData.icon ? baseURL + pluginData.icon : 'tile-icon-mediaTool',
          // replace spaces with hyphens when creating the id
          id: 'dg-pluginMenuItem-' + pluginData.title.replace(/ /g, '-')
        };
      }) : [];
      return items;
    }.property(),

    optionMenuItems: function() {
      return [
        {
          localize: true, title: 'DG.AppController.optionMenuItems.viewWebPage', // "View Web Page..."
          target: this, dgAction: 'viewWebPage', id: 'dg-optionMenuItem-view_webpage'
        },
        {
          localize: true, title: 'DG.AppController.optionMenuItems.configureGuide', // "Configure Guide..."
          target: this, dgAction: 'configureGuide', id: 'dg-optionMenuItem-configure-guide'
        }
      ];
    }.property(),

    helpMenuItems: function() {
      return [
        {
          localize: true, title: 'DG.AppController.optionMenuItems.help', // "Help...",
          target: this, dgAction: 'showHelpSite', id: 'dg-optionMenuItem-help-website'
        },
        {
          localize: true, title: 'DG.AppController.optionMenuItems.help-forum', // "Help...",
          target: this, dgAction: 'showHelpForum', id: 'dg-optionMenuItem-help-forum'
        },
        {
          localize: true, title: 'DG.AppController.optionMenuItems.toWebSite', // "CODAP website...",
          target: this, dgAction: 'showWebSite', id: 'dg-optionMenuItem-codap-website'
        },
        {
          localize: true, title: 'DG.AppController.optionMenuItems.toPrivacyPage', // "CODAP privacy...",
          target: this, dgAction: 'showPrivacyPage', id: 'dg-optionMenuItem-privacy-page'
        }
        // { localize: true, title: 'DG.AppController.optionMenuItems.reportProblem', // "Report Problem..."
        //   target: this, dgAction: 'reportProblem', id: 'dg-optionMenuItems-report-problem' }
      ];
    }.property(),

    openNewDataSetFromClipboard: function() {
      var _this = this;

      window.focus();
      if(document.activeElement) {
        document.activeElement.blur();
      }

      window.navigator.clipboard.readText().then(
         function(data) {
           SC.run(function() {
             if(/^https?:\/\/[^\n]*$/.test(data)) {
               _this.importURL(data);
             } else {
               _this.openCSVImporter({
                 contentType: 'text/csv',
                 text: data,
                 datasetName: 'clipboard data',
                 showCaseTable: true
               });
             }
           });
         },
         function(err) {
           // maybe user didn't grant access to read from clipboard
           console.log('Error importing from clipboard: ', err);
         }
      );
    },

    extractNameFromURLPath: function(iURL) {
      function parseURL(url) {
        var a = document.createElement('a');
        a.href = url;
        return a;
      }

      var parsedURL = parseURL(iURL);
      if(parsedURL.protocol === 'data:') {
        return 'data';
      }
      var fullPathname = parsedURL.pathname;
      var path = fullPathname ? fullPathname
                                   .replace(/\/$/, '')
                                   .replace(/.*\//, '')
                                   .replace(/\.[^.]*$/, '') || iURL : iURL;
      return path;
    },
    /**
     * Imports text (e.g. from a CSV file) to the document from a URL.
     *
     * @param {string} iURL The url of a text (e.g. CSV) file
     * @param {Boolean} iShowCaseTable
     * @return {Deferred|undefined}
     */
    importTextFromUrl: function(iURL, iShowCaseTable, iName) {
      var name = iName || this.extractNameFromURLPath(iURL);
      this.openCSVImporter({
        contentType: 'text/csv',
        url: iURL,
        datasetName: name,
        showCaseTable: iShowCaseTable
      });
    },
    importGeoJSONFromURL: function(iURL) {
      var name = this.extractNameFromURLPath(iURL);
      this.openGeoJSONImporter({
        contentType: 'application/geo+json',
        url: iURL,
        datasetName: name,
        showCaseTable: false
      });
    },

    openImporterPlugin: function(iName, iPath, iGameState) {
      var tComponent = DG.Component.createComponent({
        type: 'DG.GameView',
        layout: {
          isVisible: false
        },
        document: DG.currDocumentController(),
        componentStorage: {
          currentGameName: iName,
          currentGameUrl: DG.get('pluginURL') + iPath,
          savedGameState: iGameState,
          title: iName,
        }
      });
      DG.currDocumentController().createComponentAndView(tComponent);
    },
    /**
     * Opens the CSV Importer plugin, preconfigured with the information
     * it needs to perform the import.
     * @param iConfig {Object} Configuration, as follows (iConfig must have
     *                         one of url or data, but not both)
     *
     *                           url: url refering to a CSV or tab delimited file
     *                           data: an array of arrays
     *                           datasetName: the name of the dataset
     *                           showCaseTable: whether to display the case
     *                                  table for the new context
     */
    openCSVImporter: function(iConfig) {
      this.openImporterPlugin('Importer', '/Importer/', iConfig);
    },

    openGeoJSONImporter: function(iConfig) {
      this.openImporterPlugin('Importer', '/Importer/', iConfig);
    },

    openHTMLImporter: function(iConfig) {
      this.openImporterPlugin('Importer', '/Importer/', iConfig);
    },

    openGoogleSheetsImporter: function(iConfig) {
      this.openImporterPlugin('Importer', '/Importer/', iConfig);
    },

    /**
     * Imports a csv to the document from a data uri.
     *
     * @param {string} iURL The url of a text (e.g. CSV) file as a data uri
     * @return {Deferred|undefined}
     */
    importCSVFromDataUri: function(iURL) {
      if(iURL) {
        var urlParts = iURL.match(/^data:text\/csv;((base64),|(charset)=([^,]+),)?(.*)$/);
        if(urlParts) {
          var doc = urlParts[5];
          if(urlParts[2] === "base64") {
            try {
              doc = atob(doc);
            } catch (e) {
              doc = null;
              DG.logWarn(e);
            }
          } else {
            // keep decoding until there are no encoded characters (to ensure against double encoding)
            while (doc.match(/%[0-9a-f]{2}/i)) {
              doc = decodeURIComponent(doc);
            }
          }
          if(doc !== null) {
            SC.run(function() {
              return this.importText(doc, "Imported CSV");
            }.bind(this));
          }
        }
      }
    },

    /**
     * Create a data context from a string formatted as a CSV file.
     * @param iColumnName {string}
     * @param iContextName {string}
     * @return {DG.DataContext}
     */
    createMinimalDataContext: function(iColumnName, iContextName) {
      // Create document-specific store.
      var context, contextRecord,
         documentController = DG.currDocumentController(),
         baseContextName = iContextName.replace(/.*[\\\/]/g, '').replace(/\.[^.]*/, ''),
         contextName = baseContextName,
         collectionName = 'DG.AppController.createDataSet.collectionName'.loc(),
         i = 1;

      // guarantee uniqueness of data context name/title
      while (documentController.getContextByName(contextName) ||
             documentController.getContextByTitle(contextName)) {
        contextName = baseContextName + " " + (++i);
      }

      // Create the context record.
      contextRecord = DG.DataContextRecord.createContext({
        title: contextName,
        name: contextName,
        collections: [{
          name: collectionName,
          attrs: [{
            name: iColumnName
          }]
        }],
        contextStorage: {}
      });

      // create the context
      context = documentController.createDataContextForModel(contextRecord);
      context.restoreFromStorage(contextRecord.contextStorage);

      return context;
    },

    /**
     * Create a data context from a CSV string and expose it as a case table.
     * @param iText String  either CSV or tab-delimited
     * @param iName String  document name
     * @param { Boolean } iShowCaseTable Defaults to true
     * @returns {Boolean}
     */
    importText: function(iText, iName, iFilename, iShowCaseTable) {
      this.openCSVImporter({
        contentType: 'text/csv',
        text: iText,
        datasetName: iName,
        filename: iFilename,
        showCaseTable: iShowCaseTable
      });
      return true;
    },

    importHTMLTable: function(iText) {
      this.openHTMLImporter({
        contentType: 'text/html',
        text: iText
      });
      return true;
    },

    importGoogleSheets: function(iURL) {
      var config = {
        contentType: 'application/vnd.google-apps.spreadsheet',
        url: iURL,
        showCaseTable: true
      };
      this.openGoogleSheetsImporter(config);
    },
    importImage: function(iURL, iName) {
      function determineImageSize(imgSrc, callback) {
        var newImg = new Image();

        newImg.onload = function() {
          var height = newImg.height;
          var width = newImg.width;
          newImg = undefined;
          callback(width, height);
        };

        newImg.src = imgSrc; // this must be done AFTER setting onload
      }

      var documentController = DG.currDocumentController();
      var tName = iName ? iName.slice(0, 30) : '';
      determineImageSize(iURL, function(iWidth, iHeight) {
        SC.run(function() {
          documentController.addImageView(DG.mainPage.get('docView'), null,
             iURL, tName, {
               width: Math.min(iWidth, 480),
               height: Math.min(iHeight + 25, 385)
             });
        });
      });
    },
    /**
     *
     * @param iURL - the URL of a webpage, data interactive, csv or json document based on
     * file extension in pathname.
     * @param iComponentType - (optional) the type of the component, defaults to DG.GameView
     * @returns {Boolean}
     */
    importURL: function(iURL, iComponentType, iName) {

      var addInteractive = function() {
        var tDoc = DG.currDocumentController(),
           tComponent;

        switch (iComponentType || "DG.GameView") {
          case "DG.GameView":
            tComponent = DG.Component.createComponent({
              "type": "DG.GameView",
              "document": tDoc.get('content'),
              "componentStorage": {
                "currentGameName": "",
                "currentGameUrl": iURL,
                allowInitGameOverride: true
              }
            });
            tDoc.createComponentAndView(tComponent);
            break;
          case "DG.WebView":
            tDoc.addWebView(DG.mainPage.get('docView'), null, iURL, 'Web Page', { width: 600, height: 400 });
            break;
        }
      }.bind(this);

      // from: http://www.abeautifulsite.net/parsing-urls-in-javascript/
      var urlParser = document.createElement('a');
      urlParser.href = iURL;
      var baseURL = urlParser.protocol + urlParser.host + urlParser.pathname;

      var mimeSpec = this.matchMimeSpec(baseURL, iComponentType);

      if(!mimeSpec) {
        mimeSpec = { group: 'UNKOWN', mime: ['unkown'] };
      }
      DG.log('Opening url "%@" of type %@'.loc(iURL, mimeSpec.mime[0]));
      if(mimeSpec) {
        switch (mimeSpec.group) {
          case 'TEXT':
            this.importTextFromUrl(iURL, false, iName);
            break;
          case 'GEOJSON':
            this.importGeoJSONFromURL(iURL);
            break;
          case 'JSON':
            DG.cfmClient.openUrlFile(iURL);
            break;
          case 'IMAGE':
            this.importImage(iURL, iName);
            break;
          case 'SHEETS':
            this.importGoogleSheets(iURL);
            break;
          default:
            addInteractive();
        }
      }

      return true;
    },

    importDrawToolWithDataURL: function(iDataURL, iTitle) {
      var kWidth = 600, kHeight = 400,
         kComponentType = 'DG.GameView',
         layout = { width: kWidth, height: kHeight },
         drawToolUrl = DG.get('drawToolPluginURL'),
         title = "DG.DataDisplayMenu.imageOfTitle".loc(iTitle),
         tDoc = DG.currDocumentController(),
         tComponent = DG.Component.createComponent({
           type: kComponentType,
           document: tDoc.get('content'),
           layout: layout,
           componentStorage: {
             currentGameName: title,
             currentGameUrl: drawToolUrl,
             allowInitGameOverride: true
           }
         }),
         tComponentArgs = { initiatedViaCommand: true },
         tView = tDoc.createComponentAndView(tComponent, kComponentType, tComponentArgs),
         tSuperView = tView && tView.get('parentView'),
         tController = tView && tView.get('controller');
      if(tSuperView && tSuperView.positionNewComponent) {
        tSuperView.positionNewComponent(tView, 'top', true);
        /**
         * The following is a workaround for a bug that occurs in Safari where the draw tool
         * doesn't display the graph image until it receives notification of a resize event
         * It appears to be necessary to delay the notification until after the draw tool
         * has been displayed and settled down.
         * We don't special case Safari because this work around has the beneficial effect
         * of getting rid of a gray strip on the right edge of the draw tool canvas.
         */
        this.invokeLater(function() {
          DG.currDocumentController().notificationManager.sendNotification({
            action: 'notify',
            resource: 'component',
            values: {
              "operation": "resize",
              "type": "DG.GameView",
              "id": tView.getPath('model.id'),
              "title": "DrawTool"
            }
          });
        }, 1000);
      }
      if(tController && tController.sendCommand)
        tController.sendCommand({ action: 'update', resource: 'backgroundImage', values: { image: iDataURL } });
    },

    /**
     Close the current document and all its components.
     */
    closeDocument: function() {
      // Destroy the document and its contents
      DG.currDocumentController().closeDocument();
      DG.store = null;
    },

    /**
     * Closes the current document with confirmation.
     *
     * We interpose this between the menu item and closeDocumentWithConfirmation
     * to correct the argument.
     *
     * @param {object} sender: unused by the function.
     */
    closeCurrentDocument: function(sender) {
      this.closeDocumentWithConfirmation(null);
    },

    /**
     Closes the document after confirming with the user that that is desired.
     */
    closeDocumentWithConfirmation: function(iDefaultGameName) {
      var docName = DG.currDocumentController().get('documentName');

      var closeDocumentAfterConfirmation = function() {
        this.closeAndNewDocument(iDefaultGameName);
        DG.logUser("closeDocument: '%@'", docName);
      }.bind(this);

      var cancelCloseDocument = function() {
        DG.logUser("cancelCloseDocument: '%@'", docName);
      };

      if(DG.currDocumentController().get('hasUnsavedChanges')) {
        DG.logUser("confirmCloseDocument?: '%@'", docName);
        DG.AlertPane.warn({
          message: 'DG.AppController.closeDocument.warnMessage',
          description: 'DG.AppController.closeDocument.warnDescription',
          buttons: [
            {
              title: 'DG.AppController.closeDocument.okButtonTitle',
              action: closeDocumentAfterConfirmation,
              localize: YES
            },
            {
              title: 'DG.AppController.closeDocument.cancelButtonTitle',
              action: cancelCloseDocument,
              localize: YES
            }
          ],
          localize: YES
        });
      } else {
        closeDocumentAfterConfirmation();
      }
    },

    /**
     Close the current document and open up a new empty document.
     */
    closeAndNewDocument: function(iDefaultGameName) {

      // Close the current document
      this.closeDocument();

      // Create a new empty document
      DG.currDocumentController().setDocument(DG.currDocumentController().createDocument());
    },

    mimeTypesAndExtensions: [
      {
        group: 'TEXT',
        mime: ['text/csv', 'application/csv'],
        extensions: ['csv']
      },
      {
        group: 'TEXT',
        mime: ['text/plain'],
        extensions: ['txt']
      },
      {
        group: 'TEXT',
        mime: ['text/tab-separated-values'],
        extensions: ['tsv', 'tab']
      },
      {
        group: 'JSON',
        mime: ['application/json', 'application/x-javascript', 'text/x-json'],
        extensions: ['json', 'codap']
      },
      {
        group: 'GEOJSON',
        mime: ['application/geo+json', 'application/vnd.geo+json'],
        extensions: ['geojson']
      },
      {
        group: 'IMAGE',
        mime: ['image/gif'],
        extensions: ['gif']
      },
      {
        group: 'IMAGE',
        mime: ['image/jpeg'],
        extensions: ['jpeg', 'jpg']
      },
      {
        group: 'IMAGE',
        mime: ['image/png'],
        extensions: ['png']
      },
      {
        group: 'IMAGE',
        mime: ['image/svg+xml'],
        extensions: ['svg', 'svgz']
      }/*,
      {
        group: 'IMAGE',
        mime: 'application/pdf',
        xtensions: 'pdf'
      }*/,
      {
        group: 'SHEETS',
        mime: ['application/vnd.google-apps.spreadsheet'],
        extensions: []
      }
    ],
    /**
     * Attempts to match a filename or URL or a type to an entry in the above
     * spec list.
     * @param name: a filename or URL
     * @param type: a type string. May be missing.
     */
    matchMimeSpec: function(name, type) {
      var isSheetsURL = /docs.google.com\/spreadsheets/.test(name);
      var isDataURIMatch = /^data:([^;]+);.+$/.exec(name);
      var match = name && name.match(/\.([^.\/]+)$/);
      var mySuffix = match && match[1].toLowerCase();
      var typeDesc;
      // if we haven't a type and its a data URI, use its mime type
      if(type == null && isDataURIMatch) {
        type = isDataURIMatch[1];
      }
      if(isSheetsURL) {
        type = 'application/vnd.google-apps.spreadsheet';
      }
      typeDesc = typeDesc || type && this.mimeTypesAndExtensions.find(function(mimeDef) {
        return (type != null) && mimeDef.mime.find(function(str) {
          return str === type;
        });
      });
      typeDesc = typeDesc || this.mimeTypesAndExtensions.find(function(mimeDef) {
        return mySuffix && mimeDef.extensions.find(function(ext) {
          return mySuffix === ext;
        });
      });
      return typeDesc;
    },
    /**
     Imports a dragged or selected file
     */
    importFile: function(iFile) {
      var typeDesc = this.matchMimeSpec(iFile.name, iFile.type);
      var handlingGroup = typeDesc ? typeDesc.group : 'JSON';

      var tAlertDialog = {
        showAlert: function(iError) {
          var message = 'DG.AppController.dropFile.error'.loc(iError.message);
          if(DG.cfmClient) {
            DG.cfmClient.alert(message);
          } else {
            DG.AlertPane.show({
              message: message
            });
          }
        },
        close: function() {
          // Do nothing
        }
      };

      DG.log('Opening file "%@" of type %@'.loc(iFile && iFile.name, typeDesc ? typeDesc.mime[0] : 'unknown'));
      this.importFileWithConfirmation(iFile, handlingGroup, tAlertDialog);
    },

    /**
     * Read a file from the file system.
     *
     * Handles CODAP documents and 'TEXT' files
     * (TEXT files here means comma or tab delimited data files.)
     * Will present a confirmation dialog if the type indicates a CODAP document
     * and the document is managed by the document server and has unsaved
     * changes.
     *
     * The file parameter may have come from a drop or a dialog box.
     * @param {File} iFile
     * @param {String} iType 'JSON' or 'TEXT'
     * @param {{showAlert:function,close:function}} iDialog optional error alert.
     */
    importFileWithConfirmation: function(iFile, iType, iDialog) {

      var finishImport = function() {
        function handleAbnormal() {
          console.log("Abort or error on file read.");
        }

        var handleRead = function() {
          SC.run(function() {
            try {
              if(iType === 'JSON') {
                DG.cfmClient.openLocalFile(iFile);
                window.location.hash = '';
                DG.log('Opened: ' + iFile.name);
              } else if(iType === 'GEOJSON') {
                that.openGeoJSONImporter({
                  contentType: 'application/geo+json',
                  text: this.result,
                  datasetName: iFile.name.replace(/\.[^.]*$/, ''),
                  filename: iFile.name,
                  showCaseTable: true
                });
              } else if(iType === 'TEXT') {
                that.importText(this.result,
                   iFile.name.replace(/\.[^.]*$/, ''), iFile.name);
              } else if(iType === 'IMAGE') {
                that.importImage(this.result, iFile.name);
              }
              if(iDialog)
                iDialog.close();
            } catch (er) {
              console.log(er);
              if(iDialog) {
                iDialog.showAlert(er);
              }
            }
          }.bind(this));
        };

        var that = this;
        DG.busyCursor.show(function() {
          var reader = new FileReader();
          if(iFile) {
            reader.onabort = handleAbnormal;
            reader.onerror = handleAbnormal;
            reader.onload = handleRead;
            if(iType === 'IMAGE') {
              reader.readAsDataURL(iFile);
            } else {
              reader.readAsText(iFile);
            }
          }
        });
      }.bind(this);

      var docName;

      var cancelCloseDocument = function() {
        DG.logUser("cancelCloseDocument: '%@'", docName);
      };

      if((iType === 'JSON') && DG.currDocumentController().get('hasUnsavedChanges')) {
        docName = DG.currDocumentController().get('documentName');
        DG.logUser("confirmCloseDocument?: '%@'", docName);
        DG.AlertPane.warn({
          message: 'DG.AppController.closeDocument.warnMessage',
          description: 'DG.AppController.closeDocument.warnDescription',
          buttons: [
            {
              title: 'DG.AppController.closeDocument.okButtonTitle',
              action: finishImport,
              localize: YES
            },
            {
              title: 'DG.AppController.closeDocument.cancelButtonTitle',
              action: cancelCloseDocument,
              localize: YES
            }
          ],
          localize: YES
        });
      } else {
        DG.busyCursor.show(function() {
          finishImport();
        });
      }
      if(iDialog)
        iDialog.close();
    },

    /**
     Bring up the bug report page.
     */
    reportProblem: function() {

      var submitFeedback = function() {
        console.log(feedbackPane.contentView.subjectText.value);
        console.log(feedbackPane.contentView.feedbackText.value);
        console.log("Build #" + DG.BUILD_NUM);
        console.log("Browser: " + SC.browser.name + " v." + SC.browser.version);
        console.log("Device: " + SC.browser.device);
        console.log("OS: " + SC.browser.os + " v." + SC.browser.osVersion);

        //SC.Request.postUrl('http://app.codap.concord.org/DataGames/WebPages/scripts/datagames.php?'+
        SC.Request.postUrl('https://codap.concord.org/help/contact?' +
                           'device=' + SC.browser.device +
                           '&os=' + SC.browser.os +
                           '&os_version=' + SC.browser.osVersion +
                           '&cf_browser=' + SC.browser.name +
                           '&cf_browser_version=' + SC.browser.version +
                           '&version=' + DG.BUILD_NUM +
                           // '&name='+iUser+
                           '&description=' + feedbackPane.contentView.subjectText.value +
                           '&comments=' + feedbackPane.contentView.feedbackText.value)
           //  .notify()
          .send();
        feedbackPane.remove();
        feedbackPane = null;
      };

      var cancelFeedback = function() {
        feedbackPane.remove();
        feedbackPane = null;
      };

      //Begin feedback form

      var feedbackPane = SC.PanelPane.create({

        layout: { top: 175, centerX: 0, width: 405, height: 350 },
        contentView: SC.View.extend({
          backgroundColor: '#dde2e8',
          childViews: 'feedbackHeader codapLogo feedbackImage subHeaderText messageText subjectText feedbackText submitFeedbackButton cancelFeedbackButton'.w(),

          feedbackHeader: SC.LabelView.design({
            layout: { top: 27, height: 20 },
            controlSize: SC.LARGE_CONTROL_SIZE,
            fontWeight: SC.BOLD_WEIGHT,
            textAlign: SC.ALIGN_CENTER,
            value: 'DG.AppController.feedbackDialog.dialogTitle',
            localize: YES
          }),

          codapLogo: SC.ImageView.design({
            layout: { top: 10, left: 10, height: 35, width: 35 },
            value: '../../../../static/dg/de/cert/source/resources/images/codap_logo.png'
          }),

          subHeaderText: SC.LabelView.design({
            layout: { top: 55, left: 10 },
            fontWeight: SC.BOLD_WEIGHT,
            value: 'DG.AppController.feedbackDialog.subHeaderText',
            localize: YES
          }),

          messageText: SC.LabelView.design({
            layout: { top: 70, left: 10, right: 0, width: 395 },
            textAlign: SC.ALIGN_LEFT,
            value: 'DG.AppController.feedbackDialog.messageText',
            localize: YES
          }),

          subjectText: SC.TextFieldView.design({
            layout: { top: 110, left: 10, width: 385, height: 20 },
            autoCorrect: false,
            autoCapitalize: false,
            hint: 'DG.AppController.feedbackDialog.subjectHint'
          }),

          feedbackText: SC.TextFieldView.design({
            layout: { top: 140, left: 10, height: 170, width: 385 },
            isTextArea: true,
            autoCorrect: false,
            autoCapitalize: false,
            hint: 'DG.AppController.feedbackDialog.feedbackHint'
          }),

          submitFeedbackButton: SC.ButtonView.design({
            layout: { bottom: 10, height: 24, right: 10, width: 113 },
            title: 'DG.AppController.feedbackDialog.submitFeedbackButton',
            localize: YES,
            action: submitFeedback,
            isDefault: NO
          }),

          cancelFeedbackButton: SC.ButtonView.design({
            layout: { bottom: 10, height: 24, right: 135, width: 113 },
            title: 'DG.AppController.feedbackDialog.cancelFeedbackButton',
            localize: YES,
            action: cancelFeedback,
            isDefault: NO
          })
        })
      });
      feedbackPane.append();
      feedbackPane.contentView.subjectText.becomeFirstResponder();
    },

    /**
     Pass responsibility to document controller
     */
    viewWebPage: function() {
      DG.currDocumentController().viewWebPage();
    },

    /**
     Pass responsibility to document controller
     */
    configureGuide: function() {
      DG.currDocumentController().configureGuide();
    },

    /**
     Show the help window.
     */
    showHelp: function() {
      var kWidth = 600, kHeight = 400,
         tLayout = { width: kWidth, height: kHeight };
      DG.currDocumentController().addWebView(DG.mainPage.get('docView'), null,
         (DG.showHelpURL),
         'DG.AppController.showHelpTitle'.loc(), //'Help with CODAP'
         tLayout);

    },

    openWebView: function(iURL, iTitle, iWidth, iHeight) {
      var tDocFrame = DG.mainPage.mainPane.scrollView.frame(),
         tLayout = {
           left: (tDocFrame.width - iWidth) / 2, top: (tDocFrame.height - iHeight) / 2,
           width: iWidth, height: iHeight
         };

      //var windowFeatures = "location=yes,scrollbars=yes,status=yes,titlebar=yes";
      DG.currDocumentController().addWebView(DG.mainPage.get('docView'), null,
         iURL, iTitle, tLayout);
    },

    /**
     Open a new tab with the CODAP website.
     */
    showWebSite: function() {
      var kWebsiteURL = DG.get('showWebSiteURL');

      window.open(kWebsiteURL); //If tab with site is already open, no new tabs are generated, but tab with page does not come forward
    },

    showPrivacyPage: function() {
      var kWebsiteURL = DG.get('showPrivacyURL');
      window.open(kWebsiteURL);
    },

    /**
     Open a new tab with the CODAP help pages.
     */
    showHelpSite: function() {
      var tLang = DG.get('currentLanguage');
      var tHelpURL = DG.get('showHelpURL_' + tLang) || DG.get('showHelpURL'),
         tWidth = 400, tHeight = 400;
      this.openWebView(tHelpURL, 'DG.AppController.showHelpTitle'.loc(), tWidth, tHeight);
    },

    /**
     Open a new tab with the CODAP help forum.
     */
    showHelpForum: function() {
      var tHelpForumURL = DG.get('showHelpForumURL'),
         tWidth = 400, tHeight = 400,
         tBrowser = SC.browser;
      if(tBrowser.name === SC.BROWSER.safari && tBrowser.os === SC.OS.ios) {
        this.openWebView(tHelpForumURL, 'DG.AppController.showHelpForumTitle'.loc(), tWidth, tHeight);
      } else {
        window.open(tHelpForumURL);
      }
    },

    openPlugin: function(iURL) {
      this.importURL(iURL);
    }

  }; // end return from closure

}())); // end closure

/* >>>>>>>>>> BEGIN source/models/authorization_model.js */
// ==========================================================================
//                          DG.Authorization
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

  Represents a set of user login/authorization credentials.

  @extends DG.Object
*/
DG.Authorization = SC.Object.extend(
/** @scope DG.Authorization.prototype */ {

  /**
   * Indicates whether logging should be enabled for this user/session.
   * @property {Boolean}
   */
  isLoggingEnabled: true,
  
  /**
   * Counter which increments with every logging call.
   * @property {Number}
   */
  logIndex: 0,
  
  /**
   * Clears the current login credentials.
   */
  clear: function() {
    this.set('isLoggingEnabled', true);
    return this;
  }
  
}) ;

/* >>>>>>>>>> BEGIN source/controllers/authorization.js */
// ==========================================================================
//                      DG.authorizationController
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('models/authorization_model');

/**
  Logs the specified message, along with any additional properties, to the server.

  @param    iLogMessage   {String}    The main message to log
  @param    iProperties   {Object}    Additional properties to pass to the server,
                                      e.g. { type: DG.Document }
  @param    iMetaArgs     {Object}    Additional flags/properties to control the logging.
                                      The only meta-arg currently supported is { force: true }
                                      to force logging to occur even when logging is otherwise
                                      disabled for a given user. This is used to guarantee that
                                      login/logout events get logged even when other user actions
                                      are not logged (e.g. for guest users). Clients using the
                                      utility functions (e.g. DG.logUser()) can add an additional
                                      argument, which must be a JavaScript object, and which will
                                      be passed on to the logToServer function as the meta-args.
 */
DG.logToServer = function( iLogMessage, iProperties, iMetaArgs) {
  DG.authorizationController.logToServer( iLogMessage, iProperties, iMetaArgs);
};

/** @class

  (Document Your Controller Here)

  @extends SC.Object
*/
DG.authorizationController = SC.Controller.create( (function() {

  /**
   * Generates a one-time session key built from data and time and a random
   * value. Will be used for logging, if no Lara Run Key.
   */
  var sessionKey = (function () {
    var now = new Date();
    var dateTimePart = now.getFullYear().toString().slice(-2) +
        ("0"+(now.getMonth()+1)).slice(-2) + ("0" + now.getDate()).slice(-2) +
        ("0" + now.getHours()).slice(-2) + ("0" + now.getMinutes()).slice(-2) +
        ("0" + now.getSeconds()).slice(-2);
    var randomPart = Math.random().toPrecision(5).slice(2);
    return dateTimePart + '-' + randomPart;
  }());

  // var sessionIndex = 0;

  return {
  /** @scope DG.authorizationController.prototype */

    /**
      Logs the specified message, along with any additional properties, to the server.

      description and signature TODO
     */
    logToServer: function(event, iProperties, iMetaArgs) {
      function extract(obj, prop) {
        var p = obj[prop];
        obj[prop] = undefined;
        return p;
      }

      var shouldLog = window.location.hostname.toLowerCase().endsWith(DG.get('logFromServer')),
          time = new Date(),
          eventValue,
          parameters = {},
          body;

      if( !shouldLog) {
        // The logging path below indirectly triggers SproutCore notifications.
        // Calling SC.run() allows the same notifications to get triggered without the logging.
        SC.run();
        return;
      }

      if (DG.get('logServerUrl')) {
        // sessionIndex++;

        eventValue = extract(iProperties, 'args');

        // test for simple string
        if (/^[a-zA-Z]*$/.test(eventValue)) {
          parameters = {value: eventValue};
        }
        else {
          try {
            parameters = JSON.parse(eventValue);
            // If the value of parameters is not an object, then wrap the value in
            // an object. Otherwise the log manager will reject it.
            if (typeof parameters !== 'object') {
              parameters = {value: parameters};
            }
          } catch (e) {
            // ignore exceptions
          }
        }

        // hack to deal with pgsql 'varying' type length limitation

        if (eventValue && eventValue.length > 255) {
          eventValue = eventValue.substr(0, 255);
        }

        body = {
          activity:    extract(iProperties, 'activity') || 'Unknown',
          application: extract(iProperties, 'application'),
          session:     DG.get('runKey') || sessionKey,
          // avoids TZ ambiguity; getTime returns milliseconds since the epoch (1-1-1970 at 0:00 *UTC*)
          time:        time.getTime(),
          event:       event,
          event_value: eventValue,
          parameters:  parameters
        };
        
        var run_remote_endpoint = DG.get('run_remote_endpoint');
        if (run_remote_endpoint)
          body.run_remote_endpoint = run_remote_endpoint;

        var jsonBody = SC.json.encode(body);
        $.ajax(DG.get('logServerUrl'), {
          type: 'POST',
          contentType: 'application/json',
          data: jsonBody,
          xhrFields: {
            withCredentials: false
          }
        });
        console.log('sent to log server: ' + jsonBody);
      }
    }
  };
})());

/* >>>>>>>>>> BEGIN source/controllers/collection_client.js */
// ==========================================================================
//                        DG.CollectionClient
//
//  Author:   Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

  (Document Your Controller Here)

  @extends SC.Object
*/
DG.CollectionClient = SC.Object.extend(
/** @scope DG.CollectionClient.prototype */ {

  collection: null, // DG.Collection

  /**
   * The id of the underlying DG.CollectionRecord.
   * @property {Number}
   */
  id: function() {
    return this.collection && this.collection.get('id');
  }.property('collection').cacheable(),

  /**
   * The name of the collection with which this object is associated.
   * @property {String}
   */
  name: function(key, value) {
    if (value !== undefined) {
      this.collection.set('name', value);
    }
    return this.collection && this.collection.get('name');
  }.property('collection').cacheable(),

  titleBinding: '.collection.title',

  collapseChildren: function () {
    return this.collection && this.collection.get('collapseChildren');
  }.property('collection').cacheable(),

  defaults: function () {
    return this.collection && this.collection.get('defaults');
  }.property('collection').cacheable(),

  /**
   * Returns labels for this collection, if any have been set.
   * @returns {Object}
   */
  labels: function () {
    return this.collection && this.collection.get('labels');
  }.property('collection').cacheable(),

  attrsController: null,

  casesController: null,

  attrFormulaChanges: null,

  /**
    Returns true if this collection contains attributes with formulas that
    use aggregate functions. The presence of aggregate function references
    can affect how clients respond to change notifications, for instance.
    @property   {Boolean}
   */
  hasAggregates: function() {
    var attrCount = this.attrsController.get('length');
    for( var i = 0; i < attrCount; ++i) {
      var attr = this.attrsController.objectAt( i);
      if( attr && attr.getPath('_dgFormula.hasAggregates'))
        return true;
    }
    return false;
  }.property(),

  init: function() {
    arguments.callee.base.apply(this,arguments);
    this.attrsController = SC.ArrayController.create({});
    this.casesController = SC.ArrayController.create({});
  },

  /**
    Destruction method.
   */
  destroy: function() {
    this.attrsController.forEach( function( iAttribute) {
      if( iAttribute)
        this.willDestroyAttribute( iAttribute);
    }.bind(this));
    this.collection.destroy();
    arguments.callee.base.apply(this,arguments);
  },

  /**
   * Indicates whether parent/child links are configured correctly.
   * Games using the revised API (Aug 2011) should set this to true.
   * Note that this property is not a record attribute and is not
   * expected to be archived with the record. It's a temporary flag
   * for use until games using the old API are no longer supported.
   * @property {Boolean}
   */
  areParentChildLinksConfigured: function() {
    return this.getPath('collection.areParentChildLinksConfigured');
  }.property().cacheable(),
  /**
   * Provides support for hooking up collection relationships for
   * games using the old game API.
   * @param {DG.CollectionClient} iParentCollection
   */
  setParentCollection: function( iParentCollection) {
    var childCollection = this.get('collection'),
        parentCollection = iParentCollection.get('collection');
    if( childCollection && parentCollection) {
      childCollection.set('parent', parentCollection);
      childCollection.set('areParentChildLinksConfigured', true);
      parentCollection.set('areParentChildLinksConfigured', true);
    }
  },

  getParentCollectionID: function () {
    var collectionModel = this.get('collection');
    var parent = collectionModel && collectionModel.parent;
    return (parent && parent.id);
  },

  /**
    Returns true if iOtherCollection is descended from this collection.
    @param {DG.CollectionClient} iOtherCollection The collection to test for ancestry.
    @returns {Boolean} True if this is an ancestor of iOtherCollection, false otherwise.
   */
  isAncestorOf: function( iOtherCollection) {
    var myCollectionModel = this.get('collection');
    return myCollectionModel &&
            myCollectionModel.isAncestorOf( iOtherCollection.get('collection'));
  },

  /**
    Returns true if this collection is descended from iOtherCollection.
    @param {DG.CollectionClient} iOtherCollection The collection to test for ancestry.
    @returns {Boolean} True if this is an descendant of iOtherCollection, false otherwise.
   */
  isDescendantOf: function( iOtherCollection) {
    var myCollectionModel = this.get('collection');
    return myCollectionModel &&
            myCollectionModel.isDescendantOf( iOtherCollection.get('collection'));
  },

  /**
    Sets the collection model for this collection client.
    @param    {DG.CollectionModel}  iCollection -- The collection to be used as this object's model
   */
  setTargetCollection: function( iCollection) {
    this.set('collection', iCollection);
    this.attrsController.set('content', iCollection.attrs);
    this.casesController.set('content', iCollection.cases);

    // When restoring documents, we need to process the restored attributes
    this.forEachAttribute( function( iAttribute) {
                            this.didCreateAttribute( iAttribute);
                          }.bind( this));
  },

  /**
   * Reorders the attributes according to the order specified by the attribute
   * list. The attribute list is an array of attribute names. All names in the
   * list must be present as named attributes or the reordering will be
   * abandoned. There may be attributes not specified in the list. These will
   * be ordered after the attributes named in the list in their present order.
   *
   * @param {[String]} iAttributeNameList an array of attribute names
   */
  reorderAttributes: function(iAttributeNameList) {
    var nameListLength = iAttributeNameList.length;
    this.collection.attrs.sort(function(attr1, attr2) {
      var ix1 = iAttributeNameList.indexOf(attr1.name),
        ix2 = iAttributeNameList.indexOf(attr2.name);
      if (ix1 < 0) {ix1 = nameListLength++;}
      if (ix2 < 0) {ix2 = nameListLength++;}
      return ix1 - ix2;
    });
  },

  /**
    Returns an array with the IDs of the attributes in the collection.
   */
  getAttributeIDs: function() {
    return this.attrsController.getEach('id');
  },

  /**
    Returns an array with the names of the attributes in the collection.
    @returns    {[string]}   The array of attribute names
   */
  getAttributeNames: function() {
    return this.attrsController.getEach('name');
  },

    /**
     Returns an array with the names of the visible attributes in the collection.
     Omits any attributes with 'hidden' property set to true
     @returns    {[string]}   The array of attribute names
     */
    getVisibleAttributeNames: function() {
      return this.attrsController.filterProperty('hidden', false).getEach('name');
    },

  /**
    Returns the number of attributes in the collection.
    @returns    {Number}    The number of attributes in the collection
   */
  getAttributeCount: function() {
    return this.attrsController.get('length');
  },

  /**
    Returns the attribute at the specified index in the collection.
    @param    {Number}        iAttrIndex -- The index of the attribute to be returned
    @returns  {DG.Attribute}  The DG.Attribute with the specified ID or undefined
   */
  getAttributeAt: function(iAttrIndex) {
    return this.attrsController.objectAt(iAttrIndex);
  },

  /**
    Returns the attribute with the specified ID.
    @param    {Number}        iAttrID -- The ID of the attribute to be returned
    @returns  {DG.Attribute}  The DG.Attribute with the specified ID or undefined
   */
  getAttributeByID: function(iAttrID) {
    return !SC.none( iAttrID) ? this.attrsController.findProperty('id', Number(iAttrID)) : undefined;
  },

  /**
    Returns the attribute whose name matches the specified name.
    @param    {String}        iAttrName -- The name of the attribute to be returned
    @returns  {DG.Attribute}  The DG.Attribute with the specified ID or undefined
   */
  getAttributeByName: function(iAttrName) {
    return !SC.empty( iAttrName) ? this.attrsController.findProperty('name', iAttrName) : undefined;
  },

  /**
    Returns the index of the specified attribute name in the list of attribute names.
    @param    {String}        iAttrName -- The name of the attribute whose index is to be returned
    @returns  {Number}        0-origin index of attribute name in attribute list, or -1 if not found
   */
  getAttributeIndexByName: function( iAttrName) {
    var tNames = this.getAttributeNames();
    return tNames.indexOf( iAttrName );
  },

  /**
    Returns true if the collection contains an attribute with the specified name,
    false otherwise.
    @param    {String}    iAttrName -- The name of the attribute to look for
    @returns  {Boolean}   True if an attribute with the specified name exists,
                          false otherwise.
   */
  hasAttribute: function( iAttrName) {
    return this.getAttributeIndexByName( iAttrName) >= 0;
  },

  /**
    Creates a new attribute with the specified properties.
    @param    {Object}        iProperties -- Initial property values
    @returns  {DG.Attribute}  The newly-created DG.Attribute object
   */
  createAttribute: function( iProperties) {
    var newAttribute = this.collection.createAttribute( iProperties || {});

    if( newAttribute) this.didCreateAttribute( newAttribute);

    return newAttribute;
  },

  /**
    Utility function called when an attribute is added to the collection or
    when the DG.CollectionClient is first attached to an existing collection.
    Adds necessary observers for each attribute in the collection.
    @param    {DG.Attribute}  iAttribute -- The attribute being added
   */
  didCreateAttribute: function( iAttribute) {
  },

  /**
    Utility function called when an attribute is about to be removed from the collection
    or when the DG.CollectionClient is first attached to an existing collection.
    Removes necessary observers from each attribute in the collection.
   */
  willDestroyAttribute: function( iAttribute) {
  },

  canonicalizeName: function (iName) {
    return DG.Attribute.canonicalizeName(iName);
  },

  /**
    Returns the attribute which matches the specified properties, creating it if it doesn't already exist.
    @param    {Object}        iProperties -- Initial property values
    @param    {boolean}       isUndo -- optional param: whether this call is
                                part of an undo
    @returns  {DG.Attribute}  The matching or newly-created DG.Attribute object

   */
  guaranteeAttribute: function( iProperties, isUndo) {

    var tAttribute = null;

    // See if the attribute already exists
    iProperties = iProperties || {};

    if (!SC.none(iProperties.name)) {
      iProperties.name = this.canonicalizeName(iProperties.name);
    }

    // if the property has an ID then it is an existing attribute, possibly from
    // another collection. If so, we need to remove it from the other collection
    // and add it here.

    if (!SC.empty( iProperties.name)) {
      tAttribute = this.getAttributeByName( iProperties.name);

      if ( tAttribute) {
        // Attribute already exists:
        // copy the formula property, if there is one.
        if( iProperties.formula !== undefined || isUndo) {
          // we used to ban formula changes if editable flag not set.
          // Now, data interactive is considered to preempt the setting
          // in the document.
          this.setAttributeFormula( tAttribute, iProperties.formula, isUndo);
        }
        // copy the attribute colors
        if (!SC.none( iProperties.categoryMap)) {
          tAttribute.set('categoryMap', SC.clone( iProperties.categoryMap));
        }

        ['title', 'type', 'description', 'editable', 'hidden', 'precision', 'unit', 'blockDisplayOfEmptyCategories'].forEach(function (prop) {
          if (!SC.none( iProperties[prop])) {
            tAttribute.set(prop, iProperties[prop]);
          }
        });
      }

      // If the attribute doesn't exist, we must create it
      else {
        tAttribute = this.createAttribute( iProperties);
      }
    }

    return tAttribute;
  },

  /**
    Sets the formula for the specified attribute.
    If a formula is removed, computed values become editable ones.
    @param  {DG.Attribute}    iAttribute -- The attribute whose formula is to be set.
    @param  {String}          iFormula -- The formula to set for the attribute
    @param  {boolean}         isUndo -- whether call is part of an undo. If so
                                        and the operation removes a formula, we
                                        do not overwrite existing values with
                                        formula values.
   */
  setAttributeFormula: function( iAttribute, iFormula, isUndo) {
    var attrID = iAttribute && iAttribute.get('id'),
        didHaveFormula = iAttribute.get('hasFormula'),
        willHaveFormula = !SC.empty( iFormula),
        preserveComputedValues = didHaveFormula && !willHaveFormula && !isUndo,
        preservedValues = [];

    // Preserve computed values if necessary
    if( preserveComputedValues) {
      // preserve computed values
      this.forEachAttributeValue( attrID,
                                  function( iValue) {
                                    preservedValues.push( iValue);
                                  });
    }

    // Set the new formula (which may erase the formula)
    iAttribute.set('formula', iFormula);

    // Restore the preserved computed values if necessary
    if( preserveComputedValues) {
      // set the preserved values as the new case values
      this.setAttributeValuesFromArray( attrID, preservedValues);
      // Mark legacy attributes with formulae as 'editable'
      if( !iAttribute.get('editable'))
        iAttribute.set('editable', true);
    }
    // Signal a formula change manually. See comment under newAttribute
    // for details of why we're signalling manually.
    this.attributeFormulaDidChange(iAttribute);
  },

  /**
    Applies the specified function to each attribute in the collection.
    @param    {Function}      iFunction to be applied to each attribute
    @returns  {DG.CollectionClient} this, for use in chaining method invocations
   */
  forEachAttribute: function( iFunction) {
    this.collection.attrs.forEach( iFunction);
    return this;
  },

  /**
    Returns an array containing the IDs of every case.
    @returns  {Array of Number}   The array of case IDs
   */
  getCaseIDs: function() {
    return this.casesController.getEach('id');
  },

  parseSearchQuery: function (queryString) {
      if (queryString === '*') {
        return {
          valid: true,
          op: '*'
        };
      }
    // for now this is a simple single expression of "left op right" where op is a comparison operator
    // this could be expanded (along with the testCaseAgainstQuery method below) using the shunting yard algorithm
    var matches = queryString.match(/([^=!<>]+)(==|!=|<=|<|>=|>)([^=!<>]*)/),
        trim = function (s) { return s.replace(/^\s+|\s+$/, ''); },
        parsedQuery = {
          valid: !!matches,
          left: matches && trim(matches[1]),
          op: matches && matches[2],
          right: matches && trim(matches[3])
        },
        attrNameToIdMap = {},
        parseOperand = function (value) {
          var numberValue = Number(value),
              parsedValue = value === 'true' ? true : (value === 'false' ? false : (isNaN(numberValue) ? value : numberValue));
          return {
            value: parsedValue,
            id: attrNameToIdMap[value]
          };
        };

    this.forEachAttribute(function (attr) {
      attrNameToIdMap[attr.name] = attr.id;
    });

    parsedQuery.left = parseOperand(parsedQuery.left);
    parsedQuery.right = parseOperand(parsedQuery.right);

    // valid queries must have at least one side with a defined attribute
    parsedQuery.valid = !!(parsedQuery.valid && (parsedQuery.left.id || parsedQuery.right.id));

    return parsedQuery;
  },

  testCaseAgainstQuery: function (iCase, parsedQuery) {
    var getValue = function (attr) {
          return attr.id ? iCase.getValue(attr.id) : attr.value;
        },
        leftValue = parsedQuery.left && getValue(parsedQuery.left) || '',
        rightValue = parsedQuery.right && getValue(parsedQuery.right) || '';

    if (!parsedQuery.valid) {
      return false;
    }

    switch (parsedQuery.op) {
      case '*':  return true;
      case '==': return leftValue === rightValue;
      case '!=': return leftValue !== rightValue;
      case '<':  return leftValue <   rightValue;
      case '<=': return leftValue <=  rightValue;
      case '>=': return leftValue >=  rightValue;
      case '>':  return leftValue >   rightValue;
      default:   return false;
    }
  },

  searchCases: function (queryString) {
    var parsedQuery = this.parseSearchQuery(queryString);

    // return null to signal an invalid query
    if (!parsedQuery.valid) {
      return null;
    }

    return this.casesController.filter(function (iCase) {
      return this.testCaseAgainstQuery(iCase, parsedQuery);
    }.bind(this));

  },

  /**
   * Returns the cases in this collection that satisfy the query string, where
   * "satisfy" means the formula returns a truthy value for the case.
   *
   * @param queryString {string} A formula expression with the same syntax
   *   and meaning as the string constructed in the Formula Editor
   * @return {[DG.Case]}
   */
  searchCasesByFormula: function (queryString) {
    var collectionID = this.get('id');
    var context = DG.CollectionFormulaContext.create({
      ownerSpec: {
        type: DG.DEP_TYPE_UNDEFINED,
        id: this.get('id'),
        name: this.get('name')
      },
      collection: this.get('collection')
    });
    var formula = DG.Formula.create({context: context});
    formula.set('source', queryString);

    var cases = this.casesController.filter(function (iCase) {
      return formula.evaluate({
        _case_: iCase,
        _id_: iCase && iCase.get('id'),
        _collectionID_: collectionID
      });
    });

    formula.destroy();
    return cases;
  },

  caseCount: function () {
    return this.getCaseCount();
  }.property(),

  /**
    Returns the number of cases in the collection.
    @returns  {Number}    The number of cases in the collection
   */
  getCaseCount: function() {
    return this.casesController.get('length');
  },

  nonemptyCaseCount: function () {
    return this.getNonemptyCaseCount();
  }.property('*casesController'),

  getNonemptyCaseCount: function() {
    if (this.collection.children && this.collection.children.length) {
      return this.casesController.get('length');
    } else {
      return this.casesController.reduce(function (ct, myCase){
        if (!myCase.get('isEmpty')) {
          return ct + 1;
        } else {
          return ct;
        }
      }, 0);
    }
  },

  caseCountDidChange: function () {
    this.notifyPropertyChange('caseCount');
  }.observes('*casesController', 'casesController.length'),

  /**
    Returns the case at the specified index within the collection.
    @param    iCaseIndex {Number}    The index of the case to be returned
    @returns  {DG.Case}   The case at the specified index
   */
  getCaseAt: function(iCaseIndex) {
    return this.casesController.objectAt(iCaseIndex);
  },

  /**
   * @param iCaseID {number|string}
   * @returns {number|undefined}
   */
  getCaseIndexByID: function (iCaseID) {
    var tCollection = this.get('collection');
    return tCollection && tCollection.getCaseIndexByID( iCaseID);
  },

  /**
   * @param iCaseID {number|string}
   * @returns {DG.Cases}
   */
  getCaseByID: function(iCaseID) {
    var ix = this.getCaseIndexByID(iCaseID);
    if (!SC.none(ix)) {
      return this.getCaseAt(ix);
    }
  },

  /**
   * Observer function which notifies when case indices change.
   */
  caseIndicesDidChange: function() {
    this.notifyPropertyChange('caseIndices');
  }.observes('*collection.caseIDToIndexMap'),

  /**
    Returns true if the case at the specified index is selected, false otherwise.
    @param    {Number}    iCase The index of the case whose selection status is to be returned
    @returns  {Boolean}         True if the specified case is selected, false otherwise
   */
  isCaseSelected: function( iCase) {
    var tSelection = this.getPath('casesController.selection');
    return iCase && tSelection ? tSelection.contains( iCase) : false;
  },

  /**
    Returns true if the case at the specified index is selected, false otherwise.
    @param    iCaseIndex {Number}    The index of the case whose selection status is to be returned
    @returns  {Boolean}              True if the specified case is selected, false otherwise
   */
  isCaseAtIndexSelected: function( iCaseIndex) {
    var tCase = this.getCaseAt( iCaseIndex),
        tSelection = this.getPath('casesController.selection');
    return tCase && tSelection ? tSelection.contains( tCase) : false;
  },

  /**
    Creates a new case with the specified initial properties.

    If the properties object contains an `index` property, the new case will
    be inserted at the appropriate index. Otherwise, it will be added to
    the end of the cases array.

    @param    {Object}    iProperties -- Initial properties for the newly-created DG.Case
    @returns  {DG.Case}   The newly-created DG.Case object
   */
  createCase: function( iProperties) {
    return this.collection.createCase( iProperties || {});
  },

  /**
    Updates the 'attrFormulaChanges' property, triggering any observers of that property.
   */
  attributeFormulaDidChange: function(iAttribute) {
    var attrID = iAttribute.get('id'),
        prevID = this.get('attrFormulaChanges');
    this.beginPropertyChanges();
      // force notification, even if the attribute is the same
      if (prevID === attrID) {
        this.set('attrFormulaChanges', null);
      }
      this.set('attrFormulaChanges', attrID);
    this.endPropertyChanges();
  },

  /**
    Apples the specified function to each case in the collection.
    @param    {Function}  iFunction The function to apply to each case
    @returns  {DG.CollectionClient} this, for method chaining
   */
  forEachCase: function( iFunction) {
    this.casesController.forEach( iFunction);
    return this;
  },

  /**
    Applies the specified function to each value of the specified attribute.
    Passes the raw value (i.e. including Dates) to the specified callback function.
    @param    {Number}              iAttrID -- The ID of the attribute whose values are to be iterated
    @param    {Function}            iFunction -- The function to apply to each value of the specified attribute
    @returns  {DG.CollectionClient} this, for method chaining
   */
  forEachAttributeValue: function( iAttrID, iFunction) {
    var cases = this.getPath('casesController.arrangedObjects');
    cases.forEach( function( iCase) {
                    var caseValue = iCase.getRawValue( iAttrID);
                    iFunction( caseValue);
                  });
    return this;
  },

  /**
    Set multiple values for the specified case from an array of values.
    The values are assumed to be in canonical attribute order, which is
    generally order of creation. This function exists to support case
    creation by games, which specify the canonical attribute order when
    they create their collections, and then specify simple arrays of
    values when creating cases. This was deemed preferable to having
    the game provide attrName:value pairs, which would be more work
    for the game, require more bandwidth, and require the app to perform
    attribute lookups for every value. The downside to this approach is
    that the app must maintain the canonical attribute order.
    @param    {DG.Case}         iCase -- The case whose values are to be set
    @param    {Array of values} iValues -- The array of values used to set the case values
   */
  setCaseValuesFromArray: function( iCase, iValues) {
    var attrIDs = this.getAttributeIDs(),
        attrLength = attrIDs.length,
        valuesLength = iValues ? iValues.length : 0,
        i, count = attrLength < valuesLength ? attrLength : valuesLength,
        tValue;
    iCase.beginCaseValueChanges();
    for( i = 0; i < count; ++i) {
      tValue = DG.DataUtilities.canonicalizeInputValue( iValues[i]);
      // Currently, setValue is called for null values but not undefined ones.
      if( tValue !== undefined)
        iCase.setValue( attrIDs[ i], tValue);
    }
    iCase.endCaseValueChanges();
  },

  /**
    Set multiple attribute values from the specified array of values.
   */
  setAttributeValuesFromArray: function( iAttrID, iValues) {
    var cases = this.getPath('casesController.arrangedObjects');
    cases.forEach( function( iCase, iIndex) {
                    if( iIndex < iValues.length)
                      iCase.setValue( iAttrID, iValues[ iIndex]);
                  });
  },

  /**
    Delete the specified case.
    Client should call didDeleteCases() after deleting a batch of cases.
    @param    {DG.Case}   iCase: the case to delete
   */
  deleteCase: function( iCase) {
    this.get('collection').deleteCase( iCase);
  },

  setAsideCase: function (iCase) {
    this.get('collection').setAsideCase(iCase);
  },

  restoreSetAsideCases: function () {
    this.get('collection').restoreSetAsideCases();
  },

  /**
    This function should be called whenever cases are deleted to allow
    the collection a chance to synchronize store contents, ID to index
    maps, and other contents.
   */
  didDeleteCases: function() {
    this.get('collection').updateCaseIDToIndexMap();
  },

  /**
    Deletes the currently selected cases from the collection.
   */
  deleteSelectedCases: function() {
    var tCollection = this.get('collection'),
        tSelected = this.getPath('casesController.selection');
    DG.logUser("deleteSelectedCases: %@", tSelected.length());
    tSelected.forEach( function( aCase) {
      tCollection.deleteCase( aCase);
    });
    this.didDeleteCases();
  },

  /**
    Deletes all cases from the collection.
   */
  deleteAllCases: function() {
    var tCollection = this.get('collection'),
        tCases = tCollection.get('cases'),
        tArray = tCases.concat();

    tArray.forEach(function (aCase) {
      tCollection.deleteCase(aCase, true);
    });
    this.didDeleteCases();
  },

  markCasesForDeletion: function () {
    var tCollection = this.get('collection'),
        tCases = tCollection.get('cases');
    tCases.forEach(function (iCase) {
      iCase._deletable = true;
    });
  },

  deleteMarkedCases: function () {
    var tCollection = this.get('collection'),
        tCases = tCollection.get('cases'),
        tDeletedCases = [],
        tRetainedCases = [];

    // if there are no delete cases, this is a no-op
    if (!tCases.some(function (iCase) {
      return (iCase._deletable);
    })) {
      return [];
    }

    this.getPath('collection.cases').beginPropertyChanges();
    this.casesController.beginPropertyChanges();
    this.beginPropertyChanges();
    try {
      tCases.forEach(function (myCase) {
        if (myCase._deletable) {
          tDeletedCases.push(myCase);
          // DG.Case._removeCaseFromItemMap(myCase);
          DG.Case.destroyCase(myCase);
        } else {
          tRetainedCases.push(myCase);
        }
      });
      this.setPath('collection.cases', tRetainedCases);
      this.casesController.set('content', tRetainedCases);
    } finally {
      this.endPropertyChanges();
      this.casesController.endPropertyChanges();
      this.getPath('collection.cases').endPropertyChanges();
    }

    if (tDeletedCases.length > 0) {
      this.didDeleteCases();
    }
    //DG.log("Did delete %@ cases".loc(tDeletedCaseIDs.length));
    return tDeletedCases;
  },

  // deleteMarkedCases: function () {
  //   var tCollection = this.get('collection'),
  //       tCases = tCollection.get('cases'),
  //       tDeletedCaseIDs = [],
  //       tDeletedCases = [],
  //       ix,
  //       iCase;
  //   for (ix = tCases.length - 1; ix >= 0; ix --) {
  //     iCase = tCases[ix];
  //     if (iCase._deletable) {
  //       tDeletedCases.push(iCase);
  //       tDeletedCaseIDs.push(iCase.id);
  //       tCollection.deleteCase(iCase, true);
  //     }
  //   }
  //   if (tDeletedCaseIDs.length > 0) {
  //     this.didDeleteCases();
  //   }
  //   //DG.log("Did delete %@ cases".loc(tDeletedCaseIDs.length));
  //   return tDeletedCases;
  // },

  /**
    Returns a link object of the form { type: 'DG.CollectionRecord', id: collectionID }.
    @returns  {Object}  linkObject -- contains the type and id of the referenced record
              {String}  linkObject.type -- the type of record ('DG.CollectionRecord' in this case).
              {Number}  linkObject.id -- the id of the collection record
   */
  toLink: function() {
    var collection = this.getPath('collection');
    return collection && collection.toLink();
  },

  debugLog: function(iPrompt) {
    this.get('collection').debugLog(iPrompt);
  }

}) ;


/* >>>>>>>>>> BEGIN source/controllers/game_context.js */
// ==========================================================================
//                          DG.GameContext
//
//  The GameContext is a derived class of DG.DataContext specialized to
//  support the game components.
//  
//  Author:   Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('controllers/data_context');

/** @class DG.GameContext

  Coordinating controller which manages a set of collections that form a
  hierarchical data model.

  @extends DG.DataContext
*/
DG.GameContext = DG.DataContext.extend(
/** @scope DG.GameContext.prototype */ {

  /**
   *  The type of DataContext, for use when archiving/restoring.
   *  @property {String}
   */
  type: 'DG.GameContext',
  
  /**
   * The name of the currently selected game.
   * @property {String}
   */
  gameName: null,
  
  /**
   * The dimensions of the currently selected game {width,height}.
   * @property {{width: number, height}}
   */
  gameDimensions: null,
  
  /**
   * The URL of the currently selected game.
   * @property {String}
   */
  gameUrl: null,

  /**
   * The version string for the game.
   * @property {String}
   */
  gameVersion: null,

  /**
    Called after a collection has been created to make sure it's hooked up properly.
    @param    {DG.CollectionClient}   iCollectionClient -- The collection just created
   */
  didCreateCollection: function( iCollectionClient) {
    // The prior logic for this method relied upon properties in the deprecated
    // gameSpec that were not widely employed to determine proper parent/child
    // relationships. Presently this is left in as a no-op, pending a new
    // mechanism.
  },

  /**
    Returns the default DG.CollectionClient and default attributes to plot for
    newly created graphs, as indicated by this context's game.
   */
  collectionDefaults: function() {
    var defaults = { collectionClient: null,
                     plotXAttr: null, plotXAttrIsNumeric: true,
                     plotYAttr: null, plotYAttrIsNumeric: true };

    // If no default specified (or we can't find it), default to the child collection.
    if (SC.none( defaults.collectionClient)) {
      defaults.collectionClient = this.get('childCollection');
      defaults.parentCollectionClient = this.get('parentCollection');
    }

    /**
      Utility function for use in specifying default plot attributes.
      @param  {DG.CollectionClient} collectionClient
      @param  {String}    iAttrPrefix -- {'x','y','legend'}
      @param  {String}    iAttrInfix -- {'X','Y','Legend'}
     */
    function configureDefaultPlotAttr(collectionClient, iAttrPrefix, iAttrInfix) {
      // Retrieve the attribute name
      var attrName = collectionClient && collectionClient.getPath('defaults.' +
        iAttrPrefix + 'Attr'),
        attr, isNumeric;
      if( defaults.collectionClient && !SC.empty( attrName)) {
        // Set default attribute
        attr = defaults.collectionClient.getAttributeByName(attrName);
        defaults['plot' + iAttrInfix + 'Attr'] = attr;
        // Indicate the type of the default attribute
        isNumeric = collectionClient && collectionClient.getPath('defaults.' +
              iAttrPrefix + 'AttrIsNumeric');
        if(SC.none( isNumeric)) {
          isNumeric = (attr.get('type') === 'numeric');
        }
        if( !SC.none( isNumeric))
          defaults['plot' + iAttrInfix + 'AttrIsNumeric'] = isNumeric;
      }
    }
  
    // Find the game-specified default attributes and configure them appropriately.
    configureDefaultPlotAttr(defaults.collectionClient, 'x', 'X');
    configureDefaultPlotAttr(defaults.collectionClient, 'y', 'Y');
    configureDefaultPlotAttr(defaults.collectionClient, 'legend', 'Legend');

    return defaults;
  },
  
  /**
    Returns the 'labels' object from the specification of the collection with the
    specified name.
    @param    {DG.CollectionClient} iCollection -- The collection whose labels are returned
    @returns  {Object}              The 'labels' portion of the collection specification
   */
  getLabelsForCollection: function( iCollection) {
    return iCollection.get('labels');
  },
  
  /**
    Returns the string that best represents the noun form of the specified number of cases,
    e.g. "case"|"cases", "person"|"people", "deer"|"deer", "goose"|"geese", etc.
    @param    {DG.CollectionClient} iCollection -- The collection whose labels are returned
    @param    {Number}              iCount -- The number of cases to represent
    @returns  {String}              The string to represent the specified number of cases
   */
  getCaseNameForCount: function( iCollection, iCount) {
    var labels = this.getLabelsForCollection( iCollection);
    if( !labels || !labels.singleCase || !labels.pluralCase)
      return arguments.callee.base.apply(this,arguments);
    
    return iCount === 1 ? labels.singleCase : labels.pluralCase;
  },
  
  /**
    Returns the string that represents a coherent set of cases, e.g. a set of Lunar Lander
    events is often called "a flight record", while in other games it might be "a round".
    @param    {DG.CollectionClient} iCollection -- The collection whose labels are returned
    @returns  {String}              The string label to represent a set of cases
   */
  getLabelForSetOfCases: function( iCollection) {
    // Use the 'labels' specification if it's available
    var labels = this.getLabelsForCollection( iCollection),
        setOfCasesWithArticle = labels && labels.setOfCasesWithArticle;
    if( !SC.empty( setOfCasesWithArticle)) return setOfCasesWithArticle;

    // Use the base class implementation as a final fallback
    return arguments.callee.base.apply(this,arguments);
  },
  
  /**
   *  Returns the object to be JSONified for storage.
   *  @returns  {Object}
   */
  createStorage: function() {
    var theStorage = arguments.callee.base.apply(this,arguments);
    theStorage.gameName = this.get('gameName');
    theStorage.gameUrl = this.get('gameUrl');

    // If a saved game state has been cached, add it to the
    // returned storage object and then clear the cache.
    var gameState = this.get('savedGameState');
    if( gameState) {
      // Copy _links_ from gameState to theStorage
      DG.ObjectMap.forEach( gameState._links_,
                            function( iKey, iLinkID) {
                              // We prepend '_game_' so we can distinguish game links from DG
                              // app links. Currently, all game links are to DG.Cases, since
                              // the game doesn't have access to any other record IDs.
                              DG.ArchiveUtils.addLinkID( theStorage, '_game_' + iKey, 'DG.Case', iLinkID);
                            });
      theStorage.gameState = gameState;
      // Clear it once we've transferred it to storage
      this.set('savedGameState', null);
    }
    
    return theStorage;
  },
  
  /**
   *  Copies the contents of iComponentStorage to the model.
   *  @param {Object} iContextStorage -- Properties restored from document.
   */
  restoreFromStorage: function( iContextStorage) {
    arguments.callee.base.apply(this,arguments);
    
    // At the point at which we're restoring the context(s), the game may not
    // have been loaded yet. We need to cache the game state locally until we
    // receive some indication that the game is ready for the restored state.
    if( iContextStorage && iContextStorage.gameState) {
      // Copy _links_ from iContextStorage into gameState
      if( iContextStorage._links_) {
        DG.ObjectMap.forEach( iContextStorage._links_,
                              function( iKey, iLinkSpec) {
                                // Game links are prepended with '_game_'
                                if( iKey.slice( 0, 6) === '_game_') {
                                  // Remove the prefix before storing in gameState
                                  var tKey = iKey.slice( 6);
                                  // Create the gameState's _links_ property if necessary
                                  if( !iContextStorage.gameState._links_)
                                    iContextStorage.gameState._links_ = {};
                                    // Store it in gameState's _links_ property
                                  iContextStorage.gameState._links_[ tKey] = iLinkSpec.id;
                                }
                              });
      }
      
      this.set('restoredGameState', iContextStorage.gameState);
    }
  }
  
});

DG.DataContext.registry['DG.GameContext'] = function( iProperties) {
                                              return DG.GameContext.create( iProperties);
                                            };

/**
 *  Retrieve the DataContext for the specified game, creating it if necessary.
 *  @property {DG.DataContext} or a derived class
 */
DG.GameContext.getContextForGame = function( iGameSpec) {
  if( !iGameSpec) return null;
  var context = iGameSpec.get('context');
  if( !context) {
    var props = { type: iGameSpec.get('contextType') || 'DG.GameContext' };
    if( props.type === 'DG.GameContext') {
      props.gameSpec = iGameSpec;
    }
    var documentID = DG.currDocumentController().getPath('content.id'),
        model = DG.DataContextRecord.createContext({ type: props.type, document: documentID });
    if( model) { props.model = model; }
    context = DG.DataContext.factory( props);
    if( context)
      iGameSpec.set('context', context);
  }
  return context;
};


/* >>>>>>>>>> BEGIN source/controllers/globals_controller.js */
// ==========================================================================
//                      DG.GlobalsController
// 
//  The controller for all extent global variables.
//  
//  Author:   Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

  @extends SC.Controller
*/
DG.globalsController = SC.Controller.create( (function() {
/** @scope DG.GlobalsController.prototype */ 

  return {
  
    /**
      Array of objects indicating changes that have occurred.
      @property   {Array of Object}
     */
    globalNameChanges: null,
    
    /**
      Array of strings representing the names of the changed global values.
      @property   {Array of String}
     */
    globalValueChanges: null,
    
    /**
      @private
      Maps from name to global value.
     */
    _globalsMap: {},

    /**
     * Called when a document is closed so that all global values are destroyed.
     */
    reset: function() {
      DG.ObjectMap.forEach( this._globalsMap, function( iKey, iValue){
        this.destroyGlobalValue( iValue);
      }.bind(this));
    },
  
    /**
      Utility function for determining whether the specified name is available.
      @param    {String}    iName -- The proposed name to search for
      @returns  {Boolean}   True if the name is in use, false if it is available.
     */
    isNameInUse: function( iName) {
      return !SC.none( this.getGlobalValueByName( iName));
    },

    /**
      Return the global value with the matching name.
      @param    {String}          iName -- the name of the global value to search for
      @returns  {DG.GlobalValue}  The matching global value or null if not found
     */
    getGlobalValueByName: function( iName) {
      return this._globalsMap[iName];
    },

    getGlobalValueByID: function (iID) {
      return Object.values(this._globalsMap).find(function (gv) {return gv.id === Number(iID);});
    },
  
    /**
      Return the next available global value name using the specified iPrefix (or "v").
      The name is made unique by adding a numeric suffix, so if "v" is the prefix,
      "v1", "v2", "v3", ... will be tried until a unique name is found.
      @param    {String}    (Optional) iPrefix -- The name prefix; defaults to "v".
      @returns  {String}    A unique name for use with the next global value.
     */
    getUniqueName: function( iPrefix) {
      var tCounter = 0,
          tTrialName;
      iPrefix = iPrefix || "v";
      do {
        ++ tCounter;
        tTrialName = iPrefix + tCounter;
      } while( this.isNameInUse( tTrialName));
      return tTrialName;
    },
  
    /**
      Create a global with the specified properties and name prefix.
      @param    {Object}    iProperties -- Properties passed to newly created global value
      @param    {String}    (Optional) iPrefix -- The name prefix; defaults to "v".
      @returns  {DG.GlobalValue}  The newly created global value.
     */
    createGlobalValue: function( iProperties, iPrefix) {
      iProperties = iProperties || {};
      if ( SC.empty(iProperties.document)) {
        iProperties.document = DG.activeDocument;
      }
      if( SC.empty( iProperties.name))
        iProperties.name = this.getUniqueName( iPrefix);
      if( SC.none(iProperties.value))
        iProperties.value = 0.5;
      var tGlobal = DG.GlobalValue.createGlobalValue( iProperties);
      this.registerGlobalValue( tGlobal);
      return tGlobal;
    },
    
    /**
      Destroy the specified global value.
      @param    {DG.GlobalValue}  iGlobalValue -- The global value to destroy
     */
    destroyGlobalValue: function( iGlobalValue) {
      var name = iGlobalValue && iGlobalValue.get('name');
      iGlobalValue.removeObserver('name', this, this.nameDidChange);
      iGlobalValue.removeObserver('value', this, this.valueDidChange);
      delete this._globalsMap[ name];
      DG.GlobalValue.destroyGlobalValue( iGlobalValue);
      this.set('globalNameChanges', [{ oldName: name }]);
      this.valueDidChange();
    },
    
    /**
      Register the global value by adding it to the internal name map and
      adding the necessary observers. Also notifies that 'globalNameChanges'
      have occurred.
      @param    {DG.GlobalValue}  iGlobalValue -- The global value to register
     */
    registerGlobalValue: function( iGlobalValue) {
      var name = iGlobalValue && iGlobalValue.get('name');
      if( !SC.none(name) && !this._globalsMap[name]) {
        this._globalsMap[name] = iGlobalValue;
        iGlobalValue.addObserver('name', this, this.nameDidChange);
        iGlobalValue.addObserver('value', this, this.valueDidChange);
        this.set('globalNameChanges', [{newName: name}]);
      }
    },

    /**
     * When a name changes, we need to update the _globalsMap.
     * This method observes _each_ global value's name.
     * Notifies that 'globalNameChanges' have occurred.
     * @param   {DG.GlobalValue}  iGlobal -- The notifying global value
     */
    nameDidChange: function( iGlobal) {
      var tOldName = DG.ObjectMap.findValue( this._globalsMap, iGlobal),
          tNewName = iGlobal.get('name');
      if( tOldName !== tNewName) {
        this._globalsMap[ tNewName] = iGlobal;
        DG.ObjectMap.remove( this._globalsMap, tOldName);
        this.set('globalNameChanges', [{ oldName: tOldName, newName: tNewName }]);
      }
    },

    /**
      Called when any global value changes its value.
      Notifies that 'globalValueChanges' have occurred.
     */
    valueDidChange: function( iNotifier) {
      var name = iNotifier && iNotifier.get('name'),
          changes = name ? [ name ] : [];
      this.set('globalValueChanges', changes);
    },
    
    stopAnimation: function() {
      DG.ObjectMap.forEach( this._globalsMap,
                            function( iKey, iValue) {
                              if( iValue && iValue.stopAnimation)
                                iValue.stopAnimation();
                            } );
    },
    
    /**
      Returns an array of global variable names in use.
      @returns    {Array of String} The names of the current set of global values
     */
    getGlobalValueNames: function() {
      return DG.ObjectMap.keys( this._globalsMap);
    },
    
    /**
      A namespace is an object which contains name:value pairs for
      every global value. These can be used with the 'with' statement
      to simplify variable references.
      @param    {Object}    ioNamespace -- The object to which the name:value
                                            pairs should be added.
     */
    addGlobalValuesToNamespace: function( ioNamespace) {
      DG.ObjectMap.forEach( this._globalsMap,
                            function( iKey, iValue) {
                              ioNamespace[ iKey] = iValue.get('value');
                            } );
    }

  }; // return from function closure
}())); // function closure

/* >>>>>>>>>> BEGIN source/controllers/undo_history.js */
// ==========================================================================
//                      DG.UndoHistory
//
//  The controller for managing undo/redo.
//
//  Based on concepts from Fathom, Ivy (https://github.com/concord-consortium/building-models/blob/master/src/code/utils/undo-redo.coffee),
//    and undo.js (https://github.com/jzaefferer/undo/blob/master/undo.js)
//
//  Author:   Aaron Unger
//
//  Copyright (c) 2015 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class
 * The main controller for Undo and Redo functionality.
 *
 * For documentation about how to use UndoHistory, please see /docs/undo.md
 *
 * @extends SC.Object
*/
DG.UndoHistory = SC.Object.create((function() {
  var kStateNotifyMap = [
      'nan',
      /*EXECUTE*/ 'executeNotification',
      /*UNDO*/    'undoNotification',
      /*REDO*/    'redoNotification'
  ];
  /** @scope DG.UndoHistory.prototype */
  return {

    EXECUTE: 1,
    UNDO: 2,
    REDO: 3,

    enabledBinding: SC.Binding.oneWay('DG.enableUndoHistory'),

    /** @private
      A list of commands available to be undone. The last item in the array is the next item
      to be undone. This makes it easy to use pop() when undoing things and push() to add new commands on.
     */
    _undoStack: [],

    /** @private
      A list of commands available to be redone. The last item in the array is the next item
      to be redone. This makes it easy to use pop() when redoing things and push() to add new commands on.
     */
    _redoStack: [],

    /** @private
      A flag so that we can know if calls to documentWasChanged happened inside of a command function or not.
     */
    _executeInProgress: false,

    /**
      Registers a command which can be undone and redone at a later point. The command is immediately executed,
      and then added to the stack for later.
      @param    {DG.Command}  command -- An instance of DG.Command, which provides methods for doing, undoing and redoing an action.
     */
    execute: function(command) {
      try {
        this._wrapAndRun(command, command.execute);
      } catch (e) {
        // Just let exceptions bubble up, but clear the stacks...
        this._clearUndo();
        this._clearRedo();
        throw e;
      }

      // If the command didn't actually change anything, then don't add this to the stack
      // and don't invalidate either stack.
      if (!command.causedChange) { return; }

      // _executeInProgress will still be true if this is a nested call to execute. In that case, don't
      // append to the stack (we'll assume the outer-most Command knows how to undo all of its side effects).
      if (this._executeInProgress) { return; }

      if (this.get('enabled') && command.isUndoable) {

        // If we can reduce this command with the previous one, replace this command with the
        // reduced version and pop the previous one out.
        if (command.reduce && this._undoStack.length > 0) {
          var reducedCommand = command.reduce(this._undoStack[this._undoStack.length-1]);
          if (reducedCommand) {
            command.reduced = true;
            this._undoStack.pop();
            command = reducedCommand;
          }
        }

        this._undoStack.push(command);
        // Since we're not using set/get to access the stacks, notify changes manually.
        this.notifyPropertyChange('_undoStack');
      } else {
        // We've hit a not-undoable command, so clear our undo stack
        this._clearUndo();
      }
      // Clear the redo stack every time we add a new command. We *don't* support applying changes
      // from a different change tree to the current tree.
      this._clearRedo();

      this._logAction(command, this.EXECUTE);
      this._notify(command, this.EXECUTE);
      this._dirtyDocument(command.changedObject);
    },

    /**
     *  A flag indicating whether we have any commands to undo.
     *  @property {Boolean}
     */
    canUndo: function() {
      return this._undoStack.length > 0;
    }.property('_undoStack'),

    /**
     *  The next command which will be undone.
     *  @property {DG.Command}
     */
    nextUndoCommand: function() {
      if (this._undoStack.length === 0) {
        return null;
      }
      return this._undoStack[this._undoStack.length-1];
    }.property('_undoStack'),

    /**
      Undoes the most recently executed command and adds that command to the redo stack.
     */
    undo: function() {
      DG.globalEditorLock.commitCurrentEdit();

      // You can get here directly from a keyboard shortcut, so rather than check if we
      // have anything to undo outside of this function, we'll just double-check here.
      if (!this.get('enabled') || this._undoStack.length === 0) {
        return;
      }
      var command = this._undoStack.pop();
      try {
        this._wrapAndRun(command, command.undo);
      } catch (e) {
        this.showErrorAlert(true, e);
      }
      this._redoStack.push(command);

      // Since we're not using set/get to access the stacks, notify changes manually.
      this.notifyPropertyChange('_undoStack');
      this.notifyPropertyChange('_redoStack');

      if( !command.undoNotification)
        command.undoNotification = {
          action: 'notify',
          resource: 'document',
          values: {
            operation: 'undo',
          }
        };
      this._logAction(command, this.UNDO);
      this._notify(command, this.UNDO);
      this._dirtyDocument(command.changedObject);
    },

    /**
     *  A flag indicating whether we have any commands to redo.
     *  @property {Boolean}
     */
    canRedo: function() {
      return this._redoStack.length > 0;
    }.property('_redoStack'),

    /**
     *  The next command which will be redone.
     *  @property {DG.Command}
     */
    nextRedoCommand: function() {
      if (this._redoStack.length === 0) {
        return null;
      }
      return this._redoStack[this._redoStack.length-1];
    }.property('_redoStack'),

    /**
      Redoes the most recently undone command and adds that command to the undo stack.
     */
    redo: function() {
      DG.globalEditorLock.commitCurrentEdit();

      // You can get here directly from a keyboard shortcut, so rather than check if we
      // have anything to redo outside of this function, we'll just double-check here.
      if (!this.get('enabled') || this._redoStack.length === 0) {
        return;
      }
      var command = this._redoStack.pop();
      try {
        this._wrapAndRun(command, command.redo);
      } catch (e) {
        this.showErrorAlert(false, e);
      }
      this._undoStack.push(command);

      // Since we're not using set/get to access the stacks, notify changes manually.
      this.notifyPropertyChange('_undoStack');
      this.notifyPropertyChange('_redoStack');

      if( !command.redoNotification)
        command.redoNotification = {
          action: 'notify',
          resource: 'document',
          values: {
            operation: 'redo',
          }
        };
      this._logAction(command, this.REDO);
      this._notify(command, this.REDO);
      this._dirtyDocument(command.changedObject);
    },

    /**
      This method is called automatically by DG.dirtyCurrentDocument. If a document is dirtied
      as part of a command execution, then we ignore it. Otherwise, we clear the undo and redo stacks
      since a document-changing action took place which can't be undone.
     */
    documentWasChanged: function() {
      if (this._executeInProgress) { return; } // This is fine, we're doing it as part of a Command action

      // Otherwise, this wasn't part of a command, so this change is not able to be undone.
      // Clear the stacks
      this.clearUndoRedoHistory();

      // Also log the current stack so we can track these down one-by-one
/*
      if (this.get('enabled')) {
        DG.Debug.logErrorRaw("Document dirtied outside of an Undo Command\n%@".fmt((new Error()).stack));
      }
*/
    },

    clearUndoRedoHistory: function() {
      this._clearUndo();
      this._clearRedo();
    },

    // Something went wrong. We shouldn't ever reach here, because if we do, it's because of a programming error.
    // BUT, if it does happen, display an error dialog to the user, and then clear the undo/redo stacks.
    // Odds are pretty high that the entire app is going to be messed up too, but there's not much we can do about that.
    showErrorAlert: function(wasUndo, err) {
      if (!err || !err.message) {
        err = {message: "Unknown error"};
      }
      DG.Debug.logErrorRaw("Exception occurred while %@: %@\n%@".fmt((wasUndo ? "undoing: " : "redoing: "), err.message, err.stack));
      DG.AlertPane.error({
        localize: true,
        message: (wasUndo ? 'DG.Undo.exceptionOccurred' : 'DG.Redo.exceptionOccurred'),
        buttons: [
          {title: "OK", action: function() { this.clearUndoRedoHistory(); }.bind(this) }
        ]
      });
    },

    makeComponentNotification: function( iOperation, iType) {
      return {
        action: 'notify',
        resource: 'component',
        values: {
          operation: iOperation,
          type: iType
        }
      };
    },

    /** @private
      Helper method to run a function in a certain context. All calls to documentWasChanged will be ignored during its execution.
      @param    {DG.Command}   cmd -- An instance of DG.Command, which is used as the context for the function execution.
      @param    {Function}    func -- A function to be executed.
     */
    _wrapAndRun: function(cmd, func) {
      // Check if we're executing nested inside of another call to execute.
      // If we are, don't touch _executeInProgress.
      if (this._executeInProgress) {
        func.call(cmd);
      } else {
        this._executeInProgress = true;
        // We'll catch exceptions higher up, so only clean up after ourselves here...
        try {
          func.call(cmd);
        } finally {
          this._executeInProgress = false;
        }
      }
    },

    /** @private
      Helper function for clearing the undo stack.
     */
    _clearUndo: function() {
      this._undoStack.length = 0;
      this.notifyPropertyChange('_undoStack');
      this._sendUndoChangeToDI('clearUndo');
    },

    /** @private
      Helper function for clearing the redo stack.
     */
    _clearRedo: function() {
      this._redoStack.length = 0;
      this.notifyPropertyChange('_redoStack');
      this._sendUndoChangeToDI('clearRedo');
    },

    _dirtyDocument: function(changedObject) {
      if (this._executeInProgress) {
        DG.dirtyCurrentDocument(changedObject);
      } else {
        this._executeInProgress = true;
        DG.dirtyCurrentDocument(changedObject);
        this._executeInProgress = false;
      }
    },

    _queuedLogMessage: null,

    _logAction: function(command, state) {
      var logString = '';
      if (state === this.UNDO) {
        logString = 'Undo: ';
      } else if (state === this.REDO) {
        logString = 'Redo: ';
      }
      if (typeof(command.log) === 'function') {
        logString += command.log(state);
      } else {
        logString += command.log;
      }

      if (this._queuedLogMessage && !command.reduced) {
        DG.logUser(this._queuedLogMessage);
        this._queuedLogMessage = null;
      }
      if (command.reduce && state === this.EXECUTE) {
        // avoid logging reduced log messages until the end
        this._queuedLogMessage = logString;
      } else {
        DG.logUser(logString);
      }
    },

    _notify: function (command, state) {
      var propName = kStateNotifyMap[state] || ((state === this.REDO) && kStateNotifyMap);
      var prop = command[propName];
      var notification = prop && (typeof prop === 'function')? prop(state): prop;
      if (notification) {
        DG.currDocumentController().notificationManager.sendNotification(notification);
      }
    },

    _sendUndoChangeToDI: function(operation) {
      DG.sendCommandToDI({action: 'notify', resource: 'undoChangeNotice',
                          values: { operation: operation,
                                    canUndo: this.get('canUndo'),
                                    canRedo: this.get('canRedo')} });
    }

  }; // return from function closure
})()); // function closure

/* >>>>>>>>>> BEGIN source/controllers/web_view_controller.js */
// ==========================================================================
//                        DG.WebViewController
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('controllers/component_controller');

/** @class

  Coordinates save and restore for web views.

  @extends DG.ComponentController
*/
DG.WebViewController = DG.ComponentController.extend(
/** @scope DG.WebViewController.prototype */ {

  /**
   *  The URL the WebView is viewing.
   *  This property is bound to the 'value' property of the WebView.
   *  @property {String}
   */
  theURL: function (k, v) {
    if (!SC.none(v)) {
      this.setPath('model.content.URL', v);
    }
    return this.getPath('model.content.URL');
  }.property(),

  theURLDidChange: function () {
    this.notifyPropertyChange('theURL');
  }.observes('model.content.URL'),

  title: 'DG.WebView.defaultTitle'.loc(),

  /**
   *
   * @returns {Array}
   */
  createInspectorButtons: function() {
    var tButtons = arguments.callee.base.apply(this,arguments);
    tButtons.push(DG.IconButton.create({
          layout: {width: 32},
          classNames: 'dg-web-view-url'.w(),
          iconClass: 'moonicon-icon-mediaTool',
          showBlip: false,
          target: this,
          action: 'editURL',
          toolTip: 'DG.Inspector.webViewEditURL.toolTip',
          localize: true
        })
    );
    return tButtons;
  },

  editURL: function() {

    var this_ = this,
        tDialog = null;

    function setURL() {
      // User has pressed OK: can only do so if non-empty
      var tURL = tDialog.get('value');
      tDialog.close();
      this_.set('theURL', tURL);
    }

    tDialog = DG.CreateSingleTextDialog( {
                    prompt: 'DG.DocumentController.enterURLPrompt',
                    textValue: this_.get('theURL'),
                    textHint: 'URL',
                    okTarget: null,
                    okAction: setURL,
                    okTooltip: DG.DocumentController.enterViewWebPageOKTip
                  });
  },

  createComponentStorage:function () {
    var tURL = this.get('theURL'),
      tStorage = {
        title: this.title
      };
    if( !SC.empty( tURL))
      tStorage.URL = tURL;
    return tStorage;
  },

  restoreComponentStorage:function ( iComponentStorage ) {
    var tURL = iComponentStorage.URL || "";
    this.set('theURL', tURL);
    this.set('title', iComponentStorage.title);
  },

  /**
   *  Called when the view is connected to the controller.
   */
  viewDidChange: function() {
    // Bind the contents of the webView to our 'theURL' property.
    var tWebView = this.getPath('view.containerView.contentView');
    if( tWebView) {
      if( SC.empty( this.theURL)) // then it's safe to stuff it with the web view's URL
        this.set('theURL', tWebView.get('value'));
      tWebView.bind('value', this, 'theURL');
      tWebView.set('controller', this);
    }
  }.observes('view.containerView.contentView')

});


/* >>>>>>>>>> BEGIN source/formula/aggregate_function.js */
// ==========================================================================
//                        DG.AggregateFunction
//  
//  Author:   Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class DG.AggregateFunction

  The DG.AggregateFunction "class" is the base "class" for aggregate function
  implementation classes.

  @extends SC.Object
 */
DG.AggregateFunction = SC.Object.extend({

  /**
    By default, aggregate functions accept virtually any number of arguments.
    @property   {Object}  min: minimum # of arguments, max: maximum number of arguments
   */
  requiredArgs: { min: 0, max: 999 },

  /**
    By default, aggregate functions are not caseIndex-dependent.
    @param {Array of function arguments}  iArgs
    @returns  {Boolean}
   */
  isCaseIndexDependent: function(iArgs) {
    return false;
  },
  
  /**
    Returns a computed result from the cache.
    Derived classes must override.
    @param  {DG.FormulaContext}   iContext
    @param  {Object}              iEvalContext -- { _case_: , _id_: }
    @param  {Object}              iInstance -- The aggregate function instance from the context.
    @returns  {Number|String|...}
   */
  queryCache: function( iContext, iEvalContext, iInstance) {
    return undefined;
  },
  
  /**
    Evaluates the aggregate function and returns a computed result for the specified case.
    Base class evaluation method. Derived classes must override.
   */
  evaluate: function( iContext, iEvalContext, iInstance) {
  }

});


/** @class DG.IteratingAggregate

  The DG.IteratingAggregate "class" is the base "class" for aggregate function
  implementation classes which must iterate through all of the cases to perform
  their aggregate computation.

  @extends SC.AggregateFunction
 */
DG.IteratingAggregate = DG.AggregateFunction.extend({

  /**
    Returns a computed result from the cache.
    Base class implementation assumes that the cache is indexed by child case ID,
    i.e. suitable for implementation of functions that return separate values for
    each case. In Fathom we called these semi-aggregates -- functions like rank().
    @param  {DG.FormulaContext}   iContext
    @param  {Object}              iEvalContext -- { _case_: , _id_: }
    @param  {Object}              iInstance -- The aggregate function instance from the context.
    @returns  {Number|String|...}
   */
  queryCache: function( iContext, iEvalContext, iInstance) {
    return iInstance.results ? iInstance.results[ iEvalContext._id_] : undefined;
  },

  preEvaluate: function(iContext, iEvalContext, iInstance) {
    iInstance.caches = {};
    iInstance.results = {};
  },
  
  /**
    Evaluates the aggregate function and returns a computed result for the specified case.
    This implementation loops over all cases, calling the evalCase() method for each one.
    Derived classes should override the evalCase() method to perform whatever per-case
    computation and/or caching is required, and then the computeResults() method to 
    complete the computation and return the requested value.
    @param  {DG.FormulaContext}   iContext
    @param  {Object}              iEvalContext -- { _case_: , _id_: }
    @param  {Object}              iInstance -- The aggregate function instance from the context.
    @returns  {Number|String|...}
   */
  evaluate: function( iContext, iEvalContext, iInstance) {

    // If we have a valid cached value then simply return it.
    var cachedResult = this.queryCache( iContext, iEvalContext, iInstance);
    if( cachedResult !== undefined) return cachedResult;

    this.preEvaluate(iContext, iEvalContext, iInstance);

    // Prepare for iteration over all the cases.
    var collection = iContext && iContext.getCollectionToIterate(),
        cases = collection && collection.get('cases'),
        caseCount = cases && cases.get('length');

    // iterate over all the cases.
    for( var i = 0; i < caseCount; ++i) {
      var tCase = cases.objectAt( i),
          e = { _case_: tCase, _id_: tCase && tCase.get('id') };
      // Perform any per-case evaluation
      if (this.filterCase( iContext, e, iInstance))
        this.evalCase( iContext, e, iInstance);
    }
    
    // Complete the computation, returning the requested result
    return this.computeResults( iContext, iEvalContext, iInstance);
  },
  
  /**
    Returns true if the specified case passes the aggregate function filter argument.
    Base class method always returns true. Derived classes may override as appropriate.
    @param  {DG.FormulaContext}   iContext
    @param  {Object}              iEvalContext -- { _case_: , _id_: }
    @param  {Object}              iInstance -- The aggregate function instance from the context.
   */
  filterCase: function( iContext, iEvalContext, iInstance) {
    return iContext.filterCase( iEvalContext);
  },
  
  /**
    Perform any per-case computation and/or caching.
    Derived classes must override to implement their specific computations.
    @param  {DG.FormulaContext}   iContext
    @param  {Object}              iEvalContext -- { _case_: , _id_: }
    @param  {Object}              iInstance -- The aggregate function instance from the context.
    @param  {Number|null}         iCacheID -- The cache ID to use for cache lookups for this case.
   */
  evalCase: function( iContext, iEvalContext, iInstance, iCacheID) {
  },
  
  /**
    Complete the computation for a given case.
    Base class implementation assumes that the evaluate method has already filled
    the cache and that all this method needs to do is to return the cached result.
    Derived classes with more elaborate requirements can override as necessary.
    @param  {DG.FormulaContext}   iContext
    @param  {Object}              iEvalContext -- { _case_: , _id_: }
    @param  {Object}              iInstance -- The aggregate function instance from the context.
    @returns  {Number|String|...}
   */
  computeResults: function( iContext, iEvalContext, iInstance) {
    return this.queryCache( iContext, iEvalContext, iInstance);
  }

});


/** @class DG.ParentCaseAggregate

  The DG.ParentCaseAggregate "class" is the base "class" for aggregate function
  implementation classes which must iterate through all of the cases to perform
  their aggregate computation, and which compute/cache their results over a
  single parent case.

  @extends SC.IteratingAggregate
 */
DG.ParentCaseAggregate = DG.IteratingAggregate.extend({

  category: 'DG.Formula.FuncCategoryStatistical',

  // find the parent case that corresponds to the EvalContext's _collectionID_
  // if the _collectionID_ is the evaluated case, then default to its parent
  getGroupID: function(iContext, iEvalContext) {
    var tCase = iEvalContext._case_;

    // if we are evaluating a particular case, then derive the group from it
    if (tCase) {
      // if a specifid grouping variable was specified, then use it
      var groupVarID = iContext && iContext.get('groupVarID');
      if (groupVarID) {
        var groupID = iContext.getAttrValue(tCase, groupVarID);
        return !SC.empty(groupID) ? groupID : null;
      }
      else {
        // no grouping variable specified -- group by collection
        var tParent = tCase && tCase.get('parent');
        for (; tCase; tCase = tCase.get('parent'), tParent = tCase) {
          if (tCase.getPath('collection.id') === iEvalContext._collectionID_)
            return tParent ? tParent.get('id') : null;
        }
      }
    }
    // we're not evaluating a case; if client specified the group, then use it
    else {
      if (iEvalContext._groupID_) return iEvalContext._groupID_;
    }
    return null;
  },

  /**
    Returns a computed result from the cache.
    This class implementation assumes that the cache is indexed by parent case ID,
    i.e. suitable for implementation of functions that return the same value for all
    child cases of a given parent case, such as most simple univariate stats functions.
    @param  {DG.FormulaContext}   iContext
    @param  {Object}              iEvalContext -- { _case_: , _id_: }
    @param  {Object}              iInstance -- The aggregate function instance from the context.
    @returns  {Number|String|...}
   */
  queryCache: function( iContext, iEvalContext, iInstance) {
    if( iInstance.results) {
      if( iInstance.results[ iEvalContext._id_] !== undefined)
        return iInstance.results[ iEvalContext._id_];
      var cacheID = this.getGroupID( iContext, iEvalContext);
      if( iInstance.results[ cacheID] !== undefined)
        return iInstance.results[ cacheID];
    }
    return undefined;
  },

  /**
    Returns true if the specified case passes the aggregate function filter argument.
    Base class method always returns true. Derived classes may override as appropriate.
    @param  {DG.FormulaContext}   iContext
    @param  {Object}              iEvalContext -- { _case_: , _id_: }
    @param  {Object}              iInstance -- The aggregate function instance from the context.
   */
  filterCase: function( iContext, iEvalContext, iInstance) {
    var tBaseResult = arguments.callee.base.apply(this,arguments),
        filterFn = iInstance.filterFn;
    return tBaseResult && (filterFn ? filterFn( iContext, iEvalContext) : true);
  },
  
  /**
    Returns the value of the first argument, primarily for the benefit of
    univariate aggregate functions.
   */
  getValue: function( iContext, iEvalContext, iInstance) {
    var valueFn = iInstance.argFns[0];
    return valueFn && valueFn( iContext, iEvalContext);
  },
  
  /**
    Returns the numeric value of the first argument, primarily for the benefit
    of univariate aggregate functions.
   */
  getNumericValue: function( iContext, iEvalContext, iInstance) {
    var valueFn = iInstance.argFns[0];
    return valueFn && DG.getNumeric(valueFn( iContext, iEvalContext));
  },
  
  /**
    Evaluates the aggregate function and returns a computed result for the specified case.
    This implementation loops over all cases, calling the evalCase() method for each one,
    and then caching the result indexed by the parent case ID.
    Derived classes should override the evalCase() method to perform whatever per-case
    computation and/or caching is required, and then the computeResults() method to 
    complete the computation and return the requested value.
    @param  {DG.FormulaContext}   iContext
    @param  {Object}              iEvalContext -- { _case_: , _id_: }
    @param  {Object}              iInstance -- The aggregate function instance from the context.
    @returns  {Number|String|...}
   */
  evaluate: function( iContext, iEvalContext, iInstance) {

    var cachedResult = this.queryCache( iContext, iEvalContext, iInstance);
    if( cachedResult !== undefined) return cachedResult;

    this.preEvaluate(iContext, iEvalContext, iInstance);

    var collection = iContext && iContext.getCollectionToIterate(),
        cases = collection && collection.get('cases'),
        caseCount = cases && cases.get('length');

    for( var i = 0; i < caseCount; ++i) {
      var tCase = cases.objectAt( i),
          tEvalContext = $.extend({}, iEvalContext,
                                  { _case_: tCase, _id_: tCase && tCase.get('id') }),
          cacheID = this.getGroupID(iContext, tEvalContext);
      if (this.filterCase( iContext, tEvalContext, iInstance))
        this.evalCase( iContext, tEvalContext, iInstance, cacheID);
    }
    
    return this.computeResults( iContext, iEvalContext, iInstance);
  }
  
});


/** @class DG.CachedValuesParentCaseAggregate

  The DG.CachedValuesParentCaseAggregate "class" is the base "class" for aggregate function
  implementation classes which must iterate through all of the cases to perform
  their aggregate computation, and which compute/cache their results over a
  single parent case.

  @extends SC.CachedValuesParentCaseAggregate
 */
DG.CachedValuesParentCaseAggregate = DG.ParentCaseAggregate.extend({

  /**
    Perform any per-case computation and/or caching.
    For the SortDataFunction, this method simply caches its values for later sorting.
    @param  {DG.FormulaContext}   iContext
    @param  {Object}              iEvalContext -- { _case_: , _id_: }
    @param  {Object}              iInstance -- The aggregate function instance from the context.
    @param  {Number|null}         iCacheID -- The cache ID to use for cache lookups for this case.
   */
  evalCase: function( iContext, iEvalContext, iInstance, iCacheID) {
    var value = this.getNumericValue( iContext, iEvalContext, iInstance);
    if( value != null) {
      var cache = iInstance.caches[ iCacheID];
      if( cache) {
        cache.sum += value;
        cache.values.push(value);
      }
      else
        iInstance.caches[ iCacheID] = { sum: value, values: [value] };
    }
  },

  /**
    Compute the final value from the specified cache.
    @param  {Object}              iCache -- contents of the appropriate cache
    @returns  {Number|String|...}
   */
  computeResultFromCache: function(iCache) {
    // derived classes must override
  },

  /**
    Complete the computation for a given case.
    For the SortDataFunction, this requires sorting the values within each parent case,
    and then caching the extracted results from each parent case group.
    @param  {DG.FormulaContext}   iContext
    @param  {Object}              iEvalContext -- { _case_: , _id_: }
    @param  {Object}              iInstance -- The aggregate function instance from the context.
    @returns  {Number|String|...}
   */
  computeResults: function( iContext, iEvalContext, iInstance) {

    DG.ObjectMap.forEach(
        iInstance.caches,
        function(iKey, iCache) {
          iInstance.results[iKey] = this.computeResultFromCache(iCache);
        }.bind(this));
    return this.queryCache(iContext, iEvalContext, iInstance);
  },

  /*
    Utility function for computing the variance using the
    "corrected two-pass algorithm" from Numerical Recipes
    from the values cached during the first pass.
   */
  computeVarianceFromCache: function(iCache) {
    // must have at least two values to compute variance
    if (iCache.values && (iCache.values.length > 1)) {
      var count = iCache.values.length,
          mean = iCache.sum / count,
          sumDev = 0,
          sumSqrDev = 0,
          i, dev;

      // corrected two-pass algorithm from Numerical Recipes
      for (i = 0; i < count; ++i) {
        dev = iCache.values[i] - mean;
        sumDev += dev;
        sumSqrDev += dev * dev;
      }

      // second term serves as a round-off correction factor
      return ((sumSqrDev - (sumDev * sumDev) / count)) / (count - 1);
    }
    // if not enough values, return an error
    return NaN;
  }

});


/** @class DG.SortDataFunction

  The DG.SortDataFunction "class" is the base "class" for aggregate function
  implementation classes which must iterate through all of the cases to perform
  their aggregate computation, and which compute/cache their results over a
  single parent case, and which sort their values before computing their result.

  @extends SC.ParentCaseAggregate
 */
DG.SortDataFunction = DG.ParentCaseAggregate.extend({

  /**
    Perform any per-case computation and/or caching.
    For the SortDataFunction, this method simply caches its values for later sorting.
    @param  {DG.FormulaContext}   iContext
    @param  {Object}              iEvalContext -- { _case_: , _id_: }
    @param  {Object}              iInstance -- The aggregate function instance from the context.
    @param  {Number|null}         iCacheID -- The cache ID to use for cache lookups for this case.
   */
  evalCase: function( iContext, iEvalContext, iInstance, iCacheID) {
    var value = this.getNumericValue(iContext, iEvalContext, iInstance);
    // Currently, we only sort numeric values.
    // To support a Fathom-like alphanumeric sort, we would have to change the test here.
    if( value != null) {
      var cache = iInstance.caches[ iCacheID];
      if( cache) {
        cache.push( value);
      }
      else
        iInstance.caches[ iCacheID] = [ value ];
    }
    
  },
  
  /**
    Extracts a value from an array of cached values.
    @param  {Array of Number}   iCachedValues -- The array of cached values
    @returns  {Number|null}     Returns the result extracted from the array of values.
   */
  extractResult: function( iCachedValues, iEvalContext, iInstance) {
    // Derived classes must override
    return null;
  },
  
  /**
    Complete the computation for a given case.
    For the SortDataFunction, this requires sorting the values within each parent case,
    and then caching the extracted results from each parent case group.
    @param  {DG.FormulaContext}   iContext
    @param  {Object}              iEvalContext -- { _case_: , _id_: }
    @param  {Object}              iInstance -- The aggregate function instance from the context.
    @returns  {Number|String|...}
   */
  computeResults: function( iContext, iEvalContext, iInstance) {
    DG.ObjectMap.forEach( iInstance.caches,
                          function( iKey, iCachedValues) {
                            if( iCachedValues.length > 0) {
                              iCachedValues.sort( function( v1, v2) { return v1 - v2; });
                            }
                            iInstance.results[ iKey] = this.extractResult( iCachedValues, iEvalContext, iInstance);
                          }.bind( this));
    return this.queryCache( iContext, iEvalContext, iInstance);
  }

});

/** @class DG.BivariateStatsFn

  The DG.BivariateStatsFn "class" is the base "class" for bivariate aggregate function
  implementation classes which must iterate through all of the cases to store the
  valid coordinate pairs.

  @extends SC.ParentCaseAggregate
 */
DG.BivariateStatsFn = DG.ParentCaseAggregate.extend({

  requiredArgs: {min: 2, max: 2},

  /**
   Returns an object { x, y } with numeric values for each, primarily for the benefit
   of bivariate aggregate functions.
   */
  getCoordValue: function( iContext, iEvalContext, iInstance) {
    var xFn = iInstance.argFns[0],
        yFn = iInstance.argFns[1];
    return { x: xFn && DG.getNumeric(xFn( iContext, iEvalContext)),
      y: yFn && DG.getNumeric(yFn( iContext, iEvalContext)) };
  },

  /**
    Perform any per-case computation and/or caching.
    For the BivariateStatsFn, this method simply caches its coordinate pairs for later computation.
    @param  {DG.FormulaContext}   iContext
    @param  {Object}              iEvalContext -- { _case_: , _id_: }
    @param  {Object}              iInstance -- The aggregate function instance from the context.
    @param  {Number|null}         iCacheID -- The cache ID to use for cache lookups for this case.
   */
  evalCase: function( iContext, iEvalContext, iInstance, iCacheID) {
    var tCoordPair = this.getCoordValue(iContext, iEvalContext, iInstance);
    if (tCoordPair.x != null && tCoordPair.y != null) {
      var cache = iInstance.caches[iCacheID];
      if (cache) {
        cache.push( tCoordPair);
      }
      else
        iInstance.caches[iCacheID] = [tCoordPair];
    }
  }

});

/** @class DG.BivariateSemiAggregateFn

  The DG.BivariateSemiAggregateFn "class" is the base "class" for bivariate semi-aggregate function
  implementation classes which must make two passes through the data, first to gather the
  coordinate pairs and the second to compute something for each case based on quantities computed
  from the coordinate pairs in the first pass.

  @extends SC.BivariateStatsFn
 */
DG.BivariateSemiAggregateFn = DG.BivariateStatsFn.extend({

  requiredArgs: {min: 2, max: 2},
  yCanBeNonNumeric: false,

  // For bivariate functions there must be two numeric values
  filterCase: function(iContext, iEvalContext, iInstance) {

    function getValue( iIndex) {
      var tFn = iInstance.argFns[iIndex];
      return tFn && DG.getNumeric(tFn( iContext, iEvalContext));
    }

    var tBaseResult = arguments.callee.base.apply(this,arguments),
        tX = getValue(0),
        tY = getValue(1);
    return tBaseResult && DG.isNumeric(tX) && (DG.isNumeric(tY) || this.yCanBeNonNumeric);
  },

  preEvaluate: function(iContext, iEvalContext, iInstance) {
    arguments.callee.base.apply(this,arguments);

    // Make the first pass through the cases to gather coordinate pairs
    var collection = iContext && iContext.getCollectionToIterate(),
        cases = collection && collection.get('cases'),
        caseCount = cases && cases.get('length');

    for( var i = 0; i < caseCount; ++i) {
      var tCase = cases.objectAt( i),
          tEvalContext = $.extend({}, iEvalContext,
              { _case_: tCase, _id_: tCase && tCase.get('id') }),
          cacheID = this.getGroupID(iContext, tEvalContext);
      if (this.filterCase( iContext, tEvalContext, iInstance))
        this.evalCase( iContext, tEvalContext, iInstance, cacheID);
    }

    // Each cache now contains an array of coordinate pairs for its group.
    // We want to replace this array with the slope and intercept the lsrl
    DG.ObjectMap.forEach(iInstance.caches,
        function (iKey, iCache) {
          var tBiStats = DG.MathUtilities.computeBivariateStats( iCache),
              tSlope = tBiStats.sumOfProductDiffs / tBiStats.xSumSquaredDeviations;
          iInstance.caches[iKey] = {
            slope: tSlope,
            intercept: tBiStats.yMean - tSlope * tBiStats.xMean
          };
        });
  },

  /**
   Evaluates the aggregate function and returns a computed result for the specified case.
   This implementation loops over all cases, calling the evalCase() method for each one,
   and then caching the result indexed by the parent case ID.
   Derived classes should override the evalCase() method to perform whatever per-case
   computation and/or caching is required, and then the computeResults() method to
   complete the computation and return the requested value.
   @param  {DG.FormulaContext}   iContext
   @param  {Object}              iEvalContext -- { _case_: , _id_: }
   @param  {Object}              iInstance -- The aggregate function instance from the context.
   @returns  {Number|String|...}
   */
  evaluate: function( iContext, iEvalContext, iInstance) {

    var cachedResult = this.queryCache( iContext, iEvalContext, iInstance);
    if( cachedResult !== undefined) return cachedResult;

    this.preEvaluate(iContext, iEvalContext, iInstance);

    var collection = iContext && iContext.getCollectionToIterate(),
        cases = collection && collection.get('cases'),
        caseCount = cases && cases.get('length');

    for( var i = 0; i < caseCount; ++i) {
      var tCase = cases.objectAt( i),
          tEvalContext = $.extend({}, iEvalContext,
              { _case_: tCase, _id_: tCase && tCase.get('id') }),
          cacheID = this.getGroupID(iContext, tEvalContext);
      if (this.filterCase( iContext, tEvalContext, iInstance))
        this.secondPassEvalCase( iContext, tEvalContext, iInstance, cacheID);
    }

    return this.computeResults( iContext, iEvalContext, iInstance);
  }

});


/* >>>>>>>>>> BEGIN source/formula/basic_functions.js */
// ==========================================================================
//                          Basic Functions
//
//  Author:   Kirk Swenson
//
//  Copyright (c) 2016 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
/*global RandVarGen:true */
sc_require('formula/function_registry');

/**
  Implements the basic builtin functions and registers them with the FunctionRegistry.
 */
DG.functionRegistry.registerFunctions((function() {

  function trunc(x) {
    return SC.empty(x) ? '' :
        (x < 0 ? Math.ceil(x) : Math.floor(x));
  }

  var savedRandomGaussian = 0;  // The routine for generating random numbers drawn from a gaussian
                                // distribution generates two such numbers. We save one for next call
  var rvg;

  return {
    // JavaScript standard Math library functions
    'abs': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryArithmetic',
      evalFn: function(x) {
        return SC.empty(x) ? '' : Math.abs(x);
      }
    },
    'acos': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryTrigonometric',
      evalFn: function(x) {
        return SC.empty(x) ? '' : Math.acos(x);
      }
    },
    'asin': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryTrigonometric',
      evalFn: function(x) {
        return SC.empty(x) ? '' : Math.asin(x);
      }
    },
    'atan': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryTrigonometric',
      evalFn: function(x) {
        return SC.empty(x) ? '' : Math.atan(x);
      }
    },
    'atan2': {
      minArgs:2, maxArgs:2, category: 'DG.Formula.FuncCategoryTrigonometric',
      evalFn: function(y, x) {
        return SC.empty(x) || SC.empty(y) ? '' : Math.atan2(y, x);
      }
    },
    'ceil': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryArithmetic',
      evalFn: function(x) {
        return SC.empty(x) ? '' : Math.ceil(x);
      }
    },
    'combinations': {
      minArgs:2, maxArgs:2, category: 'DG.Formula.FuncCategoryArithmetic',
      evalFn: function(n, k) {

        function isInteger(num) {
          return Math.floor(Number(num)) === Number(num);
        }

        var tResult = '';
        if( !SC.empty(n) && !SC.empty(k) && isInteger(k) && isInteger(n)) {
          k = Number(k);
          n = Number(n);
          if( k < 0 || k > n) {
            tResult = 0;
          } else {
            if (n > 0 && isInteger(n)) {
              k = Math.min(k, n - k);
            }
            tResult = 1;
            var j = 1;
            while (j <= k) {
              tResult *= n--;
              if (isFinite(tResult)) {
                tResult /= j++;
              } else {
                tResult = "---OVERFLOW---";
                j = k;  // So we can escape with the overflow result
              }
            }
          }
        }
        return tResult;
      }
    },
    'cos': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryTrigonometric',
      evalFn: function(x) {
        return SC.empty(x) ? '' : Math.cos(x);
      }
    },
    'exp': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryArithmetic',
      evalFn: function(x) {
        return SC.empty(x) ? '' : Math.exp(x);
      }
    },
    'floor': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryArithmetic',
      evalFn: function(x) {
        return SC.empty(x) ? '' : Math.floor(x);
      }
    },
    //'ln': { minArgs:1, maxArgs:1 },     // replaced by DG version
    //'log': { minArgs:1, maxArgs:1 },    // replaced by DG version
    //'max': { minArgs:1, maxArgs:'n' },  // replaced by DG (aggregate) version
    //'min': { minArgs:1, maxArgs:'n' },  // replaced by DG (aggregate) version
    'pow': {
      minArgs:2, maxArgs:2, category: 'DG.Formula.FuncCategoryArithmetic',
      evalFn: function(x, y) {
        return SC.empty(x) || SC.empty(y) ? '' : Math.pow(x, y);
      }
    },
    //'random': { minArgs:0, maxArgs:0 }, // replaced by DG version
    //'round': { minArgs:1, maxArgs:1 },  // replaced by DG version
    'sin': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryTrigonometric',
      evalFn: function(x) {
        return SC.empty(x) ? '' : Math.sin(x);
      }
    },
    'sqrt': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryArithmetic',
      evalFn: function(x) {
        return SC.empty(x) ? '' : Math.sqrt(x);
      }
    },
    'tan': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryTrigonometric',
      evalFn: function(x) {
        return SC.empty(x) ? '' : Math.tan(x);
      }
    },

    /**
      Returns the fractional part of its argument.
      @param    {Number}  The numeric value whose fractional part is to be returned
      @returns  {Number}  The fractional part of its numeric argument
     */
    'frac': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryArithmetic',
      evalFn: function(x) {
        return SC.empty(x) ? '' : x - trunc(x);
      }
    },

    'if': {
      minArgs: 2, maxArgs: 3, category: 'DG.Formula.FuncCategoryOther',
      evalFn: function(condition, trueValue, falseValue) {
        function toBoolean(x) {
          var boolMap = {
            'true': true,
            'TRUE': true,
            'false' : false,
            'FALSE' : false
          };
          return boolMap[x] != null?boolMap[x]: !!x;
        }
        if (SC.empty(condition)) return '';
        return toBoolean(condition)
                ? (trueValue != null ? trueValue : '')
                : (falseValue != null ? falseValue : '');
      }
    },

    /**
      Returns the natural logarithm of its argument.
      @param    {Number}  The numeric value whose natural log is to be returned
      @returns  {Number}  The natural logarithm of its numeric argument
     */
    'ln': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryArithmetic',
      evalFn: function(x) {
        return SC.empty(x) ? '' : Math.log(x);
      }
    },

    /**
      Returns the base 10 logarithm of its argument. Note: We override Math.log
      to provide the base 10 log here. Use ln() for the natural log.
      @param    {Number}  The numeric value whose base 10 log is to be returned
      @returns  {Number}  The base 10 log of its numeric argument
     */
    'log': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryArithmetic',
      evalFn: function(x) {
        return SC.empty(x) ? '' : Math.log(x) / Math.LN10;
      }
    },

    /**
      Coerces its argument to a numeric value.
      @param    {Object}  The argument to be coerced to a number
      @returns  {Number}  The converted numeric value
     */
    'number': {
      minArgs: 1, maxArgs: 1, category: 'DG.Formula.FuncCategoryConversion',
      evalFn: function (x) {
        if (DG.isDate(x))
          return Number(x);
        else if (DG.isDateString(x))
          return Number(DG.parseDate(x));
        else
          return DG.MathUtilities.extractNumeric(x);
      }
    },

    /**
      Random number generator. Override of Math.random() to provide more flexibility.
      random()        -- Generates a random number in the range [0,1).
      random(max)     -- Generates a random number in the range [0,max).
      random(min,max) -- Generates a random number in the range [min,max).
      @param    {Number}  x1 -- If present alone, the maximum value of the random number.
                                If first of two argument, the minimum value of the random number.
      @param    {Number}  x2 -- The maximum value of the random number.
      @returns  {Number}  The generated random number
     */
    'random': {
      minArgs:0, maxArgs:2, isRandom: true, category: 'DG.Formula.FuncCategoryRandom',
      evalFn: function(x1,x2) {
        // random()
        if( SC.empty(x1)) return Math.random();
        // random(max)
        if( SC.empty(x2)) return x1 * Math.random();
        // random(min,max)
        return x1 + (x2 - x1) * Math.random();
      }
    },

    /**
      Generator for random numbers drawn from a normal distribution.
      randomNormal()        -- Generates a random number from a normal distribution with mean 0 and sd 1.
      randomNormal(mean)    -- Generates a random number from a normal distribution with mean mean and sd 1.
      randomNormal(mean,sd)  -- Generates a random number from a normal distribution with mean mean and sd sd.
      @param    {Number}  x1 -- The mean value of the normal distribution.
      @param    {Number}  x2 -- The value of the sd of the normal distribution
      @returns  {Number}  The generated random number
     */
    'randomNormal': {
      minArgs:0, maxArgs:2, isRandom: true, category: 'DG.Formula.FuncCategoryRandom',
      evalFn: function(mu,sigma) {
        var	fac, rsq, v1, v2;
        mu = mu || 0;
        sigma = SC.empty(sigma) ? 1 : sigma;

        if (savedRandomGaussian !== 0) {		// Is there one left?
          v1 = savedRandomGaussian;
          savedRandomGaussian = 0;
          return sigma*v1 + mu;
        }
        do {
          v1 = 2 * Math.random() - 1;
          v2 = 2 * Math.random() - 1;
          rsq = v1*v1 + v2*v2;
        } while (rsq >= 1);
        fac = Math.sqrt(-2.0*Math.log(rsq)/rsq);
        savedRandomGaussian = fac*v2;					// Save the first N(0,1) as double
        return sigma*fac*v1 + mu;	// and return the second.
      }
    },

  /**
      Generator for random numbers drawn from a binomial distribution.
      @param    {Number}  n -- The number of independent events
      @param    {Number}  p -- The probability of success for a single event
      @returns  {Number}  An integer drawn from a random binomial distribution with the given n and p
     */
    'randomBinomial': {
      minArgs:2, maxArgs:2, isRandom: true, category: 'DG.Formula.FuncCategoryRandom',
      evalFn: function(n,p) {
        if( SC.empty(n) || SC.empty(p) || n < 0 || Math.floor(n) !== n || p < 0 || p > 1)
          return '';
        else {
          if( !rvg)
            rvg = new RandVarGen.RandVarGen();
          return rvg.binomial( p, n);
        }
      }
    },

  /**
      Chooses one at random from its list of arguments
      @param    {any}  the arguments can have any type
      @returns  {any}
     */
    'randomPick': {
      minArgs:2, maxArgs:1000, isRandom: true, category: 'DG.Formula.FuncCategoryRandom',
      evalFn: function() {
        var tChosen = Math.floor(arguments.length * Math.random());
        return arguments[tChosen];
      }
    },

    /**
      Rounds a number to the nearest integer or specified decimal place.
      @param    {Number}  x -- The number to be rounded
      @param    {Number}  n -- {optional} The number of decimal places to round to (default 0).
      @returns  {Number}  The rounded result
     */
    'round': {
      minArgs:1, maxArgs:2, category: 'DG.Formula.FuncCategoryArithmetic',
      evalFn: function(x,n) {
        if (SC.empty(x)) return '';
        if (SC.empty(n)) return Math.round(x);
        var npow = Math.pow(10, trunc(n));
        return Math.round(npow * x) / npow;
      }
    },

    /**
      Coerces its argument to a string value.
      @param    {Object}  The argument to be coerced to a string
      @returns  {String}  The converted string value
     */
    'string': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryConversion',
      evalFn: function(x) {
        return SC.empty(x) ? '' : String(x);
      }
    },

    /**
      Returns the integer part of its argument.
      @param    {Number}  The numeric value whose integer part is to be returned
      @returns  {Number}  The integer part of its numeric argument
     */
    'trunc': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryArithmetic',
      evalFn: trunc
    },

    /**
      Returns the great circle distance between the two lat/long points on the earth's surface.
      @param    {Number}  The latitude in degrees of the first point
      @param    {Number}  The longitude in degrees of the first point
      @param    {Number}  The latitude in degrees of the second point
      @param    {Number}  The longitude in degrees of the second point
      @returns  {Number}  The distance in kilometers between the two points
     */
    'greatCircleDistance': {
      minArgs:4, maxArgs:4, category: 'DG.Formula.FuncCategoryOther',
      evalFn: function(lat1, long1, lat2, long2) {
        if( DG.isNumeric(lat1) && DG.isNumeric(lat2) && DG.isNumeric(long1) && DG.isNumeric(long2)) {
          var deltaLat = lat2 - lat1,
              deltaLong = long2 - long1,
              a = Math.pow(Math.sin((Math.PI / 180) * deltaLat / 2), 2) +
                  Math.cos(lat1 * Math.PI / 180) * Math.cos(lat2 * Math.PI / 180) *
                  Math.pow(Math.sin((Math.PI / 180) * deltaLong / 2), 2);
          return 2 * 6371 * Math.atan2(Math.sqrt(a), Math.sqrt(1 - a));
        }
        else {
          return '';
        }
      }
    }
  };
})());

/* >>>>>>>>>> BEGIN source/formula/bivariate_stats_fns.js */
// ==========================================================================
//                Bivariate Stats Aggregate Functions
//  
//  Author:   William Finzer
//
//  Copyright (c) 2017 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('formula/aggregate_function');
sc_require('formula/function_registry');

/** @class DG.BivariateStatsFns
 The DG.BivariateStatsFns object implements aggregate functions that
 perform bivariate statistical computations such as correlation, covariance,
 linRegrIntercept, linRegrPredicted, etc.
 */
DG.functionRegistry.registerAggregates((function () {

  return {

    correlation: DG.BivariateStatsFn.create({

      computeResults: function (iContext, iEvalContext, iInstance) {
        DG.ObjectMap.forEach(iInstance.caches,
            function (iKey, iCache) {
              iInstance.results[iKey] = DG.MathUtilities.correlation(iCache);
            });
        return this.queryCache(iContext, iEvalContext, iInstance);
      }
    }),

    rSquared: DG.BivariateStatsFn.create({

      computeResults: function (iContext, iEvalContext, iInstance) {
        DG.ObjectMap.forEach(iInstance.caches,
            function (iKey, iCache) {
              iInstance.results[iKey] = DG.MathUtilities.rSquared(iCache);
            });
        return this.queryCache(iContext, iEvalContext, iInstance);
      }
    }),

    linRegrSlope: DG.BivariateStatsFn.create({

      computeResults: function (iContext, iEvalContext, iInstance) {
        DG.ObjectMap.forEach(iInstance.caches,
            function (iKey, iCache) {
              iInstance.results[iKey] = DG.MathUtilities.linRegrSlope(iCache);
            });
        return this.queryCache(iContext, iEvalContext, iInstance);
      }
    }),

    linRegrSESlope: DG.BivariateStatsFn.create({

      computeResults: function (iContext, iEvalContext, iInstance) {
        DG.ObjectMap.forEach(iInstance.caches,
            function (iKey, iCache) {
              iInstance.results[iKey] = DG.MathUtilities.linRegrSESlopeAndIntercept(iCache).seSlope;
            });
        return this.queryCache(iContext, iEvalContext, iInstance);
      }
    }),

    linRegrIntercept: DG.BivariateStatsFn.create({

      computeResults: function (iContext, iEvalContext, iInstance) {
        DG.ObjectMap.forEach(iInstance.caches,
            function (iKey, iCache) {
              iInstance.results[iKey] = DG.MathUtilities.linRegrIntercept(iCache);
            });
        return this.queryCache(iContext, iEvalContext, iInstance);
      }
    }),

    linRegrResidual: DG.BivariateSemiAggregateFn.create({

      secondPassEvalCase: function (iContext, iEvalContext, iInstance, iCacheID) {
        var xFn = iInstance.argFns[0],
            yFn = iInstance.argFns[1],
            tSlope = iInstance.caches[iCacheID].slope,
            tIntercept = iInstance.caches[iCacheID].intercept,
            tCaseID = iEvalContext._id_;
        iInstance.results[tCaseID] = DG.getNumeric(yFn(iContext, iEvalContext)) -
            (tSlope * DG.getNumeric(xFn(iContext, iEvalContext)) + tIntercept);
      }
    }),

    linRegrPredicted: DG.BivariateSemiAggregateFn.create({

      yCanBeNonNumeric: true, // so that we can get predicted values for x's without y's

      secondPassEvalCase: function (iContext, iEvalContext, iInstance, iCacheID) {
        var xFn = iInstance.argFns[0],
            tSlope = iInstance.caches[iCacheID].slope,
            tIntercept = iInstance.caches[iCacheID].intercept,
            tCaseID = iEvalContext._id_;
        iInstance.results[tCaseID] = (tSlope * DG.getNumeric(xFn(iContext, iEvalContext)) + tIntercept);
      }
    })


  };

}()));

/* >>>>>>>>>> BEGIN source/formula/formula.js */
// ==========================================================================
//                            DG.Formula
//
//  Author:   Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class DG.Formula

  The DG.Formula object supports parsing, compilation, and evaluation of
  mathematical expressions. They make use of DG.FormulaContexts to provide
  variable and function references in different contexts.

  @extends SC.Object
 */
DG.Formula = SC.Object.extend((function() {

return {

  /**
    The compilation/evaluation context for the formula.
    @property   {DG.FormulaContext}
   */
  context: null,

  /**
    The original source text for the formula.
    @property   {String}
   */
  source: null,

  /**
    Initialization function.
   */
  init: function() {
    arguments.callee.base.apply(this,arguments);

    // Observe our context for dependent changes.
    var context = this.get('context');
    if( context) context.addObserver('namespaceChange', this, 'namespaceDidChange');
    if( context) context.addObserver('dependentChange', this, 'dependentDidChange');
  },

  /**
    Destruction function.
   */
  destroy: function() {
    var context = this.get('context');
    if( context) {
      // Remove observation of context
      context.removeObserver('namespaceChange', this, 'namespaceDidChange');
      context.removeObserver('dependentChange', this, 'dependentDidChange');
      context.destroy();
      this.context = null;
    }
    arguments.callee.base.apply(this,arguments);
  },

  /**
    Force a recompilation/reevaluation, including re-parsing the expression.
   */
  invalidate: function() {
    this.notifyPropertyChange('source');
  },

  /**
    Force a recompilation/reevaluation, without a re-parsing the expression.
   */
  invalidateContext: function() {
    this.notifyPropertyChange('context');
  },

  /**
    Observer function called when the context signals that its namespace
    has changed, which generally means that recompilation is required.
    This function just propagates the notification to clients of the formula.
   */
  namespaceDidChange: function( iNotifier, iKey) {
    this.invalidateContext();
    this.notifyPropertyChange( iKey);
    // For some clients, just knowing that a dependent may have changed is sufficient.
    this.notifyPropertyChange('dependentChange');
  },

  /**
    Observer function called when the context signals that one of its
    dependents has changed. This generally means that reevaluation is
    required, but that recompilation is not. This function generally
    just propagates the notification to clients of the formula.
   */
  dependentDidChange: function( iNotifier, iKey) {
    this.notifyPropertyChange( iKey);
  },

  /**
    The output of the PEG.js parser for the formula
    @property   {Object}
   */
  parseCount: 0,
  parsed: function() {
    ++ this.parseCount;
    var source = this.get('source'),
        result;
    try {
      result = source && DG.formulaParser.parse( source);
    }
    catch( err) {
      // Replace the PEG.js-generated SyntaxError message with our own
      err.originalMessage = err.message;
      err.message = err.found ? 'DG.Formula.SyntaxErrorMiddle'.loc( err.found)
                              : 'DG.Formula.SyntaxErrorEnd'.loc();
      throw err;
    }
    return result;
  }.property('source').cacheable(),

  /**
    The JavaScript function generated by walking the parse tree and generating code.
   */
  compiled: function() {
    var parsed = this.get('parsed'),
        context = this.get('context'),
        compiled = null;
    if( !context) {
      context = DG.FormulaContext.create({});
      this.context = context; // no reason to notify, so no set()
    }
    if( parsed) {
      context.willCompile();
      var output = DG.Formula.compileToJavaScript( parsed, context);
      context.didCompile();
      context.completeCompile();
      compiled = DG.FormulaContext.createContextFunction( output);
    }
    return compiled;
  }.property('parsed','context','namespaceChange').cacheable(),

  /**
    Returns true if this formula contains aggregate functions, false otherwise.
    @property {Boolean}
   */
  hasAggregates: function() {
    var hasAggregates = false;
    // Trap any parse errors that might occur
    try {
      // Make sure compilation has occurred. Shouldn't cause extra compilations
      // unless the SproutCore caching model isn't working as expected.
      this.get('compiled');

      var context = this.get('context');
      if( context)
        hasAggregates = context.get('hasAggregates');
    }
    catch(e) {
      // Formulas with parse errors can't cause aggregate function
      // evaluation, therefore we can simply swallow the parse error.
    }
    return hasAggregates;
  }.property('compiled', 'context').cacheable(),

  /**
    Evaluates the expression by compiling it to an intermediate JavaScript
    representation which is then used to create a new Function(...) for
    evaluation. This provides greater performance for formulas that are
    evaluated many times. For formulas that are only evaluated a few times,
    however, the overhead of compilation exceeds any benefit, and so
    evaluateDirect() should be used in those situations.
    @param    {Object}    iEvalContext -- An evaluation context object which allows
                                          clients to pass evaluation-time values to
                                          the evaluation process.
    @returns  {Object}    The evaluated result
   */
  evaluate: function( iEvalContext) {
    var compiled = this.get('compiled'),
        context = this.get('context');
    return compiled && compiled( context, iEvalContext);
  },

  /**
    Evaluates the expression directly without compilation.
    This is more efficient for small numbers of evaluations than the
    compile-to-JavaScript mechanism used by evaluate(), but is inefficient
    for large numbers of evaluations.
    @param    {Object}    iEvalContext -- An evaluation context object which allows
                                          clients to pass evaluation-time values to
                                          the evaluation process.
    @returns  {Object}    The evaluated result
   */
  evaluateDirect: function( iEvalContext) {
    var parsed = this.get('parsed'),
        context = this.get('context');
    if( !context) {
      context = DG.FormulaContext.create({});
      this.context = context; // no reason to notify, so no set()
    }
    return DG.Formula.evaluateParseTree( parsed, context, iEvalContext);
  }

  


};

}()));

/*
 * Regular expression for matching an identifier in a CODAP formula which handles Unicode chars u0000-u02FF.
 * Subset of https://github.com/mathiasbynens/unicode-data/blob/master/8.0.0/properties/Alphabetic-regex.js.
 * For full Unicode support, should consider a library like XRegExp (https://github.com/slevithan/xregexp).
 */
DG.Formula.identifierRegExpFirstCharSet = 'A-Za-z_\\xAA\\xB5\\xBA\\xC0-\\xD6\\xD8-\\xF6\\xF8-\\u02C1\\u02C6-\\u02D1\\u02E0-\\u02E4\\u02EC\\u02EE';

// matches simple identifiers
DG.Formula.identifierRegExp = (function() {
  var firstChar = DG.Formula.identifierRegExpFirstCharSet,
      otherChars = '0-9' + firstChar;
  return new RegExp('[%@][%@]*'.fmt(firstChar, otherChars));
}());

// matches function names, i.e. identifiers followed by a left-parenthesis
DG.Formula.functionRegExp = (function() {
  var firstChar = DG.Formula.identifierRegExpFirstCharSet,
      otherChars = '0-9' + firstChar;
  return new RegExp('[%@][%@]*(?=\\()'.fmt(firstChar, otherChars));
}());

// matches non-empty strings consisting entirely of white space characters
DG.Formula.whiteSpaceRegExp = /^[\s\uFEFF\xA0]+$/;

/**
 * Utility function used by some binary operators
 * @param iOperand1
 * @param iOperand2
 * @return {{} | NaN | Error}
 */
DG.Formula.arithmeticStarter = function( iOperand1, iOperand2) {
  var result = {
        isNumeric1: null, isNumeric2: null,
        isDate1: null, isDate2: null,
        empty1: null, empty2: null,
        num1: null, num2: null
      },
      // white-space-only strings default-convert to 0
      isSpaceStr1 = (typeof iOperand1 === "string") &&
          DG.Formula.whiteSpaceRegExp.test(iOperand1),
      isSpaceStr2 = (typeof iOperand2 === "string") &&
          DG.Formula.whiteSpaceRegExp.test(iOperand2);

  result.empty1 = SC.empty(iOperand1);
  result.empty2 = SC.empty(iOperand2);
  result.isDate1 = DG.isDate(iOperand1) || (!isSpaceStr1 && DG.isDateString(iOperand1));
  result.isDate2 = DG.isDate(iOperand2) || (!isSpaceStr2 && DG.isDateString(iOperand2));
  // booleans and strings (if possible) converted, not null values
  result.num1 = !result.empty1 && !isSpaceStr1
      ? (isNaN(iOperand1) ? Number(DG.createDate(iOperand1)) : Number(iOperand1))
      : NaN;
  result.num2 = !result.empty2 && !isSpaceStr2
      ? (isNaN(iOperand2) ? Number(DG.createDate(iOperand2)) : Number(iOperand2))
      : NaN;
  result.isNumeric1 = (result.num1 === result.num1);
  result.isNumeric2 = (result.num2 === result.num2);
  // errors propagate
  if (iOperand1 instanceof Error) return iOperand1;
  if (iOperand2 instanceof Error) return iOperand2;

  // NaNs propagate
  if ((iOperand1 !== iOperand1) || (iOperand2 !== iOperand2))
    return NaN;

  // Leave it to caller to work with result
  return result;
};

DG.Formula.arithmeticFinisher = function( iResult, iOperator) {
  // null values propagate
  if (iResult.empty1 && iResult.empty2)
    return '';
  // null values dominate numeric values
  if ((iResult.empty1 && iResult.isNumeric2) || (iResult.isNumeric1 && iResult.empty2))
    return '';
  // no more special cases - throw an exception
  throw new DG.TypeError(iOperator);
};

DG.Formula.stringFinisher = function( iResult, iOperand1, iOperand2, iOperator) {
  // null values propagate
  if (iResult.empty1 && iResult.empty2)
    return '';
  // null values dominate numeric values
  if ((iResult.empty1 && iResult.isNumeric2) || (iResult.isNumeric1 && iResult.empty2))
    return '';
  // no more special cases - operate on strings
  iOperand1 = String( iOperand1);
  iOperand2 = String( iOperand2);
  switch (iOperator) {
    case '+': return iOperand1 + iOperand2;
    case '<': return iOperand1 < iOperand2;
    case '<=': return iOperand1 <= iOperand2;
  }
};

/**
  Addition function which handles types by our rules rather than JavaScript's.
  Numbers and values interpretable as numeric (e.g. booleans, some strings)
  are added numerically. NaNs propagate. Null values propagate or concatenate
  depending on context. Otherwise, concatenate as strings.
 */
DG.Formula.add = function(iOperand1, iOperand2) {
  var result = DG.Formula.arithmeticStarter( iOperand1, iOperand2);

  if( (result instanceof Error) || typeof result !== 'object')
    return result;

  // values interpretable as numeric are added numerically
  if (result.isNumeric1 && result.isNumeric2)
    return result.isDate1 !== result.isDate2 ?
        DG.createDate((result.num1 + result.num2)) :
        result.num1 + result.num2;

  // Can't use arithmeticFinisher because strings can be concatenated
  // null values propagate
  if (result.empty1 && result.empty2)
    return '';
  // null values dominate numeric values
  if ((result.empty1 && result.isNumeric2) || (result.isNumeric1 && result.empty2))
    return '';
  // null values are concatenated (as empty strings) with string values
  if (result.empty1 && !result.empty2)
    return String(iOperand2);
  if (!result.empty1 && result.empty2)
    return String(iOperand1);

  // no more special cases - concatenate strings
  return DG.Formula.stringFinisher(result, iOperand1, iOperand2, '+');
};

/**
  Subtraction function which handles types by our rules rather than JavaScript's.
  Numbers and values interpretable as numeric (e.g. booleans, some strings)
  are subtracted numerically. Nulls and NaNs propagate.
 */
DG.Formula.subtract = function(iOperand1, iOperand2) {
  var result = DG.Formula.arithmeticStarter( iOperand1, iOperand2);

  if( (result instanceof Error) || typeof result !== 'object')
    return result;

  // values interpretable as numeric are 1subtracted numerically
  if (result.isNumeric1 && result.isNumeric2) {
    // date minus number results in date
    // all other combinations result in a number
    return (result.isDate1 && !result.isDate2) ?
        DG.createDate((result.num1 - result.num2)) :
        result.num1 - result.num2;
  }
  return DG.Formula.arithmeticFinisher( result, '\u2212');
};

/**
  Comparison function which handles types by our rules rather than JavaScript's.
  Numbers and values interpretable as numeric (e.g. dates, booleans, some strings)
  are compared numerically. Nulls and NaNs propagate.
 */
DG.Formula.lessThan = function(iOperand1, iOperand2) {
  var result = DG.Formula.arithmeticStarter( iOperand1, iOperand2);

  if( (result instanceof Error) || typeof result !== 'object')
    return result;

  // values interpretable as numeric are compared numerically
  if (result.isNumeric1 && result.isNumeric2) {
    return result.num1 < result.num2;
  }
  // no more special cases - compare strings
  return DG.Formula.stringFinisher(result, iOperand1, iOperand2, '<');
};

/**
  Comparison function which handles types by our rules rather than JavaScript's.
  Numbers and values interpretable as numeric (e.g. dates, booleans, some strings)
  are compared numerically. Strings are compared lexically. Nulls and NaNs propagate.
 */
DG.Formula.lessThanOrEqual = function(iOperand1, iOperand2) {
  var result = DG.Formula.arithmeticStarter( iOperand1, iOperand2);

  if( (result instanceof Error) || typeof result !== 'object')
    return result;

  // values interpretable as numeric are compared numerically
  if (result.isNumeric1 && result.isNumeric2) {
    return result.num1 <= result.num2;
  }
  // no more special cases - compare strings
  return DG.Formula.stringFinisher(result, iOperand1, iOperand2, '<=');
};


DG.Formula.equals = function(iOperand1, iOperand2) {
  var boolMap = {
    'true': true,
    'TRUE': true,
    'false' : false,
    'FALSE' : false
  };
  var result = DG.Formula.arithmeticStarter( iOperand1, iOperand2);

  if( (result instanceof Error) || typeof result !== 'object')
    return result;

  // if one or the other operand is boolean cast them both to boolean.
  if (iOperand1 === true || iOperand1 === false || iOperand2 === true || iOperand2 === false) {
    iOperand1 = boolMap[iOperand1] != null? boolMap[iOperand1]: iOperand1;
    iOperand2 = boolMap[iOperand2] != null? boolMap[iOperand2]: iOperand2;
  }

  // eslint-disable-next-line eqeqeq
  return iOperand1 == iOperand2;
};

/**
  Binary operator function which handles types by our rules rather than JavaScript's.
  Numbers and values interpretable as numeric (e.g. booleans, some strings)
  are handled numerically. Errors, nulls and NaNs propagate.
 */
DG.Formula.binaryOperator = function(iOperator, iOperand1, iOperand2) {
  var empty1 = SC.empty(iOperand1),
      empty2 = SC.empty(iOperand2),
      // white-space-only strings default-convert to 0
      isSpaceStr1 = (typeof iOperand1 === "string") &&
                      DG.Formula.whiteSpaceRegExp.test(iOperand1),
      isSpaceStr2 = (typeof iOperand2 === "string") &&
                      DG.Formula.whiteSpaceRegExp.test(iOperand2),
      isDate1 = DG.isDate(iOperand1) || (!isSpaceStr1 && DG.isDateString(iOperand1)),
      isDate2 = DG.isDate(iOperand2) || (!isSpaceStr2 && DG.isDateString(iOperand2)),
      num1 = !empty1 && !isSpaceStr1 ? Number(iOperand1) : NaN,
      num2 = !empty2 && !isSpaceStr2 ? Number(iOperand2) : NaN,
      // booleans and strings (if possible) converted, not null values
      isNumeric1 = (num1 === num1),
      isNumeric2 = (num2 === num2);

  // dates can't be handled by this operator
  if (isDate1 || isDate2)
    throw new DG.TypeError(iOperator);

  // values interpretable as numeric are handled numerically
  if (isNumeric1 && isNumeric2) {
    switch(iOperator) {
      case '*': return num1 * num2;
      case '/': return num1 / num2;
      case '%': return num1 % num2;
      case '^': return Math.pow(num1, num2);
      default: throw new SyntaxError('DG.Formula.SyntaxErrorInvalidOperator').loc(iOperator);
    }
  }

  // errors propagate
  if (iOperand1 instanceof Error) return iOperand1;
  if (iOperand2 instanceof Error) return iOperand2;

  // NaNs propagate
  if ((iOperand1 !== iOperand1) || (iOperand2 !== iOperand2))
    return NaN;

  // null values propagate
  if (empty1 && empty2) return '';
  // null values dominate numeric values
  if ((empty1 && isNumeric2) || (isNumeric1 && empty2))
    return '';

  // no more special cases - throw an exception
  throw new DG.TypeError(iOperator);
};

/**
  Compiles the specified parse tree results into a JavaScript expression
  which can be used with the specified context to compute the result.
  This function walks the parse tree, converting each node to its JavaScript
  equivalent and then combining the nodes appropriately so that the result
  is a single JavaScript expression.
  @param    {Object}            The parse tree results from PEG.js
  @param    {DG.FormulaContext} The context object used for variable/function references
  @returns  {String}            A JavaScript expression suitable for evaluation
 */
DG.Formula.compileToJavaScript = function( iParseTree, iContext) {

  var fnMap;

  /**
    Call the appropriate visit function based on the node type.
   */
  function visit( iNode) {
    var fn = fnMap[ iNode.type];
    return fn && fn( iNode);
  }

  function visitLiteral( iNode) {
    return iNode.value;
  }

  function visitStringLiteral( iNode) {
    return '"' + iNode.value.replace(/"/g, "\\\"") + '"';
  }

  function visitVariable( iNode) {
    // Pass variable references to the context
    return iContext.compileVariable( iNode.name, iContext.getAggregateFunctionIndices());
  }

  function visitFunctionCall( iNode) {
    var fnName = iNode.name.name,
        isAggFn = iContext.isAggregate(fnName),
        i, len = iNode.args && iNode.args.length,
        aggFnIndices = [], args = [];
    iContext.beginFunctionContext({ name: fnName, isAggregate: isAggFn });
    for( i = 0; i < len; ++i) {
      args.push( visit( iNode.args[i]));
    }
    aggFnIndices = iContext.getAggregateFunctionIndices();
    iContext.endFunctionContext({ name: fnName });
    // Pass function references to the context
    return iContext.compileFunction( fnName, args, aggFnIndices);
  }

  function visitTerm( iNode) {
    var useParens = (iNode.type === 'BinaryExpression'),
        expr = visit( iNode);
    if( useParens) expr = '(' + expr + ')';
    return expr;
  }

  function visitUnaryExpression( iNode) {
    return iNode.operator + visitTerm( iNode.expression);
  }

  function visitBinaryExpression( iNode) {
    var leftTerm = visitTerm( iNode.left),
        rightTerm = visitTerm( iNode.right);

    switch( iNode.operator) {
      case '+':
        return 'DG.Formula.add(' + leftTerm + ',' + rightTerm + ')';
      case '-':
        return 'DG.Formula.subtract(' + leftTerm + ',' + rightTerm + ')';
      case '<':
        return 'DG.Formula.lessThan(' + leftTerm + ',' + rightTerm + ')';
      case '>':
        return 'DG.Formula.lessThan(' + rightTerm + ',' + leftTerm + ')';
      case '<=':
        return 'DG.Formula.lessThanOrEqual(' + leftTerm + ',' + rightTerm + ')';
      case '>=':
        return 'DG.Formula.lessThanOrEqual(' + rightTerm + ',' + leftTerm + ')';
      case '==':
        return 'DG.Formula.equals(' + leftTerm + ',' + rightTerm + ')';
      case '!=':
        return '!DG.Formula.equals(' + leftTerm + ',' + rightTerm + ')';
    }

    // Convert standard binary operators to calls to DG.Formula.binaryOperator()
    if (['*', '/', '%', '^'].indexOf(iNode.operator) >= 0)
      return 'DG.Formula.binaryOperator("' + iNode.operator + '",' + leftTerm + ',' + rightTerm + ')';

    // Standard binary operators
    return leftTerm + iNode.operator + rightTerm;
  }

  function visitConditionalExpression( iNode) {
    return '(' + visitTerm( iNode.condition) +
            '?' + visitTerm( iNode.trueExpression) +
            ':' + visitTerm( iNode.falseExpression) + ')';
  }

  fnMap = {
    'BooleanLiteral': visitLiteral,
    'NumericLiteral': visitLiteral,
    'StringLiteral': visitStringLiteral,
    'Variable': visitVariable,
    'FunctionCall': visitFunctionCall,
    'UnaryExpression': visitUnaryExpression,
    'BinaryExpression': visitBinaryExpression,
    'ConditionalExpression': visitConditionalExpression
  };

  // Recursively visit every node in the parse tree
  return visit( iParseTree);
};

/**
  Evaluates the specified parse tree by walking the tree and evaluating nodes
  recursively. This function walks the parse tree, evaluating each node and then
  combining the nodes appropriately to come up with the final result.
  @param    {Object}            The parse tree results from PEG.js
  @param    {DG.FormulaContext} The context object used for variable/function references
  @returns  {Object}            The result of evaluation
 */
DG.Formula.evaluateParseTree = function( iParseTree, iContext, iEvalContext) {

  var fnMap;

  function visit( iNode) {
    var fn = fnMap[ iNode.type];
    return fn && fn( iNode);
  }

  function visitLiteral( iNode) {
    return iNode.value;
  }

  function visitVariable( iNode) {
    // Pass variable references to the context
    return iContext.evaluateVariable( iNode.name, iEvalContext);
  }

  function visitFunctionCall( iNode) {
    var i, len = iNode.args && iNode.args.length,
        args = [];
    for( i = 0; i < len; ++i) {
      args.push( visit( iNode.args[i]));
    }
    // Pass function references to the context
    return iContext.evaluateFunction( iNode.name.name, args);
  }

  function visitUnaryExpression( iNode) {
    var value = visit( iNode.expression);

    switch( iNode.operator) {
    case '+': return +value;
    case '-': return -value;
    case '!': return !value;
    }

    // Error: Unrecognized operator! Throw an exception?
    return undefined;
  }

  function visitBinaryExpression( iNode) {
    var left = visit( iNode.left),
        right = visit( iNode.right);

    switch (iNode.operator) {
      case '^':
        return DG.Formula.binaryOperator('^', left, right);
      case '*':
        return DG.Formula.binaryOperator('*', left, right);
      case '/':
        return DG.Formula.binaryOperator('/', left, right);
      case '%':
        return DG.Formula.binaryOperator('%', left, right);
      case '+':
        return DG.Formula.add(left, right);
      case '-':
        return DG.Formula.subtract(left, right);
      case '<':
        return DG.Formula.lessThan(left, right);
      case '>':
        return DG.Formula.lessThan(right, left);
      case '<=':
        return DG.Formula.lessThanOrEqual(left, right);
      case '>=':
        return DG.Formula.lessThanOrEqual(right, left);
      case '==':
      case '===':
        return DG.Formula.equals(left, right);
      case '!=':
      case '!==':
        return !DG.Formula.equals(left, right);
      case '&&':
        return left && right;
      case '||':
        return left || right;
      default:
    }

    // Error: Unrecognized operator! Throw an exception
    throw new SyntaxError('DG.Formula.SyntaxErrorInvalidOperator'.loc(iNode.operator));
  }

  function visitConditionalExpression( iNode) {
    return visit( iNode.condition) ? visit( iNode.trueExpression)
                                   : visit( iNode.falseExpression);
  }

  fnMap = {
    'BooleanLiteral': visitLiteral,
    'NumericLiteral': visitLiteral,
    'StringLiteral': visitLiteral,
    'Variable': visitVariable,
    'FunctionCall': visitFunctionCall,
    'UnaryExpression': visitUnaryExpression,
    'BinaryExpression': visitBinaryExpression,
    'ConditionalExpression': visitConditionalExpression
  };

  return visit( iParseTree);
};





/**
 * Returns a cloned tree with variable renamed.
 * @param oldName
 * @param newName
 */
DG.Formula.renameVariable = function (formulaObject, oldName, newName) {
  function visit(iNode) {
    var fn = fnMap[ iNode.type];
    return fn && fn( iNode);
  }
  function visitNoOp(iNode) {
    return iNode;
  }
  function visitVariable(iNode) {
    if (iNode.name === oldName) {
      return {type: iNode.type, name: newName};
    } else {
      return iNode;
    }
  }
  function visitFunctionCall(iNode) {
    return {
      args: iNode.args.map(function (arg) {return visit(arg);}),
      name: visit(iNode.name),
      type: iNode.type
    };
  }
  function visitUnaryExpression(iNode) {
    return {
      expression: visit(iNode.expression),
      operator: iNode.operator,
      type: iNode.type
    };
  }
  function visitBinaryExpression(iNode) {
    return {
      left: visit(iNode.left),
      right: visit(iNode.right),
      operator: iNode.operator,
      type: iNode.type
    };
  }
  function visitConditionalExpression(iNode) {
    return {
      condition: visit(iNode.condition),
      trueExpression: visit(iNode.trueExpression),
      falseExpression: visit(iNode.falseExpression),
      type: iNode.type
    };
  }
  var fnMap = {
    'BooleanLiteral': visitNoOp,
    'NumericLiteral': visitNoOp,
    'StringLiteral': visitNoOp,
    'Variable': visitVariable,
    'FunctionCall': visitFunctionCall,
    'UnaryExpression': visitUnaryExpression,
    'BinaryExpression': visitBinaryExpression,
    'ConditionalExpression': visitConditionalExpression
  };
  return visit(formulaObject);
};

/**
 * Generates a formula string from a formula object
 * @return {*}
 */
DG.Formula.toString = function (formulaObject) {
  function visit(iNode) {
    var fn = fnMap[ iNode.type];
    return fn && fn( iNode);
  }
  function visitNoOp(iNode) {
    return iNode.value;
  }
  function visitStringLiteral(iNode) {
    return '"' + iNode.value + '"';
  }
  function visitVariable(iNode) {
    var name = iNode.name;
    if (!/^[a-zA-Z0-9]*$/.test(name)) {
      name = '`' + name + '`';
    }
    return name;
  }
  function visitFunctionCall(iNode) {
    var args = iNode.args.map(function (arg) {return visit(arg);});
    var name = visit(iNode.name);
    return name + "(" + args.join() + ")";
  }
  function visitUnaryExpression(iNode) {
     var expression = visit(iNode.expression);
     var operator = iNode.operator;
     return '(' + operator + expression + ')';
  }
  function visitBinaryExpression(iNode) {
    var vals = {
      left: visit(iNode.left),
      right: visit(iNode.right),
      operator: iNode.operator
    };
    return '(' + String(vals.left) + ' ' + vals.operator + ' ' + String(vals.right) + ')';
  }
  function visitConditionalExpression(iNode) {
    var vals = {
      condition: visit(iNode.condition),
      trueExpression: visit(iNode.trueExpression),
      falseExpression: visit(iNode.falseExpression)
    };
    return '(' + String(vals.condition) + ')? (' + vals.trueExpression + '): (' + vals.falseExpression + ')';
  }
  var fnMap = {
    'BooleanLiteral': visitNoOp,
    'NumericLiteral': visitNoOp,
    'StringLiteral': visitStringLiteral,
    'Variable': visitVariable,
    'FunctionCall': visitFunctionCall,
    'UnaryExpression': visitUnaryExpression,
    'BinaryExpression': visitBinaryExpression,
    'ConditionalExpression': visitConditionalExpression
  };
  return visit(formulaObject);
};

/* >>>>>>>>>> BEGIN source/formula/codapFormulaMode.js */
/* Example definition of a simple mode that understands a subset of
 * JavaScript:
 */

sc_require('formula/formula');

/* global CodeMirror */
CodeMirror.defineSimpleMode("codapFormula", {
  // The start state contains the rules that are intially used
  start: [
    // The regex matches the token, the token property contains the type
    {regex: /(?:"(?:[^\\]|\\.)*?(?:"|$))|(?:'(?:[^\\]|\\.)*?(?:'|$))/, token: "string"},
    //{regex: /true|false/, token: "atom"},
    {regex: /0x[a-f\d]+|[-+]?(?:\.\d+|\d+\.?\d*)(?:e[-+]?\d+)?|true|false|pi|e|π/i, token: "number"},
    {regex: /[-+\/*=<>!^]+/, token: "operator"},
    {regex: DG.Formula.functionRegExp, token: "function"},
    {regex: DG.Formula.identifierRegExp, token: "variable"},
    {regex: /(?:`(?:[^\\]|\\.)*?(?:`|$))/, token: "variable"}
  ],
  // The meta property contains global information about the mode. It
  // can contain properties like lineComment, which are supported by
  // all modes, and also directives like dontIndentStates, which are
  // specific to simple modes.
  meta: {
    dontIndentStates: ["start"]
  }
});

/* >>>>>>>>>> BEGIN source/formula/data_context_fns.js */
// ==========================================================================
//                    Data Context Lookup Functions
//  
//  Author:   Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('formula/aggregate_function');
sc_require('formula/function_registry');

/** @class DG.DataContextLookupFns

  The DG.DataContextLookupFns object implements aggregate and semi-aggregate
  functions that evaluate the arguments in a specified data context.
  These functions potentially include lookupByKey() and lookupByIndex(), etc.
 */
DG.functionRegistry.registerAggregates((function() {

  /** @class DG.LookupDataSetError

    Error class for data context lookup errors.

    @extends Error
  */
  var LookupDataSetError = function(iName) {
    this.name = 'EvalError';
    this.message = 'DG.Formula.LookupDataSetError.message'.loc(iName);
    this.description = 'DG.Formula.LookupDataSetError.description'.loc(iName);
    this.reference = iName;
  };
  LookupDataSetError.prototype = new Error();
  LookupDataSetError.prototype.constructor = LookupDataSetError;

  /** @class DG.LookupAttrError

    Error class for attribute lookup errors in data context lookup functions.

    @extends Error
  */
  var LookupAttrError = function(iAttrName, iContextName) {
    this.name = 'EvalError';
    this.message = 'DG.Formula.LookupAttrError.message'.loc(iAttrName, iContextName);
    this.description = 'DG.Formula.LookupAttrError.description'.loc(iAttrName, iContextName);
    this.reference = iAttrName;
  };
  LookupAttrError.prototype = new Error();
  LookupAttrError.prototype.constructor = LookupAttrError;

  /*
    Utility function for binding an attribute reference in a
    separate data context.
   */
  function bindContextVar(iDataContext, iAttrFn, iContext, iEvalContext) {
    var attrName = iAttrFn && iAttrFn(iContext, iEvalContext),
        attrRef = iDataContext && attrName &&
                    iDataContext.getAttrRefByName(attrName),
        attrCollection = attrRef && attrRef.collection,
        attr = attrRef && attrRef.attribute,
        attrID = attr && attr.get('id'),
        binding = {
          isValid: !!iDataContext && !!attrCollection && !!attrID,
          dataContext: iDataContext,
          collection: attrCollection,
          attribute: attr,
          attributeName: attrName,
          attributeID: attrID
        };
    if (!attrID) throw new LookupAttrError(attrName, iDataContext.get('title'));
    return binding;
  }

  /*
    Utility function for registering a dependency between data
    contexts -- adds the dependency to both dependency managers.
   */
  function registerDependency(iBinding, iContext, iInstance) {
    if (iBinding.isValid) {
      var srcDependencyMgr = iBinding.dataContext &&
                              iBinding.dataContext.get('dependencyMgr'),
          dependency = {
            dependentSpec: iContext.get('ownerSpec'),
            independentSpec: {
              type: DG.DEP_TYPE_ATTRIBUTE,
              name: iBinding.attributeName,
              id: iBinding.attributeID
            },
            aggFnIndices: iInstance.aggFnIndices,
            dependentContext: iContext,
            srcDependencyMgr: srcDependencyMgr
          };
      // register with dependent/destination
      iContext.registerDependency(dependency);
      // register with independent/source
      if (srcDependencyMgr) {
        srcDependencyMgr.findOrRegisterNode(dependency.dependentSpec);
        srcDependencyMgr.registerDependency(dependency);
      }
    }
  }

  return {

  /**
    lookupByIndex(iSrcContextName, iSrcValueAttrName, iCaseIndex)
    Returns the value of the attribute named iSrcValueAttrName in the
    data context named iSrcContextName for the case at index iCaseIndex.
   */
  lookupByIndex: DG.AggregateFunction.create({
  
    category: 'DG.Formula.FuncCategoryLookup',
  
    requiredArgs: { min: 3, max: 3 },

    /**
      Evaluates the aggregate function and returns a computed result for the specified case.
      @param  {DG.FormulaContext}   iContext
      @param  {Object}              iEvalContext -- { _case_: , _id_: }
      @param  {Object}              iInstance -- The aggregate function instance from the context.
      @returns  {Number|String|...}
     */
    evaluate: function( iContext, iEvalContext, iInstance) {

      var binding = {};
      if (!iInstance.caches) iInstance.caches = {};

      if (!iInstance.caches.binding) {
        var contextFn = iInstance.argFns[0],
            contextName = contextFn && contextFn(iContext, iEvalContext),
            dataContext = contextName &&
                            DG.currDocumentController().getContextByTitle(contextName);
        if (!dataContext) throw new LookupDataSetError(contextName);

        binding = bindContextVar(dataContext, iInstance.argFns[1], iContext, iEvalContext);
        registerDependency(binding, iContext, iInstance);
        iInstance.caches.binding = binding;

        if (binding.isValid) {
          var srcDependencyMgr = binding.dataContext &&
                                  binding.dataContext.get('dependencyMgr'),
              dependency = {
                dependentSpec: iContext.get('ownerSpec'),
                independentSpec: {
                  type: DG.DEP_TYPE_ATTRIBUTE,
                  name: binding.attributeName,
                  id: binding.attributeID
                },
                aggFnIndices: iInstance.aggFnIndices,
                dependentContext: iContext,
                srcDependencyMgr: srcDependencyMgr
              };
          // register with dependent/destination
          iContext.registerDependency(dependency);
          // register with independent/source
          if (srcDependencyMgr) {
            srcDependencyMgr.findOrRegisterNode(dependency.dependentSpec);
            srcDependencyMgr.registerDependency(dependency);
          }
        }
      }
      else {
        binding = iInstance.caches.binding;
      }

      var cases = binding.collection &&
                    binding.collection.getPath('casesController.arrangedObjects'),
          caseIndexFn = iInstance.argFns[2],
          reqCaseIndex = caseIndexFn && caseIndexFn(iContext, iEvalContext),
          tCase = cases && cases.objectAt(reqCaseIndex-1);
      return (tCase && binding.attributeID && tCase.getValue(binding.attributeID)) || '';
    }

  }),
  
  /**
    lookupByKey(iSrcContextName, iSrcValueAttrName, iSrcKeyAttrName, iKeyValue)
    Returns the value of the attribute named iSrcValueAttrName in the
    data context named iSrcContextName for the first case that has a value for
    iSrcKeyAttrName that matches iKeyValue.
   */
  lookupByKey: DG.AggregateFunction.create({
  
    category: 'DG.Formula.FuncCategoryLookup',
  
    requiredArgs: { min: 4, max: 4 },

    evaluate: function( iContext, iEvalContext, iInstance) {

      var valueBinding = {},
          keyBinding = {},
          contextFn, contextName,
          dataContext;
      if (!iInstance.caches) iInstance.caches = {};

      if (!iInstance.caches.valueBinding || !iInstance.caches.keyBinding) {
        contextFn = iInstance.argFns[0];
        contextName = contextFn && contextFn(iContext, iEvalContext);
        dataContext = contextName &&
                        DG.currDocumentController().getContextByTitle(contextName);
        if (!dataContext) throw new LookupDataSetError(contextName);
      }
      if (!iInstance.caches.valueBinding) {
        valueBinding = bindContextVar(dataContext, iInstance.argFns[1],
                                      iContext, iEvalContext);
        registerDependency(valueBinding, iContext, iInstance);
        iInstance.caches.valueBinding = valueBinding;
      }
      else {
        valueBinding = iInstance.caches.valueBinding;
      }

      if (!iInstance.caches.keyBinding) {
        keyBinding = bindContextVar(dataContext, iInstance.argFns[2],
                                      iContext, iEvalContext);
        registerDependency(keyBinding, iContext, iInstance);
        iInstance.caches.keyBinding = keyBinding;
      }
      else {
        keyBinding = iInstance.caches.keyBinding;
      }

      if (!iInstance.caches.keyValueMap) {
        var keyValueMap = {},
            cases = keyBinding.collection &&
                      keyBinding.collection.getPath('casesController.arrangedObjects');
        if (cases) {
          cases.forEach(function(iCase) {
            var key = iCase && iCase.getValue(keyBinding.attributeID),
                value = iCase && iCase.getValue(valueBinding.attributeID);
            if (keyValueMap[key] == null)
              keyValueMap[key] = value;
          });
        }
        iInstance.caches.keyValueMap = keyValueMap;
      }

      var keyValueFn = iInstance.argFns[3],
          keyValue = keyValueFn && keyValueFn(iContext, iEvalContext);
      return iInstance.caches.keyValueMap[keyValue];
    }
  }),

  /**
   wordListMatches(iStringToSearch, iWordListContextName, iWordListAttrName, iRatingsAttrName)
   Returns the total number of times any of the words in a given word list are found in the
   given iStringToSearch. If the (optional) name of a numeric rating attribute is specified,
   the sum of the ratings for the found words is returned.
   */
  wordListMatches: DG.AggregateFunction.create({

    category: 'DG.Formula.FuncCategoryString',

    requiredArgs: { min: 3, max: 4 },

/*
      @param  {DG.FormulaContext}   iContext
      @param  {Object}              iEvalContext -- { _case_: , _id_: }
      @param  {Object}              iInstance -- The aggregate function instance from the context.
      iInstance.argFns[] is an array of functions that retrieve the desired arguments
        0 - iStringToSearch
        1 - iWordListContextName
        2 - iWordListAttrName
        3 - iRatingsName
*/
    evaluate: function( iWordsContext, iEvalContext, iInstance) {

      var wordsBinding = {},
          ratingsBinding,
          wordsContextFn, wordsContextName,
          wordsContext;
      if (!iInstance.caches) iInstance.caches = {};

      if (!iInstance.caches.wordsBinding || !iInstance.caches.ratingsBinding) {
        wordsContextFn = iInstance.argFns[1];
        wordsContextName = wordsContextFn && wordsContextFn(iWordsContext, iEvalContext);
        wordsContext = wordsContextName &&
                        DG.currDocumentController().getContextByTitle(wordsContextName);
        if (!wordsContext) throw new LookupDataSetError(wordsContextName);
      }
      if (!iInstance.caches.wordsBinding) {
        wordsBinding = bindContextVar(wordsContext, iInstance.argFns[2],
                                      iWordsContext, iEvalContext);
        registerDependency(wordsBinding, iWordsContext, iInstance);
        iInstance.caches.wordsBinding = wordsBinding;
      }
      else {
        wordsBinding = iInstance.caches.wordsBinding;
      }
      if(iInstance.argFns[3]) {
        ratingsBinding = {};
        if (!iInstance.caches.ratingsBinding) {
          ratingsBinding = bindContextVar(wordsContext, iInstance.argFns[3],
              iWordsContext, iEvalContext);
          registerDependency(ratingsBinding, iWordsContext, iInstance);
          iInstance.caches.ratingsBinding = ratingsBinding;
        }
        else {
          ratingsBinding = iInstance.caches.ratingsBinding;
        }
      }

      if (!iInstance.caches.wordRatingMap) {
        var wordRatingMap = {},
            cases = wordsBinding.collection &&
                      wordsBinding.collection.getPath('casesController.arrangedObjects');
        if (cases) {
          cases.forEach(function(iCase) {
            var word = iCase && iCase.getValue(wordsBinding.attributeID),
                rating = iCase ? ((ratingsBinding ? iCase.getValue(ratingsBinding.attributeID) : 1)) :
                    null;
            if (wordRatingMap[word] == null)
              wordRatingMap[word] = rating;
          });
        }
        iInstance.caches.wordRatingMap = wordRatingMap;
      }

      var stringToSearchFn = iInstance.argFns[0],
          stringToSearch = stringToSearchFn && stringToSearchFn(iWordsContext, iEvalContext),
          result = 0;
      DG.ObjectMap.forEach(iInstance.caches.wordRatingMap, function (iWord, iRating) {
        if(!SC.empty(iWord)) {
          var tIsRegEx = iWord.startsWith('/') && iWord.endsWith('/'),
              tPattern = tIsRegEx ? iWord.substring(1, iWord.length - 1) : '\\b' + iWord + '\\b',
              tFlags = tIsRegEx ? 'g' : 'gi',
              tRegExp = new RegExp(tPattern, tFlags),
              tMatch = stringToSearch.match(tRegExp);
          result += iRating * (!tMatch ? 0 : tMatch.length);
        }
      });
      return result;
    }
  })
  
  };
})());

/* >>>>>>>>>> BEGIN source/formula/date_time_functions.js */
// ==========================================================================
//                    Date/Time Functions
//
//  Author:   Kirk Swenson
//
//  Copyright (c) 2016 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('formula/function_registry');

/**
  Implements the basic builtin functions and registers them with the FunctionRegistry.
 */
DG.functionRegistry.registerFunctions((function() {

  /**
    Utility function for converting to a Date object.
   */
  function convertToDate(x) {
    if (DG.isDate(x)) return x;
    return DG.createDate(x); // strings are subject to browser inconsistencies
  }

  return {

    /**
      Returns a new date created from its arguments. If a single large argument,
      it is treated as
      @param  {Number}  iYearOrEpochSecs - If multiple arguments, the first argument
                          is considered to be the year. If only a single argument,
                          it is considered to be the number of seconds since 1/1/1970.
      @param  {Number}  [iMonth] - the (1-based?) month (default: 0)
      @param  {Number}  [iDay] - the (1-based) day of the month (default: 1)
      @param  {Number}  [iHour] - the hour within the day (default: 0)
      @param  {Number}  [iMinute] - the minute within the hour (default: 0)
      @param  {Number}  [iSeconds] - the second within the minute
      @param  {Number}  [iMilliseconds] - the milliseconds within the second
      @returns  {Date}  the date created
     */
    'date': {
      minArgs:1, maxArgs:7, category: 'DG.Formula.FuncCategoryDateTime',
      evalFn: function(iYearOrEpochSecs, iMonth, iDay, iHour, iMinute, iSecond, iMillisec) {
        // check for valid arguments
        var i, firstEmpty, lastValid, numValid = 0;
        for (i = 0; i < arguments.length; ++i) {
          var arg = arguments[i];
          if (SC.empty(arg)) {
            if (!firstEmpty && (i > 0)) firstEmpty = i;
          }
          else {
            // can't have non-empty arguments after empty ones (except for empty year)
            if (firstEmpty) return '';
            // can't have non-numeric arguments
            if (!DG.isNumeric(arg)) return '';
            lastValid = i;
            ++numValid;
          }
        }
        // date() => now()
        if (numValid === 0) return DG.createDate();
        // convert epoch seconds
        if ((lastValid === 0) && DG.DateUtilities.defaultToEpochSecs(iYearOrEpochSecs))
          return DG.createDate(iYearOrEpochSecs);
        var now = new Date(),
            year = now.getFullYear(),
            // dividing line for two-digit years is 10 yrs from now
            cutoff = (year + 10) % 100,
            month = iMonth > 0 ? iMonth - 1 : 0,
            day = iDay || 1,
            hour = iHour || 0,
            min = iMinute || 0,
            sec = iSecond || 0,
            ms = iMillisec || 0;
        // empty year argument => current year
        if (SC.empty(iYearOrEpochSecs))
          iYearOrEpochSecs = year;
        // interpret two-digit years; will need to be adjusted before 2090
        else if (iYearOrEpochSecs < cutoff)
          iYearOrEpochSecs += 2000;
        else if (iYearOrEpochSecs < 100)
          iYearOrEpochSecs += 1900;
        return DG.createDate(iYearOrEpochSecs, month, day, hour, min, sec, ms);
      }
    },

    /**
      Returns the day of the month corresponding to the given date.
      @param    {Date|Number|String} A date object or value convertible to a date object
      @returns  {Number}      The month for the given date
     */
    'dayOfMonth': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryDateTime',
      evalFn: function(x) {
        var date = convertToDate(x);
        return date && date.getDate();
      }
    },

    /**
      Returns the numeric day of the week corresponding to the given date.
      @param    {Date|Number|String} A date object or value convertible to a date object
      @returns  {Number}      The numeric day of the week for the given date
     */
    'dayOfWeek': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryDateTime',
      evalFn: function(x) {
        var date = convertToDate(x);
        return date && (date.getDay() + 1);
      }
    },

    /**
      Returns the day of the week corresponding to the given date as a string.
      @param    {Date|Number|String} A date object or value convertible to a date object
      @returns  {String}      The day of the week for the given date as a string
     */
    'dayOfWeekName': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryDateTime',
      evalFn: function(x) {
        var date = convertToDate(x),
            dayNames = [
              'DG.Formula.DateLongDaySunday',
              'DG.Formula.DateLongDayMonday',
              'DG.Formula.DateLongDayTuesday',
              'DG.Formula.DateLongDayWednesday',
              'DG.Formula.DateLongDayThursday',
              'DG.Formula.DateLongDayFriday',
              'DG.Formula.DateLongDaySaturday'
            ],
            dayName = date && dayNames[date.getDay()];
        return dayName && dayName.loc();
      }
    },

    /**
      Returns the hour of the day corresponding to the given date.
      @param    {Date|Number|String} A date object or value convertible to a date object
      @returns  {Number}      The numeric hour of the day for the given date
     */
    'hours': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryDateTime',
      evalFn: function(x) {
        var date = convertToDate(x);
        return date && date.getHours();
      }
    },

    /**
      Returns the minute of the hour corresponding to the given date.
      @param    {Date|Number|String} A date object or value convertible to a date object
      @returns  {Number}      The numeric minute of the hour for the given date
     */
    'minutes': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryDateTime',
      evalFn: function(x) {
        var date = convertToDate(x);
        return date && date.getMinutes();
      }
    },

    /**
      Returns the numeric month corresponding to the given date
      @param    {Date|Number|String} A date object or value convertible to a date object
      @returns  {String}  The month for the given date
     */
    'month': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryDateTime',
      evalFn: function(x) {
        var date = convertToDate(x);
        return date && date.getMonth() + 1;
      }
    },

    /**
      Returns the month corresponding to the given date as a string
      @param    {Date|Number|String} A date object or value convertible to a date object
      @returns  {String}  The month for the given date as a string
     */
    'monthName': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryDateTime',
      evalFn: function(x) {
        return DG.monthName(x);
      }
    },




    /**
      Returns the seconds of the minute corresponding to the given date.
      @param    {Date|Number|String} A date object or value convertible to a date object
      @returns  {Number}      The numeric seconds of the minute for the given date
     */
    'seconds': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryDateTime',
      evalFn: function(x) {
        var date = convertToDate(x);
        return date && date.getSeconds();
      }
    },

    /**
      Returns a date object corresponding to the current date with no time (i.e. midnight)
      @returns  {Date}    the corresponding date object
     */
    'today': {
      minArgs:0, maxArgs:0, category: 'DG.Formula.FuncCategoryDateTime',
      evalFn: function() {
        var now = new Date();
        // eliminate time within the day
        return DG.createDate(now.getFullYear(), now.getMonth(), now.getDate());
      }
    },

    /**
      Returns the year corresponding to the given date
      @param    {Date|Number|String} A date object or value convertible to a date object
      @returns  {Number}  The year for the given date
     */
    'year': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryDateTime',
      evalFn: function(x) {
        var date = convertToDate(x);
        return date && date.getFullYear();
      }
    }

  };
})());

/* >>>>>>>>>> BEGIN source/formula/dependency_mgr.js */
// ==========================================================================
//
//  Author:   kswenson
//
//  The DependencyMgr tracks formula dependencies between attributes.
//  It maintains a dependency graph where every attribute with a formula
//  and every attribute or global value (e.g. slider) that is referenced
//  by an attribute formula is a node in the graph, and each node contains
//  a list of dependencies (nodes that a given node references in its
//  formula) and dependents (nodes whose formulas reference this node).
//  The dependency graph must be kept up to date with any changes to
//  formulas, etc., at which point the invalidateDependentsOf() method can
//  be called to invalidate the relevant attribute values and return a
//  list of affected attributes in each affected collection.
//
//  Copyright (c) 2016 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

DG.depMgrLog = function() {};



/**
  Node type constants
 */
DG.DEP_TYPE_ATTRIBUTE = 'attribute';
DG.DEP_TYPE_GLOBAL = 'global';
DG.DEP_TYPE_PLOT = 'plot';
DG.DEP_TYPE_SPECIAL = 'special';
DG.DEP_TYPE_UNDEFINED = 'undefined';

/**
 * A class for managing formula dependencies
 */
DG.DependencyMgr = SC.Object.extend((function() {
/** @scope DG.DependencyMgr.prototype */ 

  // comparison function for node specification objects,
  // which are used for keys into the dependency graph, etc.
  function _compareNodeSpecs(iNodeSpec1, iNodeSpec2) {
    if (iNodeSpec1.type < iNodeSpec2.type) return -1;
    if (iNodeSpec1.type > iNodeSpec2.type) return 1;
    if (iNodeSpec1.id < iNodeSpec2.id) return -1;
    if (iNodeSpec1.id > iNodeSpec2.id) return 1;
    return 0;
  }

  /**
    Recursive function to invalidate a single dependency and all of the downstream
    dependents that are affected by it.
    @param  {object}  ioResult - dependencies are accumulated and returned in this object
    @param  {object}  iDepMgr - the dependency manager
    @param  {object}  iDependent - the dependent node
    @param  {object}  iDependency - the dependency to be invalidated
    @param  {boolean} iForceAggregate - true if the dependency should be treated as aggregate
   */
  function _invalidateDependency(ioResult, iDepMgr, iDependent, iDependency, iForceAggregate) {
    if (iDependent)
      iDependent.lastInvalidation = iDepMgr._currentInvalidation;

    if (iDependency && iDependency.dependentContext) {
      iDependency.dependentContext
        .invalidateDependent(ioResult, iDependent, iDependency, [], iForceAggregate);
    }
    DG.depMgrLog("DG.DependencyMgr[%@]._invalidateDependency: Invalidating %@ '%@'",
                  iDepMgr.getPath('dataContext.name'), iDependent.type, iDependent.name);
    if (iDependent && iDependency) {
      // recursively invalidate additional affected nodes
      _invalidateDependents(ioResult, iDepMgr, iDependent,
                            iForceAggregate || (iDependency.aggFnIndices.length > 0));
    }
  }

  /**
    Recursive function to invalidate all dependents of a single nod and all of
    the downstream dependents that are affected by them.
    @param  {object}  ioResult - dependencies are accumulated and returned in this object
    @param  {object}  iDepMgr - the dependency manager
    @param  {object}  iIndNode - the independent node
    @param  {boolean} iForceAggregate - true if the dependency should be treated as aggregate
   */
  function _invalidateDependents(ioResult, iDepMgr, iIndNode, iForceAggregate) {

    iIndNode.dependents.forEach(function(iDependent) {

      // if we've already invalidated this node, we don't need to do so again
      if (iDependent.lastInvalidation >= iDepMgr._currentInvalidation) return;

      // Call the specified invalidation function
      var dependency = iDepMgr._findDependency(iDependent, iIndNode);
      if (dependency)
        _invalidateDependency(ioResult, iDepMgr, iDependent, dependency, iForceAggregate);
    });
  }

  return {

  /**
    The data context for which dependencies are being tracked
    @type {DG.DataContext}
   */
  dataContext: null,

  /**
    The nodes of the dependency graph
    @private
    @type {object{}}
   */
  _nodes: null,

  /**
    Invalidation counter - used to prevent multiple invalidation, infinite recursion, etc.
    @private
    @type {number}
   */
  _currentInvalidation: 0,

  /**
    Initialization function
   */
  init: function() {
    this._nodes = {};
  },

  /**
    Create a map key from the specified node specification
    @param  {object}  iNodeSpec - the node specification
    @param  {string}  .type - the type of the node
    @param  {string}  .id - the id of the node
   */
  createKey: function(iNodeSpec) {
    return iNodeSpec.type + ':' + iNodeSpec.id;
  },

  /**
    Returns true if the specified node is already present in the dependency map
    @param  {object}  iNodeSpec - the node specification
    @param  {string}  .type - the type of the node
    @param  {string}  .id - the id of the node
   */
  hasNode: function(iNodeSpec) {
    return !!this.findNode(iNodeSpec);
  },

  /**
    Returns the specified node (if present) or undefined
    @param  {object}  iNodeSpec - the node specification
    @param  {string}  .type - the type of the node
    @param  {string}  .id - the id of the node
   */
  findNode: function(iNodeSpec) {
    var key = this.createKey(iNodeSpec);
    return this._nodes[key];
  },

  /**
    Adds the specified node to the dependency map if it's not already present,
    and returns the found or registered node.
    @param  {object}  iNodeSpec - the node specification
    @param  {string}  .type - the type of the node
    @param  {string}  .id - the id of the node
   */
  findOrRegisterNode: function(iNodeSpec) {
    return this.findNode(iNodeSpec) || this.registerNode(iNodeSpec);
  },

  /**
    Returns any nodes which match a name in the specified list, or an empty array
    @param    {string[]}  iNames - array of names to match with nodes
    @returns  {object[]}  array of nodes with matching names (possibly empty).
   */
  findNodesWithNames: function(iNames) {
    var result = [];
    DG.ObjectMap.forEach(this._nodes, function(iNodeSpec, iNode) {
      // if it matches a name on our list, add it to the results
      if (iNames.indexOf(iNode.name) >= 0)
        result.push(iNode);
    });
    return result;
  },

  /*
    Returns the immediate dependents of the specified nodes.
   */
  findDependentsOfNodes: function(iNodes) {
    var result = [];
    iNodes.forEach(function(iNode) {
      var dependents = iNode && iNode.dependents;
      if (dependents) {
        dependents.forEach(function(iDependent) {
          if (result.indexOf(iDependent) < 0)
            result.push(iDependent);
        });
      }
    });
    return result;
  },

  /**
    Adds the specified node to the dependency map if it's not already present
    @param  {object}  iNodeSpec - the node specification
    @param  {string}  .type - the type of the node
    @param  {string}  .id - the id of the node
   */
  registerNode: function(iNodeSpec) {
    if (this.hasNode(iNodeSpec)) return this.findNode(iNodeSpec);

    var key = this.createKey(iNodeSpec),
        node = $.extend({}, iNodeSpec, {
                    // nodes that this formula depends on
                    dependencies: [],
                    // nodes that depend on this node
                    dependents: [],
                    // last invalidation indicator
                    lastInvalidation: 0
                  });
    this._nodes[key] = node;
    return node;
  },

  /**
    Removes the specified node from the dependency map if it's present
    @param  {object}  iNodeSpec - the node specification
    @param  {string}  .type - the type of the node
    @param  {string}  .id - the id of the node
   */
  removeNode: function(iNodeSpec) {
    // remove the node's dependencies
    this._clearDependencies(iNodeSpec);
    this._pruneDependencies(iNodeSpec);

    // remove the node itself, as long as it doesn't have dependents
    var key = this.createKey(iNodeSpec),
        node = this._nodes[key];
    if (node && !(node.dependents && node.dependents.length)) {
      DG.depMgrLog("DG.DependencyMgr[%@].removeNode: Removing %@ '%@' from the dependency graph",
                  this.getPath('dataContext.name'), iNodeSpec.type, iNodeSpec.name);
      delete this._nodes[key];
    }
  },

  /**
    Returns the dependency object for the specified dependent and independent
    nodes. Returns undefined if no dependency exists between the nodes.
    @param    {object}  iDependentSpec - specifier for the dependent node
    @param    {object}  iIndependentSpec - specifier for the independent node
    @returns  {object}  dependency object between the specified nodes
   */
  findDependency: function(iDependentSpec, iIndependentSpec) {
    var dependentNode = this.findNode(iDependentSpec),
        independentNode = this.findNode(iIndependentSpec);
    return dependentNode && independentNode &&
            this._findDependency(dependentNode, independentNode);
  },

  /**
    Registers the specified dependency, adding a new node for the independent
    node if necessary (the dependent node should already be present because
    a formula should be registered before it is compiled).
    @param {object}   iDependency - the specification of the dependency to be added
    @param {object}   .dependentSpec - the specification of the dependent node
    @param {string}     .type - the type of the node
    @param {string}     .id - the id of the node
    @param {object}   .independentSpec - the specification of the independent node
    @param {string}     .type - the type of the node
    @param {string}     .id - the id of the node
    @param {number[]} .aggFnIndices - the indices of any dependent aggregate functions
    @param {function} .dependentContext - formula context for invalidation
    @param {object}   .srcDependencyMgr - DependencyMgr responsible for independent node
   */
  registerDependency: function(iDependency) {
    var dependentNode = this.findNode(iDependency.dependentSpec),
        prevIndependent = this.findNode(iDependency.independentSpec),
        descriptors = prevIndependent ? ["a non-aggregate", "an aggregate"]
                                      : ["a new non-aggregate", "a new aggregate"],
        independentNode = this.findOrRegisterNode(iDependency.independentSpec);

    DG.depMgrLog("DG.DependencyMgr[%@].registerDependency:\n%@ '%@' has %@ dependency on %@ '%@'",
                this.getPath('dataContext.name'),
                iDependency.dependentSpec.type, iDependency.dependentSpec.name,
                descriptors[iDependency.aggFnIndices.length > 0 ? 1 : 0],
                iDependency.independentSpec.type, iDependency.independentSpec.name);

    DG.assert(dependentNode != null,
              "DG.DependencyMgr.registerDependency: dependentNode not found!",
              "Formulas should be registered before they are compiled.");

    // register the dependency on the independentNode with the dependent node
    this._addDependency(dependentNode, independentNode, iDependency);
    // register a pointer from the independentNode back to the dependentNode
    this._addDependent(dependentNode, independentNode);
  },

  /**
    Adds a dependency on the independent node from the dependent node.
    @param {object}   iDependentNode - the node to which the dependency is to be added
    @param {object}   iIndependentNode - the node which is dependend upon
    @param {number[]} iAggFnIndices - array of aggregate function indices
    @param {object}   iDependentContext - formula context for invalidation
    @private
   */
  _addDependency: function(iDependentNode, iIndependentNode, iDependency) {
    var dependencies = iDependentNode.dependencies,
        dependencyCount = dependencies.length,
        i, dependency,
        aggFnIndices = iDependency.aggFnIndices,
        j, aggFnIndexCount = aggFnIndices ? aggFnIndices.length : 0;

    for (i = 0; i < dependencyCount; ++i) {
      dependency = dependencies[i];
      // do we already have this dependency in the list?
      if (0 === _compareNodeSpecs(dependency.node, iIndependentNode)) {
        // if already present, update the existing dependency
        if (aggFnIndexCount) {
          // merge aggFnIndices with existing dependency
          for (j = 0; j < aggFnIndexCount; ++j) {
            var aggFnIndex = aggFnIndices[j];
            if (dependency.aggFnIndices.indexOf(aggFnIndex) < 0)
              dependency.aggFnIndices.push(aggFnIndex);
          }
        }
        else {
          dependency.simpleDependency = true;
        }
        return;
      }
    }
    // if it's not already present in the list, add it
    dependencies.push({ node: iIndependentNode,
                        simpleDependency: !aggFnIndexCount,
                        aggFnIndices: aggFnIndexCount ? aggFnIndices.slice() : [],
                        dependentContext: iDependency.dependentContext,
                        srcDependencyMgr: iDependency.srcDependencyMgr });
  },

  /**
    Returns the dependency object (if any) of iDependentNode on iIndependentNode.
    @private
   */
  _findDependency: function(iDependentNode, iIndependentNode) {
    var dependentNode = this.findNode(iDependentNode),
        dependencies = dependentNode && dependentNode.dependencies,
        dependencyCount = dependencies.length,
        i, dependency;
    for (i = 0; i < dependencyCount; ++i) {
      dependency = dependencies[i];
      // do we already have this dependency in the list?
      if (0 === _compareNodeSpecs(dependency.node, iIndependentNode)) {
        return dependency;
      }
    }
    return null;
  },

  /**
    Adds a dependent to the independent node for the dependent node.
    Note that the pointer from the independent to the dependent is a simple pointer
    that doesn't contain the additional information maintained by the dependent node
    in its dependency object.
    @param {object}   iDependentNode - the dependent node
    @param {object}   iIndependentNode - the node to which the dependent is to be added
    @private
   */
  _addDependent: function(iDependentNode, iIndependentNode) {
    var dependents = iIndependentNode.dependents,
        dependentCount = dependents.length,
        i, dependentNode;
    for (i = 0; i < dependentCount; ++i) {
      dependentNode = dependents[i];
      // we already have this dependent in the list
      if (0 === _compareNodeSpecs(dependentNode, iDependentNode)) return;
    }
    // if it's not already present in the list, add it
    dependents.push(iDependentNode);
  },

  /**
    Adds a dependent to the independent node for the dependent node.
    Note that the pointer from the independent to the dependent is a simple pointer
    that doesn't contain the additional information maintained by the dependent node
    in its dependency object.
    @param {object}   iDependentNode - the dependent node
    @param {object}   iIndependentNode - the node to which the dependent is to be added
    @private
   */
  _removeDependent: function(iDependentNode, iIndependentNode) {
    var dependents = iIndependentNode.dependents,
        dependentCount = dependents.length,
        i, dependentNode;
    for (i = dependentCount - 1; i >= 0; --i) {
      dependentNode = dependents[i];
      // remove the matching item
      if (0 === _compareNodeSpecs(dependentNode, iDependentNode)) {
        dependents.splice(i, 1);
        return;
      }
    }
  },

  /**
    Clears the detailed dependency information (e.g. 'simpleDependency' and 'aggFnIndices')
    from every dependency of the specified node. This is generally done before recompiling
    the formula so that dependencies that are no longer valid can be identified and pruned.
    @param  {object}  iDependentSpec - the node specification
    @param  {string}  .type - the type of the node
    @param  {string}  .id - the id of the node
    @private
   */
  _clearDependencies: function(iDependentSpec) {
    var dependentNode = this.findNode(iDependentSpec);
    if (!dependentNode) return;

    var dependencies = dependentNode.dependencies,
        dependencyCount = dependencies.length,
        i, dependency;
    for (i = 0; i < dependencyCount; ++i) {
      dependency = dependencies[i];
      dependency.simpleDependency = false;
      dependency.aggFnIndices = [];
      // clear remote dependencies such as those created from lookup functions
      if (dependency.srcDependencyMgr && (this !== dependency.srcDependencyMgr))
        dependency.srcDependencyMgr._clearDependencies(iDependentSpec);
    }
  },

  /**
    Removes dependencies that are no longer required. This is generally done
    after _clearDependencies() and then compiling the formula. Any dependencies
    that are still empty after compilation are no longer valid and can be pruned.
    @param  {object}  iDependentSpec - the node specification
    @param  {string}  .type - the type of the node
    @param  {string}  .id - the id of the node
    @private
   */
  _pruneDependencies: function(iDependentSpec) {
    var dependentNode = this.findNode(iDependentSpec);
    if (!dependentNode) return;

    var dependencies = dependentNode.dependencies,
        dependencyCount = dependencies.length,
        independentNode,
        i, dependency;
    for (i = dependencyCount - 1; i >= 0; --i) {
      dependency = dependencies[i];
      if (!dependency.simpleDependency && !dependency.aggFnIndices.length) {
        independentNode = dependency.node;
        DG.depMgrLog("DG.DependencyMgr[%@]._pruneDependencies:\nRemoving dependence of %@ '%@' on %@ '%@'",
                    this.getPath('dataContext.name'), 
                    dependentNode.type, dependentNode.name,
                    independentNode.type, independentNode.name);
        this._removeDependent(dependentNode, independentNode);
        dependencies.splice(i, 1);
      }
      // prune remote dependencies such as those created from lookup functions
      if (dependency.srcDependencyMgr && (this !== dependency.srcDependencyMgr))
        dependency.srcDependencyMgr._pruneDependencies(iDependentSpec);
    }
  },

  /**
    Invalidate nodes with the specified names. Designed to handle name changes,
    object creation/deletion, and other namespace-affecting changes.
    returns an object indicating the affected nodes.
    @param {string[]}   iNames
    @returns {object}   result
                        .simpleDependencies[]
                        .aggregateDependencies[]
   */
  invalidateNames: function(iNames) {
    var i, result = { simpleDependencies: [], aggregateDependencies: [] };

    // increment our invalidation counter
    ++this._currentInvalidation;

    // invalidate dependents of the named nodes
    var nodes = this.findNodesWithNames(iNames);
    nodes.forEach(function(iNode) {
      _invalidateDependents(result, this, nodes[i], true);
    });

    return result;
  },

  /**
    Invalidate a particular dependent of a particular node.
    returns an object indicating the affected nodes.
    @param {object}   iDependentSpec - specifier for the dependent node
    @param {object}   iIndependentSpec - specifier for the independent node
    @param {boolean}  iForceAggregate - true if the dependency should be treated as aggregate
    @returns {object}   result
                        .simpleDependencies[]
                        .aggregateDependencies[]
   */
  invalidateDependency: function(iDependentSpec, iIndependentSpec, iForceAggregate) {
    var dependentNode = this.findNode(iDependentSpec),
        dependency = this.findDependency(iDependentSpec, iIndependentSpec),
        result = { simpleDependencies: [], aggregateDependencies: [] };
    if (dependency) {
      // increment our invalidation counter
      ++this._currentInvalidation;
      // invalidate the specified dependency
      _invalidateDependency(result, this, dependentNode, dependency, iForceAggregate);
    }
    return result;
  },

  /**
    Invalidate the specified nodes; returns an object indicating the affected nodes.
    @param {object[]}   iNodeSpecs
    @returns {object}   result
                        .simpleDependencies[]
                        .aggregateDependencies[]
   */
  invalidateDependentsOf: function(iNodeSpecs) {
    var i, nodeSpecCount = iNodeSpecs.length,
        result = { simpleDependencies: [], aggregateDependencies: [] };

    // increment our invalidation counter
    ++this._currentInvalidation;

    // invalidate the initial set of nodes
    for (i = 0; i < nodeSpecCount; ++i) {
      var indNode = this.findNode(iNodeSpecs[i]);
      if (indNode) {
        // invalidate dependents of each node
        _invalidateDependents(result, this, indNode);
      }
    }

    return result;
  }

  }; // return from function closure
}())); // function closure

/* >>>>>>>>>> BEGIN source/formula/formula_common.js */
// ==========================================================================
//              DG.VarReferenceError, DG.FuncReferenceError
//                DG.HierReferenceError,DG.FuncArgsError
//
//  Author:   Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

DG.UNICODE = {

  PLUS_SIGN: '+',
  MINUS_SIGN: '\u2212',
  MULTIPLICATION_SIGN: '\u00D7',
  DIVISION_SIGN: '\u00F7',

  EQUALS_SIGN: '=',
  NOT_EQUAL_TO: '\u2260',
  LESS_THAN_OR_EQUAL_TO: '\u2264',
  GREATER_THAN_OR_EQUAL_TO: '\u2265',

  GREEK_SMALL_LETTER_ALPHA: '\u03B1',
  GREEK_SMALL_LETTER_BETA: '\u03B2',
  GREEK_SMALL_LETTER_GAMMA: '\u03B3',
  GREEK_SMALL_LETTER_DELTA: '\u03B4',
  GREEK_SMALL_LETTER_EPSILON: '\u03B5',
  GREEK_SMALL_LETTER_ZETA: '\u03B6',
  GREEK_SMALL_LETTER_ETA: '\u03B7',
  GREEK_SMALL_LETTER_THETA: '\u03B8',
  GREEK_SMALL_LETTER_IOTA: '\u03B9',
  GREEK_SMALL_LETTER_KAPPA: '\u03BA',
  GREEK_SMALL_LETTER_LAMDA: '\u03BB',
  GREEK_SMALL_LETTER_MU: '\u03BC',
  GREEK_SMALL_LETTER_NU: '\u03BD',
  GREEK_SMALL_LETTER_XI: '\u03BE',
  GREEK_SMALL_LETTER_OMICRON: '\u03BF',
  GREEK_SMALL_LETTER_PI: '\u03C0',
  GREEK_SMALL_LETTER_RHO: '\u03C1',
  GREEK_SMALL_LETTER_FINAL_SIGMA: '\u03C2',
  GREEK_SMALL_LETTER_SIGMA: '\u03C3',
  GREEK_SMALL_LETTER_TAU: '\u03C4',
  GREEK_SMALL_LETTER_UPSILON: '\u03C5',
  GREEK_SMALL_LETTER_PHI: '\u03C6',
  GREEK_SMALL_LETTER_CHI: '\u03C7',
  GREEK_SMALL_LETTER_PSI: '\u03C8',
  GREEK_SMALL_LETTER_OMEGA: '\u03C9',

  INFINITY: '\u221E'
};

DG.SimpleMap = function(object) {
  this.map = object || {};
};
DG.SimpleMap.prototype.toString = function() {
  var str = '',
      kStrLengthThreshold = 16;
  for (var key in this.map) { // jshint ignore:line
    var ellipsize = str.length >= kStrLengthThreshold,
        keyToAdd = ellipsize ? '...' : key;
    str += (str ? ', ' : '') + keyToAdd;
    if (ellipsize) break;
  }
  return '{' + str + '}';
};

DG.BoundaryMap = function(object) {
  DG.SimpleMap.call(this, object);
};
DG.BoundaryMap.prototype = new DG.SimpleMap();
DG.BoundaryMap.prototype.constructor = DG.BoundaryMap;

// Error class definition follows pattern from
// https://developer.mozilla.org/en-US/docs/JavaScript/Reference/Global_Objects/Error

/** @class DG.TypeError

  Error class for type errors.

  @extends Error
*/
DG.TypeError = function(iOperator) {
  this.name = 'DG.Formula.TypeError.name'.loc();
  this.message = 'DG.Formula.TypeError.message'.loc(iOperator);
  this.description = 'DG.Formula.TypeError.description'.loc(iOperator);
};
DG.TypeError.prototype = new Error();
DG.TypeError.prototype.constructor = DG.TypeError;

/** @class DG.VarReferenceError

  Error class for variable reference errors.

  @extends Error
*/
DG.VarReferenceError = function( iName) {
  this.name = 'DG.Formula.VarReferenceError.name'.loc();
  this.message = 'DG.Formula.VarReferenceError.message'.loc( iName);
  this.description = 'DG.Formula.VarReferenceError.description'.loc( iName);
  this.reference = iName;
};
DG.VarReferenceError.prototype = new Error();
DG.VarReferenceError.prototype.constructor = DG.VarReferenceError;

/** @class DG.HierReferenceError

  Error class for hierarchical variable reference errors.

  @extends Error
*/
DG.HierReferenceError = function( iName) {
  this.name = 'DG.Formula.HierReferenceError.name'.loc();
  this.message = 'DG.Formula.HierReferenceError.message'.loc( iName);
  this.description = 'DG.Formula.HierReferenceError.description'.loc( iName);
  this.reference = iName;
};
DG.HierReferenceError.prototype = new Error();
DG.HierReferenceError.prototype.constructor = DG.HierReferenceError;

/** @class DG.FuncReferenceError

  Error class for function reference errors.

  @extends Error
*/
DG.FuncReferenceError = function( iName) {
  this.name = 'DG.Formula.FuncReferenceError.name'.loc();
  this.message = 'DG.Formula.FuncReferenceError.message'.loc( iName);
  this.description = 'DG.Formula.FuncReferenceError.description'.loc( iName);
  this.reference = iName;
};
DG.FuncReferenceError.prototype = new Error();
DG.FuncReferenceError.prototype.constructor = DG.FuncReferenceError;

/** @class DG.FuncArgsError

  Error class for function argument errors.

  @extends Error
*/
DG.FuncArgsError = function( iName, iRequiredArgs) {
  var minArgs = iRequiredArgs && iRequiredArgs.min,
      maxArgs = iRequiredArgs && iRequiredArgs.max;

  this.name = 'DG.Formula.FuncArgsError.name'.loc();
  if( (minArgs === 1) && (minArgs === maxArgs)) {
    this.message = 'DG.Formula.FuncArgsErrorSingle.message'.loc( iName, minArgs);
    this.description = 'DG.Formula.FuncArgsErrorSingle.description'.loc( iName, minArgs);
  }
  else if( (minArgs >= 0) && !SC.none( maxArgs) && (minArgs !== maxArgs)) {
    this.message = 'DG.Formula.FuncArgsErrorRange.message'.loc( iName, minArgs, maxArgs);
    this.description = 'DG.Formula.FuncArgsErrorRange.description'.loc( iName, minArgs, maxArgs);
  }
  else {
    this.message = 'DG.Formula.FuncArgsErrorPlural.message'.loc( iName, minArgs);
    this.description = 'DG.Formula.FuncArgsErrorPlural.description'.loc( iName, minArgs);
  }
  this.reference = iName;
};
DG.FuncArgsError.prototype = new Error();
DG.FuncArgsError.prototype.constructor = DG.FuncArgsError;


/* >>>>>>>>>> BEGIN source/formula/formulaParser.js */
DG.formulaParser = /*
 * Generated by PEG.js 0.10.0.
 *
 * http://pegjs.org/
 */
    (function() {
      "use strict";

      function peg$subclass(child, parent) {
        function ctor() { this.constructor = child; }
        ctor.prototype = parent.prototype;
        child.prototype = new ctor();
      }

      function peg$SyntaxError(message, expected, found, location) {
        this.message  = message;
        this.expected = expected;
        this.found    = found;
        this.location = location;
        this.name     = "SyntaxError";

        if (typeof Error.captureStackTrace === "function") {
          Error.captureStackTrace(this, peg$SyntaxError);
        }
      }

      peg$subclass(peg$SyntaxError, Error);

      peg$SyntaxError.buildMessage = function(expected, found) {
        var DESCRIBE_EXPECTATION_FNS = {
          literal: function(expectation) {
            return "\"" + literalEscape(expectation.text) + "\"";
          },

          "class": function(expectation) {
            var escapedParts = "",
                i;

            for (i = 0; i < expectation.parts.length; i++) {
              escapedParts += expectation.parts[i] instanceof Array
                  ? classEscape(expectation.parts[i][0]) + "-" + classEscape(expectation.parts[i][1])
                  : classEscape(expectation.parts[i]);
            }

            return "[" + (expectation.inverted ? "^" : "") + escapedParts + "]";
          },

          any: function(expectation) {
            return "any character";
          },

          end: function(expectation) {
            return "end of input";
          },

          other: function(expectation) {
            return expectation.description;
          }
        };

        function hex(ch) {
          return ch.charCodeAt(0).toString(16).toUpperCase();
        }

        function literalEscape(s) {
          return s
              .replace(/\\/g, '\\\\')
              .replace(/"/g,  '\\"')
              .replace(/\0/g, '\\0')
              .replace(/\t/g, '\\t')
              .replace(/\n/g, '\\n')
              .replace(/\r/g, '\\r')
              .replace(/[\x00-\x0F]/g,          function(ch) { return '\\x0' + hex(ch); })
              .replace(/[\x10-\x1F\x7F-\x9F]/g, function(ch) { return '\\x'  + hex(ch); });
        }

        function classEscape(s) {
          return s
              .replace(/\\/g, '\\\\')
              .replace(/\]/g, '\\]')
              .replace(/\^/g, '\\^')
              .replace(/-/g,  '\\-')
              .replace(/\0/g, '\\0')
              .replace(/\t/g, '\\t')
              .replace(/\n/g, '\\n')
              .replace(/\r/g, '\\r')
              .replace(/[\x00-\x0F]/g,          function(ch) { return '\\x0' + hex(ch); })
              .replace(/[\x10-\x1F\x7F-\x9F]/g, function(ch) { return '\\x'  + hex(ch); });
        }

        function describeExpectation(expectation) {
          return DESCRIBE_EXPECTATION_FNS[expectation.type](expectation);
        }

        function describeExpected(expected) {
          var descriptions = new Array(expected.length),
              i, j;

          for (i = 0; i < expected.length; i++) {
            descriptions[i] = describeExpectation(expected[i]);
          }

          descriptions.sort();

          if (descriptions.length > 0) {
            for (i = 1, j = 1; i < descriptions.length; i++) {
              if (descriptions[i - 1] !== descriptions[i]) {
                descriptions[j] = descriptions[i];
                j++;
              }
            }
            descriptions.length = j;
          }

          switch (descriptions.length) {
            case 1:
              return descriptions[0];

            case 2:
              return descriptions[0] + " or " + descriptions[1];

            default:
              return descriptions.slice(0, -1).join(", ")
                  + ", or "
                  + descriptions[descriptions.length - 1];
          }
        }

        function describeFound(found) {
          return found ? "\"" + literalEscape(found) + "\"" : "end of input";
        }

        return "Expected " + describeExpected(expected) + " but " + describeFound(found) + " found.";
      };

      function peg$parse(input, options) {
        options = options !== void 0 ? options : {};

        var peg$FAILED = {},

            peg$startRuleFunctions = { start: peg$parsestart },
            peg$startRuleFunction  = peg$parsestart,

            peg$c0 = function(formula) { return formula; },
            peg$c1 = peg$anyExpectation(),
            peg$c2 = peg$otherExpectation("whitespace"),
            peg$c3 = /^[\t\x0B\f \xA0]/,
            peg$c4 = peg$classExpectation(["\t", "\x0B", "\f", " ", "\xA0"], false, false),
            peg$c5 = /^[\n\r]/,
            peg$c6 = peg$classExpectation(["\n", "\r"], false, false),
            peg$c7 = peg$otherExpectation("end of line"),
            peg$c8 = "\n",
            peg$c9 = peg$literalExpectation("\n", false),
            peg$c10 = "\r\n",
            peg$c11 = peg$literalExpectation("\r\n", false),
            peg$c12 = "\r",
            peg$c13 = peg$literalExpectation("\r", false),
            peg$c14 = peg$otherExpectation("identifier"),
            peg$c15 = function(name) { return name; },
            peg$c16 = function(start, parts) {
              return start + parts.join("");
            },
            peg$c17 = "_",
            peg$c18 = peg$literalExpectation("_", false),
            peg$c19 = "`",
            peg$c20 = peg$literalExpectation("`", false),
            peg$c21 = function(parts) { return parts[1]; },
            peg$c22 = function(chars) { return chars.join(""); },
            peg$c23 = "\\",
            peg$c24 = peg$literalExpectation("\\", false),
            peg$c25 = function(char_) { return char_; },
            peg$c26 = function(sequence) { return sequence; },
            peg$c27 = function(value) {
              return {
                type:  "NumericLiteral",
                value: value
              };
            },
            peg$c28 = function(value) {
              return {
                type:  "StringLiteral",
                value: value
              };
            },
            peg$c29 = function() { return { type: "BooleanLiteral", value: true  }; },
            peg$c30 = function() { return { type: "BooleanLiteral", value: false }; },
            peg$c31 = peg$otherExpectation("number"),
            peg$c32 = function(literal) {
              return literal;
            },
            peg$c33 = ".",
            peg$c34 = peg$literalExpectation(".", false),
            peg$c35 = function(before, after, exponent) {
              return parseFloat(before + "." + after + exponent);
            },
            peg$c36 = function(after, exponent) {
              return parseFloat("." + after + exponent);
            },
            peg$c37 = function(before, exponent) {
              return parseFloat(before + exponent);
            },
            peg$c38 = "0",
            peg$c39 = peg$literalExpectation("0", false),
            peg$c40 = function(digit, digits) { return digits?digit + digits:digit; },
            peg$c41 = function(digits) { return digits.join(""); },
            peg$c42 = /^[0-9]/,
            peg$c43 = peg$classExpectation([["0", "9"]], false, false),
            peg$c44 = /^[1-9]/,
            peg$c45 = peg$classExpectation([["1", "9"]], false, false),
            peg$c46 = function(indicator, integer) {
              return indicator + integer;
            },
            peg$c47 = /^[eE]/,
            peg$c48 = peg$classExpectation(["e", "E"], false, false),
            peg$c49 = /^[\-+]/,
            peg$c50 = peg$classExpectation(["-", "+"], false, false),
            peg$c51 = function(sign, digits) { return sign + digits; },
            peg$c52 = /^[0-9a-fA-F]/,
            peg$c53 = peg$classExpectation([["0", "9"], ["a", "f"], ["A", "F"]], false, false),
            peg$c54 = peg$otherExpectation("string"),
            peg$c55 = "\"",
            peg$c56 = peg$literalExpectation("\"", false),
            peg$c57 = "'",
            peg$c58 = peg$literalExpectation("'", false),
            peg$c59 = function(parts) {
              return parts[1] || "";
            },
            peg$c60 = function(char_) { return char_;     },
            peg$c61 = /^['"\\bfnrtv]/,
            peg$c62 = peg$classExpectation(["'", "\"", "\\", "b", "f", "n", "r", "t", "v"], false, false),
            peg$c63 = function(char_) {
              return char_
                  .replace("b", "\b")
                  .replace("f", "\f")
                  .replace("n", "\n")
                  .replace("r", "\r")
                  .replace("t", "\t")
                  .replace("v", "\x0B") // IE does not recognize "\v".
            },
            peg$c64 = "x",
            peg$c65 = peg$literalExpectation("x", false),
            peg$c66 = "u",
            peg$c67 = peg$literalExpectation("u", false),
            peg$c68 = function(h1, h2) {
              return String.fromCharCode(parseInt("0x" + h1 + h2));
            },
            peg$c69 = function(h1, h2, h3, h4) {
              return String.fromCharCode(parseInt("0x" + h1 + h2 + h3 + h4));
            },
            peg$c70 = "and",
            peg$c71 = peg$literalExpectation("and", false),
            peg$c72 = function() { return "&&"; },
            peg$c73 = "AND",
            peg$c74 = peg$literalExpectation("AND", false),
            peg$c75 = "or",
            peg$c76 = peg$literalExpectation("or", false),
            peg$c77 = function() { return "||"; },
            peg$c78 = "OR",
            peg$c79 = peg$literalExpectation("OR", false),
            peg$c80 = "false",
            peg$c81 = peg$literalExpectation("false", false),
            peg$c82 = "FALSE",
            peg$c83 = peg$literalExpectation("FALSE", false),
            peg$c84 = "true",
            peg$c85 = peg$literalExpectation("true", false),
            peg$c86 = "TRUE",
            peg$c87 = peg$literalExpectation("TRUE", false),
            peg$c88 = /^[a-z|\u03B1-\u03C9]/,
            peg$c89 = peg$classExpectation([["a", "z"], "|", ["\u03B1", "\u03C9"]], false, false),
            peg$c90 = /^(?!)/,
            peg$c91 = peg$classExpectation([], false, false),
            peg$c92 = /^[A-Z|\u0391-\u03A9]/,
            peg$c93 = peg$classExpectation([["A", "Z"], "|", ["\u0391", "\u03A9"]], false, false),
            peg$c94 = /^[_]/,
            peg$c95 = peg$classExpectation(["_"], false, false),
            peg$c96 = /^[ \xA0]/,
            peg$c97 = peg$classExpectation([" ", "\xA0"], false, false),
            peg$c98 = function(name) { return { type: "Variable", name: name }; },
            peg$c99 = "(",
            peg$c100 = peg$literalExpectation("(", false),
            peg$c101 = ")",
            peg$c102 = peg$literalExpectation(")", false),
            peg$c103 = function(expression) { return expression; },
            peg$c104 = function(name, args) {
              return {
                type:      "FunctionCall",
                name:      name,
                args:      args
              };
            },
            peg$c105 = function(base, args) {
              return {
                type:      "FunctionCallArguments",
                args:      args
              };
            },
            peg$c106 = function(base, argumentsOrAccessors) {
              var result = base;
              for (var i = 0; i < argumentsOrAccessors.length; i++) {
                switch (argumentsOrAccessors[i].type) {
                  case "FunctionCallArguments":
                    result = {
                      type:      "FunctionCall",
                      name:      result,
                      args:      argumentsOrAccessors[i].args
                    };
                    break;
                  default:
                    throw new Error(
                        "Invalid expression type: " + argumentsOrAccessors[i].type
                    );
                }
              }
              return result;
            },
            peg$c107 = function(args) {
              return args !== "" ? args : [];
            },
            peg$c108 = ",",
            peg$c109 = peg$literalExpectation(",", false),
            peg$c110 = function(head, tail) {
              var result = [head];
              for (var i = 0; i < tail.length; i++) {
                result.push(tail[i][3]);
              }
              return result;
            },
            peg$c111 = function(operator, expression) {
              if (operator === '!') {
                return {
                  type:       "UnaryExpression",
                  operator:   operator,
                  expression: {
                    type: "FunctionCall",
                    name: {type: "FunctionCall", name: "boolean"},
                    args: [expression]
                  }
                }
              }
              return {
                type:       "UnaryExpression",
                operator:   operator,
                expression: expression
              };
            },
            peg$c112 = "+",
            peg$c113 = peg$literalExpectation("+", false),
            peg$c114 = "-",
            peg$c115 = peg$literalExpectation("-", false),
            peg$c116 = "\u2212",
            peg$c117 = peg$literalExpectation("\u2212", false),
            peg$c118 = function() { return "-"; },
            peg$c119 = "!",
            peg$c120 = peg$literalExpectation("!", false),
            peg$c121 = function(head, tail) {
              var result = tail;
              for (var i = head.length - 1; i >= 0; i--) {
                result = {
                  type:     "BinaryExpression",
                  operator: "^",
                  left:     head[i][1],
                  right:    result
                };
              }
              return result;
            },
            peg$c122 = "^",
            peg$c123 = peg$literalExpectation("^", false),
            peg$c124 = function(head, tail) {
              var result = head;
              for (var i = 0; i < tail.length; i++) {
                result = {
                  type:     "BinaryExpression",
                  operator: tail[i][1],
                  left:     result,
                  right:    tail[i][3]
                };
              }
              return result;
            },
            peg$c125 = "*",
            peg$c126 = peg$literalExpectation("*", false),
            peg$c127 = "/",
            peg$c128 = peg$literalExpectation("/", false),
            peg$c129 = "%",
            peg$c130 = peg$literalExpectation("%", false),
            peg$c131 = "=",
            peg$c132 = peg$literalExpectation("=", false),
            peg$c133 = function(operator) { return operator; },
            peg$c134 = "\xD7",
            peg$c135 = peg$literalExpectation("\xD7", false),
            peg$c136 = function() { return "*"; },
            peg$c137 = "\xF7",
            peg$c138 = peg$literalExpectation("\xF7", false),
            peg$c139 = function() { return "/"; },
            peg$c140 = "\u22C5",
            peg$c141 = peg$literalExpectation("\u22C5", false),
            peg$c142 = function() { return "+"; },
            peg$c143 = "<=",
            peg$c144 = peg$literalExpectation("<=", false),
            peg$c145 = ">=",
            peg$c146 = peg$literalExpectation(">=", false),
            peg$c147 = "<",
            peg$c148 = peg$literalExpectation("<", false),
            peg$c149 = ">",
            peg$c150 = peg$literalExpectation(">", false),
            peg$c151 = "\u2264",
            peg$c152 = peg$literalExpectation("\u2264", false),
            peg$c153 = function() { return "<="; },
            peg$c154 = "\u2265",
            peg$c155 = peg$literalExpectation("\u2265", false),
            peg$c156 = function() { return ">="; },
            peg$c157 = function() { return "=="; },
            peg$c158 = "!=",
            peg$c159 = peg$literalExpectation("!=", false),
            peg$c160 = function() { return "!="; },
            peg$c161 = "\u2260",
            peg$c162 = peg$literalExpectation("\u2260", false),
            peg$c163 = function(head, tail) {
              var result = head;
              for (var i = 0; i < tail.length; i++) {
                result = {
                  type:     "BinaryExpression",
                  operator: tail[i][1],
                  left:     {
                    type: "FunctionCall",
                    name: {type: "FunctionCall", name: "boolean"},
                    args: [result]
                  },
                  right:    {
                    type: "FunctionCall",
                    name: {type: "FunctionCall", name: "boolean"},
                    args: [tail[i][3]]
                  }
                };
              }
              return result;
            },
            peg$c164 = "&",
            peg$c165 = peg$literalExpectation("&", false),
            peg$c166 = function(head, tail) {
              var result = head;
              for (var i = 0; i < tail.length; i++) {
                result = {
                  type:     "BinaryExpression",
                  operator: tail[i][1],
                  left:     {
                    type: "FunctionCall",
                    name: {type: "FunctionCall", name: "boolean"},
                    args: [result]
                  },
                  right:    {
                    type: "FunctionCall",
                    name: {type: "FunctionCall", name: "boolean"},
                    args: [tail[i][3]]
                  }
                };
              }
              return result;
            },
            peg$c167 = "|",
            peg$c168 = peg$literalExpectation("|", false),
            peg$c169 = "?",
            peg$c170 = peg$literalExpectation("?", false),
            peg$c171 = ":",
            peg$c172 = peg$literalExpectation(":", false),
            peg$c173 = function(condition, trueExpression, falseExpression) {
              return {
                type:            "ConditionalExpression",
                condition:       {
                  type: "FunctionCall",
                  name: {type: "FunctionCall", name: "boolean"},
                  args: [condition]
                },
                trueExpression:  trueExpression,
                falseExpression: falseExpression
              };
            },

            peg$currPos          = 0,
            peg$savedPos         = 0,
            peg$posDetailsCache  = [{ line: 1, column: 1 }],
            peg$maxFailPos       = 0,
            peg$maxFailExpected  = [],
            peg$silentFails      = 0,

            peg$result;

        if ("startRule" in options) {
          if (!(options.startRule in peg$startRuleFunctions)) {
            throw new Error("Can't start parsing from rule \"" + options.startRule + "\".");
          }

          peg$startRuleFunction = peg$startRuleFunctions[options.startRule];
        }

        function text() {
          return input.substring(peg$savedPos, peg$currPos);
        }

        function location() {
          return peg$computeLocation(peg$savedPos, peg$currPos);
        }

        function expected(description, location) {
          location = location !== void 0 ? location : peg$computeLocation(peg$savedPos, peg$currPos)

          throw peg$buildStructuredError(
              [peg$otherExpectation(description)],
              input.substring(peg$savedPos, peg$currPos),
              location
          );
        }

        function error(message, location) {
          location = location !== void 0 ? location : peg$computeLocation(peg$savedPos, peg$currPos)

          throw peg$buildSimpleError(message, location);
        }

        function peg$literalExpectation(text, ignoreCase) {
          return { type: "literal", text: text, ignoreCase: ignoreCase };
        }

        function peg$classExpectation(parts, inverted, ignoreCase) {
          return { type: "class", parts: parts, inverted: inverted, ignoreCase: ignoreCase };
        }

        function peg$anyExpectation() {
          return { type: "any" };
        }

        function peg$endExpectation() {
          return { type: "end" };
        }

        function peg$otherExpectation(description) {
          return { type: "other", description: description };
        }

        function peg$computePosDetails(pos) {
          var details = peg$posDetailsCache[pos], p;

          if (details) {
            return details;
          } else {
            p = pos - 1;
            while (!peg$posDetailsCache[p]) {
              p--;
            }

            details = peg$posDetailsCache[p];
            details = {
              line:   details.line,
              column: details.column
            };

            while (p < pos) {
              if (input.charCodeAt(p) === 10) {
                details.line++;
                details.column = 1;
              } else {
                details.column++;
              }

              p++;
            }

            peg$posDetailsCache[pos] = details;
            return details;
          }
        }

        function peg$computeLocation(startPos, endPos) {
          var startPosDetails = peg$computePosDetails(startPos),
              endPosDetails   = peg$computePosDetails(endPos);

          return {
            start: {
              offset: startPos,
              line:   startPosDetails.line,
              column: startPosDetails.column
            },
            end: {
              offset: endPos,
              line:   endPosDetails.line,
              column: endPosDetails.column
            }
          };
        }

        function peg$fail(expected) {
          if (peg$currPos < peg$maxFailPos) { return; }

          if (peg$currPos > peg$maxFailPos) {
            peg$maxFailPos = peg$currPos;
            peg$maxFailExpected = [];
          }

          peg$maxFailExpected.push(expected);
        }

        function peg$buildSimpleError(message, location) {
          return new peg$SyntaxError(message, null, null, location);
        }

        function peg$buildStructuredError(expected, found, location) {
          return new peg$SyntaxError(
              peg$SyntaxError.buildMessage(expected, found),
              expected,
              found,
              location
          );
        }

        function peg$parsestart() {
          var s0, s1, s2, s3;

          s0 = peg$currPos;
          s1 = peg$parse__();
          if (s1 !== peg$FAILED) {
            s2 = peg$parseConditionalExpression();
            if (s2 !== peg$FAILED) {
              s3 = peg$parse__();
              if (s3 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c0(s2);
                s0 = s1;
              } else {
                peg$currPos = s0;
                s0 = peg$FAILED;
              }
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }

          return s0;
        }

        function peg$parseSourceCharacter() {
          var s0;

          if (input.length > peg$currPos) {
            s0 = input.charAt(peg$currPos);
            peg$currPos++;
          } else {
            s0 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c1); }
          }

          return s0;
        }

        function peg$parseWhiteSpace() {
          var s0, s1;

          peg$silentFails++;
          if (peg$c3.test(input.charAt(peg$currPos))) {
            s0 = input.charAt(peg$currPos);
            peg$currPos++;
          } else {
            s0 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c4); }
          }
          if (s0 === peg$FAILED) {
            s0 = peg$parseZs();
          }
          peg$silentFails--;
          if (s0 === peg$FAILED) {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c2); }
          }

          return s0;
        }

        function peg$parseLineTerminator() {
          var s0;

          if (peg$c5.test(input.charAt(peg$currPos))) {
            s0 = input.charAt(peg$currPos);
            peg$currPos++;
          } else {
            s0 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c6); }
          }

          return s0;
        }

        function peg$parseLineTerminatorSequence() {
          var s0, s1;

          peg$silentFails++;
          if (input.charCodeAt(peg$currPos) === 10) {
            s0 = peg$c8;
            peg$currPos++;
          } else {
            s0 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c9); }
          }
          if (s0 === peg$FAILED) {
            if (input.substr(peg$currPos, 2) === peg$c10) {
              s0 = peg$c10;
              peg$currPos += 2;
            } else {
              s0 = peg$FAILED;
              if (peg$silentFails === 0) { peg$fail(peg$c11); }
            }
            if (s0 === peg$FAILED) {
              if (input.charCodeAt(peg$currPos) === 13) {
                s0 = peg$c12;
                peg$currPos++;
              } else {
                s0 = peg$FAILED;
                if (peg$silentFails === 0) { peg$fail(peg$c13); }
              }
            }
          }
          peg$silentFails--;
          if (s0 === peg$FAILED) {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c7); }
          }

          return s0;
        }

        function peg$parseIdentifier() {
          var s0, s1, s2;

          peg$silentFails++;
          s0 = peg$currPos;
          s1 = peg$currPos;
          peg$silentFails++;
          s2 = peg$parseBooleanLiteral();
          peg$silentFails--;
          if (s2 === peg$FAILED) {
            s1 = void 0;
          } else {
            peg$currPos = s1;
            s1 = peg$FAILED;
          }
          if (s1 !== peg$FAILED) {
            s2 = peg$parseIdentifierName();
            if (s2 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c15(s2);
              s0 = s1;
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }
          if (s0 === peg$FAILED) {
            s0 = peg$parseBacktickIdentifier();
          }
          peg$silentFails--;
          if (s0 === peg$FAILED) {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c14); }
          }

          return s0;
        }

        function peg$parseIdentifierName() {
          var s0, s1, s2, s3;

          peg$silentFails++;
          s0 = peg$currPos;
          s1 = peg$parseIdentifierStart();
          if (s1 !== peg$FAILED) {
            s2 = [];
            s3 = peg$parseIdentifierPart();
            while (s3 !== peg$FAILED) {
              s2.push(s3);
              s3 = peg$parseIdentifierPart();
            }
            if (s2 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c16(s1, s2);
              s0 = s1;
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }
          peg$silentFails--;
          if (s0 === peg$FAILED) {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c14); }
          }

          return s0;
        }

        function peg$parseIdentifierStart() {
          var s0;

          s0 = peg$parseUnicodeLetter();
          if (s0 === peg$FAILED) {
            if (input.charCodeAt(peg$currPos) === 95) {
              s0 = peg$c17;
              peg$currPos++;
            } else {
              s0 = peg$FAILED;
              if (peg$silentFails === 0) { peg$fail(peg$c18); }
            }
          }

          return s0;
        }

        function peg$parseIdentifierPart() {
          var s0;

          s0 = peg$parseIdentifierStart();
          if (s0 === peg$FAILED) {
            s0 = peg$parseNd();
            if (s0 === peg$FAILED) {
              s0 = peg$parsePc();
            }
          }

          return s0;
        }

        function peg$parseBacktickIdentifier() {
          var s0, s1, s2, s3, s4;

          s0 = peg$currPos;
          s1 = peg$currPos;
          if (input.charCodeAt(peg$currPos) === 96) {
            s2 = peg$c19;
            peg$currPos++;
          } else {
            s2 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c20); }
          }
          if (s2 !== peg$FAILED) {
            s3 = peg$parseBacktickIdentifierCharacters();
            if (s3 !== peg$FAILED) {
              if (input.charCodeAt(peg$currPos) === 96) {
                s4 = peg$c19;
                peg$currPos++;
              } else {
                s4 = peg$FAILED;
                if (peg$silentFails === 0) { peg$fail(peg$c20); }
              }
              if (s4 !== peg$FAILED) {
                s2 = [s2, s3, s4];
                s1 = s2;
              } else {
                peg$currPos = s1;
                s1 = peg$FAILED;
              }
            } else {
              peg$currPos = s1;
              s1 = peg$FAILED;
            }
          } else {
            peg$currPos = s1;
            s1 = peg$FAILED;
          }
          if (s1 !== peg$FAILED) {
            peg$savedPos = s0;
            s1 = peg$c21(s1);
          }
          s0 = s1;

          return s0;
        }

        function peg$parseBacktickIdentifierCharacters() {
          var s0, s1, s2;

          s0 = peg$currPos;
          s1 = [];
          s2 = peg$parseBacktickIdentifierChar();
          if (s2 !== peg$FAILED) {
            while (s2 !== peg$FAILED) {
              s1.push(s2);
              s2 = peg$parseBacktickIdentifierChar();
            }
          } else {
            s1 = peg$FAILED;
          }
          if (s1 !== peg$FAILED) {
            peg$savedPos = s0;
            s1 = peg$c22(s1);
          }
          s0 = s1;

          return s0;
        }

        function peg$parseBacktickIdentifierChar() {
          var s0, s1, s2;

          s0 = peg$currPos;
          s1 = peg$currPos;
          peg$silentFails++;
          if (input.charCodeAt(peg$currPos) === 96) {
            s2 = peg$c19;
            peg$currPos++;
          } else {
            s2 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c20); }
          }
          if (s2 === peg$FAILED) {
            if (input.charCodeAt(peg$currPos) === 92) {
              s2 = peg$c23;
              peg$currPos++;
            } else {
              s2 = peg$FAILED;
              if (peg$silentFails === 0) { peg$fail(peg$c24); }
            }
            if (s2 === peg$FAILED) {
              s2 = peg$parseLineTerminator();
            }
          }
          peg$silentFails--;
          if (s2 === peg$FAILED) {
            s1 = void 0;
          } else {
            peg$currPos = s1;
            s1 = peg$FAILED;
          }
          if (s1 !== peg$FAILED) {
            s2 = peg$parseSourceCharacter();
            if (s2 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c25(s2);
              s0 = s1;
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }
          if (s0 === peg$FAILED) {
            s0 = peg$currPos;
            if (input.charCodeAt(peg$currPos) === 92) {
              s1 = peg$c23;
              peg$currPos++;
            } else {
              s1 = peg$FAILED;
              if (peg$silentFails === 0) { peg$fail(peg$c24); }
            }
            if (s1 !== peg$FAILED) {
              s2 = peg$parseEscapeSequence();
              if (s2 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c26(s2);
                s0 = s1;
              } else {
                peg$currPos = s0;
                s0 = peg$FAILED;
              }
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          }

          return s0;
        }

        function peg$parseUnicodeLetter() {
          var s0;

          s0 = peg$parseLu();
          if (s0 === peg$FAILED) {
            s0 = peg$parseLl();
          }

          return s0;
        }

        function peg$parseLiteral() {
          var s0, s1;

          s0 = peg$parseBooleanLiteral();
          if (s0 === peg$FAILED) {
            s0 = peg$currPos;
            s1 = peg$parseNumericLiteral();
            if (s1 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c27(s1);
            }
            s0 = s1;
            if (s0 === peg$FAILED) {
              s0 = peg$currPos;
              s1 = peg$parseStringLiteral();
              if (s1 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c28(s1);
              }
              s0 = s1;
            }
          }

          return s0;
        }

        function peg$parseBooleanLiteral() {
          var s0, s1;

          s0 = peg$currPos;
          s1 = peg$parseTrueToken();
          if (s1 !== peg$FAILED) {
            peg$savedPos = s0;
            s1 = peg$c29();
          }
          s0 = s1;
          if (s0 === peg$FAILED) {
            s0 = peg$currPos;
            s1 = peg$parseFalseToken();
            if (s1 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c30();
            }
            s0 = s1;
          }

          return s0;
        }

        function peg$parseNumericLiteral() {
          var s0, s1, s2, s3;

          peg$silentFails++;
          s0 = peg$currPos;
          s1 = peg$parseDecimalLiteral();
          if (s1 !== peg$FAILED) {
            s2 = peg$currPos;
            peg$silentFails++;
            s3 = peg$parseIdentifierStart();
            peg$silentFails--;
            if (s3 === peg$FAILED) {
              s2 = void 0;
            } else {
              peg$currPos = s2;
              s2 = peg$FAILED;
            }
            if (s2 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c32(s1);
              s0 = s1;
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }
          peg$silentFails--;
          if (s0 === peg$FAILED) {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c31); }
          }

          return s0;
        }

        function peg$parseDecimalLiteral() {
          var s0, s1, s2, s3, s4;

          s0 = peg$currPos;
          s1 = peg$parseDecimalIntegerLiteral();
          if (s1 !== peg$FAILED) {
            if (input.charCodeAt(peg$currPos) === 46) {
              s2 = peg$c33;
              peg$currPos++;
            } else {
              s2 = peg$FAILED;
              if (peg$silentFails === 0) { peg$fail(peg$c34); }
            }
            if (s2 !== peg$FAILED) {
              s3 = peg$parseDecimalDigits();
              if (s3 === peg$FAILED) {
                s3 = null;
              }
              if (s3 !== peg$FAILED) {
                s4 = peg$parseExponentPart();
                if (s4 === peg$FAILED) {
                  s4 = null;
                }
                if (s4 !== peg$FAILED) {
                  peg$savedPos = s0;
                  s1 = peg$c35(s1, s3, s4);
                  s0 = s1;
                } else {
                  peg$currPos = s0;
                  s0 = peg$FAILED;
                }
              } else {
                peg$currPos = s0;
                s0 = peg$FAILED;
              }
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }
          if (s0 === peg$FAILED) {
            s0 = peg$currPos;
            if (input.charCodeAt(peg$currPos) === 46) {
              s1 = peg$c33;
              peg$currPos++;
            } else {
              s1 = peg$FAILED;
              if (peg$silentFails === 0) { peg$fail(peg$c34); }
            }
            if (s1 !== peg$FAILED) {
              s2 = peg$parseDecimalDigits();
              if (s2 !== peg$FAILED) {
                s3 = peg$parseExponentPart();
                if (s3 === peg$FAILED) {
                  s3 = null;
                }
                if (s3 !== peg$FAILED) {
                  peg$savedPos = s0;
                  s1 = peg$c36(s2, s3);
                  s0 = s1;
                } else {
                  peg$currPos = s0;
                  s0 = peg$FAILED;
                }
              } else {
                peg$currPos = s0;
                s0 = peg$FAILED;
              }
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
            if (s0 === peg$FAILED) {
              s0 = peg$currPos;
              s1 = peg$parseDecimalIntegerLiteral();
              if (s1 !== peg$FAILED) {
                s2 = peg$parseExponentPart();
                if (s2 === peg$FAILED) {
                  s2 = null;
                }
                if (s2 !== peg$FAILED) {
                  peg$savedPos = s0;
                  s1 = peg$c37(s1, s2);
                  s0 = s1;
                } else {
                  peg$currPos = s0;
                  s0 = peg$FAILED;
                }
              } else {
                peg$currPos = s0;
                s0 = peg$FAILED;
              }
            }
          }

          return s0;
        }

        function peg$parseDecimalIntegerLiteral() {
          var s0, s1, s2;

          if (input.charCodeAt(peg$currPos) === 48) {
            s0 = peg$c38;
            peg$currPos++;
          } else {
            s0 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c39); }
          }
          if (s0 === peg$FAILED) {
            s0 = peg$currPos;
            s1 = peg$parseNonZeroDigit();
            if (s1 !== peg$FAILED) {
              s2 = peg$parseDecimalDigits();
              if (s2 === peg$FAILED) {
                s2 = null;
              }
              if (s2 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c40(s1, s2);
                s0 = s1;
              } else {
                peg$currPos = s0;
                s0 = peg$FAILED;
              }
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          }

          return s0;
        }

        function peg$parseDecimalDigits() {
          var s0, s1, s2;

          s0 = peg$currPos;
          s1 = [];
          s2 = peg$parseDecimalDigit();
          if (s2 !== peg$FAILED) {
            while (s2 !== peg$FAILED) {
              s1.push(s2);
              s2 = peg$parseDecimalDigit();
            }
          } else {
            s1 = peg$FAILED;
          }
          if (s1 !== peg$FAILED) {
            peg$savedPos = s0;
            s1 = peg$c41(s1);
          }
          s0 = s1;

          return s0;
        }

        function peg$parseDecimalDigit() {
          var s0;

          if (peg$c42.test(input.charAt(peg$currPos))) {
            s0 = input.charAt(peg$currPos);
            peg$currPos++;
          } else {
            s0 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c43); }
          }

          return s0;
        }

        function peg$parseNonZeroDigit() {
          var s0;

          if (peg$c44.test(input.charAt(peg$currPos))) {
            s0 = input.charAt(peg$currPos);
            peg$currPos++;
          } else {
            s0 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c45); }
          }

          return s0;
        }

        function peg$parseExponentPart() {
          var s0, s1, s2;

          s0 = peg$currPos;
          s1 = peg$parseExponentIndicator();
          if (s1 !== peg$FAILED) {
            s2 = peg$parseSignedInteger();
            if (s2 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c46(s1, s2);
              s0 = s1;
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }

          return s0;
        }

        function peg$parseExponentIndicator() {
          var s0;

          if (peg$c47.test(input.charAt(peg$currPos))) {
            s0 = input.charAt(peg$currPos);
            peg$currPos++;
          } else {
            s0 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c48); }
          }

          return s0;
        }

        function peg$parseSignedInteger() {
          var s0, s1, s2;

          s0 = peg$currPos;
          if (peg$c49.test(input.charAt(peg$currPos))) {
            s1 = input.charAt(peg$currPos);
            peg$currPos++;
          } else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c50); }
          }
          if (s1 === peg$FAILED) {
            s1 = null;
          }
          if (s1 !== peg$FAILED) {
            s2 = peg$parseDecimalDigits();
            if (s2 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c51(s1, s2);
              s0 = s1;
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }

          return s0;
        }

        function peg$parseHexDigit() {
          var s0;

          if (peg$c52.test(input.charAt(peg$currPos))) {
            s0 = input.charAt(peg$currPos);
            peg$currPos++;
          } else {
            s0 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c53); }
          }

          return s0;
        }

        function peg$parseStringLiteral() {
          var s0, s1, s2, s3, s4;

          peg$silentFails++;
          s0 = peg$currPos;
          s1 = peg$currPos;
          if (input.charCodeAt(peg$currPos) === 34) {
            s2 = peg$c55;
            peg$currPos++;
          } else {
            s2 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c56); }
          }
          if (s2 !== peg$FAILED) {
            s3 = peg$parseDoubleStringCharacters();
            if (s3 === peg$FAILED) {
              s3 = null;
            }
            if (s3 !== peg$FAILED) {
              if (input.charCodeAt(peg$currPos) === 34) {
                s4 = peg$c55;
                peg$currPos++;
              } else {
                s4 = peg$FAILED;
                if (peg$silentFails === 0) { peg$fail(peg$c56); }
              }
              if (s4 !== peg$FAILED) {
                s2 = [s2, s3, s4];
                s1 = s2;
              } else {
                peg$currPos = s1;
                s1 = peg$FAILED;
              }
            } else {
              peg$currPos = s1;
              s1 = peg$FAILED;
            }
          } else {
            peg$currPos = s1;
            s1 = peg$FAILED;
          }
          if (s1 === peg$FAILED) {
            s1 = peg$currPos;
            if (input.charCodeAt(peg$currPos) === 39) {
              s2 = peg$c57;
              peg$currPos++;
            } else {
              s2 = peg$FAILED;
              if (peg$silentFails === 0) { peg$fail(peg$c58); }
            }
            if (s2 !== peg$FAILED) {
              s3 = peg$parseSingleStringCharacters();
              if (s3 === peg$FAILED) {
                s3 = null;
              }
              if (s3 !== peg$FAILED) {
                if (input.charCodeAt(peg$currPos) === 39) {
                  s4 = peg$c57;
                  peg$currPos++;
                } else {
                  s4 = peg$FAILED;
                  if (peg$silentFails === 0) { peg$fail(peg$c58); }
                }
                if (s4 !== peg$FAILED) {
                  s2 = [s2, s3, s4];
                  s1 = s2;
                } else {
                  peg$currPos = s1;
                  s1 = peg$FAILED;
                }
              } else {
                peg$currPos = s1;
                s1 = peg$FAILED;
              }
            } else {
              peg$currPos = s1;
              s1 = peg$FAILED;
            }
          }
          if (s1 !== peg$FAILED) {
            peg$savedPos = s0;
            s1 = peg$c59(s1);
          }
          s0 = s1;
          peg$silentFails--;
          if (s0 === peg$FAILED) {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c54); }
          }

          return s0;
        }

        function peg$parseDoubleStringCharacters() {
          var s0, s1, s2;

          s0 = peg$currPos;
          s1 = [];
          s2 = peg$parseDoubleStringCharacter();
          if (s2 !== peg$FAILED) {
            while (s2 !== peg$FAILED) {
              s1.push(s2);
              s2 = peg$parseDoubleStringCharacter();
            }
          } else {
            s1 = peg$FAILED;
          }
          if (s1 !== peg$FAILED) {
            peg$savedPos = s0;
            s1 = peg$c22(s1);
          }
          s0 = s1;

          return s0;
        }

        function peg$parseSingleStringCharacters() {
          var s0, s1, s2;

          s0 = peg$currPos;
          s1 = [];
          s2 = peg$parseSingleStringCharacter();
          if (s2 !== peg$FAILED) {
            while (s2 !== peg$FAILED) {
              s1.push(s2);
              s2 = peg$parseSingleStringCharacter();
            }
          } else {
            s1 = peg$FAILED;
          }
          if (s1 !== peg$FAILED) {
            peg$savedPos = s0;
            s1 = peg$c22(s1);
          }
          s0 = s1;

          return s0;
        }

        function peg$parseDoubleStringCharacter() {
          var s0, s1, s2;

          s0 = peg$currPos;
          s1 = peg$currPos;
          peg$silentFails++;
          if (input.charCodeAt(peg$currPos) === 34) {
            s2 = peg$c55;
            peg$currPos++;
          } else {
            s2 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c56); }
          }
          if (s2 === peg$FAILED) {
            if (input.charCodeAt(peg$currPos) === 92) {
              s2 = peg$c23;
              peg$currPos++;
            } else {
              s2 = peg$FAILED;
              if (peg$silentFails === 0) { peg$fail(peg$c24); }
            }
            if (s2 === peg$FAILED) {
              s2 = peg$parseLineTerminator();
            }
          }
          peg$silentFails--;
          if (s2 === peg$FAILED) {
            s1 = void 0;
          } else {
            peg$currPos = s1;
            s1 = peg$FAILED;
          }
          if (s1 !== peg$FAILED) {
            s2 = peg$parseSourceCharacter();
            if (s2 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c60(s2);
              s0 = s1;
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }
          if (s0 === peg$FAILED) {
            s0 = peg$currPos;
            if (input.charCodeAt(peg$currPos) === 92) {
              s1 = peg$c23;
              peg$currPos++;
            } else {
              s1 = peg$FAILED;
              if (peg$silentFails === 0) { peg$fail(peg$c24); }
            }
            if (s1 !== peg$FAILED) {
              s2 = peg$parseEscapeSequence();
              if (s2 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c26(s2);
                s0 = s1;
              } else {
                peg$currPos = s0;
                s0 = peg$FAILED;
              }
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          }

          return s0;
        }

        function peg$parseSingleStringCharacter() {
          var s0, s1, s2;

          s0 = peg$currPos;
          s1 = peg$currPos;
          peg$silentFails++;
          if (input.charCodeAt(peg$currPos) === 39) {
            s2 = peg$c57;
            peg$currPos++;
          } else {
            s2 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c58); }
          }
          if (s2 === peg$FAILED) {
            if (input.charCodeAt(peg$currPos) === 92) {
              s2 = peg$c23;
              peg$currPos++;
            } else {
              s2 = peg$FAILED;
              if (peg$silentFails === 0) { peg$fail(peg$c24); }
            }
            if (s2 === peg$FAILED) {
              s2 = peg$parseLineTerminator();
            }
          }
          peg$silentFails--;
          if (s2 === peg$FAILED) {
            s1 = void 0;
          } else {
            peg$currPos = s1;
            s1 = peg$FAILED;
          }
          if (s1 !== peg$FAILED) {
            s2 = peg$parseSourceCharacter();
            if (s2 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c60(s2);
              s0 = s1;
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }
          if (s0 === peg$FAILED) {
            s0 = peg$currPos;
            if (input.charCodeAt(peg$currPos) === 92) {
              s1 = peg$c23;
              peg$currPos++;
            } else {
              s1 = peg$FAILED;
              if (peg$silentFails === 0) { peg$fail(peg$c24); }
            }
            if (s1 !== peg$FAILED) {
              s2 = peg$parseEscapeSequence();
              if (s2 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c26(s2);
                s0 = s1;
              } else {
                peg$currPos = s0;
                s0 = peg$FAILED;
              }
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          }

          return s0;
        }

        function peg$parseEscapeSequence() {
          var s0;

          s0 = peg$parseCharacterEscapeSequence();
          if (s0 === peg$FAILED) {
            s0 = peg$parseHexEscapeSequence();
            if (s0 === peg$FAILED) {
              s0 = peg$parseUnicodeEscapeSequence();
            }
          }

          return s0;
        }

        function peg$parseCharacterEscapeSequence() {
          var s0;

          s0 = peg$parseSingleEscapeCharacter();
          if (s0 === peg$FAILED) {
            s0 = peg$parseNonEscapeCharacter();
          }

          return s0;
        }

        function peg$parseSingleEscapeCharacter() {
          var s0, s1;

          s0 = peg$currPos;
          if (peg$c61.test(input.charAt(peg$currPos))) {
            s1 = input.charAt(peg$currPos);
            peg$currPos++;
          } else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c62); }
          }
          if (s1 !== peg$FAILED) {
            peg$savedPos = s0;
            s1 = peg$c63(s1);
          }
          s0 = s1;

          return s0;
        }

        function peg$parseNonEscapeCharacter() {
          var s0, s1, s2;

          s0 = peg$currPos;
          s1 = peg$currPos;
          peg$silentFails++;
          s2 = peg$parseEscapeCharacter();
          peg$silentFails--;
          if (s2 === peg$FAILED) {
            s1 = void 0;
          } else {
            peg$currPos = s1;
            s1 = peg$FAILED;
          }
          if (s1 === peg$FAILED) {
            s1 = peg$parseLineTerminator();
          }
          if (s1 !== peg$FAILED) {
            s2 = peg$parseSourceCharacter();
            if (s2 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c25(s2);
              s0 = s1;
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }

          return s0;
        }

        function peg$parseEscapeCharacter() {
          var s0;

          s0 = peg$parseSingleEscapeCharacter();
          if (s0 === peg$FAILED) {
            s0 = peg$parseDecimalDigit();
            if (s0 === peg$FAILED) {
              if (input.charCodeAt(peg$currPos) === 120) {
                s0 = peg$c64;
                peg$currPos++;
              } else {
                s0 = peg$FAILED;
                if (peg$silentFails === 0) { peg$fail(peg$c65); }
              }
              if (s0 === peg$FAILED) {
                if (input.charCodeAt(peg$currPos) === 117) {
                  s0 = peg$c66;
                  peg$currPos++;
                } else {
                  s0 = peg$FAILED;
                  if (peg$silentFails === 0) { peg$fail(peg$c67); }
                }
              }
            }
          }

          return s0;
        }

        function peg$parseHexEscapeSequence() {
          var s0, s1, s2, s3;

          s0 = peg$currPos;
          if (input.charCodeAt(peg$currPos) === 120) {
            s1 = peg$c64;
            peg$currPos++;
          } else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c65); }
          }
          if (s1 !== peg$FAILED) {
            s2 = peg$parseHexDigit();
            if (s2 !== peg$FAILED) {
              s3 = peg$parseHexDigit();
              if (s3 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c68(s2, s3);
                s0 = s1;
              } else {
                peg$currPos = s0;
                s0 = peg$FAILED;
              }
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }

          return s0;
        }

        function peg$parseUnicodeEscapeSequence() {
          var s0, s1, s2, s3, s4, s5;

          s0 = peg$currPos;
          if (input.charCodeAt(peg$currPos) === 117) {
            s1 = peg$c66;
            peg$currPos++;
          } else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c67); }
          }
          if (s1 !== peg$FAILED) {
            s2 = peg$parseHexDigit();
            if (s2 !== peg$FAILED) {
              s3 = peg$parseHexDigit();
              if (s3 !== peg$FAILED) {
                s4 = peg$parseHexDigit();
                if (s4 !== peg$FAILED) {
                  s5 = peg$parseHexDigit();
                  if (s5 !== peg$FAILED) {
                    peg$savedPos = s0;
                    s1 = peg$c69(s2, s3, s4, s5);
                    s0 = s1;
                  } else {
                    peg$currPos = s0;
                    s0 = peg$FAILED;
                  }
                } else {
                  peg$currPos = s0;
                  s0 = peg$FAILED;
                }
              } else {
                peg$currPos = s0;
                s0 = peg$FAILED;
              }
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }

          return s0;
        }

        function peg$parseAndToken() {
          var s0, s1, s2, s3;

          s0 = peg$currPos;
          if (input.substr(peg$currPos, 3) === peg$c70) {
            s1 = peg$c70;
            peg$currPos += 3;
          } else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c71); }
          }
          if (s1 !== peg$FAILED) {
            s2 = peg$currPos;
            peg$silentFails++;
            s3 = peg$parseIdentifierPart();
            peg$silentFails--;
            if (s3 === peg$FAILED) {
              s2 = void 0;
            } else {
              peg$currPos = s2;
              s2 = peg$FAILED;
            }
            if (s2 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c72();
              s0 = s1;
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }
          if (s0 === peg$FAILED) {
            s0 = peg$currPos;
            if (input.substr(peg$currPos, 3) === peg$c73) {
              s1 = peg$c73;
              peg$currPos += 3;
            } else {
              s1 = peg$FAILED;
              if (peg$silentFails === 0) { peg$fail(peg$c74); }
            }
            if (s1 !== peg$FAILED) {
              s2 = peg$currPos;
              peg$silentFails++;
              s3 = peg$parseIdentifierPart();
              peg$silentFails--;
              if (s3 === peg$FAILED) {
                s2 = void 0;
              } else {
                peg$currPos = s2;
                s2 = peg$FAILED;
              }
              if (s2 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c72();
                s0 = s1;
              } else {
                peg$currPos = s0;
                s0 = peg$FAILED;
              }
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          }

          return s0;
        }

        function peg$parseOrToken() {
          var s0, s1, s2, s3;

          s0 = peg$currPos;
          if (input.substr(peg$currPos, 2) === peg$c75) {
            s1 = peg$c75;
            peg$currPos += 2;
          } else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c76); }
          }
          if (s1 !== peg$FAILED) {
            s2 = peg$currPos;
            peg$silentFails++;
            s3 = peg$parseIdentifierPart();
            peg$silentFails--;
            if (s3 === peg$FAILED) {
              s2 = void 0;
            } else {
              peg$currPos = s2;
              s2 = peg$FAILED;
            }
            if (s2 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c77();
              s0 = s1;
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }
          if (s0 === peg$FAILED) {
            s0 = peg$currPos;
            if (input.substr(peg$currPos, 2) === peg$c78) {
              s1 = peg$c78;
              peg$currPos += 2;
            } else {
              s1 = peg$FAILED;
              if (peg$silentFails === 0) { peg$fail(peg$c79); }
            }
            if (s1 !== peg$FAILED) {
              s2 = peg$currPos;
              peg$silentFails++;
              s3 = peg$parseIdentifierPart();
              peg$silentFails--;
              if (s3 === peg$FAILED) {
                s2 = void 0;
              } else {
                peg$currPos = s2;
                s2 = peg$FAILED;
              }
              if (s2 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c77();
                s0 = s1;
              } else {
                peg$currPos = s0;
                s0 = peg$FAILED;
              }
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          }

          return s0;
        }

        function peg$parseFalseToken() {
          var s0, s1, s2, s3;

          s0 = peg$currPos;
          if (input.substr(peg$currPos, 5) === peg$c80) {
            s1 = peg$c80;
            peg$currPos += 5;
          } else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c81); }
          }
          if (s1 !== peg$FAILED) {
            s2 = peg$currPos;
            peg$silentFails++;
            s3 = peg$parseIdentifierPart();
            peg$silentFails--;
            if (s3 === peg$FAILED) {
              s2 = void 0;
            } else {
              peg$currPos = s2;
              s2 = peg$FAILED;
            }
            if (s2 !== peg$FAILED) {
              s1 = [s1, s2];
              s0 = s1;
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }
          if (s0 === peg$FAILED) {
            if (input.substr(peg$currPos, 5) === peg$c82) {
              s0 = peg$c82;
              peg$currPos += 5;
            } else {
              s0 = peg$FAILED;
              if (peg$silentFails === 0) { peg$fail(peg$c83); }
            }
          }

          return s0;
        }

        function peg$parseTrueToken() {
          var s0, s1, s2, s3;

          s0 = peg$currPos;
          if (input.substr(peg$currPos, 4) === peg$c84) {
            s1 = peg$c84;
            peg$currPos += 4;
          } else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c85); }
          }
          if (s1 !== peg$FAILED) {
            s2 = peg$currPos;
            peg$silentFails++;
            s3 = peg$parseIdentifierPart();
            peg$silentFails--;
            if (s3 === peg$FAILED) {
              s2 = void 0;
            } else {
              peg$currPos = s2;
              s2 = peg$FAILED;
            }
            if (s2 !== peg$FAILED) {
              s1 = [s1, s2];
              s0 = s1;
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }
          if (s0 === peg$FAILED) {
            if (input.substr(peg$currPos, 4) === peg$c86) {
              s0 = peg$c86;
              peg$currPos += 4;
            } else {
              s0 = peg$FAILED;
              if (peg$silentFails === 0) { peg$fail(peg$c87); }
            }
          }

          return s0;
        }

        function peg$parseLl() {
          var s0;

          if (peg$c88.test(input.charAt(peg$currPos))) {
            s0 = input.charAt(peg$currPos);
            peg$currPos++;
          } else {
            s0 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c89); }
          }

          return s0;
        }

        function peg$parseLm() {
          var s0;

          if (peg$c90.test(input.charAt(peg$currPos))) {
            s0 = input.charAt(peg$currPos);
            peg$currPos++;
          } else {
            s0 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c91); }
          }

          return s0;
        }

        function peg$parseLo() {
          var s0;

          if (peg$c90.test(input.charAt(peg$currPos))) {
            s0 = input.charAt(peg$currPos);
            peg$currPos++;
          } else {
            s0 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c91); }
          }

          return s0;
        }

        function peg$parseLt() {
          var s0;

          if (peg$c90.test(input.charAt(peg$currPos))) {
            s0 = input.charAt(peg$currPos);
            peg$currPos++;
          } else {
            s0 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c91); }
          }

          return s0;
        }

        function peg$parseLu() {
          var s0;

          if (peg$c92.test(input.charAt(peg$currPos))) {
            s0 = input.charAt(peg$currPos);
            peg$currPos++;
          } else {
            s0 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c93); }
          }

          return s0;
        }

        function peg$parseMc() {
          var s0;

          if (peg$c90.test(input.charAt(peg$currPos))) {
            s0 = input.charAt(peg$currPos);
            peg$currPos++;
          } else {
            s0 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c91); }
          }

          return s0;
        }

        function peg$parseMn() {
          var s0;

          if (peg$c90.test(input.charAt(peg$currPos))) {
            s0 = input.charAt(peg$currPos);
            peg$currPos++;
          } else {
            s0 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c91); }
          }

          return s0;
        }

        function peg$parseNd() {
          var s0;

          if (peg$c42.test(input.charAt(peg$currPos))) {
            s0 = input.charAt(peg$currPos);
            peg$currPos++;
          } else {
            s0 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c43); }
          }

          return s0;
        }

        function peg$parseNl() {
          var s0;

          if (peg$c90.test(input.charAt(peg$currPos))) {
            s0 = input.charAt(peg$currPos);
            peg$currPos++;
          } else {
            s0 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c91); }
          }

          return s0;
        }

        function peg$parsePc() {
          var s0;

          if (peg$c94.test(input.charAt(peg$currPos))) {
            s0 = input.charAt(peg$currPos);
            peg$currPos++;
          } else {
            s0 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c95); }
          }

          return s0;
        }

        function peg$parseZs() {
          var s0;

          if (peg$c96.test(input.charAt(peg$currPos))) {
            s0 = input.charAt(peg$currPos);
            peg$currPos++;
          } else {
            s0 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c97); }
          }

          return s0;
        }

        function peg$parse_() {
          var s0, s1;

          s0 = [];
          s1 = peg$parseWhiteSpace();
          while (s1 !== peg$FAILED) {
            s0.push(s1);
            s1 = peg$parseWhiteSpace();
          }

          return s0;
        }

        function peg$parse__() {
          var s0, s1;

          s0 = [];
          s1 = peg$parseWhiteSpace();
          if (s1 === peg$FAILED) {
            s1 = peg$parseLineTerminatorSequence();
          }
          while (s1 !== peg$FAILED) {
            s0.push(s1);
            s1 = peg$parseWhiteSpace();
            if (s1 === peg$FAILED) {
              s1 = peg$parseLineTerminatorSequence();
            }
          }

          return s0;
        }

        function peg$parsePrimaryExpression() {
          var s0, s1, s2, s3, s4, s5;

          s0 = peg$currPos;
          s1 = peg$parseIdentifier();
          if (s1 !== peg$FAILED) {
            peg$savedPos = s0;
            s1 = peg$c98(s1);
          }
          s0 = s1;
          if (s0 === peg$FAILED) {
            s0 = peg$parseLiteral();
            if (s0 === peg$FAILED) {
              s0 = peg$currPos;
              if (input.charCodeAt(peg$currPos) === 40) {
                s1 = peg$c99;
                peg$currPos++;
              } else {
                s1 = peg$FAILED;
                if (peg$silentFails === 0) { peg$fail(peg$c100); }
              }
              if (s1 !== peg$FAILED) {
                s2 = peg$parse__();
                if (s2 !== peg$FAILED) {
                  s3 = peg$parseConditionalExpression();
                  if (s3 !== peg$FAILED) {
                    s4 = peg$parse__();
                    if (s4 !== peg$FAILED) {
                      if (input.charCodeAt(peg$currPos) === 41) {
                        s5 = peg$c101;
                        peg$currPos++;
                      } else {
                        s5 = peg$FAILED;
                        if (peg$silentFails === 0) { peg$fail(peg$c102); }
                      }
                      if (s5 !== peg$FAILED) {
                        peg$savedPos = s0;
                        s1 = peg$c103(s3);
                        s0 = s1;
                      } else {
                        peg$currPos = s0;
                        s0 = peg$FAILED;
                      }
                    } else {
                      peg$currPos = s0;
                      s0 = peg$FAILED;
                    }
                  } else {
                    peg$currPos = s0;
                    s0 = peg$FAILED;
                  }
                } else {
                  peg$currPos = s0;
                  s0 = peg$FAILED;
                }
              } else {
                peg$currPos = s0;
                s0 = peg$FAILED;
              }
            }
          }

          return s0;
        }

        function peg$parseMemberExpression() {
          var s0;

          s0 = peg$parsePrimaryExpression();

          return s0;
        }

        function peg$parseCallExpression() {
          var s0, s1, s2, s3, s4, s5;

          s0 = peg$currPos;
          s1 = peg$currPos;
          s2 = peg$parseMemberExpression();
          if (s2 !== peg$FAILED) {
            s3 = peg$parse__();
            if (s3 !== peg$FAILED) {
              s4 = peg$parseArguments();
              if (s4 !== peg$FAILED) {
                peg$savedPos = s1;
                s2 = peg$c104(s2, s4);
                s1 = s2;
              } else {
                peg$currPos = s1;
                s1 = peg$FAILED;
              }
            } else {
              peg$currPos = s1;
              s1 = peg$FAILED;
            }
          } else {
            peg$currPos = s1;
            s1 = peg$FAILED;
          }
          if (s1 !== peg$FAILED) {
            s2 = [];
            s3 = peg$currPos;
            s4 = peg$parse__();
            if (s4 !== peg$FAILED) {
              s5 = peg$parseArguments();
              if (s5 !== peg$FAILED) {
                peg$savedPos = s3;
                s4 = peg$c105(s1, s5);
                s3 = s4;
              } else {
                peg$currPos = s3;
                s3 = peg$FAILED;
              }
            } else {
              peg$currPos = s3;
              s3 = peg$FAILED;
            }
            while (s3 !== peg$FAILED) {
              s2.push(s3);
              s3 = peg$currPos;
              s4 = peg$parse__();
              if (s4 !== peg$FAILED) {
                s5 = peg$parseArguments();
                if (s5 !== peg$FAILED) {
                  peg$savedPos = s3;
                  s4 = peg$c105(s1, s5);
                  s3 = s4;
                } else {
                  peg$currPos = s3;
                  s3 = peg$FAILED;
                }
              } else {
                peg$currPos = s3;
                s3 = peg$FAILED;
              }
            }
            if (s2 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c106(s1, s2);
              s0 = s1;
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }

          return s0;
        }

        function peg$parseArguments() {
          var s0, s1, s2, s3, s4, s5;

          s0 = peg$currPos;
          if (input.charCodeAt(peg$currPos) === 40) {
            s1 = peg$c99;
            peg$currPos++;
          } else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c100); }
          }
          if (s1 !== peg$FAILED) {
            s2 = peg$parse__();
            if (s2 !== peg$FAILED) {
              s3 = peg$parseArgumentList();
              if (s3 === peg$FAILED) {
                s3 = null;
              }
              if (s3 !== peg$FAILED) {
                s4 = peg$parse__();
                if (s4 !== peg$FAILED) {
                  if (input.charCodeAt(peg$currPos) === 41) {
                    s5 = peg$c101;
                    peg$currPos++;
                  } else {
                    s5 = peg$FAILED;
                    if (peg$silentFails === 0) { peg$fail(peg$c102); }
                  }
                  if (s5 !== peg$FAILED) {
                    peg$savedPos = s0;
                    s1 = peg$c107(s3);
                    s0 = s1;
                  } else {
                    peg$currPos = s0;
                    s0 = peg$FAILED;
                  }
                } else {
                  peg$currPos = s0;
                  s0 = peg$FAILED;
                }
              } else {
                peg$currPos = s0;
                s0 = peg$FAILED;
              }
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }

          return s0;
        }

        function peg$parseArgumentList() {
          var s0, s1, s2, s3, s4, s5, s6, s7;

          s0 = peg$currPos;
          s1 = peg$parseConditionalExpression();
          if (s1 !== peg$FAILED) {
            s2 = [];
            s3 = peg$currPos;
            s4 = peg$parse__();
            if (s4 !== peg$FAILED) {
              if (input.charCodeAt(peg$currPos) === 44) {
                s5 = peg$c108;
                peg$currPos++;
              } else {
                s5 = peg$FAILED;
                if (peg$silentFails === 0) { peg$fail(peg$c109); }
              }
              if (s5 !== peg$FAILED) {
                s6 = peg$parse__();
                if (s6 !== peg$FAILED) {
                  s7 = peg$parseConditionalExpression();
                  if (s7 !== peg$FAILED) {
                    s4 = [s4, s5, s6, s7];
                    s3 = s4;
                  } else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                  }
                } else {
                  peg$currPos = s3;
                  s3 = peg$FAILED;
                }
              } else {
                peg$currPos = s3;
                s3 = peg$FAILED;
              }
            } else {
              peg$currPos = s3;
              s3 = peg$FAILED;
            }
            while (s3 !== peg$FAILED) {
              s2.push(s3);
              s3 = peg$currPos;
              s4 = peg$parse__();
              if (s4 !== peg$FAILED) {
                if (input.charCodeAt(peg$currPos) === 44) {
                  s5 = peg$c108;
                  peg$currPos++;
                } else {
                  s5 = peg$FAILED;
                  if (peg$silentFails === 0) { peg$fail(peg$c109); }
                }
                if (s5 !== peg$FAILED) {
                  s6 = peg$parse__();
                  if (s6 !== peg$FAILED) {
                    s7 = peg$parseConditionalExpression();
                    if (s7 !== peg$FAILED) {
                      s4 = [s4, s5, s6, s7];
                      s3 = s4;
                    } else {
                      peg$currPos = s3;
                      s3 = peg$FAILED;
                    }
                  } else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                  }
                } else {
                  peg$currPos = s3;
                  s3 = peg$FAILED;
                }
              } else {
                peg$currPos = s3;
                s3 = peg$FAILED;
              }
            }
            if (s2 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c110(s1, s2);
              s0 = s1;
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }

          return s0;
        }

        function peg$parseLeftHandSideExpression() {
          var s0;

          s0 = peg$parseCallExpression();
          if (s0 === peg$FAILED) {
            s0 = peg$parseMemberExpression();
          }

          return s0;
        }

        function peg$parseUnaryExpression() {
          var s0, s1, s2, s3;

          s0 = peg$parseLeftHandSideExpression();
          if (s0 === peg$FAILED) {
            s0 = peg$currPos;
            s1 = peg$parseUnaryOperator();
            if (s1 !== peg$FAILED) {
              s2 = peg$parse__();
              if (s2 !== peg$FAILED) {
                s3 = peg$parseUnaryExpression();
                if (s3 !== peg$FAILED) {
                  peg$savedPos = s0;
                  s1 = peg$c111(s1, s3);
                  s0 = s1;
                } else {
                  peg$currPos = s0;
                  s0 = peg$FAILED;
                }
              } else {
                peg$currPos = s0;
                s0 = peg$FAILED;
              }
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          }

          return s0;
        }

        function peg$parseUnaryOperator() {
          var s0, s1;

          if (input.charCodeAt(peg$currPos) === 43) {
            s0 = peg$c112;
            peg$currPos++;
          } else {
            s0 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c113); }
          }
          if (s0 === peg$FAILED) {
            if (input.charCodeAt(peg$currPos) === 45) {
              s0 = peg$c114;
              peg$currPos++;
            } else {
              s0 = peg$FAILED;
              if (peg$silentFails === 0) { peg$fail(peg$c115); }
            }
            if (s0 === peg$FAILED) {
              s0 = peg$currPos;
              if (input.charCodeAt(peg$currPos) === 8722) {
                s1 = peg$c116;
                peg$currPos++;
              } else {
                s1 = peg$FAILED;
                if (peg$silentFails === 0) { peg$fail(peg$c117); }
              }
              if (s1 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c118();
              }
              s0 = s1;
              if (s0 === peg$FAILED) {
                if (input.charCodeAt(peg$currPos) === 33) {
                  s0 = peg$c119;
                  peg$currPos++;
                } else {
                  s0 = peg$FAILED;
                  if (peg$silentFails === 0) { peg$fail(peg$c120); }
                }
              }
            }
          }

          return s0;
        }

        function peg$parsePowerExpression() {
          var s0, s1, s2, s3, s4, s5, s6;

          s0 = peg$currPos;
          s1 = [];
          s2 = peg$currPos;
          s3 = peg$parse__();
          if (s3 !== peg$FAILED) {
            s4 = peg$parseUnaryExpression();
            if (s4 !== peg$FAILED) {
              s5 = peg$parse__();
              if (s5 !== peg$FAILED) {
                s6 = peg$parsePowerOperator();
                if (s6 !== peg$FAILED) {
                  s3 = [s3, s4, s5, s6];
                  s2 = s3;
                } else {
                  peg$currPos = s2;
                  s2 = peg$FAILED;
                }
              } else {
                peg$currPos = s2;
                s2 = peg$FAILED;
              }
            } else {
              peg$currPos = s2;
              s2 = peg$FAILED;
            }
          } else {
            peg$currPos = s2;
            s2 = peg$FAILED;
          }
          while (s2 !== peg$FAILED) {
            s1.push(s2);
            s2 = peg$currPos;
            s3 = peg$parse__();
            if (s3 !== peg$FAILED) {
              s4 = peg$parseUnaryExpression();
              if (s4 !== peg$FAILED) {
                s5 = peg$parse__();
                if (s5 !== peg$FAILED) {
                  s6 = peg$parsePowerOperator();
                  if (s6 !== peg$FAILED) {
                    s3 = [s3, s4, s5, s6];
                    s2 = s3;
                  } else {
                    peg$currPos = s2;
                    s2 = peg$FAILED;
                  }
                } else {
                  peg$currPos = s2;
                  s2 = peg$FAILED;
                }
              } else {
                peg$currPos = s2;
                s2 = peg$FAILED;
              }
            } else {
              peg$currPos = s2;
              s2 = peg$FAILED;
            }
          }
          if (s1 !== peg$FAILED) {
            s2 = peg$parseUnaryExpression();
            if (s2 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c121(s1, s2);
              s0 = s1;
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }

          return s0;
        }

        function peg$parsePowerOperator() {
          var s0;

          if (input.charCodeAt(peg$currPos) === 94) {
            s0 = peg$c122;
            peg$currPos++;
          } else {
            s0 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c123); }
          }

          return s0;
        }

        function peg$parseMultiplicativeExpression() {
          var s0, s1, s2, s3, s4, s5, s6, s7;

          s0 = peg$currPos;
          s1 = peg$parsePowerExpression();
          if (s1 !== peg$FAILED) {
            s2 = [];
            s3 = peg$currPos;
            s4 = peg$parse__();
            if (s4 !== peg$FAILED) {
              s5 = peg$parseMultiplicativeOperator();
              if (s5 !== peg$FAILED) {
                s6 = peg$parse__();
                if (s6 !== peg$FAILED) {
                  s7 = peg$parsePowerExpression();
                  if (s7 !== peg$FAILED) {
                    s4 = [s4, s5, s6, s7];
                    s3 = s4;
                  } else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                  }
                } else {
                  peg$currPos = s3;
                  s3 = peg$FAILED;
                }
              } else {
                peg$currPos = s3;
                s3 = peg$FAILED;
              }
            } else {
              peg$currPos = s3;
              s3 = peg$FAILED;
            }
            while (s3 !== peg$FAILED) {
              s2.push(s3);
              s3 = peg$currPos;
              s4 = peg$parse__();
              if (s4 !== peg$FAILED) {
                s5 = peg$parseMultiplicativeOperator();
                if (s5 !== peg$FAILED) {
                  s6 = peg$parse__();
                  if (s6 !== peg$FAILED) {
                    s7 = peg$parsePowerExpression();
                    if (s7 !== peg$FAILED) {
                      s4 = [s4, s5, s6, s7];
                      s3 = s4;
                    } else {
                      peg$currPos = s3;
                      s3 = peg$FAILED;
                    }
                  } else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                  }
                } else {
                  peg$currPos = s3;
                  s3 = peg$FAILED;
                }
              } else {
                peg$currPos = s3;
                s3 = peg$FAILED;
              }
            }
            if (s2 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c124(s1, s2);
              s0 = s1;
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }

          return s0;
        }

        function peg$parseMultiplicativeOperator() {
          var s0, s1, s2, s3;

          s0 = peg$currPos;
          if (input.charCodeAt(peg$currPos) === 42) {
            s1 = peg$c125;
            peg$currPos++;
          } else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c126); }
          }
          if (s1 === peg$FAILED) {
            if (input.charCodeAt(peg$currPos) === 47) {
              s1 = peg$c127;
              peg$currPos++;
            } else {
              s1 = peg$FAILED;
              if (peg$silentFails === 0) { peg$fail(peg$c128); }
            }
            if (s1 === peg$FAILED) {
              if (input.charCodeAt(peg$currPos) === 37) {
                s1 = peg$c129;
                peg$currPos++;
              } else {
                s1 = peg$FAILED;
                if (peg$silentFails === 0) { peg$fail(peg$c130); }
              }
            }
          }
          if (s1 !== peg$FAILED) {
            s2 = peg$currPos;
            peg$silentFails++;
            if (input.charCodeAt(peg$currPos) === 61) {
              s3 = peg$c131;
              peg$currPos++;
            } else {
              s3 = peg$FAILED;
              if (peg$silentFails === 0) { peg$fail(peg$c132); }
            }
            peg$silentFails--;
            if (s3 === peg$FAILED) {
              s2 = void 0;
            } else {
              peg$currPos = s2;
              s2 = peg$FAILED;
            }
            if (s2 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c133(s1);
              s0 = s1;
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }
          if (s0 === peg$FAILED) {
            s0 = peg$currPos;
            if (input.charCodeAt(peg$currPos) === 215) {
              s1 = peg$c134;
              peg$currPos++;
            } else {
              s1 = peg$FAILED;
              if (peg$silentFails === 0) { peg$fail(peg$c135); }
            }
            if (s1 !== peg$FAILED) {
              s2 = peg$currPos;
              peg$silentFails++;
              if (input.charCodeAt(peg$currPos) === 61) {
                s3 = peg$c131;
                peg$currPos++;
              } else {
                s3 = peg$FAILED;
                if (peg$silentFails === 0) { peg$fail(peg$c132); }
              }
              peg$silentFails--;
              if (s3 === peg$FAILED) {
                s2 = void 0;
              } else {
                peg$currPos = s2;
                s2 = peg$FAILED;
              }
              if (s2 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c136();
                s0 = s1;
              } else {
                peg$currPos = s0;
                s0 = peg$FAILED;
              }
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
            if (s0 === peg$FAILED) {
              s0 = peg$currPos;
              if (input.charCodeAt(peg$currPos) === 247) {
                s1 = peg$c137;
                peg$currPos++;
              } else {
                s1 = peg$FAILED;
                if (peg$silentFails === 0) { peg$fail(peg$c138); }
              }
              if (s1 !== peg$FAILED) {
                s2 = peg$currPos;
                peg$silentFails++;
                if (input.charCodeAt(peg$currPos) === 61) {
                  s3 = peg$c131;
                  peg$currPos++;
                } else {
                  s3 = peg$FAILED;
                  if (peg$silentFails === 0) { peg$fail(peg$c132); }
                }
                peg$silentFails--;
                if (s3 === peg$FAILED) {
                  s2 = void 0;
                } else {
                  peg$currPos = s2;
                  s2 = peg$FAILED;
                }
                if (s2 !== peg$FAILED) {
                  peg$savedPos = s0;
                  s1 = peg$c139();
                  s0 = s1;
                } else {
                  peg$currPos = s0;
                  s0 = peg$FAILED;
                }
              } else {
                peg$currPos = s0;
                s0 = peg$FAILED;
              }
              if (s0 === peg$FAILED) {
                s0 = peg$currPos;
                if (input.charCodeAt(peg$currPos) === 8901) {
                  s1 = peg$c140;
                  peg$currPos++;
                } else {
                  s1 = peg$FAILED;
                  if (peg$silentFails === 0) { peg$fail(peg$c141); }
                }
                if (s1 !== peg$FAILED) {
                  s2 = peg$currPos;
                  peg$silentFails++;
                  if (input.charCodeAt(peg$currPos) === 61) {
                    s3 = peg$c131;
                    peg$currPos++;
                  } else {
                    s3 = peg$FAILED;
                    if (peg$silentFails === 0) { peg$fail(peg$c132); }
                  }
                  peg$silentFails--;
                  if (s3 === peg$FAILED) {
                    s2 = void 0;
                  } else {
                    peg$currPos = s2;
                    s2 = peg$FAILED;
                  }
                  if (s2 !== peg$FAILED) {
                    peg$savedPos = s0;
                    s1 = peg$c136();
                    s0 = s1;
                  } else {
                    peg$currPos = s0;
                    s0 = peg$FAILED;
                  }
                } else {
                  peg$currPos = s0;
                  s0 = peg$FAILED;
                }
              }
            }
          }

          return s0;
        }

        function peg$parseAdditiveExpression() {
          var s0, s1, s2, s3, s4, s5, s6, s7;

          s0 = peg$currPos;
          s1 = peg$parseMultiplicativeExpression();
          if (s1 !== peg$FAILED) {
            s2 = [];
            s3 = peg$currPos;
            s4 = peg$parse__();
            if (s4 !== peg$FAILED) {
              s5 = peg$parseAdditiveOperator();
              if (s5 !== peg$FAILED) {
                s6 = peg$parse__();
                if (s6 !== peg$FAILED) {
                  s7 = peg$parseMultiplicativeExpression();
                  if (s7 !== peg$FAILED) {
                    s4 = [s4, s5, s6, s7];
                    s3 = s4;
                  } else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                  }
                } else {
                  peg$currPos = s3;
                  s3 = peg$FAILED;
                }
              } else {
                peg$currPos = s3;
                s3 = peg$FAILED;
              }
            } else {
              peg$currPos = s3;
              s3 = peg$FAILED;
            }
            while (s3 !== peg$FAILED) {
              s2.push(s3);
              s3 = peg$currPos;
              s4 = peg$parse__();
              if (s4 !== peg$FAILED) {
                s5 = peg$parseAdditiveOperator();
                if (s5 !== peg$FAILED) {
                  s6 = peg$parse__();
                  if (s6 !== peg$FAILED) {
                    s7 = peg$parseMultiplicativeExpression();
                    if (s7 !== peg$FAILED) {
                      s4 = [s4, s5, s6, s7];
                      s3 = s4;
                    } else {
                      peg$currPos = s3;
                      s3 = peg$FAILED;
                    }
                  } else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                  }
                } else {
                  peg$currPos = s3;
                  s3 = peg$FAILED;
                }
              } else {
                peg$currPos = s3;
                s3 = peg$FAILED;
              }
            }
            if (s2 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c124(s1, s2);
              s0 = s1;
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }

          return s0;
        }

        function peg$parseAdditiveOperator() {
          var s0, s1, s2, s3;

          s0 = peg$currPos;
          if (input.charCodeAt(peg$currPos) === 43) {
            s1 = peg$c112;
            peg$currPos++;
          } else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c113); }
          }
          if (s1 !== peg$FAILED) {
            s2 = peg$currPos;
            peg$silentFails++;
            if (input.charCodeAt(peg$currPos) === 43) {
              s3 = peg$c112;
              peg$currPos++;
            } else {
              s3 = peg$FAILED;
              if (peg$silentFails === 0) { peg$fail(peg$c113); }
            }
            if (s3 === peg$FAILED) {
              if (input.charCodeAt(peg$currPos) === 61) {
                s3 = peg$c131;
                peg$currPos++;
              } else {
                s3 = peg$FAILED;
                if (peg$silentFails === 0) { peg$fail(peg$c132); }
              }
            }
            peg$silentFails--;
            if (s3 === peg$FAILED) {
              s2 = void 0;
            } else {
              peg$currPos = s2;
              s2 = peg$FAILED;
            }
            if (s2 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c142();
              s0 = s1;
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }
          if (s0 === peg$FAILED) {
            s0 = peg$currPos;
            if (input.charCodeAt(peg$currPos) === 45) {
              s1 = peg$c114;
              peg$currPos++;
            } else {
              s1 = peg$FAILED;
              if (peg$silentFails === 0) { peg$fail(peg$c115); }
            }
            if (s1 !== peg$FAILED) {
              s2 = peg$currPos;
              peg$silentFails++;
              if (input.charCodeAt(peg$currPos) === 45) {
                s3 = peg$c114;
                peg$currPos++;
              } else {
                s3 = peg$FAILED;
                if (peg$silentFails === 0) { peg$fail(peg$c115); }
              }
              if (s3 === peg$FAILED) {
                if (input.charCodeAt(peg$currPos) === 61) {
                  s3 = peg$c131;
                  peg$currPos++;
                } else {
                  s3 = peg$FAILED;
                  if (peg$silentFails === 0) { peg$fail(peg$c132); }
                }
              }
              peg$silentFails--;
              if (s3 === peg$FAILED) {
                s2 = void 0;
              } else {
                peg$currPos = s2;
                s2 = peg$FAILED;
              }
              if (s2 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c118();
                s0 = s1;
              } else {
                peg$currPos = s0;
                s0 = peg$FAILED;
              }
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
            if (s0 === peg$FAILED) {
              s0 = peg$currPos;
              if (input.charCodeAt(peg$currPos) === 8722) {
                s1 = peg$c116;
                peg$currPos++;
              } else {
                s1 = peg$FAILED;
                if (peg$silentFails === 0) { peg$fail(peg$c117); }
              }
              if (s1 !== peg$FAILED) {
                s2 = peg$currPos;
                peg$silentFails++;
                if (input.charCodeAt(peg$currPos) === 8722) {
                  s3 = peg$c116;
                  peg$currPos++;
                } else {
                  s3 = peg$FAILED;
                  if (peg$silentFails === 0) { peg$fail(peg$c117); }
                }
                if (s3 === peg$FAILED) {
                  if (input.charCodeAt(peg$currPos) === 61) {
                    s3 = peg$c131;
                    peg$currPos++;
                  } else {
                    s3 = peg$FAILED;
                    if (peg$silentFails === 0) { peg$fail(peg$c132); }
                  }
                }
                peg$silentFails--;
                if (s3 === peg$FAILED) {
                  s2 = void 0;
                } else {
                  peg$currPos = s2;
                  s2 = peg$FAILED;
                }
                if (s2 !== peg$FAILED) {
                  peg$savedPos = s0;
                  s1 = peg$c118();
                  s0 = s1;
                } else {
                  peg$currPos = s0;
                  s0 = peg$FAILED;
                }
              } else {
                peg$currPos = s0;
                s0 = peg$FAILED;
              }
            }
          }

          return s0;
        }

        function peg$parseRelationalExpression() {
          var s0, s1, s2, s3, s4, s5, s6, s7;

          s0 = peg$currPos;
          s1 = peg$parseAdditiveExpression();
          if (s1 !== peg$FAILED) {
            s2 = [];
            s3 = peg$currPos;
            s4 = peg$parse__();
            if (s4 !== peg$FAILED) {
              s5 = peg$parseRelationalOperator();
              if (s5 !== peg$FAILED) {
                s6 = peg$parse__();
                if (s6 !== peg$FAILED) {
                  s7 = peg$parseAdditiveExpression();
                  if (s7 !== peg$FAILED) {
                    s4 = [s4, s5, s6, s7];
                    s3 = s4;
                  } else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                  }
                } else {
                  peg$currPos = s3;
                  s3 = peg$FAILED;
                }
              } else {
                peg$currPos = s3;
                s3 = peg$FAILED;
              }
            } else {
              peg$currPos = s3;
              s3 = peg$FAILED;
            }
            while (s3 !== peg$FAILED) {
              s2.push(s3);
              s3 = peg$currPos;
              s4 = peg$parse__();
              if (s4 !== peg$FAILED) {
                s5 = peg$parseRelationalOperator();
                if (s5 !== peg$FAILED) {
                  s6 = peg$parse__();
                  if (s6 !== peg$FAILED) {
                    s7 = peg$parseAdditiveExpression();
                    if (s7 !== peg$FAILED) {
                      s4 = [s4, s5, s6, s7];
                      s3 = s4;
                    } else {
                      peg$currPos = s3;
                      s3 = peg$FAILED;
                    }
                  } else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                  }
                } else {
                  peg$currPos = s3;
                  s3 = peg$FAILED;
                }
              } else {
                peg$currPos = s3;
                s3 = peg$FAILED;
              }
            }
            if (s2 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c124(s1, s2);
              s0 = s1;
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }

          return s0;
        }

        function peg$parseRelationalOperator() {
          var s0, s1;

          if (input.substr(peg$currPos, 2) === peg$c143) {
            s0 = peg$c143;
            peg$currPos += 2;
          } else {
            s0 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c144); }
          }
          if (s0 === peg$FAILED) {
            if (input.substr(peg$currPos, 2) === peg$c145) {
              s0 = peg$c145;
              peg$currPos += 2;
            } else {
              s0 = peg$FAILED;
              if (peg$silentFails === 0) { peg$fail(peg$c146); }
            }
            if (s0 === peg$FAILED) {
              if (input.charCodeAt(peg$currPos) === 60) {
                s0 = peg$c147;
                peg$currPos++;
              } else {
                s0 = peg$FAILED;
                if (peg$silentFails === 0) { peg$fail(peg$c148); }
              }
              if (s0 === peg$FAILED) {
                if (input.charCodeAt(peg$currPos) === 62) {
                  s0 = peg$c149;
                  peg$currPos++;
                } else {
                  s0 = peg$FAILED;
                  if (peg$silentFails === 0) { peg$fail(peg$c150); }
                }
                if (s0 === peg$FAILED) {
                  s0 = peg$currPos;
                  if (input.charCodeAt(peg$currPos) === 8804) {
                    s1 = peg$c151;
                    peg$currPos++;
                  } else {
                    s1 = peg$FAILED;
                    if (peg$silentFails === 0) { peg$fail(peg$c152); }
                  }
                  if (s1 !== peg$FAILED) {
                    peg$savedPos = s0;
                    s1 = peg$c153();
                  }
                  s0 = s1;
                  if (s0 === peg$FAILED) {
                    s0 = peg$currPos;
                    if (input.charCodeAt(peg$currPos) === 8805) {
                      s1 = peg$c154;
                      peg$currPos++;
                    } else {
                      s1 = peg$FAILED;
                      if (peg$silentFails === 0) { peg$fail(peg$c155); }
                    }
                    if (s1 !== peg$FAILED) {
                      peg$savedPos = s0;
                      s1 = peg$c156();
                    }
                    s0 = s1;
                  }
                }
              }
            }
          }

          return s0;
        }

        function peg$parseEqualityExpression() {
          var s0, s1, s2, s3, s4, s5, s6, s7;

          s0 = peg$currPos;
          s1 = peg$parseRelationalExpression();
          if (s1 !== peg$FAILED) {
            s2 = [];
            s3 = peg$currPos;
            s4 = peg$parse__();
            if (s4 !== peg$FAILED) {
              s5 = peg$parseEqualityOperator();
              if (s5 !== peg$FAILED) {
                s6 = peg$parse__();
                if (s6 !== peg$FAILED) {
                  s7 = peg$parseRelationalExpression();
                  if (s7 !== peg$FAILED) {
                    s4 = [s4, s5, s6, s7];
                    s3 = s4;
                  } else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                  }
                } else {
                  peg$currPos = s3;
                  s3 = peg$FAILED;
                }
              } else {
                peg$currPos = s3;
                s3 = peg$FAILED;
              }
            } else {
              peg$currPos = s3;
              s3 = peg$FAILED;
            }
            while (s3 !== peg$FAILED) {
              s2.push(s3);
              s3 = peg$currPos;
              s4 = peg$parse__();
              if (s4 !== peg$FAILED) {
                s5 = peg$parseEqualityOperator();
                if (s5 !== peg$FAILED) {
                  s6 = peg$parse__();
                  if (s6 !== peg$FAILED) {
                    s7 = peg$parseRelationalExpression();
                    if (s7 !== peg$FAILED) {
                      s4 = [s4, s5, s6, s7];
                      s3 = s4;
                    } else {
                      peg$currPos = s3;
                      s3 = peg$FAILED;
                    }
                  } else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                  }
                } else {
                  peg$currPos = s3;
                  s3 = peg$FAILED;
                }
              } else {
                peg$currPos = s3;
                s3 = peg$FAILED;
              }
            }
            if (s2 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c124(s1, s2);
              s0 = s1;
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }

          return s0;
        }

        function peg$parseEqualityOperator() {
          var s0, s1;

          s0 = peg$currPos;
          if (input.charCodeAt(peg$currPos) === 61) {
            s1 = peg$c131;
            peg$currPos++;
          } else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c132); }
          }
          if (s1 !== peg$FAILED) {
            peg$savedPos = s0;
            s1 = peg$c157();
          }
          s0 = s1;
          if (s0 === peg$FAILED) {
            s0 = peg$currPos;
            if (input.substr(peg$currPos, 2) === peg$c158) {
              s1 = peg$c158;
              peg$currPos += 2;
            } else {
              s1 = peg$FAILED;
              if (peg$silentFails === 0) { peg$fail(peg$c159); }
            }
            if (s1 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c160();
            }
            s0 = s1;
            if (s0 === peg$FAILED) {
              s0 = peg$currPos;
              if (input.charCodeAt(peg$currPos) === 8800) {
                s1 = peg$c161;
                peg$currPos++;
              } else {
                s1 = peg$FAILED;
                if (peg$silentFails === 0) { peg$fail(peg$c162); }
              }
              if (s1 !== peg$FAILED) {
                peg$savedPos = s0;
                s1 = peg$c160();
              }
              s0 = s1;
            }
          }

          return s0;
        }

        function peg$parseLogicalANDExpression() {
          var s0, s1, s2, s3, s4, s5, s6, s7;

          s0 = peg$currPos;
          s1 = peg$parseEqualityExpression();
          if (s1 !== peg$FAILED) {
            s2 = [];
            s3 = peg$currPos;
            s4 = peg$parse__();
            if (s4 !== peg$FAILED) {
              s5 = peg$parseLogicalANDOperator();
              if (s5 !== peg$FAILED) {
                s6 = peg$parse__();
                if (s6 !== peg$FAILED) {
                  s7 = peg$parseEqualityExpression();
                  if (s7 !== peg$FAILED) {
                    s4 = [s4, s5, s6, s7];
                    s3 = s4;
                  } else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                  }
                } else {
                  peg$currPos = s3;
                  s3 = peg$FAILED;
                }
              } else {
                peg$currPos = s3;
                s3 = peg$FAILED;
              }
            } else {
              peg$currPos = s3;
              s3 = peg$FAILED;
            }
            while (s3 !== peg$FAILED) {
              s2.push(s3);
              s3 = peg$currPos;
              s4 = peg$parse__();
              if (s4 !== peg$FAILED) {
                s5 = peg$parseLogicalANDOperator();
                if (s5 !== peg$FAILED) {
                  s6 = peg$parse__();
                  if (s6 !== peg$FAILED) {
                    s7 = peg$parseEqualityExpression();
                    if (s7 !== peg$FAILED) {
                      s4 = [s4, s5, s6, s7];
                      s3 = s4;
                    } else {
                      peg$currPos = s3;
                      s3 = peg$FAILED;
                    }
                  } else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                  }
                } else {
                  peg$currPos = s3;
                  s3 = peg$FAILED;
                }
              } else {
                peg$currPos = s3;
                s3 = peg$FAILED;
              }
            }
            if (s2 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c163(s1, s2);
              s0 = s1;
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }

          return s0;
        }

        function peg$parseLogicalANDOperator() {
          var s0, s1, s2, s3;

          s0 = peg$currPos;
          if (input.charCodeAt(peg$currPos) === 38) {
            s1 = peg$c164;
            peg$currPos++;
          } else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c165); }
          }
          if (s1 !== peg$FAILED) {
            s2 = peg$currPos;
            peg$silentFails++;
            if (input.charCodeAt(peg$currPos) === 61) {
              s3 = peg$c131;
              peg$currPos++;
            } else {
              s3 = peg$FAILED;
              if (peg$silentFails === 0) { peg$fail(peg$c132); }
            }
            peg$silentFails--;
            if (s3 === peg$FAILED) {
              s2 = void 0;
            } else {
              peg$currPos = s2;
              s2 = peg$FAILED;
            }
            if (s2 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c72();
              s0 = s1;
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }
          if (s0 === peg$FAILED) {
            s0 = peg$parseAndToken();
          }

          return s0;
        }

        function peg$parseLogicalORExpression() {
          var s0, s1, s2, s3, s4, s5, s6, s7;

          s0 = peg$currPos;
          s1 = peg$parseLogicalANDExpression();
          if (s1 !== peg$FAILED) {
            s2 = [];
            s3 = peg$currPos;
            s4 = peg$parse__();
            if (s4 !== peg$FAILED) {
              s5 = peg$parseLogicalOROperator();
              if (s5 !== peg$FAILED) {
                s6 = peg$parse__();
                if (s6 !== peg$FAILED) {
                  s7 = peg$parseLogicalANDExpression();
                  if (s7 !== peg$FAILED) {
                    s4 = [s4, s5, s6, s7];
                    s3 = s4;
                  } else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                  }
                } else {
                  peg$currPos = s3;
                  s3 = peg$FAILED;
                }
              } else {
                peg$currPos = s3;
                s3 = peg$FAILED;
              }
            } else {
              peg$currPos = s3;
              s3 = peg$FAILED;
            }
            while (s3 !== peg$FAILED) {
              s2.push(s3);
              s3 = peg$currPos;
              s4 = peg$parse__();
              if (s4 !== peg$FAILED) {
                s5 = peg$parseLogicalOROperator();
                if (s5 !== peg$FAILED) {
                  s6 = peg$parse__();
                  if (s6 !== peg$FAILED) {
                    s7 = peg$parseLogicalANDExpression();
                    if (s7 !== peg$FAILED) {
                      s4 = [s4, s5, s6, s7];
                      s3 = s4;
                    } else {
                      peg$currPos = s3;
                      s3 = peg$FAILED;
                    }
                  } else {
                    peg$currPos = s3;
                    s3 = peg$FAILED;
                  }
                } else {
                  peg$currPos = s3;
                  s3 = peg$FAILED;
                }
              } else {
                peg$currPos = s3;
                s3 = peg$FAILED;
              }
            }
            if (s2 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c166(s1, s2);
              s0 = s1;
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }

          return s0;
        }

        function peg$parseLogicalOROperator() {
          var s0, s1, s2, s3;

          s0 = peg$currPos;
          if (input.charCodeAt(peg$currPos) === 124) {
            s1 = peg$c167;
            peg$currPos++;
          } else {
            s1 = peg$FAILED;
            if (peg$silentFails === 0) { peg$fail(peg$c168); }
          }
          if (s1 !== peg$FAILED) {
            s2 = peg$currPos;
            peg$silentFails++;
            if (input.charCodeAt(peg$currPos) === 61) {
              s3 = peg$c131;
              peg$currPos++;
            } else {
              s3 = peg$FAILED;
              if (peg$silentFails === 0) { peg$fail(peg$c132); }
            }
            peg$silentFails--;
            if (s3 === peg$FAILED) {
              s2 = void 0;
            } else {
              peg$currPos = s2;
              s2 = peg$FAILED;
            }
            if (s2 !== peg$FAILED) {
              peg$savedPos = s0;
              s1 = peg$c77();
              s0 = s1;
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }
          if (s0 === peg$FAILED) {
            s0 = peg$parseOrToken();
          }

          return s0;
        }

        function peg$parseConditionalExpression() {
          var s0, s1, s2, s3, s4, s5, s6, s7, s8, s9;

          s0 = peg$currPos;
          s1 = peg$parseLogicalORExpression();
          if (s1 !== peg$FAILED) {
            s2 = peg$parse__();
            if (s2 !== peg$FAILED) {
              if (input.charCodeAt(peg$currPos) === 63) {
                s3 = peg$c169;
                peg$currPos++;
              } else {
                s3 = peg$FAILED;
                if (peg$silentFails === 0) { peg$fail(peg$c170); }
              }
              if (s3 !== peg$FAILED) {
                s4 = peg$parse__();
                if (s4 !== peg$FAILED) {
                  s5 = peg$parseConditionalExpression();
                  if (s5 !== peg$FAILED) {
                    s6 = peg$parse__();
                    if (s6 !== peg$FAILED) {
                      if (input.charCodeAt(peg$currPos) === 58) {
                        s7 = peg$c171;
                        peg$currPos++;
                      } else {
                        s7 = peg$FAILED;
                        if (peg$silentFails === 0) { peg$fail(peg$c172); }
                      }
                      if (s7 !== peg$FAILED) {
                        s8 = peg$parse__();
                        if (s8 !== peg$FAILED) {
                          s9 = peg$parseConditionalExpression();
                          if (s9 !== peg$FAILED) {
                            peg$savedPos = s0;
                            s1 = peg$c173(s1, s5, s9);
                            s0 = s1;
                          } else {
                            peg$currPos = s0;
                            s0 = peg$FAILED;
                          }
                        } else {
                          peg$currPos = s0;
                          s0 = peg$FAILED;
                        }
                      } else {
                        peg$currPos = s0;
                        s0 = peg$FAILED;
                      }
                    } else {
                      peg$currPos = s0;
                      s0 = peg$FAILED;
                    }
                  } else {
                    peg$currPos = s0;
                    s0 = peg$FAILED;
                  }
                } else {
                  peg$currPos = s0;
                  s0 = peg$FAILED;
                }
              } else {
                peg$currPos = s0;
                s0 = peg$FAILED;
              }
            } else {
              peg$currPos = s0;
              s0 = peg$FAILED;
            }
          } else {
            peg$currPos = s0;
            s0 = peg$FAILED;
          }
          if (s0 === peg$FAILED) {
            s0 = peg$parseLogicalORExpression();
          }

          return s0;
        }

        peg$result = peg$startRuleFunction();

        if (peg$result !== peg$FAILED && peg$currPos === input.length) {
          return peg$result;
        } else {
          if (peg$result !== peg$FAILED && peg$currPos < input.length) {
            peg$fail(peg$endExpectation());
          }

          throw peg$buildStructuredError(
              peg$maxFailExpected,
              peg$maxFailPos < input.length ? input.charAt(peg$maxFailPos) : null,
              peg$maxFailPos < input.length
                  ? peg$computeLocation(peg$maxFailPos, peg$maxFailPos + 1)
                  : peg$computeLocation(peg$maxFailPos, peg$maxFailPos)
          );
        }
      }

      return {
        SyntaxError: peg$SyntaxError,
        parse:       peg$parse
      };
    })();

/* >>>>>>>>>> BEGIN source/utilities/geojson_utils.js */
// ==========================================================================
//                            DG.GeojsonUtils
//
//  A collection of utilities for working with Geojson objects.
//
//  Author: William Finzer
//  Copyright (c) 2017 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

DG.GeojsonUtils = {

  /**
   *
   * @param iBoundaryValue { {String} | {Object}}
   * @return {{Object} | null}
   */
  boundaryObjectFromBoundaryValue: function( iBoundaryValue) {
    if( typeof iBoundaryValue === 'object') {
      return iBoundaryValue;
    }
    else if((typeof iBoundaryValue === 'string') && iBoundaryValue.startsWith('{')) // Assume it's the geojson itself
    {
      var tObject;
      try{
        tObject = JSON.parse(iBoundaryValue);
      }
      catch (er) {
        console.log( er);
      }
      return {jsonBoundaryObject: tObject};
    }
    else
      return null;
  }

};


/* >>>>>>>>>> BEGIN source/formula/geojson_functions.js */
// ==========================================================================
//                        GeoJSON Functions
//
//  Author:   William Finzer
//
//  Copyright (c) 2017 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('formula/function_registry');
sc_require('utilities/geojson_utils');

/**
  Implements functions that lookup or manipulate geojson boundaries and registers them with the FunctionRegistry.
 */
DG.functionRegistry.registerFunctions((function() {

  return {
    /**
      Returns true if the specified string contains the specified target string
      as its initial characters.
      @param    {String}  iCollectionName - the name of the online collection of boundaries to look in
      @param    {String}  iBoundaryName - the name of the desired boundary
      @returns  {Object}  the object that can be passed to the map to display a boundary
     */
    'lookupBoundary': {
      minArgs:2, maxArgs:2, category: 'DG.Formula.FuncCategoryLookup',
      evalFn: function(iBoundaryMap, iBoundaryName) {
        if (iBoundaryMap instanceof Error) throw iBoundaryMap;
        if (iBoundaryName instanceof Error) throw iBoundaryName;
        if (!iBoundaryMap || !iBoundaryName) return '';
        if (!(iBoundaryMap instanceof DG.BoundaryMap)) throw new DG.TypeError();
        return iBoundaryMap.map[iBoundaryName.toString().toLowerCase()] || '';
      }
    }

  };
})());

/* >>>>>>>>>> BEGIN source/formula/logic_functions.js */
// ==========================================================================
//                          Basic Functions
//
//  Author:   William Finzer
//
//  Copyright (c) 2021 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
sc_require('formula/function_registry');

/**
  Implements the basic builtin functions and registers them with the FunctionRegistry.
 */
DG.functionRegistry.registerFunctions((function() {

  return {
    /**
      Coerces its argument to a boolean value.
      @param    {Object}  x The argument to be coerced to boolean
      @returns  {Boolean} The converted boolean value
     */
    'boolean': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryLogic',
      evalFn: function(x) {
        return SC.empty(x) ? '' :
            !(x === false || (typeof x === 'string' && x.toLowerCase() === 'false') || x === 0 || x === '0');
      }
    },

    'isBoolean': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryLogic',
      evalFn: function(x) {
        if (typeof x === 'string') {
          x = x.toLowerCase();
        }
        return [true, false, 'true', 'false'].indexOf(x) >=0;
      }
    },

    'isBoundary': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryLogic',
      evalFn: function(x) {
        return typeof x === 'object' && x.hasOwnProperty('jsonBoundaryObject');
      }
    },

    'isColor': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryLogic',
      evalFn: function(x) {
        return DG.ColorUtilities.isColorSpecString(x);
      }
    },

    'isDate': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryLogic',
      evalFn: function(x) {
        return DG.isDateString(x) || DG.isDate(x);
      }
    },

    'isFinite': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryLogic',
      evalFn: function(x) { return DG.isFinite(x); }
    },

    'isMissing': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryLogic',
      evalFn: function(x) { return x==='' || SC.none(x); }
    },

    'isNumber': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryLogic',
      evalFn: function(x) { return DG.isNumeric(x); }
    }
  };
})());

/* >>>>>>>>>> BEGIN source/formula/lookup_agg_fns.js */
// ==========================================================================
//                    Lookup Aggregate Functions
//  
//  Author:   Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('formula/aggregate_function');
sc_require('formula/function_registry');

/** @class DG.LookupAggFns

  The DG.LookupAggFns object implements aggregate and semi-aggregate
  functions that evaluate the arguments in the context of other cases.
  These functions potentially include first(), last(), prev(), next(), etc.
 */
DG.functionRegistry.registerAggregates({

  /**
    first(expr)
    Returns the value of its argument for the first case in its game/run, or
    the first game/run itself, depending on the context in which it is used.
   */
  first: DG.AggregateFunction.create({

    category: 'DG.Formula.FuncCategoryLookup',
  
    requiredArgs: { min: 1, max: 2 },

    isCaseIndexDependent: function() {
      return true;
    },

    evaluate: function( iContext, iEvalContext, iInstance) {
      var valueFn = iInstance.argFns[0],
          filterFn = iInstance.argFns[1];

      // Find the first of the specified cases which passes the filter
      function getFirstFilteredCase(iCases) {
        if (!iCases) return null;
        if (!filterFn) return iCases.firstObject();

        var i, tCase, count = iCases.get('length');
        for (i = 0; i < count; ++i) {
          tCase = iCases.objectAt(i);
          if (filterFn(iContext, { _case_: tCase, _id_: tCase.get('id') }))
            return tCase;
        }
      }
      
      // The appropriate evaluation context for the first() argument
      // is the first case, i.e. the case at index 0.
      function getFirstEvalContext( iContext, iEvalContext) {
        var iCase = iEvalContext._case_,
            parentCase = iCase && iCase.get('parent'),
            siblings = parentCase ? parentCase.get('children')
                                  : (iContext && iContext.getPath('collection.cases')),
            children = iCase && iCase.get('children'),
            firstCase = getFirstFilteredCase(siblings),
            tmpEvalContext = { _caseMap_: {} };
        // The appropriate first case depends on the attribute argument.
        // We stash a map of potential first cases into the evaluation context
        // and then upstream clients can choose the appropriate one.
        if (firstCase) {
          tmpEvalContext._caseMap_[firstCase.getPath('collection.id')] = firstCase;
        }
        while (children && children.length > 0) {
          firstCase = getFirstFilteredCase(children);
          if (firstCase) {
            var childCollectionID = firstCase.getPath('collection.id');
            tmpEvalContext._caseMap_[childCollectionID] = firstCase;
          }
          children = firstCase && firstCase.get('children');
        }
        for (; parentCase; parentCase = parentCase.get('parent')) {
          var parentCollectionID = parentCase.getPath('collection.id');
          tmpEvalContext._caseMap_[parentCollectionID] = parentCase;
        }
        tmpEvalContext._id_ = firstCase && firstCase.get('id');
        tmpEvalContext._case_ = firstCase;
        return tmpEvalContext;
      }
      
      var firstEvalContext = valueFn && getFirstEvalContext( iContext, iEvalContext);
      if (firstEvalContext && DG.ObjectMap.length(firstEvalContext._caseMap_))
        return valueFn(iContext, firstEvalContext);
    }
  }),
  
  /**
    last(expr)
    Returns the value of its argument for the last case in its game/run, or
    the last game/run itself, depending on the context in which it is used.
   */
  last: DG.AggregateFunction.create({
  
    category: 'DG.Formula.FuncCategoryLookup',
  
    requiredArgs: { min: 1, max: 2 },

    isCaseIndexDependent: function() {
      return true;
    },

    evaluate: function( iContext, iEvalContext, iInstance) {
      var valueFn = iInstance.argFns[0],
          filterFn = iInstance.argFns[1];
      
      // Find the last of the specified cases which passes the filter
      function getLastFilteredCase(iCases) {
        if (!iCases) return null;
        if (!filterFn) return iCases.lastObject();

        var i, tCase, count = iCases.get('length');
        for (i = count - 1; i >= 0; --i) {
          tCase = iCases.objectAt(i);
          if (filterFn(iContext, { _case_: tCase, _id_: tCase.get('id') }))
            return tCase;
        }
      }
      
      // The appropriate evaluation context for the last() argument
      // is the last case, i.e. the case at index [length-1].
      function getLastEvalContext( iContext, iEvalContext) {
        var iCase = iEvalContext._case_,
            parentCase = iCase && iCase.get('parent'),
            siblings = parentCase ? parentCase.get('children')
                                  : (iContext && iContext.getPath('collection.cases')),
            children = iCase && iCase.get('children'),
            lastCase = getLastFilteredCase(siblings),
            tmpEvalContext = { _caseMap_: {} };
        // The appropriate last case depends on the attribute argument.
        // We stash a map of potential last cases into the evaluation context
        // and then upstream clients can choose the appropriate one.
        if (lastCase) {
          tmpEvalContext._caseMap_[lastCase.getPath('collection.id')] = lastCase;
        }
        while (children && children.length > 0) {
          lastCase = getLastFilteredCase(children);
          if (lastCase) {
            var childCollectionID = lastCase.getPath('collection.id');
            tmpEvalContext._caseMap_[childCollectionID] = lastCase;
          }
          children = lastCase && lastCase.get('children');
        }
        for (; parentCase; parentCase = parentCase.get('parent')) {
          var parentCollectionID = parentCase.getPath('collection.id');
          tmpEvalContext._caseMap_[parentCollectionID] = parentCase;
        }
        tmpEvalContext._id_ = lastCase && lastCase.get('id');
        tmpEvalContext._case_ = lastCase;
        return tmpEvalContext;
      }
      
      var lastEvalContext = valueFn && getLastEvalContext( iContext, iEvalContext);
      if (lastEvalContext && DG.ObjectMap.length(lastEvalContext._caseMap_))
        return valueFn( iContext, lastEvalContext);
    }
  }),
  
  /**
    next(expr,[default])
    Returns the value of its argument for the next case in its game/run, or
    the next game/run itself, depending on the context in which it is used.
    Returns the optional [default] value if there is no next case, or null 
    if no default is specified.
   */
  next: DG.AggregateFunction.create({
  
    category: 'DG.Formula.FuncCategoryLookup',
  
    requiredArgs: { min: 1, max: 3 },

    isCaseIndexDependent: function() {
      return true;
    },

    evaluate: function( iContext, iEvalContext, iInstance) {
      var valueFn = iInstance.argFns[0],
          defaultFn = iInstance.argFns[1],
          filterFn = iInstance.argFns[2];
      
      // Find the next case which passes the filter
      function getNextFilteredCase(iCases, iIndex) {
        if (!iCases || (iIndex < 0)) return null;
        if (!filterFn) return iCases.objectAt(iIndex);

        var i, tCase, count = iCases.get('length');
        for (i = iIndex; i < count; ++i) {
          tCase = iCases.objectAt(i);
          if (filterFn(iContext, { _case_: tCase, _id_: tCase.get('id') }))
            return tCase;
        }
      }
      
      // The appropriate evaluation context for the next() argument is
      // the subsequent case, i.e. the case at the subsequent index.
      function getNextEvalContext( iContext, iEvalContext) {
        var iCase = iEvalContext._case_,
            parentCase = iCase && iCase.get('parent'),
            siblings = parentCase ? parentCase.get('children')
                                  : (iContext && iContext.getPath('collection.cases')),
            thisCaseIndex = iContext.getCaseIndex( iEvalContext._id_),  // 1-based index
            nextCase = getNextFilteredCase(siblings, thisCaseIndex),    // 0-based index
            tmpEvalContext = { _caseMap_: {}, _case_: nextCase, _id_: nextCase && nextCase.get('id') };

        // The appropriate next case depends on the attribute argument.
        // We stash a map of potential next cases into the evaluation context
        // and then upstream clients can choose the appropriate one.
        // Note that we we don't support child cases because it's unclear
        // what prev/next refer to among child cases.
        if (nextCase) {
          tmpEvalContext._caseMap_[nextCase.getPath('collection.id')] = nextCase;
          for (; parentCase; parentCase = parentCase.get('parent')) {
            var parentCollectionID = parentCase.getPath('collection.id');
            tmpEvalContext._caseMap_[parentCollectionID] = parentCase;
          }
        }
        return tmpEvalContext;
      }
      
      var nextEvalContext = valueFn && getNextEvalContext( iContext, iEvalContext);
      
      // default to undefined (empty) if no user-specified default
      return nextEvalContext && DG.ObjectMap.length(nextEvalContext._caseMap_)
                    ? valueFn( iContext, nextEvalContext)
                    : defaultFn ? defaultFn( iContext, iEvalContext) : undefined;
    }
  }),
  
  /**
    prev(expr,[default])
    Returns the value of its argument for the previous case in its game/run, or
    the previous game/run itself, depending on the context in which it is used.
    Returns the optional [default] value if there is no next case, or zero if 
    no default is specified.
   */
  prev: DG.AggregateFunction.create({
  
    category: 'DG.Formula.FuncCategoryLookup',
  
    requiredArgs: { min: 1, max: 3 },

    isCaseIndexDependent: function() {
      return true;
    },

    evaluate: function( iContext, iEvalContext, iInstance) {
      var valueFn = iInstance.argFns[0],
          defaultFn = iInstance.argFns[1],
          filterFn = iInstance.argFns[2];
      
      // Find the previous case which passes the filter
      function getPrevFilteredCase(iCases, iIndex) {
        if (!iCases || (iIndex < 0)) return null;
        if (!filterFn) return iCases.objectAt(iIndex);

        var i, tCase;
        for (i = iIndex; i >= 0; --i) {
          tCase = iCases.objectAt(i);
          if (filterFn(iContext, { _case_: tCase, _id_: tCase.get('id') }))
            return tCase;
        }
      }
      
      // The appropriate evaluation context for the prev() argument
      // is the previous case, i.e. the case at the previous index.
      function getPrevEvalContext( iContext, iEvalContext) {
        var iCase = iEvalContext._case_,
            parentCase = iCase && iCase.get('parent'),
            siblings = parentCase ? parentCase.get('children')
                                  : (iContext && iContext.getPath('collection.cases')),
            thisCaseIndex = iContext.getCaseIndex( iEvalContext._id_),    // 1-based index
            prevCase = getPrevFilteredCase(siblings, thisCaseIndex - 2),  // 0-based index
            tmpEvalContext = { _caseMap_: {}, _case_: prevCase, _id_: prevCase && prevCase.get('id')  };

        // The appropriate prev case depends on the attribute argument.
        // We stash a map of potential prev cases into the evaluation context
        // and then upstream clients can choose the appropriate one.
        // Note that we we don't support child cases because it's unclear
        // what prev/next refer to among child cases.
        if (prevCase) {
          tmpEvalContext._caseMap_[prevCase.getPath('collection.id')] = prevCase;
          for (; parentCase; parentCase = parentCase.get('parent')) {
            var parentCollectionID = parentCase.getPath('collection.id');
            tmpEvalContext._caseMap_[parentCollectionID] = parentCase;
          }
        }
        return tmpEvalContext;
      }
      
      var prevEvalContext = valueFn && getPrevEvalContext( iContext, iEvalContext);

      // default to undefined (empty) if no user-specified default
      return prevEvalContext && DG.ObjectMap.length(prevEvalContext._caseMap_)
                    ? valueFn( iContext, prevEvalContext)
                    : defaultFn ? defaultFn( iContext, iEvalContext) : undefined;
    }
  
  })
});

/* >>>>>>>>>> BEGIN source/utilities/data_utilities.js */
// ==========================================================================
//  DG.DataUtilities
//
//  Functions and constants for consistent handling of data values
//  in plots, tables, etc.
//
//  Author:   Craig D. Miller
//
//  Copyright ©2011-13 Scientific Reasoning Research Institute,
//                  University of Massachusetts Amherst
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
/*global nanoid */

/**
    @namespace Data value utility functions
*/
DG.DataUtilities = {
    // add constants here
};

/** Get the standard internal representation of "missing" value,
 *  to be excluded from statistical calculations and plotted points.
 *  See also isMissingValue()
 *  @returns null
 */
DG.DataUtilities.getMissingValue = function() {
    return null;
};

/** Is the given data value a "missing" value, to be excluded
 *  from statistical calculations and plotted points?
 *  See also getMissingValue()
 *  @param iValue
 */
DG.DataUtilities.isMissingValue = function( iValue ) {
    switch( typeof iValue ) {
        case 'string':  return iValue === '';
        case 'number':  return ! isFinite( iValue );
        case 'boolean': return false;
    }
    return true; // null, undefined, objects, functions, etc.
};

/**
  Canonicalize/sanitize case values sent to us from the game.
  Currently, we only check for the "undefined" string, but this is
  the appropriate place to perform any other validation as well.
  @param    iValue  The value sent by the game, e.g. a string value
  @returns          The canonicalized value
 */
DG.DataUtilities.canonicalizeInputValue = function( iValue) {
  // canonicalize null, undefined, and "undefined"
  if ((iValue == null) || (iValue === "undefined")) return "";
  if( typeof iValue !== 'string')
      return iValue;

  var value = iValue.trim();
  return /*DG.isDateString(value) ? DG.createDate(value) :*/ value;
};

/**
  Canonicalize/sanitize case values converted to strings internally.
  Currently, we only check for the "undefined" string and canonical
  (ISO 8601) date strings.
  @param    iValue  The string value to be converted
  @returns          The canonicalized value
 */
DG.DataUtilities.canonicalizeInternalValue = function(iValue) {
  // canonicalize null, undefined, and "undefined"
  if ((iValue == null) || (iValue === "undefined")) return "";
  if( typeof iValue !== 'string')
      return iValue;

  var isIso8601DateString = function(iValue) {
    // canonicalize dates (cf. http://stackoverflow.com/a/37563868)
    var ISO_8601_FULL = /^\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d(\.\d+)?(([+-]\d\d:\d\d)|Z)?$/i;
    return (typeof iValue === 'string' && ISO_8601_FULL.test(iValue));
  }.bind(this);

  var value = iValue.trim();
  return isIso8601DateString(value) ? DG.createDate(value) : value;
};

/**
  Canonicalize/sanitize case values sent to us from the game.
  This function also converts a map of property names to values
  to one that maps attribute IDs to values.
  @param    iAttrs  The set of attributes
  @param    iDataMap  A map from attribute names to values
  @returns          The canonicalized value map (attribute IDs to values)
 */
DG.DataUtilities.canonicalizeAttributeValues = function(iAttrs, iDataMap) {
  var valuesMap = {};
  DG.ObjectMap.forEach(iDataMap, function (iKey, iValue) {

    var attr = iAttrs.findProperty('name', iKey) ||
            iAttrs.findProperty('name', DG.Attribute.canonicalizeName(iKey)),
        value = DG.DataUtilities.canonicalizeInputValue(iValue);
    if(attr != null) {
      valuesMap[attr.id] = value;
    }
    else {
      valuesMap[iKey] = value;
    }
  });
  return valuesMap;
};

/**
 * Return true if the two data values are equal, ignoring case if they are both strings.
 * Data values are primitive case-attribute values, e.g. the return value of DG.Case.getValue()
 * @param iDataValue1
 * @param iDataValue2
 * @returns {Boolean}
 */
DG.DataUtilities.isEqualIgnoreCase = function( iDataValue1, iDataValue2 ) {
    var     tType1 = typeof iDataValue1,
            tType2 = typeof iDataValue2,
            tLowerStr1,
            tLowerStr2;
    if( tType1 === tType2 && tType1 === 'string' ) {
        tLowerStr1 = iDataValue1.toLowerCase();
        tLowerStr2 = iDataValue2.toLowerCase();
        return tLowerStr1 === tLowerStr2;
    } else {
        return iDataValue1 === iDataValue2;
    }

};

/**
 * Converts the input value to a string value, if it is not already.
 *
 * Converts dates according to the default date format.
 * Converts nulls and undefined to the empty string.
 *
 * @param {*} iValue The value to be converted.
 * @returns {String}
 */
DG.DataUtilities.toString = function (iValue) {
    var valType = typeof iValue,
        value = iValue;
    if (DG.isDate(iValue)) {
      // treat dates as strings
      value = DG.formatDate(iValue);
      valType = "string";
    }
    else if (iValue instanceof Error) {
      value = iValue.name + " " + iValue.message;
      valType = "string";
    }
    else if (iValue instanceof DG.SimpleMap) {
      // map has its own toString() function
      valType = "map";
    }
    switch( valType) {
      case "string":
        return value;
      case "number":
      case "boolean":
      case "map":
        return String(iValue);
    }
    return "";
};

var kTypeError = 1,
    kTypeNaN = 2,
    kTypeNull = 3,
    kTypeString = 4,
    kTypeBoolean = 5,
    kTypeNumber = 6,
    kTypeDate = 7,
    kTypeSimpleMap = 8, // e.g. boundaries
    kTypeUnknown = 9;

/**
  Returns the type code corresponding to the specified value.
 */
DG.DataUtilities.sortableValue = function(value) {
  function typeCode(value) {
    if (value == null) return kTypeNull;
    if (value instanceof Error) return kTypeError;
    if (DG.isDate(value) || DG.isDateString(value)) return kTypeDate;
    if (value instanceof DG.SimpleMap) return kTypeSimpleMap;
    switch (typeof value) {
      case 'number': return isNaN(value) ? kTypeNaN : kTypeNumber;
      case 'boolean': return kTypeBoolean;
      case 'string': return kTypeString;
      default: return kTypeUnknown;
    }
  }

  var type = typeCode(value),
      num = type === kTypeNumber ? value : NaN;
  // strings convertible to numbers are treated numerically
  if (type === kTypeString && value.length) {
    num = Number(value);
    if (!isNaN(num))
      return { type: kTypeNumber, value: num };
  }
  // booleans are treated as strings
  else if (type === kTypeBoolean)
    return { type: kTypeString, value: value };
  // dates are treated numerically
  else if (type === kTypeDate)
    return { type: kTypeNumber, value: Number(DG.createDate(value)) };
  // other values are treated according to their type
  return { type: type, value: value };
};

/**
  Comparison function for ascending sorts.
 */
DG.DataUtilities.compareAscending = function(value1, value2) {
  var v1 = DG.DataUtilities.sortableValue(value1),
      v2 = DG.DataUtilities.sortableValue(value2);

  if (v1.type !== v2.type) return v1.type - v2.type;

  function strCompareAscending(str1, str2) {
    // cf. https://stackoverflow.com/a/25775469 for performance issues with localeCompare
    return str1.localeCompare(str2, undefined, { sensitivity: 'base' });
  }

  switch(v1.type) {
    case kTypeNumber: return v1.value - v2.value;
    case kTypeString:
    case kTypeError: return strCompareAscending(String(v1.value), String(v2.value));
    default: return 0;  // other types are not ordered
  }
};

/**
  Comparison function for descending sorts.
 */
DG.DataUtilities.compareDescending = function(value1, value2) {
  var v1 = DG.DataUtilities.sortableValue(value1),
      v2 = DG.DataUtilities.sortableValue(value2);

  if (v1.type !== v2.type) return v2.type - v1.type;

  function strCompareDescending(str1, str2) {
    // cf. https://stackoverflow.com/a/25775469 for performance issues with localeCompare
    return -str1.localeCompare(str2, undefined, { sensitivity: 'base' });
  }

  switch(v1.type) {
    case kTypeNumber: return v2.value - v1.value;
    case kTypeString:
    case kTypeError: return strCompareDescending(String(v1.value), String(v2.value));
    default: return 0;  // other types are not ordered
  }
};

/**
 * Create a globally unique id, or really globally wildly improbable id.
 *
 * @return {string}
 */
DG.DataUtilities.createUniqueID = function () {
  return 'id:' + nanoid(16);
};

/* >>>>>>>>>> BEGIN source/formula/string_functions.js */
// ==========================================================================
//                        String Functions
//  
//  Author:   Kirk Swenson
//
//  Copyright (c) 2016 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('formula/function_registry');
sc_require('utilities/data_utilities');

/**
  Implements the basic builtin functions and registers them with the FunctionRegistry.
 */
DG.functionRegistry.registerFunctions((function() {
  var kDefaultSortItemsDelimiter = ',';

  return {
    /**
      Returns true if the specified string contains the specified target string
      as its initial characters.
      @param    {String}  iString - the string to search within
      @param    {String}  iTarget - the string to search for
      @returns  {Boolean} true if the string begins with the target string, false otherwise
     */
    'beginsWith': {
      minArgs:2, maxArgs:2, category: 'DG.Formula.FuncCategoryString',
      evalFn: function(iString, iTarget) {
        var string = DG.DataUtilities.toString(iString), target = DG.DataUtilities.toString(iTarget);
        if (!target) return true;
        if (!string) return false;
        return string.indexOf(target) === 0;
      }
    },

    /**
      Returns the character at the specified position.
      @param    {String}  iString - the string from which a character is to be extracted
      @param    {Number}  iPosition - the position of the character to be extracted
      @returns  {String}  the character at the specified position
     */
    'charAt': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryString',
      evalFn: function(iString, iPosition) {
        var string = DG.DataUtilities.toString(iString);
        if (iPosition < 0) iPosition += string.length + 1;
        return string.charAt(iPosition - 1);
      }
    },

    /**
      Returns the string formed by concatenating/joining its string arguments.
      @param    {String, ...}  iStr1, iStr2, ... - the strings to concatenate
      @returns  {String}  the joined string
     */
    'concat': {
      minArgs:1, maxArgs:99, category: 'DG.Formula.FuncCategoryString',
      evalFn: function(/* iStr1, iStr2, ... */) {
        var args = Array.prototype.slice.call(arguments);
        return args.length ? args.join("") : "";
      }
    },

    /**
      Returns true if the specified string contains the specified target string
      as its final characters.
      @param    {String}  iString - the string to search within
      @param    {String}  iTarget - the string to search for
      @returns  {Boolean} true if the string ends with the target string, false otherwise
     */
    'endsWith': {
      minArgs:2, maxArgs:2, category: 'DG.Formula.FuncCategoryString',
      evalFn: function(iString, iTarget) {
        var string = DG.DataUtilities.toString(iString), target = DG.DataUtilities.toString(iTarget);
        if (!target) return true;
        if (!string) return false;
        if (target.length > string.length) return false;
        var ending = string.substr(-target.length);
        return ending && ending.indexOf(target) === 0;
      }
    },

    /**
      Searches the first string argument (optionally starting at
      the specified position) for the specified target string.
      If found, returns the (1-based) position at which the
      match was found. Returns 0 if not found.
      @param    {String}  iString - the string to search within
      @param    {String}  iTarget - the string to search for
      @param    {Number}  iPosition - the offset of the first character to return
      @returns  {Number}  (1-based) position of the match if found, 0 otherwise
     */
    'findString': {
      minArgs:2, maxArgs:3, category: 'DG.Formula.FuncCategoryString',
      evalFn: function(iString, iTarget, iPosition) {
        var string = DG.DataUtilities.toString(iString), target = DG.DataUtilities.toString(iTarget),
            position = iPosition || 0;
        if (!DG.isNumeric(position)) return 0;
        if (!target) return 1;
        if (!string) return 0;
        if (position < 0) position += string.length;
        var ending = iPosition ? string.substr(position) : string,
            found = ending.indexOf(target);
        return found >= 0 ? position + found + 1 : 0;
      }
    },

    /**
      Searches the first string argument the specified regular expression.
      Returns the number of matches found.
      @param    {String}  iString - the string to search within
      @param    {String}  iPattern - the pattern to search for
      @returns  {Number}  the number of matches found
     */
    'patternMatches': {
      minArgs:2, maxArgs:2, category: 'DG.Formula.FuncCategoryString',
      evalFn: function(iTarget, iPattern) {
        var target = DG.DataUtilities.toString(iTarget),
            pattern = DG.DataUtilities.toString(iPattern);
        if (!pattern || !target)
          return 0;
        var re = new RegExp(pattern, 'gmi'),
            result = target.match(re);
        return !result ? 0 : result.length;
      }
    },

    /**
      Returns true if the string first argument contains the second string argument.
      @param    {String}  iString - the string to search within
      @param    {String}  iTarget - the string to search for
      @returns  {Boolean} true if the target string was found, false otherwise
     */
    'includes': {
      minArgs:2, maxArgs:2, category: 'DG.Formula.FuncCategoryString',
      evalFn: function(iString, iTarget) {
        var string = DG.DataUtilities.toString(iString), target = DG.DataUtilities.toString(iTarget);
        if (!target) return true;
        if (!string) return false;
        // case insensitive
        return string.toLowerCase().indexOf(target.toLowerCase()) >= 0;
      }
    },

    /**
      Returns the string formed by concatenating/joining its string arguments,
      each separated by the specified iSeparator argument.
      @param    {String}  iSeparator - the string to use between joined arguments
      @param    {String, ...}  iStr1, iStr2, ... - the strings to concatenate
      @returns  {String}  the joined string
     */
    'join': {
      minArgs:1, maxArgs:99, category: 'DG.Formula.FuncCategoryString',
      evalFn: function(iSeparator /*, iStr1, iStr2, ... */) {
        var args = Array.prototype.slice.call(arguments, 1),
            separator = iSeparator != null ? iSeparator : " ";
        return args.length ? args.join(separator) : "";
      }
    },

    /**
      Returns the string formed by repeating its first string argument
      the number of times specified by its second string argument.
      @param    {String}  iString - the string to repeat
      @param    {Number}  iCount - the number of times to repeat
      @returns  {String}  the resulting string
     */
    'repeatString': {
      minArgs:2, maxArgs:2, category: 'DG.Formula.FuncCategoryString',
      evalFn: function(iString, iCount) {
        var string = DG.DataUtilities.toString(iString);
        if (!string || !iCount) return "";
        var i, result = "";
        for (i = 0; i < iCount; ++i) {
          result += string;
        }
        return result;
      }
    },

    /**
      Returns the string formed by replacing the specified characters
      with the specified replacement string.
      @param    {String}  iString - the string on which to perform the replacement
      @param    {Number}  iPosition - the position of the first character to replace
      @param    {Number}  iLength - the number of characters to replace
      @param    {String}  iReplace - the string to replace with
      @returns  {String}  the resulting string
     */
    'replaceChars': {
      minArgs:4, maxArgs:4, category: 'DG.Formula.FuncCategoryString',
      evalFn: function(iString, iPosition, iLength, iReplace) {
        var string = DG.DataUtilities.toString(iString);
        if (!string) return "";
        var position;
        if (!iPosition) {
          position = 0;
        }
        else if (iPosition >= 1) {
          position = iPosition - 1;
        }
        else if (iPosition < 0) {
          position = iPosition + string.length;
        }
        else {
          return iString;
        }
        var left = string.substr(0, position),
            right = string.substr(position + iLength);
        return left + iReplace + right;
      }
    },

    /**
      Returns the string formed by replacing the specified substring
      with the specified replacement string.
      @param    {String}  iString - the string on which to perform the replacement
      @param    {String}  iTarget - the substring to be replaced
      @param    {String}  iReplace - the string to replace with
      @returns  {String}  the resulting string
     */
    'replaceString': {
      minArgs:3, maxArgs:3, category: 'DG.Formula.FuncCategoryString',
      evalFn: function(iString, iTarget, iReplace) {
        var string = DG.DataUtilities.toString(iString), target = DG.DataUtilities.toString(iTarget);
        if (!target) return string;
        var re = DG.StringUtilities.createEscapedRegExp(target, 'g');
        return string.replace(re, iReplace);
      }
    },

    /**
      Treats the given string as a list. The default delimiter is ','.
      The returned string has the items in the list in sorted order.
      If the delimiter is '', the characters of the given string are sorted.
      Spaces between items are ignored except so far as they are part of the delimiter.
      @param    {String}  iString - the string containing the list to be sorted
      @param    {String}  iDelimiter - the character(s) that separates items in the list
      @returns  {String}  the resulting sorted list
     */
    'sortItems': {
      minArgs:1, maxArgs:2, category: 'DG.Formula.FuncCategoryString',
      evalFn: function(iString, iDelimiter) {
        var tList = DG.DataUtilities.toString(iString),
            tResult;
        if (iDelimiter === undefined || iDelimiter === null) {
          iDelimiter = kDefaultSortItemsDelimiter;
        }
        tResult = tList.split(iDelimiter).sort();

        return tResult.join( iDelimiter);
      }
    },

    /**
      Returns the string formed by splitting the specified string by the
      specified separator and then returning the element at the specified index.
      @param    {String}  iString - the string on which to perform the replacement
      @param    {String}  iSeparator - the separator by which to split the string
      @param    {Number}  iIndex - the index of the element to be returned
      @returns  {String}  the resulting string
     */
    'split': {
      minArgs:2, maxArgs:3, category: 'DG.Formula.FuncCategoryString',
      evalFn: function(iString, iSeparator, iIndex) {
        var string = DG.DataUtilities.toString(iString),
            index = iIndex ? iIndex : 1,
            results = string.split(iSeparator);
        return ((index >= 1) && (index <= results.length))
                  ? results[index - 1]
                  : "";
      }
    },

    /**
      Returns a substring of the specified string, determined by its position and
      length arguments.
      @param    {String}  iString - the string to search within
      @param    {Number}  iPosition - the offset of the first character to return
      @param    {Number}  iLength - the number of characters to return
      @returns  {String}  the specified substring
     */
    'subString': {
      minArgs:2, maxArgs:3, category: 'DG.Formula.FuncCategoryString',
      evalFn: function(iString, iPosition, iLength) {
        var string = DG.DataUtilities.toString(iString);
        if (!string) return '';
        if (!iPosition) iPosition = 1;
        var position = iPosition >= 1 ? iPosition - 1 : iPosition + string.length,
            length = iLength != null ? iLength : string.length;
        return string.substr(position, length);
      }
    },

    /**
      Returns the number of characters in the specified string.
      @param    {String}  iString - the string whose characters are to be counted
      @returns  {Number}  the number of characters in the string
     */
    'stringLength': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryString',
      evalFn: function(iString) { return DG.DataUtilities.toString(iString).length; }
    },

    /**
      Converts all characters in the string to lowercase.
      @param    {String}  iString - the string whose characters are to be lower-cased
      @returns  {String}  the resulting lowercase string
     */
    'toLower': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryString',
      evalFn: function(iString) { return DG.DataUtilities.toString(iString).toLowerCase(); }
    },

    /**
      Converts all characters in the string to uppercase.
      @param    {String}  iString - the string whose characters are to be upper-cased
      @returns  {String}  the resulting uppercase string
     */
    'toUpper': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryString',
      evalFn: function(iString) { return DG.DataUtilities.toString(iString).toUpperCase(); }
    },

    /**
      Converts all characters in the string to uppercase.
      @param    {String}  iString - the string whose characters are to be upper-cased
      @returns  {String}  the resulting uppercase string
     */
    'trim': {
      minArgs:1, maxArgs:1, category: 'DG.Formula.FuncCategoryString',
      evalFn: function(iString) {
        return DG.DataUtilities.toString(iString)
                .trim()
                .replace(/[\s\uFEFF\xA0][\s\uFEFF\xA0]*/g, " ");
      }
    }

  };
})());

/* >>>>>>>>>> BEGIN source/formula/univariate_stats_fns.js */
// ==========================================================================
//                Univariate Stats Aggregate Functions
//  
//  Author:   Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/* global Set:true */

sc_require('formula/aggregate_function');
sc_require('formula/function_registry');

/** @class DG.UnivariateStatsFns

  The DG.UnivariateStatsFns object implements aggregate functions that
  perform univariate statistical computations such as count() mean(),
  median(), sum(), etc.
 */
DG.functionRegistry.registerAggregates((function() {

return {

  /**
    count([expr])
    Returns the aggregated count of its (optional) argument.
    If no argument is supplied, then the count of cases is returned.
    All other non-empty values except boolean false are counted.
    (The boolean false exception allows count(x>0) to behave as expected.)
   */
  count: DG.ParentCaseAggregate.create({
  
    requiredArgs: { min: 0, max: 1 },

    // count() with no arguments must be invalidated when case indices change
    isCaseIndexDependent: function(iArgs) {
      return !iArgs || !iArgs.length;
    },

    evaluate: function( iContext, iEvalContext, iInstance) {
      // if we have an argument, use the base class iteration method
      if (iInstance.argFns[0] != null) {
        return arguments.callee.base.apply(this,arguments);
      }

      // if no argument, count non-empty child cases
      var childCases = iEvalContext._case_ && iEvalContext._case_.get('children');
      return childCases ? childCases.filter(function(c) {return !c.isEmpty();}).length : 0;
    },

    evalCase: function( iContext, iEvalContext, iInstance, iCacheID) {
      var value = this.getValue( iContext, iEvalContext, iInstance);
      // Count:
      //  -- non-empty values except for boolean false and empty string
      //      (this way count(x>0) returns the expected result)
      if(!SC.empty(value) && (value !== false)) {
        if( iInstance.results[ iCacheID])
          ++iInstance.results[ iCacheID];
        else
          iInstance.results[ iCacheID] = 1;
      }
      else if( !iInstance.results[ iCacheID]) {
        // put a 0 entry in the cache for evaluated groups
        iInstance.results[ iCacheID] = 0;
      }
    },

    computeResults: function( iContext, iEvalContext, iInstance) {
      // default to 0 rather than undefined (e.g. if there are no cases)
      return arguments.callee.base.apply(this,arguments) || 0;
    }
  }),

  /**
    uniqueValues([expr])
    Returns the number of unique values of its first argument.
    The second argument determines which case's values contribute.
   */
  uniqueValues: DG.ParentCaseAggregate.create({

    requiredArgs: { min: 1, max: 1 },

    evalCase: function( iContext, iEvalContext, iInstance, iCacheID) {
      var value = this.getValue( iContext, iEvalContext, iInstance);
      if (!iInstance.caches[iCacheID])
        iInstance.caches[iCacheID] = new Set();
      if(!SC.empty(value)) {
        iInstance.caches[iCacheID].add(value);
      }
    },

    computeResults: function( iContext, iEvalContext, iInstance) {
      DG.ObjectMap.forEach( iInstance.caches,
          function( iKey, iCache) {
            iInstance.results[ iKey] = iCache.size;
          });
      return this.queryCache( iContext, iEvalContext, iInstance);
    }
  }),

  /**
    min(expr)
    Returns the smallest of its evaluated argument values.
   */
  min: DG.ParentCaseAggregate.create({
  
    requiredArgs: { min: 1, max: 1 },

    evalCase: function( iContext, iEvalContext, iInstance, iCacheID) {
      var value = this.getNumericValue( iContext, iEvalContext, iInstance);
      if( value != null) {
        var cache = iInstance.caches[ iCacheID];
        if( cache) {
          if( cache.min > value)
            cache.min = value;
        }
        else
          iInstance.caches[ iCacheID] = { min: value };
      }
    },
    
    computeResults: function( iContext, iEvalContext, iInstance) {
      DG.ObjectMap.forEach( iInstance.caches,
                            function( iKey, iCache) {
                              iInstance.results[ iKey] = iCache.min;
                            });
      return this.queryCache( iContext, iEvalContext, iInstance);
    }
  }),

  /**
    max(expr)
    Returns the largest of its evaluated argument values.
   */
  max: DG.ParentCaseAggregate.create({
  
    requiredArgs: { min: 1, max: 1 },

    evalCase: function( iContext, iEvalContext, iInstance, iCacheID) {
      var value = this.getNumericValue( iContext, iEvalContext, iInstance);
      if( value != null) {
        var cache = iInstance.caches[ iCacheID];
        if( cache) {
          if( cache.max < value)
            cache.max = value;
        }
        else
          iInstance.caches[ iCacheID] = { max: value };
      }
    },
    
    computeResults: function( iContext, iEvalContext, iInstance) {
      DG.ObjectMap.forEach( iInstance.caches,
                            function( iKey, iCache) {
                              iInstance.results[ iKey] = iCache.max;
                            });
      return this.queryCache( iContext, iEvalContext, iInstance);
    }
  }),

  /**
    mean(expr)
    Returns the aggregated mean of its evaluated argument values.
   */
  mean: DG.ParentCaseAggregate.create({
  
    requiredArgs: { min: 1, max: 1 },

    evalCase: function( iContext, iEvalContext, iInstance, iCacheID) {
      var value = this.getNumericValue( iContext, iEvalContext, iInstance);
      if( value != null) {
        var cache = iInstance.caches[ iCacheID];
        if( cache) {
          cache.count += 1;
          cache.sum += value;
        }
        else
          iInstance.caches[ iCacheID] = { count: 1, sum: value };
      }
    },
    
    computeResults: function( iContext, iEvalContext, iInstance) {
      DG.ObjectMap.forEach( iInstance.caches,
                            function( iKey, iCache) {
                              iInstance.results[ iKey] = iCache.count > 0
                                                            ? iCache.sum / iCache.count
                                                            : null;
                            });
      return this.queryCache( iContext, iEvalContext, iInstance);
    }
  }),

  /**
    median(expr)
    Returns the aggregated median of its evaluated argument values.
   */
  median: DG.SortDataFunction.create({
  
    requiredArgs: { min: 1, max: 1 },

    extractResult: function( iCachedValues, iEvalContext, iInstance) {
      return DG.MathUtilities.medianOfNumericArray( iCachedValues);
    }
  }),

  /**
    variance(expr)
    Returns the aggregated sample standard deviation of its evaluated argument values.
   */
  variance: DG.CachedValuesParentCaseAggregate.create({
  
    requiredArgs: { min: 1, max: 1 },

    computeResultFromCache: function(iCache) {
      return this.computeVarianceFromCache(iCache);
    }
  }),

  /**
    stdDev(expr)
    Returns the aggregated sample standard deviation of its evaluated argument values.
   */
  stdDev: DG.CachedValuesParentCaseAggregate.create({
  
    requiredArgs: { min: 1, max: 1 },

    computeResultFromCache: function(iCache) {
      return Math.sqrt(this.computeVarianceFromCache(iCache));
    }
  }),

  /**
    stdErr(expr)
    Returns the aggregated standard error of its evaluated argument values.
   */
  stdErr: DG.CachedValuesParentCaseAggregate.create({
  
    requiredArgs: { min: 1, max: 1 },

    computeResultFromCache: function(iCache) {
      var count = iCache.values && iCache.values.length,
          stdDev = Math.sqrt(this.computeVarianceFromCache(iCache));
      return stdDev / Math.sqrt(count);
    }
  }),

  /**
    mad(expr)
    Returns the mean absolute deviation of its evaluated argument values.
   */
  mad: DG.CachedValuesParentCaseAggregate.create({

    requiredArgs: { min: 1, max: 1 },

    computeResultFromCache: function(iCache) {
      var count = iCache.values && iCache.values.length,
          tMean = iCache.sum / count;
      return iCache.values && iCache.values.reduce( function( iSum, iValue) {
            return iSum + Math.abs( tMean - iValue);
          }, 0) / count;
    }
  }),

  /**
    percentile(expr)
    Returns the aggregated percentile of its evaluated argument values.
   */
  percentile: DG.SortDataFunction.create({

    // todo: Figure out what should be the min number of arguments. 2 or 1?
    requiredArgs: { min: 2, max: 2 },

    preEvaluate: function(iContext, iEvalContext, iInstance) {
      arguments.callee.base.apply(this,arguments);

      var tPercValueFn = iInstance.argFns[1],
          percValue = tPercValueFn ? tPercValueFn(iContext, iEvalContext) : undefined;
      // Note that the percentile argument could evaluate to a different value for every
      // case, e.g. percentile(x, caseIndex/count(x)). The code here somewhat arbitrarily
      // chooses the last evaluated percentile value to use for the aggregate evaluation.
      // A fully general implementation would treat the percentile function as a semi-
      // aggregate which could evaluate to a different value for every case.
      if (!iInstance.caches) iInstance.caches = {};
      iInstance.caches._percentile_ = percValue;
    },

    extractResult: function (iCachedValues, iEvalContext, iInstance) {
      return DG.MathUtilities.quantileOfSortedArray(iCachedValues, iInstance.caches._percentile_);
    }
  }),

  /**
    sum(expr)
    Returns the aggregated sum of its evaluated argument values.
   */
  sum: DG.ParentCaseAggregate.create({

    requiredArgs: { min: 1, max: 1 },

    evalCase: function( iContext, iEvalContext, iInstance, iCacheID) {
      var value = this.getNumericValue( iContext, iEvalContext, iInstance);
      if (iInstance.results[ iCacheID] == null) {
        iInstance.results[ iCacheID] = 0;
      }
      if( value != null) {
        if( iInstance.results[ iCacheID])
          iInstance.results[ iCacheID] += value;
        else
          iInstance.results[ iCacheID] = value;
      }
    }
  }),

  /**
   combine(expr)
   Returns the aggregated concatenation of its evaluated argument values.
   */
  'combine': DG.ParentCaseAggregate.create({

    category: 'DG.Formula.FuncCategoryString',
    requiredArgs: { min: 1, max: 1 },

    evalCase: function( iContext, iEvalContext, iInstance, iCacheID) {
      var value = this.getValue( iContext, iEvalContext, iInstance);
      if( value != null) {
        if( iInstance.results[ iCacheID])
          iInstance.results[ iCacheID] += String( value);
        else
          iInstance.results[ iCacheID] = String( value);
      }
    }
  }),
  /**
   * rolling_mean(expr, width, filter)
   * Returns the running mean. 'expr' is the expression evaluated for each case.
   * 'width', is the number of prior and succeeding cases included in the mean.
   * It is a positive odd integer. For example, a width of seven will sum the
   * values for the three prior (filtered) cases, the three succeeding (filtered)
   * cases, and the current case and divide by seven. The filter is an expression
   * that excludes cases from consideration.
   *
   */
  rollingMean: DG.AggregateFunction.create({
    category: 'DG.Formula.FuncCategoryStatistical',
    requiredArgs: { min: 2, max: 3 }, // expression, width, filter
    isCaseIndexDependent: function () { return false; },
    evaluate: function(iContext, iEvalContext, iInstance) {
      var valueFn = iInstance.argFns[0],
          widthFn = iInstance.argFns[1],
          filterFn = iInstance.argFns[2];
      /**
       * @return {[object]}
       */
      function getRangeValues(iContext, iEvalContext) {
        var width = Math.round(widthFn(iContext, iEvalContext));
        if (width<1) return [];
        var numPreceding = Math.floor(width/2);
        var numFollowing = width - 1 - numPreceding;
        var rtn = [];
        var iCase = iEvalContext._case_;
        var parentCase = iCase && iCase.get('parent');
        var siblings = parentCase ? parentCase.get('children')
            : (iContext && iContext.getPath('collection.cases'));
        var thisCaseIndex = iContext.getCaseIndex( iEvalContext._id_); // 1-based index
        var ix = thisCaseIndex - 1; // 0-based index
        var remaining = numPreceding;
        var tCase;
        var value = DG.getNumeric(valueFn(iContext, iEvalContext));
        if (numPreceding > ix || numFollowing >= (siblings.length - ix)) {
          return [];
        }
        if (value != null) {rtn.push(value);}
        while(ix > 0 && remaining > 0) {
          ix -= 1;
          tCase = siblings[ix];
          if (!filterFn || filterFn(iContext, {_case_: tCase, _id_: tCase.get('id') })) {
            value = DG.getNumeric(valueFn(iContext, { _case_: tCase, _id_: tCase && tCase.get('id')  }));
            if (value != null) { rtn.push(value); }
            remaining -= 1;
          }
        }
        ix = thisCaseIndex - 1; // 0-based index
        remaining = numFollowing;
        while(ix < siblings.length - 1 && remaining > 0) {
          ix += 1;
          tCase = siblings[ix];
          if (tCase && (!filterFn || filterFn(iContext, {_case_: tCase, _id_: tCase.get('id') }))) {
            value = DG.getNumeric(valueFn(iContext, { _case_: tCase, _id_: tCase && tCase.get('id')  }));
            if (value != null) { rtn.push(value); }
            remaining -= 1;
          }
        }
        return rtn;
      }
      var values = getRangeValues(iContext, iEvalContext);
      if (values.length === 0) {
        return null;
      }
      var sum = values.reduce(function (accum, value, ix) {
        return accum + value;
      }.bind(this), 0);
      return sum / values.length;
    }
  })
};

}()));

/* >>>>>>>>>> BEGIN source/libraries/iframe-phone.js */
!function(e){"object"==typeof exports?module.exports=e():"function"==typeof define&&define.amd?define(e):"undefined"!=typeof window?window.iframePhone=e():"undefined"!=typeof global?global.iframePhone=e():"undefined"!=typeof self&&(self.iframePhone=e())}(function(){var define,module,exports;return (function e(t,n,r){function s(o,u){if(!n[o]){if(!t[o]){var a=typeof require=="function"&&require;if(!u&&a)return a(o,!0);if(i)return i(o,!0);throw new Error("Cannot find module '"+o+"'")}var f=n[o]={exports:{}};t[o][0].call(f.exports,function(e){var n=t[o][1][e];return s(n?n:e)},f,f.exports,e,t,n,r)}return n[o].exports}var i=typeof require=="function"&&require;for(var o=0;o<r.length;o++)s(r[o]);return s})({1:[function(require,module,exports){
var structuredClone = require('./structured-clone');
var HELLO_INTERVAL_LENGTH = 200;
var HELLO_TIMEOUT_LENGTH = 60000;

function IFrameEndpoint() {
  var listeners = {};
  var isInitialized = false;
  var connected = false;
  var postMessageQueue = [];
  var helloInterval;

  function postToParent(message) {
    // See http://dev.opera.com/articles/view/window-postmessage-messagechannel/#crossdoc
    //     https://github.com/Modernizr/Modernizr/issues/388
    //     http://jsfiddle.net/ryanseddon/uZTgD/2/
    if (structuredClone.supported()) {
      window.parent.postMessage(message, '*');
    } else {
      window.parent.postMessage(JSON.stringify(message), '*');
    }
  }

  function post(type, content) {
    var message;
    // Message object can be constructed from 'type' and 'content' arguments or it can be passed
    // as the first argument.
    if (arguments.length === 1 && typeof type === 'object' && typeof type.type === 'string') {
      message = type;
    } else {
      message = {
        type: type,
        content: content
      };
    }
    if (connected) {
      postToParent(message);
    } else {
      postMessageQueue.push(message);
    }
  }

  function postHello() {
    postToParent({
      type: 'hello'
    });
  }

  function addListener(type, fn) {
    listeners[type] = fn;
  }

  function removeAllListeners() {
    listeners = {};
  }

  function getListenerNames() {
    return Object.keys(listeners);
  }

  function messageListener(message) {
    // Anyone can send us a message. Only pay attention to messages from parent.
    if (message.source !== window.parent) return;
    var messageData = message.data;
    if (typeof messageData === 'string') messageData = JSON.parse(messageData);

    if (!connected && messageData.type === 'hello') {
      connected = true;
      stopPostingHello();
      while (postMessageQueue.length > 0) {
        post(postMessageQueue.shift());
      }
    }

    if (connected && listeners[messageData.type]) {
      listeners[messageData.type](messageData.content);
    }
  }

  function disconnect() {
    connected = false;
    stopPostingHello();
    window.removeEventListener('message', messageListener);
  }

  /**
    Initialize communication with the parent frame. This should not be called until the app's custom
    listeners are registered (via our 'addListener' public method) because, once we open the
    communication, the parent window may send any messages it may have queued. Messages for which
    we don't have handlers will be silently ignored.
  */
  function initialize() {
    if (isInitialized) {
      return;
    }
    isInitialized = true;
    if (window.parent === window) return;

    // We kick off communication with the parent window by sending a "hello" message. Then we wait
    // for a handshake (another "hello" message) from the parent window.
    startPostingHello();
    window.addEventListener('message', messageListener, false);
  }

  function startPostingHello() {
    if (helloInterval) {
      stopPostingHello();
    }
    helloInterval = window.setInterval(postHello, HELLO_INTERVAL_LENGTH);
    window.setTimeout(stopPostingHello, HELLO_TIMEOUT_LENGTH);
    // Post the first msg immediately.
    postHello();
  }

  function stopPostingHello() {
    window.clearInterval(helloInterval);
    helloInterval = null;
  }

  // Public API.
  return {
    initialize: initialize,
    getListenerNames: getListenerNames,
    addListener: addListener,
    removeAllListeners: removeAllListeners,
    disconnect: disconnect,
    post: post
  };
}

var instance = null;

// IFrameEndpoint is a singleton, as iframe can't have multiple parents anyway.
module.exports = function getIFrameEndpoint() {
  if (!instance) {
    instance = new IFrameEndpoint();
  }
  return instance;
};

},{"./structured-clone":4}],2:[function(require,module,exports){
var ParentEndpoint = require('./parent-endpoint');
var getIFrameEndpoint = require('./iframe-endpoint');

// Not a real UUID as there's an RFC for that (needed for proper distributed computing).
// But in this fairly parochial situation, we just need to be fairly sure to avoid repeats.
function getPseudoUUID() {
  var chars = 'abcdefghijklmnopqrstuvwxyz0123456789';
  var len = chars.length;
  var ret = [];

  for (var i = 0; i < 10; i++) {
    ret.push(chars[Math.floor(Math.random() * len)]);
  }
  return ret.join('');
}

module.exports = function IframePhoneRpcEndpoint(handler, namespace, targetWindow, targetOrigin, phone) {
  var pendingCallbacks = Object.create({});

  // if it's a non-null object, rather than a function, 'handler' is really an options object
  if (handler && typeof handler === 'object') {
    namespace = handler.namespace;
    targetWindow = handler.targetWindow;
    targetOrigin = handler.targetOrigin;
    phone = handler.phone;
    handler = handler.handler;
  }

  if (!phone) {
    if (targetWindow === window.parent) {
      phone = getIFrameEndpoint();
      phone.initialize();
    } else {
      phone = new ParentEndpoint(targetWindow, targetOrigin);
    }
  }

  phone.addListener(namespace, function (message) {
    var callbackObj;

    if (message.messageType === 'call' && typeof this.handler === 'function') {
      this.handler.call(undefined, message.value, function (returnValue) {
        phone.post(namespace, {
          messageType: 'returnValue',
          uuid: message.uuid,
          value: returnValue
        });
      });
    } else if (message.messageType === 'returnValue') {
      callbackObj = pendingCallbacks[message.uuid];

      if (callbackObj) {
        window.clearTimeout(callbackObj.timeout);
        if (callbackObj.callback) {
          callbackObj.callback.call(undefined, message.value);
        }
        pendingCallbacks[message.uuid] = null;
      }
    }
  }.bind(this));

  function call(message, callback) {
    var uuid = getPseudoUUID();

    pendingCallbacks[uuid] = {
      callback: callback,
      timeout: window.setTimeout(function () {
        if (callback) {
          callback(undefined, new Error("IframePhone timed out waiting for reply"));
        }
      }, 2000)
    };

    phone.post(namespace, {
      messageType: 'call',
      uuid: uuid,
      value: message
    });
  }

  function disconnect() {
    phone.disconnect();
  }

  this.handler = handler;
  this.call = call.bind(this);
  this.disconnect = disconnect.bind(this);
};

},{"./iframe-endpoint":1,"./parent-endpoint":3}],3:[function(require,module,exports){
var structuredClone = require('./structured-clone');

/**
  Call as:
    new ParentEndpoint(targetWindow, targetOrigin, afterConnectedCallback)
      targetWindow is a WindowProxy object. (Messages will be sent to it)

      targetOrigin is the origin of the targetWindow. (Messages will be restricted to this origin)

      afterConnectedCallback is an optional callback function to be called when the connection is
        established.

  OR (less secure):
    new ParentEndpoint(targetIframe, afterConnectedCallback)

      targetIframe is a DOM object (HTMLIframeElement); messages will be sent to its contentWindow.

      afterConnectedCallback is an optional callback function

    In this latter case, targetOrigin will be inferred from the value of the src attribute of the
    provided DOM object at the time of the constructor invocation. This is less secure because the
    iframe might have been navigated to an unexpected domain before constructor invocation.

  Note that it is important to specify the expected origin of the iframe's content to safeguard
  against sending messages to an unexpected domain. This might happen if our iframe is navigated to
  a third-party URL unexpectedly. Furthermore, having a reference to Window object (as in the first
  form of the constructor) does not protect against sending a message to the wrong domain. The
  window object is actualy a WindowProxy which transparently proxies the Window object of the
  underlying iframe, so that when the iframe is navigated, the "same" WindowProxy now references a
  completely differeent Window object, possibly controlled by a hostile domain.

  See http://www.esdiscuss.org/topic/a-dom-use-case-that-can-t-be-emulated-with-direct-proxies for
  more about this weird behavior of WindowProxies (the type returned by <iframe>.contentWindow).
*/

module.exports = function ParentEndpoint(targetWindowOrIframeEl, targetOrigin, afterConnectedCallback) {
  var postMessageQueue = [];
  var connected = false;
  var handlers = {};
  var targetWindowIsIframeElement;

  function getIframeOrigin(iframe) {
    return iframe.src.match(/(.*?\/\/.*?)\//)[1];
  }

  function post(type, content) {
    var message;
    // Message object can be constructed from 'type' and 'content' arguments or it can be passed
    // as the first argument.
    if (arguments.length === 1 && typeof type === 'object' && typeof type.type === 'string') {
      message = type;
    } else {
      message = {
        type: type,
        content: content
      };
    }
    if (connected) {
      var tWindow = getTargetWindow();
      // if we are laready connected ... send the message
      // See http://dev.opera.com/articles/view/window-postmessage-messagechannel/#crossdoc
      //     https://github.com/Modernizr/Modernizr/issues/388
      //     http://jsfiddle.net/ryanseddon/uZTgD/2/
      if (structuredClone.supported()) {
        tWindow.postMessage(message, targetOrigin);
      } else {
        tWindow.postMessage(JSON.stringify(message), targetOrigin);
      }
    } else {
      // else queue up the messages to send after connection complete.
      postMessageQueue.push(message);
    }
  }

  function addListener(messageName, func) {
    handlers[messageName] = func;
  }

  function removeListener(messageName) {
    handlers[messageName] = null;
  }

  // Note that this function can't be used when IFrame element hasn't been added to DOM yet
  // (.contentWindow would be null). At the moment risk is purely theoretical, as the parent endpoint
  // only listens for an incoming 'hello' message and the first time we call this function
  // is in #receiveMessage handler (so iframe had to be initialized before, as it could send 'hello').
  // It would become important when we decide to refactor the way how communication is initialized.
  function getTargetWindow() {
    if (targetWindowIsIframeElement) {
      var tWindow = targetWindowOrIframeEl.contentWindow;
      if (!tWindow) {
        throw "IFrame element needs to be added to DOM before communication " +
              "can be started (.contentWindow is not available)";
      }
      return tWindow;
    }
    return targetWindowOrIframeEl;
  }

  function receiveMessage(message) {
    var messageData;
    if (message.source === getTargetWindow() && (targetOrigin === '*' || message.origin === targetOrigin)) {
      messageData = message.data;
      if (typeof messageData === 'string') {
        messageData = JSON.parse(messageData);
      }
      if (handlers[messageData.type]) {
        handlers[messageData.type](messageData.content);
      } else {
        console.log("cant handle type: " + messageData.type);
      }
    }
  }

  function disconnect() {
    connected = false;
    window.removeEventListener('message', receiveMessage);
  }

  // handle the case that targetWindowOrIframeEl is actually an <iframe> rather than a Window(Proxy) object
  // Note that if it *is* a WindowProxy, this probe will throw a SecurityException, but in that case
  // we also don't need to do anything
  try {
    targetWindowIsIframeElement = targetWindowOrIframeEl.constructor === HTMLIFrameElement;
  } catch (e) {
    targetWindowIsIframeElement = false;
  }

  if (targetWindowIsIframeElement) {
    // Infer the origin ONLY if the user did not supply an explicit origin, i.e., if the second
    // argument is empty or is actually a callback (meaning it is supposed to be the
    // afterConnectionCallback)
    if (!targetOrigin || targetOrigin.constructor === Function) {
      afterConnectedCallback = targetOrigin;
      targetOrigin = getIframeOrigin(targetWindowOrIframeEl);
    }
  }

  // Handle pages served through file:// protocol. Behaviour varies in different browsers. Safari sets origin
  // to 'file://' and everything works fine, but Chrome and Safari set message.origin to null.
  // Also, https://developer.mozilla.org/en-US/docs/Web/API/Window/postMessage says:
  //  > Lastly, posting a message to a page at a file: URL currently requires that the targetOrigin argument be "*".
  //  > file:// cannot be used as a security restriction; this restriction may be modified in the future.
  // So, using '*' seems like the only possible solution.
  if (targetOrigin === 'file://') {
    targetOrigin = '*';
  }

  // when we receive 'hello':
  addListener('hello', function () {
    connected = true;

    // send hello response
    post({
      type: 'hello',
      // `origin` property isn't used by IframeEndpoint anymore (>= 1.2.0), but it's being sent to be
      // backward compatible with old IframeEndpoint versions (< v1.2.0).
      origin: window.location.href.match(/(.*?\/\/.*?)\//)[1]
    });

    // give the user a chance to do things now that we are connected
    // note that is will happen before any queued messages
    if (afterConnectedCallback && typeof afterConnectedCallback === "function") {
      afterConnectedCallback();
    }

    // Now send any messages that have been queued up ...
    while (postMessageQueue.length > 0) {
      post(postMessageQueue.shift());
    }
  });

  window.addEventListener('message', receiveMessage, false);

  // Public API.
  return {
    post: post,
    addListener: addListener,
    removeListener: removeListener,
    disconnect: disconnect,
    getTargetWindow: getTargetWindow,
    targetOrigin: targetOrigin
  };
};

},{"./structured-clone":4}],4:[function(require,module,exports){
var featureSupported = {
  'structuredClones': 0
};

(function () {
  var result = 0;

  if (!!window.postMessage) {
    try {
      // Spec states you can't transmit DOM nodes and it will throw an error
      // postMessage implementations that support cloned data will throw.
      window.postMessage(document.createElement("a"), "*");
    } catch (e) {
      // BBOS6 throws but doesn't pass through the correct exception
      // so check error message
      result = (e.DATA_CLONE_ERR || e.message === "Cannot post cyclic structures.") ? 1 : 0;
      featureSupported = {
        'structuredClones': result
      };
    }
  }
}());

exports.supported = function supported() {
  return featureSupported && featureSupported.structuredClones > 0;
};

},{}],5:[function(require,module,exports){
module.exports = {
  /**
   * Allows to communicate with an iframe.
   */
  ParentEndpoint:  require('./lib/parent-endpoint'),
  /**
   * Allows to communicate with a parent page.
   * IFrameEndpoint is a singleton, as iframe can't have multiple parents anyway.
   */
  getIFrameEndpoint: require('./lib/iframe-endpoint'),
  structuredClone: require('./lib/structured-clone'),

  // TODO: May be misnamed
  IframePhoneRpcEndpoint: require('./lib/iframe-phone-rpc-endpoint')

};

},{"./lib/iframe-endpoint":1,"./lib/iframe-phone-rpc-endpoint":2,"./lib/parent-endpoint":3,"./lib/structured-clone":4}]},{},[5])
(5)
});
;
/* >>>>>>>>>> BEGIN source/libraries/jquery/jquery.event.drag-2.2.js */
/*! 
 * jquery.event.drag - v 2.2
 * Copyright (c) 2010 Three Dub Media - http://threedubmedia.com
 * Open Source MIT License - http://threedubmedia.com/code/license
 */
// Created: 2008-06-04 
// Updated: 2012-05-21
// REQUIRES: jquery 1.7.x

;(function( $ ){

// add the jquery instance method
$.fn.drag = function( str, arg, opts ){
	// figure out the event type
	var type = typeof str == "string" ? str : "",
	// figure out the event handler...
	fn = $.isFunction( str ) ? str : $.isFunction( arg ) ? arg : null;
	// fix the event type
	if ( type.indexOf("drag") !== 0 ) 
		type = "drag"+ type;
	// were options passed
	opts = ( str == fn ? arg : opts ) || {};
	// trigger or bind event handler
	return fn ? this.bind( type, opts, fn ) : this.trigger( type );
};

// local refs (increase compression)
var $event = $.event, 
$special = $event.special,
// configure the drag special event 
drag = $special.drag = {
	
	// these are the default settings
	defaults: {
		which: 1, // mouse button pressed to start drag sequence
		distance: 0, // distance dragged before dragstart
		not: ':input', // selector to suppress dragging on target elements
		handle: null, // selector to match handle target elements
		relative: false, // true to use "position", false to use "offset"
		touch: true, // [CC] false to suppress touch dragging, true to allow
		drop: true, // false to suppress drop events, true or selector to allow
		click: false // false to suppress click events after dragend (no proxy)
	},
	
	// the key name for stored drag data
	datakey: "dragdata",
	
	// prevent bubbling for better performance
	noBubble: true,
	
	// count bound related events
	add: function( obj ){ 
		// read the interaction data
		var data = $.data( this, drag.datakey ),
		// read any passed options 
		opts = obj.data || {};
		// count another realted event
		data.related += 1;
		// extend data options bound with this event
		// don't iterate "opts" in case it is a node 
		$.each( drag.defaults, function( key, def ){
			if ( opts[ key ] !== undefined )
				data[ key ] = opts[ key ];
		});
	},
	
	// forget unbound related events
	remove: function(){
		$.data( this, drag.datakey ).related -= 1;
	},
	
	// configure interaction, capture settings
	setup: function(){
		// check for related events
		if ( $.data( this, drag.datakey ) ) 
			return;
		// initialize the drag data with copied defaults
		var data = $.extend({ related:0 }, drag.defaults );
		// store the interaction data
		$.data( this, drag.datakey, data );
		// bind the mousedown event, which starts drag interactions
		$event.add( this, "touchstart mousedown", drag.init, data );
		// prevent image dragging in IE...
		if ( this.attachEvent ) 
			this.attachEvent("ondragstart", drag.dontstart ); 
	},
	
	// destroy configured interaction
	teardown: function(){
		var data = $.data( this, drag.datakey ) || {};
		// check for related events
		if ( data.related ) 
			return;
		// remove the stored data
		$.removeData( this, drag.datakey );
		// remove the mousedown event
		$event.remove( this, "touchstart mousedown", drag.init );
		// enable text selection
		drag.textselect( true ); 
		// un-prevent image dragging in IE...
		if ( this.detachEvent ) 
			this.detachEvent("ondragstart", drag.dontstart ); 
	},
		
	// initialize the interaction
	init: function( event ){ 
		// sorry, only one touch at a time
		if ( drag.touched ) 
			return;
		// the drag/drop interaction data
		var dd = event.data, results;
		// [CC] allow disabling of touch-dragging
		if ( !dd.touch && event.type == 'touchstart') return;
		// check the which directive
		if ( event.which != 0 && dd.which > 0 && event.which != dd.which ) 
			return; 
		// check for suppressed selector
		if ( $( event.target ).is( dd.not ) ) 
			return;
		// check for handle selector
		if ( dd.handle && !$( event.target ).closest( dd.handle, event.currentTarget ).length ) 
			return;

		drag.touched = event.type == 'touchstart' ? this : null;
		dd.propagates = 1;
		dd.mousedown = this;
		dd.interactions = [ drag.interaction( this, dd ) ];
		dd.target = event.target;
		dd.pageX = event.pageX;
		dd.pageY = event.pageY;
		dd.dragging = null;
		// handle draginit event... 
		results = drag.hijack( event, "draginit", dd );
		// early cancel
		if ( !dd.propagates )
			return;
		// flatten the result set
		results = drag.flatten( results );
		// insert new interaction elements
		if ( results && results.length ){
			dd.interactions = [];
			var elem = this;	// [CC] capture `this` outside $.each
			$.each( results, function(){
				dd.interactions.push( drag.interaction( elem, dd ) );
			});
		}
		// remember how many interactions are propagating
		dd.propagates = dd.interactions.length;
		// locate and init the drop targets
		if ( dd.drop !== false && $special.drop ) 
			$special.drop.handler( event, dd );
		// disable text selection
		drag.textselect( false ); 
		// bind additional events...
		if ( drag.touched )
			$event.add( drag.touched, "touchmove touchend", drag.handler, dd );
		else 
			$event.add( document, "mousemove mouseup", drag.handler, dd );
		// helps prevent text selection or scrolling
		if ( !drag.touched || dd.live )
			return false;
	},	
	
	// returns an interaction object
	interaction: function( elem, dd ){
		var offset = $( elem )[ dd.relative ? "position" : "offset" ]() || { top:0, left:0 };
		return {
			drag: elem, 
			callback: new drag.callback(), 
			droppable: [],
			offset: offset
		};
	},
	
	// handle drag-releatd DOM events
	handler: function( event ){ 
		// read the data before hijacking anything
		var dd = event.data;	
		// handle various events
		switch ( event.type ){
			// mousemove, check distance, start dragging
			case !dd.dragging && 'touchmove': 
				event.preventDefault();
			case !dd.dragging && 'mousemove':
				//  drag tolerance, x² + y² = distance²
				if ( Math.pow(  event.pageX-dd.pageX, 2 ) + Math.pow(  event.pageY-dd.pageY, 2 ) < Math.pow( dd.distance, 2 ) ) 
					break; // distance tolerance not reached
				event.target = dd.target; // force target from "mousedown" event (fix distance issue)
				drag.hijack( event, "dragstart", dd ); // trigger "dragstart"
				if ( dd.propagates ) // "dragstart" not rejected
					dd.dragging = true; // activate interaction
			// mousemove, dragging
			case 'touchmove':
				event.preventDefault();
			case 'mousemove':
				if ( dd.dragging ){
					// trigger "drag"		
					drag.hijack( event, "drag", dd );
					if ( dd.propagates ){
						// manage drop events
						if ( dd.drop !== false && $special.drop )
							$special.drop.handler( event, dd ); // "dropstart", "dropend"							
						break; // "drag" not rejected, stop		
					}
					event.type = "mouseup"; // helps "drop" handler behave
				}
			// mouseup, stop dragging
			case 'touchend': 
			case 'mouseup': 
			default:
				if ( drag.touched )
					$event.remove( drag.touched, "touchmove touchend", drag.handler ); // remove touch events
				else 
					$event.remove( document, "mousemove mouseup", drag.handler ); // remove page events	
				if ( dd.dragging ){
					if ( dd.drop !== false && $special.drop )
						$special.drop.handler( event, dd ); // "drop"
					drag.hijack( event, "dragend", dd ); // trigger "dragend"	
				}
				drag.textselect( true ); // enable text selection
				// if suppressing click events...
				if ( dd.click === false && dd.dragging )
					$.data( dd.mousedown, "suppress.click", new Date().getTime() + 5 );
				dd.dragging = drag.touched = false; // deactivate element	
				break;
		}
	},
		
	// re-use event object for custom events
	hijack: function( event, type, dd, x, elem ){
		// not configured
		if ( !dd ) 
			return;
		// remember the original event and type
		var orig = { event:event.originalEvent, type:event.type },
		// is the event drag related or drog related?
		mode = type.indexOf("drop") ? "drag" : "drop",
		// iteration vars
		result, i = x || 0, ia, $elems, callback,
		len = !isNaN( x ) ? x : dd.interactions.length;
		// modify the event type
		event.type = type;
		// remove the original event
		event.originalEvent = null;
		// initialize the results
		dd.results = [];
		// handle each interacted element
		do if ( ia = dd.interactions[ i ] ){
			// validate the interaction
			if ( type !== "dragend" && ia.cancelled )
				continue;
			// set the dragdrop properties on the event object
			callback = drag.properties( event, dd, ia );
			// prepare for more results
			ia.results = [];
			// handle each element
			$( elem || ia[ mode ] || dd.droppable ).each(function( p, subject ){
				// identify drag or drop targets individually
				callback.target = subject;
				// force propagtion of the custom event
				event.isPropagationStopped = function(){ return false; };
				// handle the event	
				result = subject ? $event.dispatch.call( subject, event, callback ) : null;
				// stop the drag interaction for this element
				if ( result === false ){
					if ( mode == "drag" ){
						ia.cancelled = true;
						dd.propagates -= 1;
					}
					if ( type == "drop" ){
						ia[ mode ][p] = null;
					}
				}
				// assign any dropinit elements
				else if ( type == "dropinit" )
					ia.droppable.push( drag.element( result ) || subject );
				// accept a returned proxy element 
				if ( type == "dragstart" )
					ia.proxy = $( drag.element( result ) || ia.drag )[0];
				// remember this result	
				ia.results.push( result );
				// forget the event result, for recycling
				delete event.result;
				// break on cancelled handler
				if ( type !== "dropinit" )
					return result;
			});	
			// flatten the results	
			dd.results[ i ] = drag.flatten( ia.results );	
			// accept a set of valid drop targets
			if ( type == "dropinit" )
				ia.droppable = drag.flatten( ia.droppable );
			// locate drop targets
			if ( type == "dragstart" && !ia.cancelled )
				callback.update(); 
		}
		while ( ++i < len )
		// restore the original event & type
		event.type = orig.type;
		event.originalEvent = orig.event;
		// return all handler results
		return drag.flatten( dd.results );
	},
		
	// extend the callback object with drag/drop properties...
	properties: function( event, dd, ia ){		
		var obj = ia.callback;
		// elements
		obj.drag = ia.drag;
		obj.proxy = ia.proxy || ia.drag;
		// starting mouse position
		obj.startX = dd.pageX;
		obj.startY = dd.pageY;
		// current distance dragged
		obj.deltaX = event.pageX - dd.pageX;
		obj.deltaY = event.pageY - dd.pageY;
		// original element position
		obj.originalX = ia.offset.left;
		obj.originalY = ia.offset.top;
		// adjusted element position
		obj.offsetX = obj.originalX + obj.deltaX; 
		obj.offsetY = obj.originalY + obj.deltaY;
		// assign the drop targets information
		obj.drop = drag.flatten( ( ia.drop || [] ).slice() );
		obj.available = drag.flatten( ( ia.droppable || [] ).slice() );
		return obj;	
	},
	
	// determine is the argument is an element or jquery instance
	element: function( arg ){
		if ( arg && ( arg.jquery || arg.nodeType == 1 ) )
			return arg;
	},
	
	// flatten nested jquery objects and arrays into a single dimension array
	flatten: function( arr ){
		return $.map( arr, function( member ){
			return member && member.jquery ? $.makeArray( member ) : 
				member && member.length ? drag.flatten( member ) : member;
		});
	},
	
	// toggles text selection attributes ON (true) or OFF (false)
	textselect: function( bool ){ 
		$( document )[ bool ? "unbind" : "bind" ]("selectstart", drag.dontstart )
			.css("MozUserSelect", bool ? "" : "none" );
		// .attr("unselectable", bool ? "off" : "on" )
		document.unselectable = bool ? "off" : "on"; 
	},
	
	// suppress "selectstart" and "ondragstart" events
	dontstart: function(){ 
		return false; 
	},
	
	// a callback instance contructor
	callback: function(){}
	
};

// callback methods
drag.callback.prototype = {
	update: function(){
		if ( $special.drop && this.available.length )
			$.each( this.available, function( i ){
				$special.drop.locate( this, i );
			});
	}
};

// patch $.event.$dispatch to allow suppressing clicks
var $dispatch = $event.dispatch;
$event.dispatch = function( event ){
	if ( $.data( this, "suppress."+ event.type ) - new Date().getTime() > 0 ){
		$.removeData( this, "suppress."+ event.type );
		return;
	}
	return $dispatch.apply( this, arguments );
};

// event fix hooks for touch events...
var touchHooks = 
$event.fixHooks.touchstart = 
$event.fixHooks.touchmove = 
$event.fixHooks.touchend =
$event.fixHooks.touchcancel = {
	props: "clientX clientY pageX pageY screenX screenY".split( " " ),
	filter: function( event, orig ) {
		if ( orig ){
			var touched = ( orig.touches && orig.touches[0] )
				|| ( orig.changedTouches && orig.changedTouches[0] )
				|| null; 
			// iOS webkit: touchstart, touchmove, touchend
			if ( touched ) 
				$.each( touchHooks.props, function( i, prop ){
					event[ prop ] = touched[ prop ];
				});
		}
		return event;
	}
};

// share the same special event configuration with related events...
$special.draginit = $special.dragstart = $special.dragend = drag;

})( jQuery );

/* >>>>>>>>>> BEGIN source/libraries/raphaelExt.js */
// ==========================================================================
//                          Raphael Extensions
//
//  Defines extensions to Raphael using Raphael's customization capabilities
//
//  Author:   Jonathan Sandoe
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

if (window.sc_require) {
    sc_require('libraries/raphael');
}

/**
 * @receiver {R}
 * @return {Raphael path element} line from (x1, y1) to (x2, y2)
 * @param {Number} each parameter is coordinate relative to the canvas
 * @example canvas.line(0, 0, 45, 70)
 */
if (!Raphael.fn.line) {
    Raphael.fn.line = function(x1, y1, x2, y2) {
        // first, create the line graphic using the existing path api
        var x = this.path("M" + x1 + "," + y1 + "L" + x2 + "," + y2)
        // create attributes, so they can be reported.
//        x.attrs.x1 = x1;
//        x.attrs.y1 = y1;
//        x.attrs.x2 = x2;
//        x.attrs.y2 = y2;
//        // next, create setters for the attributes.
//        x.paper.customAttributes["x1"] = function (num) {
//            var p = this.attr("path");
//            p[0][1] = num;
//            return{"path": p};
//        }
//        x.paper.customAttributes["y1"] = function (num) {
//            var p = this.attr("path");
//            p[0][2] = num;
//            return{"path": p};
//        }
//        x.paper.customAttributes["x2"] = function (num) {
//            var p = this.attr("path");
//            p[1][1] = num;
//            return{"path": p};
//        }
//        x.paper.customAttributes["y2"] = function (num) {
//            var p = this.attr("path");
//            p[1][2] = num;
//            return{"path": p};
//        }
        return x;
    }
}

/**
 * Add the given class name to the classnames belonging to the receiving element
 * The new name will not be added if already present.
 * @param {String}
  * @return {Raphael element}
 */
if (!Raphael.el.addClass) {
    Raphael.el.addClass = function (newClass) {
        var classNameEl = this.node.className;
        var classes = classNameEl.baseVal.trim().split(" ");

        if (classes.indexOf(newClass) < 0) {
            classes.push(newClass);
            classNameEl.baseVal = classes.join(' ');
        }
        return this;
    }
}
if (!Raphael.el.setClass) {
    Raphael.el.setClass = function (newClass) {
        var classNameEl = this.node.className;
        classNameEl.baseVal = newClass;
        return this;
    }
}

if (!Raphael.el.hasClass) {
  Raphael.el.hasClass = function (myClass) {
    var classNameEl = this.node.className;
    var classes = classNameEl.baseVal;
    if (classes.indexOf(myClass) < 0) {
      return false;
    } else {
      return new RegExp('\b' + myClass + '\b').test(classes);
    }

  }
}

/**
 * Remove the given class name from those belonging to the receiver.
 * Do nothing if not present.
 * @receiver {Raphael element}
 * @param {String}
 * @return {Raphael element }
 */
if (!Raphael.el.removeClass) {
  Raphael.el.removeClass = function (myClass) {
    function removeWord(str, word) {
      var rslt, words, wordIndex;
      if (str === word) {
        rslt = '';
      } else if (!str) {
        rslt = str;
      } else {
        words = str.split(" ");
        wordIndex = words.indexOf(word);
        if (wordIndex >= 0) {
          words.splice(wordIndex, 1)
          rslt = words.join(' ');
        } else {
          rslt = str;
        }
      }
      return rslt;
    }
    var classes = this.node.className.baseVal;

    var newClasses = removeWord(classes, myClass);

    this.node.className.baseVal = newClasses;
  }
}

/**
 * Set an id on the svg element belonging to the receiver.
 * @receiver {Raphael element}
 * @param {String}
 * @return {Raphael element }
 */
if (!Raphael.el.setId) {
    Raphael.el.setId = function (myId) {
        this.node.id.baseVal = myId;
        return this;
    }
}

/**
 * Returns true if the Raphael element has been hidden.
 * @receiver {Raphael element}
 * @returns  {Boolean}  True if the element is hidden, false otherwise.
 */
if (!Raphael.el.isHidden) {
  Raphael.el.isHidden = function() {
    return (this.node.style.display === "none");
  }
}

/* >>>>>>>>>> BEGIN source/libraries/slickgrid/plugins/slick.headermenu.js */
(function ($) {
  // register namespace
  $.extend(true, window, {
    "Slick": {
      "Plugins": {
        "HeaderMenu": HeaderMenu
      }
    }
  });


  /***
   * A plugin to add drop-down menus to column headers.
   *
   * USAGE:
   *
   * Add the plugin .js & .css files and register it with the grid.
   *
   * To specify a menu in a column header, extend the column definition like so:
   *
   *   var columns = [
   *     {
   *       id: 'myColumn',
   *       name: 'My column',
   *
   *       // This is the relevant part
   *       header: {
   *          menu: {
   *              items: [
   *                {
   *                  // menu item options
   *                },
   *                {
   *                  // menu item options
   *                }
   *              ]
   *          }
   *       }
   *     }
   *   ];
   *
   *
   * Available menu options:
   *    tooltip:      Menu button tooltip.
   *
   *
   * Available menu item options:
   *    title:        Menu item text.
   *    disabled:     Whether the item is disabled.
   *    tooltip:      Item tooltip.
   *    command:      A command identifier to be passed to the onCommand event handlers.
   *    iconCssClass: A CSS class to be added to the menu item icon.
   *    iconImage:    A url to the icon image.
   *
   *
   * The plugin exposes the following events:
   *    onBeforeMenuShow:   Fired before the menu is shown.  You can customize the menu or dismiss it by returning false.
   *        Event args:
   *            grid:     Reference to the grid.
   *            column:   Column definition.
   *            menu:     Menu options.  Note that you can change the menu items here.
   *
   *    onCommand:    Fired on menu item click for buttons with 'command' specified.
   *        Event args:
   *            grid:     Reference to the grid.
   *            column:   Column definition.
   *            command:  Button command identified.
   *            button:   Button options.  Note that you can change the button options in your
   *                      event handler, and the column header will be automatically updated to
   *                      reflect them.  This is useful if you want to implement something like a
   *                      toggle button.
   *
   *
   * @param options {Object} Options:
   *    buttonCssClass:   an extra CSS class to add to the menu button
   *    buttonImage:      a url to the menu button image (default '../images/down.gif')
   * @class Slick.Plugins.HeaderButtons
   * @constructor
   */
  function HeaderMenu(options) {
    var _grid;
    var _self = this;
    var _handler = new Slick.EventHandler();
    var _defaults = {
      buttonCssClass: null,
      buttonImage: "../images/down.gif"
    };
    var $menu;
    var $activeHeaderColumn;


    function init(grid) {
      options = $.extend(true, {}, _defaults, options);
      _grid = grid;
      _handler
        .subscribe(_grid.onHeaderCellRendered, handleHeaderCellRendered)
        .subscribe(_grid.onBeforeHeaderCellDestroy, handleBeforeHeaderCellDestroy);

      // Force the grid to re-render the header now that the events are hooked up.
      _grid.setColumns(_grid.getColumns());

      // Hide the menu on outside click.
      $(document.body).bind("mousedown", handleBodyMouseDown);
      $(document.body).bind("touchstart", handleBodyMouseDown);
      $(document.body).bind("keydown", handleBodyKeyDown);
    }


    function destroy() {
      _handler.unsubscribeAll();
      $(document.body).unbind("mousedown", handleBodyMouseDown);
      $(document.body).unbind("touchstart", handleBodyMouseDown);
      $(document.body).unbind("keydown", handleBodyKeyDown);
    }


    function handleBodyMouseDown(e) {
      if ($menu && $menu[0] != e.target && !$.contains($menu[0], e.target)) {
        hideMenu();
      }
    }


    function handleBodyKeyDown(e) {
      if ($menu && (e.keyCode === 27)) {
        hideMenu();
        e.preventDefault();
        e.stopPropagation();
      }
    }


    function hideMenu() {
      if ($menu) {
        $menu.remove();
        $menu = null;
        $activeHeaderColumn
          .removeClass("slick-header-column-active");
      }
    }

    function handleHeaderCellRendered(e, args) {
      var column = args.column;
      var menu = column.header && column.header.menu;

      if (menu) {
        var buttonDivHtml = options.buttonIsCell
                              ? "<div style=\"display:none\"></div>"
                              : "<div></div>",
            $el = $(buttonDivHtml)
                    .addClass("slick-header-menubutton")
                    .data("column", column)
                    .data("menu", menu);

        if (options.buttonCssClass) {
          $el.addClass(options.buttonCssClass);
        }

        if (options.buttonImage) {
          $el.css("background-image", "url(" + options.buttonImage + ")");
        }

        if (menu.tooltip) {
          $el.attr("title", menu.tooltip);
        }

        $el.appendTo(args.node);

        if (options.buttonIsCell) {
          $(args.node).bind("click", showMenu);
        }
        else {
          $el.bind("click", showMenu);
        }
      }
    }


    function handleBeforeHeaderCellDestroy(e, args) {
      var column = args.column;

      if (column.header && column.header.menu) {
        $(args.node).find(".slick-header-menubutton").remove();
      }
    }


    function showMenu(e) {
      var $menuButton = options.buttonIsCell
                          ? $(this).find(".slick-header-menubutton")
                          : $(this);
      var menu = $menuButton.data("menu");
      var columnDef = $menuButton.data("column");

      // Let the user modify the menu or cancel altogether,
      // or provide alternative menu implementation.
      if (_self.onBeforeMenuShow.notify({
          "grid": _grid,
          "column": columnDef,
          "menu": menu
        }, e, _self) == false) {
        return;
      }


      if (!$menu) {
        $menu = $("<div class='slick-header-menu'></div>")
          .appendTo(document.body);
      }
      $menu.empty();


      // Construct the menu items.
      for (var i = 0; i < menu.items.length; i++) {
        var item = menu.items[i];

        var $li = $("<div class='slick-header-menuitem'></div>")
          .data("command", item.command || '')
          .data("column", columnDef)
          .data("item", item)
          .bind("click", handleMenuItemClick)
          .appendTo($menu);

        if (item.disabled) {
          $li.addClass("slick-header-menuitem-disabled");
        }

        if (item.tooltip) {
          $li.attr("title", item.tooltip);
        }

        var $icon = $("<div class='slick-header-menuicon'></div>")
          .appendTo($li);

        if (item.iconCssClass) {
          $icon.addClass(item.iconCssClass);
        }

        if (item.iconImage) {
          $icon.css("background-image", "url(" + item.iconImage + ")");
        }

        $("<span class='slick-header-menucontent'></span>")
          .text(item.title)
          .appendTo($li);
      }


      // Position the menu.
      $menu
        .css("top", $(this).offset().top + $(this).height())
        .css("left", $(this).offset().left);


      // Mark the header as active to keep the highlighting.
      $activeHeaderColumn = $menuButton.closest(".slick-header-column");
      $activeHeaderColumn
        .addClass("slick-header-column-active");
    }


    function handleMenuItemClick(e) {
      var command = $(this).data("command");
      var columnDef = $(this).data("column");
      var item = $(this).data("item");

      if (item.disabled) {
        return;
      }

      hideMenu();

      if (command != null && command != '') {
        _self.onCommand.notify({
            "grid": _grid,
            "column": columnDef,
            "command": command,
            "item": item
          }, e, _self);
      }

      // Stop propagation so that it doesn't register as a header click event.
      e.preventDefault();
      e.stopPropagation();
    }

    $.extend(this, {
      "init": init,
      "destroy": destroy,
      "hideMenu": hideMenu,

      "onBeforeMenuShow": new Slick.Event(),
      "onCommand": new Slick.Event()
    });
  }
})(jQuery);
/* >>>>>>>>>> BEGIN source/libraries/slickgrid/plugins/slick.rowselectionmodel.js */
(function ($) {
  // register namespace
  $.extend(true, window, {
    "Slick": {
      "RowSelectionModel": RowSelectionModel
    }
  });

  function RowSelectionModel(options) {
    var _grid;
    var _ranges = [];
    var _self = this;
    var _handler = new Slick.EventHandler();
    var _inHandler;
    var _options;
    var _defaults = {
      selectActiveRow: true
    };

    function init(grid) {
      _options = $.extend(true, {}, _defaults, options);
      _grid = grid;
      _handler.subscribe(_grid.onActiveCellChanged,
          wrapHandler(handleActiveCellChange));
      _handler.subscribe(_grid.onKeyDown,
          wrapHandler(handleKeyDown));
      _handler.subscribe(_grid.onClick,
          wrapHandler(handleClick));
    }

    function destroy() {
      _handler.unsubscribeAll();
    }

    function wrapHandler(handler) {
      return function () {
        var result;
        if (!_inHandler) {
          _inHandler = true;
          result = handler.apply(this, arguments);
          _inHandler = false;
          return result;
        }
      };
    }

    function rangesToRows(ranges) {
      var rows = [];
      for (var i = 0; i < ranges.length; i++) {
        for (var j = ranges[i].fromRow; j <= ranges[i].toRow; j++) {
          rows.push(j);
        }
      }
      return rows;
    }

    function rowsToRanges(rows) {
      var ranges = [];
      var lastCell = _grid.getColumns().length - 1;
      for (var i = 0; i < rows.length; i++) {
        ranges.push(new Slick.Range(rows[i], 0, rows[i], lastCell));
      }
      return ranges;
    }

    function getRowsRange(from, to) {
      var i, rows = [];
      for (i = from; i <= to; i++) {
        rows.push(i);
      }
      for (i = to; i < from; i++) {
        rows.push(i);
      }
      return rows;
    }

    function getSelectedRows() {
      return rangesToRows(_ranges);
    }

    function setSelectedRows(rows) {
      setSelectedRanges(rowsToRanges(rows));
    }

    function setSelectedRanges(ranges) {
      _ranges = ranges;
      _self.onSelectedRangesChanged.notify(_ranges);
    }

    function getSelectedRanges() {
      return _ranges;
    }

    function handleActiveCellChange(e, data) {
      if (_options.selectActiveRow && data.row != null) {
        setSelectedRanges([new Slick.Range(data.row, 0, data.row, _grid.getColumns().length - 1)]);
      }
    }

    function handleKeyDown(e) {
      var activeRow = _grid.getActiveCell();
      if (activeRow && e.shiftKey && !e.ctrlKey && !e.altKey && !e.metaKey && (e.which == 38 || e.which == 40)) {
        var selectedRows = getSelectedRows();
        selectedRows.sort(function (x, y) {
          return x - y
        });

        if (!selectedRows.length) {
          selectedRows = [activeRow.row];
        }

        var top = selectedRows[0];
        var bottom = selectedRows[selectedRows.length - 1];
        var active;

        if (e.which == 40) {
          active = activeRow.row < bottom || top == bottom ? ++bottom : ++top;
        } else {
          active = activeRow.row < bottom ? --bottom : --top;
        }

        if (active >= 0 && active < _grid.getDataLength()) {
          _grid.scrollRowIntoView(active);
          _ranges = rowsToRanges(getRowsRange(top, bottom));
          setSelectedRanges(_ranges);
        }

        e.preventDefault();
        e.stopPropagation();
      }
    }

    function handleClick(e) {
      var cell = _grid.getCellFromEvent(e);
      if (!cell || !_grid.canCellBeActive(cell.row, cell.cell)) {
        return false;
      }

      var selection = rangesToRows(_ranges);
      var idx = $.inArray(cell.row, selection);

      if (!e.ctrlKey && !e.shiftKey && !e.metaKey) {
        return false;
      }
      else if (_grid.getOptions().multiSelect) {
        if (idx === -1 && (e.ctrlKey || e.metaKey)) {
          selection.push(cell.row);
          _grid.setActiveCell(cell.row, cell.cell);
        } else if (idx !== -1 && (e.ctrlKey || e.metaKey)) {
          selection = $.grep(selection, function (o, i) {
            return (o !== cell.row);
          });
          _grid.setActiveCell(cell.row, cell.cell);
        } else if (selection.length && e.shiftKey) {
          var last = selection.pop();
          var from = Math.min(cell.row, last);
          var to = Math.max(cell.row, last);
          selection = [];
          for (var i = from; i <= to; i++) {
            if (i !== last) {
              selection.push(i);
            }
          }
          selection.push(last);
          _grid.setActiveCell(cell.row, cell.cell);
        }
      }

      _ranges = rowsToRanges(selection);
      setSelectedRanges(_ranges);
      e.stopImmediatePropagation();

      return true;
    }

    $.extend(this, {
      "getSelectedRows": getSelectedRows,
      "setSelectedRows": setSelectedRows,

      "getSelectedRanges": getSelectedRanges,
      "setSelectedRanges": setSelectedRanges,

      "init": init,
      "destroy": destroy,

      "onSelectedRangesChanged": new Slick.Event()
    });
  }
})(jQuery);
/* >>>>>>>>>> BEGIN source/libraries/slickgrid/slick.core.js */
/***
 * Contains core SlickGrid classes.
 * @module Core
 * @namespace Slick
 */

(function ($) {
  // register namespace
  $.extend(true, window, {
    "Slick": {
      "Event": Event,
      "EventData": EventData,
      "EventHandler": EventHandler,
      "Range": Range,
      "NonDataRow": NonDataItem,
      "Group": Group,
      "GroupTotals": GroupTotals,
      "EditorLock": EditorLock,

      /***
       * A global singleton editor lock.
       * @class GlobalEditorLock
       * @static
       * @constructor
       */
      "GlobalEditorLock": new EditorLock()
    }
  });

  /***
   * An event object for passing data to event handlers and letting them control propagation.
   * <p>This is pretty much identical to how W3C and jQuery implement events.</p>
   * @class EventData
   * @constructor
   */
  function EventData() {
    var isPropagationStopped = false;
    var isImmediatePropagationStopped = false;

    /***
     * Stops event from propagating up the DOM tree.
     * @method stopPropagation
     */
    this.stopPropagation = function () {
      isPropagationStopped = true;
    };

    /***
     * Returns whether stopPropagation was called on this event object.
     * @method isPropagationStopped
     * @return {Boolean}
     */
    this.isPropagationStopped = function () {
      return isPropagationStopped;
    };

    /***
     * Prevents the rest of the handlers from being executed.
     * @method stopImmediatePropagation
     */
    this.stopImmediatePropagation = function () {
      isImmediatePropagationStopped = true;
    };

    /***
     * Returns whether stopImmediatePropagation was called on this event object.\
     * @method isImmediatePropagationStopped
     * @return {Boolean}
     */
    this.isImmediatePropagationStopped = function () {
      return isImmediatePropagationStopped;
    }
  }

  /***
   * A simple publisher-subscriber implementation.
   * @class Event
   * @constructor
   */
  function Event() {
    var handlers = [];

    /***
     * Adds an event handler to be called when the event is fired.
     * <p>Event handler will receive two arguments - an <code>EventData</code> and the <code>data</code>
     * object the event was fired with.<p>
     * @method subscribe
     * @param fn {Function} Event handler.
     */
    this.subscribe = function (fn) {
      handlers.push(fn);
    };

    /***
     * Removes an event handler added with <code>subscribe(fn)</code>.
     * @method unsubscribe
     * @param fn {Function} Event handler to be removed.
     */
    this.unsubscribe = function (fn) {
      for (var i = handlers.length - 1; i >= 0; i--) {
        if (handlers[i] === fn) {
          handlers.splice(i, 1);
        }
      }
    };

    /***
     * Fires an event notifying all subscribers.
     * @method notify
     * @param args {Object} Additional data object to be passed to all handlers.
     * @param e {EventData}
     *      Optional.
     *      An <code>EventData</code> object to be passed to all handlers.
     *      For DOM events, an existing W3C/jQuery event object can be passed in.
     * @param scope {Object}
     *      Optional.
     *      The scope ("this") within which the handler will be executed.
     *      If not specified, the scope will be set to the <code>Event</code> instance.
     */
    this.notify = function (args, e, scope) {
      e = e || new EventData();
      scope = scope || this;

      var returnValue;
      for (var i = 0; i < handlers.length && !(e.isPropagationStopped() || e.isImmediatePropagationStopped()); i++) {
        returnValue = handlers[i].call(scope, e, args);
      }

      return returnValue;
    };
  }

  function EventHandler() {
    var handlers = [];

    this.subscribe = function (event, handler) {
      handlers.push({
        event: event,
        handler: handler
      });
      event.subscribe(handler);

      return this;  // allow chaining
    };

    this.unsubscribe = function (event, handler) {
      var i = handlers.length;
      while (i--) {
        if (handlers[i].event === event &&
            handlers[i].handler === handler) {
          handlers.splice(i, 1);
          event.unsubscribe(handler);
          return;
        }
      }

      return this;  // allow chaining
    };

    this.unsubscribeAll = function () {
      var i = handlers.length;
      while (i--) {
        handlers[i].event.unsubscribe(handlers[i].handler);
      }
      handlers = [];

      return this;  // allow chaining
    }
  }

  /***
   * A structure containing a range of cells.
   * @class Range
   * @constructor
   * @param fromRow {Integer} Starting row.
   * @param fromCell {Integer} Starting cell.
   * @param toRow {Integer} Optional. Ending row. Defaults to <code>fromRow</code>.
   * @param toCell {Integer} Optional. Ending cell. Defaults to <code>fromCell</code>.
   */
  function Range(fromRow, fromCell, toRow, toCell) {
    if (toRow === undefined && toCell === undefined) {
      toRow = fromRow;
      toCell = fromCell;
    }

    /***
     * @property fromRow
     * @type {Integer}
     */
    this.fromRow = Math.min(fromRow, toRow);

    /***
     * @property fromCell
     * @type {Integer}
     */
    this.fromCell = Math.min(fromCell, toCell);

    /***
     * @property toRow
     * @type {Integer}
     */
    this.toRow = Math.max(fromRow, toRow);

    /***
     * @property toCell
     * @type {Integer}
     */
    this.toCell = Math.max(fromCell, toCell);

    /***
     * Returns whether a range represents a single row.
     * @method isSingleRow
     * @return {Boolean}
     */
    this.isSingleRow = function () {
      return this.fromRow == this.toRow;
    };

    /***
     * Returns whether a range represents a single cell.
     * @method isSingleCell
     * @return {Boolean}
     */
    this.isSingleCell = function () {
      return this.fromRow == this.toRow && this.fromCell == this.toCell;
    };

    /***
     * Returns whether a range contains a given cell.
     * @method contains
     * @param row {Integer}
     * @param cell {Integer}
     * @return {Boolean}
     */
    this.contains = function (row, cell) {
      return row >= this.fromRow && row <= this.toRow &&
          cell >= this.fromCell && cell <= this.toCell;
    };

    /***
     * Returns a readable representation of a range.
     * @method toString
     * @return {String}
     */
    this.toString = function () {
      if (this.isSingleCell()) {
        return "(" + this.fromRow + ":" + this.fromCell + ")";
      }
      else {
        return "(" + this.fromRow + ":" + this.fromCell + " - " + this.toRow + ":" + this.toCell + ")";
      }
    }
  }


  /***
   * A base class that all special / non-data rows (like Group and GroupTotals) derive from.
   * @class NonDataItem
   * @constructor
   */
  function NonDataItem() {
    this.__nonDataRow = true;
  }


  /***
   * Information about a group of rows.
   * @class Group
   * @extends Slick.NonDataItem
   * @constructor
   */
  function Group() {
    this.__group = true;

    /**
     * Grouping level, starting with 0.
     * @property level
     * @type {Number}
     */
    this.level = 0;

    /***
     * Number of rows in the group.
     * @property count
     * @type {Integer}
     */
    this.count = 0;

    /***
     * Grouping value.
     * @property value
     * @type {Object}
     */
    this.value = null;

    /***
     * Formatted display value of the group.
     * @property title
     * @type {String}
     */
    this.title = null;

    /***
     * Whether a group is collapsed.
     * @property collapsed
     * @type {Boolean}
     */
    this.collapsed = false;

    /***
     * GroupTotals, if any.
     * @property totals
     * @type {GroupTotals}
     */
    this.totals = null;

    /**
     * Rows that are part of the group.
     * @property rows
     * @type {Array}
     */
    this.rows = null;

    /**
     * Sub-groups that are part of the group.
     * @property groups
     * @type {Array}
     */
    this.groups = null;

    /**
     * A unique key used to identify the group.  This key can be used in calls to DataView
     * collapseGroup() or expandGroup().
     * @property groupingKey
     * @type {Object}
     */
    this.groupingKey = null;
  }

  Group.prototype = new NonDataItem();

  /***
   * Compares two Group instances.
   * @method equals
   * @return {Boolean}
   * @param group {Group} Group instance to compare to.
   */
  Group.prototype.equals = function (group) {
    return this.value === group.value &&
        this.count === group.count &&
        this.collapsed === group.collapsed;
  };

  /***
   * Information about group totals.
   * An instance of GroupTotals will be created for each totals row and passed to the aggregators
   * so that they can store arbitrary data in it.  That data can later be accessed by group totals
   * formatters during the display.
   * @class GroupTotals
   * @extends Slick.NonDataItem
   * @constructor
   */
  function GroupTotals() {
    this.__groupTotals = true;

    /***
     * Parent Group.
     * @param group
     * @type {Group}
     */
    this.group = null;
  }

  GroupTotals.prototype = new NonDataItem();

  /***
   * A locking helper to track the active edit controller and ensure that only a single controller
   * can be active at a time.  This prevents a whole class of state and validation synchronization
   * issues.  An edit controller (such as SlickGrid) can query if an active edit is in progress
   * and attempt a commit or cancel before proceeding.
   * @class EditorLock
   * @constructor
   */
  function EditorLock() {
    var activeEditController = null;

    /***
     * Returns true if a specified edit controller is active (has the edit lock).
     * If the parameter is not specified, returns true if any edit controller is active.
     * @method isActive
     * @param editController {EditController}
     * @return {Boolean}
     */
    this.isActive = function (editController) {
      return (editController ? activeEditController === editController : activeEditController !== null);
    };

    /***
     * Sets the specified edit controller as the active edit controller (acquire edit lock).
     * If another edit controller is already active, and exception will be thrown.
     * @method activate
     * @param editController {EditController} edit controller acquiring the lock
     */
    this.activate = function (editController) {
      if (editController === activeEditController) { // already activated?
        return;
      }
      if (activeEditController !== null) {
        throw "SlickGrid.EditorLock.activate: an editController is still active, can't activate another editController";
      }
      if (!editController.commitCurrentEdit) {
        throw "SlickGrid.EditorLock.activate: editController must implement .commitCurrentEdit()";
      }
      if (!editController.cancelCurrentEdit) {
        throw "SlickGrid.EditorLock.activate: editController must implement .cancelCurrentEdit()";
      }
      activeEditController = editController;
    };

    /***
     * Unsets the specified edit controller as the active edit controller (release edit lock).
     * If the specified edit controller is not the active one, an exception will be thrown.
     * @method deactivate
     * @param editController {EditController} edit controller releasing the lock
     */
    this.deactivate = function (editController) {
      if (activeEditController !== editController) {
        throw "SlickGrid.EditorLock.deactivate: specified editController is not the currently active one";
      }
      activeEditController = null;
    };

    /***
     * Attempts to commit the current edit by calling "commitCurrentEdit" method on the active edit
     * controller and returns whether the commit attempt was successful (commit may fail due to validation
     * errors, etc.).  Edit controller's "commitCurrentEdit" must return true if the commit has succeeded
     * and false otherwise.  If no edit controller is active, returns true.
     * @method commitCurrentEdit
     * @return {Boolean}
     */
    this.commitCurrentEdit = function () {
      return (activeEditController ? activeEditController.commitCurrentEdit() : true);
    };

    /***
     * Attempts to cancel the current edit by calling "cancelCurrentEdit" method on the active edit
     * controller and returns whether the edit was successfully cancelled.  If no edit controller is
     * active, returns true.
     * @method cancelCurrentEdit
     * @return {Boolean}
     */
    this.cancelCurrentEdit = function cancelCurrentEdit() {
      return (activeEditController ? activeEditController.cancelCurrentEdit() : true);
    };
  }
})(jQuery);



/* >>>>>>>>>> BEGIN source/libraries/slickgrid/slick.dataview.js */
(function ($) {
  $.extend(true, window, {
    Slick: {
      Data: {
        DataView: DataView,
        Aggregators: {
          Avg: AvgAggregator,
          Min: MinAggregator,
          Max: MaxAggregator,
          Sum: SumAggregator
        }
      }
    }
  });


  /***
   * A sample Model implementation.
   * Provides a filtered view of the underlying data.
   *
   * Relies on the data item having an "id" property uniquely identifying it.
   *
   *  @param  {Object}      options
   *          {Slick.Data.GroupItemMetadataProvider}
   *                        .groupItemMetadataProvider      Grouping helper
   *          {Boolean}     .inlineFilters                  True if the filter expression should
   *                                                        be "inlined" internally for performance.
   *                                                        Inlining should lead to better performance,
   *                                                        but may not work in some circumstances.
   *          {Boolean}     .showExpandedGroupRows [KCPT]   If true, group header rows are shown
   *                                                        for expanded groups as well as
   *                                                        collapsed groups. If false, group
   *                                                        header rows are shown only for
   *                                                        collapsed groups.
   */
  function DataView(options) {
    var self = this;

    var defaults = {
      groupItemMetadataProvider: null,
      inlineFilters: false,
      showExpandedGroupRows: true
    };


    // private
    var idProperty = "id";  // property holding a unique row id
    var items = [];         // data by index
    var rows = [];          // data by row
    var idxById = {};       // indexes by id
    var rowsById = null;    // rows by id; lazy-calculated
    var filter = null;      // filter function
    var updated = null;     // updated item ids
    var suspend = false;    // suspends the recalculation
    var sortAsc = true;
    var fastSortField;
    var sortComparer;
    var refreshHints = {};
    var prevRefreshHints = {};
    var filterArgs;
    var filteredItems = [];
    var compiledFilter;
    var compiledFilterWithCaching;
    var filterCache = [];

    // grouping
    var groupingInfoDefaults = {
      getter: null,
      formatter: null,
      comparer: function(a, b) { return a.value - b.value; },
      aggregators: [],
      aggregateCollapsed: false,
      aggregateChildGroups: false,
      collapsed: false
    };
    var groupingInfos = [];
    var groups = [];
    var toggledGroupsByLevel = [];
    var groupingDelimiter = ':|:';

    var pagesize = 0;
    var pagenum = 0;
    var totalRows = 0;

    // events
    var onRowCountChanged = new Slick.Event();
    var onRowsChanged = new Slick.Event();
    var onPagingInfoChanged = new Slick.Event();

    options = $.extend(true, {}, defaults, options);


    function beginUpdate() {
      suspend = true;
    }

    function endUpdate() {
      suspend = false;
      refresh();
    }

    function setRefreshHints(hints) {
      refreshHints = hints;
    }

    function setFilterArgs(args) {
      filterArgs = args;
    }

    function updateIdxById(startingIndex) {
      startingIndex = startingIndex || 0;
      var id;
      for (var i = startingIndex, l = items.length; i < l; i++) {
        id = items[i][idProperty];
        if (id === undefined) {
          throw "Each data element must implement a unique 'id' property";
        }
        idxById[id] = i;
      }
    }

    function ensureIdUniqueness() {
      var id;
      for (var i = 0, l = items.length; i < l; i++) {
        id = items[i][idProperty];
        if (id === undefined || idxById[id] !== i) {
          throw "Each data element must implement a unique 'id' property";
        }
      }
    }

    function getItems() {
      return items;
    }

    function setItems(data, objectIdProperty) {
      if (objectIdProperty !== undefined) {
        idProperty = objectIdProperty;
      }
      items = filteredItems = data;
      idxById = {};
      updateIdxById();
      ensureIdUniqueness();
      refresh();
    }

    function setPagingOptions(args) {
      if (args.pageSize != undefined) {
        pagesize = args.pageSize;
        pagenum = pagesize ? Math.min(pagenum, Math.max(0, Math.ceil(totalRows / pagesize) - 1)) : 0;
      }

      if (args.pageNum != undefined) {
        pagenum = Math.min(args.pageNum, Math.max(0, Math.ceil(totalRows / pagesize) - 1));
      }

      onPagingInfoChanged.notify(getPagingInfo(), null, self);

      refresh();
    }

    function getPagingInfo() {
      var totalPages = pagesize ? Math.max(1, Math.ceil(totalRows / pagesize)) : 1;
      return {pageSize: pagesize, pageNum: pagenum, totalRows: totalRows, totalPages: totalPages};
    }

    function sort(comparer, ascending) {
      sortAsc = ascending;
      sortComparer = comparer;
      fastSortField = null;
      if (ascending === false) {
        items.reverse();
      }
      items.sort(comparer);
      if (ascending === false) {
        items.reverse();
      }
      idxById = {};
      updateIdxById();
      refresh();
    }

    /***
     * Provides a workaround for the extremely slow sorting in IE.
     * Does a [lexicographic] sort on a give column by temporarily overriding Object.prototype.toString
     * to return the value of that field and then doing a native Array.sort().
     */
    function fastSort(field, ascending) {
      sortAsc = ascending;
      fastSortField = field;
      sortComparer = null;
      var oldToString = Object.prototype.toString;
      Object.prototype.toString = (typeof field == "function") ? field : function () {
        return this[field]
      };
      // an extra reversal for descending sort keeps the sort stable
      // (assuming a stable native sort implementation, which isn't true in some cases)
      if (ascending === false) {
        items.reverse();
      }
      items.sort();
      Object.prototype.toString = oldToString;
      if (ascending === false) {
        items.reverse();
      }
      idxById = {};
      updateIdxById();
      refresh();
    }

    function reSort() {
      if (sortComparer) {
        sort(sortComparer, sortAsc);
      } else if (fastSortField) {
        fastSort(fastSortField, sortAsc);
      }
    }

    function setFilter(filterFn) {
      filter = filterFn;
      if (options.inlineFilters) {
        compiledFilter = compileFilter();
        compiledFilterWithCaching = compileFilterWithCaching();
      }
      refresh();
    }

    function getGrouping() {
      return groupingInfos;
    }

    function setGrouping(groupingInfo) {
      if (!options.groupItemMetadataProvider) {
        options.groupItemMetadataProvider = new Slick.Data.GroupItemMetadataProvider();
      }

      groups = [];
      toggledGroupsByLevel = [];
      groupingInfo = groupingInfo || [];
      groupingInfos = (groupingInfo instanceof Array) ? groupingInfo : [groupingInfo];

      for (var i = 0; i < groupingInfos.length; i++) {
        var gi = groupingInfos[i] = $.extend(true, {}, groupingInfoDefaults, groupingInfos[i]);
        gi.getterIsAFn = typeof gi.getter === "function";

        // pre-compile accumulator loops
        gi.compiledAccumulators = [];
        var idx = gi.aggregators.length;
        while (idx--) {
          gi.compiledAccumulators[idx] = compileAccumulatorLoop(gi.aggregators[idx]);
        }

        toggledGroupsByLevel[i] = {};
      }

      refresh();
    }

    /**
     * @deprecated Please use {@link setGrouping}.
     */
    function groupBy(valueGetter, valueFormatter, sortComparer) {
      if (valueGetter == null) {
        setGrouping([]);
        return;
      }

      setGrouping({
        getter: valueGetter,
        formatter: valueFormatter,
        comparer: sortComparer
      });
    }

    /**
     * @deprecated Please use {@link setGrouping}.
     */
    function setAggregators(groupAggregators, includeCollapsed) {
      if (!groupingInfos.length) {
        throw new Error("At least must setGrouping must be specified before calling setAggregators().");
      }

      groupingInfos[0].aggregators = groupAggregators;
      groupingInfos[0].aggregateCollapsed = includeCollapsed;

      setGrouping(groupingInfos);
    }

    function getItemByIdx(i) {
      return items[i];
    }

    function getIdxById(id) {
      return idxById[id];
    }

    function ensureRowsByIdCache() {
      if (!rowsById) {
        rowsById = {};
        for (var i = 0, l = rows.length; i < l; i++) {
          rowsById[rows[i][idProperty]] = i;
        }
      }
    }

    function getRowById(id) {
      ensureRowsByIdCache();
      return rowsById[id];
    }

    function getItemById(id) {
      return items[idxById[id]];
    }

    function mapIdsToRows(idArray) {
      var rows = [];
      ensureRowsByIdCache();
      for (var i = 0; i < idArray.length; i++) {
        var row = rowsById[idArray[i]];
        if (row != null) {
          rows[rows.length] = row;
        }
      }
      return rows;
    }

    function mapRowsToIds(rowArray) {
      var ids = [];
      for (var i = 0; i < rowArray.length; i++) {
        if (rowArray[i] < rows.length) {
          ids[ids.length] = rows[rowArray[i]][idProperty];
        }
      }
      return ids;
    }

    function updateItem(id, item) {
      if (idxById[id] === undefined || id !== item[idProperty]) {
        throw "Invalid or non-matching id";
      }
      items[idxById[id]] = item;
      if (!updated) {
        updated = {};
      }
      updated[id] = true;
      refresh();
    }

    function insertItem(insertBefore, item) {
      items.splice(insertBefore, 0, item);
      updateIdxById(insertBefore);
      refresh();
    }

    function addItem(item) {
      items.push(item);
      updateIdxById(items.length - 1);
      refresh();
    }

    function deleteItem(id) {
      var idx = idxById[id];
      if (idx === undefined) {
        throw "Invalid id";
      }
      delete idxById[id];
      items.splice(idx, 1);
      updateIdxById(idx);
      refresh();
    }

    function getLength() {
      return rows.length;
    }

    function getItem(i) {
      return rows[i];
    }

    function getItemMetadata(i) {
      var item = rows[i];
      if (item === undefined) {
        return null;
      }

      // overrides for setGrouping rows
      if (item.__group) {
        return options.groupItemMetadataProvider.getGroupRowMetadata(item);
      }

      // overrides for totals rows
      if (item.__groupTotals) {
        return options.groupItemMetadataProvider.getTotalsRowMetadata(item);
      }

      return null;
    }

    function expandCollapseAllGroups(level, collapse) {
      if (level == null) {
        for (var i = 0; i < groupingInfos.length; i++) {
          toggledGroupsByLevel[i] = {};
          groupingInfos[i].collapsed = collapse;
        }
      } else {
        toggledGroupsByLevel[level] = {};
        groupingInfos[level].collapsed = collapse;
      }
      refresh();
    }

    /**
     * @param level {Number} Optional level to collapse.  If not specified, applies to all levels.
     */
    function collapseAllGroups(level) {
      expandCollapseAllGroups(level, true);
    }

    /**
     * @param level {Number} Optional level to expand.  If not specified, applies to all levels.
     */
    function expandAllGroups(level) {
      expandCollapseAllGroups(level, false);
    }

    function expandCollapseGroup(level, groupingKey, collapse) {
      toggledGroupsByLevel[level][groupingKey] = groupingInfos[level].collapsed ^ collapse;
      refresh();
    }

    /**
     * @param varArgs Either a Slick.Group's "groupingKey" property, or a
     *     variable argument list of grouping values denoting a unique path to the row.
     *     For example, calling isGroupCollapsed('high', '10%') will return whether the
     *     collapse the '10%' subgroup of the 'high' setGrouping is collapsed.
     */
    function isGroupCollapsed(groupingValue) {
      var args = Array.prototype.slice.call(arguments);
      var arg0 = args[0];
      var level;
      var groupingKey;
      if (args.length == 1 && arg0.indexOf(groupingDelimiter) != -1) {
        level = arg0.split(groupingDelimiter).length - 1;
        groupingKey = arg0;
      } else {
        level = args.length - 1;
        groupingKey = args.join(groupingDelimiter);
      }
      return toggledGroupsByLevel[level][groupingKey];
    }
    
    /**
     * @param varArgs Either a Slick.Group's "groupingKey" property, or a
     *     variable argument list of grouping values denoting a unique path to the row.  For
     *     example, calling collapseGroup('high', '10%') will collapse the '10%' subgroup of
     *     the 'high' setGrouping.
     */
    function collapseGroup(varArgs) {
      var args = Array.prototype.slice.call(arguments);
      var arg0 = args[0];
      if (args.length == 1 && arg0.indexOf(groupingDelimiter) != -1) {
        expandCollapseGroup(arg0.split(groupingDelimiter).length - 1, arg0, true);
      } else {
        expandCollapseGroup(args.length - 1, args.join(groupingDelimiter), true);
      }
    }

    /**
     * @param varArgs Either a Slick.Group's "groupingKey" property, or a
     *     variable argument list of grouping values denoting a unique path to the row.  For
     *     example, calling expandGroup('high', '10%') will expand the '10%' subgroup of
     *     the 'high' setGrouping.
     */
    function expandGroup(varArgs) {
      var args = Array.prototype.slice.call(arguments);
      var arg0 = args[0];
      if (args.length == 1 && arg0.indexOf(groupingDelimiter) != -1) {
        expandCollapseGroup(arg0.split(groupingDelimiter).length - 1, arg0, false);
      } else {
        expandCollapseGroup(args.length - 1, args.join(groupingDelimiter), false);
      }
    }

    function getGroups() {
      return groups;
    }

    function extractGroups(rows, parentGroup) {
      var group;
      var val;
      var groups = [];
      var groupsByVal = [];
      var r;
      var level = parentGroup ? parentGroup.level + 1 : 0;
      var gi = groupingInfos[level];

      for (var i = 0, l = rows.length; i < l; i++) {
        r = rows[i];
        val = gi.getterIsAFn ? gi.getter(r) : r[gi.getter];
        val = val || 0;
        group = groupsByVal[val];
        if (!group) {
          group = new Slick.Group();
          group.count = 0;
          group.value = val;
          group.level = level;
          group.groupingKey = (parentGroup ? parentGroup.groupingKey + groupingDelimiter : '') + val;
          group.rows = [];
          groups[groups.length] = group;
          groupsByVal[val] = group;
        }

        group.rows[group.count++] = r;
      }

      if (level < groupingInfos.length - 1) {
        for (var i = 0; i < groups.length; i++) {
          group = groups[i];
          group.groups = extractGroups(group.rows, group);
        }
      }      

      groups.sort(groupingInfos[level].comparer);

      return groups;
    }

    // TODO:  lazy totals calculation
    function calculateGroupTotals(group) {
      // TODO:  try moving iterating over groups into compiled accumulator
      var gi = groupingInfos[group.level];
      var isLeafLevel = (group.level == groupingInfos.length);
      var totals = new Slick.GroupTotals();
      var agg, idx = gi.aggregators.length;
      while (idx--) {
        agg = gi.aggregators[idx];
        agg.init();
        gi.compiledAccumulators[idx].call(agg,
            (!isLeafLevel && gi.aggregateChildGroups) ? group.groups : group.rows);
        agg.storeResult(totals);
      }
      totals.group = group;
      group.totals = totals;
    }

    function calculateTotals(groups, level) {
      level = level || 0;
      var gi = groupingInfos[level];
      var idx = groups.length, g;
      while (idx--) {
        g = groups[idx];

        if (g.collapsed && !gi.aggregateCollapsed) {
          continue;
        }

        // Do a depth-first aggregation so that parent setGrouping aggregators can access subgroup totals.
        if (g.groups) {
          calculateTotals(g.groups, level + 1);
        }

        if (gi.aggregators.length) {
          calculateGroupTotals(g);
        }
      }
    }

    function finalizeGroups(groups, level) {
      level = level || 0;
      var gi = groupingInfos[level];
      var groupCollapsed = gi.collapsed;
      var toggledGroups = toggledGroupsByLevel[level];
      var idx = groups.length, g;
      while (idx--) {
        g = groups[idx];
        g.collapsed = groupCollapsed ^ toggledGroups[g.groupingKey];
        g.title = gi.formatter ? gi.formatter(g) : g.value;

        if (g.groups) {
          finalizeGroups(g.groups, level + 1);
          // Let the non-leaf setGrouping rows get garbage-collected.
          // They may have been used by aggregates that go over all of the descendants,
          // but at this point they are no longer needed.
          g.rows = null;
        }
      }
    }

    function flattenGroupedRows(groups) {
      var groupedRows = [], rows, gl = 0, g;
      for (var i = 0, l = groups.length; i < l; i++) {
        g = groups[i];
                
        if (options.showExpandedGroupRows || g.collapsed)
          groupedRows[gl++] = g;

        if (!g.collapsed) {
          rows = g.groups ? flattenGroupedRows(g.groups) : g.rows;
          for (var j = 0, jj = rows.length; j < jj; j++) {
            groupedRows[gl++] = rows[j];
          }
        }

        if (g.totals && (!g.collapsed || groupingInfos[g.level].aggregateCollapsed)) {
          groupedRows[gl++] = g.totals;
        }
      }
      return groupedRows;
    }

    function getFunctionInfo(fn) {
      var fnRegex = /^function[^(]*\(([^)]*)\)\s*{([\s\S]*)}$/;
      var matches = fn.toString().match(fnRegex);
      return {
        params: matches[1].split(","),
        body: matches[2]
      };
    }

    function compileAccumulatorLoop(aggregator) {
      var accumulatorInfo = getFunctionInfo(aggregator.accumulate);
      var fn = new Function(
          "_items",
          "for (var " + accumulatorInfo.params[0] + ", _i=0, _il=_items.length; _i<_il; _i++) {" +
              accumulatorInfo.params[0] + " = _items[_i]; " +
              accumulatorInfo.body +
          "}"
      );
      fn.displayName = fn.name = "compiledAccumulatorLoop";
      return fn;
    }

    function compileFilter() {
      var filterInfo = getFunctionInfo(filter);

      var filterBody = filterInfo.body
          .replace(/return false[;}]/gi, "{ continue _coreloop; }")
          .replace(/return true[;}]/gi, "{ _retval[_idx++] = $item$; continue _coreloop; }")
          .replace(/return ([^;}]+?);/gi,
          "{ if ($1) { _retval[_idx++] = $item$; }; continue _coreloop; }");

      // This preserves the function template code after JS compression,
      // so that replace() commands still work as expected.
      var tpl = [
        //"function(_items, _args) { ",
        "var _retval = [], _idx = 0; ",
        "var $item$, $args$ = _args; ",
        "_coreloop: ",
        "for (var _i = 0, _il = _items.length; _i < _il; _i++) { ",
        "$item$ = _items[_i]; ",
        "$filter$; ",
        "} ",
        "return _retval; "
        //"}"
      ].join("");
      tpl = tpl.replace(/\$filter\$/gi, filterBody);
      tpl = tpl.replace(/\$item\$/gi, filterInfo.params[0]);
      tpl = tpl.replace(/\$args\$/gi, filterInfo.params[1]);

      var fn = new Function("_items,_args", tpl);
      fn.displayName = fn.name = "compiledFilter";
      return fn;
    }

    function compileFilterWithCaching() {
      var filterInfo = getFunctionInfo(filter);

      var filterBody = filterInfo.body
          .replace(/return false[;}]/gi, "{ continue _coreloop; }")
          .replace(/return true[;}]/gi, "{ _cache[_i] = true;_retval[_idx++] = $item$; continue _coreloop; }")
          .replace(/return ([^;}]+?);/gi,
          "{ if ((_cache[_i] = $1)) { _retval[_idx++] = $item$; }; continue _coreloop; }");

      // This preserves the function template code after JS compression,
      // so that replace() commands still work as expected.
      var tpl = [
        //"function(_items, _args, _cache) { ",
        "var _retval = [], _idx = 0; ",
        "var $item$, $args$ = _args; ",
        "_coreloop: ",
        "for (var _i = 0, _il = _items.length; _i < _il; _i++) { ",
        "$item$ = _items[_i]; ",
        "if (_cache[_i]) { ",
        "_retval[_idx++] = $item$; ",
        "continue _coreloop; ",
        "} ",
        "$filter$; ",
        "} ",
        "return _retval; "
        //"}"
      ].join("");
      tpl = tpl.replace(/\$filter\$/gi, filterBody);
      tpl = tpl.replace(/\$item\$/gi, filterInfo.params[0]);
      tpl = tpl.replace(/\$args\$/gi, filterInfo.params[1]);

      var fn = new Function("_items,_args,_cache", tpl);
      fn.displayName = fn.name = "compiledFilterWithCaching";
      return fn;
    }

    function uncompiledFilter(items, args) {
      var retval = [], idx = 0;

      for (var i = 0, ii = items.length; i < ii; i++) {
        if (filter(items[i], args)) {
          retval[idx++] = items[i];
        }
      }

      return retval;
    }

    function uncompiledFilterWithCaching(items, args, cache) {
      var retval = [], idx = 0, item;

      for (var i = 0, ii = items.length; i < ii; i++) {
        item = items[i];
        if (cache[i]) {
          retval[idx++] = item;
        } else if (filter(item, args)) {
          retval[idx++] = item;
          cache[i] = true;
        }
      }

      return retval;
    }

    function getFilteredAndPagedItems(items) {
      if (filter) {
        var batchFilter = options.inlineFilters ? compiledFilter : uncompiledFilter;
        var batchFilterWithCaching = options.inlineFilters ? compiledFilterWithCaching : uncompiledFilterWithCaching;

        if (refreshHints.isFilterNarrowing) {
          filteredItems = batchFilter(filteredItems, filterArgs);
        } else if (refreshHints.isFilterExpanding) {
          filteredItems = batchFilterWithCaching(items, filterArgs, filterCache);
        } else if (!refreshHints.isFilterUnchanged) {
          filteredItems = batchFilter(items, filterArgs);
        }
      } else {
        // special case:  if not filtering and not paging, the resulting
        // rows collection needs to be a copy so that changes due to sort
        // can be caught
        filteredItems = pagesize ? items : items.concat();
      }

      // get the current page
      var paged;
      if (pagesize) {
        if (filteredItems.length < pagenum * pagesize) {
          pagenum = Math.floor(filteredItems.length / pagesize);
        }
        paged = filteredItems.slice(pagesize * pagenum, pagesize * pagenum + pagesize);
      } else {
        paged = filteredItems;
      }

      return {totalRows: filteredItems.length, rows: paged};
    }

    function getRowDiffs(rows, newRows) {
      var item, r, eitherIsNonData, diff = [];
      var from = 0, to = newRows.length;

      if (refreshHints && refreshHints.ignoreDiffsBefore) {
        from = Math.max(0,
            Math.min(newRows.length, refreshHints.ignoreDiffsBefore));
      }

      if (refreshHints && refreshHints.ignoreDiffsAfter) {
        to = Math.min(newRows.length,
            Math.max(0, refreshHints.ignoreDiffsAfter));
      }

      for (var i = from, rl = rows.length; i < to; i++) {
        if (i >= rl) {
          diff[diff.length] = i;
        } else {
          item = newRows[i];
          r = rows[i];

          if ((groupingInfos.length && (eitherIsNonData = (item.__nonDataRow) || (r.__nonDataRow)) &&
              item.__group !== r.__group ||
              item.__group && !item.equals(r))
              || (eitherIsNonData &&
              // no good way to compare totals since they are arbitrary DTOs
              // deep object comparison is pretty expensive
              // always considering them 'dirty' seems easier for the time being
              (item.__groupTotals || r.__groupTotals))
              || item[idProperty] != r[idProperty]
              || (updated && updated[item[idProperty]])
              ) {
            diff[diff.length] = i;
          }
        }
      }
      return diff;
    }

    function recalc(_items) {
      rowsById = null;

      if (refreshHints.isFilterNarrowing != prevRefreshHints.isFilterNarrowing ||
          refreshHints.isFilterExpanding != prevRefreshHints.isFilterExpanding) {
        filterCache = [];
      }

      var filteredItems = getFilteredAndPagedItems(_items);
      totalRows = filteredItems.totalRows;
      var newRows = filteredItems.rows;

      groups = [];
      if (groupingInfos.length) {
        groups = extractGroups(newRows);
        if (groups.length) {
          calculateTotals(groups);
          finalizeGroups(groups);
          newRows = flattenGroupedRows(groups);
        }
      }

      var diff = getRowDiffs(rows, newRows);

      rows = newRows;

      return diff;
    }

    function refresh() {
      if (suspend) {
        return;
      }

      var countBefore = rows.length;
      var totalRowsBefore = totalRows;

      var diff = recalc(items, filter); // pass as direct refs to avoid closure perf hit

      // if the current page is no longer valid, go to last page and recalc
      // we suffer a performance penalty here, but the main loop (recalc) remains highly optimized
      if (pagesize && totalRows < pagenum * pagesize) {
        pagenum = Math.max(0, Math.ceil(totalRows / pagesize) - 1);
        diff = recalc(items, filter);
      }

      updated = null;
      prevRefreshHints = refreshHints;
      refreshHints = {};

      if (totalRowsBefore != totalRows) {
        onPagingInfoChanged.notify(getPagingInfo(), null, self);
      }
      if (countBefore != rows.length) {
        onRowCountChanged.notify({previous: countBefore, current: rows.length}, null, self);
      }
      if (diff.length > 0) {
        onRowsChanged.notify({rows: diff}, null, self);
      }
    }

    function syncGridSelection(grid, preserveHidden) {
      var self = this;
      var selectedRowIds = self.mapRowsToIds(grid.getSelectedRows());;
      var inHandler;

      function update() {
        if (selectedRowIds.length > 0) {
          inHandler = true;
          var selectedRows = self.mapIdsToRows(selectedRowIds);
          if (!preserveHidden) {
            selectedRowIds = self.mapRowsToIds(selectedRows);
          }
          grid.setSelectedRows(selectedRows);
          inHandler = false;
        }
      }

      grid.onSelectedRowsChanged.subscribe(function(e, args) {
        if (inHandler) { return; }
        selectedRowIds = self.mapRowsToIds(grid.getSelectedRows());
      });

      this.onRowsChanged.subscribe(update);

      this.onRowCountChanged.subscribe(update);
    }

    function syncGridCellCssStyles(grid, key) {
      var hashById;
      var inHandler;

      // since this method can be called after the cell styles have been set,
      // get the existing ones right away
      storeCellCssStyles(grid.getCellCssStyles(key));

      function storeCellCssStyles(hash) {
        hashById = {};
        for (var row in hash) {
          var id = rows[row][idProperty];
          hashById[id] = hash[row];
        }
      }

      function update() {
        if (hashById) {
          inHandler = true;
          ensureRowsByIdCache();
          var newHash = {};
          for (var id in hashById) {
            var row = rowsById[id];
            if (row != undefined) {
              newHash[row] = hashById[id];
            }
          }
          grid.setCellCssStyles(key, newHash);
          inHandler = false;
        }
      }

      grid.onCellCssStylesChanged.subscribe(function(e, args) {
        if (inHandler) { return; }
        if (key != args.key) { return; }
        if (args.hash) {
          storeCellCssStyles(args.hash);
        }
      });

      this.onRowsChanged.subscribe(update);

      this.onRowCountChanged.subscribe(update);
    }

    return {
      // methods
      "beginUpdate": beginUpdate,
      "endUpdate": endUpdate,
      "setPagingOptions": setPagingOptions,
      "getPagingInfo": getPagingInfo,
      "getItems": getItems,
      "setItems": setItems,
      "setFilter": setFilter,
      "sort": sort,
      "fastSort": fastSort,
      "reSort": reSort,
      "setGrouping": setGrouping,
      "getGrouping": getGrouping,
      "groupBy": groupBy,
      "setAggregators": setAggregators,
      "collapseAllGroups": collapseAllGroups,
      "expandAllGroups": expandAllGroups,
      "isGroupCollapsed": isGroupCollapsed,
      "collapseGroup": collapseGroup,
      "expandGroup": expandGroup,
      "getGroups": getGroups,
      "getIdxById": getIdxById,
      "getRowById": getRowById,
      "getItemById": getItemById,
      "getItemByIdx": getItemByIdx,
      "mapRowsToIds": mapRowsToIds,
      "mapIdsToRows": mapIdsToRows,
      "setRefreshHints": setRefreshHints,
      "setFilterArgs": setFilterArgs,
      "refresh": refresh,
      "updateItem": updateItem,
      "insertItem": insertItem,
      "addItem": addItem,
      "deleteItem": deleteItem,
      "syncGridSelection": syncGridSelection,
      "syncGridCellCssStyles": syncGridCellCssStyles,

      // data provider methods
      "getLength": getLength,
      "getItem": getItem,
      "getItemMetadata": getItemMetadata,

      // events
      "onRowCountChanged": onRowCountChanged,
      "onRowsChanged": onRowsChanged,
      "onPagingInfoChanged": onPagingInfoChanged
    };
  }

  function AvgAggregator(field) {
    this.field_ = field;

    this.init = function () {
      this.count_ = 0;
      this.nonNullCount_ = 0;
      this.sum_ = 0;
    };

    this.accumulate = function (item) {
      var val = item[this.field_];
      this.count_++;
      if (val != null && val !== "" && val !== NaN) {
        this.nonNullCount_++;
        this.sum_ += parseFloat(val);
      }
    };

    this.storeResult = function (groupTotals) {
      if (!groupTotals.avg) {
        groupTotals.avg = {};
      }
      if (this.nonNullCount_ != 0) {
        groupTotals.avg[this.field_] = this.sum_ / this.nonNullCount_;
      }
    };
  }

  function MinAggregator(field) {
    this.field_ = field;

    this.init = function () {
      this.min_ = null;
    };

    this.accumulate = function (item) {
      var val = item[this.field_];
      if (val != null && val !== "" && val !== NaN) {
        if (this.min_ == null || val < this.min_) {
          this.min_ = val;
        }
      }
    };

    this.storeResult = function (groupTotals) {
      if (!groupTotals.min) {
        groupTotals.min = {};
      }
      groupTotals.min[this.field_] = this.min_;
    }
  }

  function MaxAggregator(field) {
    this.field_ = field;

    this.init = function () {
      this.max_ = null;
    };

    this.accumulate = function (item) {
      var val = item[this.field_];
      if (val != null && val !== "" && val !== NaN) {
        if (this.max_ == null || val > this.max_) {
          this.max_ = val;
        }
      }
    };

    this.storeResult = function (groupTotals) {
      if (!groupTotals.max) {
        groupTotals.max = {};
      }
      groupTotals.max[this.field_] = this.max_;
    }
  }

  function SumAggregator(field) {
    this.field_ = field;

    this.init = function () {
      this.sum_ = null;
    };

    this.accumulate = function (item) {
      var val = item[this.field_];
      if (val != null && val !== "" && val !== NaN) {
        this.sum_ += parseFloat(val);
      }
    };

    this.storeResult = function (groupTotals) {
      if (!groupTotals.sum) {
        groupTotals.sum = {};
      }
      groupTotals.sum[this.field_] = this.sum_;
    }
  }

  // TODO:  add more built-in aggregators
  // TODO:  merge common aggregators in one to prevent needles iterating

})(jQuery);
/* >>>>>>>>>> BEGIN source/libraries/slickgrid/slick.grid.js */
/**
 * @license
 * (c) 2009-2012 Michael Leibman
 * michael{dot}leibman{at}gmail{dot}com
 * http://github.com/mleibman/slickgrid
 *
 * Distributed under MIT license.
 * All rights reserved.
 *
 * SlickGrid v2.1
 *
 * NOTES:
 *     Cell/row DOM manipulations are done directly bypassing jQuery's DOM manipulation methods.
 *     This increases the speed dramatically, but can only be done safely because there are no event handlers
 *     or data associated with any cell/row DOM nodes.  Cell editors must make sure they implement .destroy()
 *     and do proper cleanup.
 */

// make sure required JavaScript modules are loaded
if (typeof jQuery === "undefined") {
  throw "SlickGrid requires jquery module to be loaded";
}
if (!jQuery.fn.drag) {
  throw "SlickGrid requires jquery.event.drag module to be loaded";
}
if (typeof Slick === "undefined") {
  throw "slick.core.js not loaded";
}


(function ($) {
  // Slick.Grid
  $.extend(true, window, {
    Slick: {
      Grid: SlickGrid
    }
  });

  // shared across all grids on the page
  var scrollbarDimensions;
  var maxSupportedCssHeight;  // browser's breaking point

  //////////////////////////////////////////////////////////////////////////////////////////////
  // SlickGrid class implementation (available as Slick.Grid)

  /**
   * Creates a new instance of the grid.
   * @class SlickGrid
   * @constructor
   * @param {Node}              container   Container node to create the grid in.
   * @param {Array,Object}      data        An array of objects for databinding.
   * @param {Array}             columns     An array of column definitions.
   * @param {Object}            options     Grid options.
   *
   * [KCPT] SlickGrid 2.1
   *  data: Array of data items or an object which implements the data-access functions
   *    {Array} of data items, each item has the following:
   *      id:         {String}    A unique ID for the item
   *      Other properties as indicated by the 'field' entries of the columns array.
   *      For instance, if one of the columns specifies a field value of 'name',
   *      then each item of the data array should have a 'name' property.
   *    {Object} implementing the data-access functions:
   *      getLength()         Returns the number of data items (analogous to data.length)
   *      getItem(i)          Returns the ith data item (analogous to data[i])
   *      getItemMetadata(i)  Returns the metadata for the ith row
   *    Slick.DataView is an example of an Object which provides this API. It is essentially
   *    a wrapper around an {Array} of data items which provides additional data manipulation
   *    features, such as filtering and sorting.
   *
   *  columns: Array of objects which specify details about the columns
   *      id:                 {String}    A unique ID for the column
   *      name:               {String}    The name of the column, displayed in column header cell
   *      field:              {String}    The name of the data item property to be displayed in this column
   *      width:              {Number}    The width of the column in pixels
   *      minWidth:           {Number}    The minimum width of the column
   *      maxWidth:           {Number}    The maximum width of the column
   *      cssClass:           {String}    The name of the CSS class to use for cells in this column
   *      formatter:          {Function}  formatter(rowIndex, colIndex, cellValue, colInfo, rowItem)
   *      editor:             {Function}  The constructor function for the class to use for editing
   *      validator:          {Function}  A function to be called when validating user-entered values
   *      cannotTriggerInsert:{Boolean}
   *      resizable:          {Boolean}   Whether this column can be resized
   *      selectable:         {Boolean}   Whether this column can be selected
   *      sortable:           {Boolean}   Whether the grid rows can be sorted by this column
   *
   *  options: Object with additional customization options
   *      explicitInitialization:
   *                          {Boolean}   Defers initialization until the client calls the
   *                                      grid.init() method explicitly. Supports situations in
   *                                      which SlickGrid containers may not be in the DOM at creation.
   *      rowHeight:          {Number}    Height of each row in pixels
   *      minRowHeight:       {Number}    Minimum height of each row (enforced during resizing; default: 18)
   *      rowResizerHeight:   {Number}    Height of row resizer handle (default: minRowHeight / 2)
   *      snapToLineHeight:   {Number}    Line height to snap to for row resizing (default: 14, null to disable)
   *      autoHeight:         {Boolean}   (?) Don't need vertical scroll bar
   *      defaultColumnWidth: {Number}    Default column width for columns that don't specify a width
   *      enableColumnReorder:{Boolean}   Can columns be reordered?
   *      enableAddRow:       {Boolean}   Can rows be added?
   *      leaveSpaceForNewRows:{Boolean}  Should space be left for a new/data entry row at bottom?
   *      showTopPanel:       {Boolean}   Should the top panel be shown?
   *      topPanelHeight:     {Number}    Height of the top panel in pixels
   *      showHeaderRow:      {Boolean}   Should the header row be shown?
   *      headerRowHeight:    {Number}    Height of the header row in pixels
   *      enableCellNavigation:{Boolean}  Should arrow keys navigate between cells?
   *      enableTextSelectionOnCells:
   *                          {Boolean}   Should text selection be allowed in cells?
   *      forceFitColumns:    {Boolean}   Should column widths be automatically resized to fit?
   *      syncColumnCellResize:{Boolean}  Should the grid width be changed dynamically during a drag
   *                                      to change column widths, or only once the mouse is released?
   *      dataItemColumnValueExtractor(item, columnDef):
   *                          {Function}  If present, will be called to retrieve a data value from the
   *                                      specified item for the corresponding column.
   *                                      Analogous to item[columnDef.field], where item is analogous to data[i].
   *      formatterFactory:   {Object}    If present, its getFormatter(column) method will be called
   *                                      to retrieve a formatter for the specified cell
   *      selectedCellCssClass:{Object?}  (?)Object used to specify CSS class for selected cells
   *      cellFlashingCssClass:{Object?}  (?)Object used to specify CSS class for flashing cells
   *      enableAsyncPostRender:{Boolean}
   *      asyncPostRenderDelay:{Number}   Delay passed to setTimeout in milliseconds
   *      editable:           {Boolean}   Is editing table cells supported?
   *      autoEdit:           {Boolean}   (?)Should editing be initiated automatically on click in cell?
   *      editorFactory:      {Object}    If present, its getEditor(column) method will be called
   *                                      to retrieve an editor for the specified cell,
   *                                      unless column.editor is specified, which will be used.
   *      editorLock:
   *      asyncEditorLoading: {Boolean}   Should editors be loaded asynchronously?
   *      asyncEditorLoadDelay:{Number}   Delay passed to setTimeout in milliseconds
   *      editCommandHandler: {Function}  editCommandHandler(item, column, editCommand) is called from
   *                                      the commitCurrentEdit() function, where it can be used to
   *                                      implement undo/redo, for instance.
   *      fullWidthRows:      {Boolean}   If true, rows are sized to take up the available grid width.
   *      multiColumnSort:    {Boolean}   If true, rows can be sorted by multiple columns.
   *      defaultFormatter:   {Function}  Default function for converting cell values to strings.
   *      forceSyncScrolling: {Boolean}   If true, renders more frequently during scrolling, rather than
   *                                      deferring rendering until default scroll thresholds are met.
   * [/KCPT]
   **/
  function SlickGrid(container, data, columns, options) {
    // settings
    var defaults = {
      explicitInitialization: false,
      rowHeight: 25,
      minRowHeight: 18, // [CC]
      rowResizerHeight: null, // [CC] if not set, defaults to minRowHeight / 2
      snapToLineHeight: 14, // [CC]
      defaultColumnWidth: 80,
      enableAddRow: false,
      leaveSpaceForNewRows: false,
      editable: false,
      autoEdit: true,
      enableCellNavigation: true,
      enableColumnReorder: true,
      asyncEditorLoading: false,
      asyncEditorLoadDelay: 100,
      forceFitColumns: false,
      enableAsyncPostRender: false,
      asyncPostRenderDelay: 50,
      autoHeight: false,
      editorLock: Slick.GlobalEditorLock,
      showHeaderRow: false,
      headerRowHeight: 25,
      showTopPanel: false,
      topPanelHeight: 25,
      formatterFactory: null,
      editorFactory: null,
      cellFlashingCssClass: "flashing",
      selectedCellCssClass: "selected",
      multiSelect: true,
      enableTextSelectionOnCells: false,
      dataItemColumnValueExtractor: null,
      fullWidthRows: false,
      multiColumnSort: false,
      defaultFormatter: defaultFormatter,
      forceSyncScrolling: false
    };

    var columnDefaults = {
      name: "",
      resizable: true,
      sortable: false,
      minWidth: 30,
      rerenderOnResize: false,
      headerCssClass: null,
      defaultSortAsc: true,
      focusable: true,
      selectable: true
    };

    // scroller
    var th;   // virtual height
    var h;    // real scrollable height
    var ph;   // page height
    var n;    // number of pages
    var cj;   // "jumpiness" coefficient

    var page = 0;       // current page
    var offset = 0;     // current page offset
    var vScrollDir = 1;

    // private
    var initialized = false;
    var $container;
    var uid = "slickgrid_" + Math.round(1000000 * Math.random());
    var self = this;
    var $focusSink, $focusSink2;
    var $headerScroller;
    var $headers;
    var $headerRow, $headerRowScroller, $headerRowSpacer;
    var $topPanelScroller;
    var $topPanel;
    var $viewport;
    var $canvas;
    var $style;
    var $boundAncestors;
    var stylesheet, columnCssRulesL, columnCssRulesR;
    var viewportH, viewportW;
    var canvasWidth;
    var viewportHasHScroll, viewportHasVScroll;
    var headerColumnWidthDiff = 0, headerColumnHeightDiff = 0, // border+padding
        cellWidthDiff = 0, cellHeightDiff = 0;
    var absoluteColumnMinWidth;
    var numberOfRows = 0;

    var tabbingDirection = 1;
    var activePosX;
    var activeRow, activeCell;
    var activeCellNode = null;
    var currentEditor = null;
    var serializedEditorValue;
    var editController;

    var rowsCache = {};
    var rowResizers = {}; // [CC]
    var activeResizeRow = null;  // [CC]
    var renderedRows = 0;
    var numVisibleRows;
    var prevScrollTop = 0;
    var scrollTop = 0;
    var lastRenderedScrollTop = 0;
    var lastRenderedScrollLeft = 0;
    var prevScrollLeft = 0;
    var scrollLeft = 0;

    var selectionModel;
    var selectedRows = [];

    var plugins = [];
    var cellCssClasses = {};

    var columnsById = {};
    var sortColumns = [];
    var columnPosLeft = [];
    var columnPosRight = [];


    // async call handles
    var h_editorLoader = null;
    var h_render = null;
    var h_postrender = null;
    var postProcessedRows = {};
    var postProcessToRow = null;
    var postProcessFromRow = null;

    // perf counters
    var counter_rows_rendered = 0;
    var counter_rows_removed = 0;


    //////////////////////////////////////////////////////////////////////////////////////////////
    // Initialization

    function init() {
      $container = $(container);
      if ($container.length < 1) {
        throw new Error("SlickGrid requires a valid container, " + container + " does not exist in the DOM.");
      }

      // calculate these only once and share between grid instances
      maxSupportedCssHeight = maxSupportedCssHeight || getMaxSupportedCssHeight();
      scrollbarDimensions = scrollbarDimensions || measureScrollbar();

      options = $.extend({}, defaults, options);
      validateAndEnforceOptions();
      columnDefaults.width = options.defaultColumnWidth;

      columnsById = {};
      for (var i = 0; i < columns.length; i++) {
        var m = columns[i] = $.extend({}, columnDefaults, columns[i]);
        columnsById[m.id] = i;
        if (m.minWidth && m.width < m.minWidth) {
          m.width = m.minWidth;
        }
        if (m.maxWidth && m.width > m.maxWidth) {
          m.width = m.maxWidth;
        }
      }

      // validate loaded JavaScript modules against requested options
      if (options.enableColumnReorder && !$.fn.sortable) {
        throw new Error("SlickGrid's 'enableColumnReorder = true' option requires jquery-ui.sortable module to be loaded");
      }

      editController = {
        "commitCurrentEdit": commitCurrentEdit,
        "cancelCurrentEdit": cancelCurrentEdit
      };

      $container
          .empty()
          .css("overflow", "hidden")
          .css("outline", 0)
          .addClass(uid)
          .addClass("ui-widget");

      // set up a positioning container if needed
      if (!/relative|absolute|fixed/.test($container.css("position"))) {
        $container.css("position", "relative");
      }

      $focusSink = $("<div tabIndex='0' hideFocus style='position:fixed;width:0;height:0;top:0;left:0;outline:0;'></div>").appendTo($container);

      $headerScroller = $("<div class='slick-header ui-state-default' style='overflow:hidden;position:relative;' />").appendTo($container);
      $headers = $("<div class='slick-header-columns' style='left:-1000px' />").appendTo($headerScroller);
      $headers.width(getHeadersWidth());

      $headerRowScroller = $("<div class='slick-headerrow ui-state-default' style='overflow:hidden;position:relative;' />").appendTo($container);
      $headerRow = $("<div class='slick-headerrow-columns' />").appendTo($headerRowScroller);
      $headerRowSpacer = $("<div style='display:block;height:1px;position:absolute;top:0;left:0;'></div>")
          .css("width", getCanvasWidth() + scrollbarDimensions.width + "px")
          .appendTo($headerRowScroller);

      $topPanelScroller = $("<div class='slick-top-panel-scroller ui-state-default' style='overflow:hidden;position:relative;' />").appendTo($container);
      $topPanel = $("<div class='slick-top-panel' style='width:10000px' />").appendTo($topPanelScroller);

      if (!options.showTopPanel) {
        $topPanelScroller.hide();
      }

      if (!options.showHeaderRow) {
        $headerRowScroller.hide();
      }

      $viewport = $("<div class='slick-viewport' style='width:100%;overflow:auto;outline:0;position:relative;;'>").appendTo($container);
      $viewport.css("overflow-y", options.autoHeight ? "hidden" : "auto");

      $canvas = $("<div class='grid-canvas' />").appendTo($viewport);

      $focusSink2 = $focusSink.clone().appendTo($container);

      if (!options.explicitInitialization) {
        finishInitialization();
      }
    }

    function finishInitialization() {
      if (!initialized) {
        initialized = true;

        viewportW = parseFloat($.css($container[0], "width", true));

        // header columns and cells may have different padding/border skewing width calculations (box-sizing, hello?)
        // calculate the diff so we can set consistent sizes
        measureCellPaddingAndBorder();

        // for usability reasons, all text selection in SlickGrid is disabled
        // with the exception of input and textarea elements (selection must
        // be enabled there so that editors work as expected); note that
        // selection in grid cells (grid body) is already unavailable in
        // all browsers except IE
        disableSelection($headers); // disable all text selection in header (including input and textarea)

        if (!options.enableTextSelectionOnCells) {
          // disable text selection in grid cells except in input and textarea elements
          // (this is IE-specific, because selectstart event will only fire in IE)
          $viewport.bind("selectstart.ui", function (event) {
            return $(event.target).is("input,textarea");
          });
        }

        updateColumnCaches();
        createColumnHeaders();
        setupColumnSort();
        createCssRules();
        resizeCanvas();
        bindAncestorScrollEvents();

        $container
            .bind("resize.slickgrid", resizeCanvas);
        $viewport
            .bind("scroll", handleScroll);
        $headerScroller
            .bind("contextmenu", handleHeaderContextMenu)
            .bind("click", handleHeaderClick)
            .delegate(".slick-header-column", "mouseenter", handleHeaderMouseEnter)
            .delegate(".slick-header-column", "mouseleave", handleHeaderMouseLeave)
            .bind("draginit", handleHeaderDragInit)
            .bind("dragstart", handleHeaderDragStart)
            // [CC Change] Configure the default distance (pixels) to recognize drag
            // On Windows/Chrome drag started too soon.
            .bind("drag", {distance: 5}, handleHeaderDrag)
            // End [CC Change]
            .bind("dragend", handleHeaderDragEnd);
        $headerRowScroller
            .bind("scroll", handleHeaderRowScroll);
        $focusSink.add($focusSink2)
            .bind("keydown", handleKeyDown);
        $canvas
            .bind("keydown", handleKeyDown)
            .bind("click", handleClick)
            .bind("dblclick", handleDblClick)
            .bind("contextmenu", handleContextMenu)
            .bind("draginit", {touch: false}, handleDragInit)
            .bind("dragstart", {distance: 3}, handleDragStart)
            .bind("drag", handleDrag)
            .bind("dragend", handleDragEnd)
            .delegate(".slick-cell", "mouseenter", handleMouseEnter)
            .delegate(".slick-cell", "mouseleave", handleMouseLeave);
      }
    }

    function registerPlugin(plugin) {
      plugins.unshift(plugin);
      plugin.init(self);
    }

    function unregisterPlugin(plugin) {
      for (var i = plugins.length; i >= 0; i--) {
        if (plugins[i] === plugin) {
          if (plugins[i].destroy) {
            plugins[i].destroy();
          }
          plugins.splice(i, 1);
          break;
        }
      }
    }

    function setSelectionModel(model) {
      if (selectionModel) {
        selectionModel.onSelectedRangesChanged.unsubscribe(handleSelectedRangesChanged);
        if (selectionModel.destroy) {
          selectionModel.destroy();
        }
      }

      selectionModel = model;
      if (selectionModel) {
        selectionModel.init(self);
        selectionModel.onSelectedRangesChanged.subscribe(handleSelectedRangesChanged);
      }
    }

    function getSelectionModel() {
      return selectionModel;
    }

    function getCanvasNode() {
      return $canvas[0];
    }

    function measureScrollbar() {
      var $c = $("<div style='position:absolute; top:-10000px; left:-10000px; width:100px; height:100px; overflow:scroll;'></div>").appendTo("body");
      var dim = {
        width: $c.width() - $c[0].clientWidth,
        height: $c.height() - $c[0].clientHeight
      };
      $c.remove();
      return dim;
    }

    function getHeadersWidth() {
      var headersWidth = 0;
      for (var i = 0, ii = columns.length; i < ii; i++) {
        var width = columns[i].width;
        headersWidth += width;
      }
      headersWidth += scrollbarDimensions.width;
      return Math.max(headersWidth, viewportW) + 1000;
    }

    function getCanvasWidth() {
      var availableWidth = viewportHasVScroll ? viewportW - scrollbarDimensions.width : viewportW;
      var rowWidth = 0;
      var i = columns.length;
      while (i--) {
        rowWidth += columns[i].width;
      }
      return options.fullWidthRows ? Math.max(rowWidth, availableWidth) : rowWidth;
    }

    function updateCanvasWidth(forceColumnWidthsUpdate) {
      var oldCanvasWidth = canvasWidth;
      canvasWidth = getCanvasWidth();

      // see https://github.com/mleibman/SlickGrid/issues/477
      viewportHasHScroll = (canvasWidth > viewportW - scrollbarDimensions.width);

      if (canvasWidth != oldCanvasWidth) {
        $canvas.width(canvasWidth);
        $headerRow.width(canvasWidth);
        $headers.width(getHeadersWidth());
        trigger(self.onCanvasWidthChanged, { width: canvasWidth });
      }

      $headerRowSpacer.width(canvasWidth + (viewportHasVScroll ? scrollbarDimensions.width : 0));

      if (canvasWidth != oldCanvasWidth || forceColumnWidthsUpdate) {
        applyColumnWidths();
      }
    }

    function disableSelection($target) {
      if ($target && $target.jquery) {
        $target
            .attr("unselectable", "on")
            .css("MozUserSelect", "none")
            .bind("selectstart.ui", function () {
              return false;
            }); // from jquery:ui.core.js 1.7.2
      }
    }

    function getMaxSupportedCssHeight() {
      var supportedHeight = 1000000;
      // FF reports the height back but still renders blank after ~6M px
      var testUpTo = navigator.userAgent.toLowerCase().match(/firefox/) ? 6000000 : 1000000000;
      var div = $("<div style='display:none' />").appendTo(document.body);

      while (true) {
        var test = supportedHeight * 2;
        div.css("height", test);
        if (test > testUpTo || div.height() !== test) {
          break;
        } else {
          supportedHeight = test;
        }
      }

      div.remove();
      return supportedHeight;
    }

    // TODO:  this is static.  need to handle page mutation.
    function bindAncestorScrollEvents() {
      var elem = $canvas[0];
      while ((elem = elem.parentNode) != document.body && elem != null) {
        // bind to scroll containers only
        if (elem == $viewport[0] || elem.scrollWidth != elem.clientWidth || elem.scrollHeight != elem.clientHeight) {
          var $elem = $(elem);
          if (!$boundAncestors) {
            $boundAncestors = $elem;
          } else {
            $boundAncestors = $boundAncestors.add($elem);
          }
          $elem.bind("scroll." + uid, handleActiveCellPositionChange);
        }
      }
    }

    function unbindAncestorScrollEvents() {
      if (!$boundAncestors) {
        return;
      }
      $boundAncestors.unbind("scroll." + uid);
      $boundAncestors = null;
    }

    function updateColumnHeader(columnId, title, toolTip) {
      if (!initialized) { return; }
      var idx = getColumnIndex(columnId);
      if (idx == null) {
        return;
      }

      var columnDef = columns[idx];
      var $header = $headers.children().eq(idx);
      if ($header) {
        if (title !== undefined) {
          columns[idx].name = title;
        }
        if (toolTip !== undefined) {
          columns[idx].toolTip = toolTip;
        }

        trigger(self.onBeforeHeaderCellDestroy, {
          "node": $header[0],
          "column": columnDef
        });

        $header
            .attr("title", toolTip || "")
            .children().eq(0).html(title);

        trigger(self.onHeaderCellRendered, {
          "node": $header[0],
          "column": columnDef
        });
      }
    }

    function getHeaderRow() {
      return $headerRow[0];
    }

    function getHeaderRowColumn(columnId) {
      var idx = getColumnIndex(columnId);
      var $header = $headerRow.children().eq(idx);
      return $header && $header[0];
    }

    function createColumnHeaders() {
      function onMouseEnter() {
        $(this).addClass("ui-state-hover");
      }

      function onMouseLeave() {
        $(this).removeClass("ui-state-hover");
      }

      $headers.find(".slick-header-column")
        .each(function() {
          var columnDef = $(this).data("column");
          if (columnDef) {
            trigger(self.onBeforeHeaderCellDestroy, {
              "node": this,
              "column": columnDef
            });
          }
        });
      $headers.empty();
      $headers.width(getHeadersWidth());

      $headerRow.find(".slick-headerrow-column")
        .each(function() {
          var columnDef = $(this).data("column");
          if (columnDef) {
            trigger(self.onBeforeHeaderRowCellDestroy, {
              "node": this,
              "column": columnDef
            });
          }
        });
      $headerRow.empty();

      for (var i = 0; i < columns.length; i++) {
        var m = columns[i];

        var header = $("<div class='ui-state-default slick-header-column' id='" + uid + m.id + "' />")
            .html("<span class='slick-column-name'>" + m.name + "</span>")
            .width(m.width - headerColumnWidthDiff)
            .attr("title", m.toolTip || "")
            .data("column", m)
            .addClass(m.headerCssClass || "")
            .appendTo($headers);

        if (options.enableColumnReorder || m.sortable) {
          header
            .on('mouseenter', onMouseEnter)
            .on('mouseleave', onMouseLeave);
        }

        if (m.sortable) {
          header.addClass("slick-header-sortable");
          header.append("<span class='slick-sort-indicator' />");
        }

        trigger(self.onHeaderCellRendered, {
          "node": header[0],
          "column": m
        });

        if (options.showHeaderRow) {
          var headerRowCell = $("<div class='ui-state-default slick-headerrow-column l" + i + " r" + i + "'></div>")
              .data("column", m)
              .appendTo($headerRow);

          trigger(self.onHeaderRowCellRendered, {
            "node": headerRowCell[0],
            "column": m
          });
        }
      }

      setSortColumns(sortColumns);
      setupColumnResize();
      if (options.enableColumnReorder) {
        setupColumnReorder();
      }
    }

    function setupColumnSort() {
      $headers.click(function (e) {
        // temporary workaround for a bug in jQuery 1.7.1 (http://bugs.jquery.com/ticket/11328)
        e.metaKey = e.metaKey || e.ctrlKey;

        if ($(e.target).hasClass("slick-resizable-handle")) {
          return;
        }

        var $col = $(e.target).closest(".slick-header-column");
        if (!$col.length) {
          return;
        }

        var column = $col.data("column");
        if (column.sortable) {
          if (!getEditorLock().commitCurrentEdit()) {
            return;
          }

          var sortOpts = null;
          var i = 0;
          for (; i < sortColumns.length; i++) {
            if (sortColumns[i].columnId == column.id) {
              sortOpts = sortColumns[i];
              sortOpts.sortAsc = !sortOpts.sortAsc;
              break;
            }
          }

          if (e.metaKey && options.multiColumnSort) {
            if (sortOpts) {
              sortColumns.splice(i, 1);
            }
          }
          else {
            if ((!e.shiftKey && !e.metaKey) || !options.multiColumnSort) {
              sortColumns = [];
            }

            if (!sortOpts) {
              sortOpts = { columnId: column.id, sortAsc: column.defaultSortAsc };
              sortColumns.push(sortOpts);
            } else if (sortColumns.length == 0) {
              sortColumns.push(sortOpts);
            }
          }

          setSortColumns(sortColumns);

          if (!options.multiColumnSort) {
            trigger(self.onSort, {
              multiColumnSort: false,
              sortCol: column,
              sortAsc: sortOpts.sortAsc}, e);
          } else {
            trigger(self.onSort, {
              multiColumnSort: true,
              sortCols: $.map(sortColumns, function(col) {
                return {sortCol: columns[getColumnIndex(col.columnId)], sortAsc: col.sortAsc };
              })}, e);
          }
        }
      });
    }

    function setupColumnReorder() {
      $headers.filter(":ui-sortable").sortable("destroy");
      $headers.sortable({
        containment: "parent",
        distance: 3,
        axis: "x",
        cursor: "default",
        tolerance: "intersection",
        helper: "clone",
        placeholder: "slick-sortable-placeholder ui-state-default slick-header-column",
        forcePlaceholderSize: true,
        start: function (e, ui) {
          $(ui.helper).addClass("slick-header-column-active");
        },
        beforeStop: function (e, ui) {
          $(ui.helper).removeClass("slick-header-column-active");
        },
        stop: function (e) {
          if (!getEditorLock().commitCurrentEdit()) {
            $(this).sortable("cancel");
            return;
          }

          var reorderedIds = $headers.sortable("toArray");
          var reorderedColumns = [];
          for (var i = 0; i < reorderedIds.length; i++) {
            reorderedColumns.push(columns[getColumnIndex(reorderedIds[i].replace(uid, ""))]);
          }
          setColumns(reorderedColumns);

          trigger(self.onColumnsReordered, {});
          e.stopPropagation();
          setupColumnResize();
        }
      });
    }

    function setupColumnResize() {
      var $col, j, c, pageX, columnElements, minPageX, maxPageX, firstResizable, lastResizable;
      columnElements = $headers.children();
      columnElements.find(".slick-resizable-handle").remove();
      columnElements.each(function (i, e) {
        if (columns[i].resizable) {
          if (firstResizable === undefined) {
            firstResizable = i;
          }
          lastResizable = i;
        }
      });
      if (firstResizable === undefined) {
        return;
      }
      columnElements.each(function (i, e) {
        if (i < firstResizable || (options.forceFitColumns && i >= lastResizable)) {
          return;
        }
        $col = $(e);
        $("<div class='slick-resizable-handle dg-wants-mouse dg-wants-touch' />")
            .appendTo(e)
            // [KCPT]
            // all touch support here added by KCPT.
            // increase touchable area on touch devices
            // see http://modernizr.github.com/Modernizr/touch.html for discussion of
            // this test as a means to determine that we're running on a touch platform.
            // We also increase the width of the resize area for the last column so that
            // it isn't entirely overlapped/hidden by the divider view.
            .css({ width: 'ontouchstart' in window ? 16 : (i === lastResizable ? 10 : 8) })
            // [\KCPT]
            .bind("dragstart touchstart", function (e, dd) {
              if (!getEditorLock().commitCurrentEdit()) {
                return false;
              }
              pageX = e.pageX;
              $(this).parent().addClass("slick-header-column-active");
              var shrinkLeewayOnRight = null, stretchLeewayOnRight = null;
              // lock each column's width option to current width
              columnElements.each(function (i, e) {
                columns[i].previousWidth = $(e).outerWidth();
              });
              if (options.forceFitColumns) {
                shrinkLeewayOnRight = 0;
                stretchLeewayOnRight = 0;
                // colums on right affect maxPageX/minPageX
                for (j = i + 1; j < columnElements.length; j++) {
                  c = columns[j];
                  if (c.resizable) {
                    if (stretchLeewayOnRight !== null) {
                      if (c.maxWidth) {
                        stretchLeewayOnRight += c.maxWidth - c.previousWidth;
                      } else {
                        stretchLeewayOnRight = null;
                      }
                    }
                    shrinkLeewayOnRight += c.previousWidth - Math.max(c.minWidth || 0, absoluteColumnMinWidth);
                  }
                }
              }
              var shrinkLeewayOnLeft = 0, stretchLeewayOnLeft = 0;
              for (j = 0; j <= i; j++) {
                // columns on left only affect minPageX
                c = columns[j];
                if (c.resizable) {
                  if (stretchLeewayOnLeft !== null) {
                    if (c.maxWidth) {
                      stretchLeewayOnLeft += c.maxWidth - c.previousWidth;
                    } else {
                      stretchLeewayOnLeft = null;
                    }
                  }
                  shrinkLeewayOnLeft += c.previousWidth - Math.max(c.minWidth || 0, absoluteColumnMinWidth);
                }
              }
              if (shrinkLeewayOnRight === null) {
                shrinkLeewayOnRight = 100000;
              }
              if (shrinkLeewayOnLeft === null) {
                shrinkLeewayOnLeft = 100000;
              }
              if (stretchLeewayOnRight === null) {
                stretchLeewayOnRight = 100000;
              }
              if (stretchLeewayOnLeft === null) {
                stretchLeewayOnLeft = 100000;
              }
              maxPageX = pageX + Math.min(shrinkLeewayOnRight, stretchLeewayOnLeft);
              minPageX = pageX - Math.min(shrinkLeewayOnLeft, stretchLeewayOnRight);
            })
            .bind("drag touchmove", function (e, dd) {
              var actualMinWidth, d = Math.min(maxPageX, Math.max(minPageX, e.pageX)) - pageX, x;
              if (d < 0) { // shrink column
                x = d;
                for (j = i; j >= 0; j--) {
                  c = columns[j];
                  if (c.resizable) {
                    actualMinWidth = Math.max(c.minWidth || 0, absoluteColumnMinWidth);
                    if (x && c.previousWidth + x < actualMinWidth) {
                      x += c.previousWidth - actualMinWidth;
                      c.width = actualMinWidth;
                    } else {
                      c.width = c.previousWidth + x;
                      x = 0;
                    }
                  }
                }

                if (options.forceFitColumns) {
                  x = -d;
                  for (j = i + 1; j < columnElements.length; j++) {
                    c = columns[j];
                    if (c.resizable) {
                      if (x && c.maxWidth && (c.maxWidth - c.previousWidth < x)) {
                        x -= c.maxWidth - c.previousWidth;
                        c.width = c.maxWidth;
                      } else {
                        c.width = c.previousWidth + x;
                        x = 0;
                      }
                    }
                  }
                }
              } else { // stretch column
                x = d;
                for (j = i; j >= 0; j--) {
                  c = columns[j];
                  if (c.resizable) {
                    if (x && c.maxWidth && (c.maxWidth - c.previousWidth < x)) {
                      x -= c.maxWidth - c.previousWidth;
                      c.width = c.maxWidth;
                    } else {
                      c.width = c.previousWidth + x;
                      x = 0;
                    }
                  }
                }

                if (options.forceFitColumns) {
                  x = -d;
                  for (j = i + 1; j < columnElements.length; j++) {
                    c = columns[j];
                    if (c.resizable) {
                      actualMinWidth = Math.max(c.minWidth || 0, absoluteColumnMinWidth);
                      if (x && c.previousWidth + x < actualMinWidth) {
                        x += c.previousWidth - actualMinWidth;
                        c.width = actualMinWidth;
                      } else {
                        c.width = c.previousWidth + x;
                        x = 0;
                      }
                    }
                  }
                }
              }
              applyColumnHeaderWidths();
              if (options.syncColumnCellResize) {
                applyColumnWidths();
                updateCanvasWidth(true);
                // [CC]
                // Modification to add access to intermediate values during
                // column resizing. Needed for two-line table headers.
                trigger(self.onColumnResizing, {});
              }
            })
            .bind("dragend touchend", function (e, dd) {
              var newWidth;
              $(this).parent().removeClass("slick-header-column-active");
              for (j = 0; j < columnElements.length; j++) {
                c = columns[j];
                newWidth = $(columnElements[j]).outerWidth();

                if (c.previousWidth !== newWidth && c.rerenderOnResize) {
                  invalidateAllRows();
                }
              }
              updateCanvasWidth(true);
              render();
              trigger(self.onColumnsResized, {});
            })
            // Don't propagate clicks to parent
            .bind("click", function (e) { e.stopPropagation(); });
      });
    }

    function getVBoxDelta($el) {
      var p = ["borderTopWidth", "borderBottomWidth", "paddingTop", "paddingBottom"];
      var delta = 0;
      $.each(p, function (n, val) {
        delta += parseFloat($el.css(val)) || 0;
      });
      return delta;
    }

    function measureCellPaddingAndBorder() {
      var el;
      var h = ["borderLeftWidth", "borderRightWidth", "paddingLeft", "paddingRight"];
      var v = ["borderTopWidth", "borderBottomWidth", "paddingTop", "paddingBottom"];

      el = $("<div class='ui-state-default slick-header-column' style='visibility:hidden'>-</div>").appendTo($headers);
      headerColumnWidthDiff = headerColumnHeightDiff = 0;
      $.each(h, function (n, val) {
        headerColumnWidthDiff += parseFloat(el.css(val)) || 0;
      });
      $.each(v, function (n, val) {
        headerColumnHeightDiff += parseFloat(el.css(val)) || 0;
      });
      el.remove();

      var r = $("<div class='slick-row' />").appendTo($canvas);
      el = $("<div class='slick-cell' id='' style='visibility:hidden'>-</div>").appendTo(r);
      cellWidthDiff = cellHeightDiff = 0;
      $.each(h, function (n, val) {
        cellWidthDiff += parseFloat(el.css(val)) || 0;
      });
      $.each(v, function (n, val) {
        cellHeightDiff += parseFloat(el.css(val)) || 0;
      });
      r.remove();

      absoluteColumnMinWidth = Math.max(headerColumnWidthDiff, cellWidthDiff);
    }

    function createCssRules() {
      $style = $("<style type='text/css' rel='stylesheet' />").appendTo($("head"));
      var rowHeight = (options.rowHeight - cellHeightDiff);
      var rules = [
        "." + uid + " .slick-header-column { left: 1000px; }",
        "." + uid + " .slick-top-panel { height:" + options.topPanelHeight + "px; }",
        "." + uid + " .slick-headerrow-columns { height:" + options.headerRowHeight + "px; }",
        "." + uid + " .slick-cell { height:" + rowHeight + "px; }",
        "." + uid + " .slick-row { height:" + options.rowHeight + "px; }"
      ];

      for (var i = 0; i < columns.length; i++) {
        rules.push("." + uid + " .l" + i + " { }");
        rules.push("." + uid + " .r" + i + " { }");
      }

      if ($style[0].styleSheet) { // IE
        $style[0].styleSheet.cssText = rules.join(" ");
      } else {
        $style[0].appendChild(document.createTextNode(rules.join(" ")));
      }
    }

    function getColumnCssRules(idx) {
      if (!stylesheet) {
        var sheets = document.styleSheets;
        for (var i = 0; i < sheets.length; i++) {
          if ((sheets[i].ownerNode || sheets[i].owningElement) == $style[0]) {
            stylesheet = sheets[i];
            break;
          }
        }

        if (!stylesheet) {
          throw new Error("Cannot find stylesheet.");
        }

        // find and cache column CSS rules
        columnCssRulesL = [];
        columnCssRulesR = [];
        var cssRules = (stylesheet.cssRules || stylesheet.rules);
        var matches, columnIdx;
        for (var i = 0; i < cssRules.length; i++) {
          var selector = cssRules[i].selectorText;
          if (matches = /\.l\d+/.exec(selector)) {
            columnIdx = parseInt(matches[0].substr(2, matches[0].length - 2), 10);
            columnCssRulesL[columnIdx] = cssRules[i];
          } else if (matches = /\.r\d+/.exec(selector)) {
            columnIdx = parseInt(matches[0].substr(2, matches[0].length - 2), 10);
            columnCssRulesR[columnIdx] = cssRules[i];
          }
        }
      }

      return {
        "left": columnCssRulesL[idx],
        "right": columnCssRulesR[idx]
      };
    }

    function removeCssRules() {
      $style.remove();
      stylesheet = null;
    }

    function destroy() {
      getEditorLock().cancelCurrentEdit();

      trigger(self.onBeforeDestroy, {});

      var i = plugins.length;
      while(i--) {
        unregisterPlugin(plugins[i]);
      }

      if (options.enableColumnReorder && $headers.sortable) {
        $headers.sortable("destroy");
      }

      unbindAncestorScrollEvents();
      $container.unbind(".slickgrid");
      removeCssRules();

      $canvas.unbind("draginit dragstart dragend drag");
      $container.empty().removeClass(uid);
    }


    //////////////////////////////////////////////////////////////////////////////////////////////
    // General

    function trigger(evt, args, e) {
      e = e || new Slick.EventData();
      args = args || {};
      args.grid = self;
      return evt.notify(args, e, self);
    }

    function getEditorLock() {
      return options.editorLock;
    }

    function getEditController() {
      return editController;
    }

    function getColumnIndex(id) {
      return columnsById[id];
    }

    function autosizeColumns() {
      var i, c,
          widths = [],
          shrinkLeeway = 0,
          total = 0,
          prevTotal,
          availWidth = viewportHasVScroll ? viewportW - scrollbarDimensions.width : viewportW;

      for (i = 0; i < columns.length; i++) {
        c = columns[i];
        widths.push(c.width);
        total += c.width;
        if (c.resizable) {
          shrinkLeeway += c.width - Math.max(c.minWidth, absoluteColumnMinWidth);
        }
      }

      // shrink
      prevTotal = total;
      while (total > availWidth && shrinkLeeway) {
        var shrinkProportion = (total - availWidth) / shrinkLeeway;
        for (i = 0; i < columns.length && total > availWidth; i++) {
          c = columns[i];
          var width = widths[i];
          if (!c.resizable || width <= c.minWidth || width <= absoluteColumnMinWidth) {
            continue;
          }
          var absMinWidth = Math.max(c.minWidth, absoluteColumnMinWidth);
          var shrinkSize = Math.floor(shrinkProportion * (width - absMinWidth)) || 1;
          shrinkSize = Math.min(shrinkSize, width - absMinWidth);
          total -= shrinkSize;
          shrinkLeeway -= shrinkSize;
          widths[i] -= shrinkSize;
        }
        if (prevTotal == total) {  // avoid infinite loop
          break;
        }
        prevTotal = total;
      }

      // grow
      prevTotal = total;
      while (total < availWidth) {
        var growProportion = availWidth / total;
        for (i = 0; i < columns.length && total < availWidth; i++) {
          c = columns[i];
          if (!c.resizable || c.maxWidth <= c.width) {
            continue;
          }
          var growSize = Math.min(Math.floor(growProportion * c.width) - c.width, (c.maxWidth - c.width) || 1000000) || 1;
          total += growSize;
          widths[i] += growSize;
        }
        if (prevTotal == total) {  // avoid infinite loop
          break;
        }
        prevTotal = total;
      }

      var reRender = false;
      for (i = 0; i < columns.length; i++) {
        if (columns[i].rerenderOnResize && columns[i].width != widths[i]) {
          reRender = true;
        }
        columns[i].width = widths[i];
      }

      applyColumnHeaderWidths();
      updateCanvasWidth(true);
      if (reRender) {
        invalidateAllRows();
        render();
      }
    }

    function applyColumnHeaderWidths() {
      if (!initialized) { return; }
      var h;
      for (var i = 0, headers = $headers.children(), ii = headers.length; i < ii; i++) {
        h = $(headers[i]);
        if (h.width() !== columns[i].width - headerColumnWidthDiff) {
          h.width(columns[i].width - headerColumnWidthDiff);
        }
      }

      updateColumnCaches();
    }

    function applyColumnWidths() {
      var x = 0, w, rule;
      for (var i = 0; i < columns.length; i++) {
        w = columns[i].width;

        rule = getColumnCssRules(i);
        rule.left.style.left = x + "px";
        rule.right.style.right = (canvasWidth - x - w) + "px";

        x += columns[i].width;
      }
    }

    function setSortColumn(columnId, ascending) {
      setSortColumns([{ columnId: columnId, sortAsc: ascending}]);
    }

    function setSortColumns(cols) {
      sortColumns = cols;

      var headerColumnEls = $headers.children();
      headerColumnEls
          .removeClass("slick-header-column-sorted")
          .find(".slick-sort-indicator")
              .removeClass("slick-sort-indicator-asc slick-sort-indicator-desc");

      $.each(sortColumns, function(i, col) {
        if (col.sortAsc == null) {
          col.sortAsc = true;
        }
        var columnIndex = getColumnIndex(col.columnId);
        if (columnIndex != null) {
          headerColumnEls.eq(columnIndex)
              .addClass("slick-header-column-sorted")
              .find(".slick-sort-indicator")
                  .addClass(col.sortAsc ? "slick-sort-indicator-asc" : "slick-sort-indicator-desc");
        }
      });
    }

    function getSortColumns() {
      return sortColumns;
    }

    function handleSelectedRangesChanged(e, ranges) {
      selectedRows = [];
      var hash = {};
      for (var i = 0; i < ranges.length; i++) {
        for (var j = ranges[i].fromRow; j <= ranges[i].toRow; j++) {
          if (!hash[j]) {  // prevent duplicates
            selectedRows.push(j);
            hash[j] = {};
          }
          for (var k = ranges[i].fromCell; k <= ranges[i].toCell; k++) {
            if (canCellBeSelected(j, k)) {
              hash[j][columns[k].id] = options.selectedCellCssClass;
            }
          }
        }
      }

      setCellCssStyles(options.selectedCellCssClass, hash);

      trigger(self.onSelectedRowsChanged, {rows: getSelectedRows()}, e);
    }

    function getColumns() {
      return columns;
    }

    function updateColumnCaches() {
      // Pre-calculate cell boundaries.
      columnPosLeft = [];
      columnPosRight = [];
      var x = 0;
      for (var i = 0, ii = columns.length; i < ii; i++) {
        columnPosLeft[i] = x;
        columnPosRight[i] = x + columns[i].width;
        x += columns[i].width;
      }
    }

    function setColumns(columnDefinitions) {
      columns = columnDefinitions;

      columnsById = {};
      for (var i = 0; i < columns.length; i++) {
        var m = columns[i] = $.extend({}, columnDefaults, columns[i]);
        columnsById[m.id] = i;
        if (m.minWidth && m.width < m.minWidth) {
          m.width = m.minWidth;
        }
        if (m.maxWidth && m.width > m.maxWidth) {
          m.width = m.maxWidth;
        }
      }

      updateColumnCaches();

      if (initialized) {
        invalidateAllRows();
        createColumnHeaders();
        removeCssRules();
        createCssRules();
        resizeCanvas();
        applyColumnWidths();
        handleScroll();
      }
    }

    function getOptions() {
      return options;
    }

    function setOptions(args) {
      if (!getEditorLock().commitCurrentEdit()) {
        return;
      }

      makeActiveCellNormal();

      if (options.enableAddRow !== args.enableAddRow) {
        invalidateRow(getDataLength());
      }

      options = $.extend(options, args);
      validateAndEnforceOptions();

      $viewport.css("overflow-y", options.autoHeight ? "hidden" : "auto");
      render();
    }

    function validateAndEnforceOptions() {
      if (options.autoHeight) {
        options.leaveSpaceForNewRows = false;
      }
    }

    function setData(newData, scrollToTop) {
      data = newData;
      invalidateAllRows();
      updateRowCount();
      if (scrollToTop) {
        scrollTo(0);
      }
    }

    function getData() {
      return data;
    }

    function getDataLength() {
      if (data.getLength) {
        return data.getLength();
      } else {
        return data.length;
      }
    }

    function getDataItem(i) {
      if (data.getItem) {
        return data.getItem(i);
      } else {
        return data[i];
      }
    }

    function getTopPanel() {
      return $topPanel[0];
    }

    function setTopPanelVisibility(visible) {
      if (options.showTopPanel != visible) {
        options.showTopPanel = visible;
        if (visible) {
          $topPanelScroller.slideDown("fast", resizeCanvas);
        } else {
          $topPanelScroller.slideUp("fast", resizeCanvas);
        }
      }
    }

    function setHeaderRowVisibility(visible) {
      if (options.showHeaderRow != visible) {
        options.showHeaderRow = visible;
        if (visible) {
          $headerRowScroller.slideDown("fast", resizeCanvas);
        } else {
          $headerRowScroller.slideUp("fast", resizeCanvas);
        }
      }
    }

    //////////////////////////////////////////////////////////////////////////////////////////////
    // Rendering / Scrolling

    function scrollTo(y) {
      y = Math.max(y, 0);
      y = Math.min(y, th - viewportH + (viewportHasHScroll ? scrollbarDimensions.height : 0));

      var oldOffset = offset;

      page = Math.min(n - 1, Math.floor(y / ph));
      offset = Math.round(page * cj);
      var newScrollTop = y - offset;

      if (offset != oldOffset) {
        var range = getVisibleRange(newScrollTop);
        cleanupRows(range);
        updateRowPositions();
      }

      if (prevScrollTop != newScrollTop) {
        vScrollDir = (prevScrollTop + oldOffset < newScrollTop + offset) ? 1 : -1;
        $viewport[0].scrollTop = (lastRenderedScrollTop = scrollTop = prevScrollTop = newScrollTop);

        trigger(self.onViewportChanged, {});
      }
    }

    function defaultFormatter(row, cell, value, columnDef, dataContext) {
      if (value == null) {
        return "";
      } else {
        return value.toString().replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;");
      }
    }

    function getFormatter(row, column) {
      var rowMetadata = data.getItemMetadata && data.getItemMetadata(row);

      // look up by id, then index
      var columnOverrides = rowMetadata &&
          rowMetadata.columns &&
          (rowMetadata.columns[column.id] || rowMetadata.columns[getColumnIndex(column.id)]);

      return (columnOverrides && columnOverrides.formatter) ||
          (rowMetadata && rowMetadata.formatter) ||
          column.formatter ||
          (options.formatterFactory && options.formatterFactory.getFormatter(column)) ||
          options.defaultFormatter;
    }

    // [CC] patterned after getFormatter()
    function getTooltipFormatter(row, column) {
      var rowMetadata = data.getItemMetadata && data.getItemMetadata(row);

      // look up by id, then index
      var columnOverrides = rowMetadata &&
          rowMetadata.columns &&
          (rowMetadata.columns[column.id] || rowMetadata.columns[getColumnIndex(column.id)]);

      return (columnOverrides && columnOverrides.tooltipFormatter) ||
          (rowMetadata && rowMetadata.tooltipFormatter) ||
          column.tooltipFormatter ||
          (options.tooltipFormatterFactory && options.tooltipFormatterFactory.getTooltipFormatter(column)) ||
          options.defaultTooltipFormatter;
    }

    function getEditor(row, cell) {
      var column = columns[cell];
      var rowMetadata = data.getItemMetadata && data.getItemMetadata(row);
      var columnMetadata = rowMetadata && rowMetadata.columns;

      if (columnMetadata && columnMetadata[column.id] && columnMetadata[column.id].editor !== undefined) {
        return columnMetadata[column.id].editor;
      }
      if (columnMetadata && columnMetadata[cell] && columnMetadata[cell].editor !== undefined) {
        return columnMetadata[cell].editor;
      }

      return column.editor || (options.editorFactory && options.editorFactory.getEditor(column));
    }

    function getDataItemValueForColumn(item, columnDef) {
      if (options.dataItemColumnValueExtractor) {
        return options.dataItemColumnValueExtractor(item, columnDef);
      }
      return item[columnDef.field];
    }

    function appendRowHtml(stringArray, row, range) {
      var d = getDataItem(row);
      var dataLoading = row < getDataLength() && !d;
      var rowCss = "slick-row" +
          (dataLoading ? " loading" : "") +
          (row === activeRow ? " active" : "") +
          (row % 2 == 1 ? " odd" : " even");

      var metadata = data.getItemMetadata && data.getItemMetadata(row);

      if (metadata && metadata.cssClasses) {
        rowCss += " " + metadata.cssClasses;
      }

      stringArray.push("<div class='ui-widget-content " + rowCss + "' " +
                            "style='top:" + (options.rowHeight * row - offset) + "px' " +
                            "data-row-id='" + (d ? d.get('id') : '') + "'>"); // [CC]

      var colspan, m;
      for (var i = 0, ii = columns.length; i < ii; i++) {
        m = columns[i];
        colspan = 1;
        if (metadata && metadata.columns) {
          var columnData = metadata.columns[m.id] || metadata.columns[i];
          colspan = (columnData && columnData.colspan) || 1;
          if (colspan === "*") {
            colspan = ii - i;
          }
        }

        // Do not render cells outside of the viewport.
        if (columnPosRight[Math.min(ii - 1, i + colspan - 1)] > range.leftPx) {
          if (columnPosLeft[i] > range.rightPx) {
            // All columns to the right are outside the range.
            break;
          }

          appendCellHtml(stringArray, row, i, colspan);
        }

        if (colspan > 1) {
          i += (colspan - 1);
        }
      }

      stringArray.push("</div>");
    }

    function appendCellHtml(stringArray, row, cell, colspan) {
      var m = columns[cell];
      var d = getDataItem(row);
      var cellCss = "slick-cell l" + cell + " r" + Math.min(columns.length - 1, cell + colspan - 1) +
          (m.cssClass ? " " + m.cssClass : "");
      if (row === activeRow && cell === activeCell) {
        cellCss += (" active");
      }

      // TODO:  merge them together in the setter
      for (var key in cellCssClasses) {
        if (cellCssClasses[key][row] && cellCssClasses[key][row][m.id]) {
          cellCss += (" " + cellCssClasses[key][row][m.id]);
        }
      }

      var cellValue = "",
          formattedValue = "",
          tooltipFormatter,
          tooltipValue = "",
          tooltipAttr = "";
      // if there is a corresponding row (if not, this is the Add New row or this data hasn't been loaded yet)
      if (d) {
        cellValue = getDataItemValueForColumn(d, m);
        formattedValue = getFormatter(row, m)(row, cell, cellValue, m, d);
        tooltipFormatter = getTooltipFormatter(row, m);
        tooltipValue = tooltipFormatter ? tooltipFormatter(row, cell, cellValue, formattedValue, m, d) : "";
        tooltipAttr = tooltipValue ? " title=\"" + tooltipValue + "\"" : "";
      }

      // [CC] https://css-tricks.com/almanac/properties/l/line-clamp/
      var lineHeight = 14,  // must show part of a line to clamp the ellipsis on that line
          style = " style='-webkit-line-clamp:" + Math.ceil((options.rowHeight - 8) / lineHeight) + "'";
      stringArray.push("<div class='" + cellCss + "'" + tooltipAttr + style + ">");
      // [/CC]

      // if there is a corresponding row (if not, this is the Add New row or this data hasn't been loaded yet)
      if (d) {
        stringArray.push(formattedValue);
      }

      stringArray.push("</div>");

      rowsCache[row].cellRenderQueue.push(cell);
      rowsCache[row].cellColSpans[cell] = colspan;
    }

    /*
     * [CC] Handle row height resizing via drag handles
     */
    function handleRowResizeDragInit(e, dd) {
      var retval = trigger(self.onRowResizeDragInit, dd, e);
      if (e.isImmediatePropagationStopped()) {
        return retval;
      }
      return false;
    }

    function handleRowResizeDragStart(e, dd) {
      activeResizeRow = $(dd.target).data("row-index");
      dd.initialRowHeight = options.rowHeight;
      dd.minRowHeight = options.minRowHeight;
      dd.rowHeight = options.rowHeight;
      var retval = trigger(self.onRowResizeDragStart, dd, e);
      if (e.isImmediatePropagationStopped()) {
        return retval;
      }
      return false;
    }

    function handleRowResizeDrag(e, dd) {
      dd.rowHeight = Math.max(dd.minRowHeight, dd.initialRowHeight + dd.deltaY);
      if (options.snapToLineHeight)
        dd.rowHeight = options.snapToLineHeight * Math.round((dd.rowHeight - 4) / options.snapToLineHeight) + 4;
      return trigger(self.onRowResizeDrag, dd, e);
    }

    function handleRowResizeDragEnd(e, dd) {
      trigger(self.onRowResizeDragEnd, dd, e);
      activeResizeRow = null;
    }

    function installRowResizeHandlesForRange(firstRow, lastRow) {
      for (var row = firstRow; row <= lastRow; ++row) {
        var cacheEntry = rowsCache[row];
        if (cacheEntry && cacheEntry.rowNode && !cacheEntry.hasRowResizeHandle) {
          cacheEntry.hasRowResizeHandle = installResizeHandleForRow(row, cacheEntry.rowNode);
        }
      }
    }

    function installResizeHandleForRow(row, rowNode) {
      // don't allow row-resize from input row
      if ($(rowNode).hasClass('dg-proto-row')) return;
      // resizer straddles the bottom edge of the row
      var resizerHeight = options.rowResizerHeight || options.minRowHeight / 2;
      var resizerTop = options.rowHeight - offset - resizerHeight / 2 - 0.5;
      var rowResizer = rowResizers[row] // use cached resizer (with updated position) if available
                        ? rowResizers[row].css("top", resizerTop)
                        : "<div class='slick-row-resizer' data-row-index='" + row + "' style='top:" + resizerTop + "px;height:" + resizerHeight + "px'></div>";
      $(rowNode).append(rowResizer);
      var $resizer = $(rowNode).children(".slick-row-resizer");
      if ($resizer) {
        $resizer.on("draginit", handleRowResizeDragInit);
        $resizer.on("dragstart", handleRowResizeDragStart);
        $resizer.on("drag", handleRowResizeDrag);
        $resizer.on("dragend", handleRowResizeDragEnd);
        return true;  // handlers have been installed
      }
      return false; // handlers have not been installed
    }

    function removeResizeHandleForRow(row, rowNode) {
      var $resizer = $(rowNode).children(".slick-row-resizer");
      if ($resizer) {
        $resizer.off("draginit", handleRowResizeDragInit);
        $resizer.off("dragstart", handleRowResizeDragStart);
        $resizer.off("drag", handleRowResizeDrag);
        $resizer.off("dragend", handleRowResizeDragEnd);
        // detach and cache resize handle so it can be reused
        // otherwise, drag couldn't continue through rerender
        rowResizers[row] = $resizer.detach();
      }
    }
    /*
     * [/CC]
     */

    function cleanupRows(rangeToKeep) {
      // [CC] keep rendering all relevant rows if we're actively resizing
      (activeResizeRow != null) && (rangeToKeep.bottom = Math.max(rangeToKeep.bottom, activeResizeRow));
      for (var i in rowsCache) {
        if (((i = parseInt(i, 10)) !== activeRow) && (i < rangeToKeep.top || i > rangeToKeep.bottom)) {
          removeRowFromCache(i);
        }
      }
    }

    function invalidate() {
      updateRowCount();
      invalidateAllRows();
      render();
    }

    function invalidateAllRows() {
      if (currentEditor) {
        makeActiveCellNormal();
      }
      for (var row in rowsCache) {
        removeRowFromCache(row);
      }
    }

    function removeRowFromCache(row) {
      var cacheEntry = rowsCache[row];
      if (!cacheEntry) {
        return;
      }
      // [CC]
      if (cacheEntry.rowNode && cacheEntry.hasRowResizeHandle) {
        removeResizeHandleForRow(row, cacheEntry.rowNode);
      }
      // [/CC]
      $canvas[0].removeChild(cacheEntry.rowNode);
      delete rowsCache[row];
      delete postProcessedRows[row];
      renderedRows--;
      counter_rows_removed++;
    }

    function invalidateRows(rows) {
      var i, rl;
      if (!rows || !rows.length) {
        return;
      }
      vScrollDir = 0;
      for (i = 0, rl = rows.length; i < rl; i++) {
        if (currentEditor && activeRow === rows[i]) {
          makeActiveCellNormal();
        }
        if (rowsCache[rows[i]]) {
          removeRowFromCache(rows[i]);
        }
      }
    }

    function invalidateRow(row) {
      invalidateRows([row]);
    }

    function updateCell(row, cell) {
      var cellNode = getCellNode(row, cell);
      if (!cellNode) {
        return;
      }

      var m = columns[cell], d = getDataItem(row);
      if (currentEditor && activeRow === row && activeCell === cell) {
        currentEditor.loadValue(d);
      } else {
        cellNode.innerHTML = d ? getFormatter(row, m)(row, cell, getDataItemValueForColumn(d, m), m, d) : "";
        invalidatePostProcessingResults(row);
      }
    }

    function updateRow(row) {
      var cacheEntry = rowsCache[row];
      if (!cacheEntry) {
        return;
      }

      ensureCellNodesInRowsCache(row);

      for (var columnIdx in cacheEntry.cellNodesByColumnIdx) {
        if (!cacheEntry.cellNodesByColumnIdx.hasOwnProperty(columnIdx)) {
          continue;
        }

        columnIdx = columnIdx | 0;
        var m = columns[columnIdx],
            d = getDataItem(row),
            node = cacheEntry.cellNodesByColumnIdx[columnIdx];

        if (row === activeRow && columnIdx === activeCell && currentEditor) {
          currentEditor.loadValue(d);
        } else if (d) {
          node.innerHTML = getFormatter(row, m)(row, columnIdx, getDataItemValueForColumn(d, m), m, d);
        } else {
          node.innerHTML = "";
        }
      }

      invalidatePostProcessingResults(row);
    }

    function getViewportHeight() {
      return parseFloat($.css($container[0], "height", true)) -
          parseFloat($.css($container[0], "paddingTop", true)) -
          parseFloat($.css($container[0], "paddingBottom", true)) -
          parseFloat($.css($headerScroller[0], "height")) - getVBoxDelta($headerScroller) -
          (options.showTopPanel ? options.topPanelHeight + getVBoxDelta($topPanelScroller) : 0) -
          (options.showHeaderRow ? options.headerRowHeight + getVBoxDelta($headerRowScroller) : 0);
    }

    // Returns the size of the content area
    function getContentSize() {
      var canvasWidth = $canvas.width(),
          canvasHeight = $canvas.height(),
          hasVScroll = canvasHeight > $viewport.height(),
          contentWidth = canvasWidth + (hasVScroll ? scrollbarDimensions.width : 0),
          hasHScroll = contentWidth > $viewport.width(),
          contentHeight = canvasHeight + (hasHScroll ? scrollbarDimensions.height : 0);
      return { width: contentWidth, height: contentHeight };
    }

    // Returns the size of the visible area, i.e. between the scroll bars
    function getVisibleSize() {
      var width = $viewport.width(),
          height = $viewport.height(),
          hasHScroll = $canvas.width() > width - scrollbarDimensions.width,
          hasVScroll = $canvas.height() > height - scrollbarDimensions.height;
      width -= hasVScroll ? scrollbarDimensions.width : 0;
      height -= hasHScroll ? scrollbarDimensions.height : 0;
      return { width: width, height: height };
    }

    function resizeCanvas() {
      if (!initialized) { return; }
      if (options.autoHeight) {
        viewportH = options.rowHeight * (getDataLength() + (options.enableAddRow ? 1 : 0));
      } else {
        viewportH = getViewportHeight();
      }

      numVisibleRows = Math.ceil(viewportH / options.rowHeight);
      viewportW = parseFloat($.css($container[0], "width", true));
      if (!options.autoHeight) {
        $viewport.height(viewportH);
      }

      if (options.forceFitColumns) {
        autosizeColumns();
      }

      cleanUpAndRenderCells(getRenderedRange());
      updateRowCount();
      handleScroll();
      render();
    }

    function updateRowCount() {
      if (!initialized) { return; }
      numberOfRows = getDataLength() +
          (options.enableAddRow ? 1 : 0) +
          (options.leaveSpaceForNewRows ? numVisibleRows - 1 : 0);

      var oldViewportHasVScroll = viewportHasVScroll;
      // with autoHeight, we do not need to accommodate the vertical scroll bar
      viewportHasVScroll = !options.autoHeight && (numberOfRows * options.rowHeight > viewportH);

      // remove the rows that are now outside of the data range
      // this helps avoid redundant calls to .removeRow() when the size of the data decreased by thousands of rows
      var l = options.enableAddRow ? getDataLength() : getDataLength() - 1;
      for (var i in rowsCache) {
        if (i >= l) {
          removeRowFromCache(i);
        }
      }

      if (activeCellNode && activeRow > l) {
        resetActiveCell();
      }

      var oldH = h;
      th = Math.max(options.rowHeight * numberOfRows, viewportH - scrollbarDimensions.height);
      if (th < maxSupportedCssHeight) {
        // just one page
        h = ph = th;
        n = 1;
        cj = 0;
      } else {
        // break into pages
        h = maxSupportedCssHeight;
        ph = h / 100;
        n = Math.floor(th / ph);
        cj = (th - h) / (n - 1);
      }

      if (h !== oldH) {
        $canvas.css("height", h);
        scrollTop = $viewport[0].scrollTop;
      }

      var oldScrollTopInRange = (scrollTop + offset <= th - viewportH);

      if (th == 0 || scrollTop == 0) {
        page = offset = 0;
      } else if (oldScrollTopInRange) {
        // maintain virtual position
        scrollTo(scrollTop + offset);
      } else {
        // scroll to bottom
        scrollTo(th - viewportH);
      }

      if (h != oldH && options.autoHeight) {
        resizeCanvas();
      }

      if (options.forceFitColumns && oldViewportHasVScroll != viewportHasVScroll) {
        autosizeColumns();
      }
      updateCanvasWidth(false);
    }

    function getVisibleRange(viewportTop, viewportLeft) {
      if (viewportTop == null) {
        viewportTop = scrollTop;
      }
      if (viewportLeft == null) {
        viewportLeft = scrollLeft;
      }

      return {
        top: Math.floor((viewportTop + offset) / options.rowHeight),
        bottom: Math.ceil((viewportTop + offset + viewportH) / options.rowHeight),
        leftPx: viewportLeft,
        rightPx: viewportLeft + viewportW
      };
    }

    function getRenderedRange(viewportTop, viewportLeft) {
      var range = getVisibleRange(viewportTop, viewportLeft);
      var buffer = Math.round(viewportH / options.rowHeight);
      var minBuffer = 3;

      if (vScrollDir == -1) {
        range.top -= buffer;
        range.bottom += minBuffer;
      } else if (vScrollDir == 1) {
        range.top -= minBuffer;
        range.bottom += buffer;
      } else {
        range.top -= minBuffer;
        range.bottom += minBuffer;
      }

      range.top = Math.max(0, range.top);
      range.bottom = Math.min(options.enableAddRow ? getDataLength() : getDataLength() - 1, range.bottom);

      range.leftPx -= viewportW;
      range.rightPx += viewportW;

      range.leftPx = Math.max(0, range.leftPx);
      range.rightPx = Math.min(canvasWidth, range.rightPx);

      return range;
    }

    function ensureCellNodesInRowsCache(row) {
      var cacheEntry = rowsCache[row];
      if (cacheEntry) {
        if (cacheEntry.cellRenderQueue.length) {
          // [CC] last child is last cell, ignoring row-resize handles
          var lastChild = $(cacheEntry.rowNode).children(".slick-cell").last()[0];
          while (cacheEntry.cellRenderQueue.length) {
            var columnIdx = cacheEntry.cellRenderQueue.pop();
            cacheEntry.cellNodesByColumnIdx[columnIdx] = lastChild;
            lastChild = lastChild.previousSibling;
          }
        }
      }
    }

    function cleanUpCells(range, row) {
      var totalCellsRemoved = 0;
      var cacheEntry = rowsCache[row];

      // Remove cells outside the range.
      var cellsToRemove = [];
      for (var i in cacheEntry.cellNodesByColumnIdx) {
        // I really hate it when people mess with Array.prototype.
        if (!cacheEntry.cellNodesByColumnIdx.hasOwnProperty(i)) {
          continue;
        }

        // This is a string, so it needs to be cast back to a number.
        i = i | 0;

        var colspan = cacheEntry.cellColSpans[i];
        if (columnPosLeft[i] > range.rightPx ||
          columnPosRight[Math.min(columns.length - 1, i + colspan - 1)] < range.leftPx) {
          if (!(row == activeRow && i == activeCell)) {
            cellsToRemove.push(i);
          }
        }
      }

      var cellToRemove;
      while ((cellToRemove = cellsToRemove.pop()) != null) {
        cacheEntry.rowNode.removeChild(cacheEntry.cellNodesByColumnIdx[cellToRemove]);
        delete cacheEntry.cellColSpans[cellToRemove];
        delete cacheEntry.cellNodesByColumnIdx[cellToRemove];
        if (postProcessedRows[row]) {
          delete postProcessedRows[row][cellToRemove];
        }
        totalCellsRemoved++;
      }
    }

    function cleanUpAndRenderCells(range) {
      var cacheEntry;
      var stringArray = [];
      var processedRows = [];
      var cellsAdded;
      var totalCellsAdded = 0;
      var colspan;

      for (var row = range.top; row <= range.bottom; row++) {
        cacheEntry = rowsCache[row];
        if (!cacheEntry) {
          continue;
        }

        // cellRenderQueue populated in renderRows() needs to be cleared first
        ensureCellNodesInRowsCache(row);

        cleanUpCells(range, row);

        // Render missing cells.
        cellsAdded = 0;

        var metadata = data.getItemMetadata && data.getItemMetadata(row);
        metadata = metadata && metadata.columns;

        // TODO:  shorten this loop (index? heuristics? binary search?)
        for (var i = 0, ii = columns.length; i < ii; i++) {
          // Cells to the right are outside the range.
          if (columnPosLeft[i] > range.rightPx) {
            break;
          }

          // Already rendered.
          if ((colspan = cacheEntry.cellColSpans[i]) != null) {
            i += (colspan > 1 ? colspan - 1 : 0);
            continue;
          }

          colspan = 1;
          if (metadata) {
            var columnData = metadata[columns[i].id] || metadata[i];
            colspan = (columnData && columnData.colspan) || 1;
            if (colspan === "*") {
              colspan = ii - i;
            }
          }

          if (columnPosRight[Math.min(ii - 1, i + colspan - 1)] > range.leftPx) {
            appendCellHtml(stringArray, row, i, colspan);
            cellsAdded++;
          }

          i += (colspan > 1 ? colspan - 1 : 0);
        }

        if (cellsAdded) {
          totalCellsAdded += cellsAdded;
          processedRows.push(row);
        }
      }

      if (!stringArray.length) {
        return;
      }

      var x = document.createElement("div");
      x.innerHTML = stringArray.join("");

      var processedRow;
      var node;
      while ((processedRow = processedRows.pop()) != null) {
        cacheEntry = rowsCache[processedRow];
        var columnIdx;
        while ((columnIdx = cacheEntry.cellRenderQueue.pop()) != null) {
          node = x.lastChild;
          cacheEntry.rowNode.appendChild(node);
          cacheEntry.cellNodesByColumnIdx[columnIdx] = node;
        }
      }
    }

    function renderRows(range) {
      var parentNode = $canvas[0],
          stringArray = [],
          rows = [],
          needToReselectCell = false;

      for (var i = range.top; i <= range.bottom; i++) {
        if (rowsCache[i]) {
          continue;
        }
        renderedRows++;
        rows.push(i);

        // Create an entry right away so that appendRowHtml() can
        // start populatating it.
        rowsCache[i] = {
          "rowNode": null,

          "hasRowResizeHandle": false,  // [CC]

          // ColSpans of rendered cells (by column idx).
          // Can also be used for checking whether a cell has been rendered.
          "cellColSpans": [],

          // Cell nodes (by column idx).  Lazy-populated by ensureCellNodesInRowsCache().
          "cellNodesByColumnIdx": [],

          // Column indices of cell nodes that have been rendered, but not yet indexed in
          // cellNodesByColumnIdx.  These are in the same order as cell nodes added at the
          // end of the row.
          "cellRenderQueue": []
        };

        appendRowHtml(stringArray, i, range);
        if (activeCellNode && activeRow === i) {
          needToReselectCell = true;
        }
        counter_rows_rendered++;
      }

      if (!rows.length) { return; }

      var x = document.createElement("div");
      x.innerHTML = stringArray.join("");

      for (var i = 0, ii = rows.length; i < ii; i++) {
        rowsCache[rows[i]].rowNode = parentNode.appendChild(x.firstChild);
        // Safari 6.0.5 doesn't always render the new row immediately.
        // "Touching" the node's offsetWidth is sufficient to force redraw.
        // rowsCache[rows[i]].rowNode.offsetWidth;
      }

      if (needToReselectCell) {
        activeCellNode = getCellNode(activeRow, activeCell);
      }
    }

    function startPostProcessing() {
      if (!options.enableAsyncPostRender) {
        return;
      }
      clearTimeout(h_postrender);
      h_postrender = setTimeout(asyncPostProcessRows, options.asyncPostRenderDelay);
    }

    function invalidatePostProcessingResults(row) {
      delete postProcessedRows[row];
      postProcessFromRow = Math.min(postProcessFromRow, row);
      postProcessToRow = Math.max(postProcessToRow, row);
      startPostProcessing();
    }

    function updateRowPositions() {
      for (var row in rowsCache) {
        rowsCache[row].rowNode.style.top = (row * options.rowHeight - offset) + "px";
      }
    }

    function render() {
      if (!initialized) { return; }
      var visible = getVisibleRange();
      var rendered = getRenderedRange();

      // remove rows no longer in the viewport
      cleanupRows(rendered);

      // add new rows & missing cells in existing rows
      if (lastRenderedScrollLeft != scrollLeft) {
        cleanUpAndRenderCells(rendered);
      }

      // render missing rows
      renderRows(rendered);

      postProcessFromRow = visible.top;
      postProcessToRow = Math.min(options.enableAddRow ? getDataLength() : getDataLength() - 1, visible.bottom);
      (activeResizeRow != null) && (postProcessToRow = Math.max(postProcessToRow, activeResizeRow));  // [CC]
      startPostProcessing();

      installRowResizeHandlesForRange(postProcessFromRow, postProcessToRow);  // [CC]

      lastRenderedScrollTop = scrollTop;
      lastRenderedScrollLeft = scrollLeft;
      h_render = null;
    }

    function handleHeaderRowScroll() {
      var scrollLeft = $headerRowScroller[0].scrollLeft;
      if (scrollLeft != $viewport[0].scrollLeft) {
        $viewport[0].scrollLeft = scrollLeft;
      }
    }

    function handleScroll() {
      scrollTop = $viewport[0].scrollTop;
      scrollLeft = $viewport[0].scrollLeft;
      var vScrollDist = Math.abs(scrollTop - prevScrollTop);
      var hScrollDist = Math.abs(scrollLeft - prevScrollLeft);

      if (hScrollDist) {
        prevScrollLeft = scrollLeft;
        $headerScroller[0].scrollLeft = scrollLeft;
        $topPanelScroller[0].scrollLeft = scrollLeft;
        $headerRowScroller[0].scrollLeft = scrollLeft;
      }

      if (vScrollDist) {
        vScrollDir = prevScrollTop < scrollTop ? 1 : -1;
        prevScrollTop = scrollTop;

        // switch virtual pages if needed
        if (vScrollDist < viewportH) {
          scrollTo(scrollTop + offset);
        } else {
          var oldOffset = offset;
          if (h == viewportH) {
            // see https://github.com/mleibman/SlickGrid/issues/309
            page = n - 1;
          } else {
            page = Math.min(n - 1, Math.floor(scrollTop * ((th - viewportH) / (h - viewportH)) * (1 / ph)));
          }
          offset = Math.round(page * cj);
          if (oldOffset != offset) {
            invalidateAllRows();
          }
        }
      }

      if (hScrollDist || vScrollDist) {
        if (h_render) {
          clearTimeout(h_render);
        }

        if (Math.abs(lastRenderedScrollTop - scrollTop) > 20 ||
            Math.abs(lastRenderedScrollLeft - scrollLeft) > 20) {
          if (options.forceSyncScrolling || (
              Math.abs(lastRenderedScrollTop - scrollTop) < viewportH &&
              Math.abs(lastRenderedScrollLeft - scrollLeft) < viewportW)) {
            render();
          } else {
            h_render = setTimeout(render, 50);
          }

          trigger(self.onViewportChanged, {});
        }
      }

      trigger(self.onScroll, {scrollLeft: scrollLeft, scrollTop: scrollTop});
    }

    function asyncPostProcessRows() {
      while (postProcessFromRow <= postProcessToRow) {
        var row = (vScrollDir >= 0) ? postProcessFromRow++ : postProcessToRow--;
        var cacheEntry = rowsCache[row];
        if (!cacheEntry || row >= getDataLength()) {
          continue;
        }

        if (!postProcessedRows[row]) {
          postProcessedRows[row] = {};
        }

        ensureCellNodesInRowsCache(row);
        for (var columnIdx in cacheEntry.cellNodesByColumnIdx) {
          if (!cacheEntry.cellNodesByColumnIdx.hasOwnProperty(columnIdx)) {
            continue;
          }

          columnIdx = columnIdx | 0;

          var m = columns[columnIdx];
          if (m.asyncPostRender && !postProcessedRows[row][columnIdx]) {
            var node = cacheEntry.cellNodesByColumnIdx[columnIdx];
            if (node) {
              m.asyncPostRender(node, row, getDataItem(row), m);
            }
            postProcessedRows[row][columnIdx] = true;
          }
        }

        h_postrender = setTimeout(asyncPostProcessRows, options.asyncPostRenderDelay);
        return;
      }
    }

    function updateCellCssStylesOnRenderedRows(addedHash, removedHash) {
      var node, columnId, addedRowHash, removedRowHash;
      for (var row in rowsCache) {
        removedRowHash = removedHash && removedHash[row];
        addedRowHash = addedHash && addedHash[row];

        if (removedRowHash) {
          for (columnId in removedRowHash) {
            if (!addedRowHash || removedRowHash[columnId] != addedRowHash[columnId]) {
              node = getCellNode(row, getColumnIndex(columnId));
              if (node) {
                $(node).removeClass(removedRowHash[columnId]);
              }
            }
          }
        }

        if (addedRowHash) {
          for (columnId in addedRowHash) {
            if (!removedRowHash || removedRowHash[columnId] != addedRowHash[columnId]) {
              node = getCellNode(row, getColumnIndex(columnId));
              if (node) {
                $(node).addClass(addedRowHash[columnId]);
              }
            }
          }
        }
      }
    }

    function addCellCssStyles(key, hash) {
      if (cellCssClasses[key]) {
        throw "addCellCssStyles: cell CSS hash with key '" + key + "' already exists.";
      }

      cellCssClasses[key] = hash;
      updateCellCssStylesOnRenderedRows(hash, null);

      trigger(self.onCellCssStylesChanged, { "key": key, "hash": hash });
    }

    function removeCellCssStyles(key) {
      if (!cellCssClasses[key]) {
        return;
      }

      updateCellCssStylesOnRenderedRows(null, cellCssClasses[key]);
      delete cellCssClasses[key];

      trigger(self.onCellCssStylesChanged, { "key": key, "hash": null });
    }

    function setCellCssStyles(key, hash) {
      var prevHash = cellCssClasses[key];

      cellCssClasses[key] = hash;
      updateCellCssStylesOnRenderedRows(hash, prevHash);

      trigger(self.onCellCssStylesChanged, { "key": key, "hash": hash });
    }

    function getCellCssStyles(key) {
      return cellCssClasses[key];
    }

    function flashCell(row, cell, speed) {
      speed = speed || 100;
      if (rowsCache[row]) {
        var $cell = $(getCellNode(row, cell));

        function toggleCellClass(times) {
          if (!times) {
            return;
          }
          setTimeout(function () {
                $cell.queue(function () {
                  $cell.toggleClass(options.cellFlashingCssClass).dequeue();
                  toggleCellClass(times - 1);
                });
              },
              speed);
        }

        toggleCellClass(4);
      }
    }

    //////////////////////////////////////////////////////////////////////////////////////////////
    // Interactivity

    // Handle header drags the way body drags are handled, so we set up a parallel
    // set of handlers to the ones used for body drags.
    function handleHeaderDragInit(e, dd) {
      var $header = $(e.target).closest(".slick-header-column", ".slick-header-columns");
      var column = $header && $header.data("column");

      if (!column) {
        return false;
      }

      dd.column = column;
      retval = trigger(self.onHeaderDragInit, dd, e);
      if (e.isImmediatePropagationStopped()) {
        return retval;
      }

      // if nobody claims to be handling drag'n'drop by stopping immediate propagation,
      // cancel out of it
      return false;
    }

    function handleHeaderDragStart(e, dd) {
      var $header = $(e.target).closest(".slick-header-column", ".slick-header-columns");
      var column = $header && $header.data("column");

      if (!column) {
        return false;
      }

      dd.column = column;
      var retval = trigger(self.onHeaderDragStart, dd, e);
      if (e.isImmediatePropagationStopped()) {
        return retval;
      }

      return false;
    }

    function handleHeaderDrag(e, dd) {
      return trigger(self.onHeaderDrag, dd, e);
    }

    function handleHeaderDragEnd(e, dd) {
      trigger(self.onHeaderDragEnd, dd, e);
    }

    function handleDragInit(e, dd) {
      var cell = getCellFromEvent(e);
      if (!cell || !cellExists(cell.row, cell.cell)) {
        return false;
      }

      retval = trigger(self.onDragInit, dd, e);
      if (e.isImmediatePropagationStopped()) {
        return retval;
      }

      // if nobody claims to be handling drag'n'drop by stopping immediate propagation,
      // cancel out of it
      return false;
    }

    function handleDragStart(e, dd) {
      var cell = getCellFromEvent(e);
      if (!cell || !cellExists(cell.row, cell.cell)) {
        return false;
      }

      var retval = trigger(self.onDragStart, dd, e);
      if (e.isImmediatePropagationStopped()) {
        return retval;
      }

      return false;
    }

    function handleDrag(e, dd) {
      return trigger(self.onDrag, dd, e);
    }

    function handleDragEnd(e, dd) {
      trigger(self.onDragEnd, dd, e);
    }

    function handleKeyDown(e) {
      trigger(self.onKeyDown, {row: activeRow, cell: activeCell}, e);
      var handled = e.isImmediatePropagationStopped();

      if (!handled) {
        if (!e.shiftKey && !e.altKey && !e.ctrlKey) {
          if (e.which == 27) {
            if (!getEditorLock().isActive()) {
              return; // no editing mode to cancel, allow bubbling and default processing (exit without cancelling the event)
            }
            cancelEditAndSetFocus();
          } else if (e.which == 37) {
            handled = navigateLeft();
          } else if (e.which == 39) {
            handled = navigateRight();
          } else if (e.which == 38) {
            handled = navigateUp();
          } else if (e.which == 40) {
            handled = navigateDown();
          } else if (e.which == 9) {
            handled = navigateNext();
          } else if (e.which == 13) {
            if (options.editable) {
              if (currentEditor) {
                // adding new row
                if (activeRow === getDataLength()) {
                  navigateDown();
                } else {
                  commitEditAndSetFocus();
                }
              } else {
                if (getEditorLock().commitCurrentEdit()) {
                  makeActiveCellEditable();
                }
              }
            }
            handled = true;
          }
        } else if (e.which == 9 && e.shiftKey && !e.ctrlKey && !e.altKey) {
          handled = navigatePrev();
        }
      }

      if (handled) {
        // the event has been handled so don't let parent element (bubbling/propagation) or browser (default) handle it
        e.stopPropagation();
        e.preventDefault();
        try {
          e.originalEvent.keyCode = 0; // prevent default behaviour for special keys in IE browsers (F3, F5, etc.)
        }
        // ignore exceptions - setting the original event's keycode throws access denied exception for "Ctrl"
        // (hitting control key only, nothing else), "Shift" (maybe others)
        catch (error) {
        }
      }
    }

    function handleClick(e) {
      if (!currentEditor) {
        // if this click resulted in some cell child node getting focus,
        // don't steal it back - keyboard events will still bubble up
        if (e.target != document.activeElement) {
          setFocus();
        }
      }

      var cell = getCellFromEvent(e);
      if (!cell || (currentEditor !== null && activeRow == cell.row && activeCell == cell.cell)) {
        return;
      }

      trigger(self.onClick, {row: cell.row, cell: cell.cell}, e);
      if (e.isImmediatePropagationStopped()) {
        return;
      }

      if ((activeCell != cell.cell || activeRow != cell.row) && canCellBeActive(cell.row, cell.cell)) {
        if (!getEditorLock().isActive() || getEditorLock().commitCurrentEdit()) {
          scrollRowIntoView(cell.row, false);
          setActiveCellInternal(getCellNode(cell.row, cell.cell),
                                (cell.row === getDataLength()) || canAutoEditCell(cell.row, cell.cell, 'click'));
        }
      }
    }

    function handleContextMenu(e) {
      var $cell = $(e.target).closest(".slick-cell", $canvas);
      if ($cell.length === 0) {
        return;
      }

      // are we editing this cell?
      if (activeCellNode === $cell[0] && currentEditor !== null) {
        return;
      }

      trigger(self.onContextMenu, {}, e);
    }

    function handleDblClick(e) {
      var cell = getCellFromEvent(e);
      if (!cell || (currentEditor !== null && activeRow == cell.row && activeCell == cell.cell)) {
        return;
      }

      trigger(self.onDblClick, {row: cell.row, cell: cell.cell}, e);
      if (e.isImmediatePropagationStopped()) {
        return;
      }

      if (options.editable) {
        gotoCell(cell.row, cell.cell, true);
      }
    }

    function handleHeaderMouseEnter(e) {
      trigger(self.onHeaderMouseEnter, {
        "column": $(this).data("column")
      }, e);
    }

    function handleHeaderMouseLeave(e) {
      trigger(self.onHeaderMouseLeave, {
        "column": $(this).data("column")
      }, e);
    }

    function handleHeaderContextMenu(e) {
      var $header = $(e.target).closest(".slick-header-column", ".slick-header-columns");
      var column = $header && $header.data("column");
      trigger(self.onHeaderContextMenu, {column: column}, e);
    }

    function handleHeaderClick(e) {
      var $header = $(e.target).closest(".slick-header-column", ".slick-header-columns");
      var column = $header && $header.data("column");
      if (column) {
        trigger(self.onHeaderClick, {column: column}, e);
      }
    }

    function handleMouseEnter(e) {
      trigger(self.onMouseEnter, {}, e);
    }

    function handleMouseLeave(e) {
      trigger(self.onMouseLeave, {}, e);
    }

    function cellExists(row, cell) {
      return !(row < 0 || row >= getDataLength() || cell < 0 || cell >= columns.length);
    }

    function getCellFromPoint(x, y) {
      var row = Math.floor((y + offset) / options.rowHeight);
      var cell = 0;

      var w = 0;
      for (var i = 0; i < columns.length && w < x; i++) {
        w += columns[i].width;
        cell++;
      }

      if (cell < 0) {
        cell = 0;
      }

      return {row: row, cell: cell - 1};
    }

    function getCellFromNode(cellNode) {
      // read column number from .l<columnNumber> CSS class
      var cls = /l\d+/.exec(cellNode.className);
      if (!cls) {
        throw "getCellFromNode: cannot get cell - " + cellNode.className;
      }
      return parseInt(cls[0].substr(1, cls[0].length - 1), 10);
    }

    function getRowFromNode(rowNode) {
      for (var row in rowsCache) {
        if (rowsCache[row].rowNode === rowNode) {
          return row | 0;
        }
      }

      return null;
    }

    function getCellFromEvent(e) {
      var $cell = $(e.target).closest(".slick-cell", $canvas);
      if (!$cell.length) {
        return null;
      }

      var row = getRowFromNode($cell[0].parentNode);
      var cell = getCellFromNode($cell[0]);

      if (row == null || cell == null) {
        return null;
      } else {
        return {
          "row": row,
          "cell": cell
        };
      }
    }

    function getCellNodeBox(row, cell) {
      if (!cellExists(row, cell)) {
        return null;
      }

      var y1 = row * options.rowHeight - offset;
      var y2 = y1 + options.rowHeight - 1;
      var x1 = 0;
      for (var i = 0; i < cell; i++) {
        x1 += columns[i].width;
      }
      var x2 = x1 + columns[cell].width;

      return {
        top: y1,
        left: x1,
        bottom: y2,
        right: x2
      };
    }

    //////////////////////////////////////////////////////////////////////////////////////////////
    // Cell switching

    function resetActiveCell() {
      setActiveCellInternal(null, false);
    }

    function setFocus() {
      if (tabbingDirection == -1) {
        $focusSink[0].focus();
      } else {
        $focusSink2[0].focus();
      }
    }

    function scrollCellIntoView(row, cell) {
      var colspan = getColspan(row, cell);
      var left = columnPosLeft[cell],
        right = columnPosRight[cell + (colspan > 1 ? colspan - 1 : 0)],
        scrollRight = scrollLeft + viewportW;

      if (left < scrollLeft) {
        $viewport.scrollLeft(left);
        handleScroll();
        render();
      } else if (right > scrollRight) {
        $viewport.scrollLeft(Math.min(left, right - $viewport[0].clientWidth));
        handleScroll();
        render();
      }
    }

    function setActiveCellInternal(newCell, editMode) {
      if (activeCellNode !== null) {
        makeActiveCellNormal();
        $(activeCellNode).removeClass("active");
        if (rowsCache[activeRow]) {
          $(rowsCache[activeRow].rowNode).removeClass("active");
        }
      }

      var activeCellChanged = (activeCellNode !== newCell);
      activeCellNode = newCell;

      if (activeCellNode != null) {
        activeRow = getRowFromNode(activeCellNode.parentNode);
        activeCell = activePosX = getCellFromNode(activeCellNode);

        $(activeCellNode).addClass("active");
        $(rowsCache[activeRow].rowNode).addClass("active");

        if (options.editable && editMode && isCellPotentiallyEditable(activeRow, activeCell)) {
          clearTimeout(h_editorLoader);

          if (options.asyncEditorLoading) {
            h_editorLoader = setTimeout(function () {
              makeActiveCellEditable();
            }, options.asyncEditorLoadDelay);
          } else {
            makeActiveCellEditable();
          }
        }
      } else {
        activeRow = activeCell = null;
      }

      if (activeCellChanged) {
        trigger(self.onActiveCellChanged, getActiveCell());
      }
    }

    function clearTextSelection() {
      if (document.selection && document.selection.empty) {
        document.selection.empty();
      } else if (window.getSelection) {
        var sel = window.getSelection();
        if (sel && sel.removeAllRanges) {
          sel.removeAllRanges();
        }
      }
    }

    function isCellPotentiallyEditable(row, cell) {
      // is the data for this row loaded?
      if (row < getDataLength() && !getDataItem(row)) {
        return false;
      }

      // are we in the Add New row?  can we create new from this cell?
      if (columns[cell].cannotTriggerInsert && row >= getDataLength()) {
        return false;
      }

      // does this cell have an editor?
      if (!getEditor(row, cell)) {
        return false;
      }

      return true;
    }

    function makeActiveCellNormal() {
      if (!currentEditor) {
        return;
      }
      trigger(self.onBeforeCellEditorDestroy, {editor: currentEditor});
      currentEditor.destroy();
      currentEditor = null;

      if (activeCellNode) {
        var d = getDataItem(activeRow);
        $(activeCellNode).removeClass("editable invalid");
        if (d) {
          var column = columns[activeCell];
          var formatter = getFormatter(activeRow, column);
          activeCellNode.innerHTML = formatter(activeRow, activeCell, getDataItemValueForColumn(d, column), column, getDataItem(activeRow));
          invalidatePostProcessingResults(activeRow);
        }
      }

      // if there previously was text selected on a page (such as selected text in the edit cell just removed),
      // IE can't set focus to anything else correctly
      //
      // Borrowed from a forward checkin on the Slickgrid codeline - jms 3/2015
      //if ($.browser.msie) {
      if (navigator.userAgent.toLowerCase().match(/msie/)) {
        clearTextSelection();
      }

      getEditorLock().deactivate(editController);
    }

    function makeActiveCellEditable(editor) {
      if (!activeCellNode) {
        return;
      }
      if (!options.editable) {
        throw "Grid : makeActiveCellEditable : should never get called when options.editable is false";
      }

      // cancel pending async call if there is one
      clearTimeout(h_editorLoader);

      if (!isCellPotentiallyEditable(activeRow, activeCell)) {
        return;
      }

      var columnDef = columns[activeCell];
      var item = getDataItem(activeRow);

      if (trigger(self.onBeforeEditCell, {row: activeRow, cell: activeCell, item: item, column: columnDef}) === false) {
        setFocus();
        return;
      }

      getEditorLock().activate(editController);
      $(activeCellNode).addClass("editable");

      // don't clear the cell if a custom editor is passed through
      if (!editor) {
        activeCellNode.innerHTML = "";
      }

      currentEditor = new (editor || getEditor(activeRow, activeCell))({
        grid: self,
        gridPosition: absBox($container[0]),
        position: absBox(activeCellNode),
        container: activeCellNode,
        column: columnDef,
        item: item || {},
        commitChanges: commitEditAndSetFocus,
        cancelChanges: cancelEditAndSetFocus
      });

      if (item) {
        currentEditor.loadValue(item);
      }

      serializedEditorValue = currentEditor.serializeValue();

      if (currentEditor.position) {
        handleActiveCellPositionChange();
      }
    }

    function commitEditAndSetFocus() {
      // if the commit fails, it would do so due to a validation error
      // if so, do not steal the focus from the editor
      var cell = getActiveCell();
      if (getEditorLock().commitCurrentEdit()) {
        setFocus();
        if (canAutoEditCell(cell.row, cell.cell, 'commit')) {
          navigateDown();
        }
      }
    }

    function cancelEditAndSetFocus() {
      if (getEditorLock().cancelCurrentEdit()) {
        setFocus();
      }
    }

    function absBox(elem) {
      var box = {
        top: elem.offsetTop,
        left: elem.offsetLeft,
        bottom: 0,
        right: 0,
        width: $(elem).outerWidth(),
        height: $(elem).outerHeight(),
        visible: true};
      box.bottom = box.top + box.height;
      box.right = box.left + box.width;

      // walk up the tree
      var offsetParent = elem.offsetParent;
      while ((elem = elem.parentNode) != document.body) {
        if (box.visible && elem.scrollHeight != elem.offsetHeight && $(elem).css("overflowY") != "visible") {
          box.visible = box.bottom > elem.scrollTop && box.top < elem.scrollTop + elem.clientHeight;
        }

        if (box.visible && elem.scrollWidth != elem.offsetWidth && $(elem).css("overflowX") != "visible") {
          box.visible = box.right > elem.scrollLeft && box.left < elem.scrollLeft + elem.clientWidth;
        }

        box.left -= elem.scrollLeft;
        box.top -= elem.scrollTop;

        if (elem === offsetParent) {
          box.left += elem.offsetLeft;
          box.top += elem.offsetTop;
          offsetParent = elem.offsetParent;
        }

        box.bottom = box.top + box.height;
        box.right = box.left + box.width;
      }

      return box;
    }

    function getActiveCellPosition() {
      return absBox(activeCellNode);
    }

    function getGridPosition() {
      return absBox($container[0])
    }

    function handleActiveCellPositionChange() {
      if (!activeCellNode) {
        return;
      }

      trigger(self.onActiveCellPositionChanged, {});

      if (currentEditor) {
        var cellBox = getActiveCellPosition();
        if (currentEditor.show && currentEditor.hide) {
          if (!cellBox.visible) {
            currentEditor.hide();
          } else {
            currentEditor.show();
          }
        }

        if (currentEditor.position) {
          currentEditor.position(cellBox);
        }
      }
    }

    function getCellEditor() {
      return currentEditor;
    }

    function getActiveCell() {
      if (!activeCellNode) {
        return null;
      } else {
        return {row: activeRow, cell: activeCell};
      }
    }

    function getActiveCellNode() {
      return activeCellNode;
    }

    function scrollRowIntoView(row, doPaging) {
      var rowAtTop = row * options.rowHeight;
      var rowAtBottom = (row + 1) * options.rowHeight - viewportH + (viewportHasHScroll ? scrollbarDimensions.height : 0);

      // need to page down?
      if ((row + 1) * options.rowHeight > scrollTop + viewportH + offset) {
        scrollTo(doPaging ? rowAtTop : rowAtBottom);
        render();
      }
      // or page up?
      else if (row * options.rowHeight < scrollTop + offset) {
        scrollTo(doPaging ? rowAtBottom : rowAtTop);
        render();
      }
    }

    function scrollRowToTop(row) {
      scrollTo(row * options.rowHeight);
      render();
    }

    function getColspan(row, cell) {
      var metadata = data.getItemMetadata && data.getItemMetadata(row);
      if (!metadata || !metadata.columns) {
        return 1;
      }

      var columnData = metadata.columns[columns[cell].id] || metadata.columns[cell];
      var colspan = (columnData && columnData.colspan);
      if (colspan === "*") {
        colspan = columns.length - cell;
      } else {
        colspan = colspan || 1;
      }

      return colspan;
    }

    function findFirstFocusableCell(row) {
      var cell = 0;
      while (cell < columns.length) {
        if (canCellBeActive(row, cell)) {
          return cell;
        }
        cell += getColspan(row, cell);
      }
      return null;
    }

    function findLastFocusableCell(row) {
      var cell = 0;
      var lastFocusableCell = null;
      while (cell < columns.length) {
        if (canCellBeActive(row, cell)) {
          lastFocusableCell = cell;
        }
        cell += getColspan(row, cell);
      }
      return lastFocusableCell;
    }

    function gotoRight(row, cell, posX) {
      if (cell >= columns.length) {
        return null;
      }

      do {
        cell += getColspan(row, cell);
      }
      while (cell < columns.length && !canCellBeActive(row, cell));

      if (cell < columns.length) {
        return {
          "row": row,
          "cell": cell,
          "posX": cell
        };
      }
      return null;
    }

    function gotoLeft(row, cell, posX) {
      if (cell <= 0) {
        return null;
      }

      var firstFocusableCell = findFirstFocusableCell(row);
      if (firstFocusableCell === null || firstFocusableCell >= cell) {
        return null;
      }

      var prev = {
        "row": row,
        "cell": firstFocusableCell,
        "posX": firstFocusableCell
      };
      var pos;
      while (true) {
        pos = gotoRight(prev.row, prev.cell, prev.posX);
        if (!pos) {
          return null;
        }
        if (pos.cell >= cell) {
          return prev;
        }
        prev = pos;
      }
    }

    function gotoDown(row, cell, posX) {
      var prevCell;
      while (true) {
        if (++row >= getDataLength() + (options.enableAddRow ? 1 : 0)) {
          return null;
        }

        prevCell = cell = 0;
        while (cell <= posX) {
          prevCell = cell;
          cell += getColspan(row, cell);
        }

        if (canCellBeActive(row, prevCell)) {
          return {
            "row": row,
            "cell": prevCell,
            "posX": posX
          };
        }
      }
    }

    function gotoUp(row, cell, posX) {
      var prevCell;
      while (true) {
        if (--row < 0) {
          return null;
        }

        prevCell = cell = 0;
        while (cell <= posX) {
          prevCell = cell;
          cell += getColspan(row, cell);
        }

        if (canCellBeActive(row, prevCell)) {
          return {
            "row": row,
            "cell": prevCell,
            "posX": posX
          };
        }
      }
    }

    function gotoNext(row, cell, posX) {
      if (row == null && cell == null) {
        row = cell = posX = 0;
        if (canCellBeActive(row, cell)) {
          return {
            "row": row,
            "cell": cell,
            "posX": cell
          };
        }
      }

      var pos = gotoRight(row, cell, posX);
      if (pos) {
        return pos;
      }

      var firstFocusableCell = null;
      while (++row < getDataLength() + (options.enableAddRow ? 1 : 0)) {
        firstFocusableCell = findFirstFocusableCell(row);
        if (firstFocusableCell !== null) {
          return {
            "row": row,
            "cell": firstFocusableCell,
            "posX": firstFocusableCell
          };
        }
      }
      return null;
    }

    function gotoPrev(row, cell, posX) {
      if (row == null && cell == null) {
        row = getDataLength() + (options.enableAddRow ? 1 : 0) - 1;
        cell = posX = columns.length - 1;
        if (canCellBeActive(row, cell)) {
          return {
            "row": row,
            "cell": cell,
            "posX": cell
          };
        }
      }

      var pos;
      var lastSelectableCell;
      while (!pos) {
        pos = gotoLeft(row, cell, posX);
        if (pos) {
          break;
        }
        if (--row < 0) {
          return null;
        }

        cell = 0;
        lastSelectableCell = findLastFocusableCell(row);
        if (lastSelectableCell !== null) {
          pos = {
            "row": row,
            "cell": lastSelectableCell,
            "posX": lastSelectableCell
          };
        }
      }
      return pos;
    }

    function navigateRight() {
      return navigate("right");
    }

    function navigateLeft() {
      return navigate("left");
    }

    function navigateDown() {
      return navigate("down");
    }

    function navigateUp() {
      return navigate("up");
    }

    function navigateNext() {
      return navigate("next");
    }

    function navigatePrev() {
      return navigate("prev");
    }

    /**
     * @param {string} dir Navigation direction.
     * @return {boolean} Whether navigation resulted in a change of active cell.
     */
    function navigate(dir) {
      if (!options.enableCellNavigation) {
        return false;
      }

      if (!activeCellNode && dir != "prev" && dir != "next") {
        return false;
      }

      if (!getEditorLock().commitCurrentEdit()) {
        return true;
      }
      setFocus();

      var tabbingDirections = {
        "up": -1,
        "down": 1,
        "left": -1,
        "right": 1,
        "prev": -1,
        "next": 1
      };
      tabbingDirection = tabbingDirections[dir];

      var stepFunctions = {
        "up": gotoUp,
        "down": gotoDown,
        "left": gotoLeft,
        "right": gotoRight,
        "prev": gotoPrev,
        "next": gotoNext
      };
      var stepFn = stepFunctions[dir];
      var pos = stepFn(activeRow, activeCell, activePosX);
      if (pos) {
        var isAddNewRow = (pos.row == getDataLength());
        scrollRowIntoView(pos.row, !isAddNewRow);
        scrollCellIntoView(pos.row, pos.cell);
        setActiveCellInternal(getCellNode(pos.row, pos.cell), isAddNewRow || canAutoEditCell(pos.row, pos.cell, 'navigate'));
        activePosX = pos.posX;
        return true;
      } else {
        setActiveCellInternal(getCellNode(activeRow, activeCell), (activeRow == getDataLength()) || canAutoEditCell(activeRow, activeCell, 'navigate'));
        return false;
      }
    }

    function getCellNode(row, cell) {
      if (rowsCache[row]) {
        ensureCellNodesInRowsCache(row);
        return rowsCache[row].cellNodesByColumnIdx[cell];
      }
      return null;
    }

    function setActiveCell(row, cell) {
      if (!initialized) { return; }
      if (row > getDataLength() || row < 0 || cell >= columns.length || cell < 0) {
        return;
      }

      if (!options.enableCellNavigation) {
        return;
      }

      scrollRowIntoView(row, false);
      scrollCellIntoView(row, cell);
      setActiveCellInternal(getCellNode(row, cell), false);
    }

    function canCellBeActive(row, cell) {
      if (!options.enableCellNavigation || row >= getDataLength() + (options.enableAddRow ? 1 : 0) ||
          row < 0 || cell >= columns.length || cell < 0) {
        return false;
      }

      var rowMetadata = data.getItemMetadata && data.getItemMetadata(row);
      if (rowMetadata && typeof rowMetadata.focusable === "boolean") {
        return rowMetadata.focusable;
      }

      var columnMetadata = rowMetadata && rowMetadata.columns;
      if (columnMetadata && columnMetadata[columns[cell].id] && typeof columnMetadata[columns[cell].id].focusable === "boolean") {
        return columnMetadata[columns[cell].id].focusable;
      }
      if (columnMetadata && columnMetadata[cell] && typeof columnMetadata[cell].focusable === "boolean") {
        return columnMetadata[cell].focusable;
      }

      return columns[cell].focusable;
    }

    function canCellBeSelected(row, cell) {
      if (row >= getDataLength() || row < 0 || cell >= columns.length || cell < 0) {
        return false;
      }

      var rowMetadata = data.getItemMetadata && data.getItemMetadata(row);
      if (rowMetadata && typeof rowMetadata.selectable === "boolean") {
        return rowMetadata.selectable;
      }

      var columnMetadata = rowMetadata && rowMetadata.columns && (rowMetadata.columns[columns[cell].id] || rowMetadata.columns[cell]);
      if (columnMetadata && typeof columnMetadata.selectable === "boolean") {
        return columnMetadata.selectable;
      }

      return columns[cell].selectable;
    }

    // [CC] Added to enable autoEdit on a cell-by-cell basis
    function canAutoEditCell(row, cell, source) {
      return options.autoEdit || trigger(self.onBeforeAutoEditCell, {row: row, cell: cell, source: source});
    }

    function gotoCell(row, cell, forceEdit) {
      if (!initialized) { return; }
      if (!canCellBeActive(row, cell)) {
        return;
      }

      if (!getEditorLock().commitCurrentEdit()) {
        return;
      }

      scrollRowIntoView(row, false);
      scrollCellIntoView(row, cell);

      var newCell = getCellNode(row, cell);

      // if selecting the 'add new' row, start editing right away
      setActiveCellInternal(newCell, forceEdit || (row === getDataLength()) || canAutoEditCell(row, cell, 'goto'));

      // if no editor was created, set the focus back on the grid
      if (!currentEditor) {
        setFocus();
      }
    }


    //////////////////////////////////////////////////////////////////////////////////////////////
    // IEditor implementation for the editor lock

    function commitCurrentEdit() {
      var item = getDataItem(activeRow);
      var column = columns[activeCell];

      if (currentEditor) {
        if (currentEditor.isValueChanged()) {
          var validationResults = currentEditor.validate();

          if (validationResults.valid) {
            if (activeRow < getDataLength()) {
              var editCommand = {
                row: activeRow,
                cell: activeCell,
                editor: currentEditor,
                serializedValue: currentEditor.serializeValue(),
                prevSerializedValue: serializedEditorValue,
                execute: function () {
                  this.editor.applyValue(item, this.serializedValue);
                  updateRow(this.row);
                },
                undo: function () {
                  this.editor.applyValue(item, this.prevSerializedValue);
                  updateRow(this.row);
                }
              };

              if (options.editCommandHandler) {
                makeActiveCellNormal();
                options.editCommandHandler(item, column, editCommand);
              } else {
                editCommand.execute();
                makeActiveCellNormal();
              }

              trigger(self.onCellChange, {
                row: activeRow,
                cell: activeCell,
                item: item
              });
            } else {
              var newItem = {};
              currentEditor.applyValue(newItem, currentEditor.serializeValue());
              makeActiveCellNormal();
              trigger(self.onAddNewRow, {item: newItem, column: column});
            }

            // check whether the lock has been re-acquired by event handlers
            return !getEditorLock().isActive();
          } else {
            // TODO: remove and put in onValidationError handlers in examples
            $(activeCellNode).addClass("invalid");
            $(activeCellNode).stop(true, true).effect("highlight", {color: "red"}, 300);

            trigger(self.onValidationError, {
              editor: currentEditor,
              cellNode: activeCellNode,
              validationResults: validationResults,
              row: activeRow,
              cell: activeCell,
              column: column
            });

            currentEditor.focus();
            return false;
          }
        }

        makeActiveCellNormal();
      }
      return true;
    }

    function cancelCurrentEdit() {
      makeActiveCellNormal();
      return true;
    }

    function rowsToRanges(rows) {
      var ranges = [];
      var lastCell = columns.length - 1;
      for (var i = 0; i < rows.length; i++) {
        ranges.push(new Slick.Range(rows[i], 0, rows[i], lastCell));
      }
      return ranges;
    }

    function getSelectedRows() {
      if (!selectionModel) {
        throw "Selection model is not set";
      }
      return selectedRows;
    }

    function setSelectedRows(rows) {
      if (!selectionModel) {
        throw "Selection model is not set";
      }
      selectionModel.setSelectedRanges(rowsToRanges(rows));
    }


    //////////////////////////////////////////////////////////////////////////////////////////////
    // Debug

    this.debug = function () {
      var s = "";

      s += ("\n" + "counter_rows_rendered:  " + counter_rows_rendered);
      s += ("\n" + "counter_rows_removed:  " + counter_rows_removed);
      s += ("\n" + "renderedRows:  " + renderedRows);
      s += ("\n" + "numVisibleRows:  " + numVisibleRows);
      s += ("\n" + "maxSupportedCssHeight:  " + maxSupportedCssHeight);
      s += ("\n" + "n(umber of pages):  " + n);
      s += ("\n" + "(current) page:  " + page);
      s += ("\n" + "page height (ph):  " + ph);
      s += ("\n" + "vScrollDir:  " + vScrollDir);

      alert(s);
    };

    // a debug helper to be able to access private members
    this.eval = function (expr) {
      return eval(expr);
    };

    //////////////////////////////////////////////////////////////////////////////////////////////
    // Public API

    $.extend(this, {
      "slickGridVersion": "2.1",

      // Events
      "onScroll": new Slick.Event(),
      "onSort": new Slick.Event(),
      "onHeaderMouseEnter": new Slick.Event(),
      "onHeaderMouseLeave": new Slick.Event(),
      "onHeaderContextMenu": new Slick.Event(),
      "onHeaderClick": new Slick.Event(),
      "onHeaderCellRendered": new Slick.Event(),
      "onBeforeHeaderCellDestroy": new Slick.Event(),
      "onHeaderRowCellRendered": new Slick.Event(),
      "onBeforeHeaderRowCellDestroy": new Slick.Event(),
      "onMouseEnter": new Slick.Event(),
      "onMouseLeave": new Slick.Event(),
      "onClick": new Slick.Event(),
      "onDblClick": new Slick.Event(),
      "onContextMenu": new Slick.Event(),
      "onKeyDown": new Slick.Event(),
      "onAddNewRow": new Slick.Event(),
      "onValidationError": new Slick.Event(),
      "onCanvasWidthChanged": new Slick.Event(),
      "onViewportChanged": new Slick.Event(),
      "onColumnsReordered": new Slick.Event(),
      "onColumnsResized": new Slick.Event(),
      "onCellChange": new Slick.Event(),
      "onBeforeAutoEditCell": new Slick.Event(),  // [CC]
      "onBeforeEditCell": new Slick.Event(),
      "onBeforeCellEditorDestroy": new Slick.Event(),
      "onBeforeDestroy": new Slick.Event(),
      "onActiveCellChanged": new Slick.Event(),
      "onActiveCellPositionChanged": new Slick.Event(),
      "onHeaderDragInit": new Slick.Event(),
      "onHeaderDragStart": new Slick.Event(),
      "onHeaderDrag": new Slick.Event(),
      "onHeaderDragEnd": new Slick.Event(),
      "onDragInit": new Slick.Event(),
      "onDragStart": new Slick.Event(),
      "onDrag": new Slick.Event(),
      "onDragEnd": new Slick.Event(),
      "onSelectedRowsChanged": new Slick.Event(),
      "onCellCssStylesChanged": new Slick.Event(),

      // [CC]
      // for in progress notifications of column resizing.
      "onColumnResizing": new Slick.Event(),
      // row resizing
      "onRowResizeDragInit": new Slick.Event(),
      "onRowResizeDragStart": new Slick.Event(),
      "onRowResizeDrag": new Slick.Event(),
      "onRowResizeDragEnd": new Slick.Event(),
      // [/CC]

      // Methods
      "registerPlugin": registerPlugin,
      "unregisterPlugin": unregisterPlugin,
      "getColumns": getColumns,
      "setColumns": setColumns,
      "getColumnIndex": getColumnIndex,
      "updateColumnHeader": updateColumnHeader,
      "setSortColumn": setSortColumn,
      "setSortColumns": setSortColumns,
      "getSortColumns": getSortColumns,
      "autosizeColumns": autosizeColumns,
      "getOptions": getOptions,
      "setOptions": setOptions,
      "getData": getData,
      "getDataLength": getDataLength,
      "getDataItem": getDataItem,
      "setData": setData,
      "getSelectionModel": getSelectionModel,
      "setSelectionModel": setSelectionModel,
      "getSelectedRows": getSelectedRows,
      "setSelectedRows": setSelectedRows,

      "render": render,
      "invalidate": invalidate,
      "invalidateRow": invalidateRow,
      "invalidateRows": invalidateRows,
      "invalidateAllRows": invalidateAllRows,
      "updateCell": updateCell,
      "updateRow": updateRow,
      "getViewport": getVisibleRange,
      "getRenderedRange": getRenderedRange,
      "getContentSize": getContentSize,
      "getVisibleSize": getVisibleSize,
      "resizeCanvas": resizeCanvas,
      "updateRowCount": updateRowCount,
      "scrollRowIntoView": scrollRowIntoView,
      "scrollRowToTop": scrollRowToTop,
      "scrollCellIntoView": scrollCellIntoView,
      "getCanvasNode": getCanvasNode,
      "focus": setFocus,

      "getCellFromPoint": getCellFromPoint,
      "getCellFromEvent": getCellFromEvent,
      "getActiveCell": getActiveCell,
      "setActiveCell": setActiveCell,
      "getActiveCellNode": getActiveCellNode,
      "getActiveCellPosition": getActiveCellPosition,
      "resetActiveCell": resetActiveCell,
      "editActiveCell": makeActiveCellEditable,
      "getCellEditor": getCellEditor,
      "getCellNode": getCellNode,
      "getCellNodeBox": getCellNodeBox,
      "canCellBeSelected": canCellBeSelected,
      "canCellBeActive": canCellBeActive,
      "navigatePrev": navigatePrev,
      "navigateNext": navigateNext,
      "navigateUp": navigateUp,
      "navigateDown": navigateDown,
      "navigateLeft": navigateLeft,
      "navigateRight": navigateRight,
      "gotoCell": gotoCell,
      "getTopPanel": getTopPanel,
      "setTopPanelVisibility": setTopPanelVisibility,
      "setHeaderRowVisibility": setHeaderRowVisibility,
      "getHeaderRow": getHeaderRow,
      "getHeaderRowColumn": getHeaderRowColumn,
      "getGridPosition": getGridPosition,
      "flashCell": flashCell,
      "addCellCssStyles": addCellCssStyles,
      "setCellCssStyles": setCellCssStyles,
      "removeCellCssStyles": removeCellCssStyles,
      "getCellCssStyles": getCellCssStyles,

      "init": finishInitialization,
      "destroy": destroy,

      // IEditor implementation
      "getEditorLock": getEditorLock,
      "getEditController": getEditController
    });

    init();
  }
}(jQuery));

/* >>>>>>>>>> BEGIN source/libraries/slickgrid/slick.groupitemmetadataprovider.js */
(function ($) {
  $.extend(true, window, {
    Slick: {
      Data: {
        GroupItemMetadataProvider: GroupItemMetadataProvider
      }
    }
  });


  /***
   * Provides item metadata for group (Slick.Group) and totals (Slick.Totals) rows produced by the DataView.
   * This metadata overrides the default behavior and formatting of those rows so that they appear and function
   * correctly when processed by the grid.
   *
   * This class also acts as a grid plugin providing event handlers to expand & collapse groups.
   * If "grid.registerPlugin(...)" is not called, expand & collapse will not work.
   *
   * @class GroupItemMetadataProvider
   * @module Data
   * @namespace Slick.Data
   * @constructor
   * @param options
   */
  function GroupItemMetadataProvider(options) {
    var _grid;
    var _defaults = {
      groupCssClass: "slick-group",
      groupTitleCssClass: "slick-group-title",
      totalsCssClass: "slick-group-totals",
      groupSelectable: false,
      groupFocusable: true,
      totalsFocusable: false,
      toggleCssClass: "slick-group-toggle",
      toggleExpandedCssClass: "expanded",
      toggleCollapsedCssClass: "collapsed",
      enableExpandCollapse: true
    };

    options = $.extend(true, {}, _defaults, options);


    function defaultGroupCellFormatter(row, cell, value, columnDef, item) {
      if (!options.enableExpandCollapse) {
        return item.title;
      }

      var indentation = item.level * 15 + "px";

      return "<span class='" + options.toggleCssClass + " " +
          (item.collapsed ? options.toggleCollapsedCssClass : options.toggleExpandedCssClass) +
          "' style='margin-left:" + indentation +"'>" +
          "</span>" +
          "<span class='" + options.groupTitleCssClass + "' level='" + item.level + "'>" +
            item.title +
          "</span>";
    }

    function defaultTotalsCellFormatter(row, cell, value, columnDef, item) {
      return (columnDef.groupTotalsFormatter && columnDef.groupTotalsFormatter(item, columnDef)) || "";
    }


    function init(grid) {
      _grid = grid;
      _grid.onClick.subscribe(handleGridClick);
      _grid.onKeyDown.subscribe(handleGridKeyDown);

    }

    function destroy() {
      if (_grid) {
        _grid.onClick.unsubscribe(handleGridClick);
        _grid.onKeyDown.unsubscribe(handleGridKeyDown);
      }
    }

    function handleGridClick(e, args) {
      var item = this.getDataItem(args.row);
      if (item && item instanceof Slick.Group && $(e.target).hasClass(options.toggleCssClass)) {
        if (item.collapsed) {
          this.getData().expandGroup(item.groupingKey);
        } else {
          this.getData().collapseGroup(item.groupingKey);
        }

        e.stopImmediatePropagation();
        e.preventDefault();
      }
    }

    // TODO:  add -/+ handling
    function handleGridKeyDown(e, args) {
      if (options.enableExpandCollapse && (e.which == $.ui.keyCode.SPACE)) {
        var activeCell = this.getActiveCell();
        if (activeCell) {
          var item = this.getDataItem(activeCell.row);
          if (item && item instanceof Slick.Group) {
            if (item.collapsed) {
              this.getData().expandGroup(item.groupingKey);
            } else {
              this.getData().collapseGroup(item.groupingKey);
            }

            e.stopImmediatePropagation();
            e.preventDefault();
          }
        }
      }
    }

    function getGroupRowMetadata(item) {
      return {
        selectable: options.groupSelectable,
        focusable: options.groupFocusable,
        cssClasses: options.groupCssClass,
        columns: {
          0: {
            colspan: "*",
            formatter: defaultGroupCellFormatter,
            editor: null
          }
        }
      };
    }

    function getTotalsRowMetadata(item) {
      return {
        selectable: false,
        focusable: options.totalsFocusable,
        cssClasses: options.totalsCssClass,
        formatter: defaultTotalsCellFormatter,
        editor: null
      };
    }


    return {
      "init": init,
      "destroy": destroy,
      "getGroupRowMetadata": getGroupRowMetadata,
      "getTotalsRowMetadata": getTotalsRowMetadata
    };
  }
})(jQuery);

/* >>>>>>>>>> BEGIN source/libraries/spectrum/spectrum.js */
// Spectrum Colorpicker v1.7.0
// https://github.com/bgrins/spectrum
// Author: Brian Grinstead
// License: MIT

(function (factory) {
    "use strict";

    if (typeof define === 'function' && define.amd) { // AMD
        define(['jquery'], factory);
    }
    else if (typeof exports == "object" && typeof module == "object") { // CommonJS
        module.exports = factory;
    }
    else { // Browser
        factory(jQuery);
    }
})(function($, undefined) {
    "use strict";

    var defaultOpts = {

        // Callbacks
        beforeShow: noop,
        move: noop,
        change: noop,
        show: noop,
        hide: noop,

        // Options
        color: false,
        flat: false,
        showInput: false,
        allowEmpty: false,
        showButtons: true,
        clickoutFiresChange: true,
        showInitial: false,
        showPalette: false,
        showPaletteOnly: false,
        hideAfterPaletteSelect: false,
        togglePaletteOnly: false,
        showSelectionPalette: true,
        localStorageKey: false,
        appendTo: "body",
        maxSelectionSize: 7,
        cancelText: "cancel",
        chooseText: "choose",
        togglePaletteMoreText: "more",
        togglePaletteLessText: "less",
        clearText: "Clear Color Selection",
        noColorSelectedText: "No Color Selected",
        preferredFormat: false,
        className: "", // Deprecated - use containerClassName and replacerClassName instead.
        containerClassName: "",
        replacerClassName: "",
        showAlpha: false,
        theme: "sp-light",
        palette: [["#ffffff", "#000000", "#ff0000", "#ff8000", "#ffff00", "#008000", "#0000ff", "#4b0082", "#9400d3"]],
        selectionPalette: [],
        disabled: false,
        offset: null
    },
    spectrums = [],
    IE = !!/msie/i.exec( window.navigator.userAgent ),
    rgbaSupport = (function() {
        function contains( str, substr ) {
            return !!~('' + str).indexOf(substr);
        }

        var elem = document.createElement('div');
        var style = elem.style;
        style.cssText = 'background-color:rgba(0,0,0,.5)';
        return contains(style.backgroundColor, 'rgba') || contains(style.backgroundColor, 'hsla');
    })(),
    replaceInput = [
        "<div class='sp-replacer'>",
            "<div class='sp-preview'><div class='sp-preview-inner'></div></div>",
            "<div class='sp-dd'>&#9660;</div>",
        "</div>"
    ].join(''),
    markup = (function () {

        // IE does not support gradients with multiple stops, so we need to simulate
        //  that for the rainbow slider with 8 divs that each have a single gradient
        var gradientFix = "";
        if (IE) {
            for (var i = 1; i <= 6; i++) {
                gradientFix += "<div class='sp-" + i + "'></div>";
            }
        }

        return [
            "<div class='sp-container sp-hidden'>",
                "<div class='sp-palette-container'>",
                    "<div class='sp-palette sp-thumb sp-cf'></div>",
                    "<div class='sp-palette-button-container sp-cf'>",
                        "<button type='button' class='sp-palette-toggle'></button>",
                    "</div>",
                "</div>",
                "<div class='sp-picker-container'>",
                    "<div class='sp-top sp-cf'>",
                        "<div class='sp-fill'></div>",
                        "<div class='sp-top-inner'>",
                            "<div class='sp-color'>",
                                "<div class='sp-sat'>",
                                    "<div class='sp-val'>",
                                        "<div class='sp-dragger'></div>",
                                    "</div>",
                                "</div>",
                            "</div>",
                            "<div class='sp-clear sp-clear-display'>",
                            "</div>",
                            "<div class='sp-hue'>",
                                "<div class='sp-slider'></div>",
                                gradientFix,
                            "</div>",
                        "</div>",
                        "<div class='sp-alpha'><div class='sp-alpha-inner'><div class='sp-alpha-handle'></div></div></div>",
                    "</div>",
                    "<div class='sp-input-container sp-cf'>",
                        "<input class='sp-input' type='text' spellcheck='false'  />",
                    "</div>",
                    "<div class='sp-initial sp-thumb sp-cf'></div>",
                    "<div class='sp-button-container sp-cf'>",
                        "<a class='sp-cancel' href='#'></a>",
                        "<button type='button' class='sp-choose'></button>",
                    "</div>",
                "</div>",
            "</div>"
        ].join("");
    })();

    function paletteTemplate (p, color, className, opts) {
        var html = [];
        for (var i = 0; i < p.length; i++) {
            var current = p[i];
            if(current) {
                var tiny = tinycolor(current);
                var c = tiny.toHsl().l < 0.5 ? "sp-thumb-el sp-thumb-dark" : "sp-thumb-el sp-thumb-light";
                c += (tinycolor.equals(color, current)) ? " sp-thumb-active" : "";
                var formattedString = tiny.toString(opts.preferredFormat || "rgb");
                var swatchStyle = rgbaSupport ? ("background-color:" + tiny.toRgbString()) : "filter:" + tiny.toFilter();
                html.push('<span title="' + formattedString + '" data-color="' + tiny.toRgbString() + '" class="' + c + '"><span class="sp-thumb-inner" style="' + swatchStyle + ';" /></span>');
            } else {
                var cls = 'sp-clear-display';
                html.push($('<div />')
                    .append($('<span data-color="" style="background-color:transparent;" class="' + cls + '"></span>')
                        .attr('title', opts.noColorSelectedText)
                    )
                    .html()
                );
            }
        }
        return "<div class='sp-cf " + className + "'>" + html.join('') + "</div>";
    }

    function hideAll() {
        for (var i = 0; i < spectrums.length; i++) {
            if (spectrums[i]) {
                spectrums[i].hide();
            }
        }
    }

    function instanceOptions(o, callbackContext) {
        var opts = $.extend({}, defaultOpts, o);
        opts.callbacks = {
            'move': bind(opts.move, callbackContext),
            'change': bind(opts.change, callbackContext),
            'show': bind(opts.show, callbackContext),
            'hide': bind(opts.hide, callbackContext),
            'beforeShow': bind(opts.beforeShow, callbackContext)
        };

        return opts;
    }

    function spectrum(element, o) {

        var opts = instanceOptions(o, element),
            flat = opts.flat,
            showSelectionPalette = opts.showSelectionPalette,
            localStorageKey = opts.localStorageKey,
            theme = opts.theme,
            callbacks = opts.callbacks,
            resize = throttle(reflow, 10),
            visible = false,
            isDragging = false,
            dragWidth = 0,
            dragHeight = 0,
            dragHelperHeight = 0,
            slideHeight = 0,
            slideWidth = 0,
            alphaWidth = 0,
            alphaSlideHelperWidth = 0,
            slideHelperHeight = 0,
            currentHue = 0,
            currentSaturation = 0,
            currentValue = 0,
            currentAlpha = 1,
            palette = [],
            paletteArray = [],
            paletteLookup = {},
            selectionPalette = opts.selectionPalette.slice(0),
            maxSelectionSize = opts.maxSelectionSize,
            draggingClass = "sp-dragging",
            shiftMovementDirection = null;

        var doc = element.ownerDocument,
            body = doc.body,
            boundElement = $(element),
            disabled = false,
            container = $(markup, doc).addClass(theme),
            pickerContainer = container.find(".sp-picker-container"),
            dragger = container.find(".sp-color"),
            dragHelper = container.find(".sp-dragger"),
            slider = container.find(".sp-hue"),
            slideHelper = container.find(".sp-slider"),
            alphaSliderInner = container.find(".sp-alpha-inner"),
            alphaSlider = container.find(".sp-alpha"),
            alphaSlideHelper = container.find(".sp-alpha-handle"),
            textInput = container.find(".sp-input"),
            paletteContainer = container.find(".sp-palette"),
            initialColorContainer = container.find(".sp-initial"),
            cancelButton = container.find(".sp-cancel"),
            clearButton = container.find(".sp-clear"),
            chooseButton = container.find(".sp-choose"),
            toggleButton = container.find(".sp-palette-toggle"),
            isInput = boundElement.is("input"),
            isInputTypeColor = isInput && boundElement.attr("type") === "color" && inputTypeColorSupport(),
            shouldReplace = isInput && !flat,
            replacer = (shouldReplace) ? $(replaceInput).addClass(theme).addClass(opts.className).addClass(opts.replacerClassName) : $([]),
            offsetElement = (shouldReplace) ? replacer : boundElement,
            previewElement = replacer.find(".sp-preview-inner"),
            initialColor = opts.color || (isInput && boundElement.val()),
            colorOnShow = false,
            preferredFormat = opts.preferredFormat,
            currentPreferredFormat = preferredFormat,
            clickoutFiresChange = !opts.showButtons || opts.clickoutFiresChange,
            isEmpty = !initialColor,
            allowEmpty = opts.allowEmpty && !isInputTypeColor;

        function applyOptions() {

            if (opts.showPaletteOnly) {
                opts.showPalette = true;
            }

            toggleButton.text(opts.showPaletteOnly ? opts.togglePaletteMoreText : opts.togglePaletteLessText);

            if (opts.palette) {
                palette = opts.palette.slice(0);
                paletteArray = $.isArray(palette[0]) ? palette : [palette];
                paletteLookup = {};
                for (var i = 0; i < paletteArray.length; i++) {
                    for (var j = 0; j < paletteArray[i].length; j++) {
                        var rgb = tinycolor(paletteArray[i][j]).toRgbString();
                        paletteLookup[rgb] = true;
                    }
                }
            }

            container.toggleClass("sp-flat", flat);
            container.toggleClass("sp-input-disabled", !opts.showInput);
            container.toggleClass("sp-alpha-enabled", opts.showAlpha);
            container.toggleClass("sp-clear-enabled", allowEmpty);
            container.toggleClass("sp-buttons-disabled", !opts.showButtons);
            container.toggleClass("sp-palette-buttons-disabled", !opts.togglePaletteOnly);
            container.toggleClass("sp-palette-disabled", !opts.showPalette);
            container.toggleClass("sp-palette-only", opts.showPaletteOnly);
            container.toggleClass("sp-initial-disabled", !opts.showInitial);
            container.addClass(opts.className).addClass(opts.containerClassName);

            reflow();
        }

        function initialize() {

            if (IE) {
                container.find("*:not(input)").attr("unselectable", "on");
            }

            applyOptions();

            if (shouldReplace) {
                boundElement.after(replacer).hide();
            }

            if (!allowEmpty) {
                clearButton.hide();
            }

            if (flat) {
                boundElement.after(container).hide();
            }
            else {

                var appendTo = opts.appendTo === "parent" ? boundElement.parent() : $(opts.appendTo);
                if (appendTo.length !== 1) {
                    appendTo = $("body");
                }

                appendTo.append(container);
            }

            updateSelectionPaletteFromStorage();

            offsetElement.bind("click.spectrum touchstart.spectrum", function (e) {
                if (!disabled) {
                    toggle();
                }

                e.stopPropagation();

                if (!$(e.target).is("input")) {
                    e.preventDefault();
                }
            });

            if(boundElement.is(":disabled") || (opts.disabled === true)) {
                disable();
            }

            // Prevent clicks from bubbling up to document.  This would cause it to be hidden.
            container.click(stopPropagation);

            // Handle user typed input
            textInput.change(setFromTextInput);
            textInput.bind("paste", function () {
                setTimeout(setFromTextInput, 1);
            });
            textInput.keydown(function (e) { if (e.keyCode == 13) { setFromTextInput(); } });

            cancelButton.text(opts.cancelText);
            cancelButton.bind("click.spectrum", function (e) {
                e.stopPropagation();
                e.preventDefault();
                revert();
                hide();
            });

            clearButton.attr("title", opts.clearText);
            clearButton.bind("click.spectrum", function (e) {
                e.stopPropagation();
                e.preventDefault();
                isEmpty = true;
                move();

                if(flat) {
                    //for the flat style, this is a change event
                    updateOriginalInput(true);
                }
            });

            chooseButton.text(opts.chooseText);
            chooseButton.bind("click.spectrum", function (e) {
                e.stopPropagation();
                e.preventDefault();

                if (IE && textInput.is(":focus")) {
                    textInput.trigger('change');
                }

                if (isValid()) {
                    updateOriginalInput(true);
                    hide();
                }
            });

            toggleButton.text(opts.showPaletteOnly ? opts.togglePaletteMoreText : opts.togglePaletteLessText);
            toggleButton.bind("click.spectrum", function (e) {
                e.stopPropagation();
                e.preventDefault();

                opts.showPaletteOnly = !opts.showPaletteOnly;

                // To make sure the Picker area is drawn on the right, next to the
                // Palette area (and not below the palette), first move the Palette
                // to the left to make space for the picker, plus 5px extra.
                // The 'applyOptions' function puts the whole container back into place
                // and takes care of the button-text and the sp-palette-only CSS class.
                if (!opts.showPaletteOnly && !flat) {
                    container.css('left', '-=' + (pickerContainer.outerWidth(true) + 5));
                }
                applyOptions();
            });

            draggable(alphaSlider, function (dragX, dragY, e) {
                currentAlpha = (dragX / alphaWidth);
                isEmpty = false;
                if (e.shiftKey) {
                    currentAlpha = Math.round(currentAlpha * 10) / 10;
                }

                move();
            }, dragStart, dragStop);

            draggable(slider, function (dragX, dragY) {
                currentHue = parseFloat(dragY / slideHeight);
                isEmpty = false;
                if (!opts.showAlpha) {
                    currentAlpha = 1;
                }
                move();
            }, dragStart, dragStop);

            draggable(dragger, function (dragX, dragY, e) {

                // shift+drag should snap the movement to either the x or y axis.
                if (!e.shiftKey) {
                    shiftMovementDirection = null;
                }
                else if (!shiftMovementDirection) {
                    var oldDragX = currentSaturation * dragWidth;
                    var oldDragY = dragHeight - (currentValue * dragHeight);
                    var furtherFromX = Math.abs(dragX - oldDragX) > Math.abs(dragY - oldDragY);

                    shiftMovementDirection = furtherFromX ? "x" : "y";
                }

                var setSaturation = !shiftMovementDirection || shiftMovementDirection === "x";
                var setValue = !shiftMovementDirection || shiftMovementDirection === "y";

                if (setSaturation) {
                    currentSaturation = parseFloat(dragX / dragWidth);
                }
                if (setValue) {
                    currentValue = parseFloat((dragHeight - dragY) / dragHeight);
                }

                isEmpty = false;
                if (!opts.showAlpha) {
                    currentAlpha = 1;
                }

                move();

            }, dragStart, dragStop);

            if (!!initialColor) {
                set(initialColor);

                // In case color was black - update the preview UI and set the format
                // since the set function will not run (default color is black).
                updateUI();
                currentPreferredFormat = preferredFormat || tinycolor(initialColor).format;

                addColorToSelectionPalette(initialColor);
            }
            else {
                updateUI();
            }

            if (flat) {
                show();
            }

            function paletteElementClick(e) {
                if (e.data && e.data.ignore) {
                    set($(e.target).closest(".sp-thumb-el").data("color"));
                    move();
                }
                else {
                    set($(e.target).closest(".sp-thumb-el").data("color"));
                    move();
                    updateOriginalInput(true);
                    if (opts.hideAfterPaletteSelect) {
                      hide();
                    }
                }

                return false;
            }

            var paletteEvent = IE ? "mousedown.spectrum" : "click.spectrum touchstart.spectrum";
            paletteContainer.delegate(".sp-thumb-el", paletteEvent, paletteElementClick);
            initialColorContainer.delegate(".sp-thumb-el:nth-child(1)", paletteEvent, { ignore: true }, paletteElementClick);
        }

        function updateSelectionPaletteFromStorage() {

            if (localStorageKey && window.localStorage) {

                // Migrate old palettes over to new format.  May want to remove this eventually.
                try {
                    var oldPalette = window.localStorage[localStorageKey].split(",#");
                    if (oldPalette.length > 1) {
                        delete window.localStorage[localStorageKey];
                        $.each(oldPalette, function(i, c) {
                             addColorToSelectionPalette(c);
                        });
                    }
                }
                catch(e) { }

                try {
                    selectionPalette = window.localStorage[localStorageKey].split(";");
                }
                catch (e) { }
            }
        }

        function addColorToSelectionPalette(color) {
            if (showSelectionPalette) {
                var rgb = tinycolor(color).toRgbString();
                if (!paletteLookup[rgb] && $.inArray(rgb, selectionPalette) === -1) {
                    selectionPalette.push(rgb);
                    while(selectionPalette.length > maxSelectionSize) {
                        selectionPalette.shift();
                    }
                }

                if (localStorageKey && window.localStorage) {
                    try {
                        window.localStorage[localStorageKey] = selectionPalette.join(";");
                    }
                    catch(e) { }
                }
            }
        }

        function getUniqueSelectionPalette() {
            var unique = [];
            if (opts.showPalette) {
                for (var i = 0; i < selectionPalette.length; i++) {
                    var rgb = tinycolor(selectionPalette[i]).toRgbString();

                    if (!paletteLookup[rgb]) {
                        unique.push(selectionPalette[i]);
                    }
                }
            }

            return unique.reverse().slice(0, opts.maxSelectionSize);
        }

        function drawPalette() {

            var currentColor = get();

            var html = $.map(paletteArray, function (palette, i) {
                return paletteTemplate(palette, currentColor, "sp-palette-row sp-palette-row-" + i, opts);
            });

            updateSelectionPaletteFromStorage();

            if (selectionPalette) {
                html.push(paletteTemplate(getUniqueSelectionPalette(), currentColor, "sp-palette-row sp-palette-row-selection", opts));
            }

            paletteContainer.html(html.join(""));
        }

        function drawInitial() {
            if (opts.showInitial) {
                var initial = colorOnShow;
                var current = get();
                initialColorContainer.html(paletteTemplate([initial, current], current, "sp-palette-row-initial", opts));
            }
        }

        function dragStart() {
            if (dragHeight <= 0 || dragWidth <= 0 || slideHeight <= 0) {
                reflow();
            }
            isDragging = true;
            container.addClass(draggingClass);
            shiftMovementDirection = null;
            boundElement.trigger('dragstart.spectrum', [ get() ]);
        }

        function dragStop() {
            isDragging = false;
            container.removeClass(draggingClass);
            boundElement.trigger('dragstop.spectrum', [ get() ]);
        }

        function setFromTextInput() {

            var value = textInput.val();

            if ((value === null || value === "") && allowEmpty) {
                set(null);
                updateOriginalInput(true);
            }
            else {
                var tiny = tinycolor(value);
                if (tiny.isValid()) {
                    set(tiny);
                    updateOriginalInput(true);
                }
                else {
                    textInput.addClass("sp-validation-error");
                }
            }
        }

        function toggle() {
            if (visible) {
                hide();
            }
            else {
                show();
            }
        }

        function show() {
            var event = $.Event('beforeShow.spectrum');

            if (visible) {
                reflow();
                return;
            }

            boundElement.trigger(event, [ get() ]);

            if (callbacks.beforeShow(get()) === false || event.isDefaultPrevented()) {
                return;
            }

            hideAll();
            visible = true;

            $(doc).bind("keydown.spectrum", onkeydown);
            $(doc).bind("click.spectrum", clickout);
            $(window).bind("resize.spectrum", resize);
            replacer.addClass("sp-active");
            container.removeClass("sp-hidden");

            reflow();
            updateUI();

            colorOnShow = get();

            drawInitial();
            callbacks.show(colorOnShow);
            boundElement.trigger('show.spectrum', [ colorOnShow ]);
        }

        function onkeydown(e) {
            // Close on ESC
            if (e.keyCode === 27) {
                hide();
            }
        }

        function clickout(e) {
            // Return on right click.
            if (e.button == 2) { return; }

            // If a drag event was happening during the mouseup, don't hide
            // on click.
            if (isDragging) { return; }

            if (clickoutFiresChange) {
                updateOriginalInput(true);
            }
            else {
                revert();
            }
            hide();
        }

        function hide() {
            // Return if hiding is unnecessary
            if (!visible || flat) { return; }
            visible = false;

            $(doc).unbind("keydown.spectrum", onkeydown);
            $(doc).unbind("click.spectrum", clickout);
            $(window).unbind("resize.spectrum", resize);

            replacer.removeClass("sp-active");
            container.addClass("sp-hidden");

            callbacks.hide(get());
            boundElement.trigger('hide.spectrum', [ get() ]);
        }

        function revert() {
            set(colorOnShow, true);
        }

        function set(color, ignoreFormatChange) {
            if (tinycolor.equals(color, get())) {
                // Update UI just in case a validation error needs
                // to be cleared.
                updateUI();
                return;
            }

            var newColor, newHsv;
            if (!color && allowEmpty) {
                isEmpty = true;
            } else {
                isEmpty = false;
                newColor = tinycolor(color);
                newHsv = newColor.toHsv();

                currentHue = (newHsv.h % 360) / 360;
                currentSaturation = newHsv.s;
                currentValue = newHsv.v;
                currentAlpha = newHsv.a;
            }
            updateUI();

            if (newColor && newColor.isValid() && !ignoreFormatChange) {
                currentPreferredFormat = preferredFormat || newColor.getFormat();
            }
        }

        function get(opts) {
            opts = opts || { };

            if (allowEmpty && isEmpty) {
                return null;
            }

            return tinycolor.fromRatio({
                h: currentHue,
                s: currentSaturation,
                v: currentValue,
                a: Math.round(currentAlpha * 100) / 100
            }, { format: opts.format || currentPreferredFormat });
        }

        function isValid() {
            return !textInput.hasClass("sp-validation-error");
        }

        function move() {
            updateUI();

            callbacks.move(get());
            boundElement.trigger('move.spectrum', [ get() ]);
        }

        function updateUI() {

            textInput.removeClass("sp-validation-error");

            updateHelperLocations();

            // Update dragger background color (gradients take care of saturation and value).
            var flatColor = tinycolor.fromRatio({ h: currentHue, s: 1, v: 1 });
            dragger.css("background-color", flatColor.toHexString());

            // Get a format that alpha will be included in (hex and names ignore alpha)
            var format = currentPreferredFormat;
            if (currentAlpha < 1 && !(currentAlpha === 0 && format === "name")) {
                if (format === "hex" || format === "hex3" || format === "hex6" || format === "name") {
                    format = "rgb";
                }
            }

            var realColor = get({ format: format }),
                displayColor = '';

             //reset background info for preview element
            previewElement.removeClass("sp-clear-display");
            previewElement.css('background-color', 'transparent');

            if (!realColor && allowEmpty) {
                // Update the replaced elements background with icon indicating no color selection
                previewElement.addClass("sp-clear-display");
            }
            else {
                var realHex = realColor.toHexString(),
                    realRgb = realColor.toRgbString();

                // Update the replaced elements background color (with actual selected color)
                if (rgbaSupport || realColor.alpha === 1) {
                    previewElement.css("background-color", realRgb);
                }
                else {
                    previewElement.css("background-color", "transparent");
                    previewElement.css("filter", realColor.toFilter());
                }

                if (opts.showAlpha) {
                    var rgb = realColor.toRgb();
                    rgb.a = 0;
                    var realAlpha = tinycolor(rgb).toRgbString();
                    var gradient = "linear-gradient(left, " + realAlpha + ", " + realHex + ")";

                    if (IE) {
                        alphaSliderInner.css("filter", tinycolor(realAlpha).toFilter({ gradientType: 1 }, realHex));
                    }
                    else {
                        alphaSliderInner.css("background", "-webkit-" + gradient);
                        alphaSliderInner.css("background", "-moz-" + gradient);
                        alphaSliderInner.css("background", "-ms-" + gradient);
                        // Use current syntax gradient on unprefixed property.
                        alphaSliderInner.css("background",
                            "linear-gradient(to right, " + realAlpha + ", " + realHex + ")");
                    }
                }

                displayColor = realColor.toString(format);
            }

            // Update the text entry input as it changes happen
            if (opts.showInput) {
                textInput.val(displayColor);
            }

            if (opts.showPalette) {
                drawPalette();
            }

            drawInitial();
        }

        function updateHelperLocations() {
            var s = currentSaturation;
            var v = currentValue;

            if(allowEmpty && isEmpty) {
                //if selected color is empty, hide the helpers
                alphaSlideHelper.hide();
                slideHelper.hide();
                dragHelper.hide();
            }
            else {
                //make sure helpers are visible
                alphaSlideHelper.show();
                slideHelper.show();
                dragHelper.show();

                // Where to show the little circle in that displays your current selected color
                var dragX = s * dragWidth;
                var dragY = dragHeight - (v * dragHeight);
                dragX = Math.max(
                    -dragHelperHeight,
                    Math.min(dragWidth - dragHelperHeight, dragX - dragHelperHeight)
                );
                dragY = Math.max(
                    -dragHelperHeight,
                    Math.min(dragHeight - dragHelperHeight, dragY - dragHelperHeight)
                );
                dragHelper.css({
                    "top": dragY + "px",
                    "left": dragX + "px"
                });

                var alphaX = currentAlpha * alphaWidth;
                alphaSlideHelper.css({
                    "left": (alphaX - (alphaSlideHelperWidth / 2)) + "px"
                });

                // Where to show the bar that displays your current selected hue
                var slideY = (currentHue) * slideHeight;
                slideHelper.css({
                    "top": (slideY - slideHelperHeight) + "px"
                });
            }
        }

        function updateOriginalInput(fireCallback) {
            var color = get(),
                displayColor = '',
                hasChanged = !tinycolor.equals(color, colorOnShow);

            if (color) {
                displayColor = color.toString(currentPreferredFormat);
                // Update the selection palette with the current color
                addColorToSelectionPalette(color);
            }

            if (isInput) {
                boundElement.val(displayColor);
            }

            if (fireCallback && hasChanged) {
                callbacks.change(color);
                boundElement.trigger('change', [ color ]);
            }
        }

        function reflow() {
            dragWidth = dragger.width();
            dragHeight = dragger.height();
            dragHelperHeight = dragHelper.height();
            slideWidth = slider.width();
            slideHeight = slider.height();
            slideHelperHeight = slideHelper.height();
            alphaWidth = alphaSlider.width();
            alphaSlideHelperWidth = alphaSlideHelper.width();

            if (!flat) {
                container.css("position", "absolute");
                if (opts.offset) {
                    container.offset(opts.offset);
                } else {
                    container.offset(getOffset(container, offsetElement));
                }
            }

            updateHelperLocations();

            if (opts.showPalette) {
                drawPalette();
            }

            boundElement.trigger('reflow.spectrum');
        }

        function destroy() {
            boundElement.show();
            offsetElement.unbind("click.spectrum touchstart.spectrum");
            container.remove();
            replacer.remove();
            spectrums[spect.id] = null;
        }

        function option(optionName, optionValue) {
            if (optionName === undefined) {
                return $.extend({}, opts);
            }
            if (optionValue === undefined) {
                return opts[optionName];
            }

            opts[optionName] = optionValue;
            applyOptions();
        }

        function enable() {
            disabled = false;
            boundElement.attr("disabled", false);
            offsetElement.removeClass("sp-disabled");
        }

        function disable() {
            hide();
            disabled = true;
            boundElement.attr("disabled", true);
            offsetElement.addClass("sp-disabled");
        }

        function setOffset(coord) {
            opts.offset = coord;
            reflow();
        }

        initialize();

        var spect = {
            show: show,
            hide: hide,
            toggle: toggle,
            reflow: reflow,
            option: option,
            enable: enable,
            disable: disable,
            offset: setOffset,
            set: function (c) {
                set(c);
                updateOriginalInput();
            },
            get: get,
            destroy: destroy,
            container: container
        };

        spect.id = spectrums.push(spect) - 1;

        return spect;
    }

    /**
    * checkOffset - get the offset below/above and left/right element depending on screen position
    * Thanks https://github.com/jquery/jquery-ui/blob/master/ui/jquery.ui.datepicker.js
    */
    function getOffset(picker, input) {
        var extraY = 0;
        var dpWidth = picker.outerWidth();
        var dpHeight = picker.outerHeight();
        var inputHeight = input.outerHeight();
        var doc = picker[0].ownerDocument;
        var docElem = doc.documentElement;
        var viewWidth = docElem.clientWidth + $(doc).scrollLeft();
        var viewHeight = docElem.clientHeight + $(doc).scrollTop();
        var offset = input.offset();
        offset.top += inputHeight;

        offset.left -=
            Math.min(offset.left, (offset.left + dpWidth > viewWidth && viewWidth > dpWidth) ?
            Math.abs(offset.left + dpWidth - viewWidth) : 0);

        offset.top -=
            Math.min(offset.top, ((offset.top + dpHeight > viewHeight && viewHeight > dpHeight) ?
            Math.abs(dpHeight + inputHeight - extraY) : extraY));

        return offset;
    }

    /**
    * noop - do nothing
    */
    function noop() {

    }

    /**
    * stopPropagation - makes the code only doing this a little easier to read in line
    */
    function stopPropagation(e) {
        e.stopPropagation();
    }

    /**
    * Create a function bound to a given object
    * Thanks to underscore.js
    */
    function bind(func, obj) {
        var slice = Array.prototype.slice;
        var args = slice.call(arguments, 2);
        return function () {
            return func.apply(obj, args.concat(slice.call(arguments)));
        };
    }

    /**
    * Lightweight drag helper.  Handles containment within the element, so that
    * when dragging, the x is within [0,element.width] and y is within [0,element.height]
    */
    function draggable(element, onmove, onstart, onstop) {
        onmove = onmove || function () { };
        onstart = onstart || function () { };
        onstop = onstop || function () { };
        var doc = document;
        var dragging = false;
        var offset = {};
        var maxHeight = 0;
        var maxWidth = 0;
        var hasTouch = ('ontouchstart' in window);

        var duringDragEvents = {};
        duringDragEvents["selectstart"] = prevent;
        duringDragEvents["dragstart"] = prevent;
        duringDragEvents["touchmove mousemove"] = move;
        duringDragEvents["touchend mouseup"] = stop;

        function prevent(e) {
            if (e.stopPropagation) {
                e.stopPropagation();
            }
            if (e.preventDefault) {
                e.preventDefault();
            }
            e.returnValue = false;
        }

        function move(e) {
            if (dragging) {
                // Mouseup happened outside of window
                if (IE && doc.documentMode < 9 && !e.button) {
                    return stop();
                }

                var t0 = e.originalEvent && e.originalEvent.touches && e.originalEvent.touches[0];
                var pageX = t0 && t0.pageX || e.pageX;
                var pageY = t0 && t0.pageY || e.pageY;

                var dragX = Math.max(0, Math.min(pageX - offset.left, maxWidth));
                var dragY = Math.max(0, Math.min(pageY - offset.top, maxHeight));

                if (hasTouch) {
                    // Stop scrolling in iOS
                    prevent(e);
                }

                onmove.apply(element, [dragX, dragY, e]);
            }
        }

        function start(e) {
            var rightclick = (e.which) ? (e.which == 3) : (e.button == 2);

            if (!rightclick && !dragging) {
                if (onstart.apply(element, arguments) !== false) {
                    dragging = true;
                    maxHeight = $(element).height();
                    maxWidth = $(element).width();
                    offset = $(element).offset();

                    $(doc).bind(duringDragEvents);
                    $(doc.body).addClass("sp-dragging");

                    move(e);

                    prevent(e);
                }
            }
        }

        function stop() {
            if (dragging) {
                $(doc).unbind(duringDragEvents);
                $(doc.body).removeClass("sp-dragging");

                // Wait a tick before notifying observers to allow the click event
                // to fire in Chrome.
                setTimeout(function() {
                    onstop.apply(element, arguments);
                }, 0);
            }
            dragging = false;
        }

        $(element).bind("touchstart mousedown", start);
    }

    function throttle(func, wait, debounce) {
        var timeout;
        return function () {
            var context = this, args = arguments;
            var throttler = function () {
                timeout = null;
                func.apply(context, args);
            };
            if (debounce) clearTimeout(timeout);
            if (debounce || !timeout) timeout = setTimeout(throttler, wait);
        };
    }

    function inputTypeColorSupport() {
        return $.fn.spectrum.inputTypeColorSupport();
    }

    /**
    * Define a jQuery plugin
    */
    var dataID = "spectrum.id";
    $.fn.spectrum = function (opts, extra) {

        if (typeof opts == "string") {

            var returnValue = this;
            var args = Array.prototype.slice.call( arguments, 1 );

            this.each(function () {
                var spect = spectrums[$(this).data(dataID)];
                if (spect) {
                    var method = spect[opts];
                    if (!method) {
                        throw new Error( "Spectrum: no such method: '" + opts + "'" );
                    }

                    if (opts == "get") {
                        returnValue = spect.get();
                    }
                    else if (opts == "container") {
                        returnValue = spect.container;
                    }
                    else if (opts == "option") {
                        returnValue = spect.option.apply(spect, args);
                    }
                    else if (opts == "destroy") {
                        spect.destroy();
                        $(this).removeData(dataID);
                    }
                    else {
                        method.apply(spect, args);
                    }
                }
            });

            return returnValue;
        }

        // Initializing a new instance of spectrum
        return this.spectrum("destroy").each(function () {
            var options = $.extend({}, opts, $(this).data());
            var spect = spectrum(this, options);
            $(this).data(dataID, spect.id);
        });
    };

    $.fn.spectrum.load = true;
    $.fn.spectrum.loadOpts = {};
    $.fn.spectrum.draggable = draggable;
    $.fn.spectrum.defaults = defaultOpts;
    $.fn.spectrum.inputTypeColorSupport = function inputTypeColorSupport() {
        if (typeof inputTypeColorSupport._cachedResult === "undefined") {
            var colorInput = $("<input type='color' value='!' />")[0];
            inputTypeColorSupport._cachedResult = colorInput.type === "color" && colorInput.value !== "!";
        }
        return inputTypeColorSupport._cachedResult;
    };

    $.spectrum = { };
    $.spectrum.localization = { };
    $.spectrum.palettes = { };

    $.fn.spectrum.processNativeColorInputs = function () {
        var colorInputs = $("input[type=color]");
        if (colorInputs.length && !inputTypeColorSupport()) {
            colorInputs.spectrum({
                preferredFormat: "hex6"
            });
        }
    };

    // TinyColor v1.1.2
    // https://github.com/bgrins/TinyColor
    // Brian Grinstead, MIT License

    (function() {

    var trimLeft = /^[\s,#]+/,
        trimRight = /\s+$/,
        tinyCounter = 0,
        math = Math,
        mathRound = math.round,
        mathMin = math.min,
        mathMax = math.max,
        mathRandom = math.random;

    var tinycolor = function(color, opts) {

        color = (color) ? color : '';
        opts = opts || { };

        // If input is already a tinycolor, return itself
        if (color instanceof tinycolor) {
           return color;
        }
        // If we are called as a function, call using new instead
        if (!(this instanceof tinycolor)) {
            return new tinycolor(color, opts);
        }

        var rgb = inputToRGB(color);
        this._originalInput = color,
        this._r = rgb.r,
        this._g = rgb.g,
        this._b = rgb.b,
        this._a = rgb.a,
        this._roundA = mathRound(100*this._a) / 100,
        this._format = opts.format || rgb.format;
        this._gradientType = opts.gradientType;

        // Don't let the range of [0,255] come back in [0,1].
        // Potentially lose a little bit of precision here, but will fix issues where
        // .5 gets interpreted as half of the total, instead of half of 1
        // If it was supposed to be 128, this was already taken care of by `inputToRgb`
        if (this._r < 1) { this._r = mathRound(this._r); }
        if (this._g < 1) { this._g = mathRound(this._g); }
        if (this._b < 1) { this._b = mathRound(this._b); }

        this._ok = rgb.ok;
        this._tc_id = tinyCounter++;
    };

    tinycolor.prototype = {
        isDark: function() {
            return this.getBrightness() < 128;
        },
        isLight: function() {
            return !this.isDark();
        },
        isValid: function() {
            return this._ok;
        },
        getOriginalInput: function() {
          return this._originalInput;
        },
        getFormat: function() {
            return this._format;
        },
        getAlpha: function() {
            return this._a;
        },
        getBrightness: function() {
            var rgb = this.toRgb();
            return (rgb.r * 299 + rgb.g * 587 + rgb.b * 114) / 1000;
        },
        setAlpha: function(value) {
            this._a = boundAlpha(value);
            this._roundA = mathRound(100*this._a) / 100;
            return this;
        },
        toHsv: function() {
            var hsv = rgbToHsv(this._r, this._g, this._b);
            return { h: hsv.h * 360, s: hsv.s, v: hsv.v, a: this._a };
        },
        toHsvString: function() {
            var hsv = rgbToHsv(this._r, this._g, this._b);
            var h = mathRound(hsv.h * 360), s = mathRound(hsv.s * 100), v = mathRound(hsv.v * 100);
            return (this._a == 1) ?
              "hsv("  + h + ", " + s + "%, " + v + "%)" :
              "hsva(" + h + ", " + s + "%, " + v + "%, "+ this._roundA + ")";
        },
        toHsl: function() {
            var hsl = rgbToHsl(this._r, this._g, this._b);
            return { h: hsl.h * 360, s: hsl.s, l: hsl.l, a: this._a };
        },
        toHslString: function() {
            var hsl = rgbToHsl(this._r, this._g, this._b);
            var h = mathRound(hsl.h * 360), s = mathRound(hsl.s * 100), l = mathRound(hsl.l * 100);
            return (this._a == 1) ?
              "hsl("  + h + ", " + s + "%, " + l + "%)" :
              "hsla(" + h + ", " + s + "%, " + l + "%, "+ this._roundA + ")";
        },
        toHex: function(allow3Char) {
            return rgbToHex(this._r, this._g, this._b, allow3Char);
        },
        toHexString: function(allow3Char) {
            return '#' + this.toHex(allow3Char);
        },
        toHex8: function() {
            return rgbaToHex(this._r, this._g, this._b, this._a);
        },
        toHex8String: function() {
            return '#' + this.toHex8();
        },
        toRgb: function() {
            return { r: mathRound(this._r), g: mathRound(this._g), b: mathRound(this._b), a: this._a };
        },
        toRgbString: function() {
            return (this._a == 1) ?
              "rgb("  + mathRound(this._r) + ", " + mathRound(this._g) + ", " + mathRound(this._b) + ")" :
              "rgba(" + mathRound(this._r) + ", " + mathRound(this._g) + ", " + mathRound(this._b) + ", " + this._roundA + ")";
        },
        toPercentageRgb: function() {
            return { r: mathRound(bound01(this._r, 255) * 100) + "%", g: mathRound(bound01(this._g, 255) * 100) + "%", b: mathRound(bound01(this._b, 255) * 100) + "%", a: this._a };
        },
        toPercentageRgbString: function() {
            return (this._a == 1) ?
              "rgb("  + mathRound(bound01(this._r, 255) * 100) + "%, " + mathRound(bound01(this._g, 255) * 100) + "%, " + mathRound(bound01(this._b, 255) * 100) + "%)" :
              "rgba(" + mathRound(bound01(this._r, 255) * 100) + "%, " + mathRound(bound01(this._g, 255) * 100) + "%, " + mathRound(bound01(this._b, 255) * 100) + "%, " + this._roundA + ")";
        },
        toName: function() {
            if (this._a === 0) {
                return "transparent";
            }

            if (this._a < 1) {
                return false;
            }

            return hexNames[rgbToHex(this._r, this._g, this._b, true)] || false;
        },
        toFilter: function(secondColor) {
            var hex8String = '#' + rgbaToHex(this._r, this._g, this._b, this._a);
            var secondHex8String = hex8String;
            var gradientType = this._gradientType ? "GradientType = 1, " : "";

            if (secondColor) {
                var s = tinycolor(secondColor);
                secondHex8String = s.toHex8String();
            }

            return "progid:DXImageTransform.Microsoft.gradient("+gradientType+"startColorstr="+hex8String+",endColorstr="+secondHex8String+")";
        },
        toString: function(format) {
            var formatSet = !!format;
            format = format || this._format;

            var formattedString = false;
            var hasAlpha = this._a < 1 && this._a >= 0;
            var needsAlphaFormat = !formatSet && hasAlpha && (format === "hex" || format === "hex6" || format === "hex3" || format === "name");

            if (needsAlphaFormat) {
                // Special case for "transparent", all other non-alpha formats
                // will return rgba when there is transparency.
                if (format === "name" && this._a === 0) {
                    return this.toName();
                }
                return this.toRgbString();
            }
            if (format === "rgb") {
                formattedString = this.toRgbString();
            }
            if (format === "prgb") {
                formattedString = this.toPercentageRgbString();
            }
            if (format === "hex" || format === "hex6") {
                formattedString = this.toHexString();
            }
            if (format === "hex3") {
                formattedString = this.toHexString(true);
            }
            if (format === "hex8") {
                formattedString = this.toHex8String();
            }
            if (format === "name") {
                formattedString = this.toName();
            }
            if (format === "hsl") {
                formattedString = this.toHslString();
            }
            if (format === "hsv") {
                formattedString = this.toHsvString();
            }

            return formattedString || this.toHexString();
        },

        _applyModification: function(fn, args) {
            var color = fn.apply(null, [this].concat([].slice.call(args)));
            this._r = color._r;
            this._g = color._g;
            this._b = color._b;
            this.setAlpha(color._a);
            return this;
        },
        lighten: function() {
            return this._applyModification(lighten, arguments);
        },
        brighten: function() {
            return this._applyModification(brighten, arguments);
        },
        darken: function() {
            return this._applyModification(darken, arguments);
        },
        desaturate: function() {
            return this._applyModification(desaturate, arguments);
        },
        saturate: function() {
            return this._applyModification(saturate, arguments);
        },
        greyscale: function() {
            return this._applyModification(greyscale, arguments);
        },
        spin: function() {
            return this._applyModification(spin, arguments);
        },

        _applyCombination: function(fn, args) {
            return fn.apply(null, [this].concat([].slice.call(args)));
        },
        analogous: function() {
            return this._applyCombination(analogous, arguments);
        },
        complement: function() {
            return this._applyCombination(complement, arguments);
        },
        monochromatic: function() {
            return this._applyCombination(monochromatic, arguments);
        },
        splitcomplement: function() {
            return this._applyCombination(splitcomplement, arguments);
        },
        triad: function() {
            return this._applyCombination(triad, arguments);
        },
        tetrad: function() {
            return this._applyCombination(tetrad, arguments);
        }
    };

    // If input is an object, force 1 into "1.0" to handle ratios properly
    // String input requires "1.0" as input, so 1 will be treated as 1
    tinycolor.fromRatio = function(color, opts) {
        if (typeof color == "object") {
            var newColor = {};
            for (var i in color) {
                if (color.hasOwnProperty(i)) {
                    if (i === "a") {
                        newColor[i] = color[i];
                    }
                    else {
                        newColor[i] = convertToPercentage(color[i]);
                    }
                }
            }
            color = newColor;
        }

        return tinycolor(color, opts);
    };

    // Given a string or object, convert that input to RGB
    // Possible string inputs:
    //
    //     "red"
    //     "#f00" or "f00"
    //     "#ff0000" or "ff0000"
    //     "#ff000000" or "ff000000"
    //     "rgb 255 0 0" or "rgb (255, 0, 0)"
    //     "rgb 1.0 0 0" or "rgb (1, 0, 0)"
    //     "rgba (255, 0, 0, 1)" or "rgba 255, 0, 0, 1"
    //     "rgba (1.0, 0, 0, 1)" or "rgba 1.0, 0, 0, 1"
    //     "hsl(0, 100%, 50%)" or "hsl 0 100% 50%"
    //     "hsla(0, 100%, 50%, 1)" or "hsla 0 100% 50%, 1"
    //     "hsv(0, 100%, 100%)" or "hsv 0 100% 100%"
    //
    function inputToRGB(color) {

        var rgb = { r: 0, g: 0, b: 0 };
        var a = 1;
        var ok = false;
        var format = false;

        if (typeof color == "string") {
            color = stringInputToObject(color);
        }

        if (typeof color == "object") {
            if (color.hasOwnProperty("r") && color.hasOwnProperty("g") && color.hasOwnProperty("b")) {
                rgb = rgbToRgb(color.r, color.g, color.b);
                ok = true;
                format = String(color.r).substr(-1) === "%" ? "prgb" : "rgb";
            }
            else if (color.hasOwnProperty("h") && color.hasOwnProperty("s") && color.hasOwnProperty("v")) {
                color.s = convertToPercentage(color.s);
                color.v = convertToPercentage(color.v);
                rgb = hsvToRgb(color.h, color.s, color.v);
                ok = true;
                format = "hsv";
            }
            else if (color.hasOwnProperty("h") && color.hasOwnProperty("s") && color.hasOwnProperty("l")) {
                color.s = convertToPercentage(color.s);
                color.l = convertToPercentage(color.l);
                rgb = hslToRgb(color.h, color.s, color.l);
                ok = true;
                format = "hsl";
            }

            if (color.hasOwnProperty("a")) {
                a = color.a;
            }
        }

        a = boundAlpha(a);

        return {
            ok: ok,
            format: color.format || format,
            r: mathMin(255, mathMax(rgb.r, 0)),
            g: mathMin(255, mathMax(rgb.g, 0)),
            b: mathMin(255, mathMax(rgb.b, 0)),
            a: a
        };
    }


    // Conversion Functions
    // --------------------

    // `rgbToHsl`, `rgbToHsv`, `hslToRgb`, `hsvToRgb` modified from:
    // <http://mjijackson.com/2008/02/rgb-to-hsl-and-rgb-to-hsv-color-model-conversion-algorithms-in-javascript>

    // `rgbToRgb`
    // Handle bounds / percentage checking to conform to CSS color spec
    // <http://www.w3.org/TR/css3-color/>
    // *Assumes:* r, g, b in [0, 255] or [0, 1]
    // *Returns:* { r, g, b } in [0, 255]
    function rgbToRgb(r, g, b){
        return {
            r: bound01(r, 255) * 255,
            g: bound01(g, 255) * 255,
            b: bound01(b, 255) * 255
        };
    }

    // `rgbToHsl`
    // Converts an RGB color value to HSL.
    // *Assumes:* r, g, and b are contained in [0, 255] or [0, 1]
    // *Returns:* { h, s, l } in [0,1]
    function rgbToHsl(r, g, b) {

        r = bound01(r, 255);
        g = bound01(g, 255);
        b = bound01(b, 255);

        var max = mathMax(r, g, b), min = mathMin(r, g, b);
        var h, s, l = (max + min) / 2;

        if(max == min) {
            h = s = 0; // achromatic
        }
        else {
            var d = max - min;
            s = l > 0.5 ? d / (2 - max - min) : d / (max + min);
            switch(max) {
                case r: h = (g - b) / d + (g < b ? 6 : 0); break;
                case g: h = (b - r) / d + 2; break;
                case b: h = (r - g) / d + 4; break;
            }

            h /= 6;
        }

        return { h: h, s: s, l: l };
    }

    // `hslToRgb`
    // Converts an HSL color value to RGB.
    // *Assumes:* h is contained in [0, 1] or [0, 360] and s and l are contained [0, 1] or [0, 100]
    // *Returns:* { r, g, b } in the set [0, 255]
    function hslToRgb(h, s, l) {
        var r, g, b;

        h = bound01(h, 360);
        s = bound01(s, 100);
        l = bound01(l, 100);

        function hue2rgb(p, q, t) {
            if(t < 0) t += 1;
            if(t > 1) t -= 1;
            if(t < 1/6) return p + (q - p) * 6 * t;
            if(t < 1/2) return q;
            if(t < 2/3) return p + (q - p) * (2/3 - t) * 6;
            return p;
        }

        if(s === 0) {
            r = g = b = l; // achromatic
        }
        else {
            var q = l < 0.5 ? l * (1 + s) : l + s - l * s;
            var p = 2 * l - q;
            r = hue2rgb(p, q, h + 1/3);
            g = hue2rgb(p, q, h);
            b = hue2rgb(p, q, h - 1/3);
        }

        return { r: r * 255, g: g * 255, b: b * 255 };
    }

    // `rgbToHsv`
    // Converts an RGB color value to HSV
    // *Assumes:* r, g, and b are contained in the set [0, 255] or [0, 1]
    // *Returns:* { h, s, v } in [0,1]
    function rgbToHsv(r, g, b) {

        r = bound01(r, 255);
        g = bound01(g, 255);
        b = bound01(b, 255);

        var max = mathMax(r, g, b), min = mathMin(r, g, b);
        var h, s, v = max;

        var d = max - min;
        s = max === 0 ? 0 : d / max;

        if(max == min) {
            h = 0; // achromatic
        }
        else {
            switch(max) {
                case r: h = (g - b) / d + (g < b ? 6 : 0); break;
                case g: h = (b - r) / d + 2; break;
                case b: h = (r - g) / d + 4; break;
            }
            h /= 6;
        }
        return { h: h, s: s, v: v };
    }

    // `hsvToRgb`
    // Converts an HSV color value to RGB.
    // *Assumes:* h is contained in [0, 1] or [0, 360] and s and v are contained in [0, 1] or [0, 100]
    // *Returns:* { r, g, b } in the set [0, 255]
     function hsvToRgb(h, s, v) {

        h = bound01(h, 360) * 6;
        s = bound01(s, 100);
        v = bound01(v, 100);

        var i = math.floor(h),
            f = h - i,
            p = v * (1 - s),
            q = v * (1 - f * s),
            t = v * (1 - (1 - f) * s),
            mod = i % 6,
            r = [v, q, p, p, t, v][mod],
            g = [t, v, v, q, p, p][mod],
            b = [p, p, t, v, v, q][mod];

        return { r: r * 255, g: g * 255, b: b * 255 };
    }

    // `rgbToHex`
    // Converts an RGB color to hex
    // Assumes r, g, and b are contained in the set [0, 255]
    // Returns a 3 or 6 character hex
    function rgbToHex(r, g, b, allow3Char) {

        var hex = [
            pad2(mathRound(r).toString(16)),
            pad2(mathRound(g).toString(16)),
            pad2(mathRound(b).toString(16))
        ];

        // Return a 3 character hex if possible
        if (allow3Char && hex[0].charAt(0) == hex[0].charAt(1) && hex[1].charAt(0) == hex[1].charAt(1) && hex[2].charAt(0) == hex[2].charAt(1)) {
            return hex[0].charAt(0) + hex[1].charAt(0) + hex[2].charAt(0);
        }

        return hex.join("");
    }
        // `rgbaToHex`
        // Converts an RGBA color plus alpha transparency to hex
        // Assumes r, g, b and a are contained in the set [0, 255]
        // Returns an 8 character hex
        function rgbaToHex(r, g, b, a) {

            var hex = [
                pad2(convertDecimalToHex(a)),
                pad2(mathRound(r).toString(16)),
                pad2(mathRound(g).toString(16)),
                pad2(mathRound(b).toString(16))
            ];

            return hex.join("");
        }

    // `equals`
    // Can be called with any tinycolor input
    tinycolor.equals = function (color1, color2) {
        if (!color1 || !color2) { return false; }
        return tinycolor(color1).toRgbString() == tinycolor(color2).toRgbString();
    };
    tinycolor.random = function() {
        return tinycolor.fromRatio({
            r: mathRandom(),
            g: mathRandom(),
            b: mathRandom()
        });
    };


    // Modification Functions
    // ----------------------
    // Thanks to less.js for some of the basics here
    // <https://github.com/cloudhead/less.js/blob/master/lib/less/functions.js>

    function desaturate(color, amount) {
        amount = (amount === 0) ? 0 : (amount || 10);
        var hsl = tinycolor(color).toHsl();
        hsl.s -= amount / 100;
        hsl.s = clamp01(hsl.s);
        return tinycolor(hsl);
    }

    function saturate(color, amount) {
        amount = (amount === 0) ? 0 : (amount || 10);
        var hsl = tinycolor(color).toHsl();
        hsl.s += amount / 100;
        hsl.s = clamp01(hsl.s);
        return tinycolor(hsl);
    }

    function greyscale(color) {
        return tinycolor(color).desaturate(100);
    }

    function lighten (color, amount) {
        amount = (amount === 0) ? 0 : (amount || 10);
        var hsl = tinycolor(color).toHsl();
        hsl.l += amount / 100;
        hsl.l = clamp01(hsl.l);
        return tinycolor(hsl);
    }

    function brighten(color, amount) {
        amount = (amount === 0) ? 0 : (amount || 10);
        var rgb = tinycolor(color).toRgb();
        rgb.r = mathMax(0, mathMin(255, rgb.r - mathRound(255 * - (amount / 100))));
        rgb.g = mathMax(0, mathMin(255, rgb.g - mathRound(255 * - (amount / 100))));
        rgb.b = mathMax(0, mathMin(255, rgb.b - mathRound(255 * - (amount / 100))));
        return tinycolor(rgb);
    }

    function darken (color, amount) {
        amount = (amount === 0) ? 0 : (amount || 10);
        var hsl = tinycolor(color).toHsl();
        hsl.l -= amount / 100;
        hsl.l = clamp01(hsl.l);
        return tinycolor(hsl);
    }

    // Spin takes a positive or negative amount within [-360, 360] indicating the change of hue.
    // Values outside of this range will be wrapped into this range.
    function spin(color, amount) {
        var hsl = tinycolor(color).toHsl();
        var hue = (mathRound(hsl.h) + amount) % 360;
        hsl.h = hue < 0 ? 360 + hue : hue;
        return tinycolor(hsl);
    }

    // Combination Functions
    // ---------------------
    // Thanks to jQuery xColor for some of the ideas behind these
    // <https://github.com/infusion/jQuery-xcolor/blob/master/jquery.xcolor.js>

    function complement(color) {
        var hsl = tinycolor(color).toHsl();
        hsl.h = (hsl.h + 180) % 360;
        return tinycolor(hsl);
    }

    function triad(color) {
        var hsl = tinycolor(color).toHsl();
        var h = hsl.h;
        return [
            tinycolor(color),
            tinycolor({ h: (h + 120) % 360, s: hsl.s, l: hsl.l }),
            tinycolor({ h: (h + 240) % 360, s: hsl.s, l: hsl.l })
        ];
    }

    function tetrad(color) {
        var hsl = tinycolor(color).toHsl();
        var h = hsl.h;
        return [
            tinycolor(color),
            tinycolor({ h: (h + 90) % 360, s: hsl.s, l: hsl.l }),
            tinycolor({ h: (h + 180) % 360, s: hsl.s, l: hsl.l }),
            tinycolor({ h: (h + 270) % 360, s: hsl.s, l: hsl.l })
        ];
    }

    function splitcomplement(color) {
        var hsl = tinycolor(color).toHsl();
        var h = hsl.h;
        return [
            tinycolor(color),
            tinycolor({ h: (h + 72) % 360, s: hsl.s, l: hsl.l}),
            tinycolor({ h: (h + 216) % 360, s: hsl.s, l: hsl.l})
        ];
    }

    function analogous(color, results, slices) {
        results = results || 6;
        slices = slices || 30;

        var hsl = tinycolor(color).toHsl();
        var part = 360 / slices;
        var ret = [tinycolor(color)];

        for (hsl.h = ((hsl.h - (part * results >> 1)) + 720) % 360; --results; ) {
            hsl.h = (hsl.h + part) % 360;
            ret.push(tinycolor(hsl));
        }
        return ret;
    }

    function monochromatic(color, results) {
        results = results || 6;
        var hsv = tinycolor(color).toHsv();
        var h = hsv.h, s = hsv.s, v = hsv.v;
        var ret = [];
        var modification = 1 / results;

        while (results--) {
            ret.push(tinycolor({ h: h, s: s, v: v}));
            v = (v + modification) % 1;
        }

        return ret;
    }

    // Utility Functions
    // ---------------------

    tinycolor.mix = function(color1, color2, amount) {
        amount = (amount === 0) ? 0 : (amount || 50);

        var rgb1 = tinycolor(color1).toRgb();
        var rgb2 = tinycolor(color2).toRgb();

        var p = amount / 100;
        var w = p * 2 - 1;
        var a = rgb2.a - rgb1.a;

        var w1;

        if (w * a == -1) {
            w1 = w;
        } else {
            w1 = (w + a) / (1 + w * a);
        }

        w1 = (w1 + 1) / 2;

        var w2 = 1 - w1;

        var rgba = {
            r: rgb2.r * w1 + rgb1.r * w2,
            g: rgb2.g * w1 + rgb1.g * w2,
            b: rgb2.b * w1 + rgb1.b * w2,
            a: rgb2.a * p  + rgb1.a * (1 - p)
        };

        return tinycolor(rgba);
    };


    // Readability Functions
    // ---------------------
    // <http://www.w3.org/TR/AERT#color-contrast>

    // `readability`
    // Analyze the 2 colors and returns an object with the following properties:
    //    `brightness`: difference in brightness between the two colors
    //    `color`: difference in color/hue between the two colors
    tinycolor.readability = function(color1, color2) {
        var c1 = tinycolor(color1);
        var c2 = tinycolor(color2);
        var rgb1 = c1.toRgb();
        var rgb2 = c2.toRgb();
        var brightnessA = c1.getBrightness();
        var brightnessB = c2.getBrightness();
        var colorDiff = (
            Math.max(rgb1.r, rgb2.r) - Math.min(rgb1.r, rgb2.r) +
            Math.max(rgb1.g, rgb2.g) - Math.min(rgb1.g, rgb2.g) +
            Math.max(rgb1.b, rgb2.b) - Math.min(rgb1.b, rgb2.b)
        );

        return {
            brightness: Math.abs(brightnessA - brightnessB),
            color: colorDiff
        };
    };

    // `readable`
    // http://www.w3.org/TR/AERT#color-contrast
    // Ensure that foreground and background color combinations provide sufficient contrast.
    // *Example*
    //    tinycolor.isReadable("#000", "#111") => false
    tinycolor.isReadable = function(color1, color2) {
        var readability = tinycolor.readability(color1, color2);
        return readability.brightness > 125 && readability.color > 500;
    };

    // `mostReadable`
    // Given a base color and a list of possible foreground or background
    // colors for that base, returns the most readable color.
    // *Example*
    //    tinycolor.mostReadable("#123", ["#fff", "#000"]) => "#000"
    tinycolor.mostReadable = function(baseColor, colorList) {
        var bestColor = null;
        var bestScore = 0;
        var bestIsReadable = false;
        for (var i=0; i < colorList.length; i++) {

            // We normalize both around the "acceptable" breaking point,
            // but rank brightness constrast higher than hue.

            var readability = tinycolor.readability(baseColor, colorList[i]);
            var readable = readability.brightness > 125 && readability.color > 500;
            var score = 3 * (readability.brightness / 125) + (readability.color / 500);

            if ((readable && ! bestIsReadable) ||
                (readable && bestIsReadable && score > bestScore) ||
                ((! readable) && (! bestIsReadable) && score > bestScore)) {
                bestIsReadable = readable;
                bestScore = score;
                bestColor = tinycolor(colorList[i]);
            }
        }
        return bestColor;
    };


    // Big List of Colors
    // ------------------
    // <http://www.w3.org/TR/css3-color/#svg-color>
    var names = tinycolor.names = {
        aliceblue: "f0f8ff",
        antiquewhite: "faebd7",
        aqua: "0ff",
        aquamarine: "7fffd4",
        azure: "f0ffff",
        beige: "f5f5dc",
        bisque: "ffe4c4",
        black: "000",
        blanchedalmond: "ffebcd",
        blue: "00f",
        blueviolet: "8a2be2",
        brown: "a52a2a",
        burlywood: "deb887",
        burntsienna: "ea7e5d",
        cadetblue: "5f9ea0",
        chartreuse: "7fff00",
        chocolate: "d2691e",
        coral: "ff7f50",
        cornflowerblue: "6495ed",
        cornsilk: "fff8dc",
        crimson: "dc143c",
        cyan: "0ff",
        darkblue: "00008b",
        darkcyan: "008b8b",
        darkgoldenrod: "b8860b",
        darkgray: "a9a9a9",
        darkgreen: "006400",
        darkgrey: "a9a9a9",
        darkkhaki: "bdb76b",
        darkmagenta: "8b008b",
        darkolivegreen: "556b2f",
        darkorange: "ff8c00",
        darkorchid: "9932cc",
        darkred: "8b0000",
        darksalmon: "e9967a",
        darkseagreen: "8fbc8f",
        darkslateblue: "483d8b",
        darkslategray: "2f4f4f",
        darkslategrey: "2f4f4f",
        darkturquoise: "00ced1",
        darkviolet: "9400d3",
        deeppink: "ff1493",
        deepskyblue: "00bfff",
        dimgray: "696969",
        dimgrey: "696969",
        dodgerblue: "1e90ff",
        firebrick: "b22222",
        floralwhite: "fffaf0",
        forestgreen: "228b22",
        fuchsia: "f0f",
        gainsboro: "dcdcdc",
        ghostwhite: "f8f8ff",
        gold: "ffd700",
        goldenrod: "daa520",
        gray: "808080",
        green: "008000",
        greenyellow: "adff2f",
        grey: "808080",
        honeydew: "f0fff0",
        hotpink: "ff69b4",
        indianred: "cd5c5c",
        indigo: "4b0082",
        ivory: "fffff0",
        khaki: "f0e68c",
        lavender: "e6e6fa",
        lavenderblush: "fff0f5",
        lawngreen: "7cfc00",
        lemonchiffon: "fffacd",
        lightblue: "add8e6",
        lightcoral: "f08080",
        lightcyan: "e0ffff",
        lightgoldenrodyellow: "fafad2",
        lightgray: "d3d3d3",
        lightgreen: "90ee90",
        lightgrey: "d3d3d3",
        lightpink: "ffb6c1",
        lightsalmon: "ffa07a",
        lightseagreen: "20b2aa",
        lightskyblue: "87cefa",
        lightslategray: "789",
        lightslategrey: "789",
        lightsteelblue: "b0c4de",
        lightyellow: "ffffe0",
        lime: "0f0",
        limegreen: "32cd32",
        linen: "faf0e6",
        magenta: "f0f",
        maroon: "800000",
        mediumaquamarine: "66cdaa",
        mediumblue: "0000cd",
        mediumorchid: "ba55d3",
        mediumpurple: "9370db",
        mediumseagreen: "3cb371",
        mediumslateblue: "7b68ee",
        mediumspringgreen: "00fa9a",
        mediumturquoise: "48d1cc",
        mediumvioletred: "c71585",
        midnightblue: "191970",
        mintcream: "f5fffa",
        mistyrose: "ffe4e1",
        moccasin: "ffe4b5",
        navajowhite: "ffdead",
        navy: "000080",
        oldlace: "fdf5e6",
        olive: "808000",
        olivedrab: "6b8e23",
        orange: "ffa500",
        orangered: "ff4500",
        orchid: "da70d6",
        palegoldenrod: "eee8aa",
        palegreen: "98fb98",
        paleturquoise: "afeeee",
        palevioletred: "db7093",
        papayawhip: "ffefd5",
        peachpuff: "ffdab9",
        peru: "cd853f",
        pink: "ffc0cb",
        plum: "dda0dd",
        powderblue: "b0e0e6",
        purple: "800080",
        rebeccapurple: "663399",
        red: "f00",
        rosybrown: "bc8f8f",
        royalblue: "4169e1",
        saddlebrown: "8b4513",
        salmon: "fa8072",
        sandybrown: "f4a460",
        seagreen: "2e8b57",
        seashell: "fff5ee",
        sienna: "a0522d",
        silver: "c0c0c0",
        skyblue: "87ceeb",
        slateblue: "6a5acd",
        slategray: "708090",
        slategrey: "708090",
        snow: "fffafa",
        springgreen: "00ff7f",
        steelblue: "4682b4",
        tan: "d2b48c",
        teal: "008080",
        thistle: "d8bfd8",
        tomato: "ff6347",
        turquoise: "40e0d0",
        violet: "ee82ee",
        wheat: "f5deb3",
        white: "fff",
        whitesmoke: "f5f5f5",
        yellow: "ff0",
        yellowgreen: "9acd32"
    };

    // Make it easy to access colors via `hexNames[hex]`
    var hexNames = tinycolor.hexNames = flip(names);


    // Utilities
    // ---------

    // `{ 'name1': 'val1' }` becomes `{ 'val1': 'name1' }`
    function flip(o) {
        var flipped = { };
        for (var i in o) {
            if (o.hasOwnProperty(i)) {
                flipped[o[i]] = i;
            }
        }
        return flipped;
    }

    // Return a valid alpha value [0,1] with all invalid values being set to 1
    function boundAlpha(a) {
        a = parseFloat(a);

        if (isNaN(a) || a < 0 || a > 1) {
            a = 1;
        }

        return a;
    }

    // Take input from [0, n] and return it as [0, 1]
    function bound01(n, max) {
        if (isOnePointZero(n)) { n = "100%"; }

        var processPercent = isPercentage(n);
        n = mathMin(max, mathMax(0, parseFloat(n)));

        // Automatically convert percentage into number
        if (processPercent) {
            n = parseInt(n * max, 10) / 100;
        }

        // Handle floating point rounding errors
        if ((math.abs(n - max) < 0.000001)) {
            return 1;
        }

        // Convert into [0, 1] range if it isn't already
        return (n % max) / parseFloat(max);
    }

    // Force a number between 0 and 1
    function clamp01(val) {
        return mathMin(1, mathMax(0, val));
    }

    // Parse a base-16 hex value into a base-10 integer
    function parseIntFromHex(val) {
        return parseInt(val, 16);
    }

    // Need to handle 1.0 as 100%, since once it is a number, there is no difference between it and 1
    // <http://stackoverflow.com/questions/7422072/javascript-how-to-detect-number-as-a-decimal-including-1-0>
    function isOnePointZero(n) {
        return typeof n == "string" && n.indexOf('.') != -1 && parseFloat(n) === 1;
    }

    // Check to see if string passed in is a percentage
    function isPercentage(n) {
        return typeof n === "string" && n.indexOf('%') != -1;
    }

    // Force a hex value to have 2 characters
    function pad2(c) {
        return c.length == 1 ? '0' + c : '' + c;
    }

    // Replace a decimal with it's percentage value
    function convertToPercentage(n) {
        if (n <= 1) {
            n = (n * 100) + "%";
        }

        return n;
    }

    // Converts a decimal to a hex value
    function convertDecimalToHex(d) {
        return Math.round(parseFloat(d) * 255).toString(16);
    }
    // Converts a hex value to a decimal
    function convertHexToDecimal(h) {
        return (parseIntFromHex(h) / 255);
    }

    var matchers = (function() {

        // <http://www.w3.org/TR/css3-values/#integers>
        var CSS_INTEGER = "[-\\+]?\\d+%?";

        // <http://www.w3.org/TR/css3-values/#number-value>
        var CSS_NUMBER = "[-\\+]?\\d*\\.\\d+%?";

        // Allow positive/negative integer/number.  Don't capture the either/or, just the entire outcome.
        var CSS_UNIT = "(?:" + CSS_NUMBER + ")|(?:" + CSS_INTEGER + ")";

        // Actual matching.
        // Parentheses and commas are optional, but not required.
        // Whitespace can take the place of commas or opening paren
        var PERMISSIVE_MATCH3 = "[\\s|\\(]+(" + CSS_UNIT + ")[,|\\s]+(" + CSS_UNIT + ")[,|\\s]+(" + CSS_UNIT + ")\\s*\\)?";
        var PERMISSIVE_MATCH4 = "[\\s|\\(]+(" + CSS_UNIT + ")[,|\\s]+(" + CSS_UNIT + ")[,|\\s]+(" + CSS_UNIT + ")[,|\\s]+(" + CSS_UNIT + ")\\s*\\)?";

        return {
            rgb: new RegExp("rgb" + PERMISSIVE_MATCH3),
            rgba: new RegExp("rgba" + PERMISSIVE_MATCH4),
            hsl: new RegExp("hsl" + PERMISSIVE_MATCH3),
            hsla: new RegExp("hsla" + PERMISSIVE_MATCH4),
            hsv: new RegExp("hsv" + PERMISSIVE_MATCH3),
            hsva: new RegExp("hsva" + PERMISSIVE_MATCH4),
            hex3: /^([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,
            hex6: /^([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/,
            hex8: /^([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/
        };
    })();

    // `stringInputToObject`
    // Permissive string parsing.  Take in a number of formats, and output an object
    // based on detected format.  Returns `{ r, g, b }` or `{ h, s, l }` or `{ h, s, v}`
    function stringInputToObject(color) {

        color = color.replace(trimLeft,'').replace(trimRight, '').toLowerCase();
        var named = false;
        if (names[color]) {
            color = names[color];
            named = true;
        }
        else if (color == 'transparent') {
            return { r: 0, g: 0, b: 0, a: 0, format: "name" };
        }

        // Try to match string input using regular expressions.
        // Keep most of the number bounding out of this function - don't worry about [0,1] or [0,100] or [0,360]
        // Just return an object and let the conversion functions handle that.
        // This way the result will be the same whether the tinycolor is initialized with string or object.
        var match;
        if ((match = matchers.rgb.exec(color))) {
            return { r: match[1], g: match[2], b: match[3] };
        }
        if ((match = matchers.rgba.exec(color))) {
            return { r: match[1], g: match[2], b: match[3], a: match[4] };
        }
        if ((match = matchers.hsl.exec(color))) {
            return { h: match[1], s: match[2], l: match[3] };
        }
        if ((match = matchers.hsla.exec(color))) {
            return { h: match[1], s: match[2], l: match[3], a: match[4] };
        }
        if ((match = matchers.hsv.exec(color))) {
            return { h: match[1], s: match[2], v: match[3] };
        }
        if ((match = matchers.hsva.exec(color))) {
            return { h: match[1], s: match[2], v: match[3], a: match[4] };
        }
        if ((match = matchers.hex8.exec(color))) {
            return {
                a: convertHexToDecimal(match[1]),
                r: parseIntFromHex(match[2]),
                g: parseIntFromHex(match[3]),
                b: parseIntFromHex(match[4]),
                format: named ? "name" : "hex8"
            };
        }
        if ((match = matchers.hex6.exec(color))) {
            return {
                r: parseIntFromHex(match[1]),
                g: parseIntFromHex(match[2]),
                b: parseIntFromHex(match[3]),
                format: named ? "name" : "hex"
            };
        }
        if ((match = matchers.hex3.exec(color))) {
            return {
                r: parseIntFromHex(match[1] + '' + match[1]),
                g: parseIntFromHex(match[2] + '' + match[2]),
                b: parseIntFromHex(match[3] + '' + match[3]),
                format: named ? "name" : "hex"
            };
        }

        return false;
    }

    window.tinycolor = tinycolor;
    })();

    $(function () {
        if ($.fn.spectrum.load) {
            $.fn.spectrum.processNativeColorInputs();
        }
    });

});

/* >>>>>>>>>> BEGIN source/models/base_game_spec.js */
// ==========================================================================
//                            DG.BaseGameSpec
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

  (Document your Model here)

  @extends SC.Object
*/
DG.BaseGameSpec = SC.Object.extend(
/** @scope DG.BaseGameSpec.prototype */ {

  name: null,           // String
  
  url: null,            // String
  
  collections: null,    // Array of Object (collection specification objects)
  
  dimensions: { width: 0, height: 0}, // Default view/component dimensions
  
  context: null,        // DG.DataContext or derived class
   
  // The following properties are simple properties for games using the old game API.
  // When using the new game API (DG.GameSpec), they are computed from the 'collections' property.
  
  collectionName: null,         // String
  
  parentCollectionName: null,   // String
  
  eventsAttributeName: null,    // String
  
  xAttrName: null,              // String
  
  xAttrIsNumeric: true,         // Boolean
  
  yAttrName: null,              // String
  
  yAttrIsNumeric: true,         // Boolean
  
  init: function() {
    arguments.callee.base.apply(this,arguments);
    this.collections = [];
  },

  /**
    Returns the specification for the collection with the specified name.
    @param    iCollectionName {String}    The name of the collection whose
                                          specification is requested
    @returns  {Object}    The collection specification
   */
  getCollectionSpecByName: function( iCollectionName) {
    var collections = this.get('collections'),
        i, collectionCount = collections && collections.length;
    for( i = 0; i < collectionCount; ++i) {
      if( collections[ i].name === iCollectionName)
        return collections[ i];
    }
    return null;
  }
}) ;

/* >>>>>>>>>> BEGIN source/models/collection_model.js */
// ==========================================================================
//                              DG.Collection
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('models/base_model');

/** @class

  A container for the cases and attributes that make up a collection.

  @extends SC.Object
*/
DG.Collection = DG.BaseModel.extend( (function() // closure
/** @scope DG.Collection.prototype */ {

  return {

    /**
     * The id of the model object.
     * @property {number}
     */
    id: null,

    /**
     * A relational link back to the owning data context.
     * @property {DG.DataContextRecord}
     */
    context: null,

    /**
     * A convenience member. The DataSet for this context.
     * @type {DG.DataSet}
     */
    dataSet: null,

    /**
     * Utility function for use in sorting DataItems into user/case order.
     * @type {function}
     */
    _caseCompareFunc: null,

    /**
     * Utility function for retrieving/caching the _caseCompareFunc.
     */
    getCaseCompareFunc: function() {
      if (this._caseCompareFunc) return this._caseCompareFunc;
      var itemCompareFunc = this.getPath('dataSet.compareItemsByClientIndex');
      if (itemCompareFunc) {
        this._caseCompareFunc = function(case1, case2) {
                                  return itemCompareFunc(case1.item, case2.item);
                                };
      }
      return this._caseCompareFunc;
    },

    /**
     * A relational link back to the parent collection (if any).
     * @property {DG.Collection}
     */
    parent: null,

    /**
     * A relational link to the subcollections of this collection.
     *
     * Note: in the current design there can be only one direct sub-
     * collection of this collection.
     *
     * @property {[DG.Collection]}
     */
    children: null,

    /**
     * A relational link to the attributes of this collection.
     *
     *  Note that "attributes" is a reserved property name in SproutCore.
     *
     * This array also defines the order of attributes of the collection.
     *
     * @property {[DG.Attribute]}
     */
    attrs: null,

    /**
     * A relational link to the cases of this collection.
     * @property {[DG.Case]}
     */
    cases: null,

    /**
     * Map of case IDs to indices within the collection as a whole
     *
     * @property {Object} of {String}:{Number}
     */
    caseIDToIndexMap: null,

    /**
     * Map of case IDs to indices within parent cases
     *
     * @property {Object} of {String}:{Number}
     */
    caseIDToGroupedIndexMap: null,

    /**
     * Indicates whether parent/child links are configured correctly.
     * Games using the revised API (Aug 2011) should set this to true.
     * Note that this property is not a record attribute and is not
     * expected to be archived with the record. It's a temporary flag
     * for use until games using the old API are no longer supported.
     *
     * ToDo: Believe this property is removable.
     *
     * @property {Boolean}
     */
    areParentChildLinksConfigured: false,

    /**
     * Map of parent case IDs to number of cases with that parent
     *
     * ToDo: Make dynamic?
     *
     * @property {Object}
     */
    caseCounts: null,

    /**
     * If present, the name of an individual case.
     * @property {String}
     */
    caseName: null,

    /**
     * ToDo: define
     * @property {String}
     */
    childAttrName: null,

    /**
     * Whether tabular representations of a child table should collapse
     * all the children of a single parent to a single row.
     *
     * @property {Boolean}
     */
    collapseChildren: null,

    /**
     * Default axes for the collection
     * @property {{defaults: { xAttr: string, yAttr: string }}}
     */
    defaults: undefined,

    /**
     * A description of/comment for the collection.
     * @property {String}
     */
    description: '',

    /**
     * Labels for the collection
     *
     * @param {{
     *           singleCase: string,
     *           pluralCase: string,
     *           singleCaseWithArticle: string,
     *           setOfCases: string,
     *           setOfCasesWithArticle: string
     *         }}
     */
    labels: undefined,

    /**
     * The name of the collection
     * @property {String}
     */
    name: '',

    /**
     * The displayed name of the collection
     * @property {String}
     */
    _title: null,
    title: function (k, v) {
      if (!SC.none(v)) {
        this._title = v;
      }
      return this._title || this.name;
    }.property(),

    /**
     * Initializes the DG.Collection object.
     */
    init: function () {

      arguments.callee.base.apply(this,arguments);

      this.attrs = [];
      this.cases = [];
      this.children = this.children || [];
      this.dataSet = this.context.dataSet;
      this.dataSet.registerCollection(this, this.children[0]);
      this.updateCaseIDToIndexMap();
    },

    /**
     Destroy the collection's cases and attributes when the collection is destroyed.
     */
    destroy: function() {
      var context, ix;
      this.cases.forEach( function( iCase) {
        DG.Case.destroyCase( iCase);
      });

      while( this.attrs.length > 0) {
        DG.Attribute.destroyAttribute( this.attrs.pop());
      }

      // remove link from parent
      if (this.parent) {
        ix = this.parent.children.indexOf(this);
        if (ix >= 0) {
          this.parent.children.removeAt(ix, 1);
        }
      }

      // link up child
      if (this.children) {
        this.children.forEach(function (child) {
          if (this.parent) {
            this.parent.children.pushObject(child);
          }
          child.parent = this.parent;
        }.bind(this));
      }
      context = this.context;
      if(context.dataSet)
        context.dataSet.unregisterCollection( this);
      context.removeCollection(this);
      arguments.callee.base.apply(this,arguments);
    },

    verify: function () {
      if (SC.empty(this.context)) {
        DG.logWarn('Unattached collection: ' + this.id);
      }
      if (typeof this.context === 'number') {
        DG.logWarn('Unresolved reference in collection ' + this.id + ' to context ' + this.context);
      }
      if (!SC.empty(this.parent) && (typeof this.parent === 'number')) {
        DG.logWarn('Collection parent is a key -- collection/key: ' + this.name
          + '/' + this.parent);
      }
      if (SC.empty(this.name)) {
        DG.logWarn('Collection with no name: ' + this.id);
      }
    },

    /**
     Returns true if iOtherCollection is descended from this collection.
     @param {DG.Collection} iOtherCollection The collection to test for ancestry.
     @returns {Boolean} True if this is an ancestor of iOtherCollection, false otherwise.
     */
    isAncestorOf: function (iOtherCollection) {
      return iOtherCollection.isDescendantOf( this);
    },

    /**
     Returns true if this collection is descended from iOtherCollection.
     @param {DG.Collection} iOtherCollection The collection to test for ancestry.
     @returns {Boolean} True if this is an descendant of iOtherCollection, false otherwise.
     */
    isDescendantOf: function (iOtherCollection) {
      var parent = this.get('parent');
      // If I don't have a parent, then I'm not descended from anything
      if( !parent) return false;
      // If the other collection is my parent, then I'm a descendant
      if( parent === iOtherCollection) return true;
      // Otherwise, if my parent is a descendant, then I'm a descendant
      return parent.isDescendantOf( iOtherCollection);
    },

    /**
     * Creates a new attribute in this collection with the specified properties.
     * @returns {DG.Attribute}
     */
    createAttribute: function (iProperties) {
      var attr, tStoredAttr;
      iProperties = iProperties || {};
      // Relate it to its parent collection
      iProperties.collection = this;
      tStoredAttr = DG.store.find(DG.Attribute, iProperties.guid);
      if( tStoredAttr) {
        attr = tStoredAttr;
      } else {
        attr = DG.Attribute.createAttribute(iProperties);
      }
      this.attrs.pushObject(attr);
      if( !this.dataSet.hasAttribute(attr))
        this.dataSet.addAttributes([attr]);
      return attr;
    },

    /**
     * Adds an existing attribute at a particular position in the sequence of
     * attributes. If position is undefined, defaults to the last position.
     *
     * @param attr
     * @param position
     */
    addAttribute: function (attr, position) {
      attr.set('collection', this);

      if (SC.none(position)) {
        this.attrs.pushObject(attr);
      } else {
        this.attrs.insertAt(position, attr);
      }
    },

    /**
     Find the DG.Attribute with the specified name.
     @param    {String}        iName -- The name of the attribute to find
     @returns  {DG.Attribute}  The attribute with the specified name
     */
    getAttributeByName: function( iName) {
      var attrs = this.get('attrs'),
        i, attrCount = attrs && attrs.get('length');
      for( i = 0; i < attrCount; ++i) {
        var attr = attrs.objectAt( i);
        if( attr && (attr.get('name') === iName))
          return attr;
      }
      return null;
    },

    /**
     * Creates a new case in this collection with the specified properties.
     *
     * If the properties object contains an `index` property, the new case will
     * be inserted at the appropriate index. Otherwise, it will be added to
     * the end of the cases array.
     *
     * @param iProperties {Object}  Properties of the newly created case
     *                  We assume iProperties only applies to this creation event
     *                  and is mutable.
     * @returns {DG.Case}
     */
    createCase: function (iProperties) {

      function gatherLeftAttributeList (collection) {
        if (SC.none(collection)) {
          return [];
        } else {
          return gatherLeftAttributeList(collection.get('parent')).concat(collection.getAttributeIDs());
        }
      }
      function joinValues(values, parentItem) {
        var list = gatherLeftAttributeList(_this.get('parent'));
        list.forEach(function(attrId) { values[attrId] = parentItem.values[attrId]; });
        return values;
      }

      iProperties = iProperties || {};

      var item = iProperties.item;
      var newCase;
      var _this = this;
      var dataSet = this.get('dataSet');
      var values = DG.DataUtilities.canonicalizeAttributeValues(this.attrs, iProperties.values);
      var parentID = iProperties.parent;
      var parent;
      var parentItemID;
      var parentHasChildren;
      var itemID = iProperties.itemID;

      // Relate it to its parent collection
      iProperties.collection = this;

      delete iProperties.values;

      if (!item) {
        if (SC.none(parentID)) {
          // if no parent then create item
          item = dataSet.addDataItem(DG.DataItem.create({id: itemID, values: values}));
        } else {
          parent = DG.store.resolve(parentID);
          parentItemID = parent.item.id;
          parentHasChildren = parent.get('children') && parent.get('children').length > 0;
          if (parentHasChildren && SC.none(itemID)){
            // if new child case has no item id, create new item by merging new
            // values with parent values.
            item = dataSet.addDataItem(joinValues(values, parent.item));
          } else if (itemID && itemID !== parentItemID) {
            // if new child has item id and it differs from parent's item id,
            // create a new item by merging new values with parent values
            item = dataSet.addDataItem(DG.DataItem.create({id: itemID, values: joinValues(values, parent.item)}));
          } else {
            // if item id matches parent item, update the parent's item
            item = parent.get('item');
            item.updateData(values);
          }
        }
        iProperties.item = item;
      }

      newCase = DG.Case.createCase(iProperties);

      this.addCase(newCase);

      return newCase;
    },

    /**
     * Returns the last case in the collection.
     * @returns {*|boolean}
     */
    lastCase: function () {
      return this.cases[this.cases.length - 1];
    },
    /**
     * Adds a new case to the collection.

     * @param   {DG.Case}  iCase The newly created case
     */
    addCase: function (iCase) {
      // If we are in the top level collection we always append cases.
      // We always append cases to the parent's case group, so if parent of the
      // last case in this collection has an index not greater than this case we
      // can append to this collection.
      function caseShouldBeAddedAtEnd(iParentID, iParentCollection, iLastCase) {
        if (SC.none(iParentID) || SC.none(iLastCase) || SC.none(iLastCase.parent)) {
          return true;
        }
        DG.assert(!SC.none(iParentCollection), 'parentCollection should exist');
        var parentCaseIndex = iParentCollection.caseIDToIndexMap[iParentID];
        var lastCaseParentIndex = iParentCollection.caseIDToIndexMap[iLastCase.parent.id];

        return (lastCaseParentIndex <= parentCaseIndex );
      }
      function insertCaseInCollection(iParentID, iCase) {
        var parentCollection = _this.parent;
        DG.assert(!SC.none(parentCollection), 'parentCollection does not exist');
        var parentCaseIndex = parentCollection.caseIDToIndexMap[iParentID];
        DG.assert(!SC.none(parentCaseIndex), 'parentCaseIndex does not exist');
        var parentCase = parentCollection.cases[parentCaseIndex];
        var parentsLastChild;
        var priorIndex = -1;

        DG.assert(!SC.none(parentCase), 'parentCase does not exist');
        if (parentCase.children.length > 1) { // the newly added case is already known
                                              // at the parent level, so we adjust for it
          parentsLastChild = parentCase.children[parentCase.children.length - 2];
          priorIndex = _this.caseIDToIndexMap[parentsLastChild.id];
        } else {
          // if we get here, our parent is not the last case in the parent
          // collection, and it doesn't have any children, so we perform a
          // search of this collection to find the last case in this collection
          // with a parent earlier in the parent collection than our parent.
          _this.cases.some(function (iCase, ix) {
            if (parentCollection.caseIDToIndexMap[iCase.parent.id] <= parentCaseIndex) {
              priorIndex = ix;
              return false;
            } else {
              return true;
            }
          });
        }
        DG.assert(!SC.none(priorIndex), 'parent\'s last child not in index map.');
        _this.cases.insertAt(priorIndex+1, iCase);
        _this.updateCaseIDToIndexMap();
      }

      /*
       * start of addCase method
       */
      var caseID = iCase.get('id'),
        parentID = iCase.getPath('parent.id'),
        caseIDToIndexMap = this.get('caseIDToIndexMap'),
        caseCounts = this.get('caseCounts'),
        _this = this;

      if (SC.none(caseCounts[parentID])) {
        caseCounts[parentID] = 0;
      }

      if (caseShouldBeAddedAtEnd(parentID, this.parent, this.lastCase())) {
        /**
         * Order is important in the test because iCase.isEmpty may cause a side effect and
         * caching of formula results. We only want to bring that about *after* we've
         * created the caseIDToIndexMap.
         */
        if (!this.caseIDToIndexMap[caseID] || !iCase.isEmpty() || !parentID) {
          this.caseIDToGroupedIndexMap[caseID] = caseCounts[parentID]++;
        }
        caseIDToIndexMap[caseID] = this.cases.length;
        this.cases.pushObject(iCase);
        this.notifyPropertyChange('caseIDToIndexMap');
      } else {
        insertCaseInCollection(parentID, iCase);
      }
    },

    /**
     * Changes the order of the specified case within this collection.
     * If moving multiple cases, clients should pass false for iSkipIDMapUpdate
     * in all calls except the last, or call updateCaseIDToIndexMap() directly
     * once all moves are complete.
     * @param   {DG.Case} iCase The case to move.
     * @param   {number}  position The desired index of the moved case
     * @param   {boolean} iSkipIDMapUpdate If true, the re-mapping of case IDs to indices will be skipped.
     */
    moveCase: function(iCase, position, iSkipIDMapUpdate) {
      var currentPosition = this.cases.indexOf(iCase);
      if (currentPosition >= 0 && currentPosition !== position) {
        this.cases.removeAt(currentPosition);
        this.cases.insertAt(position, iCase);
      }
      if (!iSkipIDMapUpdate) {
        this.updateCaseIDToIndexMap();
      }
    },

    /**
     * Deletes the specified case from this collection.
     * Clients should call updateCaseIDToIndexMap() after deleting cases.
     * @param   {DG.Case} iCase The case to delete.
     * @param   {boolean} retainItem Delete the case, but do not delete the
     *                    underlying data item.
     */
    deleteCase: function (iCase, retainItem) {
      var item = iCase.item;
      DG.Case.destroyCase(iCase);
      if (!retainItem) {
        this.dataSet.deleteDataItem(item);
      }
    },

    setAsideCase: function (iCase) {
      var item = iCase.item;
      DG.Case.destroyCase(iCase);
      this.dataSet.deleteDataItem(item, true);
    },

    restoreSetAsideCases: function () {
      var items = this.dataSet.restoreSetAsideItems();
      var count = items.length;
      if (count > 0) {
        this.updateCaseIDToIndexMap();
      }
      DG.log("Restored " + count + " cases in collection \"" + this.get('name') + "\"");
    },

    /**
     * Recreates a set of cases in this collection from the DataSet. If no
     * argument is provided, will recreate cases for all items, otherwise will create cases
     * for this set only. In either situation will append to the collection's case
     * array, as created.
     *
     * @param items {[DG.DataItem]}
     * @param parent {DG.Case} The parent case for this set of cases.
     */
    recreateCases: function (items, parent) {
      var collectionID = this.get('id'),
          createdCases = [];
      // Look for a case that references the item. If found we position it
      function findOrCreateCaseForItem (items, parent, collection) {
        var tCase;
        items.some(function (item) {
          tCase = DG.Case.findCase(collectionID, item.get('id'));
          return !!tCase;
        });
        // var tCase = DG.Case.findCase(collectionID, item.get('id'));
        if (!tCase) {
          tCase = DG.Case.createCase({
            parent: parent,
            collection: collection,
            item: items[0]
          });
          collection.addCase(tCase);
          createdCases.push(tCase);
        } else {
          if (parent) {
            tCase.parent = parent;
            parent.children.pushObject(tCase);
          } else {
            tCase.parent = null;
          }
          tCase.children = [];
        }
        return tCase;
      }

      // ------- Start of recreateCases --------

      var childCollection = this.children[0];
      var itemGroups = {};  // a hash value representing the values for the
                            // attributes of this collection
      var attrs = [];

      if (SC.none(items)) {
        items = this.dataSet.getDataItems()
                  .filter(function (item) { return !item.deleted; });
      }

      attrs = this.attrs.filter(function (attr) {
        return SC.empty(attr.formula);
      });


      // We are going to walk the itemGroups hash-map creating cases.
      // If we are the base collection we will have a case for each item in the
      // order defined by the item list.
      if (SC.none(childCollection)) {
        items.forEach(function (item) {
          // create a case
          var theCase = findOrCreateCaseForItem([item], parent, this);
          theCase._deletable = false;
        }.bind(this));
      } else {
        // If this is not a base collection, we
        // make a hash-map of items with the hash-key being the attribute
        // values for this collection's attributes and the values being arrays of items
        items.forEach(function (item) {
          if (!item.deleted) {
            var values = attrs.map(function (attr) {
              var value =  item.values[attr.id];
              var newValue;
              if (typeof value === 'object') {
                try {
                  newValue = JSON.stringify(value);
                } catch (ex) {
                  console.warn('In collection ' + collectionID + ', item ' +
                      item.id + ', Attribute value is non-serializable object');
                  newValue = 'object';
                }
              } else {
                newValue = value;
              }
              return newValue;
            }).join();
            var list = itemGroups[values] || [];
            if (list.length === 0) {
              itemGroups[values] = list;
            }
            list.push(item);
          }
        }.bind(this));

        // Now we make or find a case for each group in the hash map, and
        // recreate cases for the items in each group
        DG.ObjectMap.forEach(itemGroups, function(key, list) {
          var childCases;
          var theCase = findOrCreateCaseForItem(list, parent, this);
          theCase.children = [];
          theCase._deletable = false;

          // call recreate cases on the child collection for each hash entry.
          childCases = childCollection.recreateCases(list, theCase);
          createdCases = createdCases.concat(childCases);
        }.bind(this));
      }
      //this.updateCaseIDToIndexMap();
      return createdCases;
    },

    reorderCases: function (level, levelCounts, iCases, parent) {
      var childCollection = this.children[0],
          caseCompareFunc = this.getCaseCompareFunc();
      if (SC.none(levelCounts[level])) {
        levelCounts[level] = 0;
      }
      if (SC.none(iCases)) {
        // Sort top level collection
        this.cases.sort(caseCompareFunc);
        if (!SC.none(childCollection)) {
          this.cases.forEach(function (iCase) {
            var children = iCase.children;
            childCollection.reorderCases(level + 1, levelCounts, children, iCase);
          });
        }
      } else {
        // sort children
        iCases.sort(caseCompareFunc);
        iCases.forEach(function (iCase) {
          this.cases[levelCounts[level]++] = iCase;
          if (iCase.children && iCase.children.length>0) {
            childCollection.reorderCases(level + 1, levelCounts, iCase.children, iCase);
          }
        }.bind(this));
      }
      //this.updateCaseIDToIndexMap();
    },

    /**
     * Removes an attribute from this collection. The attribute is not deleted.
     * It is assumed the attribute will be added to a new collection.
     *
     * @param attr {DG.Attribute}
     * @return {DG.Attribute}
     */
    removeAttribute: function (attr) {
      var ix;
      for (ix = 0; ix < this.attrs.length; ix += 1) {
        if (this.attrs[ix].id === attr.id) {
          break;
        }
      }
      this.attrs.removeAt(ix, 1);

      attr.set('collection', null);
      return attr;
    },

    /**
     * Returns an array of ids for the attributes in the collection.
     * @returns {[Number]}
     */
    getAttributeIDs: function () {
      return this.attrs.getEach('id');
    },

    /**
     *
     * @param iId {Number}
     * @returns {DG.Attribute}
     */
    getAttributeByID: function( iId) {
      return this.attrs.find( function( iAttr) {
        return iAttr.get('id') === iId;
      });
    },

    /**
     * Returns an array of names for the attributes in the collection.
     * @returns {[String]}
     */
    getAttributeNames: function () {
      return this.attrs.getEach('name');
    },

    /**
     * Returns an array of names for the attributes in the collection.
     * @returns {[String]}
     */
    numberOfVisibleAttributes: function () {
      return this.attrs.reduce( function (iCountVisible, iAttr) {
        if( !iAttr.get('hidden'))
          iCountVisible++;
        return iCountVisible;
      }, 0);
    },

    /**
     * Returns an array of ids for the cases in the collection,
     *  suitable for use by clients like Protovis.
     * @returns {[Number]}
     */
    getCaseIDs: function () {
      return this.cases.getEach('id');
    },

    /**
     * Rebuilds the 'caseIDToIndexMap' and 'caseCounts' properties.
     * This function should be called whenever the mapping between
     * case IDs and indices must change, e.g. after deleting cases.
     */
    updateCaseIDToIndexMap: function () {
      var caseIndices = {},
          map = {},
          groupedMap = {};
      this.cases.forEach(function (iCase, ix) {
          if (!iCase.get('isDestroyed')) {
            var caseID = iCase.get('id'), parentID = iCase.getPath('parent.id');
            if (SC.none(caseIndices[parentID]))
              caseIndices[parentID] = 0;
            if (!iCase.isEmpty() || !parentID) {
              groupedMap[caseID] = caseIndices[parentID]++;
            }
            map[caseID] = ix;
          }
        });
      this.set('caseIDToIndexMap', map);
      this.set('caseIDToGroupedIndexMap', groupedMap);
      // The caseIndices map now indicates # cases for each parent
      this.set('caseCounts', caseIndices);
    },

    /**
     * @param iCaseID {number|string}
     * @returns {number|undefined}
     */
    getCaseIndexByID: function (iCaseID) {
      var caseIDToIndexMap = this.get('caseIDToIndexMap');
      return caseIDToIndexMap && caseIDToIndexMap[iCaseID];
    },

    /**
     * Debug-only utility function.
     */
    debugLog: function (iPrompt) {
      DG.log((iPrompt || "") + " Collection " +
        this.get('id') + ", Attrs: [" +
        this.getAttributeIDs() + "], Cases: [" + this.getCaseIDs() + "]");
    },

    toArchive: function (excludeCases) {
      var parentID, obj;
      if (this.parent) {
        if (typeof this.parent === 'number') {
          parentID = this.parent;
        } else {
          parentID = this.parent.id;
        }
      }
      obj = {
        areParentChildLinksConfigured: this.areParentChildLinksConfigured,
        attrs: [],
        cases: [],
        caseName: this.get('caseName'),
        childAttrName: this.get('childAttrName'),
        collapseChildren: this.get('collapseChildren'),
        defaults: this.get('defaults'),
        guid: this.get('id'),
        id: this.get('id'),
        labels: this.labels,
        name: this.get('name'),
        parent: parentID,
        title: this.get('title'),
        type: 'DG.Collection'
      };
      this.attrs.forEach(function (attr) {
        obj.attrs.push(attr.toArchive());
      });
      if (!excludeCases) {
        this.cases.forEach(function (myCase) {
          obj.cases.push(myCase.toArchive());
        });
      }
      return obj;
    }
  };
}())) ;

DG.Collection.createCollection = function( iProperties) {
  if (!(iProperties && iProperties.context)) {
    return;
  }

  var tContextRecord = iProperties.context;
  var tParent = SC.none(iProperties.parent)? null :  DG.store.resolve(iProperties.parent);
  var tRoot = DG.ObjectMap.values(tContextRecord.collections).find(function (collection) {
    return SC.none(collection.parent);
  });
  var tCollection;
  var childCollection = null;

  if( SC.none( iProperties.type)) {
    iProperties.type = 'DG.Collection';
  }

  if (iProperties.children) {
    childCollection = iProperties.children[0];
  }

  iProperties.parent = tParent;

  tCollection = DG.Collection.create(iProperties);

  // if child collection, link this collection in
  if (childCollection) {
    if (childCollection.get('parent')) {
      childCollection.get('parent').children[0] = tCollection;
      tCollection.set('parent', childCollection.get('parent'));
    }
    tCollection.children[0] = childCollection;
    childCollection.set('parent', tCollection);
  } else if (tParent) {
    if (tParent.children[0]) {
      tParent.children[0].set('parent', tCollection);
      tCollection.children[0] = tParent.children[0];
    }
    tParent.children[0] = tCollection;
  } else if (tRoot) {
    tCollection.children[0] = tRoot;
    tRoot.set('parent', tCollection);
  }

  tContextRecord.addCollection( tCollection);

  if (!SC.none(iProperties.areParentChildLinksConfigured)) {
    tCollection.set('areParentChildLinksConfigured',
      iProperties.areParentChildLinksConfigured);
  }

  if (iProperties.attrs) {
    iProperties.attrs.forEach(function (iAttr) {
      iAttr.collection = tCollection;
      tCollection.createAttribute(iAttr);
    });
  }

  if (iProperties.cases) {
    iProperties.cases.forEach(function (iCase) {
      iCase.collection = tCollection;
      tCollection.createCase(iCase);
    });
  }

  DG.log('Create collection: ' + [tCollection.name, tCollection.description].join());

  return tCollection;
};

DG.Collection.destroyCollection = function (iCollection) {
  iCollection.destroy();
};

/* >>>>>>>>>> BEGIN source/models/command.js */
// ==========================================================================
//                      DG.Command
//
//  A template for objects being passed to DG.UndoHistory.
//
//  DG.UndoHistory doesn't require commands to be an instance of this class
//  or a subclass, but whatever object you pass in should implement the same
//  fields and methods as this class.
//
//  Author:   Aaron Unger
//
//  Copyright (c) 2015 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class
  A prototype for the commands to be passed into DG.UndoHistory.
  Note: As long as an object conforms to this API, the DG.UndoHistory doesn't technically care if it's an
  instance of DG.Command or not.

  For documentation about how to use UndoHistory, please see /docs/undo.md

  @extends SC.Object
*/
DG.Command = SC.Object.extend((function() {
  return {

    // Metadata to define
    name: null,
    undoString: null,
    redoString: null,

    isUndoable: true,

    // Set this to false inside execute() if you want to skip adding this to the undo stack,
    // but don't want to invalidate the current stack. Useful for when you don't know beforehand whether or
    // not the execute() action will actually make a change.
    causedChange: true,

    // The object that should be passed to dirtyCurrentDocument(). Indicates what object changed.
    changedObject: null,

    // Functions to override
    execute: function() {},
    undo: function() {},
    redo: function() {
      this.execute();
    },

    // This can either be a string or a function which returns a string.
    // The string gets sent to DG.logUser().
    // log: function(stage) {}  -- stage will be one of DG.UndoHistory.EXECUTE, DG.UndoHistory.UNDO, DG.UndoHistory.REDO
    log: 'unknown action',

    // This optional property allows multiple consecutive commands to be reduced to a single command in
    // the undo history. It takes a function in the form `reduce: function(previousCommand)` and
    // either returns a single command that combines the two actions into one, or returns `false` to
    // indicate that the commands should not be reduced.
    reduce: null

  }; // return from function closure
})()); // function closure

/* >>>>>>>>>> BEGIN source/models/data_context_record.js */
// ==========================================================================
//                        DG.DataContextRecord
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('models/model_store');
sc_require('models/base_model');

/** @class
 * Represents a data context.
 *
 * A data context is bound to a single source of data, e.g. a data interactive.
 * It manages a Data Set.
 *
 * @extends SC.BaseModel
 */
DG.DataContextRecord = DG.BaseModel.extend(/** @scope DG.DataContextRecord.prototype */ {

  type: 'DG.DataContext',

  /**
   * A relational link back to the parent DG.Document
   * @property {DG.Document}
   */
  document: null,

  /**
   * Externally specified identifier for data context.
   * @type {string}
   */
  name: null,

  /**
   * Displayable name for data context
   * @type {string}
   */
  _title: null,
  title: function(key, value) {
    if (value) {
      this._title = value;
    }
    return this._title || this.get('defaultTitle') || this.name ;
  }.property('_title', 'name'),

  /**
   * A free-text description of the data context.
   * Deprecated: use metadata.description.
   */
  description: "",

  /**
   * Data about the source of the data context.
   */
  metadata: null,

  /**
   * If true, indicates the user should be prevented from moving attributes
   * or creating new collections or attributes. Defaults to false.
   */
  preventReorg: false,

  /**
   * A relational link to the collections in this context.
   * @property {[DG.Collection]}
   */
  collections: null,
  collectionsChangeCount: 0,

  defaultTitle: function() {
    var tTitle = '';
    DG.ObjectMap.forEach(this.collections, function (collectionKey){
      if( !SC.empty( tTitle))
        tTitle += '/';
      tTitle += this.collections[collectionKey].get('name');
    }.bind(this));
    return tTitle;
  }.property(),

  /**
    The dependency mananager
   */
  dependencyMgr: null,

  /**
   * The base data set for the collections in this context.
   * @property {DG.DataSet}
   */
  dataSet: null,

  /**
   * The context is has had its original organization modified.
   * No new data should be added.
   * @property {boolean}
   */
  flexibleGroupingChangeFlag: false,

  /**
   * Per-component storage, in a component specific format.
   * @property {JSON}
   */
  contextStorage: null,

  _savedShadowCopy: null,

  init: function () {
    this.collections = {};
    this.dependencyMgr = DG.DependencyMgr.create({ dataContext: this });
    this.dataSet = DG.DataSet.create({dataContextRecord: this});
    arguments.callee.base.apply(this,arguments);
  },

  verify: function () {
    if (SC.empty(this.document)) {
      DG.logWarn('Unattached data context: ' + this.id);
    }
    if (typeof this.document === 'number') {
      DG.logWarn('Unresolved reference to document id, ' + this.document +
        ', in data context: ' + this.id);
    }
  },

  destroy: function() {
    if (this.collections) {
      DG.ObjectMap.forEach(this.collections, function( iCollectionID, iCollection) {
        DG.Collection.destroyCollection( iCollection);
      });
    }
    delete this.document.contexts[this.id];
    arguments.callee.base.apply(this,arguments);
  },

  createCollection: function( iProperties) {
    iProperties = iProperties || {};
    iProperties.context = this;
    return DG.Collection.createCollection( iProperties);
  },

  addCollection: function (iCollection) {
    this.collections[iCollection.id] = iCollection;
    this.incrementProperty('collectionsChangeCount', 1);
  },

  removeCollection: function (iCollection) {
    delete this.collections[iCollection.id];
    this.incrementProperty('collectionsChangeCount', 1);
  },

  /**
   * Prepares a streamable version of this object. Streamable means it is
   * JSON ready and has all persistent data for the object and its sub-objects.
   *
   * In this case we take special care to avoid forward references among
   * collections.
   * @param {boolean} fullData Whether to generate data or externalDocumentId only.
   *   TODO: This option is intended to support saving of document fragments and as
   *   such, may be obsolescent.
   * @param {boolean} excludeCases Whether to exclude cases.
   * @returns {Object}
   */
  toArchive: function (fullData, excludeCases) {
    function notEmpty(collection) {
      return !(SC.none(
          collection.attrs) || (collection.attrs.length === 0));
    }
    var obj;
    var root;
    fullData = true;
    if ( fullData) {
      obj = {
        type: this.type,
        document: this.document && this.document.id || undefined,
        guid: this.id,
        id: this.id,
        flexibleGroupingChangeFlag: this.flexibleGroupingChangeFlag,
        name: this.get('name'),
        title: this.get('title'),
        collections: [],
        description: this.description,
        metadata: this.metadata,
        preventReorg: this.preventReorg,
        setAsideItems: this.get('dataSet').archiveSetAsideItems(),
        contextStorage: this.contextStorage
      };

      DG.ObjectMap.values(this.collections).some(function (collection){
        if (SC.none(collection.parent) && notEmpty(collection)) {
          root = collection;
          return true;
        }
        return false;
      });

      if (root && root.children) {
        while (root.children.length > 0) {
          obj.collections.push(root.toArchive(excludeCases));
          root = root.children[0];
        }
      }
      if (!SC.none(root)) {
        obj.collections.push(root.toArchive(excludeCases));
      }
    }
    return obj;
  },

  savedShadowCopy: function() {
    return this._savedShadowCopy;
  },

  updateSavedShadowCopy: function(shadow) {
    this._savedShadowCopy = shadow;
  }

});

DG.DataContextRecord.createContext = function( iProperties) {
  function makeDataContextName() {
    var doc = DG.currDocumentController();
    var ix = 1;
    var name = 'DG.DataContext.baseName'.loc(ix);
    while (doc.getContextByName(name)) {
      name = 'DG.DataContext.baseName'.loc(++ix);
    }
    return name;
  }
  var tContext, shadowCopy = {};
  if( SC.none( iProperties)) iProperties = {};
  if( SC.none( iProperties.type)) iProperties.type = 'DG.DataContext';
  if (!iProperties.document) {
    iProperties.document = DG.currDocumentController().content;
  }
  iProperties.document = DG.store.resolve(iProperties.document);
  tContext = DG.DataContextRecord.create(iProperties);
  tContext.updateSavedShadowCopy(shadowCopy);
  if (iProperties.document) {
    iProperties.document.contexts[tContext.get('id')] = tContext;
  }
  // Make unique name, if none provided.
  if (SC.empty(tContext.name)) {
    tContext.name = makeDataContextName();
  }
  if (iProperties.collections) {
    iProperties.collections.forEach(function (iProps) {
      iProps.context = tContext;
      DG.Collection.createCollection(iProps);
    });
  }
  if (iProperties.setAsideItems) {
    var tDataSet = tContext.get('dataSet');
    tDataSet.createSetAsideItems(iProperties.setAsideItems);
  }
  DG.log("Create context: '%@'", tContext.name);

  return tContext;
};

DG.DataContextRecord.destroyContext = function( iContext) {
  iContext.destroy();
};

/* >>>>>>>>>> BEGIN source/models/data_item.js */
// ==========================================================================
//
//  Author:   jsandoe
//
//  Copyright (c) 2015 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
/**
 * A DataItem is an n-tuple each element of which corresponds to exactly one
 * attribute in the data set. It can be thought of as a row in a flat table
 * where the columns are Attributes.
 */
DG.DataItem = SC.Object.extend({
  /*
   * A 'given' ID for the DataItem. Items are also identified by their
   * index in the data set.
   * @type {string}
   */
  id: null,

  /**
   * Internal index of this item in the DataSet
   * @type {number}
   */
  itemIndex: null,

  /**
   * Index of this item in the DataSet as seen by clients
   * @type {number}
   */
  _clientIndex: null,

  /**
   * @type boolean
   */
  deleted: false,

  /**
   * Whether the case has been 'set aside': gone but retrievable
   * @type boolean
   */
  setAside: false,

  /*
   * A hash map of attribute IDs to values.
   * @type {{attributeID: *}}
   */
  values: null,

  /**
   * Set the value of an individual attribute
   * @param {number} attributeID
   * @param {*} value
   */
  setValue: function (attributeID, value) {
    this.values[attributeID] = DG.DataUtilities.canonicalizeInputValue( value);
  },

  /**
   * Gets the value of an attribute. If formula attribute, evaluates the formula
   * in the context of the case associated with the item at the level of the attribute.
   * @param attributeID {number|string} Id of attribute
   * @param [baseCollectionID] {number} Id of the rightmost collection in the DataContext
   * @return {*}
   */
  getValue: function(attributeID, baseCollectionID) {
    var attr = DG.Attribute.getAttributeByID(attributeID);
    var tCase;
    if (attr.hasFormula()) {
      tCase = DG.Case.findCase(baseCollectionID || attr.collection.id, this.id);
      return (tCase && tCase.getRawValue(attributeID));
    } else {
      return this.values[attributeID];
    }
  },

  /**
   * Update values from an attribute key to value map.
   * @param {object} dataMap
   */
  updateData: function (dataMap) {
    this.values = this.values || {};
    $.extend(this.values, dataMap);
  },

  /**
   * Creates a serializable object for transmission. Used by Plugin API.
   * At this point, items are not directly written to documents.
   * @return {{id: *, values: {}}}
   */
  toArchive: function () {
    var nameValueMap = {};
    Object.keys(this.values).map(function (key) {
      var attr = DG.Attribute.getAttributeByID(key);
      if (attr) {
        nameValueMap[attr.name] = this.getValue(key);
      }
    }.bind(this));
    return {
      id: this.id,
      values: nameValueMap
    };
  }
});

/* >>>>>>>>>> BEGIN source/models/data_set.js */
// ==========================================================================
//  Author:   Jonathan Sandoe
//
//  Copyright (c) 2015 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================


sc_require('models/data_item');

/** @class DataSet
 *
 * An indexed array of the DataItems in a DataContext.
 *
 *
 * DataItem attribute Values can be retrieved or modified by item index and
 * Attribute id.
 * Item indices, once assigned to a DataItem, are not reused.
 */
DG.DataSet = SC.Object.extend((function() // closure
/** @scope DG.DataSet.prototype */ {

  return {
    /**
     *  An array of data in the data set.
     * @type {[DG.DataItem]}
     */
    dataItems: null,

    /**
     * Attributes defined for this DataSet in the
     * order for the dataItems value array.
     *
     * @type {[DG.Attribute]}
     */
    attrs: null,

    /**
     * Order of registered collections. This ordering
     * is established by insertion and removal of collections. Collections are not moved,
     * but are created at a position relative to other groups.
     *
     * ToDo: make into a cacheable method that derives values from collection
     * ToDO: attributes.
     *
     * @type {[DG.Collection]}
     */
    collectionOrder: null,

    init: function () {
      this.dataItems = [];
      this.attrs = [];
      this.collectionOrder = [];
      this._clientToItemIndexMap = [];
    },

    /**
     * The rightmost collection.
     * @type {DG.Collection}
     */
    baseCollection: function () {
      var collections = this.get('collectionOrder');
      return collections[collections.length - 1];
    }.property('collectionOrder[]').cacheable(),

    /**
     * Inserts a group in the mapping before the existing group 'followerGroup'.
     * If no followerGroup, appends group.
     *
     * @param {DG.Collection} collection
     * @param {DG.Collection|null} followerCollection
     */
    registerCollection: function (collection, followerCollection) {
      if (followerCollection) {
        var insertLoc = this.collectionOrder.indexOf(followerCollection);
        if (insertLoc >= 0) {
          this.collectionOrder.insertAt(insertLoc, collection);
        } else {
          DG.logWarn('Inserting group, cannot find followerGroup');
          this.collectionOrder.push(collection);
        }
      } else {
        this.collectionOrder.push(collection);
      }
    },

    /**
     *
     * @param {DG.Collection} collection
     */
    unregisterCollection: function( collection) {
      var tIndex = this.collectionOrder.indexOf(collection);
      if( tIndex >= 0)
        this.collectionOrder.splice(tIndex, 1);
    },

    /**
     * Adds attributes. Ideally this is an initialization step, but may be called
     * at any time.
     *
     * TODO: consider making attribute resolution happen dynamically through
     * TODO: the collection list, and not through the mechanism here.
     *
     * @param {[DG.Attribute]|DG.Attribute} newAttributes An array or a single attribute.
     */
    addAttributes: function (newAttributes) {
      var attrs = Array.isArray(newAttributes)? newAttributes : [newAttributes];
      attrs.forEach(function (attr) {
        if (attr.constructor === DG.Attribute) {
          if (!this.attrs.contains(attr)) {
            this.attrs.push(attr);
          } else {
            DG.logWarn('Duplicate add of attribute.');
          }
        } else {
          DG.logWarn('Attempt to add non-attribute to Data Set for Context: ' +
              this.dataContextRecord.id);
        }
      }.bind(this));
    },

    hasAttribute: function( iAttr) {
      return this.attrs.contains( iAttr);
    },

    /**
     * Delete attribute from data set.
     *
     * Note we do not modify the underlying data set which is kept as a map from
     * attribute id. The orphan attribute data does not get saved nor restored.
     *
     * @param attr {DG.Attribute}
     */
    deleteAttribute: function (attr) {
      var ix = this.attrs.findIndex(function (a) {return a === attr;});
      if (ix >= 0) {
        this.attrs.splice(ix, 1);
      }
    },

    /**
     * Adds a dataItem provided as an array of values, a map of attribute keys to values,
     * or as a DG.DataItem.
     *
     * @param {DG.DataItem|{}|[*]} data  A data item, a map of attribute
     * keys to values, or an array of values indexed in attribute order.
     * @return {DG.DataItem} the item.
     */
    addDataItem: function (data, beforeItemID) {
      var dataItem;
      var ix;

      data = data || {};

      if (data.constructor === DG.DataItem) {
        dataItem = data;
        if (!dataItem.id) {
          dataItem.id = DG.DataUtilities.createUniqueID();
        }
      } else if (typeof data === 'object') {
        // the object may be just values or an object with id and values
        if (data.values && typeof data.values === 'object') {
          data.dataSet = this;
          if (!data.id) {
            data.id = DG.DataUtilities.createUniqueID();
          }
          data.values = DG.DataUtilities.canonicalizeAttributeValues(this.attrs, data.values);
          dataItem = DG.DataItem.create(data);
        } else {
          dataItem = DG.DataItem.create({
            id: DG.DataUtilities.createUniqueID(),
            dataSet: this,
            values: DG.DataUtilities.canonicalizeAttributeValues(this.attrs,
                data)
          });
        }
      }

      if (dataItem) {
        ix = this.dataItems.push(dataItem) - 1; // push returns new array length.
                                    // We want the index of the last element
        dataItem.itemIndex = ix;

        if (beforeItemID == null) {
          dataItem._clientIndex = this._clientToItemIndexMap.push(ix) - 1;
        }
        else {
          var beforeClientIndex = this.getDataItemClientIndexByID(beforeItemID);

          // give the new item its client index
          dataItem._clientIndex = beforeClientIndex;

          // update client indices for existing items being pushed back
          this._clientToItemIndexMap.forEach(function(itemIndex) {
                                                var item = this.dataItems[itemIndex];
                                                if (item._clientIndex >= beforeClientIndex)
                                                  ++ item._clientIndex;
                                              }.bind(this));
          // splice in the new client index
          this._clientToItemIndexMap.splice(beforeClientIndex, 0, ix);
        }
      }
      return  dataItem;
    },

    updateItem: function (iItemID, iValues) {
      var iItemValues = DG.DataUtilities.canonicalizeAttributeValues(this.get('attrs'), iValues);
      var iItem = this.getDataItemByID(iItemID);
      iItem.updateData(iItemValues);
      return iItem;
    },

    /**
     * Sorts the items by the specified attribute using the specified compare function.
     * @return {number[]} the original client index map (for use with undo, for instance)
     */
    sortItems: function(attributeID, accessFunc, valueCompareFunc) {
      var compareFunc = function(itemIndex1, itemIndex2) {
                          var item1 = this.dataItems[itemIndex1],
                              item2 = this.dataItems[itemIndex2],
                              value1 = accessFunc(item1.id, attributeID),
                              value2 = accessFunc(item2.id, attributeID),
                              result = valueCompareFunc(value1, value2);
                          return result || (item1._clientIndex - item2._clientIndex);
                        }.bind(this);
      // copy the array, sort the copy
      var clientIndexMap = this._clientToItemIndexMap.slice().sort(compareFunc);
      // install the new map
      return this.setClientIndexMap(clientIndexMap);
    },

    /**
     * Returns a copy of the current client index map.
     * @return {number[]} the original client index map (for use with undo, for instance)
     */
    getClientIndexMapCopy: function() {
      return this._clientToItemIndexMap.slice();
    },

    /**
     * Installs the specified client index map.
     * @return {number[]} the original client index map (for use with undo, for instance)
     */
    setClientIndexMap: function(clientIndexMap) {
      var originalMap = this._clientToItemIndexMap;
      clientIndexMap.forEach(function(itemIndex, clientIndex) {
                              this.dataItems[itemIndex]._clientIndex = clientIndex;
                            }.bind(this));
      this._clientToItemIndexMap = clientIndexMap;
      return originalMap;
    },

    /**
     * Marks an item for deletion.
     * @param {DG.DataItem} iItem
     * @param {boolean} iSetAside whether to delete or set aside
     * @return {DG.DataItem} the deleted item.
     */
    deleteDataItem: function (iItem, iSetAside) {
      if (iItem) {
        iItem.deleted = true;
        iItem.setAside = iSetAside;
      }
      return iItem;
    },

    /**
     * Marks an item for deletion.
     * @param {integer} iItemIndex
     * @param {boolean} iSetAside whether to delete or set aside
     * @return {DG.DataItem} the deleted item.
     */
    deleteDataItemByIndex: function (iItemIndex, iSetAside) {
      var index = this._clientToItemIndexMap[iItemIndex],
          item = this.getDataItem(index);
      return item ? this.deleteDataItem(item, iSetAside) : null;
    },

    /**
     * Undeletes a dataItem if possible. It may not be possible, as clean will remove
     * deleted items.
     * @param itemIndex
     * @return {[*]|undefined} the restored DataItem.
     */
    undeleteDataItem: function (itemIndex) {
      var index = this._clientToItemIndexMap[itemIndex],
          item;
      if (index >= 0 && index < this.dataItems.length) {
        item = this.dataItems[index];
        item.deleted = false;
      }
      return item;
    },

    restoreSetAsideItems: function () {
      var restoredItems = [];
      this.dataItems.forEach(function (item) {
        if (item.setAside) {
          restoredItems.push(item);
          item.deleted = false;
          item.setAside = false;
        }
      });
      return restoredItems;
    },

    getSetAsideCount: function () {
      var count = 0;
      this.dataItems.forEach(function (item) {
        if (item.setAside) { count++; }
      });
      return count;
    },

    /**
     * Permanently removes deleted dataItems and reclaims space.
     * @return {number} Count of dataItems retrieved.
     */
    cleanDeletedDataItems: function () {
      this.dataItems.forEach(function(item, ix) {
        if (item.deleted) {
          delete this.dataItems[ix];
        }
      }.bind(this));
    },

    /**
     * Retrieves or sets an attribute value for a DataItem.
     *
     * @param {integer} itemIndex a non-negative integer
     * @param {integer} attributeID a non-negative integer
     * @param {string|number} value a legal attribute value
     * @return {string|number} a legal attribute value
     */
    value: function(itemIndex, attributeID, value) {
      var index = this._clientToItemIndexMap[itemIndex],
          item, ret;
      if (index >= 0 && index < this.dataItems.length) {
        item = this.dataItems[index];
        if (item && !item.deleted) {
          if (value) {
            item.values[attributeID] = value;
          }
          ret = item.values[attributeID];
        }
      }
      return ret;
    },

    getDataItemCount: function() {
      return this.getDataItems().length;
    },

    getDataItems: function() {
      return this._clientToItemIndexMap
          .map(function(index) { return this.dataItems[index]; }.bind(this))
          .filter(function (item) {return !item.deleted;});
    },

    /**
     * Retrieves an existing DataItem by index.
     *
     * @param {integer} itemIndex
     * @return {DG.DataItem|undefined}
     */
    getDataItem: function (itemIndex) {
      var index = this._clientToItemIndexMap[itemIndex],
          item;
      if (index >= 0 && index < this.dataItems.length) {
        item = this.dataItems[index];
        if (!item.deleted) {
          return item;
        }
      }
    },

    /**
     * Retrieves a DataItem by its given ID.
     * @param {*} itemID
     * @returns {DG.DataItem|undefined}
     */
    getDataItemByID: function (itemID) {
      return this.dataItems.find(function(item) { return item.id === itemID; });
    },

    parseSearchQuery: function (queryString) {
      if (queryString === '*') {
        return {
          valid: true,
          op: '*'
        };
      }
      // for now this is a simple single expression of "left op right" where op is a comparison operator
      // this could be expanded (along with the testCaseAgainstQuery method below) using the shunting yard algorithm
      var matches = queryString.match(/([^=!<>]+)(==|!=|<=|<|>=|>)([^=!<>]+)/),
          trim = function (s) { return s.replace(/^\s+|\s+$/, ''); },
          parsedQuery = {
            valid: !!matches,
            left: matches && trim(matches[1]),
            op: matches && matches[2],
            right: matches && trim(matches[3])
          },
          attrs = this.attrs,
          parseOperand = function (value) {
            var numberValue = Number(value),
                parsedValue = value === 'true' ? true :
                    (value === 'false' ? false :
                    (isNaN(numberValue) ? value : numberValue));
            return {
              value: parsedValue,
              attr: attrs.find(function (attr) {return attr.name === value;}),
              name: value
            };
          };

      parsedQuery.left = parseOperand(parsedQuery.left);
      parsedQuery.right = parseOperand(parsedQuery.right);

      // valid queries must have at least one side with a defined attribute
      parsedQuery.valid = !!(parsedQuery.valid && (parsedQuery.left.attr || parsedQuery.right.attr));

      return parsedQuery;
    },

    testItemAgainstQuery: function (iItem, parsedQuery) {
      var getValue = function (token) {
            return token.attr ? iItem.getValue(token.attr.id) : token.value;
          },
          leftValue = parsedQuery.left && getValue(parsedQuery.left),
          rightValue = parsedQuery.right && getValue(parsedQuery.right);

      if (!parsedQuery.valid) {
        return false;
      }

      switch (parsedQuery.op) {
        case '*': return true;
// eslint-disable-next-line eqeqeq
        case '==': return leftValue == rightValue; // jshint ignore:line
// eslint-disable-next-line eqeqeq
        case '!=': return leftValue != rightValue; // jshint ignore:line
        case '<':  return leftValue <   rightValue;
        case '<=': return leftValue <=  rightValue;
        case '>=': return leftValue >=  rightValue;
        case '>':  return leftValue >   rightValue;
        default:   return false;
      }
    },

    getItemsBySearch: function (queryString) {
      var parsedQuery = this.parseSearchQuery(queryString);

      // return null to signal an invalid query
      if (!parsedQuery.valid) {
        return null;
      }

      return this.dataItems.filter(function (iItem) {

        return (!iItem.deleted) && this.testItemAgainstQuery(iItem, parsedQuery);
      }.bind(this));

    },

    /**
     * Retrieves the client index of the DataItem wth the specified ID.
     * @param {*} itemID
     * @returns {number}
     */
    getDataItemClientIndexByID: function (itemID) {
      return this._clientToItemIndexMap.findIndex(function(itemIndex) {
                                                    var item = this.dataItems[itemIndex];
                                                    return item && (item.id === itemID);
                                                  }.bind(this));
    },

    moveDataItemByID: function (itemID, order) {
      var clientIndex = this.getDataItemClientIndexByID(itemID);
      var itemIndex = this._clientToItemIndexMap[clientIndex];
      if ((clientIndex != null) && (order != null)) {
        var newIndexMap = this._clientToItemIndexMap.slice();
        newIndexMap.splice(clientIndex, 1);
        switch (order) {
          case 'first':
            newIndexMap.unshift(itemIndex);
            break;
          case 'last':
            newIndexMap.push(itemIndex);
            break;
          default:
            newIndexMap.splice(order, 0, itemIndex);
            break;
        }
        this.setClientIndexMap(newIndexMap);
      }
    },

    compareItemsByClientIndex: function(item1, item2) {
      return item1._clientIndex - item2._clientIndex;
    },

    /**
     * This method is called as a part of restoring a DataContext, to add
     * SetAside items to the DataSet.
     * @param itemSpecs
     */
    createSetAsideItems: function (itemSpecs) {
      itemSpecs.forEach(function (itemData) {
        var item = this.addDataItem(itemData);
        this.deleteDataItem(item, true);
      }.bind(this));
    },

    archiveSetAsideItems: function () {
      return this.dataItems.filter(function (item) {
          return item.setAside;
        }).map(function (item) {
          return {id: item.id, values: item.toArchive().values};
        });
      },
    /**
     * Returns a serializable version of this object.
     * @returns {{dataItems: [DG.DataItem]}}
     */
    toArchive: function () {
      return {
        dataItems: this.dataItems.filterProperty('deleted', false).map(function (item) {
          return {
            values: item.values,
            id: item.id,
            itemIndex: item.itemIndex
          };
        })
      };
    }

  };
})());

/* >>>>>>>>>> BEGIN source/models/game_spec.js */
// ==========================================================================
//                              DG.GameSpec
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('models/base_game_spec');

/** @class

  (Document your Model here)

  @extends SC.Object
*/
DG.GameSpec = DG.BaseGameSpec.extend(
/** @scope DG.GameSpec.prototype */ {

  /**
    Returns the specification for the child/leaf collection.
    @returns  {Object}    The collection specification
   */
  childCollection: function() {
    var collections = this.get('collections'),
        collectionCount = (collections && collections.length) || 0,
        index = collectionCount - 1;
    return (index >= 0) ? collections[ index] : null;
  }.property('collections').cacheable(),

  /**
    Returns the specification for the parent collection.
    @returns  {Object}    The collection specification
   */
  parentCollection: function() {
    var collections = this.get('collections'),
        collectionCount = (collections && collections.length) || 0,
        index = collectionCount - 2;
    return (index >= 0) ? collections[ index] : null;
  }.property('collections').cacheable(),

  /**
    Returns the name of the child/leaf collection.
    @returns  {String}    The name of the collection
   */
  collectionName: function() {
    var collection = this.get('childCollection'),
        name = collection && collection.name;
    return !SC.empty( name) ? name : null;
  }.property('childCollection').cacheable(),

  /**
    Returns the name of the parent collection.
    @returns  {String}    The name of the collection
   */
  parentCollectionName: function() {
    var collection = this.get('parentCollection'),
        name = collection && collection.name;
    return !SC.empty( name) ? name : null;
  }.property('parentCollection').cacheable(),

  eventsAttributeName: function() {
    var parent = this.get('parentCollection'),
        events = parent && parent.childAttrName;
    if( SC.empty( events)) {
      var child = this.get('childCollection');
      events = child && child.name;
    }
    return !SC.empty( events) ? events : null;
  }.property('parentCollection','childCollection').cacheable(),

  getAttrType: function( iCollection, iAttrName) {
    var i, attrCount = iCollection.attrs.length;
    for( i = 0; i < attrCount; ++i) {
      var attr = iCollection.attrs[ i];
      if( attr && (attr.name === iAttrName))
        return attr.type;
    }
    return null;
  },

  graphDefaults: function() {
    var collection = this.get('childCollection');
    return collection && collection.defaults;
  }.property('childCollection').cacheable(),

  xAttrName: function() {
    var defaults = this.get('graphDefaults');
    return defaults && defaults.xAttr;
  }.property('graphDefaults').cacheable(),

  xAttrIsNumeric: function() {
    var collection = this.get('childCollection'),
        attrName = this.get('xAttrName'),
        attrType = this.getAttrType( collection, attrName);
    return attrType === 'numeric';
  }.property('childCollection','xAttrName').cacheable(),

  yAttrName: function() {
    var defaults = this.get('graphDefaults');
    return defaults && defaults.yAttr;
  }.property('graphDefaults').cacheable(),

  yAttrIsNumeric: function() {
    var collection = this.get('childCollection'),
        attrName = this.get('yAttrName'),
        attrType = this.getAttrType( collection, attrName);
    return attrType === 'numeric';
  }.property('childCollection','yAttrName').cacheable(),

  legendAttrName: function() {
    var defaults = this.get('graphDefaults');
    return defaults && defaults.legendAttr;
  }.property('graphDefaults').cacheable(),

  legendAttrIsNumeric: function() {
    var collection = this.get('childCollection'),
        attrName = this.get('legendAttrName'),
        attrType = this.getAttrType( collection, attrName);
    return attrType === 'numeric';
  }.property('childCollection','legendAttrName').cacheable(),

  origin: function() {
    var matches = this.get('url').match(/(.*?\/\/.*?)\//);
    return matches ? matches[1] : null;
  }.property('url').cacheable()

}) ;

/* >>>>>>>>>> BEGIN source/react/function-browser.js */
/* global ReactDOM, ReactDOMFactories */
DG.React.ready(function () {
  var div = ReactDOMFactories.div,
      ul = ReactDOMFactories.ul,
      li = ReactDOMFactories.li,
      span = ReactDOMFactories.span,
      italic = ReactDOMFactories.i,
      h1 = ReactDOMFactories.h1,
      h2 = ReactDOMFactories.h2,
      kLeftAngleBracketChar = '&#x2039;',
      kRightAngleBracketChar = '&#x203a;',
      kInfoIconChar = '&#9432;';  // http://stackoverflow.com/a/33878610

  DG.React.Components.FunctionBrowser = DG.React.createComponent({
    getInitialState: function () {
      return {
        style: null,
        categories: this.categorize(this.props.categorizedFunctionInfo),
        category: null,
        fn: null
      };
    },

    componentDidMount: function () {
          // eslint-disable-next-line react/no-find-dom-node
      var anchorNode = ReactDOM.findDOMNode(this.props.anchor),
          anchorBounds = anchorNode.getBoundingClientRect(),
          // eslint-disable-next-line react/no-find-dom-node
          containerNode = ReactDOM.findDOMNode(this.props.container),
          containerBounds = containerNode.getBoundingClientRect(),
          spaceAbove = anchorBounds.top - containerBounds.top,
          spaceBelow = containerBounds.bottom - anchorBounds.bottom,
          kReservedHeight = 300,
          kReservedMargin = 6,
          style = { position: 'absolute', left: anchorBounds.left };
      if ((spaceBelow < kReservedHeight) && (spaceBelow < spaceAbove)) {
        // place above anchor if not enough room below
        style.bottom = containerBounds.bottom - anchorBounds.top;
        style.maxHeight = anchorBounds.top - kReservedMargin;
      }
      else {
        // place below anchor if there's enough room
        style.top = anchorBounds.bottom;
        style.maxHeight = containerBounds.bottom - anchorBounds.bottom - kReservedMargin;
      }
      this.setState({ style: style });
    },

    categorize: function(categorizedFunctionInfo) {
      var categories = [],
          categoryNames;

      categoryNames = Object.keys(categorizedFunctionInfo);
      categoryNames.sort();
      categoryNames.forEach(function(categoryName) {
        var functionNames = Object.keys(categorizedFunctionInfo[categoryName]),
            functions = [];

        functionNames.sort();
        functionNames.forEach(function (functionName) {
          var definition = categorizedFunctionInfo[categoryName][functionName],
              argList = [],
              i, maxArgs, requiredArgs, optionalArgs;

          // 99 is used to signify variable args for string concat and join
          maxArgs = definition.args ? definition.args.length
                                    : definition.maxArgs > 20 ? 2 : definition.maxArgs;

          // create the args if not found
          definition.args = definition.args || [];
          if (maxArgs) {
            for (i = 0; i < maxArgs; i++) {
              if (i === definition.args.length) {
                definition.args.push({
                  name: "abcdefghijklmnopqrstuvwxyz"[i],
                  type: "any",
                });
              }
              definition.args[i].required = i < definition.minArgs;
            }
          }

          requiredArgs = definition.args.slice(0, definition.minArgs).map(function (arg) { return arg.name; }).join(', ');
          if (requiredArgs) {
            argList.push(requiredArgs);
          }
          optionalArgs = definition.args.slice(definition.minArgs).map(function (arg) { return arg.name; }).join(', ');
          if (optionalArgs) {
            argList.push(optionalArgs);
          }

          functions.push({
            name: functionName,
            definition: definition,
            argList: argList.join(", ")
          });
        });

        categories.push({
          name: categoryName,
          functions: functions
        });
      });

      return categories;
    },

    selectFunction: function (fn) {
      if (this.props.onSelect) {
        this.props.onSelect(fn.name, fn.argList, fn);
      }
      this.props.unmount(); // unmount is added by DG.React.HighOrderComponents.UnmountOnOutsideClick
    },

    renderHeader: function (parentName, itemName, onClick) {
      return div({className: 'react-function-browser-header clickable', onClick: onClick},
        span({dangerouslySetInnerHTML: {__html:kLeftAngleBracketChar + ' ' + parentName}}),
        itemName
      );
    },

    renderCategoryList: function (categories) {
      var self = this,
          list = categories.map(function (category) {
            var clicked = function () {
              self.setState({category: category});
            };
            return li({className: 'clickable', key: category.name, onClick: clicked},
              span({}, category.name),
              div({dangerouslySetInnerHTML: {__html:kRightAngleBracketChar}})
            );
          });
      return ul({}, list);
    },

    renderFunctionList: function (category) {
      var self = this,
          list = category.functions.map(function (fn) {
            var infoClicked = function () {
                  self.setState({category: category, fn: fn});
                },
                fnClicked = function () {
                  self.selectFunction(fn);
                },
                hasInfo = !!fn.definition.description || !!fn.definition.examples;

            return li({key: fn.name},
              span({className: 'clickable', onClick: fnClicked, title: fn.definition.description},
                fn.name,
                italic({}, '(' + fn.argList + ')')
              ),
              hasInfo ? div({className: 'clickable', onClick: infoClicked, dangerouslySetInnerHTML: {__html:kInfoIconChar}}) : null
            );
          });

      return div({},
        this.renderHeader('Categories', category.name, function () {
          this.setState({category: null});
        }.bind(this)),
        ul({}, list)
      );
    },

    renderFunction: function (category, fn) {
      var self = this,
          argItems = fn.definition.args.map(function (arg, index) {
            return li({key: 'arg-' + index},
              italic({}, arg.name + (arg.description ? ': ' : '')),
              span({}, arg.description || '',
              ' (',
              italic({}, arg.required ? 'required' : 'optional'),
              ')'));
          }),
          examples = (fn.definition.examples || []).map(function (example, index) {
            return li({key: 'example-' + index}, example);
          }),
          fnClicked = function () {
            self.selectFunction(fn);
          };

      return div({},
        this.renderHeader(category.name, fn.name, function () {
          this.setState({fn: null});
        }.bind(this)),
        div({className: 'react-function-browser-function-info'},
          h1({className: 'clickable', onClick: fnClicked }, fn.name, italic({}, '(' + fn.argList + ')')),
          fn.definition.description ? div({}, fn.definition.description) : null,
          argItems ? div({},
            h2({}, 'Parameters'),
            ul({}, argItems)
          ) : null,
          examples ? div({},
            h2({}, 'Examples'),
            ul({}, examples)
          ) : null
        )
      );
    },

    render: function () {
      var contents = null;
      if (this.state.style) {
        if (this.state.fn) {
          contents = this.renderFunction(this.state.category, this.state.fn);
        }
        else if (this.state.category) {
          contents = this.renderFunctionList(this.state.category);
        }
        else {
          contents = this.renderCategoryList(this.state.categories);
        }
      }
      return div({className: 'react-function-browser dg-wants-touch', style: this.state.style}, contents);
    }
  }, [DG.React.HighOrderComponents.UnmountOnOutsideClick, DG.React.HighOrderComponents.UnmountOnEscapeKey]);

});

/* >>>>>>>>>> BEGIN source/resources/busy_cursor.js */
// ==========================================================================
//                              DG.busyCursor
//
//  Copyright (c) 2015 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

DG.busyCursor = SC.Object.create({

  cover: null,
  invocations: 0,

  /**
   * During lengthy processes, we cover up the entire document with an element whose cursor is a busy cursor.
   */
  show: function( iFunction) {
    var invocation = function() {
      this.invocations++;
      iFunction();
      this.hide();
    }.bind( this);

    var tMainPane = DG.getPath('mainPage.mainPane'),
        tCover = this.get('cover');
    if( !tCover) {
      tCover = SC.View.create( {
        classNames: ['dg-busy-cover'],
        isVisible: false
      });
      this.set('cover', tCover);
      tMainPane.appendChild( tCover);
    }
    tCover.set('isVisible', true);
    this.invokeLater(invocation, 10);
    SC.run( function() {
      SC.Event.trigger(DG.mainPage.mainPane.$()[0], 'mousemove');
      //SC.Event.simulateEvent( DG.mainPage.mainPane.$()[0], 'mousemove');
    }, this, true /* start a new run loop */);
  },

  /**
   * Uncover so regular cursors can show
   */
  hide: function() {
    this.invocations--;
    if( this.invocations <= 0) {
      var tCover = this.get('cover');
      if (tCover)
        tCover.set('isVisible', false);
    }
  }

});



/* >>>>>>>>>> BEGIN source/resources/splash.js */
// ==========================================================================
//                              DG.splash
//
//  Copyright (c) 2015 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

var splashPanel;
var kHeight = 200, kPadding = 20, kRatio = 1936 / 649;

DG.splash = SC.Object.create({

  isShowing: false,

  showSplash: function (hideSplashImage, timeOut) {
    if (hideSplashImage && DG.get('componentMode') !== 'yes') {
      if (this.get('isShowing')) {
        DG.splash.hideSplash();
      }
      splashPanel = SC.PanelPane.create({
        classNames: ['dg-splash'],
        layout: {width: 0, height: 0, left: -20, top: 0},
        contentView: null,
        close: function () {
          this.timer && this.timer.invalidate();
          this.destroy();
          DG.splash.set('isShowing', false);
        },
        timer: null,
        init: function () {
          if (timeOut) {
            this.timer = SC.Timer.schedule({
              interval: timeOut, action: DG.splash.hideSplash, target: this
            });
          }
        }
      }).append();
      this.set('isShowing', true);
    } else if (DG.Browser.isCompatibleBrowser()
          && !this.get('isShowing')
          && DG.get('componentMode') !== 'yes'
          && DG.get('hideSplashScreen') !== 'yes') {
      splashPanel = SC.PanelPane.create({
        classNames: ['dg-splash'],
        layout: { width: kRatio * kHeight + 2 * kPadding, height: kHeight + 2 * kPadding, centerX: 0, centerY: 0},
        contentView: SC.View.extend({
          childViews: 'splash spinner'.w(),
          backgroundColor: '#FFF',

          splash: SC.ImageView.extend({
            layout: { left: kPadding, right: kPadding, top: kPadding, bottom: kPadding},
            value: DG.get('splashURL'),
            click: function () {
              DG.splash.hideSplash();
            },
            keyDown: function () {
              DG.splash.hideSplash();
            },
            acceptsFirstResponder: true
          }),

          spinner: SC.ImageView.extend({
            init: function () {
              arguments.callee.base.apply(this,arguments);
              var _this = this;
              window.setTimeout(function () {
                _this.set('isVisible', YES);
              }, 2000);
            },
            layout: {centerX: 0, bottom: kPadding + 6, height: 32, width: 32},
            value: '../../../../static/dg/de/cert/source/resources/images/spinner.gif',
            canLoadInBackground: YES,
            useCanvas: NO,
            isVisible: NO
          })
        }),
        acceptsKeyPane: true,
        close: function () {
          this.destroy();
          DG.splash.set('isShowing', false);
        }
      }).append();
      splashPanel.contentView && splashPanel.contentView.becomeFirstResponder();
      this.set('isShowing', true);
    }
  },

  hideSplash: function() {
    if(splashPanel) { splashPanel.close(); }
  }

});



/* >>>>>>>>>> BEGIN source/resources/tool_button_data.js */
// ==========================================================================
//                            DG.ToolButtonData
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

DG.ToolButtonData = {
  tableButton: {
    title: 'DG.ToolButtonData.tableButton.title', // "Table"
    iconClass: 'moonicon-icon-table',
    target: 'DG.appController.caseTableMenuPane',
    action: 'showMenu',
    toolTip: 'DG.ToolButtonData.tableButton.toolTip', // "Open/close the case table (ctrl-alt-t)"
    localize: true,
    isEnabledBinding: SC.Binding.oneWay('DG.currDocumentController.ready'),
    classNames: ['dg-table-button']
  },

  graphButton: {
    title: 'DG.ToolButtonData.graphButton.title', // "Graph"
    iconClass: 'moonicon-icon-graph',
    target: 'DG.mainPage',
    action: 'addGraph',
    toolTip: 'DG.ToolButtonData.graphButton.toolTip', // "Make a graph (ctrl-alt-g)"
    localize: true,
    isEnabledBinding: SC.Binding.oneWay('DG.currDocumentController.ready'),
    classNames: ['dg-graph-button']
  },

  mapButton: {
    title: 'DG.ToolButtonData.mapButton.title', // "Map"
    iconClass: 'moonicon-icon-map',
    target: 'DG.mainPage',
    action: 'addMap',
    toolTip: 'DG.ToolButtonData.mapButton.toolTip', // "Make a map"
    localize: true,
    isEnabledBinding: SC.Binding.oneWay('DG.currDocumentController.ready'),
    classNames: ['dg-map-button']
  },

  sliderButton: {
    title: 'DG.ToolButtonData.sliderButton.title',  // "Slider"
    iconClass: 'moonicon-icon-slider',
    target: 'DG.mainPage',
    action: 'addSlider',
    toolTip: 'DG.ToolButtonData.sliderButton.toolTip',  // "Make a slider (ctrl-alt-s)"
    localize: true,
    classNames: ['dg-slider-button']
  },

  calcButton: {
    title: 'DG.ToolButtonData.calcButton.title',  // "Calc"
    iconClass: 'moonicon-icon-calc',
    target: 'DG.mainPage',
    action: 'toggleCalculator',
    toolTip: 'DG.ToolButtonData.calcButton.toolTip',  // "Open/close the calculator (ctrl-alt-c)"
    localize: true,
    classNames: ['dg-calc-button']
  },

  textButton: {
    title: 'DG.ToolButtonData.textButton.title',  // "Text"
    iconClass: 'moonicon-icon-comment',
    target: 'DG.mainPage',
    action: 'addText',
    toolTip: 'DG.ToolButtonData.textButton.toolTip',  // "Make a text object (ctrl-alt-shift-t)"
    localize: true,
    classNames: ['dg-text-button']
  },

  pluginButton: {
    title: 'DG.ToolButtonData.pluginMenu.title',  // "Utilities"
    iconClass: 'moonicon-icon-plug',
    target: 'DG.appController.pluginMenuPane',
    action: 'showMenu',
    toolTip: 'DG.ToolButtonData.pluginMenu.toolTip',  // "Select a utility component"
    localize: true,
    classNames: ['dg-plugin-button']
  }

};

DG.RightButtonData = {
  undoButton: {
    title: 'DG.mainPage.mainPane.undoButton.title', // "Undo"
    iconClass: 'moonicon-arrow-undo',
    localize: true,
    toolTip: function() {
      var cmd = this.get('nextUndoCommand');
      return (cmd ? cmd.get('undoString') : 'DG.mainPage.mainPane.undoButton.toolTip');  // "Undo the last action"
    }.property('nextUndoCommand'),
    target: 'DG.UndoHistory',
    action: 'undo',
    nextUndoCommandBinding: SC.Binding.oneWay('DG.UndoHistory.nextUndoCommand'),
    isEnabledBinding: SC.Binding.oneWay('DG.UndoHistory.canUndo'),
    isVisibleBinding: SC.Binding.oneWay('DG.UndoHistory.enabled'),
    flowSpacing: { right: 0, top: 17 },
    classNames: ['dg-undo-button']
  },

  redoButton: {
    title: 'DG.mainPage.mainPane.redoButton.title', // "Redo"
    iconClass: 'moonicon-arrow-redo',
    localize: true,
    toolTip: function() {
      var cmd = this.get('nextRedoCommand');
      return (cmd ? cmd.get('redoString') : 'DG.mainPage.mainPane.redoButton.toolTip');  // "Redo the last undone action"
    }.property('nextRedoCommand'),
    target: 'DG.UndoHistory',
    action: 'redo',
    nextRedoCommandBinding: SC.Binding.oneWay('DG.UndoHistory.nextRedoCommand'),
    isEnabledBinding: SC.Binding.oneWay('DG.UndoHistory.canRedo'),
    isVisibleBinding: SC.Binding.oneWay('DG.UndoHistory.enabled'),
    flowSpacing: { right: 20, top: 17 },
    classNames: ['dg-redo-button']
  },

  tileListButton: {
    title: 'DG.ToolButtonData.tileListMenu.title',  // "Tiles"
    iconClass: 'moonicon-icon-tileList',
    target: 'DG.appController.tileMenuPane',
    action: 'showTileList',
    toolTip: 'DG.ToolButtonData.tileListMenu.toolTip',  // "Show the list of tiles in the document"
    localize: true,
    classNames: ['dg-tilelist-button']
  },

  optionButton: {
    title: 'DG.ToolButtonData.optionMenu.title',  // "Options"
    iconClass: 'moonicon-icon-options',
    target: 'DG.appController.optionMenuPane',
    action: 'popup',
    toolTip: 'DG.ToolButtonData.optionMenu.toolTip',  // "View or change CODAP options"
    localize: true,
    classNames: ['dg-option-button']
  },

  guideButton: {
    title: 'DG.ToolButtonData.guideMenu.title',  // "Guide"
    iconClass: 'moonicon-icon-guide',
    target: 'DG.appController.guideMenuPane',
    action: 'popup',
    toolTip: 'DG.ToolButtonData.guideMenu.toolTip',  // "View or change CODAP options"
    localize: true,
    isVisible: false,
    classNames: ['dg-guide-button']
  },

  helpButton: {
    title: 'DG.ToolButtonData.help.title',  // "Guide"
    iconClass: 'moonicon-icon-help',
    target: 'DG.appController.helpMenuPane',
    action: 'popup',
    toolTip: 'DG.ToolButtonData.help.toolTip',  // "View or change CODAP options"
    localize: true,
    isVisible: true,
    classNames: ['dg-help-button']
  }

};


/* >>>>>>>>>> BEGIN source/theme.js */
// ==========================================================================
//                            DG.Theme
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

  By defining this subclass theme we give ourselves some flexibility in using css.

 @extends SC.AceTheme
 */
DG.Theme = SC.AceTheme.create(
  {
    name: 'dg'
  } );

SC.Theme.addTheme(DG.Theme);

SC.defaultTheme = 'dg';

/* >>>>>>>>>> BEGIN source/utilities/animation_math.js */
// ==========================================================================
// 							DG.AnimationMath
// 
// 	A collection of math utility functions for use in animation.
// 	
// 	Author:		Craig D. Miller
// 	Copyright:	2010 by University of Massachusetts, all rights reserved.
// 	Change Record:
// 		11/13/10	Bill	Ported from desktop TinkerPlots
// 	
// ==========================================================================
//	globals DG

DG.AnimationMath = {

	kAnimationBias: 0.7,
	kAnimationGain: 0.3,

	//  Bias
	// 
	// 	Returns a "gamma correction" or exponential adjusted 't' value 
	// 	in range [0.0 - 1.0]. Parameter 'a' adjusts the exponent curve shape,
	// 	0.5 is a "y=x" function.
	// 
	// 	From "Fast Alternatives to Perlin's Bias and Gain Functions,
	// 	Graphics Gems, IV p. 401.  Page 402 has useful diagrams.
	Bias: function( 
		t,	//  curve sampling parameter [0.0 - 1.0]
		a )	//	curve shaping parameter [0.0 - 1.0] (defaults to kAnimationBias
	{
		var r;
		if( !a)
			a = this.kAnimationBias;
	
		if ( 		a <= 0.000001 )	// should be "if ( a == 0.0 )" but handle roundoff error.
			r = 0.0;
		else if (	a >= 0.999999 ) 
			r = 1.0;
		else
			r = t / (( 1/a - 2 ) * ( 1 - t ) + 1);
		return r;
	},


	//  Gain
	// 
	// 	Returns a symmetrical "s-curve" adjusted 't' value
	// 	in the range [0.0 - 1.0].   Parameter 'a' adjusts the S curve shape,
	// 	0.5 is a "y=x" function.
	// 
	// 	From "Fast Alternatives to Perlin's Bias and Gain Functions",
	// 	Graphics Gems, IV p. 401.  Page 402 has useful diagrams.
	Gain: function( 
		t,	//  curve sampling parameter [0.0 - 1.0]
		a )	//	curve shaping parameter [0.0 - 1.0] (defaults to kAnimationGain
	{
		var r;		
		if( !a)
			a = this.kAnimationGain;
	
		if ( 		a <= 0.000001 )	// should be "if ( a == 0.0 )" but handle roundoff error.
			r = 0.0;
		else if (	a >= 0.999999 )
			r = 1.0;
		else {
			r = ( 1/a - 2 ) * ( 1 - 2*t );
	
			if ( t < 0.5 )
				r = t / (r + 1);
			else
				r = (r - t)/(r - 1);
		}
		return r;
	},
	
	// DefaultAnimationTween
	//	Given a fraction between 0 and 1, return a new fraction to use in tweening
	//	by applying the default Gain to the defatul Bias.
	DefaultAnimationTween: function( t) {
		return this.Gain( this.Bias( t));
	}

};

/* >>>>>>>>>> BEGIN source/utilities/array_utils.js */
// ==========================================================================
//                            DG.ArrayUtils
//
//  A collection of utilities for working with JavaScript Arrays.
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

DG.ArrayUtils = {

  /**
   * Modify the given array by removing the given element from it
   * @param iArray {[]}
   * @param iElement
   * @return {Array}
   */
  remove: function( iArray, iElement) {
    var tIndex = iArray.indexOf( iElement);
    if( tIndex >= 0)
      iArray.splice( tIndex, 1);
    return iArray;
  },

  /**
    Returns the index of the first array entry for which the specified
    match function returns true. Returns -1 if no match is found.
    @param    {Array}     The array in which to search for a match
    @param    {Function}  iMatchFunc: function( iArrayElement) { ... }
    @returns              index of first match or -1 if no match found
   */
  indexOfMatch: function( iArray, iMatchFunc) {
    var i, len = iArray.length;
    for( i = 0; i < len; ++i) {
      if( iMatchFunc( iArray[ i]))
        return i;
    }
    return -1;
  },

  /**
    Returns the first element of the array for which the specified
    match function returns true. Returns null if no match is found.
    @param    {Array}     The array in which to search for a match
    @param    {Function}  iMatchFunc: function( iArrayElement) { ... }
    @returns              first matching element or null if no match found
   */
  firstMatch: function( iArray, iMatchFunc) {
    var i, len = iArray.length;
    for( i = 0; i < len; ++i) {
      var element = iArray[ i];
      if( iMatchFunc( element))
        return element;
    }
    return null;
  },

  /**
    Numeric comparison function for use with Array.sort() or DG.ArrayUtils.binarySearch().
    Handles NaNs as follows: all NaNs compare equivalent to each other, greater than all
    non-NaN values so they get sorted at the end of the array.
    Note that non-numeric values are not handled at all.
    @param  {Number}  iFirst -- The first Number to compare
    @param  {Number}  iSecond -- The second Number to compare
    @returns  {Number}  -1 if iFirst < iSecond
                         0 if iFirst = iSecond
                         1 if iFirst > iSecond
   */
  numericComparator: function( iFirst, iSecond) {
    // Handle NaNs first -- NaNs compare equal to each other, at end.
    var firstNaN = isNaN( iFirst),
        secondNaN = isNaN( iSecond);
    if( firstNaN && secondNaN) return 0;
    if( firstNaN) return -1;
    if( secondNaN) return 1;
    // Handle regular values
    if( iFirst < iSecond) return -1;
    if( iFirst > iSecond) return 1;
    return 0;
  },

  /**
    Searches the specified array for the specified value using the comparison function.

    @param {Array} iArray   The Array to be searched
    @param {Object} iValue  The value to search for
    @param {Function}       The comparison function to use
    @returns {Number}       The index of the value in the array if found, -1 otherwise
   */
  binarySearch: function( iArray, iValue, iComparator) {
    if( !iArray || !iComparator) return -1;
    var low = 0, high = iArray.length - 1,
        i, comparison;
    while (low <= high) {
      i = Math.floor((low + high) / 2);
      comparison = iComparator(iArray[i], iValue);
      if (comparison < 0) low = i + 1;
      else if (comparison > 0) high = i - 1;
      else return i;
    }
    return -1;
  },

  /**
   * Returns the result of iMinuend minus iSubtrahend
   * Avoids o(n^2) by forming a hash whose keys are the id's returned for each element of
   * iMinuend using iGetIdF and whose values are the objects, removing the keys that are
   * found for elements of iSubtrahend, and finally forming an array of the remaining values
   * of the hash.
   *
   * Note that if there is nothing to subtract, we return the original array. If you want to make
   * use of the returned array without changing the original, you'll have to make your own copy.
   *
   * @param iMinuend {Array}
   * @param iSubtrahend {Array}
   * @param iGetIdF {Function}
   * @returns {Array} the difference, elements in iMinuend that are not in iSubtrahend
   */
  subtract: function( iMinuend, iSubtrahend, iGetIdF) {
    var tDifference = [],
        tHash = {};
    if(!iMinuend || iMinuend.length === 0)
      return iMinuend;
    if(!iSubtrahend || iSubtrahend.length === 0) {
      return (!Array.isArray( iMinuend) && iMinuend.toArray) ? iMinuend.toArray() : iMinuend;
    }

    iMinuend.forEach( function( iElement) {
      tHash[ iGetIdF (iElement)] = iElement;
    });
    iSubtrahend.forEach( function( iElement) {
      delete tHash[ iGetIdF( iElement)];
    });
    // Note that we have to keep the original order of elements
    iMinuend.forEach(function(iElement) {
      var tID = iGetIdF(iElement);
      if( tHash[tID])
        tDifference.push(tHash[tID]);
    });
    return tDifference;
  },

  stableSort: function (iArray, iCompare) {
    if (!iCompare) {
      iCompare = function (a, b) { return (a<=b)?((a<b)?-1:0):1; };
    }

    if (SC.browser.name !== SC.BROWSER.chrome) {
      return iArray.sort(iCompare);
    }

    // adapted from http://khan4019.github.io/front-end-Interview-Questions/sort.html#mergeSort

    function mergeSort(arr) {
      if (arr.length < 2) return arr;

      var middle = Math.floor(arr.length / 2);
      var left = arr.slice(0, middle);
      var right = arr.slice(middle, arr.length);

      return merge(mergeSort(left), mergeSort(right));
    }

    function merge(left, right) {
      var result = [];
      var leftLength = left.length;
      var rightLength = right.length;
      var leftIndex = 0;
      var rightIndex = 0;

      while (leftIndex < leftLength && rightIndex < rightLength) {
        if (iCompare(left[leftIndex], right[rightIndex]) <= 0) {
          result.push(left[leftIndex++]);
        } else {
          result.push(right[rightIndex++]);
        }
      }

      result = result.concat(left.slice(leftIndex));
      result = result.concat(right.slice(rightIndex));

      return result;
    }

    return mergeSort(iArray);
  }
};


/* >>>>>>>>>> BEGIN source/utilities/case_value_animator.js */
// ==========================================================================
//                            DG.CaseValueAnimator
// 
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

  Holds onto an array of attributeIDs, an array of cases, and a delta for each attribute. During animation, each
    case's values change incrementally so that when the animation is finished, the cases have moved the full delta
    in each attribute dimension.

 @extends SC.Object
 */
DG.CASE_VALUE_ANIMATOR_DISABLE_ANIMATION = false;

DG.CaseValueAnimator = SC.Object.extend(
  {
    /**
      The data context to which animation changes should be applied.
      @property {DG.DataContext}
     */
    dataContext: null,
    
    /**
     * Typically there are only one or two elements in this array.
     * @property {SC.Array of {Number} }
     */
    attributeIDs: null,

    /**
     * How much each case value for each attribute will have changed at animation's end.
     * There are the same number of these as there are attributeIDs.
     * @property {SC.Array of {Number} }
     */
    deltas: null,

    /**
     * The cases whose values are being animated.
     * @property {SC.Array of {Case}}
     */
    cases: null,

    /**
     * One element per case. Each element is an array of values, one per attribute
     * @property {SC.Array of {SC.Array of {Number}}}
     */
    startingValues: null,

    /**
      @property {Boolean}
    */
    isAnimating: false,

    /**
      @property {Number}
    */
    startTime: null,
    
    destroy: function() {
      this.endAnimation();
      arguments.callee.base.apply(this,arguments);
    },

    /**
      Change the values of the attributes we are animating of the cases that have been specified
      previously to the specified proportion of the animation.
      Presumes that the 'dataContext', 'cases', and 'attributeIDs' properties have been set up previously.
      @param  {Number}    The proportion of the animation to set the new values to
     */
    changeValues: function ( iProportion) {
      var this_ = this,
          tDataContext = this.get('dataContext'),
          tCases = [], tAttributeIDs = [];

      if( !tDataContext) return;

      // tween - Simple tween using iAnimationProportion
      function tween( iStart, iDelta, iAnimationProportion) {
        var tResult;
        if( DG.isDate( iStart)) {
          tResult = DG.createDate( iStart - iAnimationProportion * iDelta);
        }
        else {
          tResult = iStart - iAnimationProportion * iDelta;
        }
        return tResult;
      }
      
      this.attributeIDs.forEach( function( iAttributeID) { tAttributeIDs.push( iAttributeID); });
      this.cases.forEach( function( iCase) { tCases.push( iCase); });
      
      var change = {
            operation: 'updateCases',
            attributeIDs: tAttributeIDs,
            cases: tCases,
            values: [],
            dirtyDocument: false
          };

      this.cases.forEach( function( iCase, iValueIndex) {
        var tValues = this_.startingValues[ iValueIndex];
        this_.attributeIDs.forEach( function( iID, iAttrIndex) {
          if( !change.values[iAttrIndex]) change.values[iAttrIndex] = [];
          change.values[iAttrIndex].push( tween( tValues[ iAttrIndex], this_.deltas[ iAttrIndex], iProportion));
        });
      });
      
      tDataContext.applyChange( change);
    },



    /**
      We assume that my properties have been set to the aspects of the plot that are to
      be animated. If there is an animation already in progress, we end it.
    */
    animate: function() {
      var this_ = this,
          kInterval = 50,	// milliseconds
          kTargetDuration = DG.PlotUtilities.kDefaultAnimationTime
          ;

      function stashStartingValues() {
        this_.startingValues = [];
        if( SC.none( this_.cases))
          return;

        this_.cases.forEach( function(iCase) {
          var tValues = [];
          this_.attributeIDs.forEach( function(iID) {
            tValues.push( iCase.getRawValue( iID));
          });
          this_.startingValues.push( tValues);
        });
      }

      // animationLoop - This function is called up to 20 times per second.
      // Note that it schedules itself using an SC.Timer.
      function animationLoop() {
        var tCurrTime = (new Date()).valueOf(),
            tCurrProportion = (tCurrTime - this_.startTime) / kTargetDuration,
            tAnimationProportion;

        // getAnimationProportion - Return DefaultAnimationTween for the given 
        // proportion with a bit of bounds checking.
        function getAnimationProportion( iProportion) {
          if( iProportion >= 1)
            return 1;
          else
            return DG.AnimationMath.DefaultAnimationTween( iProportion);
        }

        // Body of animationLoop
        tAnimationProportion = getAnimationProportion( tCurrProportion);

        if( tCurrProportion < 1) {
          DG.assert( !this_.animationTimer.get( 'isPaused'));
          this_.changeValues( tAnimationProportion);
        }
        else {
          this_.endAnimation();
        }
      }

      // Body of animate
      if( this.isAnimating) {
        this.endAnimation();
      }

      stashStartingValues();

      this.isAnimating = true;
      
      if( DG.CASE_VALUE_ANIMATOR_DISABLE_ANIMATION) {
        this.endAnimation();
        return;
      }

      this.startTime = (new Date()).valueOf();

      if( SC.none( this.animationTimer))
        this.animationTimer = SC.Timer.schedule( { action: animationLoop, interval: kInterval,
                                                    repeats: YES, until: false });
      this.animationTimer.set( 'isPaused', NO);

    },

    /**
      We assume that my properties have been set to the aspects of the plot that are to
      be animated. If there is an animation already in progress, we end it.
    */
    endAnimation: function() {
      if( !SC.none( this.animationTimer))
        this.animationTimer.set('isPaused', YES);
      if( this.get('isAnimating')) {
        this.changeValues( 1);  // Finish the animation
        this.set('isAnimating', false);
      }
    }

  } );

/* >>>>>>>>>> BEGIN source/utilities/close-component.js */
DG.closeComponent = function (iComponentID) {
    var tState;

    // Give the controller a chance to do some housekeeping before we close it (defocus, commit edits, etc.).
    // Also, do this outside of the undo command, so that it can register its own
    // separate undo command if desired.
    var tController = DG.currDocumentController().componentControllersMap[iComponentID];
    if (!tController) return;
    tController.willCloseComponent();

    DG.UndoHistory.execute(DG.Command.create({
      name: 'component.close',
      undoString: 'DG.Undo.component.close',
      redoString: 'DG.Redo.component.close',
      _componentId: iComponentID,
      _controller: function() {
        return DG.currDocumentController().componentControllersMap[this._componentId];
      },
      _model: null,
      execute: function() {
        tController = this._controller();
        var tComponentView = tController.get('view'),
            tContainerView = tComponentView.get('parentView');

        this.log = 'closeComponent: %@'.fmt(tComponentView.get('title'));
        this._model = tController.get('model');

        // Some components (the graph in particular), won't restore correctly without calling willSaveComponent(),
        // because sometimes not all of the info necessary to restore the view is actively held in the model.
        // (In the graph's case, there is 'model' which relates to the view, and 'graphModel' which holds all of the
        // configuration like axis ranges, legends, etc.)
        tController.willSaveComponent();

        if (tController.saveGameState) {
          // If we are a GameController, try to save state.
          // Since this is an asynchronous operation, we have to hold off closing the component
          // until it is complete (or it will fail).
          // Also, since closing the document will happen after this command executes, dirtying the
          // document will clear the undo history, so we must force it not to dirty.
          tController.saveGameState(function(result) {
            if (result && result.success) {
              tState = result.state || result.values;
            }
            SC.run(function () {
              tContainerView.removeComponentView( tComponentView);
            });
          });
        } else {
          tContainerView.removeComponentView( tComponentView);
        }
        DG.currDocumentController().notificationManager.sendNotification({
          action: 'notify',
          resource: 'component',
          values: {
            operation: 'delete',
            type: tController.getPath('model.type'),
            id: tController.getPath('model.id'),
            name: tController.getPath('model.name'),
            title: tController.getPath('model.title')
          }
        });
      },
      undo: function() {
        DG.currDocumentController().createComponentAndView(this._model);

        tController = this._controller();
        if (tController.restoreGameState && tState) {
          tController.restoreGameState({gameState: tState});
        }
      }
    }));
  };

/* >>>>>>>>>> BEGIN source/utilities/color_utilities.js */
// ==========================================================================
//  DG.ColorUtilities
//
//  TinkerPlots-style color gradient and color transformation utility functions.
//  Ported from the TinkerPlots C++ source code.
//
//  Author:   Craig D. Miller
//
//  Copyright ©2011-13 Scientific Reasoning Research Institute,
//                  University of Massachusetts Amherst
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/* global tinycolor */

/**
 @namespace Color gradient and color transformation utility functions
 */
DG.ColorUtilities = {
  // color modifiers for categorical gradients
  // probably best imbedded in a gradient function.
  kStartingHue: (2.0 / 3.0),      // shift hue so starting variable is blue
  kCatHueSpread: 0.8,          // Spread of hue for values of categorical variable. 1.0=entire rainbow
  kCatSaturation: (2.0 / 3.0),      // Categorical data: partial saturation fades colors so they look better
  kCatBrightness: 1.0,          // Categorical data: partial brightness fades colors so they look better
  kBrightnessDampenFactor: 1.0,    // dampen partially (1.0 = darker)
  kStandardMacGammaCorrection: (1 / 1.8),  // Finish partially-corrected MacOS gamma
  kStandardWinGammaCorrection: (1 / 2.5),  // assume uncorrected gamma

  // Photoshop "K" color values for Red, Yellow, Green, Aqua, Blue, Magenta
  // (hues 0,60,120,180,240,300,360; brightness & Saturation 100%)
  kBrightnessTable: [0.54, 0.05, 0.20, 0.15, 0.75, 0.46],
  kBrightnessTableMaxK: 0.75,  // Blue is darkest

  // standard colors
  kNoAttribCaseColor: '#A6CAF0',    //tp_CColor tp_CColorGradient::kNoVarCaseColor = kcp_kSkyBlueColor;
  //kNoAttribCaseSelectedColor : { colorString: 'red' } //tp_CColor tp_CColorGradient::kNoVarCaseSelectedColor = kcp_kRedColor;
  //kNoAttribFocusedCaseColor : { colorString: 'yellow' } // tp_CColor tp_CColorGradient::kNoVarFocusedCaseColor  = kcp_kYellowColor;
  kMissingValueCaseColor: '#A0A0A0', //tp_CColor tp_CColorGradient::kMissingValueCaseColor = kcp_kDarkGrayColor;
  kMapMissingValueCaseColor: '#ffffff01', //tp_CColor tp_CColorGradient::kMissingValueCaseColor = kcp_kDarkGrayColor;
  // kDefaultBorderColor: {colorString: 'black'},     // tp_CColor tp_CColorGradient::kDefaultBorderColor = kcp_kBlackColor;
  // tp_CColor tp_CColorGradient::kHasVarFocusedCaseBorderColor = kcp_kBlueColor;

  /*
   The following list of 20 colors are maximally visually distinct from each other.
   See http://eleanormaclure.files.wordpress.com/2011/03/colour-coding.pdf
   and https://stackoverflow.com/questions/470690/how-to-automatically-generate-n-distinct-colors

   The first seven are also visually distinct for people with defective color vision
    */
  kKellyColors: [
      '#FF6800', '#803E75', '#A6BDD7', '#FFB300',
      '#C10020', '#CEA262', '#817066', '#007D34',
      '#00538A', '#F13A13', '#53377A', '#FF8E00',
      '#B32851', '#F4C800', '#7F180D', '#93AA00',
      '#593315', '#232C16', '#FF7A5C', '#F6768E'
    ],


  /** Color class for use with Rafael view objects.
   @constructor
   */
  Color: function () {
    return {colorString: ""};    // {string} Rafael-compatible color value
  },

  /** rgbColor class for colors with a Red/Green/Blue color model for color manipulation.
   @constructor
   @extends DG.ColorUtilities.Color
   */
  rgbColor: function () {
    return {
      colorString: "",   // {string} Rafael-compatible color value
      r: 1, g: 1, b: 1 // {number} Red, Green, Blue color components in range [0-1] (black to white)
    };
  },

  isRGB: function( iColor) {
    return iColor && !SC.none(iColor.r) && !SC.none(iColor.g) && !SC.none(iColor.b);
  },

  /**
   * Used to validate color specification for a 'legend' that colors points by the attribute value.
   * We only allow this for rgb and hex specification of color. We disallow normal color words like 'red'
   * and 'blue' because they will occur frequently at places we don't wish to color points.
   * @param iColorString
   * @returns {boolean|*|null}
   */
  isColorSpecString: function( iValue) {
    if (!this._isColorRegex) {
      var tExp = '^(?:' + 'DG.Utilities.colorPattern'.loc() + ')$';
      this._isColorRegex = new RegExp(tExp, 'i');
    }
    return (typeof iValue === 'string' &&
              this._isColorRegex.test(iValue.toLowerCase().replace(/\s/g,'')));
  },

  /** hsbColor class for colors with Hue/Saturation/Brightness color model for color manipulation.
   @constructor
   @extends DG.ColorUtilities.Color
   */
  hsbColor: function () {
    return {
      colorString: "",   // {string} Rafael-compatible color value
      h: 1, s: 1, b: 1 // {number} Hue, Saturation, Brightness color components in range [0-1]
    };
  },

  isHSB: function( iColor) {
    return iColor && !SC.none(iColor.h) && !SC.none(iColor.s) && !SC.none(iColor.b);
  },

  /* --------- Notes on updating of DG case icon colors.

    if color attribute value has changed and...
    numeric value change => attribute stats range change ? update all case colors : update 1 case color
    category value change => attribute category list change ? update all case colors : update 1 case color

    if color attribute is in use and...
    if attribute inserted or deleted => update all attribute colors => update all case colors.

    ----------- */

  /**
   * calcAttributeColorFromIndex()
   *      Return a kelly color based on the given attribute index.
   * @param {number} attribIndex : 0+ integer
   * @param {number} attribCount : 1+ integer
   * @returns {string}
   */
  calcAttributeColorFromIndex: function (attribIndex, attribCount) {
    if( attribIndex === 0)
      return DG.PlotUtilities.kDefaultPointColor;
    else if(attribIndex < 0 || attribIndex >= attribCount)
      return this.kNoAttribCaseColor;
    else
      return this.kKellyColors[attribIndex % this.kKellyColors.length];
/*
    var tHue = attribIndex / attribCount;  // get hue in range [0.0-1.0]
    tHue += DG.ColorUtilities.kStartingHue;      // shift hue so starting variable is blue
    tHue -= Math.floor(tHue);      // convert back to range [0 - 1]
    var tSaturation = 1.0;
    var tBrightness = DG.ColorUtilities.dampenBrightnessByHue(1.0, tHue, DG.ColorUtilities.kBrightnessDampenFactor);
    var tAttribColor = DG.ColorUtilities.hsb_to_PlatformColor(tHue, tSaturation, tBrightness);
    return tAttribColor;
*/
  },

  /**
   * calcAttributeColor()
   *      Calculate the color assigned to a variable in a dataset, using
   *      the color attribute description.
   * @param {DG.AttributePlacementDescription} iColorAttributeDescription
   * @returns {string}
   */
  calcAttributeColor: function (iColorAttributeDescription) {

    // get the stored attribute color
    var tCollectionClient = iColorAttributeDescription.get('collectionClient'),
        tAttribute = iColorAttributeDescription.get('attribute'),
        tCategoryMap = tAttribute && tAttribute.get('categoryMap'),
        tColor = DG.ColorUtilities.getAttributeColorFromColorMap(tCategoryMap);

    // else compute the color from the attribute's position in the collection
    if (!tColor) {
      DG.assert(tAttribute !== DG.Analysis.kNullAttribute);
      var tAttributeName = tAttribute.get('name'),
          tAttributeIndex = tCollectionClient.getAttributeIndexByName(tAttributeName),
          tAttributeCount = tCollectionClient.getAttributeCount();
      tColor = DG.ColorUtilities.calcAttributeColorFromIndex(tAttributeIndex, tAttributeCount);
    }

    return tColor;
  },

  /***************************************************************************
   * calcCaseColor()
   *      Calculate a case color from the case value and color attribute
   *      description.
   * @param iCaseValue {number or string or null}
   * @param {DG.AttributePlacementDescription} iColorAttributeDescription
   * @param {DG.ColorUtilities.Color} Color to be used if there is no color attribute
   * @returns {DG.ColorUtilities.Color}
   */
  calcCaseColor: function (iCaseValue, iColorAttributeDescription, iNoAttrColor, iQuantileValues) {

    // TODO: store common parameters such as attribute color so we don't need to recalc for every case.
    var newColor = null,
        tAttribute = iColorAttributeDescription.get('attribute'),
        tAttributeColor = tAttribute && DG.ColorUtilities.calcAttributeColor(iColorAttributeDescription);

    if (tAttribute === DG.Analysis.kNullAttribute) {
      newColor = iNoAttrColor || DG.ColorUtilities.kNoAttribCaseColor;
    } else if (SC.empty(iCaseValue)) {
      newColor = DG.ColorUtilities.kMissingValueCaseColor;
    } else {
      // we have an attribute and non-missing case value, now get stored or computed color
      var tAttributeType = iColorAttributeDescription.get('attributeType'),
          tIsNumeric = iColorAttributeDescription.get('isNumeric'),
          tCategoryMap = tAttribute.get('categoryMap');
      switch (tAttributeType) {
        case DG.Analysis.EAttributeType.eCategorical:
          // get color from attribute's color map, or set to null
          newColor = DG.ColorUtilities.getCategoryColorFromColorMap(tCategoryMap, iCaseValue);
          break;
        case DG.Analysis.EAttributeType.eColor:
          var tCaseColor = tinycolor(iCaseValue);
          if (tCaseColor.isValid())
            newColor = tCaseColor.toString();
          break;
        case DG.Analysis.EAttributeType.eNumeric:
        case DG.Analysis.EAttributeType.eDateTime:
          if (SC.isArray(iQuantileValues)) {
            var tFoundIndex = -1,
                tNumQuantiles = iQuantileValues.length - 1,
                tMinMax = {min: 0, max: 1},
                tSpectrumEnds = this.getAttributeColorSpectrumEndsFromColorMap(tCategoryMap, tAttributeColor);
            iQuantileValues.forEach(function (iQV, iIndex) {
              if (iIndex < tNumQuantiles) {
                if (iQV <= iCaseValue && iCaseValue < iQuantileValues[iIndex + 1])
                  tFoundIndex = iIndex;
              }
            });
            if( tFoundIndex >= 0)
              newColor = this.calcGradientColor(tMinMax, tSpectrumEnds.low, tSpectrumEnds.high, (tFoundIndex + 1) / tNumQuantiles);
            else
              newColor = DG.ColorUtilities.kMissingValueCaseColor;
          }
          break;
      }
      if (!newColor) {
        // calculate color using TinkerPlots color-space algorithm
        newColor = tIsNumeric ?
            DG.ColorUtilities.calcContinuousColor(
                iColorAttributeDescription.get('minMax'), tAttributeColor, iCaseValue) :
            DG.ColorUtilities.calcCategoryColor(
                iColorAttributeDescription.get('attributeStats'), tAttributeColor, iCaseValue);
      }
    }
    return newColor;
  },

  /**
   * @param iColorMap  {} object with category values as keys, color string as values.
   * @param iCaseValue  {number or string or null}
   * @returns {DG.ColorUtilities.Color}
   */
  getCategoryColorFromColorMap: function (iColorMap, iCaseValue) {
    if (iColorMap) {
      var tColorValue = iColorMap[iCaseValue] || '#000000';
      if (typeof tColorValue === 'string') {
        tColorValue = {colorString: tColorValue};    // {string} Rafael-compatible color value
      }
      return tColorValue;
    }
    return null;
  },

  /**
   * @param iColorMap  {} object with 'attribute-color' as the color key (see below).
   * @returns {DG.ColorUtilities.Color}
   */
  getAttributeColorFromColorMap: function (iColorMap) {
    if (iColorMap) {
      var tColorValue = iColorMap['attribute-color'];
      if (typeof tColorValue === 'string') {
        return DG.ColorUtilities.rgbColorString_to_PlatformColor(tColorValue, true);    // {string} Rafael-compatible color value, with HSB components
      }
    }
    return null;
  },

  /**
   * @param iColorMap  {} object with 'stroke-color' as the color key (see below).
   * @returns {DG.ColorUtilities.Color}
   */
  getStrokeColorFromColorMap: function (iColorMap) {
    return iColorMap ? iColorMap['stroke-color'] : null;
  },

  /**
   * @param iColorMap  {} object with 'attribute-color' as the color key (see below).
   * @returns {DG.ColorUtilities.Color}
   */
  getAttributeColorSpectrumEndsFromColorMap: function (iColorMap, iAttrColor) {
    var tEnds = {},
        tLow, tHigh;
    if (iColorMap) {
      tLow = iColorMap['low-attribute-color'] || 'rgb(255,255,255)';
      tHigh = iColorMap['high-attribute-color'] || iColorMap['attribute-color'] || iAttrColor;
      if (typeof tLow === 'string') {
        tLow = DG.ColorUtilities.rgbColorString_to_PlatformColor(tLow);
      }
      if (typeof tHigh === 'string') {
        tHigh = DG.ColorUtilities.rgbColorString_to_PlatformColor(tHigh);
      }
      else if(this.isHSB( tHigh))
      {
        tHigh = Raphael.hsb2rgb( tHigh.h, tHigh.s, tHigh.b);
        tHigh.colorString = tHigh.colorString || 'rgb(%@,%@,%@)'.fmt(tHigh.r, tHigh.g, tHigh.b);
        tHigh.r /= 255;
        tHigh.g /= 255;
        tHigh.b /= 255;
      }
      tEnds = {low: tLow, high: tHigh};
    }
    return tEnds;
  },

  /**
   * calcContinuousColor()
   *      Calculate the icon fill color for this numeric value of a continuous
   *      variable.  Creates a gradient from white for the lowest numeric value,
   *      to the attribute color for the highest numeric value. Returns the
   *      missing value color for any non-numeric case values.
   * @param {DG.AttributeStats} iMinMax
   * @param {DG.ColorUtilities.hsbColor} iAttributeColor
   * @param iCaseValue
   * @returns {DG.ColorUtilities.Color}
   */
  calcContinuousColor: function (iMinMax, iAttributeColor, iCaseValue) {

    var tCaseColor = DG.ColorUtilities.kMissingValueCaseColor,
        tRange = iMinMax.max - iMinMax.min,
        tHue = iAttributeColor.h,  // break color into components
        tSaturation = iAttributeColor.s,
        tBrightness = iAttributeColor.b,
        tScale;

    // if we have a valid numeric range and case value along that range
    if (DG.isFinite(tRange) && DG.isFinite(iCaseValue)) {
      //KCP_ASSERT( Compare::inRange( iCaseValue, iVarStats.GetMin(), iVarStats.GetMax() ));
      // adjust saturation and brightness along gradient
      tScale = (tRange > 0) ? ((iCaseValue - iMinMax.min) / tRange) : 1;
      tSaturation *= tScale;
      tBrightness = DG.ColorUtilities.gammaCorrect(1.0 - ((1.0 - tBrightness) * tScale));
      tCaseColor = DG.ColorUtilities.hsb_to_PlatformColor(tHue, tSaturation, tBrightness);
    }
    return tCaseColor;
  },

  /**
   * calcGradientColor()
   *      Calculate the icon fill color for this numeric value of a continuous
   *      variable.  Creates a gradient from iColor1 for the lowest numeric value,
   *      to iColor2 for the highest numeric value. Returns the
   *      missing value color for any non-numeric case values.
   * @param {DG.AttributeStats} iMinMax
   * @param {DG.ColorUtilities.rgbColor} iColor1
   * @param {DG.ColorUtilities.rgbColor} iColor2
   * @param iCaseValue
   * @returns {DG.ColorUtilities.Color}
   */
  calcGradientColor: function (iMinMax, iColor1, iColor2, iCaseValue) {
    var tCaseColor = DG.ColorUtilities.kMissingValueCaseColor,
        tRange = iMinMax.max - iMinMax.min;
    // if we have a valid numeric range and case value along that range
    // Todo: consider interpolating with hsb instead of rgb
    if (DG.isFinite(tRange) && DG.isFinite(iCaseValue) && this.isRGB( iColor1) && this.isRGB( iColor2)) {
      var tScale = Math.max( 0, Math.min( 1, (iCaseValue - iMinMax.min) / tRange)),
          tRed = iColor1.r + tScale * (iColor2.r - iColor1.r),
          tGreen = iColor1.g + tScale * (iColor2.g - iColor1.g),
          tBlue = iColor1.b + tScale * (iColor2.b - iColor1.b);
      tCaseColor = DG.ColorUtilities.rgb_to_PlatformColor(tRed, tGreen, tBlue);
    }
    return tCaseColor;
  },

  /**
   * CalcCategoryColor()
   *      Calculate the icon fill color for this category value of a categorical
   *      variable.  Creates a gradient of hues, one per category value.
   *      Returns the missing value color for any non-numeric case values.
   * @param {DG.AttributeStats} iAttributeStats
   * @param {DG.ColorUtilities.hsbColor} iAttributeColor
   * @param iCaseValue
   * @returns {DG.ColorUtilities.Color}
   */
  calcCategoryColor: function (iAttributeStats, iAttributeColor, iCaseValue) {
    var tCategoryIndex = iAttributeStats.cellNameToCellNumber(iCaseValue),
        tNumColors = DG.ColorUtilities.kKellyColors.length;
    return { colorString: DG.ColorUtilities.kKellyColors[ tCategoryIndex % tNumColors] };
  },

  /**
   * hsb_to_PlatformColor()
   *      convert a color in Hue, Saturation, Brightness (HSB) color space, range [0-1],
   *      to a Rafael-compatible color value.
   *
   *      Note: we are using hsb_to_rgb() for color conversions instead of the Rafael "hsb()"
   *      colorString, to give the same colors as TinkerPlots, because Rafael's color conversions
   *      are slightly different, and thus hard to compare and verify.
   * @param tHue
   * @param tSaturation
   * @param tBrightness
   * @returns {DG.ColorUtilities.hsbColor}
   */
  hsb_to_PlatformColor: function (tHue, tSaturation, tBrightness) {

    return {
      h: tHue,
      s: tSaturation,
      b: tBrightness,
      //colorString : ("hsb(" + tHue + "," + tSaturation + "," + tBrightness + ")")
      colorString: DG.ColorUtilities.hsb_to_rgb(tHue, tSaturation, tBrightness)
    };
  },

  /**
   * rgb_to_PlatformColor()
   *      convert a color in Red, Green, Blue (RGB) color space, range [0-1],
   *      to a Rafael/SVG-compatible color string (rgb values in range [0-255].
   * @param red
   * @param green
   * @param blue
   * @returns {string} Rafael-compatible RGB color string.
   */
  rgb_to_PlatformColor: function (red, green, blue) {
    // note: although SVG 'Interface RGBColor' says float is OK, not all libraries work
    // correctly unless values are integer. (E.g. Leaflet)

    return this.rgb_to_hex( red, green, blue);
  },

  /**
   * rgb_to_hex()
   *      convert a color in Red, Green, Blue (RGB) color space, range [0-1],
   *      to a hex string.
   * @param red
   * @param green
   * @param blue
   * @returns {string} #hhhhhh
   */
  rgb_to_hex: function (red, green, blue) {

    function componentToHex(c) {
      var hex = (Math.round( c * 255)).toString(16);
      return hex.length === 1 ? "0" + hex : hex;
    }

    return "#" + componentToHex(red) + componentToHex(green) + componentToHex(blue);
  },

  /**
   * hsb_to_rgb()
   *      Converts from Hue, Saturation, and Value color representation
   *      to Red, Green, Blue color representation.  From Foley & Van Dam, page 616.
   * @param {number} hue           number in range [0-1]
   * @param {number} saturation    number in range [0-1]
   * @param {number} brightness    number in range [0-1]
   * @returns {string} Rafael-compatible RGB color string.
   */
  hsb_to_rgb: function (hue, saturation, brightness) {
    var i,        // int
        f, p, q, t,    // float
        tPlatformColor; // color string

    if (saturation === 0) {
      tPlatformColor = DG.ColorUtilities.rgb_to_PlatformColor(brightness, brightness, brightness);
    }
    else {
      f = (hue >= 1.0) ? 0 : (hue * 6.0);
      i = Math.floor(f);
      f = f - i;    // fractional part of hue
      p = brightness * (1 - saturation);
      q = brightness * (1 - (saturation * f));
      t = brightness * (1 - (saturation * (1 - f)));

      switch (i) {
        case 0:
          tPlatformColor = DG.ColorUtilities.rgb_to_PlatformColor(brightness, t, p);
          break;
        case 1:
          tPlatformColor = DG.ColorUtilities.rgb_to_PlatformColor(q, brightness, p);
          break;
        case 2:
          tPlatformColor = DG.ColorUtilities.rgb_to_PlatformColor(p, brightness, t);
          break;
        case 3:
          tPlatformColor = DG.ColorUtilities.rgb_to_PlatformColor(p, q, brightness);
          break;
        case 4:
          tPlatformColor = DG.ColorUtilities.rgb_to_PlatformColor(t, p, brightness);
          break;
        case 5:
          tPlatformColor = DG.ColorUtilities.rgb_to_PlatformColor(brightness, p, q);
          break;
      }
    }
    return tPlatformColor;
  },

  /**
   * gammaCorrect()
   *      Adjusts gradient from black (0.0) to white (1.0) with
   *      a power function to compensate for non-linear brightness
   *      of monitors.  Standard monitor gamma correction value is 1 / 2.5,
   *      MacOS provides partial gamma correction of 1 / 1.4, requiring
   *      an addition gamma of 1 / 1.8.
   * @param {number} value in range [0-1]
   * @returns {number} corrected value in range [0-1]
   */
  gammaCorrect: function (value) {
    return Math.pow(value, DG.ColorUtilities.kStandardMacGammaCorrection);
  },

  /**
   * dampenBrightnessByHue()

   Dampen the brightness of a color to make different hues more uniform
   in perceived color.  For example blues (hue = 0.6) at full brightness
   (1.0) are much darker than yellows, so we dampen the brightness of
   yellows to make color gradients across the hues more uniform
   (we can't make blue brighter). Similarly, all hues are dampened in
   proportion to the relative brightness of the darkest hue.

   Because color dampening produces muddy (dark) colors, the caller can
   pass in a dampen factor in range [0.0 - 1.0] to reduce the dampening effect.
   0 = no dampening, 1 = 100% of table values, 0.75 = 75% dampening.

   * @param {number} iOldBrightness
   * @param {number} iConstHue
   * @param {number} iDampenFactor
   */
  dampenBrightnessByHue: function (iOldBrightness, iConstHue, iDampenFactor) {

    // get nearest values in brightness table
    var kBrightnessTable = DG.ColorUtilities.kBrightnessTable,
        kMaxK = DG.ColorUtilities.kBrightnessTableMaxK,
        kTableSize = kBrightnessTable.length,
        tHueIndex = iConstHue * kTableSize,
        tLower = Math.floor(tHueIndex),
        tUpper = Math.ceil(tHueIndex),
        tLowerFraction = (tLower < tUpper) ? tUpper - tHueIndex : 1.0,
        tUpperFraction = tHueIndex - tLower,
        tKValue,
        tDampenFraction;

    tLower = tLower % kTableSize; // probably not needed
    tUpper = tUpper % kTableSize; // upper can wrap around to zero (colors are in a circle).
    //KCP_ASSERT( Compare::inRange( tLower, kTableSize ));
    //KCP_ASSERT( Compare::inRange( tUpper, kTableSize ));
    //KCP_ASSERT( Compare::close( tLowerFraction + tUpperFraction, 1.0 ));

    // interpolate between K values
    tKValue = kBrightnessTable[tLower] * tLowerFraction + kBrightnessTable[tUpper] * tUpperFraction;

    // convert to amount to dampen (zero for darkest hue)
    tDampenFraction = 1 - (( kMaxK - tKValue ) * iDampenFactor);

    return ( iOldBrightness * tDampenFraction );
  },

  /**
   *
   * Return a color string representing a color darker than the given one where iFactor
   * determines the amount of darkening.
   *
   * @param iColor {String}
   * @param iFactor {Number}
   * @return {String}
   */

  darker: function (iColorString, iFactor) {
//  tStrokeColor = DG.color(iColorString).darker(DG.PlotUtilities.kStrokeDarkerFactor ).color;
    var tColor = DG.color(iColorString).darker(iFactor).color;
    return tColor;
  },

  /**
   * Convert an SVC/Rafael color string to a DG color object.
   * @param iColor
   * @param iWantHSB
   * @return {DG.ColorUtilities.rgbColor}  The color object with r,g,b components from [0-1], or optionally h,s,b components.
   *
   * NOTE: for now we use 'parseColor' to implement this:
   * parseColor
   * Copyright 2011 THEtheChad Elliott
   * Released under the MIT and GPL licenses.
   * Parse hex/rgb{a} color syntax.
   * from https://gist.github.com/1297590
   *
   * We have the option of using 'RGBColor':
   *   A class to parse color values
   *   author Stoyan Stefanov <sstoo@gmail.com>
   *   link   http://www.phpied.com/rgb-color-parser-in-javascript/
   *   license Use it if you like it
   *   Example use:
   * var color = new RGBColor('darkblue');
   if (color.ok) { // 'ok' is true when the parsing was a success
            // alert channels
            alert(color.r + ', ' + color.g + ', ' + color.b);
            // alert HEX and RGB
            alert(color.toHex());
            alert(color.toRGB());
        }
   *
   * BEST use SC.color when we update to Sproutcore 1.9
   * see http://docs.sproutcore.com/#doc=SC.Color&method=.KEYWORDS&src=false
   *
   */
  rgbColorString_to_PlatformColor: function (iColor, iWantHSB) {

    // Allow assignments as comparisons
    /* eslint no-cond-assign: "off" */
    /* jshint boss:true */

    // convert color name to hex color
    var cache,
        color = DG.ColorUtilities.colorNameToHexColor(iColor);

    // Checks for 6 digit hex and converts string to integer
    if (cache = /^#([\da-fA-F]{2})([\da-fA-F]{2})([\da-fA-F]{2})/.exec(color))
      cache = [parseInt(cache[1], 16), parseInt(cache[2], 16), parseInt(cache[3], 16)];

    // Checks for 3 digit hex and converts string to integer
    else if (cache = /^#([\da-fA-F])([\da-fA-F])([\da-fA-F])/.exec(color))
      cache = [parseInt(cache[1], 16) * 17, parseInt(cache[2], 16) * 17, parseInt(cache[3], 16) * 17];

    // Checks for rgba and converts string to
    // integer/float using unary + operator to save bytes
    else if (cache = /^rgba\(([\d]+),([\d]+),([\d]+),([\d]+|[\d]*.[\d]+)\)/.exec(color))
      cache = [+cache[1], +cache[2], +cache[3], +cache[4]];

    // Checks for rgb and converts string to
    // integer/float using unary + operator to save bytes
    else if (cache = /^rgb\(([\d]+),([\d]+),([\d]+)\)/.exec(color))
      cache = [+cache[1], +cache[2], +cache[3]];

    // Otherwise throw an exception to make debugging easier
    else throw new Error(color + ' is not supported by parseColor');

    // Performs RGBA conversion by default
    //if( isNaN(cache[3])) { cache[3] = 1; }
    // Adds or removes 4th value based on rgba support
    // Support is flipped twice to prevent erros if
    // it's not defined
    /* return cache.slice(0,3 + !!$.support.rgba); */

    // return new object with color components and original color string,
    // like hsb_to_PlatformColor()
    var newColor = {
      r: cache[0] / 255,
      g: cache[1] / 255,
      b: cache[2] / 255,
      colorString: iColor
    };
    if (iWantHSB) {
      var newHSB = Raphael.rgb2hsb(newColor.r, newColor.g, newColor.b);
      newColor.h = newHSB.h;
      newColor.s = newHSB.s;
      newColor.b = newHSB.b;
    }
    return newColor;
  },

  /**
   * Convert an SVC/Rafael color name to the equivalent hex color.
   *
   * Based on RGBColor() by Stoyan Stefanov <sstoo@gmail.com>
   * http://www.phpied.com/rgb-color-parser-in-javascript/
   *
   * @param color_string
   * @return {String} String of form #rrggbb, hex colors if match found.
   */
  colorNameToHexColor: function (color_string) {
    var tPrefix = '';
    // strip any leading #, remove spaces, make lower case
    if (color_string.charAt(0) === '#') { // remove # if any
      color_string = color_string.substr(1, 6);
      tPrefix = '#';
    }
    color_string = color_string.replace(/ /g, '');
    color_string = color_string.toLowerCase();

    // try simple matches
    if (DG.ColorUtilities.simpleColorNames.hasOwnProperty(color_string)) {
      color_string = DG.ColorUtilities.simpleColorNames[color_string];
      tPrefix = '#';
    }
    color_string = tPrefix + color_string; // add back in the prefix

    return color_string;
  },

  /**
   * SVG color names (compatible with rafael/css/w3c/svg),
   * from http://www.phpied.com/rgb-color-parser-in-javascript/
   * see also http://www.w3.org/TR/css3-color/#svg-color
   * @type {Object}
   */
  simpleColorNames: {
    aliceblue: 'f0f8ff',
    antiquewhite: 'faebd7',
    aqua: '00ffff',
    aquamarine: '7fffd4',
    azure: 'f0ffff',
    beige: 'f5f5dc',
    bisque: 'ffe4c4',
    black: '000000',
    blanchedalmond: 'ffebcd',
    blue: '0000ff',
    blueviolet: '8a2be2',
    brown: 'a52a2a',
    burlywood: 'deb887',
    cadetblue: '5f9ea0',
    chartreuse: '7fff00',
    chocolate: 'd2691e',
    coral: 'ff7f50',
    cornflowerblue: '6495ed',
    cornsilk: 'fff8dc',
    crimson: 'dc143c',
    cyan: '00ffff',
    darkblue: '00008b',
    darkcyan: '008b8b',
    darkgoldenrod: 'b8860b',
    darkgray: 'a9a9a9',
    darkgreen: '006400',
    darkkhaki: 'bdb76b',
    darkmagenta: '8b008b',
    darkolivegreen: '556b2f',
    darkorange: 'ff8c00',
    darkorchid: '9932cc',
    darkred: '8b0000',
    darksalmon: 'e9967a',
    darkseagreen: '8fbc8f',
    darkslateblue: '483d8b',
    darkslategray: '2f4f4f',
    darkturquoise: '00ced1',
    darkviolet: '9400d3',
    deeppink: 'ff1493',
    deepskyblue: '00bfff',
    dimgray: '696969',
    dodgerblue: '1e90ff',
    feldspar: 'd19275',
    firebrick: 'b22222',
    floralwhite: 'fffaf0',
    forestgreen: '228b22',
    fuchsia: 'ff00ff',
    gainsboro: 'dcdcdc',
    ghostwhite: 'f8f8ff',
    gold: 'ffd700',
    goldenrod: 'daa520',
    gray: '808080',
    green: '008000',
    greenyellow: 'adff2f',
    honeydew: 'f0fff0',
    hotpink: 'ff69b4',
    indianred: 'cd5c5c',
    indigo: '4b0082',
    ivory: 'fffff0',
    khaki: 'f0e68c',
    lavender: 'e6e6fa',
    lavenderblush: 'fff0f5',
    lawngreen: '7cfc00',
    lemonchiffon: 'fffacd',
    lightblue: 'add8e6',
    lightcoral: 'f08080',
    lightcyan: 'e0ffff',
    lightgoldenrodyellow: 'fafad2',
    lightgrey: 'd3d3d3',
    lightgreen: '90ee90',
    lightpink: 'ffb6c1',
    lightsalmon: 'ffa07a',
    lightseagreen: '20b2aa',
    lightskyblue: '87cefa',
    lightslateblue: '8470ff',
    lightslategray: '778899',
    lightsteelblue: 'b0c4de',
    lightyellow: 'ffffe0',
    lime: '00ff00',
    limegreen: '32cd32',
    linen: 'faf0e6',
    magenta: 'ff00ff',
    maroon: '800000',
    mediumaquamarine: '66cdaa',
    mediumblue: '0000cd',
    mediumorchid: 'ba55d3',
    mediumpurple: '9370d8',
    mediumseagreen: '3cb371',
    mediumslateblue: '7b68ee',
    mediumspringgreen: '00fa9a',
    mediumturquoise: '48d1cc',
    mediumvioletred: 'c71585',
    midnightblue: '191970',
    mintcream: 'f5fffa',
    mistyrose: 'ffe4e1',
    moccasin: 'ffe4b5',
    navajowhite: 'ffdead',
    navy: '000080',
    oldlace: 'fdf5e6',
    olive: '808000',
    olivedrab: '6b8e23',
    orange: 'ffa500',
    orangered: 'ff4500',
    orchid: 'da70d6',
    palegoldenrod: 'eee8aa',
    palegreen: '98fb98',
    paleturquoise: 'afeeee',
    palevioletred: 'd87093',
    papayawhip: 'ffefd5',
    peachpuff: 'ffdab9',
    peru: 'cd853f',
    pink: 'ffc0cb',
    plum: 'dda0dd',
    powderblue: 'b0e0e6',
    purple: '800080',
    red: 'ff0000',
    rosybrown: 'bc8f8f',
    royalblue: '4169e1',
    saddlebrown: '8b4513',
    salmon: 'fa8072',
    sandybrown: 'f4a460',
    seagreen: '2e8b57',
    seashell: 'fff5ee',
    sienna: 'a0522d',
    silver: 'c0c0c0',
    skyblue: '87ceeb',
    slateblue: '6a5acd',
    slategray: '708090',
    snow: 'fffafa',
    springgreen: '00ff7f',
    steelblue: '4682b4',
    tan: 'd2b48c',
    teal: '008080',
    thistle: 'd8bfd8',
    tomato: 'ff6347',
    turquoise: '40e0d0',
    violet: 'ee82ee',
    violetred: 'd02090',
    wheat: 'f5deb3',
    white: 'ffffff',
    whitesmoke: 'f5f5f5',
    yellow: 'ffff00',
    yellowgreen: '9acd32'
  }
};

DG.isColorSpecString = DG.ColorUtilities.isColorSpecString;

/* >>>>>>>>>> BEGIN source/utilities/data_context_utilities.js */
// ==========================================================================
//                          DG.DataContextUtilities
//
//  Author:   William Finzer
//
//  Copyright (c) 2018 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/*global pluralize:true*/

DG.DataContextUtilities = {

  isTopLevelReorgPrevented: function (iDataContext) {
    var pluginController = iDataContext.get('managingController');
    return !!pluginController && pluginController.get('preventTopLevelReorg');
  },

  getNonTopLevelAttributeCount: function (iDataContext) {
    var attrCount = 0;
    var collections = iDataContext.get('collections');
    collections.forEach(function (collection, index) {
      if (index > 0) {
        attrCount += collection.getPath('attrs.length');
      }
    });
    return attrCount;
  },

  isAttributeDeletable: function (iDataContext, iAttribute) {
    if (!iAttribute.get('deleteable')) return false;

    var pluginController = iDataContext.get('managingController');
    var pluginPreventsTopLevelReorg = !!pluginController &&
        pluginController.get('preventTopLevelReorg');
    var isTopLevelAttribute = !iAttribute.getPath('collection.parent');
    var nonTopLevelAttributeCount = DG.DataContextUtilities.getNonTopLevelAttributeCount(iDataContext);
    var isLastNonTopLevelAttribute = !isTopLevelAttribute && (nonTopLevelAttributeCount === 1);
    if (pluginPreventsTopLevelReorg && isLastNonTopLevelAttribute) return false;

    var pluginPreventsAttributeDeletion = !!pluginController &&
        pluginController.get('preventAttributeDeletion');
    var pluginAllowsEmptyAttributeDeletion = !!pluginController &&
        pluginController.get('allowEmptyAttributeDeletion');
    var hasAttributeFormula = iAttribute.get('hasFormula');
    var hasAttributeValues = !hasAttributeFormula && iAttribute.get('hasValues');
    var isEmptyAttribute = !hasAttributeFormula && !hasAttributeValues;
    return !pluginPreventsAttributeDeletion ||
        (pluginAllowsEmptyAttributeDeletion && isEmptyAttribute);
  },

  /**
   * Returns false if the owning plugin disables editing of the case, true otherwise.
   * @param {DG.DataContext} iDataContext
   * @param {string} itemID
   */
  isCaseEditable: function (iDataContext, iCase) {
    // we don't disable rows that don't correspond to cases, e.g. proto-case rows
    if (!iCase) return true;
    // is the plugin controlling editability?
    var pluginController = iDataContext.get('managingController');
    var pluginRespectsEditableAttribute = pluginController && pluginController.get('respectEditableItemAttribute');
    if (!pluginRespectsEditableAttribute) return true;
    // do we have an __editable__ attribute?
    var editableAttrRef = iDataContext.getAttrRefByName('__editable__');
    var editableAttr = editableAttrRef && editableAttrRef.attribute;
    if (!editableAttr) return true;
    // does it have a formula?
    if (!editableAttr.get('hasFormula')) {
      // no formula -- look up its item value
      var dataSet = iDataContext.getPath('model.dataSet');
      var itemIndex = dataSet && dataSet.getDataItemClientIndexByID(iCase.item.id);
      return !!(dataSet && (itemIndex != null) && dataSet.value(itemIndex, editableAttr.id));
    }
    // evaluate formula in context of appropriate case
    for (var aCase = iCase; aCase; aCase = aCase.get('parent')) {
      if (aCase.getPath('collection.id') === editableAttrRef.collection.get('id')) {
        var isEditable = editableAttr.evalFormula(aCase);
        return !!isEditable;
      }
    }
    return true;
  },

  /**
   * Drop is disabled if any of the following are true
   *   (a) the dataContext prevents the drop
   *   (b) the dragged attribute is from another dataContext,
   *   (c) the plugin prevents the drop
   *
   * @param iDataContext    {DG.DataContext} The DataContext receiving the drop
   * @param iAttribute      {DG.Attribute} The attribute being dragged
   * @param isTopLevelDrop  {Boolean} Whether the proposed drop target is top-level
   * @param allowTopLevelAttrs {Boolean} Whether to allow drops of top-level attrs,
   *                        which could indicate a desire to rearrange top-level attrs
   *                        without changing the collection hierarchy.
   * @returns {Boolean}   Whether the drop should be accepted
   */
  canAcceptAttributeDrop: function (iDataContext, iAttribute, isTopLevelDrop, allowTopLevelAttrs) {
    // check whether DataContext prevents reorganization
    if (iDataContext.get('hasGameInteractive') || iDataContext.get('preventReorg'))
      return false;

    // we can't reorganize drops of attributes from another DataContext
    var ownsThisAttribute = iAttribute &&
        !SC.none(iDataContext.getCollectionByID(iAttribute.collection.id));
    if (!ownsThisAttribute) return false;

    // check whether plugin prevents all reorganization
    var pluginController = iDataContext.get('managingController');
    if (pluginController && pluginController.get('preventDataContextReorg'))
      return false;

    // check whether plugin prevents top-level reorganization
    var pluginPreventsTopLevelReorg = pluginController &&
        pluginController.get('preventTopLevelReorg');
    var isTopLevelDragAttr = iAttribute && !iAttribute.getPath('collection.parent');
    if (pluginPreventsTopLevelReorg) {
      if (isTopLevelDragAttr && isTopLevelDrop && allowTopLevelAttrs)
        return true;
      if (isTopLevelDragAttr || isTopLevelDrop)
        return false;
    }

    // otherwise, we accept the drop
    return true;
  },

  updateAttribute: function (iContext, iCollection, iAttribute, iChangedAttrProps) {
    var newAttrName = iChangedAttrProps.name;
    if (newAttrName) {
      newAttrName = iContext.getUniqueAttributeName(newAttrName, [iAttribute.name]);
      iChangedAttrProps.name = newAttrName;
    }

    var tOldAttrProps = {
      id: iAttribute.get('id'),
      name: iAttribute.get('name'),
      type: iAttribute.get('type'),
      cid: iAttribute.get('cid'),
      unit: iAttribute.get('unit'),
      editable: iAttribute.get('editable'),
      precision: iAttribute.get('precision'),
      description: iAttribute.get('description'),
    };
    DG.UndoHistory.execute(DG.Command.create({
      name: "caseTable.editAttribute",
      undoString: 'DG.Undo.caseTable.editAttribute',
      redoString: 'DG.Redo.caseTable.editAttribute',
      log: 'Edit attribute "%@"'.fmt(iChangedAttrProps.name),
      execute: function () {
        var change = {
          operation: 'updateAttributes',
          collection: iCollection,
          attrPropsArray: [Object.assign({id: iAttribute.get('id')}, iChangedAttrProps)]
        };
        iContext.applyChange(change);
      },
      undo: function () {
        var change = {
          operation: 'updateAttributes',
          collection: iCollection,
          attrPropsArray: [tOldAttrProps]
        };
        iContext.applyChange(change);
      },
      redo: function () {
        this.execute();
      }
    }));
  },

  editAttributeFormula: function (iDataContext, iCollection, iAttrName, iAttrFormula) {
    iAttrName = iAttrName || '';
    iAttrFormula = iAttrFormula || '';
    var tCollClient = iDataContext.getCollectionByID(iCollection.get('id')),
        tResult = DG.AttributeFormulaView.buildOperandsMenuAndCompletionData(iDataContext),

        tApplier = SC.Object.create({
          applyFormula: function () {
            var tRef = iDataContext.getAttrRefByName(iAttrName),
                tAttrFormula = tRef && tRef.attribute.get('formula');
            // Retrieve the name of the target collection that was passed by the client originally.
            var tCollection = tEditFormulaDialog.get('collection'),
                tFormula = tEditFormulaDialog.get('formula');

            DG.UndoHistory.execute(DG.Command.create({
              name: "caseTable.editAttributeFormula",
              undoString: 'DG.Undo.caseTable.editAttributeFormula',
              redoString: 'DG.Redo.caseTable.editAttributeFormula',
              execute: function () {
                tRef = iDataContext.getAttrRefByName(iAttrName);
                var tChange = {
                      operation: 'createAttributes',
                      collection: tCollection,
                      attrPropsArray: [{name: iAttrName, formula: tFormula}]
                    },
                    tResult = iDataContext && iDataContext.applyChange(tChange);
                if (tResult.success) {
                  var action = "attributeEditFormula";
                  this.log = "%@: { name: '%@', collection: '%@', formula: '%@' }".fmt(
                      action, iAttrName, tCollection.get('name'), tFormula);
                } else {
                  this.set('causedChange', false);
                }
              },
              undo: function () {
                var tChange, tResult, action; // eslint-disable-line no-unused-vars
                tChange = {
                  operation: 'createAttributes',
                  collection: tCollection,
                  attrPropsArray: [{name: iAttrName, formula: tAttrFormula}]
                };
                tResult = iDataContext && iDataContext.applyChange(tChange);
                if (tResult.success) {
                  action = "attributeEditFormula";
                } else {
                  this.set('causedChange', false);
                }
              },
              redo: function () {
                this.execute();
              }
            }));

            tEditFormulaDialog.close();
          }
        }),

        // Use SC.mixin() to combine iProperties with the rest of the default properties
        // that are passed to the new attribute dialog.
        tEditFormulaDialog = DG.CreateAttributeFormulaView(SC.mixin({
          applyTarget: tApplier,
          applyAction: 'applyFormula',
          applyTooltip: 'DG.TableController.newAttrDlg.applyTooltip', // "Define the new attribute using the name and (optional) formula"
          attrNameHint: 'DG.TableController.newAttrDlg.attrNameHint',
          attrNameValue: iAttrName,
          attrNameIsEnabled: SC.empty(iAttrName), // disable attribute name changes if editing an existing attribute
          formulaValue: iAttrFormula,
          formulaCompletions: tResult.completionData,
          formulaOperands: tResult.operandsMenu,
          formulaHint: 'DG.TableController.newAttrDlg.formulaHint'  // "If desired, type a formula for computing values of this attribute"
        }, {collection: tCollClient}));
  },

  /**
   *
   * @param iDataContext {DG.DataContext}
   * @param iAttrID {number}
   */
  hideAttribute: function (iDataContext, iAttrID) {
    var tAttrRef = iDataContext && iDataContext.getAttrRefByID(iAttrID),
        tAttrName = tAttrRef.attribute.get('name'),
        tCollectionClient = tAttrRef.collection,
        tCollection = tCollectionClient.get('collection');

    DG.UndoHistory.execute(DG.Command.create({
      name: "caseTable.hideAttribute",
      undoString: 'DG.Undo.caseTable.hideAttribute',
      redoString: 'DG.Redo.caseTable.hideAttribute',
      log: 'Hide attribute "%@"'.fmt(tAttrName),
      _beforeStorage: {
        changeFlag: iDataContext.get('flexibleGroupingChangeFlag'),
        fromCollectionID: tCollection.get('id'),
        fromCollectionName: tCollection.get('name'),
        fromCollectionParent: tCollection.get('parent'),
        fromCollectionChild: tCollection.get('children')[0]
      },
      _afterStorage: {},
      execute: function () {
        var change;
        change = {
          operation: 'hideAttributes',
          collection: tCollectionClient,
          attrs: [{id: iAttrID, attribute: tAttrRef.attribute}]
        };
        iDataContext.applyChange(change);
        iDataContext.set('flexibleGroupingChangeFlag', true);
      },
      undo: function () {
        var tChange;
        if (iDataContext.getCollectionByID(tCollection.get('id'))) {
          tChange = {
            operation: 'unhideAttributes',
            attrs: [{id: iAttrID, attribute: tAttrRef.attribute}]
          };
          iDataContext.applyChange(tChange);
          iDataContext.set('flexibleGroupingChangeFlag',
              this._beforeStorage.changeFlag);
          this._afterStorage.collection = tCollectionClient;
        }
      }
    }));

  },

  /**
   *
   * @param iDataContext {DG.DataContext}
   * @param iAttrID {number}
   */
  showAllHiddenAttributes: function (iDataContext) {
    var tHiddenAttrs = iDataContext.getHiddenAttributes().map(function (iAttr) {
          return {id: iAttr.get('id'), attribute: iAttr};
        }),
        tChange = {
          attrs: tHiddenAttrs
        };

    DG.UndoHistory.execute(DG.Command.create({
      name: "caseTable.showAllHiddenAttributes",
      undoString: 'DG.Undo.caseTable.showAllHiddenAttributes',
      redoString: 'DG.Redo.caseTable.showAllHiddenAttributes',
      log: 'Show all hidden attributes',
      execute: function () {
        if (tHiddenAttrs.length > 0) {
          tChange.operation = 'unhideAttributes';
          iDataContext.applyChange(tChange);
        }
        iDataContext.set('flexibleGroupingChangeFlag', true);
      },
      undo: function () {
        tChange.operation = 'hideAttributes';
        iDataContext.applyChange(tChange);
      }
    }));

  },

  /**
   * Delete an attribute. Confirmation will be requested if Undo is not enabled.
   *
   */
  deleteAttribute: function (iDataContext, iAttrID) {
    var tAttrRef = iDataContext && iDataContext.getAttrRefByID(iAttrID),
        tAttrName = tAttrRef.attribute.get('name'),
        tCollectionClient = tAttrRef.collection,
        tCollection = tCollectionClient.get('collection');

    var doDeleteAttribute = function () {
      DG.UndoHistory.execute(DG.Command.create({
        name: "caseTable.deleteAttribute",
        undoString: 'DG.Undo.caseTable.deleteAttribute',
        redoString: 'DG.Redo.caseTable.deleteAttribute',
        log: 'Delete attribute "%@"'.fmt(tAttrName),
        _beforeStorage: {
          changeFlag: iDataContext.get('flexibleGroupingChangeFlag'),
          fromCollectionID: tCollection.get('id'),
          fromCollectionName: tCollection.get('name'),
          fromCollectionParent: tCollection.get('parent'),
          fromCollectionChild: tCollection.get('children')[0]
        },
        _afterStorage: {},
        execute: function () {
          var response;
          if ((tCollectionClient.get('attrsController').get('length') === 1) &&
              (iDataContext.get('collections').length !== 1) &&
              (tCollectionClient.getAttributeByID(iAttrID))) {
            response = iDataContext.applyChange({
              operation: 'deleteCollection', collection: tCollectionClient
            });
            this._afterStorage.deletedItems = response && response.deletedItems;
          } else {
            iDataContext.applyChange({
              operation: 'deleteAttributes',
              collection: tCollectionClient,
              attrs: [{id: iAttrID, attribute: tAttrRef.attribute}]
            });
          }
          iDataContext.set('flexibleGroupingChangeFlag', true);
        },
        undo: function () {
          var tChange;
          var tStatus;
          if (iDataContext.getCollectionByID(tCollection.get('id'))) {
            tChange = {
              operation: 'createAttributes',
              collection: tAttrRef && tAttrRef.collection,
              attrPropsArray: [tAttrRef.attribute],
              position: [tAttrRef.position]
            };
            iDataContext.applyChange(tChange);
            iDataContext.set('flexibleGroupingChangeFlag',
                this._beforeStorage.changeFlag);
            this._afterStorage.collection = tCollectionClient;
          } else {
            tAttrRef.attribute.collection = null;
            tChange = {
              operation: 'createCollection',
              properties: {
                id: this._beforeStorage.fromCollectionID,
                name: this._beforeStorage.fromCollectionName,
                parent: this._beforeStorage.fromCollectionParent,
                children: this._beforeStorage.fromCollectionChild ? [this._beforeStorage.fromCollectionChild] : []
              },
              attributes: [tAttrRef.attribute]
            };
            tStatus = iDataContext.applyChange(tChange);
            this._afterStorage.collection = tStatus.collection;
            if (this._afterStorage.deletedItems) {
              this._afterStorage.deletedItems.forEach(function (item) {
                if (!item.setAside) {
                  item.deleted = false;
                }
              });
            }
            iDataContext.regenerateCollectionCases();
            iDataContext.set('flexibleGroupingChangeFlag',
                this._beforeStorage.changeFlag);
          }
        },
        redo: function () {
          var change;
          var tCollectionClient1 = iDataContext.getCollectionByID(this._afterStorage.collection.get('id'));
          if ((tCollectionClient1.get('attrsController').get('length') === 1) &&
              (iDataContext.get('collections').length !== 1) &&
              (tCollectionClient1.getAttributeByID(iAttrID))) {
            change = {
              operation: 'deleteCollection',
              collection: tCollectionClient1
            };
          } else {
            change = {
              operation: 'deleteAttributes',
              collection: tCollectionClient1,
              attrs: [{id: iAttrID, attribute: tAttrRef.attribute}]
            };
          }
          iDataContext.applyChange(change);
          iDataContext.set('flexibleGroupingChangeFlag', true);
        }
      }));
    }.bind(this);

    if (DG.UndoHistory.get('enabled')) {
      doDeleteAttribute();
    } else {
      DG.AlertPane.warn({
        message: 'DG.TableController.deleteAttribute.confirmMessage'.loc(tAttrName),
        description: 'DG.TableController.deleteAttribute.confirmDescription'.loc(),
        buttons: [
          {
            title: 'DG.TableController.deleteAttribute.okButtonTitle',
            action: doDeleteAttribute,
            localize: YES
          },
          {
            title: 'DG.TableController.deleteAttribute.cancelButtonTitle',
            localize: YES
          }
        ],
        localize: false
      });
    }
  },

  /**
   * Delete attribute's formula keeping values
   *
   */
  deleteAttributeFormula: function (iDataContext, iAttrID, iUpdateFunc) {
    var tRef = iDataContext && iDataContext.getAttrRefByID(iAttrID),
        tAttrName = tRef.attribute.get('name'),
        tCollection = tRef && iDataContext.getCollectionForAttribute(tRef.attribute),
        tFormula = '',
        tPrevFormula = tRef && tRef.attribute.get('formula');

    DG.UndoHistory.execute(DG.Command.create({
      name: "caseTable.editAttributeFormula",
      undoString: 'DG.Undo.caseTable.editAttributeFormula',
      redoString: 'DG.Redo.caseTable.editAttributeFormula',
      execute: function () {
        var tChange = {
              operation: 'createAttributes',
              collection: tCollection,
              attrPropsArray: [{ name: tAttrName, formula: tFormula }]
            },
            tResult = iDataContext && iDataContext.applyChange( tChange);
        if( tResult.success) {
          tRef.attribute.set('formula', tFormula);
          tRef.attribute.set('deletedFormula', tPrevFormula);
          iUpdateFunc && iUpdateFunc();

          var action = "attributeEditFormula";
          this.log = "%@: { name: '%@', collection: '%@', formula: '%@' }".fmt(
              action, tAttrName, tCollection.get('name'), tFormula);
        } else {
          this.set('causedChange', false);
        }
      },
      undo: function () {
        var tChange, tResult, action; // eslint-disable-line no-unused-vars
        tChange = {
          operation: 'createAttributes',
          collection: tCollection,
          attrPropsArray: [{ name: tAttrName, formula: tPrevFormula }]
        };

        tResult = iDataContext && iDataContext.applyChange( tChange);
        if( tResult.success) {
          tRef.attribute.set('formula', tPrevFormula);
          tRef.attribute.set('deletedFormula', tFormula);
          iUpdateFunc && iUpdateFunc();

          action = "attributeEditFormula";
          this.log = "%@: { name: '%@', collection: '%@', formula: '%@' }".fmt(
              action, tAttrName, tCollection.get('name'), tPrevFormula);
        } else {
          this.set('causedChange', false);
        }
      },
      redo: function () {
        this.execute();
      }
    }));
  },

  /**
   * Recover attribute's formula
   *
   */
  recoverAttributeFormula: function (iDataContext, iAttrID, iUpdateFunc) {
    var tRef = iDataContext && iDataContext.getAttrRefByID(iAttrID),
        tCollection = tRef && iDataContext.getCollectionForAttribute(tRef.attribute),
        tAttrName = tRef && tRef.attribute.get('name'),
        tFormula = tRef && tRef.attribute.get('deletedFormula'),
        tPrevFormula = '';

    DG.assert( tRef && tAttrName, "recoverDeletedFormula() is missing the attribute reference or attribute name" );

    DG.UndoHistory.execute(DG.Command.create({
      name: "caseTable.editAttributeFormula",
      undoString: 'DG.Undo.caseTable.editAttributeFormula',
      redoString: 'DG.Redo.caseTable.editAttributeFormula',
      execute: function() {
        var tChange = {
              operation: 'createAttributes',
              collection: tCollection,
              attrPropsArray: [{ name: tAttrName, formula: tFormula }]
            },
            tResult = iDataContext && iDataContext.applyChange( tChange);
        if( tResult.success) {
          tRef.attribute.set('formula', tFormula);
          tRef.attribute.set('deletedFormula', tPrevFormula);
          iUpdateFunc && iUpdateFunc();

          var action = "attributeEditFormula";
          this.log = "%@: { name: '%@', collection: '%@', formula: '%@' }".fmt(
              action, tAttrName, tCollection.get('name'), tFormula);
        } else {
          this.set('causedChange', false);
        }
      },
      undo: function() {
        var tChange, tResult, action; // eslint-disable-line no-unused-vars
        tChange = {
          operation: 'createAttributes',
          collection: tCollection,
          attrPropsArray: [{ name: tAttrName, formula: tPrevFormula }]
        };

        tResult = iDataContext && iDataContext.applyChange( tChange);
        if( tResult.success) {
          tRef.attribute.set('formula', tPrevFormula);
          tRef.attribute.set('deletedFormula', tFormula);
          iUpdateFunc && iUpdateFunc();

          action = "attributeEditFormula";
          this.log = "%@: { name: '%@', collection: '%@', formula: '%@' }".fmt(
              action, tAttrName, tCollection.get('name'), tPrevFormula);
        } else {
          this.set('causedChange', false);
        }
      },
      redo: function() {
        this.execute();
      }
    }));
  },

  /**
   *
   * @param iContext {DG.DataContext}
   * @param iAttrID {Number}
   * @return {Boolean}
   */
  attributeCanBeRandomized: function (iContext, iAttrID) {
    var depMgr = iContext && iContext.get('dependencyMgr'),
        dependency = depMgr &&
            depMgr.findDependency({
                  type: DG.DEP_TYPE_ATTRIBUTE,
                  id: iAttrID
                },
                {
                  type: DG.DEP_TYPE_SPECIAL,
                  id: 'random'
                });
    return dependency;
  },

  /**
   * Randomize a single attribute
   */
  randomizeAttribute: function (iDataContext, iAttrID) {
    if (iDataContext && iAttrID) {
      iDataContext.invalidateDependencyAndNotify({
            type: DG.DEP_TYPE_ATTRIBUTE,
            id: iAttrID
          },
          {
            type: DG.DEP_TYPE_SPECIAL,
            id: 'random'
          },
          true /* force aggregate */);
    }
  },

  makeUniqueCollectionName: function (context, candidateName) {
    var name = pluralize(candidateName);
    var ix = 0;
    while (!SC.none(context.getCollectionByName(name))) {
      ix += 1;
      name = pluralize(candidateName) + ix;
    }
    return name;
  },

  /**
   * Helper method to create a DG.Command to create a new collection from
   * a dragged attribute.
   *
   * @param attribute {DG.Attribute}
   * @param collection {DG.collection}
   * @param context  {DG.DataContext} The current DataContext
   * @param parentCollectionID {number|undefined} Parent collection id, if
   *                  collection is to be created as a child collection of
   *                  another collection. Otherwise, it is created as the
   *                  parent of the current parent collection.
   * @returns {*}
   * @private
   */
  createCollectionCommand: function (attribute, collection, context, parentCollectionID) {
    var collectionName = this.makeUniqueCollectionName(context, attribute.name);
    var childCollectionID = null;
    if (SC.none(parentCollectionID)) {
      childCollectionID = context.getCollectionAtIndex(0).collection.id;
    }
    return DG.Command.create({
      name: 'caseTable.createCollection',
      undoString: 'DG.Undo.caseTable.createCollection',
      redoString: 'DG.Redo.caseTable.createCollection',
      log: 'createCollection {name: %@, attr: %@}'.loc(collectionName,
          attribute.name),
      _beforeStorage: {
        context: context,
        newCollectionName: collectionName,
        newParentCollectionID: parentCollectionID,
        newChildCollectionID: childCollectionID,
        attributeID: attribute.id,
        oldAttributePosition: collection.attrs.indexOf(
            attribute),
        oldCollectionID: collection.id,
        changeFlag: context.get('flexibleGroupingChangeFlag')
      },
      execute: function () {
        var context = this._beforeStorage.context;
        var attribute = context.getAttrRefByID(
            this._beforeStorage.attributeID).attribute;
        var childCollectionID = this._beforeStorage.newChildCollectionID;
        var childCollection = childCollectionID && context.getCollectionByID(
            childCollectionID).collection;
        var tChange = {
          operation: 'createCollection',
          properties: {
            name: this._beforeStorage.newCollectionName,
            parent: this._beforeStorage.newParentCollectionID
          },
          attributes: [attribute]
        };
        if (childCollection) {
          tChange.properties.children = [childCollection];
        }
        context.applyChange(tChange);
        context.set('flexibleGroupingChangeFlag', true);
      },
      undo: function () {
        var context = this._beforeStorage.context;
        var attribute = context.getAttrRefByID(
            this._beforeStorage.attributeID).attribute;
        var toCollection = context.getCollectionByID(
            this._beforeStorage.oldCollectionID);
        var tChange = {
          operation: 'moveAttribute',
          attr: attribute,
          toCollection: toCollection,
          position: this._beforeStorage.oldAttributePosition
        };
        context.applyChange(tChange);
        context.set('flexibleGroupingChangeFlag', this._beforeStorage.changeFlag);
      }
    });
  },

  /**
   Creates a new case with the specified values.
   */
  createCaseUndoable: function (iContext, props) {
    var contextName = iContext.get('name');
    if (!props.collection || !props.attrIDs) return;

    var createResult;
    var isRegenerated = false;

    function doCreateCase() {
      var result = iContext.applyChange({
        operation: 'createCases',
        attributeIDs: props.attrIDs,
        collection: props.collection,
        properties: {parent: props.parent},
        values: [props.values]
      });
      if (result.success && props.beforeCaseID) {
        var dataSet = iContext.get('dataSet');
        var beforeCase = iContext.getCaseByID(props.beforeCaseID);
        var beforeItem = beforeCase && beforeCase.item;
        var beforeItemIndex = dataSet && beforeItem &&
            dataSet.getDataItemClientIndexByID(beforeItem.id);
        if (result.itemIDs && dataSet && (beforeItemIndex != null)) {
          iContext.applyChange({
            operation: 'moveItems',
            items: result.itemIDs.map(function (id) {
              return dataSet.getDataItemByID(id);
            }),
            itemOrder: beforeItemIndex
          });
          isRegenerated = true;
        }
      }
      if (!isRegenerated)
        iContext.regenerateCollectionCases();

      return result;
    }

    function doDeleteCase(caseIDs) {
      var cases = caseIDs.map(function (id) {
        return DG.store.find('DG.Case', id);
      });
      return iContext.applyChange({
        operation: 'deleteCases',
        cases: cases
      });
    }

    var cmd = DG.Command.create({
      name: "caseTable.createNewCase",
      undoString: 'DG.Undo.caseTable.createNewCase',
      redoString: 'DG.Redo.caseTable.createNewCase',
      log: "create new case",
      execute: function () {
        createResult = doCreateCase();
      },
      undo: function () {
        if (createResult && createResult.caseIDs)
          doDeleteCase(createResult.caseIDs);
      },
      redo: function () {
        iContext = DG.currDocumentController().getContextByName(contextName);
        if (iContext)
          createResult = doCreateCase();
      }
    });

    DG.UndoHistory.execute(cmd);
  },

  stashAttributeValue: function (iContext, iCase, iAttr, iValue) {
    var tAttrID = iAttr.get('id'),
        originalValue = iCase.getStrValue(tAttrID),
        newValue = DG.DataUtilities.canonicalizeInputValue(iValue),
        contextName = iContext.get('name'),
        collection = iCase.get('collection'),
        collectionName = collection && collection.get('name') || "",
        attr = collection && collection.getAttributeByID(tAttrID),
        attrName = attr && attr.get('name'),
        caseIndex = collection.getCaseIndexByID(iCase.get('id'));

    function applyEditChange(attrID, iValue, isUndoRedo) {
      SC.run(function () {
        iContext.applyChange({
          operation: 'updateCases',
          cases: [iCase],
          attributeIDs: [attrID],
          values: [[iValue]]
        });
      });
    }

    var cmd = DG.Command.create({
      name: 'caseTable.editCellValue',
      undoString: 'DG.Undo.caseTable.editCellValue',
      redoString: 'DG.Redo.caseTable.editCellValue',
      log: "editValue: { collection: %@, case: %@, attribute: '%@', old: '%@', new: '%@' }"
          .fmt(collectionName, caseIndex + 1, tAttrID, originalValue, newValue),
      causedChange: true,
      execute: function () {
        applyEditChange(tAttrID, newValue);
      },
      undo: function () {
        applyEditChange(tAttrID, originalValue, true);
      },
      redo: function () {
        iContext = DG.currDocumentController().getContextByName(contextName);
        collection = iContext && iContext.getCollectionByName(collectionName);
        attr = collection && collection.getAttributeByName(attrName);
        tAttrID = attr.get('id');
        var cases = collection && collection.get('casesController');
        iCase = cases && cases.objectAt(caseIndex);
        if (iCase)
          applyEditChange(tAttrID, newValue, true);
      }
    });
    DG.UndoHistory.execute(cmd);
  },

  newAttribute: function (iDataContext, iCollection, iPosition, iEditorViewOrCallback, iAutoEdit) {
    if (iEditorViewOrCallback) {
      DG.globalEditorLock.commitCurrentEdit();
    }
    var tAttrName = iDataContext.getNewAttributeName(),
        tAttrRef;

    DG.UndoHistory.execute(DG.Command.create({
      name: "caseTable.createAttribute",
      undoString: 'DG.Undo.caseTable.createAttribute',
      redoString: 'DG.Redo.caseTable.createAttribute',
      execute: function (isRedo) {
        SC.run(function () {
          tAttrRef = iDataContext.getAttrRefByName(tAttrName);
          var change = {
                operation: 'createAttributes',
                collection: iCollection,
                attrPropsArray: [{name: tAttrName}],
                position: iPosition
              },
              result = iDataContext && iDataContext.applyChange(change);
          if (!isRedo && result.success) {
            this.log = "%@: { name: '%@', collection: '%@', formula: '%@' }".fmt(
                'attributeCreate', tAttrName, iCollection.get('name'));
            // simple callback function
            if (typeof iEditorViewOrCallback === "function") {
              iEditorViewOrCallback(tAttrName);
            } else if (iAutoEdit && iEditorViewOrCallback) {
              iEditorViewOrCallback.invokeLater(function () {
                iEditorViewOrCallback.beginEditAttributeName(tAttrName);
              });
            }
          } else {
            this.set('causedChange', false);
          }
        }.bind(this));
      },
      undo: function () {
        tAttrRef = iDataContext.getAttrRefByName(tAttrName);
        var attr = tAttrRef.attribute,
            change = {
              operation: 'deleteAttributes',
              collection: iCollection,
              attrs: [{id: attr.get('id'), attribute: attr}]
            },
            result = iDataContext && iDataContext.applyChange(change);
        if (!result.success) {
          this.set('causedChange', false);
        }
      },
      redo: function () {
        this.execute(true);
      }
    }));
  },

  joinSourceToDestCollection: function (iSourceKeyAttribute, iDestContext, iDestCollection, iDestKeyAttribute) {

    function forEachJoinableSourceAttribute(iCallback) {
      tSourceAttributes.forEach(function (iForeignAttribute) {
        if (iForeignAttribute !== iSourceKeyAttribute && !iForeignAttribute.get('hidden')) {
          var tAttributeName = iForeignAttribute.get('name'),
              tIndex = 1;
          while (tExistingDestAttributeNames.indexOf(tAttributeName) >= 0) {
            tAttributeName = iForeignAttribute.get('name') + '_' + tIndex;
            tIndex++;
          }
          iCallback(iForeignAttribute, tAttributeName);
        }
      });
    }

    var tSourceAttributeName = iSourceKeyAttribute && iSourceKeyAttribute.get('name'),
        tSourceCollection = iSourceKeyAttribute && iSourceKeyAttribute.collection,
        tSourceDatasetName = tSourceCollection && tSourceCollection.getPath('context.title'),
        tSourceAttributes = tSourceCollection && tSourceCollection.get('attrs'),
        tDestKeyValueAttributeName = iDestKeyAttribute && iDestKeyAttribute.get('name'),
        tExistingDestAttributeNames = iDestCollection.getPath('collection.attrs').map(function (iAttr) {
          return iAttr.get('name');
        });
    if (tSourceAttributes && tSourceAttributeName && tSourceDatasetName && iDestCollection &&
        tDestKeyValueAttributeName && iDestContext) {
      DG.UndoHistory.execute(DG.Command.create({
        name: "dataContext.join",
        undoString: 'DG.Undo.DataContext.join'.loc(tSourceDatasetName, iDestContext.get('title')),
        redoString: 'DG.Redo.DataContext.join'.loc(tSourceDatasetName, iDestContext.get('title')),
        log: 'Join attributes from "%@" to "%@"'.fmt(tSourceDatasetName, iDestContext.get('title')),
        executeNotification: {
          action: 'notify',
          resource: 'component',
          values: {
            operation: 'join',
            type: DG.CaseTable
          }
        },
        execute: function () {
          var tAttrSpecs = [];
          forEachJoinableSourceAttribute(function (iForeignAttribute, iNewAttrName) {
            var tProps = iForeignAttribute.getTransferableProperties(),
                tForeignAttributeName = iForeignAttribute.get('name');
            tAttrSpecs.push(Object.assign(tProps, {
              name: iNewAttrName,
              title: iNewAttrName,
              formula: 'lookupByKey("%@", "%@", "%@", `%@`)'.fmt(tSourceDatasetName, tForeignAttributeName,
                  tSourceAttributeName, tDestKeyValueAttributeName)
            }));
          });
          iDestContext.applyChange({
            operation: 'createAttributes',
            collection: iDestCollection,
            attrPropsArray: tAttrSpecs
          });
        },
        undo: function () {
          var tAttributes = [];
          forEachJoinableSourceAttribute(function (iForeignAttribute, iNewAttrName) {
            tAttributes.push(iDestCollection.getAttributeByName(iNewAttrName));
          });
          iDestContext.applyChange({
            operation: 'deleteAttributes',
            collection: iDestCollection,
            attrs: tAttributes
          });
        }
      }));
    }
  }
};

/* >>>>>>>>>> BEGIN source/utilities/do-command-response-handler.js */
// this code is shared between the embedded server in main.js and the data interactive server in game_controller.js

DG.doCommandResponseHandler = function (ret, callback) {
  // Analysis shows that the object returned by DG.doCommand may contain Error values, which
  // are not serializable and thus will cause DataCloneErrors when we call 'callback' (which
  // sends the 'ret' to the game window via postMessage). The 'requestFormulaValue' and
  // 'requestAttributeValues' API commands are the guilty parties. The following is an
  // ad-hoc attempt to clean up the object for successful serialization.

  if (ret && ret.error && ret.error instanceof Error) {
    ret.error = ret.error.message;
  }

  if (ret && ret.values && ret.values.length) {
    ret.values = ret.values.map(function (value) {
      return value instanceof Error ? null : value;
    });
  }

  // If there's a DataCloneError anyway, at least let the client know something is wrong:
  try {
    callback(ret);
  } catch (e) {
    if (e instanceof window.DOMException && e.name === 'DataCloneError') {
      callback({success: false});
    }
  }
};
/* >>>>>>>>>> BEGIN source/utilities/editor_lock.js */
// ==========================================================================
//                            DG.EditorLock
//
//  Implements a global editor lock to coordinate the actions of multiple
//  disparate edit views. Clients that support editing should register with
//  the global editor lock and implement the required methods. Non-editing
//  clients may call DG.globalEditorLock.commitCurrentEdit() to force any
//  active edit to complete.
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/**
  @class DG.EditorLock
  
  Currently just forwards to the SlickGrid implementation as a simple means
  of coordinating with it. Could easily be a replacement for it if we ever
  moved away from SlickGrid.
 */
DG.EditorLock = SC.Object.extend({

  /**
    Returns true if the specified controller is the active one.
    @param  {Object}  iEditController -- the controller to test
    @returns  {Boolean} True if the specified controller is active
   */
  isActive: function( iEditController) {
    return iEditController === DG.mainPage.getPath('mainPane.firstResponder') ||
        window.Slick.GlobalEditorLock.isActive( iEditController);
  },

  /**
    Make the specified controller the active one.
    @param  {Object}  iEditController -- the controller to activate
   */
  activate: function( iEditController) {
    try {
      window.Slick.GlobalEditorLock.activate( iEditController);
    }
    catch(e) {
      // SlickGrid throws an exception on failure to activate
      DG.logWarn( e.replace('SlickGrid', 'DG'));
    }
  },

  /**
    Remove the specified controller as the active one.
    @param  {Object}  iEditController -- the controller to deactivate
   */
  deactivate: function( iEditController) {
    try {
      window.Slick.GlobalEditorLock.deactivate( iEditController);
    }
    catch(e) {
      // SlickGrid throws an exception on failure to deactivate
      DG.logWarn( e.replace('SlickGrid', 'DG'));
    }
  },

  /**
    Requests the current active controller to complete its edit,
    commit the new value, and deactivate.
    @returns  {Boolean} True if the edit was completed successfully; false otherwise.
   */
  commitCurrentEdit: function() {
    var result = window.Slick.GlobalEditorLock.commitCurrentEdit();
    DG.mainPage.get('mainPane').makeFirstResponder( null);
    return result;
  },

  /**
    Requests the current active controller to cancel its current edit,
    discarding any results to this point.
    @returns  {Boolean} True if the edit was canceled successfully; false otherwise.
   */
  cancelCurrentEdit: function() {
    return window.Slick.GlobalEditorLock.cancelCurrentEdit();
  }
});

DG.globalEditorLock = new DG.EditorLock();

/* >>>>>>>>>> BEGIN source/utilities/iframe-phone-emulator.js */
// ==========================================================================
//  
//  Author:   jsandoe
//
//  Copyright (c) 2017 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
/**
 * The purpose of this emulator is allow parties in the same execution context
 * to communicate with one-another as if they were using the IFramePhone RPC
 * endpoint.
 */
DG.IFramePhoneEmulator = function (messageHandler, channelName, connectorName) {
  var queue = [];
  var connection = null;
  return {
    call: function (message, callback) {
      if (connection) {
        connection._transmit(message, function (reply) {
          if (callback) {
            callback(reply);
          }
        });
      } else {
        queue.push({message: message, callback: callback});
      }
    },
    connect: function (partner) {
      if (!connection && partner.connect) {
        DG.log('Local Connection established between %@ and %@'.loc(connectorName, partner.getConnectorName()));
        connection = partner;
        partner.connect(this);
        if (queue.length > 0) {
          queue.forEach(function (item) {
            this.call(item.message, item.callback);
          }.bind(this));
        }
      }
    },
    getConnectorName: function () {
      return connectorName;
    },
    _transmit: function (message, callback) {
      messageHandler(message, callback);
    }
  };
};
/* >>>>>>>>>> BEGIN source/utilities/image_utilities.js */
// ==========================================================================
//                          DG.ImageUtilities
//
//  Author:   Jonathan Sandoe
//
//  Copyright (c) 2017 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/* global Promise:true */
DG.ImageUtilities = (function () {

    /**
     * Converts an SVG scene into a png image.
     * @param rootEl {Element} a DOM element. Either HTML or SVG. This routine
     *   will extract SVG elements from this object and place them in the final
     *   image. HTML DOM element will not be visible.
     * @param width {number}
     * @param height {number}
     * @param asDataURL {boolean} true - image returned as data URI, otherwise as blob
     * @param title {string}
     * @return {Promise} The promise of an image.
     */
    function captureSVGElementsToImage (rootEl, width, height, title, asDataURL) {

      function getCSSText() {
        var text = [], ix, jx;
        for (ix = 0; ix < document.styleSheets.length; ix += 1) {
          try {
            var styleSheet = document.styleSheets[ix];
            if (styleSheet) {
              var rules = styleSheet.rules || styleSheet.cssRules || [];
              for (jx = 0; jx < rules.length; jx += 1) {
                var rule = rules[jx];
                text.push(rule.cssText);
              }
            }
          } catch (ex) {
            DG.logWarn('Exception retrieving stylesheet: ' + ex);
          }
        }
        return text.join('\n');
      }

      function makeDataURLFromSVGElement(svgEl) {
        var svgClone = $(svgEl).clone();
        var css = $('<style>').text(getCSSText());
        svgClone.prepend(css);
        var svgData = new XMLSerializer().serializeToString(svgClone[0]);
        // Raphael overspecifies the url for the gradient. It prepends the
        // windows.location.href. This causes problems with the data url,
        // because we are no longer in this namespace. So, we remove.
        svgData = svgData.replace(
            new RegExp('url\\(\'[^#]*#', 'g'), 'url(\'#');
        // The use of unescape and encodeURIComponent are part of a well
        // known hack work around btoa's handling of unicode characters.
        // see, eg:
        // http://ecmanaut.blogspot.com/2006/07/encoding-decoding-utf8-in-javascript.html
        return "data:image/svg+xml;base64,"
            + window.btoa(window.unescape(window.encodeURIComponent(svgData)));
      }

      /**
       * Create a canvas element with a white background. Not yet appended to
       * the DOM.
       * @param {number} width
       * @param {number} height
       * @returns {canvas}
       */
      function makeCanvasEl(width, height) {
        var canvas = $("<canvas>").prop({width: width, height: height})[0];
        var ctx = canvas.getContext("2d");
        ctx.fillStyle = 'white';
        ctx.fillRect(0, 0, width, height);
        return canvas;
      }

      /**
       * Add an image to the canvas at the specified location.
       * @param {canvas} canvas DOM Element
       * @param {object} image DOM Element
       * @param {number} x
       * @param {number} y
       * @param {number} width
       * @param {number} height
       */
      function addImageToCanvas(canvas, image, x, y, width, height) {
        var ctx = canvas.getContext("2d");
        ctx.drawImage(image, x, y, width, height);
      }

      function drawRectToCanvas(canvas, color, x, y, width, height) {
        var ctx = canvas.getContext("2d");
        ctx.fillStyle = color;
        ctx.fillRect(x, y, width, height);
      }
      /**
       * Convert a canvas object to a blob.
       * @param canvas
       * @returns {*}
       */
      function makeCanvasBlob(canvas) {
        var canvasDataURL = canvas.toDataURL("image/png");
        var canvasData = atob(canvasDataURL.substring("data:image/png;base64,".length));
        var canvasAsArray = new Uint8Array(canvasData.length);  /* global Uint8Array */

        for (var i = 0, len = canvasData.length; i < len; ++i) {
          canvasAsArray[i] = canvasData.charCodeAt(i);
        }

        return new Blob([canvasAsArray.buffer], {type: "image/png"});
      }

      /**
       * @returns a promise of an image.
       * @param dataURL
       */
      function makeSVGImage(dataURL) {
        return new Promise(function (resolve, reject) {
              try {
                var img = $('<img/>')[0];
                img.onload = function () {
                  resolve(img);
                };
                img.src = dataURL;
              } catch (ex) {
                reject(ex);
              }
            }
        );
      }

      function appendTitle(canvas, bgColor, fgColor, title) {
        var ctx = canvas.getContext("2d");
        ctx.fillStyle = bgColor;
        ctx.fillRect(0, height, width, 20);
        ctx.fillStyle = fgColor;
        ctx.beginPath();
        ctx.moveTo(0, height);
        ctx.lineTo(width, height);
        ctx.stroke();
        ctx.font='10pt MuseoSans-500';
        ctx.textAlign = 'center';
        ctx.textBaseline = 'middle';
        ctx.fillText(title,width/2, height + 14, width);
      }

      //
      // ######## convertImage begin ########
      //
      // find all svg elements that are not children of hidden divs
      var elements = $(rootEl).find('div.dg-plot-view,img,div:not(.sc-hidden)>svg');
      var canvas = makeCanvasEl(width, height + (title?20:0));
      var jobList = [];
      var jobIx = 0;

      function perform(job) {
        var elType = job && job.el && job.el.nodeName.toLowerCase();
        if (!job) {
          if (title) {
            appendTitle(canvas, 'white', 'black', title);
          }
          // we have drawn all the elements resolve the promise with a data URL or blob
          try {
            return Promise.resolve(asDataURL ? canvas.toDataURL("image/png") : makeCanvasBlob(canvas));
          } catch (e) {
            return Promise.reject(e);
          }
        }
        if (elType === 'div') {
          // get the background color from the base div
          drawRectToCanvas(canvas,$(job.el).css('background-color'), job.l, job.t, job.w, job.h);
          return perform(jobList[jobIx++]);
        } else if (elType === 'svg') {
          // add the svg as an image to the canvas
          return makeSVGImage(makeDataURLFromSVGElement(job.el)).then(function (img) {
              addImageToCanvas(canvas, img, job.l, job.t, job.w, job.h);
              return perform(jobList[jobIx++]);
            },
            function (error) {
              return Promise.reject(error);
            }
          );
        } else if (elType === 'img') {
          // add an img to the canvas only if it has the cross-origin attribute.
          // otherwise we will taint the canvas
          if (!SC.none(job.el.getAttribute('crossorigin'))) {
            addImageToCanvas(canvas, job.el, job.l, job.t, job.w, job.h);
          }
          return perform(jobList[jobIx++]);
        } else {
          return perform(jobList[jobIx++]);
        }

      }
      // for each svg we calculate its geometry, then add it to the canvas
      // through a promise.
      // Note: This implementation starts a number of asynchronous operations,
      // one for each SVG in the hierarchy. If they overlap and are handled out
      // of order, it is possible that they may be written to the canvas in the
      // wrong order.
      try {
        if (elements) {
          elements.forEach(function (element) {
            var width = element.offsetWidth || (element.width.baseVal?element.width.baseVal.value:0);
            var height = element.offsetHeight || (element.height.baseVal?element.height.baseVal.value:0);
            var left = 0;
            var top = 0;
            var rect = element.getBoundingClientRect();
            var rootRect = rootEl.getBoundingClientRect();
            if (element.nodeName.toLowerCase() === "img") {
              jobList.push({
                el:element,
                w: rect.width,
                h: rect.height,
                l: rect.left - rootRect.left,
                t: rect.top - rootRect.top
              });
            } else {
              $(element).add($(element).parentsUntil(rootEl)).each(function () {
                left += this.offsetLeft || 0;
                top += this.offsetTop || 0;
              });
              jobList.push({el: element, w: width, h: height, l: left, t: top});
            }
          });

          return perform (jobList[jobIx++]);
        }
      } catch (ex) {
        DG.logError('saving image: ' + ex);
      }
      return null;

    }

  function makeBaseEl(width, height) {
    var el = document.createElement('svg');
    el.setAttribute('width', width);
    el.setAttribute('height', height);
    el.setAttribute('xmlns',"http://www.w3.org/2000/svg");
    el.innerHTML = '<rect width=' + (width-1) + ' height=' + (height-1) +
        ' stroke="#888" fill="#fff"/>';
    return el;
  }

  function getElementPosition(el, rootEl) {
    var x = 0, y = 0;
    var p = el;
    while (p && p !== p.parentElement && p !== rootEl) {
      x += p.offsetLeft || 0;
      y += p.offsetTop || 0;
      p = p.parentElement;
    }
    return {x: x, y: y};
  }

  function svgText(titleText, centerX, centerY) {
      var el = document.createElement('text');
      el.setAttribute('x', centerX);
      el.setAttribute('y', centerY);
      el.setAttribute('font-family', 'MuseoSans-500,arial');
      el.setAttribute('font-size', '14px');
      el.setAttribute('stroke', 'none');
      el.setAttribute('fill', '#888');
      el.setAttribute('text-anchor', 'middle');
      el.innerText = titleText;
      return el;
  }

  function svgLine(fromX, fromY, toX, toY) {
    var el = document.createElement('path');
    el.setAttribute('d', 'M' + fromX + ' ' + fromY + ' L' + toX + ' ' + toY);
    el.setAttribute('stroke', '#888');
    el.setAttribute('fill', '#888');
    return el;
  }
  function captureGraphToSVG(rootEl, width, height, title) {
    //var elements = rootEl.querySelectorAll('div.dg-plot-view,div:not(.sc-hidden)>svg');
    if (title) {
      height = height + 20;
    }
    var elements = rootEl.querySelectorAll('div:not(.sc-hidden)>svg');
    var newSVG = makeBaseEl(width, height + (title?20:0));
    elements.forEach(function(el) {
      if (el.children) {
        var pos = getElementPosition(el, rootEl);
        var clone = el.cloneNode(true);
        clone.setAttribute('x', pos.x);
        clone.setAttribute('y', pos.y);
        clone.setAttribute('width', el.width.baseVal.value);
        clone.setAttribute('height', el.height.baseVal.value);

        if (el.tagName.toLowerCase() === 'svg') {
          newSVG.append(clone);
        }
      }
    });
    if (title) {
      newSVG.append(svgLine(0, height-20, width, height-20));
      newSVG.append(svgText(title, width/2, height));
    }
    return newSVG.outerHTML;
  }

  return {
    captureSVGElementsToImage: captureSVGElementsToImage,
    captureGraphToSVG: captureGraphToSVG
  };
}());

/* >>>>>>>>>> BEGIN source/utilities/math_utilities.js */
// ==========================================================================
//                          DG.MathUtilities
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

DG.MathUtilities = {

  /**
   Utility function to round a real to a specified number of decimal places.
   @param{Number}
   @param{Number} integer
   @return{Number}
   */
  roundToDecimalPlaces: function (iValue, iDecimalPlaces) {
    var factor = Math.pow(10, iDecimalPlaces);
    return Math.round(iValue* factor) / factor;
  },

  /**
   Utility function to round a real to a specified number of significant
   digits.
   Return both the rounded value and the number of places to the right
   of the decimal place needed to format the string correctly.
   @param{Number}
   @param{Number} integer
   @return{ { roundedValue: {Number}, decPlaces: {Number} }}
   */
  roundToSignificantDigits: function (iValue, iSigDigits) {
    var tSign = 1,
        tAdjustedPlaces = 0,
        tLower, tUpper, tNewValue, tRoundedValue, tDecPlaces;

    DG.assert(iSigDigits > 0);
    if (isNaN(iValue)) {
      return {roundedValue: iValue, decPlaces: 0};
    }

    if (iValue === 0) {
      return {roundedValue: 0, decPlaces: 0};
    }

    if (iValue < 0) {
      tSign = -1;
      iValue = -iValue;
    }

    // First get the value in the range 10^(iSigDigits-1) to 10^iSigDigits.
    tLower = Math.pow(10, iSigDigits - 1);
    tUpper = tLower * 10;
    while (iValue > tUpper) {
      iValue = iValue / 10;
      tAdjustedPlaces++;
    }
    while (iValue < tLower) {
      iValue = iValue * 10;
      tAdjustedPlaces--;
    }

    tNewValue = Math.floor(iValue);
    if (iValue - tNewValue > 0.5)
      tNewValue++;
    var tCounter = tAdjustedPlaces;
    while( tCounter < 0) {
      tNewValue = tNewValue / 10;
      tCounter++;
    }
    if( tAdjustedPlaces < 0)
      tNewValue = tNewValue.toFixed(-tAdjustedPlaces);

    while( tCounter > 0) {
      tNewValue = tNewValue * 10;
      tCounter--;
    }

    tRoundedValue = tSign * tNewValue;
    if (tAdjustedPlaces > 0)
      tAdjustedPlaces = 0;
    tDecPlaces = -tAdjustedPlaces;
    return {roundedValue: tRoundedValue, decPlaces: tDecPlaces};
  },

  formatNumber: function( iValue, iPrecision) {
    var tNumFormat = DG.Format.number().fractionDigits(0, iPrecision);
    tNumFormat.group(''); // Don't separate with commas
    return tNumFormat(iValue);
  },

  extractNumeric: function( x) {
    if( SC.empty( x))
      return '';
    var num = Number(x);
    if( !isNaN( num))
      return num;
    if( typeof x === 'string') {
    var noNumberPatt = /[^.\d-]+/gm,
        firstNumericPatt = /(^-?\.?[\d]+(.?[\d]*)?)/gm,
        firstPass = x.replace(noNumberPatt, '');
        x = firstPass.match(firstNumericPatt);
        x = Array.isArray(x) ? x[0] : null;
    }
    return SC.empty( x) ? null : Number( x);
  },

  /** Clip to the integer range which EXCLUDES the upper value.
   *  Assumes that all values are integers.
   *  @returns integer in [iMin - iMax) range.
   */
  clipToIntegerRange: function (iInteger, iMin, iMax) {
    DG.assert(iInteger === Math.round(iInteger));
    if (iInteger < iMin) {
      return iMin;
    } else if (iInteger >= iMax) {
      return iMax - 1;
    }
    return iInteger;
  },

  /** Test for inside integer range which EXCLUDES the upper value.
   *  Assumes that all values are integers.
   *  @returns integer in [iMin - iMax) range.
   */
  isInIntegerRange: function (iInteger, iMin, iMax) {
    DG.assert(iInteger === Math.round(iInteger));
    return ( iMin <= iInteger && iInteger < iMax );
  },

  /** Clip to the real numeric range which INCLUDES the upper value.
   *  Assumes that all values are finite real numbers.
   *  @returns number in [iMin - iMax] range.
   */
  clipToRange: function (iNumber, iMin, iMax) {
    DG.assert(typeof iNumber === 'number' && isFinite(iNumber));
    if (iNumber < iMin) {
      return iMin;
    } else if (iNumber > iMax) {
      return iMax;
    }
    return iNumber;
  },

  /** Test for inside the real numeric range which INCLUDES the upper value.
   *  Assumes that all values are finite real numbers.
   *  @returns boolean true if value is in the range
   */
  isInRange: function (iNumber, iMin, iMax) {
    DG.assert(typeof iNumber === 'number');
    return isFinite(iNumber) ? ( iMin <= iNumber && iNumber <= iMax ) : false;
  },

  /**
   * Distance between two points.
   * @param {x,y} iPoint1
   * @param {x,y} iPoint2
   */
  distance: function (iPoint1, iPoint2) {
    var dx = iPoint1.x - iPoint2.x,
        dy = iPoint1.y - iPoint2.y;
    return Math.sqrt(dx * dx + dy * dy);
  },

  /**
   * Compute the median of an array of finite numeric values.
   * Warning, the input array is sorted, on the assumption that it is most
   * computationally efficient to directly modify a temporary array.  Caller
   * should make a copy of the array if this is undesired behavior.
   * @param ioArray array of numbers (will be sorted ascending)
   * @return {Number} median value or undefined if ioArray.length===0
   */
  medianOfNumericArray: function (ioArray) {

    function lessThan(a, b) {
      return a - b;
    } // for ascending numeric sort()

    function median(iSortedArray) {
      var i = (iSortedArray.length - 1) / 2, // middle index in 0-(n-1) array
          i1 = Math.floor(i),
          i2 = Math.ceil(i);
      if (i < 0) {
        return undefined; // length === 0
      } else if (i === i1) {
        return iSortedArray[i];
      } else {
        return (iSortedArray[i1] + iSortedArray[i2]) / 2;
      }
    }

    ioArray.sort(lessThan);
    return median(ioArray);
  },

  /**
   * Get the quantile
   * @param iSortedArray
   * @param iQuantile {Number} quantile [0.0-1.0] to calculate, e.g. first quartile = 0.25
   * @return {Number} median value or undefined if ioArray.length===0
   */
  quantileOfSortedArray: function (iSortedArray, iQuantile) {
    var lastIndex = iSortedArray.length - 1,
        i = lastIndex * iQuantile, // quantile's numeric-real index in 0-(n-1) array
        i1 = Math.floor(i),
        i2 = Math.ceil(i),
        fraction = i - i1;
    if (i < 0) {
      return undefined; // length === 0, or iQuantile < 0.0
    } else if (i >= lastIndex) {
      return iSortedArray[lastIndex]; // iQuantile >= 1.0
    } else if (i === i1) {
      return iSortedArray[i1]; // quantile falls on data value exactly
    } else {
      // quantile between two data values;
      // note that quantile algorithms vary on method used to get value here, there is no fixed standard.
      return (iSortedArray[i2] * fraction + iSortedArray[i1] * (1.0 - fraction));
    }
  },

  /**
   * For the given array of number, compute the quantiles
   *  [ minValue, 1/iNumQuantiles quantile, ..., maxValue]
   *  Note that the given array is modified; i.e. sorted.
   *  The returned array has iNumQuantiles + 1 members.
   * @param ioValues {number[]}
   * @param iNumQuantiles {number}
   * @returns {number[]}
   */
  nQuantileValues: function (ioValues, iNumQuantiles) {

    function lessThan(a, b) {
      return a - b;
    } // for ascending numeric sort()

    var tQValues = [];
    ioValues.sort(lessThan);
    for (var tQuantile = 0; tQuantile <= iNumQuantiles; tQuantile++) {
      tQValues.push(DG.MathUtilities.quantileOfSortedArray(ioValues, tQuantile / iNumQuantiles));
    }

    return tQValues;
  },

  tAt0975ForDf: function( iDf) {
    var foundIndex = DG.stat_constants.t_quantile_at_0975_for_df.findIndex( function( iPair) {
      return iPair[0] > iDf;
    });
    return foundIndex <= 0 ? 1.96 : DG.stat_constants.t_quantile_at_0975_for_df[ foundIndex - 1][1];
  },

  /**
   * Returns an object that has the slope and intercept
   * @param iCoordPairs {[{x: {Number}, y: {Number}}]}
   * @returns {{count: {Number}, xSum: {Number}, xSumSquaredDeviations: { Number},
   *          ySum: {Number}, ySumSquaredDeviations: {Number}, sumOfProductDiffs: {Number} }}
   */
  computeBivariateStats: function (iCoordPairs) {
    var tResult = {
          count: 0,
          xSum: 0,
          xMean: 0,
          xSumSquaredDeviations: 0,
          ySum: 0,
          yMean: 0,
          ySumSquaredDeviations: 0,
          sumOfProductDiffs: 0
        },
        tSumDiffsX = 0,
        tSumDiffsY = 0;
    // Under certain circumstances (adding new case) an empty value can sneak in here. Filter out.
    iCoordPairs = iCoordPairs.filter(function( iPair) {
      return !(SC.empty(iPair.x) || SC.empty(iPair.y));
    });
    iCoordPairs.forEach(function (iPair) {
      if (isFinite(iPair.x) && isFinite(iPair.y)) {
        tResult.count += 1;
        tResult.xSum += iPair.x;
        tResult.ySum += iPair.y;
      }
    });
    if (tResult.count > 0) {
      tResult.xMean = tResult.xSum / tResult.count;
      tResult.yMean = tResult.ySum / tResult.count;
      iCoordPairs.forEach(function (iPair) {
        var tDiffX, tDiffY;
        if (isFinite(iPair.x) && isFinite(iPair.y)) {
          tResult.sumOfProductDiffs += (iPair.x - tResult.xMean) * (iPair.y - tResult.yMean);
          tDiffX = iPair.x - tResult.xMean;
          tResult.xSumSquaredDeviations += tDiffX * tDiffX;
          tSumDiffsX += tDiffX;
          tDiffY = iPair.y - tResult.yMean;
          tResult.ySumSquaredDeviations += tDiffY * tDiffY;
          tSumDiffsY += tDiffY;
        }
      });
      // Subtract a correction factor for roundoff error.
      // See Numeric Recipes in C, section 14.1 for details.
      tResult.xSumSquaredDeviations -= (tSumDiffsX * tSumDiffsX / tResult.count);
      tResult.ySumSquaredDeviations -= (tSumDiffsY * tSumDiffsY / tResult.count);
    }
    return tResult;
  },

  /**
   * Returns the correlation coefficient for the coordinates in the array
   * @param iCoords {[{x: {Number}, y: {Number}}]}
   * @returns {Number}
   */
  correlation: function (iCoords) {
    var tResult = NaN,
        tBiStats = DG.MathUtilities.computeBivariateStats(iCoords);
    if (tBiStats.count > 1) {
      tResult = Math.sqrt(tBiStats.sumOfProductDiffs * tBiStats.sumOfProductDiffs /
          (tBiStats.xSumSquaredDeviations * tBiStats.ySumSquaredDeviations));
      if (tBiStats.sumOfProductDiffs < 0)
        tResult = -tResult;
    }
    return tResult;
  },

  /**
   * Returns the square of the correlation coefficient for the coordinates in the array
   * @param iCoords {[{x: {Number}, y: {Number}}]}
   * @returns {Number}
   */
  rSquared: function (iCoords) {
    var tResult = NaN,
        tBiStats = DG.MathUtilities.computeBivariateStats(iCoords);
    if (tBiStats.count > 1) {
      tResult = (tBiStats.sumOfProductDiffs * tBiStats.sumOfProductDiffs) /
          (tBiStats.xSumSquaredDeviations * tBiStats.ySumSquaredDeviations);
    }
    return tResult;
  },

  /**
   * Returns the slope of the lsrl fitting the coordinates
   * @param iCoords {[{x: {Number}, y: {Number}}]}
   * @param iInterceptLocked {Boolean}
   * @returns {Number}
   */
  linRegrSlope: function (iCoords, iInterceptLocked) {
    var tResult = NaN,
        tBiStats = DG.MathUtilities.computeBivariateStats(iCoords);
    if (tBiStats.count > 1) {
      if (iInterceptLocked) {
        tResult = (tBiStats.sumOfProductDiffs + tBiStats.xMean * tBiStats.ySum) /
            (tBiStats.xSumSquaredDeviations + tBiStats.xMean * tBiStats.xSum);
      }
      else {
        tResult = tBiStats.sumOfProductDiffs / tBiStats.xSumSquaredDeviations;
      }
    }
    return tResult;
  },

  /**
   * Returns the intercept of the lsrl fitting the coordinates
   * @param iCoords {[{x: {Number}, y: {Number}}]}
   * @param iInterceptLocked {Boolean}
   * @returns {Number}
   */
  linRegrIntercept: function (iCoords, iInterceptLocked) {
    var tResult = NaN,
        tBiStats = DG.MathUtilities.computeBivariateStats(iCoords),
        tSlope = tBiStats.sumOfProductDiffs / tBiStats.xSumSquaredDeviations;
    if (tBiStats.count > 1) {
      if (iInterceptLocked) {
        tResult = 0;
      }
      else {
        tResult = tBiStats.yMean - tSlope * tBiStats.xMean;
      }
    }
    return tResult;
  },

  /**
   * Returns an object that has the slope and intercept
   * @param iValues {[{x: {Number}, y: {Number}}]}
   * @param iInterceptLocked {Boolean}
   * @returns {{count: {Number}, xMean: {Number}, xSumSquaredDeviations: { Number},
   *         slope: {Number}, intercept: {Number}, sse: {Number}, mse: {Number},
   *         rSquared: {Number}, sdResiduals: {Number} }}
   */
  leastSquaresLinearRegression: function (iValues, iInterceptLocked) {
    var tSlopeIntercept = {
         count: null,
         xMean: null,
         xSumSquaredDeviations: null,
         slope: null,
         intercept: null,
         sse: 0,  // sum of squared errors
         mse: null, // mean squared error
         rSquared: null,
         sdResiduals: null
       },
        tBiStats = DG.MathUtilities.computeBivariateStats(iValues);
    if (tBiStats.count > 1) {
      if (iInterceptLocked) {
        tSlopeIntercept.slope = (tBiStats.sumOfProductDiffs + tBiStats.xMean * tBiStats.ySum) /
            (tBiStats.xSumSquaredDeviations + tBiStats.xMean * tBiStats.xSum);
        tSlopeIntercept.intercept = 0;
      }
      else {
        tSlopeIntercept.count = tBiStats.count;
        tSlopeIntercept.xMean = tBiStats.xMean;
        tSlopeIntercept.yMean = tBiStats.yMean;
        tSlopeIntercept.xSumSquaredDeviations = tBiStats.xSumSquaredDeviations;
        tSlopeIntercept.slope = tBiStats.sumOfProductDiffs / tBiStats.xSumSquaredDeviations;
        tSlopeIntercept.intercept = tBiStats.yMean - tSlopeIntercept.slope * tBiStats.xMean;
        tSlopeIntercept.rSquared = (tBiStats.sumOfProductDiffs * tBiStats.sumOfProductDiffs) /
            (tBiStats.xSumSquaredDeviations * tBiStats.ySumSquaredDeviations);
        // Now that we have the slope and intercept, we can compute the sum of squared errors
        iValues.forEach(function (iPair) {
          if (isFinite(iPair.x) && isFinite(iPair.y)) {
            var tResidual = iPair.y - (tSlopeIntercept.intercept + tSlopeIntercept.slope * iPair.x);
            tSlopeIntercept.sse += tResidual * tResidual;
          }
        });
        tSlopeIntercept.sdResiduals = Math.sqrt(tSlopeIntercept.sse / (tBiStats.count - 2));
        tSlopeIntercept.mse = tSlopeIntercept.sse / (tSlopeIntercept.count - 2);
      }
    }
    return tSlopeIntercept;
  },

  /**
   * Returns the standard errors of the slope and intercept of the lsrl fitting the coordinates
   * Note that we do not compute standard errors for the situation in which the intercept is locked.
   * @param iCoords {[{x: {Number}, y: {Number}}]}
   * @returns {seSlope:number, seIntercept:number}
   */
  linRegrSESlopeAndIntercept: function (iCoords) {
    var tResult = { seSlope: NaN, seIntercept: NaN },
       tSlopeIntercept = DG.MathUtilities.leastSquaresLinearRegression(iCoords, false);
    if (tSlopeIntercept.count > 1) {
      tResult.seSlope = Math.sqrt((tSlopeIntercept.sse / (tSlopeIntercept.count - 2)) /
                          tSlopeIntercept.xSumSquaredDeviations);
      tResult.seIntercept = Math.sqrt(tSlopeIntercept.sse / (tSlopeIntercept.count - 2)) *
          Math.sqrt(1 / tSlopeIntercept.count + Math.pow(tSlopeIntercept.xMean, 2) /
              tSlopeIntercept.xSumSquaredDeviations);
    }
    return tResult;
  },

  normal: function(x, amp, mu, sigma) {
    var exponent = -(Math.pow(x - mu, 2) / (2 * Math.pow(sigma, 2)));
    return amp * Math.exp(exponent);
  },

  /**
   * Gradient descent algorithm that fits a gaussian to points that are typically the top-middles of
   * a histogram by least squares optimizing mu and sigma. The amplitude is assumed to be fixed.
   * @param points {{x: number, y: number}[]}
   * @param amp {number}  // a fixed value for the amplitude
   * @param mu0 {number}  // initial guess for mu
   * @param sigma0 {number}  // initial guess for sigma
   * @returns {{mu: number, sigma: number}}
   */
  fitGaussianGradientDescent: function(points, amp, mu0, sigma0) {

    function sumOfSquares(points1, amp1, mu1, sigma1) {
      return points1.reduce(function(sum, p) {
        return sum + Math.pow(p.y - DG.MathUtilities.normal(p.x, amp1, mu1, sigma1), 2);
      }, 0);
    }

    // Function to compute the gradient of f at (x, y)
    function gradient(f, x, y, h) {
      h = h || 1e-3;
      var fxPlus = f(x + h, y),
        fxMinus = f(x - h, y),
        dfdx = (fxPlus - fxMinus) / (2 * h),
        fyPlus = f(x, y + h),
        fyMinus = f(x, y - h),
        dfdy = (fyPlus - fyMinus) / (2 * h);
      return [dfdx, dfdy];
    }

    // Gradient Descent function to find local minimum of f(x, y)
    function gradientDescent(f, x0, y0, numericRange) {

/*
      function logIt() {
        var log = '%@: x = %@, y = %@, dfdx = %@, dfdy = %@, prevValue = %@, newValue = %@'
           .loc(i, x.toFixed(6), y.toFixed(6),
              dfdx.toFixed(6), dfdy.toFixed(6), prevValue.toFixed(6), newValue.toFixed(6));
        console.log(log);
      }
*/

      var learningRate = 0.001,
         iterations = 1000,
         tolerance = 1e-5,
         x = x0, y = y0, prevValue = f(x, y)/*,
         logInterval = iterations / 10*/;

      for (var i = 0; i < iterations; i++) {
        var gradient_ = gradient(f, x, y, numericRange / 100),
            dfdx = gradient_[0],
            dfdy = gradient_[1];

        // Update x and y
        x -= learningRate * dfdx;
        y -= learningRate * dfdy;

        var newValue = f(x, y);
/*
        if (i % logInterval <= 1) {
          logIt();
        }
*/
        if (Math.abs(newValue - prevValue) < tolerance) {
          // logIt();
          break;
        }
        prevValue = newValue;
      }

      return [x, y];
    }

    /**
     * We define this function to pass to gradientDescent, which expects a function of two variables.
     * @param mu
     * @param sigma
     * @returns {*}
     */
    function fToMinimize(mu, sigma) {
      return sumOfSquares(points, amp, mu, sigma);
    }

    var muSigma = gradientDescent(fToMinimize, mu0, sigma0, sigma0);

    return { mu: muSigma[0], sigma: muSigma[1] };
  },

  /**
   * Is the value a finite number? Unlike the global "isFinite", returns
   * false for (null || undefined || "").  Strings or Booleans are converted
   * to Numbers in the usual way.
   * @param val
   * @return {Boolean} true if the value is finite.
   */
  isFinite: function (val) {
    return !SC.empty(val) && isFinite(val);
  },

  /**
   * Is the specified value numeric? Unlike the global "isNaN", returns
   * false for (null || undefined || "").  Strings or Booleans are converted
   * to Numbers in the usual way.
   * @param val
   * @return {Boolean} true if the value is numeric
   */
  isNumeric: function (val) {
    return !SC.empty(val) && !isNaN(val);
  },

  /**
   * Returns the numeric value for numbers and null for all other types.
   * @param   {any} val - the value whose numeric value is requested
   * @return  {Number|null}  the numeric value where possible, otherwise null
   */
  getNumeric: function (val) {
    return !SC.empty(val) && !isNaN(val) ? Number(val) : null;
  },

  /**
   * @private A private variant of Array.prototype.map that supports the index
   * property.
   */
  map: function (array, f) {
    var o = {};
    return f
        ? array.map(function (d, i) {
          o.index = i;
          return f.call(o, d);
        })
        : array.slice();
  },

  /**
   * Returns <tt>this.index</tt>. This method is provided for convenience for use
   * with scales. For example, to color bars by their index, say:
   *
   * <pre>.fillStyle(pv.Colors.category10().by(pv.index))</pre>
   *
   * This method is equivalent to <tt>function() this.index</tt>, but more
   * succinct. Note that the <tt>index</tt> property is also supported for
   * accessor functions with {@link pv.max}, {@link pv.min} and other array
   * utility methods.
   *
   * @see pv.Scale
   * @see pv.Mark#index
   */
  index: function () {
    return this.index;
  },

  /**
   * Returns the maximum value of the specified array. If the specified array is
   * not an array of numbers, an optional accessor function <tt>f</tt> can be
   * specified to map the elements to numbers. See {@link #normalize} for an
   * example. Accessor functions can refer to <tt>this.index</tt>.
   *
   * @param {array} array an array of objects, or numbers.
   * @param {function} [f] an optional accessor function.
   * @returns {number} the maximum value of the specified array.
   */
  max: function (array, f) {
    if (f === DG.MathUtilities.index) return array.length - 1;
    return Math.max.apply(null, f ? DG.MathUtilities.map(array, f) : array);
  },

  /**
   * Returns an array of numbers, starting at <tt>start</tt>, incrementing by
   * <tt>step</tt>, until <tt>stop</tt> is reached. The stop value is
   * exclusive. If only a single argument is specified, this value is interpeted
   * as the <i>stop</i> value, with the <i>start</i> value as zero. If only two
   * arguments are specified, the step value is implied to be one.
   *
   * <p>The method is modeled after the built-in <tt>range</tt> method from
   * Python. See the Python documentation for more details.
   *
   * @see <a href="http://docs.python.org/library/functions.html#range">Python range</a>
   * @param {number} [start] the start value.
   * @param {number} stop the stop value.
   * @param {number} [step] the step value.
   * @returns {number[]} an array of numbers.
   */
  range: function (start, stop, step) {
    if (arguments.length === 1) {
      stop = start;
      start = 0;
    }
    if (step === undefined) step = 1;
    if ((stop - start) / step === Infinity) throw new Error("range must be finite");
    var array = [], i = 0, j;
    stop -= (stop - start) * 1e-10; // floating point precision!
    if (step < 0) {
      while ((j = start + step * i++) > stop) {
        array.push(j);
      }
    } else {
      while ((j = start + step * i++) < stop) {
        array.push(j);
      }
    }
    return array;
  },

  /**
   Computes a good major tick value from a trial value. It will be the next
   lowest value of the form 1, 2, 5, 10, ...
   @param {Number} iTrial - a suggested tick value
   */
  goodTickValue: function( iTrial) {
    // A zero trial means that the values we're going to plot either don't
    // exist or are all zero. Return 1 as an arbitrary choice.
    if( iTrial === 0)
      return 1;

    // We move to base 10 so we can get rid of the power of ten.
    var tLogTrial = Math.log( iTrial) / Math.LN10,
        tFloor = Math.floor(tLogTrial),
        tPower = Math.pow(10.0, tFloor),

        // Whatever is left is in the range 1 to 10. Choose desired number
        tBase = Math.pow(10.0, tLogTrial - tFloor);

    if (tBase < 2) tBase = 1;
    else if (tBase < 5) tBase = 2;
    else tBase = 5;

    return Math.max( tPower * tBase, Number.MIN_VALUE);
  },

  // if a number is not an integer, if it less than 0 (we don't handle BC)
  // or greater than 10,000 we assume it does not represent a year.
  notAYear: function(num) {
    return (Math.round(num)!== num ||
      num < 0 ||
      num >= 10000
  );
}


};

DG.isFinite = DG.MathUtilities.isFinite;
DG.isNumeric = DG.MathUtilities.isNumeric;
DG.getNumeric = DG.MathUtilities.getNumeric;

/* >>>>>>>>>> BEGIN source/utilities/measure_text.js */
// ==========================================================================
//  
//  Author:   jsandoe
//
//  Copyright (c) 2016 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
/**
 * A utility to measure the width of text.
 *
 * @param text {string} this text to measure
 * @param iStyle {object} font attributes if not default
 */
DG.measureText = (function () {
  /**
   * Whether or not the element contents being measured has exceeded its
   * container. This obviously depends on whether the style passed in defines
   * a container that can be exceeded. If, for example, the style specifies a
   * width and has overflow, 'auto'.
   * @param element
   * @return {boolean}
   */
  function hasOverflowed(element) {
    // For some versions of Safari, with some zoom settings, the scroll dimensions
    // exceed the client dimensions, but no overflow has occurred. We account for
    // for this possibility.
    return element.scrollHeight - 1 > element.clientHeight ||
        element.scrollWidth - 1 > element.clientWidth;
  }

  var kSelector = 'dg-text-measurer';
  var $el;

  return function (text, iStyle) {
    var style = {'font': 'initial'};
    if (iStyle) {
      style = iStyle;
    }
    $el = $('.' + kSelector);
    if ($el.length === 0) {
      $el = $('<div>').addClass(kSelector);
      $el.appendTo(document.body);
    }
    $el.attr('style', style).html(text);
    return { width: $el.outerWidth(), height: $el.outerHeight(), hasOverflowed:  hasOverflowed($el[0])};
  };
}());

/* >>>>>>>>>> BEGIN source/utilities/plugin_overlay_container.js */
// ==========================================================================
//                          DG.PluginOverlayContainer
//
//  A View that can be dragged
//
//  Author:   Takahiko Tsuchiya
//
//  Copyright (c) 2015 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================


/**
 * @class DG.PluginOverlayContainer A dummy view that handles overlay elements and drag events for plugin iframes.
 */
DG.PluginOverlayContainer = SC.View.extend({
  overlayPanes: [],

  isVisibleInWindow: true,

  isDropTarget: YES,
  isDropEnabled: YES,

  acceptDragOperation: function() {
    return YES;
  },

  dragStarted: function (iDrag, iEvent) {
    var curDoc = DG.currDocumentController();
    var dataInteractiveControllers = curDoc.get('dataInteractives');
    function getWindowCoords(view) {
      var parentView = view.parentView;
      var layout = view.get('layout');
      layout.right = (layout.width == null)?layout.right: layout.left + layout.width;
      layout.bottom = (layout.height == null)?layout.bottom: layout.top + layout.height;
      var ul = DG.ViewUtilities.viewToWindowCoordinates(
          {x: layout.left, y: layout.top+DG.ViewUtilities.kTitleBarHeight},
          parentView);
      var lr = DG.ViewUtilities.viewToWindowCoordinates({x: layout.right, y: layout.bottom}, parentView);
      return {left: ul.x, right: lr.x, top: ul.y, bottom: lr.y, width: lr.x - ul.x, height: lr.y - ul.y};
    }

    function formatDragData (op, iDragData, pos) {
      return {
        action: 'notify',
        resource: 'dragDrop[attribute]',
        values: {
          operation: op,
          text: iDragData.text,
          attribute: {
            id: iDragData.attribute.get('id'),
            name: iDragData.attribute.get('name'),
            title: iDragData.attribute.get('title')
          },
          collection: {
            id: iDragData.collection.get('id'),
            name: iDragData.collection.get('name'),
            title: iDragData.collection.get('title')
          },
          context: {
            id: iDragData.context.get('id'),
            name: iDragData.context.get('name'),
            title: iDragData.context.get('title')
          },
          position: pos
        }
      };
    }

    for (var i = 0; i < dataInteractiveControllers.length; i++) {
      var controller = dataInteractiveControllers[i];
      var view = controller.get('view');
      var viewLayout = getWindowCoords(view);

      var overlayPane = SC.Pane.extend({
        context: iDrag.getPath('data.context'),

        layout: viewLayout,

        gameController: controller,

        dragData: null,

        isVisible: true,
        isVisibleInWindow: true,

        isDropTarget: YES,
        isDropEnabled: YES,

        acceptDragOperation: function() {
          return YES;
        },

        dragEntered: function (iDrag) {
          curDoc.notificationManager.sendChannelNotification(this.gameController,
              formatDragData('dragenter', iDrag.data));
        },

        dragExited: function (iDrag) {
          curDoc.notificationManager.sendChannelNotification(this.gameController,
              formatDragData('dragleave', iDrag.data));
        },

        dragUpdated: function (iDrag) {
          var iFrameRect = this.layout;
          var x = iDrag.getPath('location.x');
          var y = iDrag.getPath('location.y');

          // TODO: use drag enter / exit info?
          if (x >= iFrameRect.left && x <= iFrameRect.right && y >= iFrameRect.top && y <= iFrameRect.bottom) {
            curDoc.notificationManager.sendChannelNotification(this.gameController,
                formatDragData('drag', iDrag.data, {x: x-iFrameRect.left, y: y - iFrameRect.top}));
          }
        },

        isValidAttribute: function (iDrag) {
          var tDragAttr = iDrag.data.attribute;
          var tAttrs = this.get('context').getAttributes();
          return tAttrs.indexOf(tDragAttr) >= 0;
        },

        computeDragOperations: function (iDrag) {
          return this.isValidAttribute(iDrag) ? SC.DRAG_LINK : SC.DRAG_NONE;
        },

        performDragOperation: function (iDrag) {
          var iFrameRect = this.layout;
          var x = iDrag.getPath('location.x');
          var y = iDrag.getPath('location.y');

          if (x >= iFrameRect.left && x <= iFrameRect.right && y >= iFrameRect.top && y <= iFrameRect.bottom) {
            curDoc.notificationManager.sendChannelNotification(this.gameController,
                formatDragData('drop', iDrag.data, {x: x-iFrameRect.left, y: y - iFrameRect.top}));
          }
          return SC.DRAG_LINK;
        },

        dragStarted: function (iDrag) {
          curDoc.notificationManager.sendChannelNotification(this.gameController,
              formatDragData('dragstart', iDrag.data));
        },

        dragEnded: function (iDrag) {
          curDoc.notificationManager.sendChannelNotification(this.gameController,
              formatDragData('dragend', iDrag.data));
        }
      }).create();

      overlayPane.appendTo(document.body);
      this.overlayPanes.pushObject(overlayPane);

      // Manually add to the global pool of the drop targets.
      iDrag._cachedDropTargets.pushObject(overlayPane);
      // DG.Drag.addDropTarget(overlayPane); // Does not work this way?

      // Since the overlay views are created after the global drag-event notifications, we have to manually invoke the drag operation on them.
      overlayPane.tryToPerform('dragStarted', iDrag, iEvent);
    }
  },

  dragEnded: function (iDrag, iEvent) {
    this.overlayPanes.forEach(function (overlayPane) {
      // Manually invoke the drag operation.
      overlayPane.tryToPerform('dragEnded', iDrag, iEvent);

      // This seems to conflict with something else (possibly the native cache clearing?)
      // iDrag._cachedDropTargets.removeObject(overlayPane);
      // DG.Drag.removeDropTarget(overlayPane); // Does not work.

      overlayPane.remove();
      overlayPane.destroy();
    }.bind(this));

    this.overlayPanes = [];
  }
});

/* >>>>>>>>>> BEGIN source/utilities/pv_color.js */
/**
 * Taken from Mike Bostock's Protovis project <http://mbostock.github.io/protovis/>. Thank you!
 *
 * Returns the {@link DG.Color} for the specified color format string. Colors
 * may have an associated opacity, or alpha channel. Color formats are specified
 * by CSS Color Modular Level 3, using either in RGB or HSL color space. For
 * example:<ul>
 *
 * <li>#f00 // #rgb
 * <li>#ff0000 // #rrggbb
 * <li>rgb(255, 0, 0)
 * <li>rgb(100%, 0%, 0%)
 * <li>hsl(0, 100%, 50%)
 * <li>rgba(0, 0, 255, 0.5)
 * <li>hsla(120, 100%, 50%, 1)
 *
 * </ul>The SVG 1.0 color keywords names are also supported, such as "aliceblue"
 * and "yellowgreen". The "transparent" keyword is supported for fully-
 * transparent black.
 *
 * <p>If the <tt>format</tt> argument is already an instance of <tt>Color</tt>,
 * the argument is returned with no further processing.
 *
 * @param {string} format the color specification string, such as "#f00".
 * @returns {DG.Color} the corresponding <tt>Color</tt>.
 * @see <a href="http://www.w3.org/TR/SVG/types.html#ColorKeywords">SVG color
 * keywords</a>
 * @see <a href="http://www.w3.org/TR/css3-color/">CSS3 color module</a>
 */
DG.color = function(format) {
  function parse(c) { // either integer or percentage
    var f = parseFloat(c);
    return (c[c.length - 1] === '%') ? Math.round(f * 2.55) : f;
  }
  var r, g, b, h, s, l, m1, m2, a;
  if (format.rgb) return format.rgb();

  /* Handle hsl, rgb. */
  m1 = /([a-z]+)\((.*)\)/i.exec(format);
  if (m1) {
    m2 = m1[2].split(",");
    a = 1;
    switch (m1[1]) {
      case "hsla":
      case "rgba": {
        a = parseFloat(m2[3]);
        if (!a) return DG.Color.transparent;
        break;
      }
    }
    switch (m1[1]) {
      case "hsla":
      case "hsl": {
        h = parseFloat(m2[0]); // degrees
        s = parseFloat(m2[1]) / 100; // percentage
        l = parseFloat(m2[2]) / 100; // percentage
        return (new DG.Color.Hsl(h, s, l, a)).rgb();
      }
      case "rgba":
      case "rgb": {
        r = parse(m2[0]);
        g = parse(m2[1]);
        b = parse(m2[2]);
        return DG.rgb(r, g, b, a);
      }
    }
  }

  /* Named colors. */
  // Not needed for DG
//  var named = DG.Color.names[format];
//  if (named) return named;

  /* Hexadecimal colors: #rgb and #rrggbb. */
  if (format.charAt(0) === "#") {
    if (format.length === 4) {
      r = format.charAt(1); r += r;
      g = format.charAt(2); g += g;
      b = format.charAt(3); b += b;
    } else if (format.length === 7) {
      r = format.substring(1, 3);
      g = format.substring(3, 5);
      b = format.substring(5, 7);
    }
    return DG.rgb(parseInt(r, 16), parseInt(g, 16), parseInt(b, 16), 1);
  }

  /* Otherwise, pass-through unsupported colors. */
  return new DG.Color(format, 1);
};

/**
 * Constructs a color with the specified color format string and opacity. This
 * constructor should not be invoked directly; use {@link DG.color} instead.
 *
 * @class Represents an abstract (possibly translucent) color. The color is
 * divided into two parts: the <tt>color</tt> attribute, an opaque color format
 * string, and the <tt>opacity</tt> attribute, a float in [0, 1]. The color
 * space is dependent on the implementing class; all colors support the
 * {@link #rgb} method to convert to RGB color space for interpolation.
 *
 * <p>See also the <a href="../../api/Color.html">Color guide</a>.
 *
 * @param {string} color an opaque color format string, such as "#f00".
 * @param {number} opacity the opacity, in [0,1].
 * @see DG.color
 */
DG.Color = function(color, opacity) {
  /**
   * An opaque color format string, such as "#f00".
   *
   * @type string
   * @see <a href="http://www.w3.org/TR/SVG/types.html#ColorKeywords">SVG color
   * keywords</a>
   * @see <a href="http://www.w3.org/TR/css3-color/">CSS3 color module</a>
   */
  this.color = color;

  /**
   * The opacity, a float in [0, 1].
   *
   * @type number
   */
  this.opacity = opacity;
};

/**
 * Returns a new color that is a brighter version of this color. The behavior of
 * this method may vary slightly depending on the underlying color space.
 * Although brighter and darker are inverse operations, the results of a series
 * of invocations of these two methods might be inconsistent because of rounding
 * errors.
 *
 * @param [k] {number} an optional scale factor; defaults to 1.
 * @see #darker
 * @returns {DG.Color} a brighter color.
 */
DG.Color.prototype.brighter = function(k) {
  return this.rgb().brighter(k);
};

/**
 * Returns a new color that is a brighter version of this color. The behavior of
 * this method may vary slightly depending on the underlying color space.
 * Although brighter and darker are inverse operations, the results of a series
 * of invocations of these two methods might be inconsistent because of rounding
 * errors.
 *
 * @param [k] {number} an optional scale factor; defaults to 1.
 * @see #brighter
 * @returns {DG.Color} a darker color.
 */
DG.Color.prototype.darker = function(k) {
  return this.rgb().darker(k);
};

/**
 * Constructs a new RGB color with the specified channel values.
 *
 * @param {number} r the red channel, an integer in [0,255].
 * @param {number} g the green channel, an integer in [0,255].
 * @param {number} b the blue channel, an integer in [0,255].
 * @param {number} [a] the alpha channel, a float in [0,1].
 * @returns DG.Color.Rgb
 */
DG.rgb = function(r, g, b, a) {
  return new DG.Color.Rgb(r, g, b, (arguments.length === 4) ? a : 1);
};

/**
 * Constructs a new RGB color with the specified channel values.
 *
 * @class Represents a color in RGB space.
 *
 * @param {number} r the red channel, an integer in [0,255].
 * @param {number} g the green channel, an integer in [0,255].
 * @param {number} b the blue channel, an integer in [0,255].
 * @param {number} a the alpha channel, a float in [0,1].
 * @extends DG.Color
 */
DG.Color.Rgb = function(r, g, b, a) {
  DG.Color.call(this, a ? ("rgb(" + r + "," + g + "," + b + ")") : "none", a);

  /**
   * The red channel, an integer in [0, 255].
   *
   * @type number
   */
  this.r = r;

  /**
   * The green channel, an integer in [0, 255].
   *
   * @type number
   */
  this.g = g;

  /**
   * The blue channel, an integer in [0, 255].
   *
   * @type number
   */
  this.b = b;

  /**
   * The alpha channel, a float in [0, 1].
   *
   * @type number
   */
  this.a = a;
};
DG.Color.Rgb.prototype = SC.extend(DG.Color);

/**
 * Constructs a new RGB color with the same green, blue and alpha channels as
 * this color, with the specified red channel.
 *
 * @param {number} r the red channel, an integer in [0,255].
 */
DG.Color.Rgb.prototype.red = function(r) {
  return DG.rgb(r, this.g, this.b, this.a);
};

/**
 * Constructs a new RGB color with the same red, blue and alpha channels as this
 * color, with the specified green channel.
 *
 * @param {number} g the green channel, an integer in [0,255].
 */
DG.Color.Rgb.prototype.green = function(g) {
  return DG.rgb(this.r, g, this.b, this.a);
};

/**
 * Constructs a new RGB color with the same red, green and alpha channels as
 * this color, with the specified blue channel.
 *
 * @param {number} b the blue channel, an integer in [0,255].
 */
DG.Color.Rgb.prototype.blue = function(b) {
  return DG.rgb(this.r, this.g, b, this.a);
};

/**
 * Constructs a new RGB color with the same red, green and blue channels as this
 * color, with the specified alpha channel.
 *
 * @param {number} a the alpha channel, a float in [0,1].
 */
DG.Color.Rgb.prototype.alpha = function(a) {
  return DG.rgb(this.r, this.g, this.b, a);
};

/**
 * Returns the RGB color equivalent to this color. This method is abstract and
 * must be implemented by subclasses.
 *
 * @returns {DG.Color.Rgb} an RGB color.
 * @function
 * @name DG.Color.prototype.rgb
 */

/**
 * Returns this.
 *
 * @returns {DG.Color.Rgb} this.
 */
DG.Color.Rgb.prototype.rgb = function() { return this; };

/**
 * Returns a new color that is a brighter version of this color. This method
 * applies an arbitrary scale factor to each of the three RGB components of this
 * color to create a brighter version of this color. Although brighter and
 * darker are inverse operations, the results of a series of invocations of
 * these two methods might be inconsistent because of rounding errors.
 *
 * @param [k] {number} an optional scale factor; defaults to 1.
 * @see #darker
 * @returns {DG.Color.Rgb} a brighter color.
 */
DG.Color.Rgb.prototype.brighter = function(k) {
  k = Math.pow(0.7, arguments.length ? k : 1);
  var r = this.r, g = this.g, b = this.b, i = 30;
  if (!r && !g && !b) return DG.rgb(i, i, i, this.a);
  if (r && (r < i)) r = i;
  if (g && (g < i)) g = i;
  if (b && (b < i)) b = i;
  return DG.rgb(
      Math.min(255, Math.floor(r / k)),
      Math.min(255, Math.floor(g / k)),
      Math.min(255, Math.floor(b / k)),
      this.a);
};

/**
 * Returns a new color that is a darker version of this color. This method
 * applies an arbitrary scale factor to each of the three RGB components of this
 * color to create a darker version of this color. Although brighter and darker
 * are inverse operations, the results of a series of invocations of these two
 * methods might be inconsistent because of rounding errors.
 *
 * @param [k] {number} an optional scale factor; defaults to 1.
 * @see #brighter
 * @returns {DG.Color.Rgb} a darker color.
 */
DG.Color.Rgb.prototype.darker = function(k) {
  k = Math.pow(0.7, arguments.length ? k : 1);
  return DG.rgb(
      Math.max(0, Math.floor(k * this.r)),
      Math.max(0, Math.floor(k * this.g)),
      Math.max(0, Math.floor(k * this.b)),
      this.a);
};


/* >>>>>>>>>> BEGIN source/utilities/raphael_layer.js */
// ==========================================================================
//                                DG.RaphaelLayer
// 
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('libraries/raphael');

/**
 * @class
 *
 * A single RaphaelLayer consists primarily of a pointer to the first element in the layer and a pointer to the
 * last element in the layer.
 *
 * @extends SC.Object
 */
DG.RaphaelLayer = SC.Object.extend(
  {
    name: null,

    _map: null,
    /**
     * @property {Boolean}
     */
    isVisible: true,

    /**
     * The layer that precedes this one; i.e. that is visibly 'below' this one. If null, we are the first layer.
     * @property {DG.RaphaelLayer}
     */
    _prevLayer: null,

    /**
     * The first element in this layer. If null, this layer has no elements.
     * @property {Raphael Element}
     */
    _firstElement: null,

    /**
     * The last element in this layer. If null, this layer has no elements.
     * @property {Raphael Element}
     */
    _lastElement: null,

    /**
     * The paper to which all elements belong
     * @property {Raphael Paper}
     */
    _paper: null,

    init: function() {
      arguments.callee.base.apply(this,arguments);
      if( SC.empty( this.name))
        this.name = 'unnamed';
      this._firstElement = this._lastElement = null;
      this._map = {};
    },

    /**
     * Remove all elements belonging to me.
     */
    clear: function() {
      this.forEach( function( iElement) {
        iElement.remove();
      });
      this._firstElement = this._lastElement = null;
      this._map = {};
    },

    /**
     * Positions the given element as the last (top) element in this layer.
     * @param iElement {Raphael Element}
     * @return {Raphael Element } The original element
     */
    push: function( iElement) {
/*
      this.isValid();
      DG.RenderingUtilities.testPaperValidity( this._paper);
*/
      DG.assert( iElement);
      if( !this._paper.bottom) // We nulled this out in preparation for this push
        this._paper.bottom = iElement;
      if( !this._map[iElement.id]) {  // If it's not already present in the layer
        this._map[iElement.id] = true;
        if (!(this._lastElement && this._lastElement.node)) {
          // We have no elements, so this becomes our first. We need to insert after previous layer's last Element.
          // But if there is no previous layer with a last element, then the given element moves to the paper's back.
          var tLayer;
          for (tLayer = this._prevLayer; tLayer; tLayer = tLayer._prevLayer) {
            if (tLayer && tLayer._lastElement) {
              break;
            }
          }
          if (tLayer) {
            iElement.insertAfter(tLayer._lastElement);
            // DG.RenderingUtilities.testPaperValidity( this._paper);
          }
          else
            iElement.toBack();
        }
        else {
          iElement.insertAfter(this._lastElement);
          // DG.RenderingUtilities.testPaperValidity( this._paper);
        }
        this._lastElement = iElement;
        if (!this._firstElement) {
          this._firstElement = iElement;
        }
        DG.assert(iElement.next || (iElement === this._lastElement));
      }
/*
      this.isValid();
      DG.RenderingUtilities.testPaperValidity( this._paper);
*/
      return iElement;
    },

    /**
     * The given element is about to be removed from paper or moved to another layer. If it is either _firstElement or
     * _lastElement, we have to adjust.
     * @param iElement {Raphael Element}
     */
    prepareToMoveOrRemove: function( iElement) {
/*
      this.isValid();
      DG.RenderingUtilities.testPaperValidity( this._paper);
*/
      // Special cases for which iElement is at the bottom or top of the paper
      if( iElement === this._paper.bottom) {
        this._paper.bottom = iElement.next;
        if( this._paper.bottom)
          this._paper.bottom.prev = null;
      }
      if( iElement === this._paper.top) {
        this._paper.top = iElement.prev;
        if( this._paper.top)
          this._paper.top.next = null;
      }
      if( iElement === this._firstElement) {
        if( this._firstElement === this._lastElement) {
          // After the move there will be no more elements in this layer
          this._firstElement = this._lastElement = null;
        }
        else
          this._firstElement = iElement.next;
      }
      else if( iElement === this._lastElement) {
        this._lastElement = iElement.prev;
      }
      if( this._map[ iElement.id]) {
        if( iElement.prev && iElement.prev.next === iElement)
          iElement.prev.next = iElement.next;
        if( iElement.next && iElement.next.prev === iElement)
          iElement.next.prev = iElement.prev;
        delete this._map[iElement.id];
      }
/*
      this.isValid();
      DG.RenderingUtilities.testPaperValidity( this._paper);
*/
    },

    forEach: function( iCallback) {
      var tElement, tNextElement,
          tIndex = 0;
      for( tElement = this._firstElement; tElement; tElement = tNextElement) {
        tNextElement = (tElement === this._lastElement) ? null : tElement.next; // In case callback messes up linkage
        iCallback( tElement, tIndex++);
      }
    },

    /**
     * Return true if the given element is in the linked list of elements between _firstElement and _lastElement
     * @param iElement { Raphael Element }
     * @return {Boolean}
     */
    contains: function( iElement) {
      return this._map[iElement.id];
    },

    /**
     *
     * @param iElement { Raphael Element }
     */
    bringToFront: function( iElement) {
      if( this.contains( iElement)) {
        this.prepareToMoveOrRemove( iElement);
        this.push( iElement);
      }
    },

    /**
     * A layer is valid if
     *  - it is empty, or there is both a first and last element, neither of which is "removed"
     *  - and if not empty you can navigate from first to last elements
     * @returns {boolean|null}
     */
    isValid: function() {
      var tIsValid = true/*,
          tOutput = 'Layer ' + this.name + '-> '*/;
      if(!this._firstElement && !this._lastElement)
        return true;
      if(!this._firstElement || !this._lastElement || this._firstElement.removed || this._lastElement.removed)
        tIsValid = false;
      else {
        var tFoundLast = false;
        this.forEach( function( iElement) {
          tIsValid = tIsValid && this._map[iElement.id];
          tFoundLast = tFoundLast || (iElement === this._lastElement);
          // tOutput += iElement.id + ': ' + DG.RenderingUtilities.svgElementClass( iElement) + ', ';
        }.bind( this));
        tIsValid = tIsValid && tFoundLast;
      }
      // console.log( tOutput);
      if( !tIsValid)
        console.log('Invalid layer: ' + this.name);
      return tIsValid;
    },

    hide: function() {
      this.set('isVisible', false);
      this.forEach( function( iElement) {
        iElement.animate({ 'fill-opacity' : 0, 'stroke-opacity': 0 },
            DG.PlotUtilities.kDefaultAnimationTime, '<>', function () { this.hide(); });
      });
    },

    /**
     *
     * @param iAttrs {Object} if specified, specifies fill-opacity and stroke-opacity to animate to
     */
    show: function( iAttrs) {
      iAttrs = iAttrs || { 'fill-opacity' : 1, 'stroke-opacity': 1 };
      this.set('isVisible', true);
      this.forEach( function( iElement) {
        iElement.show().animate( iAttrs, DG.PlotUtilities.kDefaultAnimationTime, '<>');
      });
    }

  } );

/* >>>>>>>>>> BEGIN source/utilities/remove_diacritics.js */
/*
    Adapted from http://stackoverflow.com/a/18884988.
    See http://stackoverflow.com/a/22513545 for an approach to improving performance.
 */
var defaultDiacriticsRemovalMap = [{
    'base': "A",
        'letters': /(&#65;|&#9398;|&#65313;|&#192;|&#193;|&#194;|&#7846;|&#7844;|&#7850;|&#7848;|&#195;|&#256;|&#258;|&#7856;|&#7854;|&#7860;|&#7858;|&#550;|&#480;|&#196;|&#478;|&#7842;|&#197;|&#506;|&#461;|&#512;|&#514;|&#7840;|&#7852;|&#7862;|&#7680;|&#260;|&#570;|&#11375;|[\u0041\u24B6\uFF21\u00C0\u00C1\u00C2\u1EA6\u1EA4\u1EAA\u1EA8\u00C3\u0100\u0102\u1EB0\u1EAE\u1EB4\u1EB2\u0226\u01E0\u00C4\u01DE\u1EA2\u00C5\u01FA\u01CD\u0200\u0202\u1EA0\u1EAC\u1EB6\u1E00\u0104\u023A\u2C6F])/g
}, {
    'base': "AA",
        'letters': /(&#42802;|[\uA732])/g
}, {
    'base': "AE",
        'letters': /(&#198;|&#508;|&#482;|[\u00C6\u01FC\u01E2])/g
}, {
    'base': "AO",
        'letters': /(&#42804;|[\uA734])/g
}, {
    'base': "AU",
        'letters': /(&#42806;|[\uA736])/g
}, {
    'base': "AV",
        'letters': /(&#42808;|&#42810;|[\uA738\uA73A])/g
}, {
    'base': "AY",
        'letters': /(&#42812;|[\uA73C])/g
}, {
    'base': "B",
        'letters': /(&#66;|&#9399;|&#65314;|&#7682;|&#7684;|&#7686;|&#579;|&#386;|&#385;|[\u0042\u24B7\uFF22\u1E02\u1E04\u1E06\u0243\u0182\u0181])/g
}, {
    'base': "C",
        'letters': /(&#67;|&#9400;|&#65315;|&#262;|&#264;|&#266;|&#268;|&#199;|&#7688;|&#391;|&#571;|&#42814;|[\u0043\u24B8\uFF23\u0106\u0108\u010A\u010C\u00C7\u1E08\u0187\u023B\uA73E])/g
}, {
    'base': "D",
        'letters': /(&#68;|&#9401;|&#65316;|&#7690;|&#270;|&#7692;|&#7696;|&#7698;|&#7694;|&#272;|&#395;|&#394;|&#393;|&#42873;|&#208;|[\u0044\u24B9\uFF24\u1E0A\u010E\u1E0C\u1E10\u1E12\u1E0E\u0110\u018B\u018A\u0189\uA779\u00D0])/g
}, {
    'base': "DZ",
        'letters': /(&#497;|&#452;|[\u01F1\u01C4])/g
}, {
    'base': "Dz",
        'letters': /(&#498;|&#453;|[\u01F2\u01C5])/g
}, {
    'base': "E",
        'letters': /(&#69;|&#9402;|&#65317;|&#200;|&#201;|&#202;|&#7872;|&#7870;|&#7876;|&#7874;|&#7868;|&#274;|&#7700;|&#7702;|&#276;|&#278;|&#203;|&#7866;|&#282;|&#516;|&#518;|&#7864;|&#7878;|&#552;|&#7708;|&#280;|&#7704;|&#7706;|&#400;|&#398;|[\u0045\u24BA\uFF25\u00C8\u00C9\u00CA\u1EC0\u1EBE\u1EC4\u1EC2\u1EBC\u0112\u1E14\u1E16\u0114\u0116\u00CB\u1EBA\u011A\u0204\u0206\u1EB8\u1EC6\u0228\u1E1C\u0118\u1E18\u1E1A\u0190\u018E])/g
}, {
    'base': "F",
        'letters': /(&#70;|&#9403;|&#65318;|&#7710;|&#401;|&#42875;|[\u0046\u24BB\uFF26\u1E1E\u0191\uA77B])/g
}, {
    'base': "G",
        'letters': /(&#71;|&#9404;|&#65319;|&#500;|&#284;|&#7712;|&#286;|&#288;|&#486;|&#290;|&#484;|&#403;|&#42912;|&#42877;|&#42878;|[\u0047\u24BC\uFF27\u01F4\u011C\u1E20\u011E\u0120\u01E6\u0122\u01E4\u0193\uA7A0\uA77D\uA77E])/g
}, {
    'base': "H",
        'letters': /(&#72;|&#9405;|&#65320;|&#292;|&#7714;|&#7718;|&#542;|&#7716;|&#7720;|&#7722;|&#294;|&#11367;|&#11381;|&#42893;|[\u0048\u24BD\uFF28\u0124\u1E22\u1E26\u021E\u1E24\u1E28\u1E2A\u0126\u2C67\u2C75\uA78D])/g
}, {
    'base': "I",
        'letters': /(&#73;|&#9406;|&#65321;|&#204;|&#205;|&#206;|&#296;|&#298;|&#300;|&#304;|&#207;|&#7726;|&#7880;|&#463;|&#520;|&#522;|&#7882;|&#302;|&#7724;|&#407;|[\u0049\u24BE\uFF29\u00CC\u00CD\u00CE\u0128\u012A\u012C\u0130\u00CF\u1E2E\u1EC8\u01CF\u0208\u020A\u1ECA\u012E\u1E2C\u0197])/g
}, {
    'base': "J",
        'letters': /(&#74;|&#9407;|&#65322;|&#308;|&#584;|[\u004A\u24BF\uFF2A\u0134\u0248])/g
}, {
    'base': "K",
        'letters': /(&#75;|&#9408;|&#65323;|&#7728;|&#488;|&#7730;|&#310;|&#7732;|&#408;|&#11369;|&#42816;|&#42818;|&#42820;|&#42914;|[\u004B\u24C0\uFF2B\u1E30\u01E8\u1E32\u0136\u1E34\u0198\u2C69\uA740\uA742\uA744\uA7A2])/g
}, {
    'base': "L",
        'letters': /(&#76;|&#9409;|&#65324;|&#319;|&#313;|&#317;|&#7734;|&#7736;|&#315;|&#7740;|&#7738;|&#321;|&#573;|&#11362;|&#11360;|&#42824;|&#42822;|&#42880;|[\u004C\u24C1\uFF2C\u013F\u0139\u013D\u1E36\u1E38\u013B\u1E3C\u1E3A\u0141\u023D\u2C62\u2C60\uA748\uA746\uA780])/g
}, {
    'base': "LJ",
        'letters': /(&#455;|[\u01C7])/g
}, {
    'base': "Lj",
        'letters': /(&#456;|[\u01C8])/g
}, {
    'base': "M",
        'letters': /(&#77;|&#9410;|&#65325;|&#7742;|&#7744;|&#7746;|&#11374;|&#412;|[\u004D\u24C2\uFF2D\u1E3E\u1E40\u1E42\u2C6E\u019C])/g
}, {
    'base': "N",
        'letters': /(&#78;|&#9411;|&#65326;|&#504;|&#323;|&#209;|&#7748;|&#327;|&#7750;|&#325;|&#7754;|&#7752;|&#544;|&#413;|&#42896;|&#42916;|&#330;|[\u004E\u24C3\uFF2E\u01F8\u0143\u00D1\u1E44\u0147\u1E46\u0145\u1E4A\u1E48\u0220\u019D\uA790\uA7A4\u014A])/g
}, {
    'base': "NJ",
        'letters': /(&#458;|[\u01CA])/g
}, {
    'base': "Nj",
        'letters': /(&#459;|[\u01CB])/g
}, {
    'base': "O",
        'letters': /(&#79;|&#9412;|&#65327;|&#210;|&#211;|&#212;|&#7890;|&#7888;|&#7894;|&#7892;|&#213;|&#7756;|&#556;|&#7758;|&#332;|&#7760;|&#7762;|&#334;|&#558;|&#560;|&#214;|&#554;|&#7886;|&#336;|&#465;|&#524;|&#526;|&#416;|&#7900;|&#7898;|&#7904;|&#7902;|&#7906;|&#7884;|&#7896;|&#490;|&#492;|&#216;|&#510;|&#390;|&#415;|&#42826;|&#42828;|[\u004F\u24C4\uFF2F\u00D2\u00D3\u00D4\u1ED2\u1ED0\u1ED6\u1ED4\u00D5\u1E4C\u022C\u1E4E\u014C\u1E50\u1E52\u014E\u022E\u0230\u00D6\u022A\u1ECE\u0150\u01D1\u020C\u020E\u01A0\u1EDC\u1EDA\u1EE0\u1EDE\u1EE2\u1ECC\u1ED8\u01EA\u01EC\u00D8\u01FE\u0186\u019F\uA74A\uA74C])/g
}, {
    'base': "OE",
        'letters': /(&#338;|[\u0152])/g
}, {
    'base': "OI",
        'letters': /(&#418;|[\u01A2])/g
}, {
    'base': "OO",
        'letters': /(&#42830;|[\uA74E])/g
}, {
    'base': "OU",
        'letters': /(&#546;|[\u0222])/g
}, {
    'base': "P",
        'letters': /(&#80;|&#9413;|&#65328;|&#7764;|&#7766;|&#420;|&#11363;|&#42832;|&#42834;|&#42836;|[\u0050\u24C5\uFF30\u1E54\u1E56\u01A4\u2C63\uA750\uA752\uA754])/g
}, {
    'base': "Q",
        'letters': /(&#81;|&#9414;|&#65329;|&#42838;|&#42840;|&#586;|[\u0051\u24C6\uFF31\uA756\uA758\u024A])/g
}, {
    'base': "R",
        'letters': /(&#82;|&#9415;|&#65330;|&#340;|&#7768;|&#344;|&#528;|&#530;|&#7770;|&#7772;|&#342;|&#7774;|&#588;|&#11364;|&#42842;|&#42918;|&#42882;|[\u0052\u24C7\uFF32\u0154\u1E58\u0158\u0210\u0212\u1E5A\u1E5C\u0156\u1E5E\u024C\u2C64\uA75A\uA7A6\uA782])/g
}, {
    'base': "S",
        'letters': /(&#83;|&#9416;|&#65331;|&#7838;|&#346;|&#7780;|&#348;|&#7776;|&#352;|&#7782;|&#7778;|&#7784;|&#536;|&#350;|&#11390;|&#42920;|&#42884;|[\u0053\u24C8\uFF33\u1E9E\u015A\u1E64\u015C\u1E60\u0160\u1E66\u1E62\u1E68\u0218\u015E\u2C7E\uA7A8\uA784])/g
}, {
    'base': "T",
        'letters': /(&#84;|&#9417;|&#65332;|&#7786;|&#356;|&#7788;|&#538;|&#354;|&#7792;|&#7790;|&#358;|&#428;|&#430;|&#574;|&#42886;|[\u0054\u24C9\uFF34\u1E6A\u0164\u1E6C\u021A\u0162\u1E70\u1E6E\u0166\u01AC\u01AE\u023E\uA786])/g
}, {
    'base': "TH",
        'letters': /(&#222;|[\u00DE])/g
}, {
    'base': "TZ",
        'letters': /(&#42792;|[\uA728])/g
}, {
    'base': "U",
        'letters': /(&#85;|&#9418;|&#65333;|&#217;|&#218;|&#219;|&#360;|&#7800;|&#362;|&#7802;|&#364;|&#220;|&#475;|&#471;|&#469;|&#473;|&#7910;|&#366;|&#368;|&#467;|&#532;|&#534;|&#431;|&#7914;|&#7912;|&#7918;|&#7916;|&#7920;|&#7908;|&#7794;|&#370;|&#7798;|&#7796;|&#580;|[\u0055\u24CA\uFF35\u00D9\u00DA\u00DB\u0168\u1E78\u016A\u1E7A\u016C\u00DC\u01DB\u01D7\u01D5\u01D9\u1EE6\u016E\u0170\u01D3\u0214\u0216\u01AF\u1EEA\u1EE8\u1EEE\u1EEC\u1EF0\u1EE4\u1E72\u0172\u1E76\u1E74\u0244])/g
}, {
    'base': "V",
        'letters': /(&#86;|&#9419;|&#65334;|&#7804;|&#7806;|&#434;|&#42846;|&#581;|[\u0056\u24CB\uFF36\u1E7C\u1E7E\u01B2\uA75E\u0245])/g
}, {
    'base': "VY",
        'letters': /(&#42848;|[\uA760])/g
}, {
    'base': "W",
        'letters': /(&#87;|&#9420;|&#65335;|&#7808;|&#7810;|&#372;|&#7814;|&#7812;|&#7816;|&#11378;|[\u0057\u24CC\uFF37\u1E80\u1E82\u0174\u1E86\u1E84\u1E88\u2C72])/g
}, {
    'base': "X",
        'letters': /(&#88;|&#9421;|&#65336;|&#7818;|&#7820;|[\u0058\u24CD\uFF38\u1E8A\u1E8C])/g
}, {
    'base': "Y",
        'letters': /(&#89;|&#9422;|&#65337;|&#7922;|&#221;|&#374;|&#7928;|&#562;|&#7822;|&#376;|&#7926;|&#7924;|&#435;|&#590;|&#7934;|[\u0059\u24CE\uFF39\u1EF2\u00DD\u0176\u1EF8\u0232\u1E8E\u0178\u1EF6\u1EF4\u01B3\u024E\u1EFE])/g
}, {
    'base': "Z",
        'letters': /(&#90;|&#9423;|&#65338;|&#377;|&#7824;|&#379;|&#381;|&#7826;|&#7828;|&#437;|&#548;|&#11391;|&#11371;|&#42850;|[\u005A\u24CF\uFF3A\u0179\u1E90\u017B\u017D\u1E92\u1E94\u01B5\u0224\u2C7F\u2C6B\uA762])/g
}, {
    'base': "a",
        'letters': /(&#97;|&#9424;|&#65345;|&#7834;|&#224;|&#225;|&#226;|&#7847;|&#7845;|&#7851;|&#7849;|&#227;|&#257;|&#259;|&#7857;|&#7855;|&#7861;|&#7859;|&#551;|&#481;|&#228;|&#479;|&#7843;|&#229;|&#507;|&#462;|&#513;|&#515;|&#7841;|&#7853;|&#7863;|&#7681;|&#261;|&#11365;|&#592;|[\u0061\u24D0\uFF41\u1E9A\u00E0\u00E1\u00E2\u1EA7\u1EA5\u1EAB\u1EA9\u00E3\u0101\u0103\u1EB1\u1EAF\u1EB5\u1EB3\u0227\u01E1\u00E4\u01DF\u1EA3\u00E5\u01FB\u01CE\u0201\u0203\u1EA1\u1EAD\u1EB7\u1E01\u0105\u2C65\u0250])/g
}, {
    'base': "aa",
        'letters': /(&#42803;|[\uA733])/g
}, {
    'base': "ae",
        'letters': /(&#230;|&#509;|&#483;|[\u00E6\u01FD\u01E3])/g
}, {
    'base': "ao",
        'letters': /(&#42805;|[\uA735])/g
}, {
    'base': "au",
        'letters': /(&#42807;|[\uA737])/g
}, {
    'base': "av",
        'letters': /(&#42809;|&#42811;|[\uA739\uA73B])/g
}, {
    'base': "ay",
        'letters': /(&#42813;|[\uA73D])/g
}, {
    'base': "b",
        'letters': /(&#98;|&#9425;|&#65346;|&#7683;|&#7685;|&#7687;|&#384;|&#387;|&#595;|[\u0062\u24D1\uFF42\u1E03\u1E05\u1E07\u0180\u0183\u0253])/g
}, {
    'base': "c",
        'letters': /(&#99;|&#9426;|&#65347;|&#263;|&#265;|&#267;|&#269;|&#231;|&#7689;|&#392;|&#572;|&#42815;|&#8580;|[\u0063\u24D2\uFF43\u0107\u0109\u010B\u010D\u00E7\u1E09\u0188\u023C\uA73F\u2184])/g
}, {
    'base': "d",
        'letters': /(&#100;|&#9427;|&#65348;|&#7691;|&#271;|&#7693;|&#7697;|&#7699;|&#7695;|&#273;|&#396;|&#598;|&#599;|&#42874;|&#240;|[\u0064\u24D3\uFF44\u1E0B\u010F\u1E0D\u1E11\u1E13\u1E0F\u0111\u018C\u0256\u0257\uA77A\u00F0])/g
}, {
    'base': "dz",
        'letters': /(&#499;|&#454;|[\u01F3\u01C6])/g
}, {
    'base': "e",
        'letters': /(&#101;|&#9428;|&#65349;|&#232;|&#233;|&#234;|&#7873;|&#7871;|&#7877;|&#7875;|&#7869;|&#275;|&#7701;|&#7703;|&#277;|&#279;|&#235;|&#7867;|&#283;|&#517;|&#519;|&#7865;|&#7879;|&#553;|&#7709;|&#281;|&#7705;|&#7707;|&#583;|&#603;|&#477;|[\u0065\u24D4\uFF45\u00E8\u00E9\u00EA\u1EC1\u1EBF\u1EC5\u1EC3\u1EBD\u0113\u1E15\u1E17\u0115\u0117\u00EB\u1EBB\u011B\u0205\u0207\u1EB9\u1EC7\u0229\u1E1D\u0119\u1E19\u1E1B\u0247\u025B\u01DD])/g
}, {
    'base': "f",
        'letters': /(&#102;|&#9429;|&#65350;|&#7711;|&#402;|&#42876;|[\u0066\u24D5\uFF46\u1E1F\u0192\uA77C])/g
}, {
    'base': "g",
        'letters': /(&#103;|&#9430;|&#65351;|&#501;|&#285;|&#7713;|&#287;|&#289;|&#487;|&#291;|&#485;|&#608;|&#42913;|&#7545;|&#42879;|[\u0067\u24D6\uFF47\u01F5\u011D\u1E21\u011F\u0121\u01E7\u0123\u01E5\u0260\uA7A1\u1D79\uA77F])/g
}, {
    'base': "h",
        'letters': /(&#104;|&#9431;|&#65352;|&#293;|&#7715;|&#7719;|&#543;|&#7717;|&#7721;|&#7723;|&#7830;|&#295;|&#11368;|&#11382;|&#613;|[\u0068\u24D7\uFF48\u0125\u1E23\u1E27\u021F\u1E25\u1E29\u1E2B\u1E96\u0127\u2C68\u2C76\u0265])/g
}, {
    'base': "hv",
        'letters': /(&#405;|[\u0195])/g
}, {
    'base': "i",
        'letters': /(&#105;|&#9432;|&#65353;|&#236;|&#237;|&#238;|&#297;|&#299;|&#301;|&#239;|&#7727;|&#7881;|&#464;|&#521;|&#523;|&#7883;|&#303;|&#7725;|&#616;|&#305;|[\u0069\u24D8\uFF49\u00EC\u00ED\u00EE\u0129\u012B\u012D\u00EF\u1E2F\u1EC9\u01D0\u0209\u020B\u1ECB\u012F\u1E2D\u0268\u0131])/g
}, {
    'base': "ij",
        'letters': /(&#307;|[\u0133])/g
}, {
    'base': "j",
        'letters': /(&#106;|&#9433;|&#65354;|&#309;|&#496;|&#585;|[\u006A\u24D9\uFF4A\u0135\u01F0\u0249])/g
}, {
    'base': "k",
        'letters': /(&#107;|&#9434;|&#65355;|&#7729;|&#489;|&#7731;|&#311;|&#7733;|&#409;|&#11370;|&#42817;|&#42819;|&#42821;|&#42915;|[\u006B\u24DA\uFF4B\u1E31\u01E9\u1E33\u0137\u1E35\u0199\u2C6A\uA741\uA743\uA745\uA7A3])/g
}, {
    'base': "l",
        'letters': /(&#108;|&#9435;|&#65356;|&#320;|&#314;|&#318;|&#7735;|&#7737;|&#316;|&#7741;|&#7739;|&#322;|&#410;|&#619;|&#11361;|&#42825;|&#42881;|&#42823;|[\u006C\u24DB\uFF4C\u0140\u013A\u013E\u1E37\u1E39\u013C\u1E3D\u1E3B\u0142\u019A\u026B\u2C61\uA749\uA781\uA747])/g
}, {
    'base': "lj",
        'letters': /(&#457;|[\u01C9])/g
}, {
    'base': "m",
        'letters': /(&#109;|&#9436;|&#65357;|&#7743;|&#7745;|&#7747;|&#625;|&#623;|[\u006D\u24DC\uFF4D\u1E3F\u1E41\u1E43\u0271\u026F])/g
}, {
    'base': "n",
        'letters': /(&#110;|&#9437;|&#65358;|&#505;|&#324;|&#241;|&#7749;|&#328;|&#7751;|&#326;|&#7755;|&#7753;|&#414;|&#626;|&#329;|&#42897;|&#42917;|&#331;|[\u006E\u24DD\uFF4E\u01F9\u0144\u00F1\u1E45\u0148\u1E47\u0146\u1E4B\u1E49\u019E\u0272\u0149\uA791\uA7A5\u014B])/g
}, {
    'base': "nj",
        'letters': /(&#460;|[\u01CC])/g
}, {
    'base': "o",
        'letters': /(&#111;|&#9438;|&#65359;|&#242;|&#243;|&#244;|&#7891;|&#7889;|&#7895;|&#7893;|&#245;|&#7757;|&#557;|&#7759;|&#333;|&#7761;|&#7763;|&#335;|&#559;|&#561;|&#246;|&#555;|&#7887;|&#337;|&#466;|&#525;|&#527;|&#417;|&#7901;|&#7899;|&#7905;|&#7903;|&#7907;|&#7885;|&#7897;|&#491;|&#493;|&#248;|&#511;|&#596;|&#42827;|&#42829;|&#629;|[\u006F\u24DE\uFF4F\u00F2\u00F3\u00F4\u1ED3\u1ED1\u1ED7\u1ED5\u00F5\u1E4D\u022D\u1E4F\u014D\u1E51\u1E53\u014F\u022F\u0231\u00F6\u022B\u1ECF\u0151\u01D2\u020D\u020F\u01A1\u1EDD\u1EDB\u1EE1\u1EDF\u1EE3\u1ECD\u1ED9\u01EB\u01ED\u00F8\u01FF\u0254\uA74B\uA74D\u0275])/g
}, {
    'base': "oe",
        'letters': /(&#339;|[\u0153])/g
}, {
    'base': "oi",
        'letters': /(&#419;|[\u01A3])/g
}, {
    'base': "ou",
        'letters': /(&#547;|[\u0223])/g
}, {
    'base': "oo",
        'letters': /(&#42831;|[\uA74F])/g
}, {
    'base': "p",
        'letters': /(&#112;|&#9439;|&#65360;|&#7765;|&#7767;|&#421;|&#7549;|&#42833;|&#42835;|&#42837;|[\u0070\u24DF\uFF50\u1E55\u1E57\u01A5\u1D7D\uA751\uA753\uA755])/g
}, {
    'base': "q",
        'letters': /(&#113;|&#9440;|&#65361;|&#587;|&#42839;|&#42841;|[\u0071\u24E0\uFF51\u024B\uA757\uA759])/g
}, {
    'base': "r",
        'letters': /(&#114;|&#9441;|&#65362;|&#341;|&#7769;|&#345;|&#529;|&#531;|&#7771;|&#7773;|&#343;|&#7775;|&#589;|&#637;|&#42843;|&#42919;|&#42883;|[\u0072\u24E1\uFF52\u0155\u1E59\u0159\u0211\u0213\u1E5B\u1E5D\u0157\u1E5F\u024D\u027D\uA75B\uA7A7\uA783])/g
}, {
    'base': "s",
        'letters': /(&#115;|&#9442;|&#65363;|&#347;|&#7781;|&#349;|&#7777;|&#353;|&#7783;|&#7779;|&#7785;|&#537;|&#351;|&#575;|&#42921;|&#42885;|&#7835;|&#383;|[\u0073\u24E2\uFF53\u015B\u1E65\u015D\u1E61\u0161\u1E67\u1E63\u1E69\u0219\u015F\u023F\uA7A9\uA785\u1E9B\u017F])/g
}, {
    'base': "ss",
        'letters': /(&#223;|[\u00DF])/g
}, {
    'base': "t",
        'letters': /(&#116;|&#9443;|&#65364;|&#7787;|&#7831;|&#357;|&#7789;|&#539;|&#355;|&#7793;|&#7791;|&#359;|&#429;|&#648;|&#11366;|&#42887;|[\u0074\u24E3\uFF54\u1E6B\u1E97\u0165\u1E6D\u021B\u0163\u1E71\u1E6F\u0167\u01AD\u0288\u2C66\uA787])/g
}, {
    'base': "th",
        'letters': /(&#254;|[\u00FE])/g
}, {
    'base': "tz",
        'letters': /(&#42793;|[\uA729])/g
}, {
    'base': "u",
        'letters': /(&#117;|&#9444;|&#65365;|&#249;|&#250;|&#251;|&#361;|&#7801;|&#363;|&#7803;|&#365;|&#252;|&#476;|&#472;|&#470;|&#474;|&#7911;|&#367;|&#369;|&#468;|&#533;|&#535;|&#432;|&#7915;|&#7913;|&#7919;|&#7917;|&#7921;|&#7909;|&#7795;|&#371;|&#7799;|&#7797;|&#649;|[\u0075\u24E4\uFF55\u00F9\u00FA\u00FB\u0169\u1E79\u016B\u1E7B\u016D\u00FC\u01DC\u01D8\u01D6\u01DA\u1EE7\u016F\u0171\u01D4\u0215\u0217\u01B0\u1EEB\u1EE9\u1EEF\u1EED\u1EF1\u1EE5\u1E73\u0173\u1E77\u1E75\u0289])/g
}, {
    'base': "v",
        'letters': /(&#118;|&#9445;|&#65366;|&#7805;|&#7807;|&#651;|&#42847;|&#652;|[\u0076\u24E5\uFF56\u1E7D\u1E7F\u028B\uA75F\u028C])/g
}, {
    'base': "vy",
        'letters': /(&#42849;|[\uA761])/g
}, {
    'base': "w",
        'letters': /(&#119;|&#9446;|&#65367;|&#7809;|&#7811;|&#373;|&#7815;|&#7813;|&#7832;|&#7817;|&#11379;|[\u0077\u24E6\uFF57\u1E81\u1E83\u0175\u1E87\u1E85\u1E98\u1E89\u2C73])/g
}, {
    'base': "x",
        'letters': /(&#120;|&#9447;|&#65368;|&#7819;|&#7821;|[\u0078\u24E7\uFF58\u1E8B\u1E8D])/g
}, {
    'base': "y",
        'letters': /(&#121;|&#9448;|&#65369;|&#7923;|&#253;|&#375;|&#7929;|&#563;|&#7823;|&#255;|&#7927;|&#7833;|&#7925;|&#436;|&#591;|&#7935;|[\u0079\u24E8\uFF59\u1EF3\u00FD\u0177\u1EF9\u0233\u1E8F\u00FF\u1EF7\u1E99\u1EF5\u01B4\u024F\u1EFF])/g
}, {
    'base': "z",
        'letters': /(&#122;|&#9449;|&#65370;|&#378;|&#7825;|&#380;|&#382;|&#7827;|&#7829;|&#438;|&#549;|&#576;|&#11372;|&#42851;|[\u007A\u24E9\uFF5A\u017A\u1E91\u017C\u017E\u1E93\u1E95\u01B6\u0225\u0240\u2C6C\uA763])/g
}];

/* exported removeDiacritics */
window.removeDiacritics =function(str) {
    for (var i = 0; i < defaultDiacriticsRemovalMap.length; i++) {
        str = str.replace(defaultDiacriticsRemovalMap[i].letters, defaultDiacriticsRemovalMap[i].base);
    }
    return str;
};

/* >>>>>>>>>> BEGIN source/utilities/sound_utilities.js */
// ==========================================================================
//                                DG.sounds
// 
//  A collection of utilities for working with sound embodied in a single global object
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

DG.sounds = SC.Object.extend( {

  sounds: {
    create: { path: '../../../../static/dg/de/cert/resources/sounds/create.wav' },
    drag: { path: '../../../../static/dg/de/cert/resources/sounds/drag.wav' },
    mixup: { path: '../../../../static/dg/de/cert/resources/sounds/mixup.wav' }
  },

  init: function() {
    arguments.callee.base.apply(this,arguments);
    
    //this.initAudio();
  },
  
  /**
    This function creates an Audio object for every sound as a means of
    preloading the sound so that the first time it is played it doesn't
    appear to lag the event it corresponds to. Unfortunately, preloading
    led to problems on some browsers so we've disabled both the preloading
    and the playing of sounds until further investigation has occurred.
   */
  initAudio: function() {
    var name, sound;
    for( name in this.sounds) {
      if( this.sounds.hasOwnProperty( name)) {
        sound = this.sounds[name];
        if( sound && sound.path && !sound.audio)
          sound.audio = new Audio( sound.path);
      }
    }
  },

  /**
   *
   * @param iName - {String}
   */
  playSound: function( iName) {
    var sound = this.sounds[iName];
    
    // Without preloading, sounds would lag the first time they were played.
    // With preloading (see initAudio()) we crashed on certain browsers.
    // For now, we disable audio completely, but leave the implementation
    // in place for further testing/development down the road.
    if( true) // eslint-disable-line no-constant-condition
      return;
    
    if( sound && sound.path && !sound.audio)
      sound.audio = new Audio( sound.path);
    
    if( sound.audio) {
      // See http://stackoverflow.com/questions/8733330/why-cant-i-play-sounds-more-than-once-using-html5-audio-tag
      // and http://stackoverflow.com/questions/2702343/html5-audio-plays-only-once-in-my-javascript-code
      // for details on the browser-specific issues in playing sounds.
      if (window.chrome)
        sound.audio.load();
      else
        sound.audio.currentTime = 0;
      sound.audio.play();
    }
  },

  playMixup: function() {
    this.playSound( 'mixup');
  },

  playCreate: function() {
    this.playSound( 'create');
  },

  playDrag: function() {
    this.playSound( 'drag');
  }
}).create();

/* >>>>>>>>>> BEGIN source/utilities/stat_constants.js */
DG.stat_constants = {};
DG.stat_constants.t_quantile_at_0975_for_df=[
   [1,12.7062],
  [2,4.30265],
  [3,3.18245],
  [4,2.77645],
  [5,2.57058],
  [6,2.44691],
  [7,2.36462],
  [8,2.306],
  [9,2.26216],
  [10,2.22814],
  [11,2.20099],
  [12,2.17881],
  [13,2.16037],
  [14,2.14479],
  [15,2.13145],
  [16,2.11991],
  [17,2.10982],
  [18,2.10092],
  [19,2.09302],
  [20,2.08596],
  [21,2.07961],
  [22,2.07387],
  [23,2.06866],
  [24,2.0639],
  [25,2.05954],
  [26,2.05553],
  [27,2.05183],
  [28,2.04841],
  [29,2.04523],
  [30,2.04227],
  [40,2.02108],
  [50,2.00856],
  [60,2.0003],
  [70,1.99444],
  [80,1.99006],
  [90,1.98667],
  [100,1.98397],
  [200,1.9719],
  [500,1.96472],
  [1000,1.96234],
  [2000,1.96115],
  [10000,1.9602],
  [100000,1.95999]];

/* >>>>>>>>>> BEGIN source/utilities/stripJsonComments.js */
/*

  https://github.com/sindresorhus/strip-json-comments

  The MIT License (MIT)

  Copyright (c) Sindre Sorhus <sindresorhus@gmail.com> (sindresorhus.com)

  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to deal
  in the Software without restriction, including without limitation the rights
  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
  copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
  THE SOFTWARE.

 */
var singleComment = 1;
var multiComment = 2;

function stripWithoutWhitespace() {
  return '';
}

function stripWithWhitespace(str, start, end) {
  return str.slice(start, end).replace(/\S/g, ' ');
}

window.stripJsonComments = function (str, opts) {
  'use strict';
  opts = opts || {};

  var currentChar;
  var nextChar;
  var insideString = false;
  var insideComment = false;
  var offset = 0;
  var ret = '';
  var strip = opts.whitespace === false ? stripWithoutWhitespace : stripWithWhitespace;

  for (var i = 0; i < str.length; i++) {
    currentChar = str[i];
    nextChar = str[i + 1];

    if (!insideComment && currentChar === '"') {
      var escaped = str[i - 1] === '\\' && str[i - 2] !== '\\';
      if (!escaped) {
        insideString = !insideString;
      }
    }

    if (insideString) {
      continue;
    }

    if (!insideComment && currentChar + nextChar === '//') {
      ret += str.slice(offset, i);
      offset = i;
      insideComment = singleComment;
      i++;
    } else if (insideComment === singleComment && currentChar + nextChar === '\r\n') {
      i++;
      insideComment = false;
      ret += strip(str, offset, i);
      offset = i;
      continue;
    } else if (insideComment === singleComment && currentChar === '\n') {
      insideComment = false;
      ret += strip(str, offset, i);
      offset = i;
    } else if (!insideComment && currentChar + nextChar === '/*') {
      ret += str.slice(offset, i);
      offset = i;
      insideComment = multiComment;
      i++;
      continue;
    } else if (insideComment === multiComment && currentChar + nextChar === '*/') {
      i++;
      insideComment = false;
      ret += strip(str, offset, i + 1);
      offset = i + 1;
      continue;
    }
  }

  return ret + (insideComment ? strip(str.substr(offset)) : str.substr(offset));
};

/* >>>>>>>>>> BEGIN source/utilities/svg_scene.js */
/**
 * Taken from Mike Bostock's Protovis project <http://mbostock.github.io/protovis/>. Thank you!
 *
 * @private
 * @namespace
 */
DG.Scene = DG.SvgScene = { };

/**
 * Creates a new SVG element of the specified type.
 *
 * @param type {string} an SVG element type, such as "rect".
 * @returns a new SVG element.
 */
DG.SvgScene.create = function(type) {
  return document.createElementNS(this.svg, type);
};

/**
 * @private Converts the specified b-spline curve segment to a bezier curve
 * compatible with SVG "C".
 *
 * @param p0 the first control point.
 * @param p1 the second control point.
 * @param p2 the third control point.
 * @param p3 the fourth control point.
 */
DG.SvgScene.pathBasis = (function() {

  /**
   * Matrix to transform basis (b-spline) control points to bezier control
   * points. Derived from FvD 11.2.8.
   */
  var basis = [
    [ 1/6, 2/3, 1/6,   0 ],
    [   0, 2/3, 1/3,   0 ],
    [   0, 1/3, 2/3,   0 ],
    [   0, 1/6, 2/3, 1/6 ]
  ];

  /**
   * Returns the point that is the weighted sum of the specified control points,
   * using the specified weights. This method requires that there are four
   * weights and four control points.
   */
  function weight(w, p0, p1, p2, p3) {
    return {
      x: w[0] * p0.left + w[1] * p1.left + w[2] * p2.left + w[3] * p3.left,
      y: w[0] * p0.top  + w[1] * p1.top  + w[2] * p2.top  + w[3] * p3.top
    };
  }

  var convert = function(p0, p1, p2, p3) {
    var b1 = weight(basis[1], p0, p1, p2, p3),
        b2 = weight(basis[2], p0, p1, p2, p3),
        b3 = weight(basis[3], p0, p1, p2, p3);
    return "C" + b1.x + "," + b1.y
        + "," + b2.x + "," + b2.y
        + "," + b3.x + "," + b3.y;
  };

  convert.segment = function(p0, p1, p2, p3) {
    var b0 = weight(basis[0], p0, p1, p2, p3),
        b1 = weight(basis[1], p0, p1, p2, p3),
        b2 = weight(basis[2], p0, p1, p2, p3),
        b3 = weight(basis[3], p0, p1, p2, p3);
    return "M" + b0.x + "," + b0.y
        + "C" + b1.x + "," + b1.y
        + "," + b2.x + "," + b2.y
        + "," + b3.x + "," + b3.y;
  };

  return convert;
}());

/**
 * @private Interpolates the given points using the basis spline interpolation.
 * Returns an SVG path without the leading M instruction to allow path
 * appending.
 *
 * @param points the array of points.
 */
DG.SvgScene.curveBasis = function(points) {
  if (points.length <= 2) return "";
  var path = "",
      p0 = points[0],
      p1 = p0,
      p2 = p0,
      p3 = points[1];
  path += this.pathBasis(p0, p1, p2, p3);
  for (var i = 2; i < points.length; i++) {
    p0 = p1;
    p1 = p2;
    p2 = p3;
    p3 = points[i];
    path += this.pathBasis(p0, p1, p2, p3);
  }
  /* Cycle through to get the last point. */
  path += this.pathBasis(p1, p2, p3, p3);
  path += this.pathBasis(p2, p3, p3, p3);
  return path;
};

/* >>>>>>>>>> BEGIN source/utilities/tap_hold_gesture.js */
/**
  ## What is a "tapHold"?

  A tapHold is a tap gesture that is held for an extended time (default: 500 ms) with little movement.
  Again, to be considered a tap, there should be very little movement of any touches on either axis
  while still touching. The amount of movement allowed is defined by `tapWiggle`.

  @class
  @extends SC.TapGesture
*/
DG.TapHoldGesture = SC.TapGesture.extend(
  /** @scope DG.TapHoldGesture.prototype */{

  /** @private The touch that started the timer. */
  _sc_timerStartTouch: null,

  /**
    @type String
    @default "tapHold"
    @readOnly
  */
 name: "tapHold",

 /**
    The amount of time in milliseconds after the first touch starts at which, *if the tap hasn't
    ended in that time*, the `tapStart` event should trigger.

    Because taps may be very short or because movement of the touch may invalidate a tap gesture
    entirely, you generally won't want to update the state of the view immediately when a touch
    starts.

    @type Number
    @default 500
    */
   tapStartDelay: 500,

  /** @private Triggers the tapStart event. Should *not* be reachable unless the tap is still valid. */
  _sc_triggerTapStart: function () {
    // Trigger the gesture, 'tapStart'.
    this.start(this._sc_timerStartTouch);
    // // Trigger the gesture, 'tap'.
    this.trigger(this._sc_timerStartTouch, this._sc_numberOfTouches);

    this._sc_isTapping = true;
  },

  /**
    Registers when the first touch started.

    @param {SC.Touch} touch The touch that started the session.
    @returns {void}
    @see SC.Gesture#touchSessionStarted
    */
   touchSessionStarted: function (touch) {
    arguments.callee.base.apply(this,arguments);
    this._sc_timerStartTouch = touch;
  },

  /**
    Cleans up all touch session variables and triggers the gesture.

    @returns {void}
    @see SC.Gesture#touchSessionEnded
    */
  touchSessionEnded: function () {
    // Trigger the gesture, 'tap'.
    // this.trigger(this._sc_timerStartTouch, this._sc_numberOfTouches);

    // Clean up (will fire tapEnd if _sc_isTapping is true).
    this._sc_cleanUpTouchSession(false);
  }

});

/* >>>>>>>>>> BEGIN source/utilities/touch_tooltips.js */
// ==========================================================================
//                          DG.TouchTooltips
//
//  Utility class to support tooltips on touch-hold gestures.
//
//  Author:   Kirk Swenson
//
//  Copyright (c) 2018 by The Concord Consortium, Inc. All rights reserved.
//
//  Permission is hereby granted, free of charge, to any person obtaining a
//  copy of this software and associated documentation files (the "Software"),
//  to deal in the Software without restriction, including without limitation
//  the rights to use, copy, modify, merge, publish, distribute, sublicense,
//  and/or sell copies of the Software, and to permit persons to whom the
//  Software is furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included
//  in all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
//  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
//  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
//  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
//  IN THE SOFTWARE.
// ==========================================================================
/* global Tooltip */

DG.TouchTooltips = (function() {

  var kTouchTooltipDefault = 5000,
      kTouchTooltipMax = 8000,

      tooltips = {};

  return {
    showTouchTooltip: function(touch, triggerView, title, placement) {
      var touchID = touch.identifier,
          layer = triggerView instanceof SC.View
                    ? triggerView.get('layer')
                    : triggerView,
          container = DG.mainPage.getPath('mainPane.layer'),
          _placement = placement || 'top-start',
          tooltip = new Tooltip(layer, {
                                  boundariesElement: container,
                                  container: container,
                                  placement: _placement,
                                  trigger: 'manual',
                                  title: title
                                });

      DG.TouchTooltips.hideAllTouchTooltips();

      tooltip.show();
      tooltips[touchID] = { touch: touch, tooltip: tooltip };

      DG.TouchTooltips.hideTouchTooltip(touchID, kTouchTooltipMax);

      return touchID;
    },

    hideTouchTooltip: function(touchID, delay) {
      var entry = tooltips[touchID],
          hideTooltip = function() {
            var entry = tooltips[touchID];
            if (entry) {
              if (entry.tooltip) {
                entry.tooltip.dispose();
                entry.tooltip = null;
              }
              entry.timer = null;
              if (entry.finished)
                delete tooltips[touchID];
            }
          };
      if (!entry) return;
      
      if (entry.timer) {
        clearTimeout(entry.timer);
        entry.timer = null;
      }

      if (delay == null) delay = kTouchTooltipDefault;
      if (delay) {
        entry.timer = setTimeout(hideTooltip, delay);
      }
      else {
        hideTooltip();
      }
    },

    clearTouchTooltip: function(touchID) {
      var entry = tooltips[touchID];
      if (entry) {
        entry.finished = true;
        DG.TouchTooltips.hideTouchTooltip(touchID);
        return true;
      }
      return false;
    },

    hideAllTouchTooltips: function() {
      DG.ObjectMap.forEach(tooltips,
                          function(touchID) {
                            DG.TouchTooltips.hideTouchTooltip(touchID, 0);
                          });
    }

  };
})();

/* >>>>>>>>>> BEGIN source/utilities/value_animator.js */
// ==========================================================================
//                                DG.ValueAnimator
// 
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

  Holds onto an object with a 'value' property that can be incremented. The size of the increment is obtained
  from the incrementProvider that has a property 'increment'.

 @extends SC.Object
 */
DG.ValueAnimator = SC.Object.extend(
  {
    /**
     * This object has a 'value' property that is numeric and can be incremented.
     * @property {SC.Object}
     */
    valueHolder: null,

    /**
     * This object has a numeric 'increment' property determined internally. For example, a DG.CellLinearAxisView will
     * compute this value based on the current value along the axis of a single pixel.
     */
    incrementProvider: null,

    /**
      @property {Boolean}
    */
    isAnimating: false,

    maxPerSecond: null,

    /**
      We assume that my properties have been set to the aspects of the plot that are to
      be animated. If there is an animation already in progress, we end it.
    */
    animate: function() {
      var this_ = this,
          tMaxPerSecond = this.get('maxPerSecond'),
          tInterval = (DG.isNumeric(tMaxPerSecond) && tMaxPerSecond > 0) ?
              (1000 / tMaxPerSecond) : 50,	// milliseconds
          tValueHolder = this.get('valueHolder')
          ;

      // animationLoop - This function is called up to 20 times per second. Note that it schedules itself using
      //	an SC.Timer.
      function animationLoop() {
        var tIncrement = this_.getPath('incrementProvider.increment');
        tValueHolder.set('value', tValueHolder.get('value') + tIncrement);
      }

      // End any animation we may be in the midst of
      if( this.get('isAnimating')) {
        this.endAnimation();
      }
      this.set('isAnimating', true);

      if( SC.none( this.animationTimer))
        this.animationTimer = SC.Timer.schedule( { action: animationLoop,
                      repeats: YES, until: false });
      this.animationTimer.set( 'interval', tInterval);
      this.animationTimer.set( 'isPaused', NO);
    },

    /**
      We assume that my properties have been set to the aspects of the plot that are to
      be animated. If there is an animation already in progress, we end it.
    */
    endAnimation: function() {
      if( !SC.none( this.animationTimer))
        this.animationTimer.set('isPaused', YES);
      if( this.get('isAnimating'))
        this.set('isAnimating', false);
    }

  } );

/* >>>>>>>>>> BEGIN source/utilities/view_utilities.js */
// ==========================================================================
//                          DG.ViewUtilities
//
//  A collection of utilities for manipulating views
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

DG.ViewUtilities = {

  kTitleBarHeight: 25,  // for component views
  kDragWidth: 8,  // for component views
  kBorderWidth: 4, // must correspond with .css constant
  kGridSize: 5,

  roundToGrid: function( iNumber) {
    return DG.ViewUtilities.kGridSize * Math.round( iNumber / DG.ViewUtilities.kGridSize);
  },

  floorToGrid: function( iNumber) {
    return DG.ViewUtilities.kGridSize * Math.floor( iNumber / DG.ViewUtilities.kGridSize);
  },

  /**
   * @returns {number} padding to add to interior of view to get view horizontal size.
   */
  horizontalPadding: function() {
    return 2 * DG.ViewUtilities.kDragWidth;  // kDragWidth width is used on left & right, and has 4 invisible pixels.
  },

  /**
   * @returns {number} padding to add tointerior of view to get view vertical size.
   */
  verticalPadding: function() {
    return DG.ViewUtilities.kDragWidth + // on bottom
      DG.ViewUtilities.kTitleBarHeight + DG.ViewUtilities.kBorderWidth; // on top
  },

  /**
    Transform a given point in window coordinates to coordinates in the
    given view.
    @param { Point as in {x: y: }}
    @param { SC.View }
    @return { Point as in {x: y: }}
  */
  windowToViewCoordinates: function( iWindowPt, iView) {
    var tFrame;
    do {
      tFrame = iView.get('frame');
      iWindowPt.x -= tFrame.x;
      iWindowPt.y -= tFrame.y;
/*
      iWindowPt.x += iView.get('horizontalScrollOffset') || 0;
      iWindowPt.y += iView.get('verticalScrollOffs et') || 0;
*/
      iView = iView.parentView;
    } while( !SC.none( iView));
    // When embedded, CODAP need not be at the window origin
    // todo: Store this offset globally and recompute only when there's a DOM resize
    var codapOffset = $('#codap').offset();
    return { x: iWindowPt.x - codapOffset.left, y: iWindowPt.y - codapOffset.top };
  },

  /**
    Transform a given point in window coordinates to coordinates in the
    given view.
    @param iViewPt { {x: number, y: number}}
    @param iView { SC.View }
    @return { {x: number, y: number}}
  */
  viewToWindowCoordinates: function( iViewPt, iView) {
    var tFrame;
    do {
      tFrame = iView.get('frame');
      iViewPt.x += tFrame.x;
      iViewPt.y += tFrame.y;
/*
      iViewPt.x -= iView.get('horizontalScrollOffset') || 0;
      iViewPt.y -= iView.get('verticalScrollOffset') || 0;
*/
      iView = iView.parentView;
    } while( !SC.none( iView));
    // When embedded, CODAP need not be at the window origin
    var codapOffset = $('#codap').offset();
    return { x: iViewPt.x + codapOffset.left, y: iViewPt.y + codapOffset.top };
  },

  /**
   * If the given view's layout is missing any of left, top, width, height,
   * set its layout to a new object reflecting its current position and dimensions.
   *
   * @param{SC.View} iView - The view whose layout is to be converted.
   */
  convertViewLayoutToAbsolute: function( iView) {
    var tLayout = iView.get('layout');
    if( SC.none( tLayout.left) || SC.none( tLayout.top) || SC.none( tLayout.width) || SC.none( tLayout.height)) {
      var tLayer = iView.get('layer');
      if( !SC.none( tLayer))
        iView.set('layout', { left: tLayer.offsetLeft, top: tLayer.offsetTop,
                            width: tLayer.offsetWidth, height: tLayer.offsetHeight });
    }
  },

  /* findEmptyLocationForRect: Given a component rectangle, a container rectangle and
    an array of views, return a location at which the component rectangle will fit.

    If there is no empty rectangle such that the given rectangle fits, position it in the
    center and adjust down and right until there is no component whose top left is the same
    as the proposed location.

    Note that given rectangles and view frames are expected to have form
      { x, y, width, height }.
    In fact, rectangles that come from components like the about box have NAN's for
    x and y. We just consider them to be floating on top of everything and not intersecting.
    iItemRect is the rect we are trying to place
    iContainerRect is the visible rect in the browser window, with an upper left corner of 0, 0
    iOffset is the offset of that rect from the true top of the frame
    iViewRects are the rectangles where we cannot place iItemRect
    iPosition is either 'top' or 'bottom'
    return the location { x, y } for the rectangle.
  */
  findEmptyLocationForRect: function (iItemRect, iContainerRect, iOffset, iViewRects, iPosition) {
    var
        kGap = DG.ViewUtilities.kGridSize, // Also used to increment during search
        tStartAtBottom = (iPosition === 'bottom'),
        tLoc = {x: kGap + iOffset.x,
          y: (tStartAtBottom ? iContainerRect.height - iItemRect.height - kGap : kGap) + iOffset.y },
        tSuccess = false;

    function intersectRect(r1, r2) {
      var tRes = (!isNaN(r1.x) && !isNaN(r1.y)) && !(r2.x > r1.x + r1.width ||
          r2.x + r2.width < r1.x ||
          r2.y > r1.y + r1.height ||
          r2.y + r2.height < r1.y);
      return tRes;
    }

    /*  intersects - Iterate through iViews, returning true for the first view
     that intersects iItemRect placed at the given location, false
     if none intersect.
     */
    function intersects(iTopLeft) {
      return !iViewRects.every(
          function (iViewRect) {
            return !intersectRect(iViewRect,
                {
                  x: iTopLeft.x,
                  y: iTopLeft.y,
                  width: iItemRect.width,
                  height: iItemRect.height
                });
          });
    }

    function onTopOfViewRectTopLeft(iTopLeft) {
      return !iViewRects.every(
          function (iViewRect) {
            return !( iTopLeft.x === iViewRect.x && iTopLeft.y === iViewRect.y);
          });
    }

    // If there are no other views or reserved areas, simply return the initial
    // candidate.
    if (iViewRects.length === 0) {
      return tLoc;
    }

    // Work our way through the visible portion of the document
    while (!tSuccess && tLoc.y + iItemRect.height < iOffset.y + iContainerRect.height &&
              tLoc.y >= iOffset.y + kGap) {
      tLoc.x = iOffset.x + kGap;
      // left to right, making sure we got through at least once
      while (!tSuccess) {
        // Positioned at tLoc, does the item rect intersect any view rects?
        if (intersects(tLoc)) {
          tLoc.x += kGap;
          if (tLoc.x + iItemRect.width > iOffset.x + iContainerRect.x + iContainerRect.width)
            break;
        }
        else
          tSuccess = true;
      }
      if (!tSuccess)
        tLoc.y += (tStartAtBottom ? -kGap : kGap);
    }

    if( !tSuccess) {
      // Choose a location that will center the item rect in the container
      tLoc = { x: iOffset.x +
                    Math.max( this.kGridSize, Math.round((iContainerRect.width - iItemRect.width) / 2)),
              y: iOffset.y +
                    Math.max( this.kGridSize, Math.round((iContainerRect.height - iItemRect.height) / 2))
      };
      // Adjust down and to the right until there tLoc is not on top of the upper-right corner of a view rect
      while( !tSuccess) {
        if( !onTopOfViewRectTopLeft( tLoc)) {
          tSuccess = true;
        }
        else {
          tLoc = { x: tLoc.x + kGap, y: tLoc.y + this.kTitleBarHeight };
        }
      }
    }

    return tLoc;
  },

  /* normalFormForRect: The given rectangle is expected to have properties left, top,
    right, and bottom. Return a rectangle with left <= right and bottom <= top.
  */
  normalFormForRect: function( iRect) {
    return { left: Math.min( iRect.left, iRect.right),
              top: Math.max( iRect.bottom, iRect.top),
              right: Math.max( iRect.left, iRect.right),
              bottom: Math.min( iRect.bottom, iRect.top)
        };
  },

  /* ptInRect: The given point should have properties x and y. The given rectangle should
    be in the form { x, y, width, height }. width and height >= 0.
    Return true if the given point is within or on the boundary of the given rectangle.
  */
  ptInRect: function( iPoint, iRect) {
    return (iPoint.x >= iRect.x) && (iPoint.x <= iRect.x + iRect.width) &&
           (iPoint.y >= iRect.y) && (iPoint.y <= iRect.y + iRect.height);
  },

  /**
   *
   * @param iView {SC.View} normally a child view of a ComponentView
   */
  componentViewForView: function( iView) {
    while( iView && !(iView instanceof DG.ComponentView)) {
      iView = iView.get('parentView');
    }
    return iView;
  }

};

/* >>>>>>>>>> BEGIN source/views/alert_pane.js */
// ==========================================================================
//                            DG.AlertPane
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

  Alert utilities for the DG application.

  @extends SC.AlertPane
*/
DG.AlertPane =
/** @scope DG.AlertPane.prototype */ {

  processArgs: function( iArgs) {

    // Localize any localizable arguments
    if( iArgs.localize) {
      if( !SC.empty( iArgs.message))
        iArgs.message = SC.String.loc( iArgs.message);
      if( !SC.empty( iArgs.description))
        iArgs.description = SC.String.loc( iArgs.description);
      if( !SC.empty( iArgs.caption))
        iArgs.caption = SC.String.loc( iArgs.caption);
      // We don't want SC.AlertPane doing any additional localization
      iArgs.localize = false;
    }
    return iArgs;
  },

  show: function( iArgs) {
    SC.AlertPane.show( DG.AlertPane.processArgs( iArgs));
  },
  
  warn: function( iArgs) {
    SC.run( function() {
      SC.AlertPane.warn( DG.AlertPane.processArgs( iArgs));
    });
  },
  
  info: function( iArgs) {
    SC.AlertPane.info( DG.AlertPane.processArgs( iArgs));
  },
  
  error: function( iArgs) {
    SC.AlertPane.error( DG.AlertPane.processArgs( iArgs));
  },
  
  plain: function( iArgs) {
    SC.AlertPane.plain( DG.AlertPane.processArgs( iArgs));
  }
  
};


/* >>>>>>>>>> BEGIN source/views/text_field_view.js */
// ==========================================================================
//                            DG.TextFieldView
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class  DG.TextFieldView

  A wrapper for a TextFieldView that hooks into the DG.globalEditorLock.

  @extends SC.TextFieldView
*/
DG.TextFieldView = SC.TextFieldView.extend(
/** @scope DG.TextFieldView.prototype */ {

  isTextSelectable: YES,

  /**
    Override SproutCore method to coordinate with DG.globalEditorLock.
    @returns  {Boolean} True if successful; false otherwise.
   */
  beginEditing: function() {
    // If we're already active, keep it that way
    if( DG.globalEditorLock.isActive( this)) {
      return arguments.callee.base.apply(this,arguments);
    }

    // If another editor is active, ask it to finish up
    if( !DG.globalEditorLock.commitCurrentEdit()) {
      return false;
    }

    var currValue = this.get('value'),
        beginResult = arguments.callee.base.apply(this,arguments);
    if( beginResult) {
      // Stash original value in case we need to cancel
      this._prevValue = currValue;
      DG.globalEditorLock.activate( this);
    }
    return beginResult;
  },
  
  /**
    Override SproutCore method to coordinate with DG.globalEditorLock.
    @returns  {Boolean} True if successful; false otherwise.
   */
  commitEditing: function() {
    var commitResult = arguments.callee.base.apply(this,arguments);
    if( commitResult && DG.globalEditorLock.isActive( this))
      DG.globalEditorLock.deactivate( this);
    return commitResult;
  },
  
  /**
    Override SproutCore method to coordinate with DG.globalEditorLock.
    Discard edits and restore original value.
    @returns  {Boolean} True if successful; false otherwise.
   */
  discardEditing: function() {
    this.set('value', this._prevValue || "");
    this.resignFirstResponder();
    if( DG.globalEditorLock.isActive( this))
      DG.globalEditorLock.deactivate( this);
    return true;
  },
  
  completeEditing: function() {
    // We tell the underlying HTMLElement to blur(), which triggers sending of a 'blur' event.
    // SC.TextFieldView responds to the 'blur' event by calling resignFirstResponder(),
    // commitEditing(), etc. So all we need to do is force the 'blur' event. It seems like
    // there should be SC.TextFieldView API for doing this, but it doesn't seem to exist.
    // (See SC.TextFieldView._textField_fieldDidBlur() for details of SC.TextFieldView's response.)
    this.$input().blur();
  },

  /**
    Implement SlickGrid.EditController protocol.
    @returns  {Boolean} True if commit was successful; false otherwise.
   */
  commitCurrentEdit: function() {
    return this.commitEditing();
  },
  
  /**
    Implement SlickGrid.EditController protocol.
    @returns  {Boolean} True if cancel was successful; false otherwise.
   */
  cancelCurrentEdit: function() {
    return this.discardEditing();
  },

  /**
    Sets the selection to the specified range.
    If only iStart is specified, sets it to a caret at that position.
    @param    {Number}    iStart -- The index of the start of the selection
    @param    {Number}    iEnd -- [Optional] The index of the end of the selection
                                  If not specified, iEnd = iStart
   */
  setSelection: function( iStart, iEnd) {
    if( SC.none( iStart)) return;
    var end = iEnd || iStart;
    if( end < iStart) end = iStart;
    this.set('selection', SC.TextSelection.create({ start: iStart, end: end }));
  },

  /**
    Replace the current selection with the specified string.
    @param    {String}    iNewString -- the string to insert
   */
  replaceSelectionWithString: function( iNewString) {
    var currText = this.get('value'),
        selection = this.get('selection'),
        selStart = selection.get('start'),
        selEnd = selection.get('end'),
        preText = currText.substr( 0, selStart),
        postText = currText.substr( selEnd),
        newText = preText + iNewString + postText,
        newSel = selStart + iNewString.length;
    this.set('value', newText);
    // If we aren't currently focused, then setting the selection will trigger a call to
    // _selectRootElement, which will select all the text. Setting the _disableNextSelectRoot
    // flag will trigger our _selectRootElement override to bypass this undesirable result.
    if( !this.get('focused'))
      this._disableNextSelectRoot = true;
    this.setSelection( newSel);
  }
});

/* >>>>>>>>>> BEGIN source/views/formula_rich_edit_view.js */
// ==========================================================================
//                      DG.FormulaTextEditView
//
//  Provides a DG-specific text editor for entering a formula.
//
//  Authors:  William Finzer, Kirk Swenson
//
//  Copyright (c) 2016 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('views/text_field_view');
/*global CodeMirror:true */
/** @class

  This text editor deals specially with hyphens by turning them into true minus signs.
  Its functionality can be extended to enhance formula editing.

  @extends DG.TextFieldView
*/
DG.FormulaRichEditView = DG.TextFieldView.extend((function() {
/** @scope DG.FormulaTextEditView.prototype */

  function isMatchableChar(ch) {
    // to prevent autocomplete of literal strings, include any quotes in the string to match
    if ((ch === '"') || (ch === '\'')) return true;
    // digits are matchable, even though they can't be the first character of an identifier
    if ((ch >= '0') && (ch <= '9')) return true;
    // otherwise, it must be a valid identifier character
    return DG.Formula.identifierRegExp.test(ch);
  }

  function endsWithParentheses(str) {
    return /\(\)$/.test(str);
  }
  
  function cmHintReplace(cm, data, completion) {
    var rangeStart = completion.from || data.from,
        rangeEnd = completion.to || data.to,
        nextCharEnd = { line: rangeEnd.line, ch: rangeEnd.ch + 1 },
        nextChar = cm.getRange(rangeEnd, nextCharEnd),
        isInsertingFunction = (completion.category === 'Functions'),
        replaceWithoutParens = isInsertingFunction && (nextChar === '('),
        canonicalString = isInsertingFunction ? completion.text :
            DG.Attribute.canonicalizeName(completion.text, true),
        newText;
    if( completion.text !== canonicalString)
      canonicalString = '`' + completion.text + '`';
    // if we're inserting a function reference, don't insert redundant parentheses
    newText = replaceWithoutParens
                ? canonicalString.slice(0, canonicalString.length - 2)
                : canonicalString;

    // insert the new text
    cm.replaceRange(newText, rangeStart, rangeEnd, "complete");

    // if we're inserting a function reference, put the cursor between the parentheses
    if (isInsertingFunction) {
      var cursor = cm.getCursor();
      cm.setCursor(cursor.line, replaceWithoutParens ? cursor.ch + 1 : cursor.ch - 1);
    }
  }

  function cmSortCompletions(c1, c2) {
    /* global removeDiacritics */
    var isFunction1 = (c1.category === 'Functions'),
        isFunction2 = (c2.category === 'Functions'),
        // ignore case and diacritics for sorting purposes
        canonical1 = removeDiacritics(c1.text).toLowerCase(),
        canonical2 = removeDiacritics(c2.text).toLowerCase();
    // sort non-functions before functions
    if (!isFunction1 && isFunction2) return -1;
    if (isFunction1 && !isFunction2) return 1;
    if (canonical1 < canonical2) return -1;
    if (canonical1 > canonical2) return 1;
    return 0;
  }

  /*
   * returns the set of available completions given the current caret position
   */
  function codapFormulaHints(cm, options) {
    var cursor = cm.getCursor(),
        currentLine = cm.getLine(cursor.line),
        start = cursor.ch,
        end = start;
    while (end < currentLine.length && isMatchableChar(currentLine.charAt(end))) ++end;
    while (start && isMatchableChar(currentLine.charAt(start - 1))) --start;
    var curWord = start !== end && currentLine.slice(start, end),
        regex = curWord ? new RegExp('^' + DG.StringUtilities.escapeRegExp(curWord), 'i') : null,
        result = {
          list: (!curWord || !options.completionData
                  ? []
                  : options.completionData.reduce(function(memo, item) {
                      if (item && item.label && item.label.match(regex))
                        memo.push({ text: item.value, category: item.category.key, className: 'dg-wants-touch', hint: cmHintReplace });
                      return memo;
                    }, [])).sort(cmSortCompletions),
          from: CodeMirror.Pos(cursor.line, start),
          to: CodeMirror.Pos(cursor.line, end)
        };
    // don't show the menu if there's only one option and it's already complete
    if ((result.list.length === 1) && (result.list[0].text === curWord))
      result.list = [];

    return result;
  }

return {

  isTextArea: true,

  autoCorrect: false,

  autoCapitalize: false,

  classNames: ['dg-wants-touch'],

  names: [],  // Will be filled with attribute and global variable names by client

  _disableNextSelectRoot: false,

  init: function() {
    arguments.callee.base.apply(this,arguments);

    // only works for textarea at the moment
    this.set('isTextArea', true);
  },

  didAppendToDocument: function() {

    var textArea = this.$('textarea'),
        textAreaNode = textArea[0],
        placeholderText = this.get('hint');

    // not sure why this isn't happening automatically
    if (placeholderText) {
      textArea.attr('placeholder', placeholderText.loc());
    }

    this._cm = CodeMirror.fromTextArea(textAreaNode, {
      lineWrapping: true,
      extraKeys: {
        Tab: false
      },
      mode: 'codapFormula',
      hintOptions: {
        completeSingle: false,
        completionData: this.get('completionData'),
        hint: codapFormulaHints,
        extraKeys: {
          Esc: function(cm, menu) {
            menu.close();
            if (this._lastEscKeyEvent) {
              // prevent event from bubbling up to dialog
              this._lastEscKeyEvent.stopPropagation();
              this._lastEscKeyEvent = null;
            }
            return true;
          }
        }
      }
    });

    // initialize coloring
    this.addSemanticClasses(this._cm);

    // Propagation of the touchend event leads to touches that set focus()
    // and then immediately clear it among other oddities. CodeMirror's 
    // internal touchend handler ends with a call to preventDefault(), but
    // propagation still occurs. By piggy-backing our touchend handler on
    // CodeMirror's, we can stop the propagation without modifying the
    // CodeMirror code itself. The need for this should be revisited as
    // CodeMirror is upgraded moving forward. If it could be determined
    // (via simpler test case, for instance), that this is simply a
    // CodeMirror bug rather than an interaction with SproutCore, etc.,
    // then it would make sense to submit a PR to CodeMirror.
    if (this._cm.display && this._cm.display.scroller) {
      this._cm.display.scroller.addEventListener('touchend', function(evt) {
        evt.preventDefault();
        evt.stopImmediatePropagation();
      });
    }

    this._cm.on('keydown', function(cm, evt) {
      if (evt.keyCode === SC.Event.KEY_ESC) {
        // capture event so it can be prevented from bubbling up to dialog
        this._lastEscKeyEvent = evt;
      }
    });

    this._cm.on('changes', function(cm, changes) {
      // semantic coloring; adds an appropriate CSS class indicating
      // the category of an identifier, e.g. 'codap-Attributes'.
      this.addSemanticClasses(cm);

      SC.run(function() {
        // synchronize SproutCore model
        this._cm.save();
        this.fieldValueDidChange();
      }.bind(this));
    }.bind(this));

    // show hints (autocomplete menu) on keystrokes
    this._cm.on("inputRead", function(editor, change) {
      if (DG.Formula.identifierRegExp.test(change.text))
        editor.showHint();
    });

    $('.CodeMirror').css({ height: '100%' });
  },

  becomeFirstResponder: function() {
    if (this._cm)
      this._cm.focus();
  },

  // semantic coloring; adds an appropriate CSS class indicating
  // the category of an identifier, e.g. 'codap-Attributes'.
  addSemanticClasses: function(cm) {
    this.$('.cm-variable, .cm-function').each(function(index, node) {
      var classes = this.className
                        .split(' ')
                        .filter(function(iClass) {
                                  return !/codap-[A-Za-z]*/.test(iClass);
                                }),
          isVariable = classes.indexOf('cm-variable') >= 0,
          isFunction = classes.indexOf('cm-function') >= 0,
          nodeText = $(node).text(),
          nodeTextLength = nodeText ? nodeText.length : 0,
          completions = cm.options.hintOptions && cm.options.hintOptions.completionData,
          i, completionCount = completions && completions.length;
      if (isVariable && (nodeTextLength > 2) &&
          (nodeText[0] === '`') && (nodeText[nodeTextLength-1] === '`')) {
        nodeText = nodeText.substring(1, nodeTextLength - 1);
      }
      // linear search could be replaced with faster (e.g. binary) search
      // if performance becomes a problem.
      for (i = 0; i < completionCount; ++i) {
        if ((isVariable && (nodeText === completions[i].value)) ||
            (isFunction && (nodeText + '()' === completions[i].value))) {
          classes.push('codap-' + completions[i].category.key);
        }
      }
      this.className = classes.join(' ');
    });
  },

  formulaExpression: function( iKey, iValue) {
    if( iValue === undefined) {
      var tCurrent = this._cm.getValue();
      return tCurrent ? tCurrent.trim() : "";
    }
    else {
      this._cm.setValue(iValue || "");
    }
  }.property('value'),

  /**
    Replace the current selection with the specified string.
    @param    {String}    iNewString -- the string to insert
   */
  replaceSelectionWithString: function(iNewString) {
    this._cm.replaceSelection(iNewString);

    // if we're inserting a function reference, put the cursor between the parentheses
    if (endsWithParentheses(iNewString)) {
      var cursor = this._cm.getCursor(),
          currentLine = this._cm.getLine(cursor.line),
          start = cursor.ch - 1,
          end = start;
      while (start && (currentLine.charAt(start - 1) !== '(')) --start;
      this._cm.setSelection({line: cursor.line, ch: start},
                            {line: cursor.line, ch: end});
    }
  }
};

})());

/* >>>>>>>>>> BEGIN source/views/attribute_formula_view.js */
// ==========================================================================
//                        DG.AttributeFormulaView
//
//  Implements a dialog with edit fields for attribute name and formula.
//
//  Authors:  William Finzer, Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('formula/formula_context');
sc_require('views/formula_rich_edit_view');

/** @class

  A TableView contains a scrollable view that, in turn, contains a table.

  @extends SC.PalettePane
*/
DG.AttributeFormulaView = SC.PalettePane.extend(
/** @scope DG.AttributeFormulaView.prototype */ {

  isModal: YES,

  layout: { width: 400, height: 180, centerX: 0, centerY: 0 },

  contentView: SC.View.extend({
    classNames: 'dg-formula-dialog',
    childViews: 'attrName equalsLabel formula operandPopup functionPopup apply cancel resizeHandle'.w(),
      attrName: SC.TextFieldView.design({
        layout: { top: 5, left: 5, right: 25, height:24 },
        value: '',
        spellCheckEnabled: false,
        leftAccessoryView: SC.LabelView.create( {
                    layout: { left: 1, width: 95, height:22, centerY: 0 },
                    value: 'DG.AttrFormView.attrNamePrompt',  // "Attribute Name:"
                    backgroundColor: 'lightgray',
                    localize: true
                  })
      }),
      equalsLabel: SC.LabelView.extend({
        layout: { top: 5, right: 5, width: 12, height: 24 },
        value: "="
      }),
      formula: DG.FormulaRichEditView.design({
        layout: { top: 34, left: 5, right: 5, bottom:74 },
        value: '',
        isTextArea: true,
        spellCheckEnabled: false,
        hint: '',
        leftAccessoryView: SC.LabelView.create( {
                    layout: { left: 1, width: 55, bottom:1, top: 1 },
                    value: 'DG.AttrFormView.formulaPrompt', // "Formula:",
                    backgroundColor: 'lightgray',
                    localize: true
                  }),
        classNames: 'dg-formula-dialog-input-field'
      }),
      operandPopup: SC.PopupButtonView.extend({
        layout: { bottom: 44, left: 5, width: 140, height: 24 },
        localize: true,
        title: 'DG.AttrFormView.operandMenuTitle',
        menu: SC.MenuPane.extend({
          layout: { width: 200 },
          // Computed property which converts array of strings to array of menu item objects
          rawItems: function( iKey, iValues) {
            var maxItemLength = 0;
            if( iValues !== undefined) {
              // Convert the strings to menu items, including separators
              var tValues = iValues.map( function( iItem) {
                                            if( maxItemLength < iItem.length)
                                              maxItemLength = iItem.length;
                                            return { title: iItem, isSeparator: iItem === '--' };
                                          });
              this.set('items', tValues);
            }
            // Seems to work for string of arbitrary numbers of W's
            this.adjust('width', 40 + 10 * maxItemLength);
          }.property()
        })
      }),
      functionPopup: SC.PopupButtonView.extend({
        layout: { bottom: 44, left: 150, width: 170, height: 24 },
        localize: true,
        title: 'DG.AttrFormView.functionMenuTitle',
        mouseDown: function() {
          if (this._fbDiv && DG.React.Components.FunctionBrowser) {
            var onSelectFunction = function(name, argList, info) {
                  this.getPath('parentView.formula').replaceSelectionWithString("%@(%@)".fmt(name, argList));
                }.bind(this),
                fbComponent = DG.React.Components.FunctionBrowser({
                                                    anchor: this.get('layer'),
                                                    container: DG.mainPage.mainPane.get('layer'),
                                                    categorizedFunctionInfo: DG.functionRegistry.get('categorizedFunctionInfo'),
                                                    onSelect: onSelectFunction
                                                  });
            DG.React.toggleRender(this._fbDiv, fbComponent);
          }
        },
        action: null,
        didAppendToDocument: function() {
          this._fbDiv = document.createElement("div");
          // NOTE: component div should be inserted at the body level
          // so that the absolute positioning works correctly.
          document.body.appendChild(this._fbDiv);
        }
      }),
      apply: SC.ButtonView.design({
        layout: { bottom:5, right: 25, height:24, width: 90 },
        titleMinWidth: 0,
        title: 'DG.AttrFormView.applyBtnTitle', // "Apply"
        target: null,
        action: null,
        toolTip: '',
        localize: true,
        isDefault: true,
        classNames: 'dg-formula-dialog-apply'

      }),
      cancel: SC.ButtonView.design({
        layout: { bottom:5, right: 135, height:24, width: 90 },
        titleMinWidth: 0,
        title: 'DG.AttrFormView.cancelBtnTitle',  // "Cancel"
        target: null,
        action: null,
        toolTip: 'DG.AttrFormView.cancelBtnTooltip',  // "Dismiss the dialog without making any changes"
        localize: true,
        isCancel: true,
        classNames: 'dg-formula-dialog-cancel'

      }),
      resizeHandle: SC.View.extend({
        classNames: ['resize-handle'],
        layout: { right: 0, bottom: 0, width: 20, height: 20},

        render: function (context) {
          context.begin().addClass('handle-image').end();
        },

        mouseDown: function (evt) {
          // Cache the initial vertical offset and parent height.
          var parentView = this.get('parentView'),
              wrapperView = parentView.get('parentView'),
              frame = parentView.get('borderFrame');

          // Indicate that we are resizing.
          wrapperView.beginLiveResize();

          this._initialX = evt.clientX;
          this._initialY = evt.clientY;
          this._initialWidth = frame.width;
          this._initialHeight = frame.height;

          return true;
        },

        mouseDragged: function (evt) {
          var parentView = this.get('parentView'),
              width, height,
              offsetX, offsetY;

          offsetX = evt.clientX - this._initialX;
          offsetY = evt.clientY - this._initialY;
          // Parent view is centered, so we double the offset to keep the dragger under the mouse (for aesthetic purposes - the view would
          // continue to get the events even if the mouse is no longer over it, as RootResponder routes subsequent mouse events to the view
          // which handled mouseDown).
          width = Math.max(400, this._initialWidth + offsetX);
          height = Math.max(180, this._initialHeight + offsetY);
          parentView.adjust({width: width, height: height});
        },

        mouseUp: function (evt) {
          var parentView = this.get('parentView'),
              wrapperView = parentView.get('parentView');

          // Indicate that we are resizing.
          wrapperView.endLiveResize();

          // Clean up.
          delete this._initialX;
          delete this._initialY;
          parentView.set('transitionAdjust', SC.View.SMOOTH_ADJUST);

          return true;
        }
      })
  }),

  /**
    Forwarding property for the dialog's attribute name value.
    @property   {String}
   */
  attributeName: function( iKey, iValue) {
    return iValue === undefined
              ? this.getPath('contentView.attrName.value')
              : this.setPath('contentView.attrName.value', iValue);
  }.property(),

  /**
    Forwarding property for the dialog's formula value.
    @property   {String}
   */
  formula: function( iKey, iValue) {
    return iValue === undefined
              ? this.getPath('contentView.formula.formulaExpression')
              : this.setPath('contentView.formula.formulaExpression', iValue);
  }.property(),

  /**
    Initialization function.
   */
  init: function() {
    arguments.callee.base.apply(this,arguments);
    this.setPath('contentView.cancel.target', this);
    this.setPath('contentView.cancel.action', 'close');
  },

  keyDown: function(evt) {
    if (evt.keyCode === SC.Event.KEY_ESC) {
      this.close();
      return YES;
    }
    return NO;
  },

  /**
    Observer function called when the user selects an item from the Operands popup.
   */
  userSelectedOperand: function() {
    // Extract the text of the selected item
    var insertionString = this.getPath('contentView.operandPopup.menu.selectedItem.title');
    if( !SC.empty( insertionString)) {
      var canonicalString = DG.Attribute.canonicalizeName(insertionString, true),
          formulaView = this.getPath('contentView.formula');
      if (insertionString !== canonicalString)
        insertionString = '`' + insertionString + '`';
      // Replace the current selection with the selected item text
      if( formulaView) {
        formulaView.becomeFirstResponder();
        formulaView.replaceSelectionWithString( insertionString);
      }
    }
    // Clear the selected item so the same item can be selected multiple times
    this.setPath('contentView.operandPopup.menu.selectedItem', null);
  }.observes('.contentView.operandPopup.menu.selectedItem'),

  /**
    Close the dialog.
   */
  close: function() {
    // Not clear what the best way to close/destroy is.
    this.remove();
    this.destroy();
  }
});

DG.AttributeFormulaView.buildOperandsMenuAndCompletionData = function(iDataContext) {
  var collectionRecords = iDataContext.get('collections'),
      tGlobalNames = DG.globalsController.getGlobalValueNames(),
      tCompletionData = [],
      tOperandsMenu = [],
      kAttributesCategory = { key: 'Attributes',
                              name: 'DG.TableController.newAttrDialog.AttributesCategory'.loc() },
      kSpecialCategory = { key: 'Special',
                            name: 'DG.TableController.newAttrDialog.SpecialCategory'.loc() },
      kGlobalsCategory = { key: 'Globals',
                            name: 'DG.TableController.newAttrDialog.GlobalsCategory'.loc() },
      kConstantsCategory = { key: 'Constants',
                              name: 'DG.TableController.newAttrDialog.ConstantsCategory'.loc() },
      kFunctionsCategory = { key: 'Functions',
                              name: 'DG.TableController.newAttrDialog.FunctionsCategory'.loc() };

  function appendNamesToCompletionData(iNames, iCategory) {
    /* global removeDiacritics */
    tCompletionData = tCompletionData.concat(
                        iNames.map(function(iName) {
                                    // Remove diacritics (accents, etc.) for matching
                                    var label = removeDiacritics(iName),
                                        parenPos = label.indexOf('(');
                                    // Remove "()" from functions for matching
                                    if (parenPos > 0)
                                      label = label.substr(0, parenPos);
                                    return {
                                      label: label,   // for matching
                                      value: iName,   // menu/replacing
                                      category: iCategory
                                    };
                                  }));
  }

  function appendArrayOfNamesToMenu(iNamesArray, iCategory) {
    if( !iNamesArray || !iNamesArray.length) return;
    if( tOperandsMenu.length)
      tOperandsMenu.push('--');
    tOperandsMenu = tOperandsMenu.concat( iNamesArray.sort());

    if (iCategory && iCategory.name)
      appendNamesToCompletionData(iNamesArray, iCategory);
  }

  collectionRecords.forEach(function (collectionRecord) {
    var collectionContext = iDataContext.getCollectionByName(collectionRecord.name);
    appendArrayOfNamesToMenu(collectionContext.collection.getAttributeNames(), kAttributesCategory);
  });
  if (kSpecialCategory.name !== kConstantsCategory.name)
    appendArrayOfNamesToMenu(['caseIndex'], kSpecialCategory);
  appendArrayOfNamesToMenu(tGlobalNames, kGlobalsCategory);
  if (kSpecialCategory.name === kConstantsCategory.name)
    appendArrayOfNamesToMenu(['caseIndex'], kSpecialCategory);
  appendArrayOfNamesToMenu([ "e", "π", "true", "false" ]);
  tCompletionData.push({ label: "e", value: "e", category: kConstantsCategory });
  tCompletionData.push({ label: "π", value: "π", category: kConstantsCategory,
                          fontFamily: "Symbol,serif", fontSize: "130%" });
  // match against "pi", but render "π"
  tCompletionData.push({ label: "pi", value: "π", category: kConstantsCategory,
                          fontFamily: "Symbol,serif", fontSize: "130%" });
  tCompletionData.push({ label: "true", value: "true", category: kConstantsCategory });
  tCompletionData.push({ label: "false", value: "false", category: kConstantsCategory });

  appendNamesToCompletionData(DG.functionRegistry.get('namesWithParentheses'), kFunctionsCategory);

  return { operandsMenu: tOperandsMenu, completionData: tCompletionData };
};

DG.CreateAttributeFormulaView = function( iProperties) {
  var tDialog = DG.AttributeFormulaView.create(iProperties || {}),
    kParamMap = {
      attrNamePrompt: 'attrName.leftAccessoryView.value',
      attrNameValue: 'attrName.value',
      attrNameHint: 'attrName.hint',
      attrNameIsEnabled: 'attrName.isEnabled',

      formulaPrompt: 'formula.leftAccessoryView.value',
      formulaValue: 'formula.value',
      formulaExpression: 'formula.formulaExpression',
      formulaCompletions: 'formula.completionData',
      formulaNames: 'formula.names',
      formulaHint: 'formula.hint',
      formulaIsEnabled: 'formula.isEnabled',

      formulaOperands: 'operandPopup.menu.rawItems',

      applyTitle: 'apply.title',
      applyTarget: 'apply.target',
      applyAction: 'apply.action',
      applyTooltip: 'apply.toolTip',

      cancelTitle: 'cancel.title',
      cancelTooltip: 'cancel.toolTip'
    },
    tContentView = tDialog.get('contentView'),
    tAttrNameView = tContentView.attrName,
    tFormulaView = tContentView.formula;

  // Loop through client-specified properties, applying them to the
  // appropriate property via its path given in the kParamMap.
  DG.ObjectMap.forEach( iProperties,
              function( iKey, iValue) {
                var tParamPath = kParamMap[ iKey];
                if( !SC.empty( tParamPath))
                  tContentView.setPath( tParamPath, iValue);
              } );

  // if no apply action is specified, simply close the dialog
  if (!tContentView.getPath('apply.action')) {
    tContentView.setPath('apply.action', tContentView.getPath('cancel.action'));
  }

  tDialog.append();

  var tInitialView = tAttrNameView.get('isEnabled') ? tAttrNameView : tFormulaView;
  tInitialView.becomeFirstResponder();

  return tDialog;
};

/* >>>>>>>>>> BEGIN source/views/drag_border_view.js */
//                          DG.DragBorderView
//
//  Views for managing component resizing
//
//  Author:   William Finzer / Kirk Swenson
//
//  Copyright (c) 2020 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

var kMinComponentSize = 50,
    kMaxComponentSize = Number.MAX_VALUE,
    kRightBorderCursor = SC.Cursor.create({cursorStyle: SC.E_RESIZE_CURSOR}),
    kBottomBorderCursor = SC.Cursor.create({cursorStyle: SC.S_RESIZE_CURSOR}),
    kLeftBorderCursor = SC.Cursor.create({cursorStyle: SC.W_RESIZE_CURSOR}),
    kBottomLeftBorderCursor = SC.Cursor.create({cursorStyle: SC.SW_RESIZE_CURSOR}),
    kBottomRightBorderCursor = SC.Cursor.create({cursorStyle: SC.SE_RESIZE_CURSOR});

/** @class

    DragBorderView is typically a thin view configured to lie on the border of a component
 view. It implements the dragging functionality except for the actual change in the
 frame's layout.

 @extends SC.View
 */
DG.DragBorderView = SC.View.extend(
    (function () {

      return {
        /** @scope DG.DragBorderView.prototype */
        cursor: function () {
          if (this.canBeDragged())
            return this.dragCursor;
          else
            return null;
        }.property('dragCursor').cacheable(),
        isResizableDidChange: function() {
          this.set('isVisible', this.canBeDragged());
        }.observes('parentView.isResizable'),
        mouseDown: function (evt) {
          if (evt.button === 2 || evt.ctrlKey) {
            return NO;
          }
          DG.globalEditorLock.commitCurrentEdit();
          var tView = this.viewToDrag(),
              tParentView = tView.get('parentView');
          // Make sure the enclosing view will be movable
          DG.ViewUtilities.convertViewLayoutToAbsolute(tView);
          // A click on a border should bring the view to the front
          tView.select();
          if (!this.canBeDragged())
            return NO;  // We won't get other events either
          if( tParentView.coverUpComponentViews)
            tParentView.coverUpComponentViews('cover');

          var layout = this.viewToDrag().get('layout');
          this._mouseDownInfo = {
            pageX: evt.pageX, // save mouse pointer loc for later use
            pageY: evt.pageY, // save mouse pointer loc for later use
            left: layout.left,
            top: layout.top,
            height: layout.height,
            width: layout.width
          };
/*  We don't want to send this notification because we might only click and not drag.
          var tViewToDrag = this.viewToDrag();
          DG.currDocumentController().notificationManager.sendNotification({
            action: 'notify',
            resource: 'component',
            values: {
              operation: 'beginMoveOrResize',
              type: tViewToDrag.getPath('controller.model.type'),
              id: tViewToDrag.getPath('controller.model.id')
            }
          });
*/
          tView.get('controller').updateModelLayout();
          return YES; // so we get other events
        },

        mouseUp: function (evt) {
          var tViewToDrag = this.viewToDrag(),
              tComponentID = tViewToDrag.getPath('controller.model.id'),
              tContainer = tViewToDrag.get('parentView'),
              tOldLayout = this._mouseDownInfo,
              tNewLayout = tViewToDrag.get('layout'),
              isResize = (!SC.none(this.getPath('cursor.cursorStyle'))) && this.getPath('cursor.cursorStyle').indexOf('-resize') !== -1;
          // apply one more time to set final position
          this.mouseDragged(evt);
          this._mouseDownInfo = null; // cleanup info
          if( tContainer.coverUpComponentViews) {
            tContainer.coverUpComponentViews('uncover');
            tContainer.updateFrame();
          }
          if ((tOldLayout.left !== tNewLayout.left) || (tOldLayout.top !== tNewLayout.top) ||
              (tOldLayout.height !== tNewLayout.height) || (tOldLayout.width !== tNewLayout.width)) {

            DG.UndoHistory.execute(DG.Command.create({
              name: (isResize ? 'component.resize' : 'component.move'),
              undoString: (isResize ? 'DG.Undo.componentResize' : 'DG.Undo.componentMove'),
              redoString: (isResize ? 'DG.Redo.componentResize' : 'DG.Redo.componentMove'),
              executeNotification: {
                action: 'notify',
                resource: 'component',
                values: {
                  operation: isResize ? 'resize' : 'move',
                  type: tViewToDrag.getPath('controller.model.type'),
                  id: tComponentID,
                  title: tViewToDrag.getPath('controller.model.title')
                }
              },
              log: '%@ component "%@"'.fmt((isResize ? 'Resized' : 'Moved'), tViewToDrag.get('title')),
              _componentId: tViewToDrag.getPath('controller.model.id'),
              _controller: function () {
                return DG.currDocumentController().componentControllersMap[this._componentId];
              },
              _oldLayout: null,
              execute: function () {
                this._oldLayout = this._controller().updateModelLayout();
                if (!this._oldLayout) {
                  this.causedChange = false;
                }
              },
              undo: function () {
                if( !tViewToDrag)
                  return; // got nulled out because redo wasn't possible
                var layout = SC.clone(this._oldLayout);
                if (tViewToDrag.isMinimized()) {
                  this._oldHeight = this._oldLayout.height;
                  layout.height = 25;
                }
                tViewToDrag.animate(layout,
                    {duration: 0.4, timing: 'ease-in-out'},
                    function () {
                      // bizarre bug leaves the last animated transition property still
                      // with a delay even after the end of an animation, so we clear it by hand
                      tViewToDrag._view_layer.style.transition = "";
                      // set actual model layout once animation has completed
                      this._oldLayout = this._controller().revertModelLayout(layout);
                      tContainer.updateFrame();
                    }.bind(this));
                if (DG.KEEP_IN_BOUNDS_PREF) {
                  tViewToDrag.configureViewBoundsLayout({height:layout.height,
                                             width:layout.width,
                                             x:layout.left,
                                             y:layout.top});
                }
              },
              redo: function () {
                var layout = SC.clone(this._oldLayout);
                var documentController = DG.currDocumentController();
                var component = documentController.componentControllersMap[tComponentID];
                if(component) {
                  tViewToDrag = component.get('view');
                  if (tViewToDrag.isMinimized()) {
                    layout.height = 25;
                  }
                  tViewToDrag.animate(layout,
                      {duration: 0.4, timing: 'ease-in-out'},
                      function () {
                        tViewToDrag._view_layer.style.transition = "";
                        this._oldLayout = this._controller().revertModelLayout(this._oldLayout);
                        tContainer.updateFrame();
                      }.bind(this));
                  if (DG.KEEP_IN_BOUNDS_PREF) {
                    tViewToDrag.configureViewBoundsLayout({
                      height: layout.height,
                      width: layout.width,
                      x: layout.left,
                      y: layout.top
                    });
                  }
                }
                else  // Probably trying to work with a component that has been-recreated. Bail.
                  tViewToDrag = null; // So undo will be a no-op
              }
            }));
          }
          if (DG.KEEP_IN_BOUNDS_PREF) {
            DG.currDocumentController().computeScaleBounds();
          }
          return YES; // handled!
        },

        mouseDragged: function (evt) {
          var info = this._mouseDownInfo;

          if (info) {
            this.dragAdjust(evt, info);
            return YES; // event was handled!
          }
          else
            return NO;
        },
        touchStart: function (evt) {
          return this.mouseDown(evt);
        },
        touchEnd: function (evt) {
          return this.mouseUp(evt);
        },
        touchesDragged: function (evt, touches) {
          return this.mouseDragged(evt);
        },
        dragAdjust: function (evt, info) {
          // default is to do nothing
        },
        viewToDrag: function () {
          return DG.ComponentView.findComponentViewParent(this);
        },
        getContainerWidth: function () {
          return $('#codap').width();
        },
        getContainerHeight: function () {
          var tDocView = this.viewToDrag();
          while (!SC.none(tDocView.parentView.parentView)) {
            tDocView = tDocView.parentView;
          }
          return $('#codap').height() - tDocView.get('frame').y;
        }
      };
    }())
);

DG.DragLeftBorderView = DG.DragBorderView.extend({
  dragCursor: kLeftBorderCursor,
  canBeDragged: function() {
    var tCanBeDragged = this.getPath('parentView.isWidthResizable');
    return tCanBeDragged;
  },
  dragAdjust: function (evt, info) {
    var tMaxWidth = this.parentView.get('contentMaxWidth') || kMaxComponentSize,
        tMinWidth = this.get('contentMinWidth') || kMinComponentSize,
        tContainerWidth = this.getContainerWidth();
    if (DG.KEEP_IN_BOUNDS_PREF) {
      evt.pageX = Math.max(0, evt.pageX);
    }
    var tNewWidth = DG.ViewUtilities.roundToGrid(info.width - (evt.pageX - info.pageX)),
        tLoc;
    tNewWidth = Math.min(Math.max(tNewWidth, tMinWidth), tMaxWidth);
    tLoc = info.left + info.width - tNewWidth;
    if (tLoc < tContainerWidth - tMinWidth) {
      this.parentView.adjust('width', tNewWidth);
      this.parentView.adjust('left', tLoc);
    }
    if (DG.KEEP_IN_BOUNDS_PREF) {
      var tInBoundsScaling = DG.currDocumentController().get('inBoundsScaling'),
          tScaleFactor = tInBoundsScaling.scaleFactor;
      this.parentView.originalLayout.width = tNewWidth / tScaleFactor;
      this.parentView.originalLayout.left = tLoc / tScaleFactor;
    }
  }
});

DG.DragRightBorderView = DG.DragBorderView.extend({
  dragCursor: kRightBorderCursor,
  canBeDragged: function() {
    var tCanBeDragged = this.getPath('parentView.isWidthResizable');
    return tCanBeDragged;
  },
  dragAdjust: function (evt, info) {
    // Don't let user drag right edge off left of window
    var tMinWidth = this.get('contentMinWidth') || kMinComponentSize,
        tLoc = Math.max(evt.pageX, tMinWidth),
        tNewWidth = DG.ViewUtilities.roundToGrid(info.width + (tLoc - info.pageX)),
        tMaxWidth = this.parentView.get('contentMaxWidth') || kMaxComponentSize,
        tContainerWidth = this.getContainerWidth();
    if (DG.KEEP_IN_BOUNDS_PREF) {
      var tInspectorDimensions = this.parentView.getInspectorDimensions();
      tMaxWidth = Math.min(tMaxWidth, tContainerWidth - (info.left + tInspectorDimensions.width));
    }
    // Don't let width of component become too small
    tNewWidth = Math.min(Math.max(tNewWidth, tMinWidth), tMaxWidth);
    this.parentView.adjust('width', tNewWidth);
    if (DG.KEEP_IN_BOUNDS_PREF) {
      var tInBoundsScaling = DG.currDocumentController().get('inBoundsScaling'),
          tScaleFactor = tInBoundsScaling.scaleFactor;
      this.parentView.originalLayout.width = tNewWidth / tScaleFactor;
    }
  }
});

DG.DragBottomBorderView = DG.DragBorderView.extend({
  dragCursor: kBottomBorderCursor,
  canBeDragged: function() {
    var tCanBeDragged = this.getPath('parentView.isHeightResizable');
    return tCanBeDragged;
  },
  dragAdjust: function (evt, info) {
    var tMinHeight = this.get('contentMinHeight') || kMinComponentSize,
        tMaxHeight = this.get('contentMaxHeight') || kMaxComponentSize,
        tNewHeight = info.height + (evt.pageY - info.pageY),
        tContainerHeight = this.getContainerHeight();
    if (DG.KEEP_IN_BOUNDS_PREF) {
      tMaxHeight = Math.min(tMaxHeight, tContainerHeight - info.top);
    }
    tNewHeight = DG.ViewUtilities.roundToGrid(Math.min(
        Math.max(tNewHeight, tMinHeight), tMaxHeight));
    this.parentView.adjust('height', tNewHeight);
    if (DG.KEEP_IN_BOUNDS_PREF) {
      var tInBoundsScaling = DG.currDocumentController().get('inBoundsScaling'),
          tScaleFactor = tInBoundsScaling.scaleFactor;
      this.parentView.originalLayout.height = tNewHeight / tScaleFactor;
    }
  }
});

DG.DragBottomLeftBorderView = DG.DragBorderView.extend({
  dragCursor: kBottomLeftBorderCursor,
  canBeDragged: function() {
    var tCanBeDragged = this.getPath('parentView.isWidthResizable') ||
        this.getPath('parentView.isHeightResizable');
    return tCanBeDragged;
  },
  dragAdjust: function (evt, info) {
    // Don't let user drag right edge off left of window
    var tMinHeight = this.get('contentMinHeight') || kMinComponentSize,
        tMaxHeight = this.get('contentMaxHeight') || kMaxComponentSize,
        tMinWidth = this.get('contentMinWidth') || kMinComponentSize,
        tLoc = Math.max(evt.pageX, tMinWidth),
        tNewWidth = DG.ViewUtilities.roundToGrid(info.width - (evt.pageX - info.pageX)),
        tNewHeight = DG.ViewUtilities.roundToGrid(info.height + (evt.pageY - info.pageY)),
        tMaxWidth = this.parentView.get('contentMaxWidth') || kMaxComponentSize,
        tContainerWidth = this.getContainerWidth(),
        tContainerHeight = this.getContainerHeight();
    if (DG.KEEP_IN_BOUNDS_PREF) {
      tMaxHeight = tContainerHeight - info.top;
      var tInspectorDimensions = this.parentView.getInspectorDimensions();
      tMaxWidth = Math.min(tMaxWidth, tContainerWidth - (info.left + tInspectorDimensions.width));
    }
    if( !this.getPath('parentView.isWidthResizable'))
      tNewWidth = info.width; // No change
    else {
      // Don't let width or height of component become too small
      tNewWidth = Math.min(Math.max(tNewWidth, tMinWidth), tMaxWidth);
      tLoc = info.left + info.width - tNewWidth;
      if (tLoc < tContainerWidth - tMinWidth) {
        this.parentView.adjust('width', tNewWidth);
        this.parentView.adjust('left', tLoc);
      }
    }
    if( !this.getPath('parentView.isHeightResizable'))
      tNewHeight = info.height;
    else {
      tNewHeight = Math.min(Math.max(tNewHeight, tMinHeight), tMaxHeight);
      this.parentView.adjust('height', tNewHeight);
    }
    if (DG.KEEP_IN_BOUNDS_PREF) {
      var tInBoundsScaling = DG.currDocumentController().get('inBoundsScaling'),
          tScaleFactor = tInBoundsScaling.scaleFactor;
      this.parentView.originalLayout.height = tNewHeight / tScaleFactor;
      this.parentView.originalLayout.width = tNewWidth / tScaleFactor;
    }
  }
});

DG.DragBottomRightBorderView = DG.DragBorderView.extend({
  dragCursor: kBottomRightBorderCursor,
  canBeDragged: function() {
    var tCanBeDragged = this.getPath('parentView.isWidthResizable') ||
        this.getPath('parentView.isHeightResizable');
    return tCanBeDragged;
  },
  dragAdjust: function (evt, info) {
    // Don't let user drag right edge off left of window
    var tMinHeight = this.get('contentMinHeight') || kMinComponentSize,
        tMaxHeight = this.get('contentMaxHeight') || kMaxComponentSize,
        tMinWidth = this.get('contentMinWidth') || kMinComponentSize,
        tLoc = Math.max(evt.pageX, tMinWidth),
        tNewWidth = DG.ViewUtilities.roundToGrid(info.width + (tLoc - info.pageX)),
        tNewHeight = DG.ViewUtilities.roundToGrid(info.height + (evt.pageY - info.pageY)),
        tMaxWidth = this.parentView.get('contentMaxWidth') || kMaxComponentSize,
        tContainerWidth = this.getContainerWidth(),
        tContainerHeight = this.getContainerHeight();
    if (DG.KEEP_IN_BOUNDS_PREF) {
      tMaxHeight = tContainerHeight - info.top;
      var tInspectorDimensions = this.parentView.getInspectorDimensions();
      tMaxWidth = Math.min(tMaxWidth, tContainerWidth - (info.left + tInspectorDimensions.width));
    }
    if( !this.getPath('parentView.isWidthResizable'))
      tNewWidth = info.width; // No change
    else {
      // Don't let width or height of component become too small
      tNewWidth = Math.min(Math.max(tNewWidth, tMinWidth), tMaxWidth);
      this.parentView.adjust('width', tNewWidth);
    }
    if( !this.getPath('parentView.isHeightResizable'))
      tNewHeight = info.height; // No change
    else {
      tNewHeight = Math.min(Math.max(tNewHeight, tMinHeight), tMaxHeight);
      this.parentView.adjust('height', tNewHeight);
    }
    if (DG.KEEP_IN_BOUNDS_PREF) {
      var tInBoundsScaling = DG.currDocumentController().get('inBoundsScaling'),
          tScaleFactor = tInBoundsScaling.scaleFactor;
      this.parentView.originalLayout.height = tNewHeight / tScaleFactor;
      this.parentView.originalLayout.width = tNewWidth / tScaleFactor;
    }
  }
});

/* >>>>>>>>>> BEGIN source/views/tooltip_enabler.js */
// ==========================================================================
//                          DG.TooltipEnabler
// 
//  A mixin that makes tooltips work properly in ordinary views
//  
//  Author:   William Finzer
//
//  Copyright (c) 2018 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

    DG.TooltipEnabler is a mixin the does the right thing with a View's tooltip property.

 */
DG.TooltipEnabler = {
  localize: true,
  toolTipDidChange: function() {
    this.updateLayer();
  }.observes('displayToolTip'),
  render: function(context) {
    arguments.callee.base.apply(this,arguments);
    var toolTip = this.get('displayToolTip');
    if (toolTip)
      context.setAttr('title', toolTip);
  }
};
/* >>>>>>>>>> BEGIN source/views/titlebar_button_view.js */
// ==========================================================================
//                          DG.TitleBarCloseButton
//
//  A button view that allows user to close a component view.
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('views/mouse_and_touch_view');
sc_require('views/tooltip_enabler');

/** @class

   DG.TitleBarCloseButton handles the close button in a component view's title bar.

 @extends SC.View
 */
DG.TitleBarCloseButton = SC.View.extend(DG.MouseAndTouchView, DG.TooltipEnabler,
   /** @scope DG.MouseAndTouchView.prototype */
   (function() {
     return {
       classNames: 'dg-close-icon'.w(),
       toolTip: 'DG.Component.closeComponent.toolTip',
       isSelected: false,
       classNameBindings: ['isSelected:dg-close-icon-selected'],
       allowParent: NO,
       init: function() {
         arguments.callee.base.apply(this,arguments);
         if(!SC.platform.touch) {
           // The following two lines are a workaround to make sure that in SageModeler the button shows
           // itself on the initial hover over the titlebar. (Strange, I know.)
           this.set('isVisible', true);
           this.invokeLater(function() {
             this.set('isVisible', false);
           }.bind(this), 1);
         }
       },
       doIt: function() {
         var tComponentId = this.parentView.viewToDrag().getPath(
               'controller.model.id'),
            tController = DG.currDocumentController().componentControllersMap[tComponentId],
            tShouldConfirmClose = tController.get('shouldConfirmClose'),
            tConfirmCloseMessage = tController.get('confirmCloseMessage')
                                   || 'DG.Component.closeComponent.confirmCloseMessage',
            tConfirmCloseDescription = tController.get('confirmCloseDescription')
                                       || 'DG.Component.closeComponent.confirmCloseDescription';

         // Some components are not closed, but are hidden. These are
         // distinguished by presence of toggleViewVisiblity method.
         if(tController.toggleViewVisibility) {
           tController.toggleViewVisibility();
         } else {

           var closeComponentAfterConfirm = function() {
             DG.closeComponent(tComponentId);
           }.bind(this);

           if(tShouldConfirmClose) {
             DG.AlertPane.warn({
               message: tConfirmCloseMessage,
               description: tConfirmCloseDescription,
               buttons: [
                 {
                   title: 'DG.Component.closeComponent.okButtonTitle',
                   action: closeComponentAfterConfirm,
                   localize: YES
                 },
                 {
                   title: 'DG.Component.closeComponent.cancelButtonTitle',
                   localize: YES,
                   isCancel: YES,
                   isDefault: YES
                 }
               ],
               localize: YES
             });

           } else {
             DG.closeComponent(tComponentId);
           }
         }
       },
       closeComponent: function(iComponentID, iController) {
         if(iController.toggleViewVisibility) {
           iController.toggleViewVisibility();
         } else {
           var tState;
           // Give the controller a chance to do some housekeeping before we close it (defocus, commit edits, etc.).
           // Also, do this outside of the undo command, so that it can register its own
           // separate undo command if desired.
           iController.willCloseComponent();

           DG.UndoHistory.execute(DG.Command.create({
             name: 'component.close',
             undoString: 'DG.Undo.component.close',
             redoString: 'DG.Redo.component.close',
             _componentId: iComponentID,
             _controller: function() {
               return DG.currDocumentController().componentControllersMap[this._componentId];
             },
             _model: null,
             execute: function() {
               iController = this._controller();
               var tComponentView = iController.get('view'),
                  tContainerView = tComponentView.get('parentView');

               this.log = 'closeComponent: %@'.fmt(tComponentView.get('title'));
               this._model = iController.get('model');

               // Some components (the graph in particular), won't restore correctly without calling willSaveComponent(),
               // because sometimes not all of the info necessary to restore the view is actively held in the model.
               // (In the graph's case, there is 'model' which relates to the view, and 'graphModel' which holds all of the
               // configuration like axis ranges, legends, etc.)
               iController.willSaveComponent();

               if(iController.saveGameState) {
                 // If we are a GameController, try to save state.
                 // Since this is an asynchronous operation, we have to hold off closing the component
                 // until it is complete (or it will fail).
                 // Also, since closing the document will happen after this command executes, dirtying the
                 // document will clear the undo history, so we must force it not to dirty.
                 iController.saveGameState(function(result) {
                   if(result && result.success) {
                     tState = result.state;
                   }
                   SC.run(function() {
                     if(tContainerView.removeComponentView)
                       tContainerView.removeComponentView(tComponentView);
                   });
                 });
               } else {
                 if(tContainerView.removeComponentView)
                   tContainerView.removeComponentView(tComponentView);
               }
             },
             undo: function() {
               DG.currDocumentController().createComponentAndView(this._model);

               iController = this._controller();
               if(iController.restoreGameState && tState) {
                 iController.restoreGameState({ gameState: tState });
               }
             }
           }));
         }
       }
     };
   }()) // function closure
);

/** @class

   DG.TitleBarMinimizeButton handles the minimize button in a component view's title bar.

 @extends SC.View
 */
DG.TitleBarMinimizeButton = SC.View.extend(DG.MouseAndTouchView, DG.TooltipEnabler,
   /** @scope DG.MouseAndTouchView.prototype */
   (function() {
     return {
       classNames: 'dg-min-icon'.w(),
       allowParent: NO,
       init: function() {
         arguments.callee.base.apply(this,arguments);
         if(!SC.platform.touch) {
           // The following two lines are a workaround to make sure that in SageModeler the button shows
           // itself on the initial hover over the titlebar. (Strange, I know.)
           this.set('isVisible', true);
           this.invokeLater(function() {
             this.set('isVisible', false);
           }.bind(this), 1);
         }
       },
       isSelected: false,
       classNameBindings: ['isSelected:dg-min-icon-selected'],
       toolTip: 'DG.Component.minimizeComponent.toolTip',
       doIt: function() {
         var tComponentView = this.parentView.viewToDrag();
         DG.UndoHistory.execute(DG.Command.create({
           name: 'component.minimize',
           undoString: 'DG.Undo.component.minimize',
           redoString: 'DG.Redo.component.minimize',
           log: (tComponentView.get('isMinimized') ? "Expanded component" : "Minimized component"),
           executeNotification: {
             action: 'notify',
             resource: 'component',
             values: {
               operation: 'toggle minimize component',
               type: tComponentView.getPath('model.type')
             }
           },
           execute: function() {
             tComponentView.toggleMinimization();
           },
           undo: function() {
             this.execute();
           }
         }));
       }
     };
   }()) // function closure
);

/** @class

   DG.TitleBarUndoRedoButton is a base class for TitleBarUndoButton and TitleBarRedoButton

 @extends SC.View
 */
DG.TitleBarUndoRedoButton = SC.View.extend(DG.MouseAndTouchView, DG.TooltipEnabler,
   /** @scope DG.MouseAndTouchView.prototype */
   (function() {
     return {
       localize: true,
       isVisibleBinding: SC.Binding.oneWay('DG.UndoHistory.enabled'),
       isVisible: true
     };
   }()) // function closure
);

/** @class

   DG.TitleBarUndoButton handles the undo button that appears in a component view's title bar
 when DG.embeddedMode === 'yes'.

 @extends SC.View
 */
DG.TitleBarUndoButton = DG.TitleBarUndoRedoButton.extend(
   /** @scope DG.MouseAndTouchView.prototype */
   (function() {
     return {
       toolTip: function() {
         var cmd = this.get('nextUndoCommand');
         return (cmd ? cmd.get('undoString') : 'DG.mainPage.mainPane.undoButton.toolTip'); // "Undo the last action"
       }.property('nextUndoCommand'),
       nextUndoCommandBinding: SC.Binding.oneWay('DG.UndoHistory.nextUndoCommand'),
       isEnabledBinding: SC.Binding.oneWay('DG.UndoHistory.canUndo'),
       classNames: 'dg-undo-icon'.w(),
       doIt: function() {
         DG.UndoHistory.undo();
       }
     };
   }()) // function closure
);

/** @class

   DG.TitleBarRedoButton handles the redo button that appears in a component view's title bar
 when DG.embeddedMode === 'yes'.

 @extends SC.View
 */
DG.TitleBarRedoButton = DG.TitleBarUndoRedoButton.extend(
   /** @scope DG.MouseAndTouchView.prototype */
   (function() {
     return {
       toolTip: function() {
         var cmd = this.get('nextRedoCommand');
         return (cmd ? cmd.get('redoString') : 'DG.mainPage.mainPane.redoButton.toolTip');  // "Redo the last undone action"
       }.property('nextRedoCommand'),
       nextRedoCommandBinding: SC.Binding.oneWay('DG.UndoHistory.nextRedoCommand'),
       isEnabledBinding: SC.Binding.oneWay('DG.UndoHistory.canRedo'),
       classNames: 'dg-redo-icon'.w(),
       doIt: function() {
         DG.UndoHistory.redo();
       }
     };
   }()) // function closure
);

/** @class

   DG.CaseCardToggleButton, when clicked, switches the case table to a case card

 @extends SC.View
 */
DG.CaseCardToggleButton = SC.View.extend(DG.MouseAndTouchView, DG.TooltipEnabler,
   /** @scope DG.MouseAndTouchView.prototype */
   (function() {
     return {
       classNames: 'dg-card-icon'.w(),
       toolTip: 'DG.DocumentController.toggleToCaseCard',
       isVisible: true, // to start with
       doIt: function() {
         var tComponentView = this.parentView.viewToDrag(),
            tItems = [
              {
                title: 'DG.DocumentController.toggleToCaseCard'.loc(),
              }
            ];

         DG.MenuPane.create({
           classNames: 'dg-attributes-popup'.w(),
           layout: { width: 200, height: 150 },
           items: tItems,
           selectedItemDidChange: function() {
             DG.UndoHistory.execute(DG.Command.create({
               name: 'toggle.toCaseCard',
               undoString: 'DG.Undo.component.toggleTableToCard',
               redoString: 'DG.Redo.component.toggleTableToCard',
               log: 'Toggle case table to case card',
               executeNotification: {
                 action: 'notify',
                 resource: 'component',
                 values: {
                   operation: 'toggle table to card',
                   type: 'DG.CaseTable'
                 }
               },
               execute: function() {
                 DG.currDocumentController().toggleTableToCard(tComponentView);
               },
               undo: function() {
                 var tDocController = DG.currDocumentController(),
                    tContext = tComponentView.getPath('controller.dataContext'),
                    tCardComponentView = tDocController.tableCardRegistry.getCardView(tContext);
                 tDocController.toggleCardToTable(tCardComponentView);
               }
             }));
           }.observes('selectedItem')
         }).popup(this, [0, -20, SC.POSITION_BOTTOM]);

       }
     };
   }()) // function closure
);

/** @class

   DG.CaseTableToggleButton, when clicked, switches the case table to a case card

 @extends SC.View
 */
DG.CaseTableToggleButton = SC.View.extend(DG.MouseAndTouchView, DG.TooltipEnabler,
   /** @scope DG.MouseAndTouchView.prototype */
   (function() {
     return {
       classNames: 'dg-table-icon'.w(),
       toolTip: 'DG.DocumentController.toggleToCaseTable',
       isVisible: true, // to start with
       doIt: function() {
         var tComponentView = this.parentView.viewToDrag(),
            tItems = [
              {
                title: 'DG.DocumentController.toggleToCaseTable'.loc(),
              }
            ];

         DG.MenuPane.create({
           classNames: 'dg-attributes-popup'.w(),
           layout: { width: 200, height: 150 },
           items: tItems,
           selectedItemDidChange: function() {
             DG.UndoHistory.execute(DG.Command.create({
               name: 'toggle.toCaseTable',
               undoString: 'DG.Undo.component.toggleCardToTable',
               redoString: 'DG.Redo.component.toggleCardToTable',
               log: 'Toggle case card to case table',
               executeNotification: {
                 action: 'notify',
                 resource: 'component',
                 values: {
                   operation: 'toggle card to table',
                   type: 'DG.CaseCard'
                 }
               },
               execute: function() {
                 DG.currDocumentController().toggleCardToTable(tComponentView);
               },
               undo: function() {
                 var tDocController = DG.currDocumentController(),
                    tContext = tComponentView.getPath('controller.dataContext'),
                    tTableComponentView = tDocController.tableCardRegistry.getTableView(tContext);
                 tDocController.toggleTableToCard(tTableComponentView);
               }
             }));
           }.observes('selectedItem')
         }).popup(this, [0, -20, SC.POSITION_BOTTOM]);

       }
     };
   }()) // function closure
);


/* >>>>>>>>>> BEGIN source/views/component_view.js */
//                          DG.ComponentView
//
//  Routines for changing coordinates along an animation path
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('views/drag_border_view');
sc_require('views/titlebar_button_view');

var kResizeHandleSize = 26, // total size of interactable area
    kResizeHandleInset = 4; // size of interactable area outside the component
                            // difference is the size of the visible handle

/** @class

    ComponentView provides a draggable and resizable container for components such as plots and
 tables. The structure is as follows:
 - outerView
 - containerView is inset by the border width
 - titlebarView
 - contentView passed in by clients positioned under the titlebarView
 - 4 drag views laid on top of the containerView's borders and allowing resize

 @extends SC.View
 */
DG.ComponentView = SC.View.extend(
    /** @scope DG.ComponentView.prototype */
    (function () {
      var kTitleBarHeight = DG.ViewUtilities.kTitleBarHeight,
          kMinSize = 50,
          kDragWidth = DG.ViewUtilities.kDragWidth,
          kBorderWidth = DG.ViewUtilities.kBorderWidth,
          kViewInComponentMode = DG.get('componentMode') === 'yes',
          kViewInEmbeddedMode = DG.get('embeddedMode') === 'yes',
          kHideUndoRedoInComponent = DG.get('hideUndoRedoInComponent') === 'yes',
          kShowUndoRedoButtons = (kViewInComponentMode || kViewInEmbeddedMode) && !kHideUndoRedoInComponent,
          kLockThingsDown = kViewInComponentMode;
      return {
        classNames: ['dg-component-view'],
        classNameBindings: ['isSelected:dg-component-view-selected'],

        /**
         * Returns true if model has both width and height as resizable, false otherwise
         * @property {boolean}
         */
        isResizable: function( iKey, iValue) {
          if( !SC.empty(iValue))
            this.setPath('model.isResizable', iValue);
          return this.getPath('model.isResizable');
        }.property(),
        isResizableDidChange: function() {
          this.propertyDidChange('isResizable');
        }.observes('model.isResizable'),
        isWidthResizable: function() {
          return this.getPath('model.isWidthResizable');
        }.property(),
        isHeightResizable: function() {
          return this.getPath('model.isHeightResizable');
        }.property(),

        isClosable: YES,
        showTitleBar: YES,

        /**
         * These buttons are provided by the controller and are specific to the type of component.
         * The buttons that toggle between case card and case table are an example.
         * @property {[SC.View]}
         */
        specialTitleBarButtons: function() {
          var tController = this.get('controller');
          return tController ? tController.get('specialTitleBarButtons') : [];
        }.property('controller'),

        /**
         * @property {DG.ComponentController}
         */
        controller: null,

        controllerDidChange: function() {
          var tTitleBar = this.getPath('containerView.titlebar'),
              tTitleView = tTitleBar && tTitleBar.get('titleView'),
              tTitleViewLayer = tTitleView && tTitleView.get('layer'),
              tSpecialButtons = this.get('specialTitleBarButtons');
          tSpecialButtons.forEach( function( iButton, iIndex) {
            iButton.adjust({ left: 5 + iIndex * 30, width: 25 });
            tTitleBar.appendChild( iButton);
          });
          if( tTitleView && tTitleViewLayer) {
            tTitleView.adjust({left: 0, right: 0});
            tTitleViewLayer.style.paddingLeft = (tSpecialButtons.length * 10 + 5) + 'px';
          }
        }.observes('controller'),

        /**
         * @property {DG.Component}
         */
        model: null,

        /**
         * @property {Array of DG.InspectorButtonView}
         */
        inspectorButtonsBinding: SC.Binding.from('*controller.inspectorButtons').oneWay(),

        /**
         * Is this component view the one selected component view in the container?
         * @property {Boolean}
         */
        isSelected: false,

        isSelectedChanged: function () {
          this.setPath('containerView.titlebar.isSelected', this.get('isSelected'));
        }.observes('isSelected'),

        _modelSavedHeightBinding: SC.Binding.from('*model.savedHeight').oneWay(),

        modelDidChange: function() {
          // Title bar needs to know about my model to decide whether to show closebox or not
          this.setPath('containerView.titlebar.model', this.get('model'));
        }.observes('model'),

        isMinimized: function () {
          return !SC.none(this.get('_modelSavedHeight'));
        }.property('_modelSavedHeight'),

        isMinimizedChanged: function() {
          var tIsMinimize = this.get('isMinimized');
          this.setPath('contentView.isVisible', !tIsMinimize);
        }.observes('isMinimized'),

        init: function () {
          arguments.callee.base.apply(this,arguments);
          if (!this.get('showTitleBar')) {
            this.getPath('containerView.titlebar').adjust('height', 0);
          }
          // If we are in component mode we select the component after it is
          // rendered.
          if (kViewInComponentMode && this.get('isVisible')) {
            this.invokeLater(function () {
              this.select();
            }.bind(this));
          }
          if (DG.KEEP_IN_BOUNDS_PREF && !this.originalLayout) {
            this.originalLayout = {};
          }
          if (this.get('isStandaloneComponent')) {
            this.hideBorders();
          }
          this.set('title', this.getPath('model.title'));
        },
        hideBorders: function () {
          this.get('borderRight').set('isVisible', false);
          this.get('borderBottom').set('isVisible', false);
          this.get('borderLeft').set('isVisible', false);
          this.get('borderBottomLeft').set('isVisible', false);
          this.get('borderBottomRight').set('isVisible', false);
          this.get('resizeBottomRight').set('isVisible', false);
        },
        /**
         * Makes a component view standalone. This means:
         *  * Hiding borders
         *  * Hiding title bar
         *  * Binding component dimensions to the parent container
         *  * Making component lowest in view hierarchy (sendToBack)
         */
        makeStandalone: function () {
          this.set('isStandaloneComponent', true);
          this.hideBorders();
          this.getPath('containerView.titlebar').adjust('height', 0);
          this.getPath('containerView.contentView').adjust('top', 0);
          this.parentView.sendToBack(this);
          this.layout = {};
        },
        setFocusToComponentTitle: function () {
          var titleView = this.getPath('containerView.titlebar.titleView');
          if (titleView) {
            titleView.beginEditing();
          }
        },
        contentView: function( iKey, iValue) {
          if( iValue) {
            this.setPath('containerView.contentView', iValue);
          }
          return this.getPath('containerView.contentView');
        }.property(),
        childViews: ('containerView' +
                      (DG.get('componentMode') === 'no'
                        ? ' borderRight borderBottom borderLeft borderBottomLeft borderBottomRight resizeBottomRight'
                        : '')).w(),
        containerView: SC.View.design({
          classNames: ['dg-component-container'],
          layout: {left: 0, bottom: 0, right: 0},
          childViews: 'titlebar coverSheet'.w(),
          titlebar: DG.DragBorderView.design({
            layout: {height: kTitleBarHeight},
            classNames: ['dg-titlebar'],
            isSelected: false,
            userEdit: false,
            classNameBindings: ['isSelected:dg-titlebar-selected'],
            isSelectedDidChange: function() {
              this.setPath('closeBox.isSelected', this.get('isSelected'));
              this.setPath('minimize.isSelected', this.get('isSelected'));
            }.observes('isSelected'),
            childViews: ('statusView versionView titleView ' +
            (!kLockThingsDown ? 'minimize closeBox ' : '') +
            (kShowUndoRedoButtons ? 'undo redo ' : '')).w(),
            titleView: SC.LabelView.design(DG.MouseAndTouchView, SC.AutoResize, {
              classNames: ['dg-titleview'],
              classNameBindings: ['valueIsEmpty:dg-titleview-empty'],
              isEditable: YES,
              exampleNode: null,
              _value: null,
              value: function (key, iValue) {
                if (!SC.none(iValue)) {
                  this._value = iValue;
                }
                return this._value;
              }.property(),
              inlineEditorWillBeginEditing: function (iEditor, iValue, iEditable) {
                arguments.callee.base.apply(this,arguments);
                var tComponentView = DG.ComponentView.findComponentViewParent(this),
                    tParent = this.get('parentView'),
                    tFrame = tParent.get('frame'),
                    kXGap = 4, kYGap = 2,
                    tOrigin = DG.ViewUtilities.viewToWindowCoordinates({x: kXGap, y: kYGap}, tParent);
                tParent.set('userEdit', true);
                tComponentView.select();

                // SC 1.10 introduced a new inline editor model in which
                // an 'exampleNode' is used to adjust inline editor style.
                var exampleNode = this.get('exampleNode');
                if (!exampleNode) {
                  exampleNode = this.get('layer').cloneNode(false);
                  exampleNode.id = exampleNode.id + "-clone";
                  exampleNode.style.visibility = 'hidden';
                  exampleNode.style.textAlign = 'center';
                  exampleNode.className = exampleNode.className.replace('dg-titleview', '');
                  tParent.get('layer').appendChild(exampleNode);
                  this.set('exampleNode', exampleNode);
                }
                exampleNode.style.left = 3 + 'px';
                exampleNode.style.top = 12 + 'px';

                iEditor.set({
                  exampleElement: exampleNode,
                  exampleFrame: {
                    x: tOrigin.x, y: tOrigin.y,
                    width: tFrame.width - 2 * kXGap, height: tFrame.height - 2 * kYGap
                  }
                });
              },
              inlineEditorDidEndEditing: function () {
                arguments.callee.base.apply(this,arguments);
                this.get('parentView').set('userEdit', false);
              },
              valueChanged: function () {
                var tComponentView = DG.ComponentView.findComponentViewParent(this),
                    tParent = this.get('parentView'),
                    value = this.get('value'),
                    this_ = this;
                if (!tParent.userEdit) {
                  return;
                }
                if (tComponentView) {
                  tParent.userEdit = false;
                  DG.UndoHistory.execute(DG.Command.create({
                    name: 'component.titleChange',
                    executeNotification: {
                      action: 'notify',
                      type: tComponentView.getPath('model.type'),
                      resource: 'component['+tComponentView.getPath('model.id') + ']',
                      values: {
                        operation: 'titleChange',
                        from: tComponentView.getPath('model.title'),
                        to: value
                      }
                    },
                    undoString: 'DG.Undo.componentTitleChange',
                    redoString: 'DG.Redo.componentTitleChange',
                    _userPreviouslySetTitle: tComponentView.getPath('model.userSetTitle'),
                    execute: function () {
                      this._beforeStorage = tComponentView.getPath('model.title');
                      // If the title has already been changed (e.g. due to notification),
                      // then use the previous title for purposes of logging the change.
                      if (this._beforeStorage === value)
                        this._beforeStorage = tComponentView.getPath('model._prevTitle');
                      tComponentView.setPath('model.title', value);
                      tComponentView.setPath('model.userSetTitle', true);
                      this.log = "Change title '%@' to '%@'".fmt(this._beforeStorage, value);
                    },
                    undo: function () {
                      var prev = this._beforeStorage;
                      tComponentView.setPath('model.title', prev);
                      tComponentView.setPath('model.userSetTitle', this._userPreviouslySetTitle);
                      // we have to set this as well, as 'value' is not tightly bound
                      this_._value = prev;
                      this_.propertyDidChange('value');
                    },
                    redo: function () {
                      tComponentView.setPath('model.title', value);
                      tComponentView.setPath('model.userSetTitle', true);
                      // we have to set this as well, as 'value' is not tightly bound
                      this_._value = value;
                      this_.propertyDidChange('value');
                    }
                  }));
                }
                return true;
              }.observes('value'),
              doIt: function () {
                this.beginEditing();
              },
              valueIsEmpty: function () {
                return SC.empty(this.get('value'));
              }.property('.value')
            }),
            statusView: SC.LabelView.design({
              textAlign: SC.ALIGN_LEFT,
              classNames: ['dg-status-view'],
              layout: {left: 5},
              value: ''
            }),
            versionView: SC.LabelView.design({
              textAlign: SC.ALIGN_LEFT,
              classNames: ['dg-version-view'],
              layout: {left: 5, top: 5},
              value: ''
            }),
            minimize: !kLockThingsDown ?
                DG.TitleBarMinimizeButton.design({
                  layout: {right: kTitleBarHeight, top: 10, width: 24, height: kTitleBarHeight},
                  classNames: ['dg-minimize-view'],
                  isVisible: SC.platform.touch
                }) :
                null,
            closeBox: !kLockThingsDown ?
                DG.TitleBarCloseButton.design({
                  layout: {right: 0, top: 4, width: kTitleBarHeight, height: kTitleBarHeight},
                  classNames: ['dg-close-view'],
                  isVisible: SC.platform.touch
                }) :
                null,
            undo: kShowUndoRedoButtons ?
                DG.TitleBarUndoButton.design({
                  layout: {right: (kViewInEmbeddedMode ? kTitleBarHeight * 3 : kTitleBarHeight),
                           top: 10, width: 24, height: kTitleBarHeight},
                  classNames: ['dg-undo'],
                }) :
                null,
            redo: kShowUndoRedoButtons ?
                DG.TitleBarRedoButton.design({
                  layout: {right: (kViewInEmbeddedMode ? kTitleBarHeight * 2 : 0),
                           top: 4, width: kTitleBarHeight, height: kTitleBarHeight},
                  classNames: ['dg-redo'],
                }) :
                null,
            mouseEntered: function (evt) {
              var tComponentView = DG.ComponentView.findComponentViewParent(this),
                  tCannotClose = tComponentView && tComponentView.getPath('model.cannotClose');
              this.setPath('minimize.isVisible', true);
              this.setPath('closeBox.isVisible', !tCannotClose);
              this.setPath('undo.isVisible', true);
              this.setPath('redo.isVisible', true);
              return YES;
            },
            mouseExited: function (evt) {
              this.setPath('minimize.isVisible', false);
              this.setPath('closeBox.isVisible', false);
              return YES;
            },
            dragAdjust: function (evt, info) {
              var tOuterView = this.viewToDrag(),
                  tX = DG.ViewUtilities.roundToGrid(info.left + (evt.pageX - info.pageX)), // delta
                  tY = DG.ViewUtilities.roundToGrid(info.top + (evt.pageY - info.pageY)), // delta
                  tContainerWidth = this.getContainerWidth(), // viewport coordinate system
                  tContainerHeight = this.getContainerHeight(), // viewport coordinate system
                  tScrollView = tOuterView.parentView.get('containingScrollView'),
                  tScrollBarThickness = tScrollView?tScrollView.getPath('horizontalScrollerView.scrollbarThickness'):0,
                  tScrollHeight = (tScrollView && tScrollView.get('canScrollHorizontal'))?tScrollBarThickness:0,
                  tViewframeTop = tOuterView.parentView.get('visibleTop'),
                  tViewframeLeft = tOuterView.parentView.get('visibleLeft'),
                  tMinX = -info.width + kMinSize,
                  tMaxX = tViewframeLeft + tContainerWidth - kMinSize,
                  tMinY = -kTitleBarHeight / 2,
                  tMaxY = tViewframeTop + tContainerHeight - tScrollHeight - kTitleBarHeight / 2;
              if (DG.KEEP_IN_BOUNDS_PREF) {
                var tInspectorDimensions = tOuterView.getInspectorDimensions();
                tMinX = 0;
                tMaxX = tContainerWidth - (info.width + tInspectorDimensions.width);
                tMinY = 0;
                tMaxY = tContainerHeight - (Math.max(info.height, tInspectorDimensions.height));
              }

              tX = Math.min(Math.max(tX, tMinX), tMaxX);
              tOuterView.adjust('left', tX);

              tY = Math.min(Math.max(tY, tMinY), tMaxY);
              tOuterView.adjust('top', tY);

              if (DG.KEEP_IN_BOUNDS_PREF) {
                var tInBoundsScaling = DG.currDocumentController().get('inBoundsScaling'),
                    tScaleFactor = tInBoundsScaling.scaleFactor;
                tOuterView.originalLayout.top = tY / tScaleFactor;
                tOuterView.originalLayout.left = tX / tScaleFactor;
              }
            },
            canBeDragged: function () {
              return !kLockThingsDown;
            }
          }),
          coverSheet: SC.View.design({
            backgroundColor: DG.RenderingUtilities.kSeeThrough,
            isVisible: false,
            mouseDown: function( iEvent) {
              // It can happen that we get left as visible when the mouseUp of a component drag slips
              // through the cracks. That's the only situation in which we should get a mouseDown as the
              // user tries to make things work.
              DG.mainPage.mainPane.getPath('scrollView.contentView').coverUpComponentViews('uncover');
            }
          }),
          setContentView: function (iContentView) {
            this.set('contentView', iContentView);
          }

        }), // containerView
        borderRight: DG.DragRightBorderView.design(
            {
              classNames: ['dg-component-border'],
              layout: {top: kTitleBarHeight, right: 0, width: kDragWidth}
            }),
        borderBottom: DG.DragBottomBorderView.design(
            {
              classNames: ['dg-component-border'],
              layout: {bottom: 0, height: kDragWidth}
            }),
        borderLeft: DG.DragLeftBorderView.design(
            {
              classNames: ['dg-component-border'],
              layout: {left: 0, width: kDragWidth}
            }),
        borderBottomLeft: DG.DragBottomLeftBorderView.design(
            {
              layout: {left: 0, width: 2 * kDragWidth, bottom: 0, height: 2 * kDragWidth}
            }),
        borderBottomRight: DG.DragBottomRightBorderView.design(
            {
              layout: {right: 0, width: 2 * kDragWidth, bottom: 0, height: 2 * kDragWidth}
            }),
        resizeBottomRight: DG.DragBottomRightBorderView.design(
            {
              classNames: ['dg-component-resize-handle'],
              layout: {right: -kResizeHandleInset, bottom: -kResizeHandleInset,
                        width: kResizeHandleSize, height: kResizeHandleSize},
              didCreateLayer: function() {
                this.set('isVisible', this.canBeDragged());
              },
              childViews: ['interior'],
              interior: SC.View.design({
                classNames: ['dg-component-resize-handle-interior'],
                layout: {left: 0, top: 0,
                        right: kResizeHandleInset, bottom: kResizeHandleInset}
              })
            }),

        title: function (iKey, iValue) {
          if (!SC.none(iValue))
            this.setPath('containerView.titlebar.titleView.value', iValue);
          return this.getPath('containerView.titlebar.titleView.value');
        }.property(),

        modelTitleChanged: function (iModel, iKey, iValue) {
          if (!SC.none(iValue))
            this.set('title', iValue);
        }.observes('*model.title'),

        modelDimensionsChanged: function (iModel, iKey, iValue) {
          if (!SC.none(iValue)) {
            if (iValue.width)
              this.adjust('width', iValue.width);
            // Plugins change dimensions of component model after component view has
            // set its dimensions from the saved layout. But this defeats the minimization
            // so we protect against it.
            if (iValue.height && !this.get('isMinimized'))
              this.adjust('height', iValue.height);
          }
        }.observes('*model.dimensions'),

        modelPositionChanged: function (iModel, iKey, iValue) {
          if (!SC.none(iValue)) {
            if (iValue.top)
              this.adjust('top', iValue.top);
            if (iValue.left)
              this.adjust('left', iValue.left);
          }
        }.observes('*model.position'),

        version: null,
        versionBinding: '.containerView.titlebar.versionView.value',

        modelVersionChanged: function (iModel, iKey, iValue) {
          if (!SC.none(iValue))
            this.set('version', iValue);
        }.observes('*model.version'),

        status: null,
        statusBinding: '.containerView.titlebar.statusView.value',

        contentMinWidth: function () {
          if (this.get('contentView')) {
            return this.getPath('contentView.containerMinWidth');
          }
        }.property(),
        contentMaxWidth: function () {
          if (this.get('contentView')) {
            return this.getPath('contentView.containerMaxWidth');
          }
        }.property(),
        contentMinHeight: function () {
          if (this.get('contentView')) {
            return this.getPath('contentView.containerMinHeight');
          }
        }.property(),
        contentMaxHeight: function () {
          if (this.get('contentView')) {
            return this.getPath('contentView.containerMaxHeight');
          }
        }.property(),

        getInspectorDimensions : function () {
            var tInspectorWidth = 0,
                tInspectorHeight = 0,
                tButtons = this.get('inspectorButtons');
            if (tButtons && tButtons.length) {
              if (tButtons[0].parentView && tButtons[0].parentView.layout) {
                tInspectorWidth = tButtons[0].parentView.layout.width;
                tInspectorHeight = tButtons[0].parentView.layout.height;
              } else {
                var BUTTONHORIZONTALSPACE = 50,
                    BUTTONVERTICALSPACE = 43;
                tInspectorWidth = BUTTONHORIZONTALSPACE;
                tInspectorHeight = BUTTONVERTICALSPACE * tButtons.length;
              }
            }
            return {width : tInspectorWidth, height : tInspectorHeight};
        },
        enforceViewBounds : function () {
          var tTitleBar = this.getPath('containerView.titlebar'),
              type = this.getPath('controller.model.type'),
              tInspectorDims = this.getInspectorDimensions(),
              tLayout = this.get('layout'),
              tOriginalLayout = this.get('originalLayout'),
              tContainerWidth = tTitleBar.getContainerWidth(),
              tContainerHeight = tTitleBar.getContainerHeight(),
              tInBoundsScaling = DG.currDocumentController().get('inBoundsScaling'),
              tScaleFactor = tInBoundsScaling.scaleFactor,
              tScaleBoundsX = tInBoundsScaling.scaleBoundsX,
              tScaleBoundsY = tInBoundsScaling.scaleBoundsY,
              tMinWidth = this.get('contentMinWidth') || kMinSize,
              tMinHeight = this.get('contentMinWidth') || kMinSize;
              if (tScaleBoundsX < (tLayout.left + tLayout.width + tInspectorDims.width)) {
                var tNewBoundsX = tLayout.left + tLayout.width + tInspectorDims.width;
                DG.currDocumentController().setInBoundsScaleBounds(tNewBoundsX, tScaleBoundsY);
              }
              if ((tScaleBoundsY < (tLayout.top + tLayout.height) ||
                  tScaleBoundsY < (tLayout.top + tInspectorDims.height))) {
                var tHeight = (tLayout.height > tInspectorDims.height) ? tLayout.height : tInspectorDims.height;
                var tNewBoundsY = tLayout.top + tHeight;
                DG.currDocumentController().set('scaleBoundsY', tNewBoundsY);
              }
              if (type === DG.Calculator) {
                tMinWidth = tLayout.width;
                tMinHeight = tLayout.height;
              }
          var tNewWidth = Math.max(tMinWidth,
              DG.ViewUtilities.floorToGrid(tOriginalLayout.width * tScaleFactor)),
              tNewHeight = Math.max(tMinHeight,
              DG.ViewUtilities.floorToGrid(tOriginalLayout.height * tScaleFactor)),
              tNewLeft = DG.ViewUtilities.floorToGrid(tOriginalLayout.left * tScaleFactor),
              tNewTop = DG.ViewUtilities.floorToGrid(tOriginalLayout.top * tScaleFactor);
          if ((tNewLeft + tNewWidth + tInspectorDims.width) > tContainerWidth) {
            tNewLeft = Math.max(0,  tContainerWidth - tNewWidth - tInspectorDims.width);
          }
          if (tNewTop + tNewHeight > tContainerHeight) {
            tNewTop = Math.max(0, tContainerHeight - tNewHeight);
          }
          if(!(isNaN(tNewWidth) || isNaN(tNewHeight) || isNaN(tNewLeft) || isNaN(tNewTop) ))
            this.adjust({width: tNewWidth, height: tNewHeight, left: tNewLeft, top: tNewTop});
          else {
            var tMeasures = [tNewWidth, tNewHeight, tNewLeft, tNewTop];
            console.log('Got NaN for adjust layout: tNewWidth, tNewHeight, tNewLeft, tNewTop: ' + tMeasures.join());
          }
          var controller = this.get('controller');
          if (controller && controller.view)
            controller.updateModelLayout();
        },
        configureViewBoundsLayout : function (iNewPos) {
          var tOriginalLayout = this.get('originalLayout'),
              tInBoundsScaling = DG.currDocumentController().get('inBoundsScaling'),
              tScaleFactor = tInBoundsScaling.scaleFactor;
          tOriginalLayout.top = iNewPos.y / tScaleFactor;
          tOriginalLayout.left = iNewPos.x / tScaleFactor;
          tOriginalLayout.height = iNewPos.height / tScaleFactor;
          tOriginalLayout.width = iNewPos.width / tScaleFactor;
        },

        destroy: function () {
          if (this.containerView.contentView)
            this.containerView.contentView.destroy();
          arguments.callee.base.apply(this,arguments);
        },

        /**
         * @property {Object} { action: {function}, target: {Object}, args: {Array}} or null
         */
        closeAction: function () {
          return this.getPath('contentView.closeAction');
        }.property(),

        addContent: function (iView) {
          var tFrame = iView.get('frame');
          if (tFrame.width > 0)
            this.adjust('width', tFrame.width + 2 * kBorderWidth);
          if (tFrame.height > 0)
            this.adjust('height', tFrame.height + 2 * kBorderWidth + kTitleBarHeight);
          iView.set('layout', {top: this.get('showTitleBar') ? kTitleBarHeight : 0});
          this.containerView.appendChild(iView);
          this.containerView.setContentView(iView);
          if( iView.adjustComponentViewClasses) {
            iView.adjustComponentViewClasses( this);
          }
        },

        /**
         * @param iZ {Number}
         */
        assignZ: function (iZ) {
          if (!this.getPath('controller.preventBringToFront')) {
            this.adjust('zIndex', iZ);
          }
        },

        select: function () {
          var savedLayout = this.savedLayout;
          this.set('isVisible', true);  // note that case table may have visibility set to false
          if( savedLayout) {
            // we only want to animate to saved layout one time, so delete it
            // from the object.
            this.set('savedLayout', null);
            this.animate( savedLayout,
                {duration: 0.4, timing: 'ease-in-out'},
                function () {
                  // We make a minor change to trigger a resize of the internal
                  // divs. Case table, otherwise displays empty table.
                  this.adjust({height: savedLayout.height - 1});
                });
          }
          if( this.parentView && this.parentView.select)
            this.parentView.select(this);
        },
        bringToFront: function () {
          this.parentView.bringToFront(this);
        },
        mouseDown: function (evt) {
          this.select();
          return true;
        },
        click: function (evt) {
          return this.mouseDown(evt);
        },
        touchStart: function (evt) {
          return this.mouseDown(evt);
        },

        /**
         *
         */
        showAndSelect: function () {
          if (this.get('isMinimized')) {
            this.set('savedLayout', null);
            this.toggleMinimization();
          }
          if (DG.KEEP_IN_BOUNDS_PREF && !this.get('isStandaloneComponent')) {
            DG.currDocumentController().enforceViewBounds();
          }
          this.set('isVisible', true);
          this.select();
        },

        /**
         * Selects a component. If it is minimized, first make it normal sized.
         */
        maximizeAndSelect: function () {
          if (this.get('isMinimized')) {
            this.toggleMinimization();
          }
          this.select();
        },

        toggleMinimization: function () {
          DG.log('toggleMinimization');

          var setBorderVisibility = function (iVisibility) {
            ['Bottom', 'Corner', 'Left', 'Right'].forEach(function (iLoc) {
              this.setPath('border' + iLoc + '.isVisible', iVisibility);
            }.bind(this));
          }.bind(this);

          if (this.get('isMinimized')) {
            var tSavedHeight = this.getPath('model.savedHeight');
            this.animate({height: tSavedHeight - 1},
                {duration: 0.4, timing: 'ease-in-out'},
                // This fires after the animation and has the effect of causing a refresh. Map need this to get
                // the correct portion of the map actually showing.
                function () {
                  this.adjust('height', tSavedHeight);
                  this.setPath('model.savedHeight', null);
                }.bind(this));
            setBorderVisibility(true);
          }
          else {
            var tHeightToBeSaved = this.get('layout').height;
            this.animate({height: kTitleBarHeight},
                {duration: 0.4, timing: 'ease-in-out'}, function() {
                  this.setPath('model.savedHeight', tHeightToBeSaved);
                });
            setBorderVisibility(false);
            if (this.get('isSelected')) {
              this.parentView.select(null);
            }
          }
        },

        contentIsInstanceOf: function (aPrototype) {
          return this.get('contentView') instanceof aPrototype;
        },

        cover: function (iAction) {
          var tContainer = this.get('containerView'),
              tCover = tContainer.get('coverSheet');
          tContainer.removeChild(tCover);
          tContainer.appendChild(tCover);
          tCover.set('isVisible', iAction === 'cover');
        },

        didAppendToDocument: function () {
          var contentView = this.get('contentView');
          if (contentView && contentView.didAppendToDocument) {
            contentView.didAppendToDocument();
          }
        },

        /**
         * When a component view is created by the user, it animates to its initial position, expanding
         * from zero size to its initial size. Then it is selected This process is problematic for some
         * content views. E.g. a text component will have lost editing focus, a case table will not be displaying
         * its cases any longer, and a map will no longer have the correct bounds. If the content view defines
         * this method, we'll pass it along and thus give it a chance to fix things up.
         */
        didReachInitialPosition: function () {
          var contentView = this.get('contentView');
          if (contentView && contentView.didReachInitialPosition) {
            contentView.didReachInitialPosition();
          }
        }
      };  // object returned closure
    }()) // function closure
);

DG.ComponentView._createComponent = function (iParams) {
  var tComponentClass = iParams.componentClass.constructor;

  var tMakeItVisible = (iParams.layout.isVisible === undefined) || iParams.layout.isVisible,
      tIsResizable = iParams.isResizable,
      tComponentView = DG.ComponentView.create({
        layout: iParams.layout,
        originalLayout: iParams.layout,
        isVisible: tMakeItVisible,
        showTitleBar: !iParams.isStandaloneComponent,
        isStandaloneComponent: iParams.isStandaloneComponent,
        model: iParams.model
      });
  if( iParams.controller)
    iParams.controller.set('view', tComponentView);
  iParams.contentProperties.controller = iParams.controller;
  tComponentView.addContent(tComponentClass.create(iParams.contentProperties));

  if (iParams.controller) {
    tComponentView.set('controller', iParams.controller);
    iParams.controller.set('contentView', tComponentView.getPath('containerView.contentView'));
  }
  if (iParams.isStandaloneComponent)
    tIsResizable = false;
  if (!SC.none(tIsResizable))
    tComponentView.set('isResizable', tIsResizable);
  if (!SC.none(iParams.isVisible))
    tComponentView.set('isVisible', iParams.isVisible);

  return tComponentView;
};

DG.ComponentView.restoreComponent = function (iParams) {

  var tComponentView = this._createComponent(iParams),
      tNewPos,
      tSuperView = iParams.parentView,
      tUseLayoutForPosition = iParams.useLayout;

  if (iParams.controller) {
    iParams.controller.set('view', tComponentView);
    tComponentView.set('controller', iParams.controller);
  }

  //default to use the existing layout if present, even when requested otherwise.
  if (SC.none(tUseLayoutForPosition) && !SC.none(iParams.layout.left) && !SC.none(iParams.layout.top)) {
    tUseLayoutForPosition = true;
  }
  if (!tUseLayoutForPosition) {
    tNewPos = tSuperView.positionNewComponent(tComponentView, iParams.position, iParams.positionOnCreate);
  }
  tSuperView.appendChild(tComponentView);
  if (DG.KEEP_IN_BOUNDS_PREF && !tComponentView.get('isStandaloneComponent')) {
    if (!tUseLayoutForPosition) {
      tComponentView.configureViewBoundsLayout(tNewPos);
    }
    tComponentView.enforceViewBounds();
  }
  // Do the following _after_ the above so we are using the possibly updated coordinates
  tSuperView.updateFrame();

  return tComponentView;
};

/**
 * Create a component view and add it as a subview to the given super view.
 * @param iParams {Object}
 *   parentView {SC.View}
 *   layout
 *   componentClass - The class of the content view to be contained in the component view
 *   contentProperties - These properties are passed to the new instance of the content during creation
 *   isResizable
 *   useLayout - if true, forgo auto-positioning and just use the layout.
 *   isVisible {Boolean}
 *   position {String} Default is 'top'. Also possible is 'bottom'
 */
DG.ComponentView.addComponent = function (iParams) {
  var tParams = $.extend({}, iParams, {layout: $.extend(true, {}, iParams.layout)}),
      tSuperView = tParams.parentView,
      tNewPos,
      tUseLayoutForPosition = tParams.useLayout || false;
  if (!SC.none(tParams.layout.width))
    tParams.layout.width += DG.ViewUtilities.horizontalPadding();
  if (!SC.none(tParams.layout.height))
    tParams.layout.height += DG.ViewUtilities.verticalPadding();

  var tComponentView = this._createComponent(iParams);

  if (!tUseLayoutForPosition) {
    tNewPos = tSuperView.positionNewComponent(tComponentView, iParams.position);
  }
  tSuperView.appendChild(tComponentView);
  tComponentView.bringToFront();
  tSuperView.updateFrame();

  if (DG.KEEP_IN_BOUNDS_PREF && !tUseLayoutForPosition) {
    tComponentView.configureViewBoundsLayout(tNewPos);
    DG.currDocumentController().computeScaleBounds(tNewPos);
  }

  return tComponentView;
};

DG.ComponentView.findComponentViewParent = function (iView) {
  // Work our way up the view hierarchy until our parent is a component view (or NULL)
  while (iView && !(iView instanceof DG.ComponentView))
    iView = iView.get('parentView');

  return iView;
};

DG.ComponentView.isComponentViewForViewSelected = function (iView) {
  return DG.ComponentView.findComponentViewParent( iView) === DG.mainPage.docView.get('selectedChildView');
};

/* >>>>>>>>>> BEGIN source/views/draggable_view.js */
// ==========================================================================
//                          DG.DraggableView
// 
//  A View that can be dragged
//  
//  Author:   William Finzer
//
//  Copyright (c) 2015 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

    DraggableView is typically a thin view configured to lie on the border of a component
 view. It implements the dragging functionality except for the actual change in the
 frame's layout.

 @extends SC.View
 */
DG.DraggableView = SC.View.extend(
    (function () {

      return {
        /** @scope DG.DraggableView.prototype */
        classNames: 'dg-draggable'.w(),

        mouseDown: function (iEvent) {
          DG.globalEditorLock.commitCurrentEdit();

          var tLayout = this.get('layout');
          this._mouseDownInfo = {
            pageX: iEvent.pageX, // save mouse pointer loc for later use
            pageY: iEvent.pageY, // save mouse pointer loc for later use
            left: tLayout.left,
            top: tLayout.top,
            height: tLayout.height,
            width: tLayout.width
          };
          return YES; // so we get other events
        },

        mouseUp: function (iEvent) {
          // apply one more time to set final position
          this.mouseDragged(iEvent);
          this._mouseDownInfo = null; // cleanup info
          return YES; // handled!
        },

        mouseDragged: function (iEvent) {
          var info = this._mouseDownInfo;

          if (info) {
            this.dragAdjust(iEvent, info);
            return YES; // event was handled!
          }
          else
            return NO;
        },
        touchStart: function (iEvent) {
          return this.mouseDown(iEvent);
        },
        touchEnd: function (iEvent) {
          return this.mouseUp(iEvent);
        },
        touchesDragged: function (iEvent, touches) {
          return this.mouseDragged(iEvent);
        },
        dragAdjust: function (iEvent, info) {
          // default is to do nothing
        }
      };
    }())
);

/* >>>>>>>>>> BEGIN source/views/inspector/inspector_view.js */
// ==========================================================================
//                          DG.InspectorView
// 
//  An inspector that reconfigures based on selected tile
//  
//  Author:   William Finzer
//
//  Copyright (c) 2015 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('views/draggable_view');
/** @class

    InspectorView floats above tiles, pinned to the right edge. I reconfigures based on
 currently selected tile.

 @extends DG.DraggableView
 */
DG.InspectorView = DG.DraggableView.extend(
    /** @scope DG.InspectorView.prototype */
    (function () {
      var kAnimationTime = 0.2,
          kCollapsedWidth = 0,
          kExpandedWidth = 50,
          kCellHeight = 50,
          kDefaultIconSize = 32,
          kPadding = (kCellHeight - kDefaultIconSize) / 2;
      return {
        classNames: ['dg-inspector-palette', 'dg-inspector-view'],
        transitionIn: SC.View,
        isResizable: false,
        isClosable: false,

        componentContainer: null,
        targetComponent: null,

        init: function () {
          arguments.callee.base.apply(this,arguments);
          this.set('layout', { height: kCellHeight, width: kCollapsedWidth});
          this.selectedComponentDidChange();
        },

        adjustLayout: function () {
          var tChildren = this.get('childViews'),
              tCurrTop = kPadding;
          tChildren.forEach(function (iChild, iIndex) {
            if (iChild.get('isVisible')) {
              iChild.adjust({top: tCurrTop, left: (kCellHeight - iChild.iconExtent.width) / 2});
              tCurrTop += iChild.iconExtent.height + 2 * kPadding;
            }
          });
          this.animate('height', Math.max(kCellHeight, tCurrTop - kPadding), kAnimationTime,
                        function() { this.invokeLater(this.scrollToVisible); }.bind(this));
        },

        targetComponentDidChange: function () {

          var removeChildren = function () {
                var tChildren = this.get('childViews'),
                    tChild;
                // We call removeChild for each member of the array. This has the side effect of modifying the array
                                                  // eslint-disable-next-line no-cond-assign
                while (tChild = tChildren[0]) {   // jshint ignore:line
                  this.removeChild(tChild);
                }
              }.bind(this);

          var tTarget = this.get('targetComponent');
          if (tTarget) {
            tTarget.addObserver('layout', this, 'targetLayoutDidChange');
          }
          this.targetLayoutDidChange();
          this.get('childViews').forEach( function( iChild) {
            iChild.removeObserver( 'isVisible', this, 'adjustLayout');
          }.bind(this));
          removeChildren();
          this.inspectorButtonsDidChange();
        }.observes('targetComponent'),

        selectedComponentDidChange: function () {
          var tTarget = this.get('targetComponent');
          if (tTarget) {
            tTarget.removeObserver('layout', this, 'targetLayoutDidChange');
          }
          this.set('targetComponent', this.getPath('componentContainer.selectedChildView'));
        }.observes('*componentContainer.selectedChildView'),

        targetLayoutDidChange: function () {
          var tTargetFrame = this.getPath('targetComponent.frame');
          if (tTargetFrame) {
            this.adjust('top', tTargetFrame.y);
            this.adjust('left', tTargetFrame.x + tTargetFrame.width);
          }
        },

        inspectorButtonsDidChange: function () {
          var tWidth,
              tButtons = this.getPath('targetComponent.inspectorButtons');
          if (tButtons && tButtons.length > 0) {
            tButtons.forEach(function (iButton) {
              this.appendChild(iButton);
              iButton.addObserver('isVisible', this, 'adjustLayout');
            }.bind(this));
            tWidth = kExpandedWidth;
          }
          else {
            tWidth = kCollapsedWidth;
          }
          this.animate('width', tWidth, kAnimationTime, this, 'adjustLayout');
        }.observes('*targetComponent.inspectorButtons'),

        /**
         * Called during drag
         * @param iEvent
         * @param iInfo {pageX: mouse starting X
                         pageY: pageY, mouse starting Y
                         left: original layout.left
                         top: original layout.top,
                         height: original layout.height,
                         width: original layout.width }
         */
        dragAdjust: function (iEvent, iInfo) {
          var tTargetFrame = this.getPath('targetComponent.frame'),
              tMouseMovedY = iEvent.pageY - iInfo.pageY,
              tNewTop = iInfo.top + tMouseMovedY;
          tNewTop = Math.max(tTargetFrame.y, tNewTop);
          tNewTop = Math.min(tNewTop, tTargetFrame.y + tTargetFrame.height);
          this.adjust('top', tNewTop);
        }

      };  // object returned closure
    }()) // function closure
);


/* >>>>>>>>>> BEGIN source/views/container_view.js */
// ==========================================================================
//                          DG.ContainerView
//
//  The top level view in a DG document.
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('views/inspector/inspector_view');

/** @class

  DG.ContainerView is the superview for the component views in the document.

  @extends SC.View
*/
DG.ContainerView = SC.View.extend(
/** @scope DG.ContainerView.prototype */
  (function() {
    var kDocMargin = 16;
    return {
      classNames: 'dg-container-view'.w(),

      isResizable: YES,

      /**
       * To bring a component frontmost, we assign it this value and then increment the value.
       * We don't worry about running out of numbers.
       * @property{Number}
       */
      nextZIndex: function() {
        var tMaxZIndex = 100;
        this.get('componentViews').forEach( function( iView) {
          var tZIndex = iView.get('layout').zIndex;
          if( tZIndex)
              tMaxZIndex = Math.max( tMaxZIndex, tZIndex);
        });
        return tMaxZIndex + 1;
      }.property(),
      lowerZIndex: function() {
        var tMinZIndex = 100;
        this.get('componentViews').forEach( function( iView) {
          var tZIndex = iView.get('layout').zIndex;
          if( tZIndex)
              tMinZIndex = Math.min( tMinZIndex, tZIndex);
        });
        return tMinZIndex - 1;
      }.property(),

      /**
       * @property {DG.InspectorView}
       */
      inspectorView: null,

      /**
       * These rectangles are in addition to rectangles occupied by componentViews. Typically,
       * they are reserved for the duration of an animation of a component to its final location, and
       * then given up.
       * @property { [{{left: {Number}, top: {Number}, width: {Number}, height: {Number}}}]
       */
      reservedRects: null,

      // We want the container to encompass the entire window or the
      // entire content, whichever is greater.
      layout: { left: 0, top: 0, minWidth: '100%', minHeight: '100%' },

      /**
        Indicates that this view's layout should never be considered fixed.
        A fixed layout has a fixed width and height and is unaffected by changes
        to the parent view's size/layout. This view sometimes has a "fixed" width
        and/or height in it layout (for scrolling purposes) but should always
        refresh its layout when its parent view changes. Therefore, we override
        this base class computed property to always return false, so that it can
        respond appropriately when its parent view changes.
        @returns  {Boolean} false -- this view's layout is never fixed
       */
      isFixedLayout: function() {
        return false;
      }.property(),

      init: function() {
        arguments.callee.base.apply(this,arguments);
        this.reservedRects = [];
        this.set('inspectorView', DG.InspectorView.create( {
          componentContainer: this
        }));
        this.appendChild( this.get('inspectorView'));
      },

      parentViewDidResize: function( iParentFrame) {
        arguments.callee.base.apply(this,arguments);
        if( DG.STANDALONE_MODE) {
          // Needed for SageModeler so that inspector pane doesn't disappear off right edge.
          this.adjust({width: iParentFrame.width});
        }
      },

      /**
       * There may be child views other than DG.ComponentView. E.g. in one prototype of showing
       * the map in the background, the map view was a child but not a ComponentView.
       * In standalone mode, we don't return those with content DG.GameView
       * @property {Array of DG.ComponentView }
       */
      componentViews: function() {
        return this.get('childViews' ).filter( function (iChildView) {
          return (iChildView instanceof DG.ComponentView) &&
              !(DG.STANDALONE_MODE && iChildView.contentIsInstanceOf(DG.GameView));
        });
      }.property( 'childViews'),

      allComponentViews: function() {
        var tSavedMode = DG.STANDALONE_MODE;
        DG.STANDALONE_MODE = false; // temporarily
        var tViews = this.get('componentViews');
        DG.STANDALONE_MODE = tSavedMode;
        return tViews;
      }.property('childViews'),

      /**
       * @property {Array of Object }
       */
      tileMenuItems: function() {

        function componentViewToClassName(iView) {
          var tContentView = iView.get('contentView');
          if( tContentView) {
            switch (tContentView.constructor) {
              case DG.TableView:
                return 'tile-icon-table';
              case DG.CaseCardView:
                return 'tile-icon-card';
              case DG.GraphView:
                return 'tile-icon-graph';
              case DG.MapView:
                return 'tile-icon-map';
              case DG.SliderView:
                return 'tile-icon-slider';
              case DG.Calculator:
                return 'tile-icon-calc';
              case DG.TextView:
                return 'tile-icon-comment';
              case DG.GuideView:
                return 'tile-icon-guide';
              case DG.GameView:
                return 'tile-icon-dataTool';
              case DG.WebView:
              case SC.WebView:
                return 'tile-icon-mediaTool';
              default:
                return 'tile-icon-dataTool';
            }
          }
        }

        var tItems = [];
        this.get('componentViews').forEach( function( iComponentView) {
          if( iComponentView.get( 'isVisible')) {
            tItems.push({
              title: iComponentView.get('title'),
              target: iComponentView,
              action: 'maximizeAndSelect',
              icon: componentViewToClassName(iComponentView)
            });
          }
        });
        return tItems;
      }.property(),

      /**
        Computes/returns the bounding rectangle for the view.
       */
      updateFrame: function() {
        if( DG.STANDALONE_MODE) // Our frame is independent of our child views, so just bail.
          return;
        // Note that we're not providing scroll bars to scroll to left or above document
        var tWidth = 0, tHeight = 0;

        // Compute the content size as the bounding rectangle of the child views.
        this.get('childViews').forEach(
                          function( iView) {
                            var tLayout = iView.get('layout');
                            // Rarely, a layout will be missing the fields we need
                            // NB: Attempting to call get('frame') causes infinite recursion
                            tWidth = Math.max( tWidth, (tLayout.left || 0) + (tLayout.width || 0));
                            tHeight = Math.max( tHeight, (tLayout.top || 0) + (tLayout.height || 0));
                          });
        // Add a margin around the components as part of the content
        tWidth += kDocMargin;
        tHeight += kDocMargin;

        this.adjust({ width: tWidth, height: tHeight });
      },

      removeComponentView: function( iComponentView) {
        var tCloseAction = iComponentView.get('closeAction');
        if( tCloseAction) {
          tCloseAction.action.apply( tCloseAction.target, tCloseAction.args );
        }
        else {
          this.select(null);
          DG.currDocumentController().removeComponentAssociatedWithView( iComponentView);
          iComponentView.destroy();
        }
        this.updateFrame();
      },

      /**
       Removes all children from the parentView.

       @returns {SC.View} receiver
       */
      destroyAllChildren: function () {
        this.select(null);  // To close inspector
        var componentViews = this.get('allComponentViews');
        componentViews.forEach(function (iView) {
          if (iView && iView.willDestroy)
            iView.willDestroy();
          iView.destroy();
        });
        return this;
      },

      /**
       * @property{DG.ComponentView}
       */
      selectedChildView: null,

      /**
       * The given child view, if not minimized, will become the currently selected childView.
       * @param iChildView
       */
      select: function( iChildView) {
        var tCurrentSelected = this.get('selectedChildView'),
            tIsMinimized = iChildView && iChildView.get('isMinimized');
        if( iChildView) {
          this.bringToFront( iChildView);
        }
        if( iChildView !== tCurrentSelected && !tIsMinimized) {
          DG.globalEditorLock.commitCurrentEdit();
          if( tCurrentSelected)
            tCurrentSelected.set('isSelected', false);
          this.set('selectedChildView', iChildView);
          if( iChildView) {
            iChildView.set('isSelected', true);
          }
        }
      },

      /* bringToFront - The given child view will be placed at the end of the list, thus
        rendered last and appearing in front of all others.
      */
      bringToFront: function( iChildView) {
        if( iChildView.assignZ) {
          iChildView.assignZ(this.get('nextZIndex'));
        }
      },

      /* sendToBack - The given child view will be placed at the beginning of the list, thus
        rendered first and appearing behind all others.
      */
      sendToBack: function( iChildView) {
        if (iChildView.assignZ) {
          iChildView.assignZ(this.get('lowerZIndex'));
        }
      },

      /** positionNewComponent - It is assumed that the given view has not yet been added
        and that its layout has the desired width and height.
        We find a non-overlapping position for the view and place it there.
        @param{DG.ComponentView} iView - the view to be positioned
        @param {String} iPosition Default is 'top'
        @param {boolean} iPositionGameViews - true to set GameView positions as well as sizes
      */
      positionNewComponent: function( iView, iPosition, iPositionGameViews) {
        var this_ = this,
            tViewRect = iView.get( 'frame'),
            tDocRect = this.parentView.get('clippingFrame'),
            tFrameWithinParent = this.computeFrameWithParentFrame(),
            tOffset = { x: -tFrameWithinParent.x, y: -tFrameWithinParent.y},
            tViewRects = this.get('componentViews').map(function (iView) {
              return iView.get('isVisible') ? iView.get('frame') : {x: 0, y: 0, width: 0, height: 0};
            }),
            tReservedRects = this.get('reservedRects'),
            tLoc = DG.ViewUtilities.findEmptyLocationForRect(
                                      tViewRect,
                                      tDocRect,
                                      tOffset,
                                      tViewRects.concat( tReservedRects),
                                      iPosition);
        if (DG.KEEP_IN_BOUNDS_PREF) {
          var HORIZONTALBUFFER = 50,
              containerWidth = $('#codap').width();
          if ((tLoc.x + tViewRect.width + HORIZONTALBUFFER) > containerWidth) {
            tLoc.x = Math.max(0, containerWidth - tViewRect.width - HORIZONTALBUFFER);
          }
          var tDocView = this.parentView;
          while (!SC.none(tDocView.parentView.parentView)) {
            tDocView = tDocView.parentView;
          }
          var containerHeight = $('#codap').height() - tDocView.get('frame').y;
          if ((tLoc.y + tViewRect.height) > containerHeight) {
            tLoc.y = Math.max(0, containerHeight - tViewRect.height);
          }
        }
        var tFinalRect = { x: tLoc.x, y: tLoc.y, width: tViewRect.width, height: tViewRect.height},
            tOptions = { duration: 0.5, timing: 'ease-in-out'},
            tIsGameView = iView.get('contentView').constructor === DG.GameView;
        if( tIsGameView) {
          // As of 2016-10-26, tFinalRect was being passed to iView.adjust() directly for GameViews,
          // apparently with the intent that the game view would be moved to the rectangle specified.
          // The adjust() function takes a layout object with { left, right }, rather than a rectangle
          // with { x, y }, however, so since then the size of GameViews has been set but not their location.
          // Rather than changing that behavior at this point, we introduce the iPositionGameViews
          // parameter which allows clients aware of the issue to specify that they do want the
          // location of GameViews to be set as well.
          var newLayout = { width: tFinalRect.width, height: tFinalRect.height };
          if (iPositionGameViews) {
            newLayout.left = tFinalRect.x;
            newLayout.top = tFinalRect.y;
          }
          iView.adjust(newLayout);
        }
        else {
          tReservedRects.push(tFinalRect);
          // Hack: deferring this command fixes an issue where the animation
          // was failing for case tables in InBounds mode.
          // Todo 1/2021: ferret out cause and fix more properly
          this.invokeLater(function () {
            iView.adjust({
              left: DG.ViewUtilities.kGridSize, top: DG.ViewUtilities.kGridSize,
              width: 0, height: 0
            });
            iView.animate({left: tLoc.x, top: tLoc.y, width: tViewRect.width, height: tViewRect.height}, tOptions,
                function () {
                  // map component doesn't come out right without the following kludge
                  // Todo: Figure out how to do this with less kludge. Possibly install the contentView
                  // after the animation has completed? Or set the size of the contentView and simply
                  // expand onto it.
                  this.adjust('width', tViewRect.width + 1);
                  this.adjust('width', tViewRect.width);
                  this.adjust('height', tViewRect.height + 1);
                  this.adjust('height', tViewRect.height);
                  this.select();
                  this_.updateFrame();
                  tReservedRects.splice(tReservedRects.indexOf(tFinalRect), 1);
                  // beginEditing applies only to text component, but couldn't find a better place to put this
                  // Better would be to define something like 'didReachFinalPosition' as a generic component
                  this.didReachInitialPosition();
                });
          }.bind(this), 100);
          iView.adjust({width: 0, height: 0});
        }
        return tFinalRect;
      },

      /** coverUpComponentViews - Request each component view to cover up its contents with a see-through layer.
       * We need to do this when we're dragging or resizing one component, so that the event handlers in components
       * we are passing over don't get in the way.
       * @param{String} either 'cover' or 'uncover'
      */
      coverUpComponentViews: function( iAction) {
        this.allComponentViews().forEach( function( iView) {
          if( iView.get('isVisible'))
            iView.cover( iAction);
        });
      },

      mouseDown: function( iEvent) {
        this.select(null);
        return true;
      },

      touchStart: function(iEvent) {
        return this.mouseDown( iEvent);
      },

      containingScrollView: function () {
        var v = this;
        while (v.parentView != null && !(v.parentView instanceof SC.ScrollView)) {
          v = v.parentView;
        }
        return v && v.parentView;
      }.property(),

      visibleLeft: function() {
        var scrollView = this.get('containingScrollView');
        var visibleLeft = scrollView.get('horizontalScrollOffset');
        return visibleLeft;
      }.property(),

      visibleTop: function() {
        var scrollView = this.get('containingScrollView');
        var visibleTop = scrollView.get('verticalScrollOffset');
        return visibleTop;
      }.property(),

    };  // object returned closure
  }()) // function closure
);


/* >>>>>>>>>> BEGIN source/views/dg_drag.js */
// ==========================================================================
//                              DG.Drag
//
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/*
 * We override SC.Drag for the single purpose of dealing with overlapping drop targets
 * in the graph. Different browsers seem to produce different results with the SC.Drag
 * implementation. Namely, for one browser, the AxisMultiTarget will allow a drop while
 * for another browser it won't.
 */

/** @class  Override the private method _findDropTarget

*/
DG.Drag = SC.Drag.extend({

  /** @private
   This will actually start the drag process. Called by SC.Drag.start().
   [Finzer - Concord Consortium] We override to get a previous behavior with regard dragStarted for views
        that are not visible.
   */
  startDrag: function () {
    // Deselect all components so inspector panes won't get in the way
    DG.mainPage.docView.select();

    if (this.get('sourceIsDraggable')) {
      // create the ghost view
      this._createGhostView();
    }

    var evt = this.event;

    // compute the ghost offset from the original start location
    // When CODAP is in an iFrame on a touch device, clientX/Y is not present, so
    // we substitute layer/Y instead.
    var loc = SC.none( evt.clientX) ? {x: evt.layerX, y: evt.layerY } :
        { x: evt.clientX, y: evt.clientY };
    this.set('location', loc);

    if (this.get('sourceIsDraggable')) {
      var dv = this._getDragView();
      var pv = dv.get('parentView');

      // convert to global coordinates. Origin is used to slide the ghost view back.
      var tOffset = pv && $(pv.containerLayer()).offset(),
          origin = { x: tOffset?tOffset.left:0, y: tOffset?tOffset.top:0 };

      if (this.get('ghost')) {
        // Hide the dragView
        this._dragViewWasVisible = dv.get('isVisible');
        dv.set('isVisible', NO);
      }

      if (this.ghostActsLikeCursor) this.ghostOffset = { x: 14 - window.pageXOffset, y: 14 - window.pageYOffset};
      else this.ghostOffset = { x: (loc.x - origin.x), y: (loc.y - origin.y) };

      // position the ghost view
      if (!this._ghostViewHidden) this._positionGhostView(evt);

      if (evt.makeTouchResponder) {
        // Should use invokeLater if I can figure it out
        var self = this;
        SC.Timer.schedule({
          target: evt,
          action: function () {
            if (!evt.hasEnded) evt.makeTouchResponder(self, YES);
          },
          interval: 1
        });
      }
      else {
        // notify root responder that a drag is in process
        this.ghostView.rootResponder.dragDidStart(this, evt);
      }
    }

    var source = this.source;
    if (source && source.dragDidBegin) source.dragDidBegin(this, loc);

    // let all drop targets know that a drag has started
    var ary = this._dropTargets();

    for (var idx = 0, len = ary.length; idx < len; idx++) {
      var target = ary[idx];
      // This change to ignore views that are not visible was introduced post SC 1.9.
      // We rely on get dragStarted in the various axis views and there is no easy alternative.
      // If the target is not visible, it is not valid.
      //if (!target.get('isVisibleInWindow')) continue;

      target.tryToPerform('dragStarted', this, evt);
    }
  },

  /**
   * We special-case AxisMultiTarget and the right vertical axis view because they
   * must be frontmost
   * @param iEvent
   * @return {SC.View}
   * @private
   */
  _findDropTarget: function( iEvent) {
    var tTargets = this._dropTargets(),
        tLoc = {x: iEvent.clientX, y: iEvent.clientY},
        tSuperResult = arguments.callee.base.apply(this,arguments),
        tSpecialTarget = tTargets.find(function (iTarget) {
          if ((iTarget.constructor === DG.AxisMultiTarget) ||
              (iTarget.get('orientation') === DG.GraphTypes.EOrientation.kVertical2)) {
            var tFrame = iTarget.convertFrameToView(iTarget.get('frame'), null);
            return SC.pointInRect(tLoc, tFrame);
          }
          else return false;
        });
    if( !SC.none( tSpecialTarget)) {
      var tCompView = DG.ComponentView.findComponentViewParent( tSpecialTarget),
          tZIndex = tCompView ? tCompView.get('layout').zIndex : 0,
          tSuperCompView = DG.ComponentView.findComponentViewParent( tSuperResult),
          tSuperZIndex  = tSuperCompView ? tSuperCompView.get('layout').zIndex : 0;
      return tZIndex >= tSuperZIndex ? tSpecialTarget : tSuperResult;
    }
    else
      return tSuperResult;
  },

  /** @private Called instead of _destroyGhostView if slideBack is YES.
   *  Overridden to get a better destination for the slideBack than SC provides
   * */
  _slideGhostViewBack: function () {
    if( !this.origin || SC.none( this.origin.x) || SC.none( this.origin.y) )
        arguments.callee.base.apply(this,arguments);
    else if (this.ghostView) {
      var scrollLeft = window.pageXOffset || document.documentElement.scrollLeft,
          scrollTop = window.pageYOffset || document.documentElement.scrollTop,
          slidebackLayout = { top: this.origin.y + scrollTop,
            left: this.origin.x + scrollLeft };

      // Animate the ghost view back to its original position; destroy after.
      this.ghostView.animate(slidebackLayout, 0.5, this, function () {
        this.invokeNext(function() {
          // notify the source that slideback has completed
          var source = this.get('source');
          if (this.get('slideBack') && source && source.dragSlideBackDidEnd)
            source.dragSlideBackDidEnd(this);
          this._endDrag();
        });
      });

    }
    else {
      this._endDrag();
    }
  },

  /**
   * If we haven't yet computed the _cachedDropTargets, let my base class do so,
   * then order the array so that the targets whose component views are on top
   * are first in the array.
   * @return {[SC.View]}
   * @private
   */
  _dropTargets: function () {
    if (this._cachedDropTargets)
      return this._cachedDropTargets;
    var tResult = arguments.callee.base.apply(this,arguments);
    tResult.forEach( function( iTarg) {
      var tCompView = DG.ComponentView.findComponentViewParent( iTarg);
      iTarg.parentZIndex = tCompView ? tCompView.get('layout').zIndex : null;
    });
    tResult.sort( function( iTarg1, iTarg2) {
      var tIdx1 = iTarg1.parentZIndex,
          tIdx2 = iTarg2.parentZIndex;
      if( SC.none( tIdx1))
        return 1;
      else if( SC.none( tIdx2))
        return -1;
      if( tIdx1 < tIdx2)
        return 1;
      else if( tIdx2 < tIdx1)
        return -1;
      else
        return 0;
    });
    tResult.forEach( function( iTarg) {
      delete iTarg.parentZIndex;
    });
    return tResult;
  }
});

/* >>>>>>>>>> BEGIN source/views/export_case_data_dialog.js */
// ==========================================================================
//  DG.ExportCaseDataDialog
//
//  An 'export case data' dialog box with a label, popup menu, a text edit
//  view, and an OK button. Used to allow the user to cut and paste case data
//  from DG to TinkerPlots/Fathom/spreadsheet.
//
//  See also DG.SingleTextDialog
//
//  Author:   Craig D. Miller
//
//  Copyright ©2013 Scientific Reasoning Research Institute,
//                  University of Massachusetts Amherst
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/**
 * @class   DG.ExportCaseDataDialog
 * @extends SC.PalettePane
 * An 'export case data' dialog box with a label, popup menu, a text edit view, and an OK button.
 * To allow the user to cut and paste case data from DG to TinkerPlots/Fathom/spreadsheet.
 */
DG.ExportCaseDataDialog = SC.PalettePane.extend(
/** @scope DG.ExportCaseDataDialog.prototype */ {

  isModal: true,

  layout: { width: 400, height: 120, centerX: 0, centerY: 0 },

  contentView: SC.View.extend({

    childViews: 'promptView collectionPopup exportButton cancelButton'.w(),
    promptView: SC.LabelView.extend({
      layerId: 'export_case_data_prompt', // use dg.css #export_case_data_prompt for text properties
      layout: { top: 10, left: 10, right: 210, height:24 },
      localize: true,
      value: ''
    }),
    collectionPopup: SC.PopupButtonView.extend({
      layout: { top: 10, left: 200, right: 10, height: 24 },
      title: '',
      menu: SC.MenuPane.extend({
        layout: { width: 250 },
        items: null // filled in later
      })
    }),
    exportButton: SC.ButtonView.design({
      layout: { bottom:5, right: 110, height:24, width: 90 },
      titleMinWidth: 0,
      localize: true,
      title: '',
      target: null,
      action: null,
      isDefault: true
    }),
    cancelButton: SC.ButtonView.design({
      layout: { bottom:5, right: 10, height:24, width: 90 },
      titleMinWidth: 0,
      localize: true,
      title: '',
      target: null,
      action: null,
      isDefault: false
    })
  }),

  init: function() {
    arguments.callee.base.apply(this,arguments);

    this.setPath('contentView.exportButton.target', this);
    this.setPath('contentView.exportButton.action', 'export');

    this.setPath('contentView.cancelButton.target', this);
    this.setPath('contentView.cancelButton.action', 'close');
  },

  /**
   * Observer function called when the user selects an item from the collection popup menu.
   */
  collectionSelected: function() {
    // Extract the text of the selected item
    var menuItemString = this.getPath('contentView.collectionPopup.menu.selectedItem.title');
    if( !SC.empty( menuItemString)) {
      this.setPath('contentView.collectionPopup.title', menuItemString ); // update menu
    }
  }.observes('.contentView.collectionPopup.menu.selectedItem'),

  /**
   * Exports the data using the CFM
   */
  // We quote export below because it is a javascript reserved word. The
  // yuicompressor embedded in Sproutcore build chokes.
  'export': function() {
    var menuItemString = this.getPath('contentView.collectionPopup.title'),
        menuItemAction = this.getPath('contentView.collectionPopup.itemAction');
    if( !SC.empty( menuItemString)) {
      this.close();
      menuItemAction( menuItemString); // get new case data to match the menu item
    }
  },

  /**
   * Close the dialog. Used by cancelButton.action.
   */
  close: function() {
    this.remove();
    this.destroy();
  }
});

/**
  Brings up the export dialog with the properties specified by the client.

  @param {Object} iProperties   Configuration properties for export dialog.
                                See the kParamMap below for details.
  @returns  {DG.ExportCaseDataDialog} the created dialog
 */
DG.CreateExportCaseDataDialog = function( iProperties) {
  var tDialog = DG.ExportCaseDataDialog.create( iProperties),
      kParamMap = {
        prompt: 'promptView.value',

        exportTitle: 'exportButton.title',
        exportTooltip: 'exportButton.toolTip',
        cancelTitle: 'cancelButton.title',
        cancelTooltip: 'cancelButton.toolTip',

        collectionMenuTitle: 'collectionPopup.title',
        collectionMenuItems: 'collectionPopup.menu.items',
        collectionMenuItemAction: 'collectionPopup.itemAction' // non-standard param used by collectionSelected()
      },
      tContentView = tDialog.get('contentView');

  // Loop through client-specified properties, applying them to the
  // appropriate property via its path given in the kParamMap.
  DG.ObjectMap.forEach( iProperties,
              function( iKey, iValue) {
                var tParamPath = kParamMap[ iKey];
                if( !SC.empty( tParamPath))
                  tContentView.setPath( tParamPath, iValue);
              } );

  // Put up the dialog
  tDialog.append();

  return tDialog;
};


/* >>>>>>>>>> BEGIN source/views/font_icon_view.js */
// ==========================================================================
//                              DG.FontIconView
// 
//  Authors:  William Finzer
//
//  Copyright (c) 2015 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

    A simple view class to display an icon embedded as a character in a font.

 @extends SC.View
 */
DG.FontIconView = SC.View.extend(
    /** @scope DG.FontIconView.prototype */ {

      iconClass: null,

      init: function() {
        arguments.callee.base.apply(this,arguments);
      },

      /**
       Install the toolTip and alternate text at render time.
       @param {SC.RenderContext} context the render context instance
       */
      render: function (iContext) {
        iContext.push('<span class="' + this.get('iconClass') + '"></span>');
      }
    });


/* >>>>>>>>>> BEGIN source/views/formula_text_edit_view.js */
// ==========================================================================
//                      DG.FormulaTextEditView
// 
//  Provides a DG-specific text editor for entering a formula.
//  
//  Authors:  William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

sc_require('views/text_field_view');

/** @class

  This text editor deals specially with hyphens by turning them into true minus signs.
  Its functionality can be extended to enhance formula editing.

  @extends DG.TextFieldView
*/
DG.FormulaTextEditView = DG.TextFieldView.extend((function() {
/** @scope DG.FormulaTextEditView.prototype */

return {

  autoCorrect: false,

  autoCapitalize: false,
  
  names: [],  // Will be filled with attribute and global variable names by client

  _disableNextSelectRoot: false,

  _selectRootElement: function() {
    if( !this._disableNextSelectRoot)
      arguments.callee.base.apply(this,arguments);
    this._disableNextSelectRoot = false;
  },

  keyDown: function( evt) {
    var kMinus = DG.UNICODE.MINUS_SIGN,
        tCurrent = this.get('value'),
        tSelection = this.get('selection');

    if( evt.getCharString() === '-') {
      if( !SC.none( tCurrent)) {
        tCurrent = tCurrent.slice( 0, tSelection.get( 'start')) +
              kMinus + tCurrent.slice( tSelection.get( 'end'));
      }
      else
        tCurrent = kMinus;

      this.set('value', tCurrent);
      this.setSelection( tSelection.start + 1);
      return true;
    }
    // If the selection goes to the end and is non-null, a tab key will move the caret
    // to the end. (Note that it doesn't matter how those initial conditions came about.)
    else if( (evt.which === SC.Event.KEY_TAB) && 
        (tSelection.start !== tCurrent.length) &&
        (tSelection.end === tCurrent.length)){
      this.setSelection( tCurrent.length);
      return true;
    }
    return arguments.callee.base.apply(this,arguments);
  },
  performValidateKeyDown: function( evt) {
    return ( evt.getCharString() !== '-') && arguments.callee.base.apply(this,arguments);
  },
  formulaExpression: function( iKey, iValue) {
    if( iValue === undefined) {
      // Replace unicode minus with hyphen for purposes of evaluation
      var tCurrent = this.get('value');
      return !SC.empty( tCurrent) ? tCurrent.replace( /\u2212/g, '-') : tCurrent;
    }
    else {
      // Replace hyphen with unicode minus because hyphen can be unrecognizable
      this.set('value', !SC.empty( iValue) ? iValue.replace( /-/g, DG.UNICODE.MINUS_SIGN) : '');
    }
  }.property( 'value')
  
};

})());

/* >>>>>>>>>> BEGIN source/views/icon_button.js */
// ==========================================================================
//                          DG.IconButton
// 
//  A button view that allows user to close a component view.
//  
//  Author:   William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
sc_require('utilities/tap_hold_gesture');
sc_require('views/image_view');
sc_require('views/tooltip_enabler');

/** @class

  DG.IconButton provides a labeled icon button used in the tool shelf.

  @extends SC.View
*/
DG.IconButton = SC.View.extend(SC.Gesturable, DG.TooltipEnabler,
/** @scope DG.IconButton.prototype */
  (function() {
    var kTopOffset = 0,
        kIconExtent = { width: 34, height: 25 };
    return {
      classNames: 'dg-toolshelf-button',
      // if the property 'disabled' is set a class of the same name is set on the
      // button
      classNameBindings: ['disabled'],
      iconName: null,
      depressedIconName: null,
      title: null,
      iconExtent: kIconExtent,
      showBlip: false,  // If true, will show indicator that click will bring up palette
      childViews: 'iconView labelView'.w(),
        iconView: DG.FontIconView.design({
          classNames: 'dg-icon-button'
        }),
        labelView: SC.LabelView.design({
          classNames: ['dg-icon-label'],
          textAlign: SC.ALIGN_CENTER,
          valueBinding: '.parentView.title',
          localizeBinding: '.parentView.localize'
        }),

      gestures: [DG.TapHoldGesture],

      init: function() {
        arguments.callee.base.apply(this,arguments);
        var tTitle = this.get('title') ? this.get('title').loc() : null,
            tTitleIsEmpty = SC.empty( tTitle),
            tLabelHeight = tTitleIsEmpty ? 0 : 15,
            tLabelWidth = tTitleIsEmpty ? 0 : DG.RenderingUtilities.textExtent(tTitle, 'MuseoSans-500', 12).x;
        this.iconView.set('layout',
          { top: kTopOffset, centerX: 0, height: this.iconExtent.height, width: this.iconExtent.width });
        this.iconView.set('iconClass', this.iconClass);
        this.setPath('labelView.layout',
            { top: this.iconExtent.height + kTopOffset, centerX: 0,
              width: tLabelWidth, height: tLabelHeight });
        this.labelView.set('isVisible', !tTitleIsEmpty);
        //this.adjust('height', this.iconExtent.height + kTopOffset + tLabelHeight);

        if( this.get('showBlip')) {
          this.iconView.set('layout',
              { top: 0, right: 0, height: this.iconExtent.height, width: this.iconExtent.width });
          this.adjust('width', this.iconExtent.width + 3);
          this.adjust('height', this.iconExtent.height + 3);
          this.appendChild(DG.ImageView.create({
            classNames: 'dg-icon-button-blip'.w(),
            layout: { left: 0, bottom: 0, width: 3, height: 3 }
          }));
        }
      },

      getWidth: function() {
        return Math.max( this.getPath('iconView.layout').width, this.getPath('labelView.layout').width);
      },

      iconClassDidChange: function() {
        this.iconView.set('iconClass', this.iconClass);
        this.iconView.displayDidChange();
      }.observes('iconClass'),

      /**
       * When part of a FlowedLayout, our height can get messed with, and this can cause a popup to
       * displayed in an inconvenient place.
       */
      adjustHeight: function() {
        this.adjust('height', this.getPath('iconView.layout').height +
            this.getPath('labelView.layout').height + kTopOffset);
      },
      
      isEnabled: true,
      // inverts the significance of isEnabled.
      disabledBinding: SC.Binding.transform(function (state) {return !state;}).oneWay('.isEnabled'),

      isMouseDown: NO,
      isMouseOver: NO,
      mouseMoved: function( evt) {
        this.mouseOver( evt);
        return YES;
      },
      mouseOver: function(evt) {
        this.set( 'isMouseOver', YES);
        return YES;
      },
      mouseExited: function(evt) {
        this.set( 'isMouseOver', NO);
        return YES;
      },
      mouseDown: function(evt) {
        DG.globalEditorLock.commitCurrentEdit();
        if( this.get('isEnabled')) {
          this.set( 'isMouseDown', YES);
          return YES; // so we get other events
        }
        return NO;
      },
      _lastMouseUpTime: 0,

      mouseUp: function(evt) {
        var thisTime = evt.timeStamp;
        // I have replaced the check for if the mouse is still hovering on the target. This fixes 
        // the issue, BZ754 where the menu doesn't appear if the user has clicked to make it disappear, 
        // but hasn't moved the mouse yet.  The reason the previous test was failing even though we were
        // still hovering on the icon, is that moving the mouse while a menu was open caused the
        // mouse exit event flag to fire off because a modal pane appears and removes the icon
        // from the responder chain.  This new test checks correctly for whether the mouse up event was
        // triggered by this icon.
        // Separately, but slightly related, with Webkit browsers, this fix doesn't solve the 
        // mouse cursor problem where the mouse doesn't look like a pointer(it remains default), 
        // after clicking away the modal pane, because Webkit doesn't update the mouse cursor 
        // until there is a mouse move event.
        var inside = this.$().within(evt.target);
        if( inside && thisTime - this._lastMouseUpTime >= 500) {
          this._action( evt);
          this._lastMouseUpTime = evt.timeStamp;
        }
        this.set( 'isMouseDown', NO);
        return YES; // so we get other events
      },
      _action: function(evt) {
        var action = this.get('action');
        var target = this.get('target') || null;
        var pane   = this.get('pane');
        if( action instanceof Function) {
          action.call( target);
        }
        else {
          var responder = pane ? pane.get('rootResponder') : null;
          if (responder) responder.sendAction(action, target, this, pane);
        }
      },
      touchStart: function( iTouch) {
        this.gestureTouchStart(iTouch);
        this.beginPropertyChanges();
        this.set( 'isMouseOver', YES);
        this.set( 'isMouseDown', YES);
        this.endPropertyChanges();
        return YES;
      },
      touchEnd: function( iTouch) {
        this.gestureTouchEnd(iTouch);
        if (!DG.TouchTooltips.clearTouchTooltip(iTouch.identifier))
          this._action(iTouch);
        this.beginPropertyChanges();
        this.set( 'isMouseOver', NO);
        this.set( 'isMouseDown', NO);
        this.endPropertyChanges();
      },

      tapHold: function(touch) {
        this._tooltipTouchID = DG.TouchTooltips.showTouchTooltip(
                                    touch, this, this.get('displayToolTip'));
      },

      tapHoldCancelled: function() {
        if (this._tooltipTouchID) {
          DG.TouchTooltips.hideTouchTooltip(this._tooltipTouchID);
        }
      },

      toolTipDidChange: function() {
        this.updateLayer();
      }.observes('displayToolTip'),

      /**
        Install the toolTip
        @param {SC.RenderContext} context the render context instance
      */
      render: function(context) {
        arguments.callee.base.apply(this,arguments);

        // 'displayToolTip' is auto-localized if 'localize' is true
        var toolTip = this.get('displayToolTip');
        if (toolTip)
          context.setAttr('title', toolTip);
      }
    };
  }()) // function closure
);

/* >>>>>>>>>> BEGIN source/views/inspector/inspector_picker_pane.js */
// ==========================================================================
//                              DG.InspectorPickerPane
// 
//  Authors:  William Finzer
//
//  Copyright (c) 2015 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

    DG.InspectorPickerPane adds functionality to SC.PickerPane so that it can
 appear non-modal in that clicks outside click through to other objects and
 the cursor responds to hovering over other objects, but a click outside
 removes the pane. This is done by registering with DG.MainPage.MainPane which
 will remove it on receiving a mouseDown.

 @extends SC.PickerPane
 */
DG.InspectorPickerPane = SC.PickerPane.extend(
    /** @scope DG.InspectorPickerPane.prototype */ {

      /**
       * We will set this to true if we find ourselves responding to a mousedown in this pickerpane's
       * icon button, so that this fact can be detected and we'll be left removed.
       */
      removedByClickInButton: false,

      isModal: false,
      acceptsKeyPane: false,  // So that we don't prevent text entry elsewhere

      init: function () {
        arguments.callee.base.apply(this,arguments);
        DG.set('inspectorPicker', this);
        this.set('removeTarget', this);
      },
      click: function (evt) {
        var tSubPane = this.get('subPane');
        if( this.get('subPane')) {
          tSubPane.remove();
          tSubPane.destroy();
          this.set('subPane', null);
        }
        return false;
      },
      transitionIn: SC.View.SCALE_IN,
      removeAction: function () {
        console.log('removeAction');
      }
    });

/*
 * Closes any open inspector pane.
 * If no iClass is specified, returns true if an inspector was closed.
 * If iClass is specified, returns true if an inspector with the specified class was closed.
 */
DG.InspectorPickerPane.close = function (iClass) {
  var tInspectorPicker = DG.get('inspectorPicker'),
      hasClass = tInspectorPicker && (tInspectorPicker.get('buttonIconClass') === iClass);
  if (tInspectorPicker) {
    SC.run(function () {
      var tSubPane = tInspectorPicker.get('subPane');
      tInspectorPicker.remove();
      tInspectorPicker.destroy();
      DG.set('inspectorPicker', null);
      if( tSubPane) {
        tSubPane.remove();
        tSubPane.destroy();
      }
    });
  }
  return (tInspectorPicker != null) && (!iClass || hasClass);
};

/* >>>>>>>>>> BEGIN source/views/inspector/picker_color_control.js */
// ==========================================================================
//                              DG.PickerColorControl
// 
//  SC.PickerColorControl brings up a spectrum color picker
//  
//  Authors:  William Finzer
//
//  Copyright (c) 2015 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

    A PickerColorControl brings up a spectrum color picker

 @extends SC.View
 */
DG.PickerColorControl = SC.View.extend(
    /** @scope DG.PickerColorControl.prototype */ {
      classNames: 'dg-inspector-picker-color'.w(),
      initialColor: null, // Should be set by caller
      colorKey: null, // Should be set by caller
      setColorFunc: null, // Should be set by caller
      closedFunc: null, // Optionally set by caller
      appendToLayerFunc: null, // Should be set by caller
      lastColor: null, // the last color selected when closed
      render: function(iContext, iFirstTime) {
        iContext.push('<input type="text" id="custom1" />');
        if (this.get('lastColor') == null) {
          this.set('lastColor', this.get('initialColor'));
        }
        this.invokeLast(function () {
          /* global tinycolor */
          this.$('#custom1').spectrum({
            color: tinycolor(this.initialColor),
            appendTo: this.appendToLayerFunc(),
            showAlpha: true,
            showInitial: true,
            showButtons: false,
            togglePaletteOnly: true,
            togglePaletteMoreText: 'DG.Inspector.colorPicker.more'.loc(),
            togglePaletteLessText: 'DG.Inspector.colorPicker.less'.loc(),
            showPaletteOnly: true,
            showPalette: true,
            palette: [
                // See http://alumni.media.mit.edu/~wad/color/palette.html
              ['black', 'darkgray', 'lightgray', 'white'],
                // red, orange, yellow, green
              ['rgb(173,35,35);', 'rgb(255,150,50);', 'rgb(255,238,51);', 'rgb(29,105,20);'],
                // blue, brown, purple, cyan
              ['rgb(42,75,215);', 'rgb(129,74,25);', 'rgb(129,38,192);', 'rgb(41,208,208);'],
                // tan, pink, lt blue, lt green
              ['rgb(233,222,187);', 'rgb(255,205,243);', 'rgb(157,175,255);', 'rgb(129,197,122);']
            ],
            move: function (iColor) {
              SC.run(function() {
                if( this.setColorFunc)
                  this.setColorFunc( iColor, this.colorKey);
              }.bind(this));
            }.bind(this),
            change: function (iColor) {
              SC.run(function() {
                if( this.setColorFunc)
                  this.setColorFunc( iColor, this.colorKey);
                if ( this.closedFunc)
                  this.closedFunc( this.get('lastColor'), iColor);
                this.set( 'lastColor', iColor, this.colorKey);
              }.bind(this));
            }.bind(this)
          });
        }.bind(this));
      }
    });


/* >>>>>>>>>> BEGIN source/views/scroll_view.js */
// ==========================================================================
//                            DG.ScrollView
// 
//  A derived class of SC.ScrollView that implements DG-specific behaviors.
//  
//  Author:   Kirk Swenson
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

  A DG.ScrollView manages the horizontal and vertical scroll bars.
  DG.ScrollView differs from SC.ScrollView in that it always leaves room for
  a resize-corner and permits no overlap between the thumb and the buttons.

  @extends SC.ScrollView
*/
DG.ScrollView = SC.ScrollView.extend(
/** @scope DG.ScrollView.prototype */ {

  // Thumb should not overlap the arrow buttons
  horizontalScrollerView: SC.ScrollerView.extend({ buttonOverlap: 0 }),
  
  // Always leave room for resize-corner, even when opposite scroller isn't visible
  horizontalScrollerLayout: function() {
    var tRight = this.get('isVerticalScrollerVisible') ? 0 : this.getPath('horizontalScrollerView.scrollbarThickness');
    return { top: 0, left: 0, bottom: 0, right: tRight };
  }.property(),
  
  // Thumb should not overlap the arrow buttons
  verticalScrollerView: SC.ScrollerView.extend({ buttonOverlap: 0 }),

  // Always leave room for resize-corner, even when opposite scroller isn't visible
  verticalScrollerLayout: function() {
    var tBottom = this.get('isHorizontalScrollerVisible') ? 0 : this.getPath('verticalScrollerView.scrollbarThickness');
    return { top: 0, left: 0, bottom: tBottom, right: 0 };
  }.property(),



  // Convenience function
  scrollToBottom: function() {
    this.scrollTo( null, this.get('maximumVerticalScrollOffset'));
  }
});


/* >>>>>>>>>> BEGIN source/views/single_text_dialog.js */
// ==========================================================================
//                          DG.SingleTextDialog
//
//  Implements a dialog with a single text field and Ok and Cancel buttons
//  Has options to hide the cancel button, and make the text field multi-line.
//
//  Authors:  William Finzer
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

  A simple dialog box with a label, a text edit view, a cancel button, and an OK button

  @extends SC.PalettePane
*/
DG.SingleTextDialog = SC.PalettePane.extend(
/** @scope DG.SingleTextDialog.prototype */ {

  isModal: true,
  // Use to opt in to allowing HTML in the prompt
  escapePromptHTML: true,

  layout: { width: 400, height: 120, centerX: 0, centerY: 0 },

  contentView: SC.View.extend({

    childViews: 'promptView editView okButton cancelButton'.w(),
    promptView: SC.LabelView.extend({
      displayProperties: ['escapeHTML'],
      layout: { top: 10, left: 5, right: 5, height:24 },
      localize: true,
      value: '',
      escapeHTMLBinding: '.parentView.parentView.escapePromptHTML'
    }),
    editView: SC.TextFieldView.design({
      layout: { top: 40, left: 5, right: 5, height:24 },
      value: '',
      isTextArea: false,
      spellCheckEnabled: false,
      classNames: 'dg-single-text-dialog-textfield'
    }),
    okButton: SC.ButtonView.design({
      layout: { bottom:5, right: 5, height:24, width: 90 },
      titleMinWidth: 0,
      localize: true,
      title: 'DG.SingleTextDialog.okButton.title',  // "OK"
      target: null,
      action: null,
      isDefault: true,
      isEnabledBinding: '.parentView.editView.value',
      classNames: 'dg-single-text-dialog-ok'
    }),
    cancelButton: SC.ButtonView.design({
      layout: { bottom:5, right: 115, height:24, width: 90 },
      titleMinWidth: 0,
      localize: true,
      title: 'DG.SingleTextDialog.cancelButton.title',  // "Cancel"
      target: null,
      action: null,
      toolTip: 'DG.SingleTextDialog.cancelButton.toolTip',  // "Dismiss the dialog without making any changes"
      isVisible: true,
      isCancel: true,
      classNames: 'dg-single-text-dialog-cancel'
    })
  }),

  value: function() {
    return this.getPath('contentView.editView.value');
  }.property(),

  init: function() {
    arguments.callee.base.apply(this,arguments);

    // By default, cancel simply closes the dialog
    this.setPath('contentView.cancelButton.target', this);
    this.setPath('contentView.cancelButton.action', 'close');
  },

  /**
    Close the open/save dialog.

    Call this function from your okButton/cancelButton action handlers.
    (The default cancelButton handler simply calls this method directly.)
   */
  close: function() {
    // Not clear what the best way to close/destroy is.
    this.remove();
    this.destroy();
  }
});

/**
  Brings up the open/save dialog with the properties specified by the client.

  @param {Object} iProperties   Configuration properties for open/save dialog.
                                Clients should set the 'documentNameValue' to the default name
                                to display in the dialog, and the 'okTarget' and 'okAction'
                                to the method to be called when a name is entered.
                                Additional options include the titles of the buttons, tooltips
                                displayed for the dialog items, etc.
                                See the kParamMap below for details.

  @returns  {DG.SingleTextDialog} the created dialog
 */
DG.CreateSingleTextDialog = function( iProperties) {
  var tDialog = DG.SingleTextDialog.create( iProperties),
      kParamMap = {
        prompt: 'promptView.value',

        textValue: 'editView.value',
        textHint: 'editView.hint',
        textLimit: 'editView.maxLength',
        textIsMultiLine: 'editView.isTextArea',

        okTarget: 'okButton.target',
        okAction: 'okButton.action',
        okTooltip: 'okButton.toolTip',

        cancelTitle: 'cancelButton.title',
        cancelVisible: 'cancelButton.isVisible',
        cancelTooltip: 'cancelButton.toolTip'
      },
      tContentView = tDialog.get('contentView'),
      tEditView = tContentView.editView;

  // Loop through client-specified properties, applying them to the
  // appropriate property via its path given in the kParamMap.
  DG.ObjectMap.forEach( iProperties,
              function( iKey, iValue) {
                var tParamPath = kParamMap[ iKey];
                if( !SC.empty( tParamPath))
                  tContentView.setPath( tParamPath, iValue);
              } );

  // Put up the dialog
  tDialog.append();

  tEditView.becomeFirstResponder();

  return tDialog;
};


/* >>>>>>>>>> BEGIN source/views/tip_view.js */
// ==========================================================================
//                          DG.TipView
// 
//  A simple view for displaying a tip during a drag.
//  There is one global instance.
//  
//  Author:   William Finzer
//
//  Copyright (c) 2020 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

/** @class

    DG.TipView displays text in a popup LabelView

 */
DG.TipView = SC.LabelView.extend(
    /** @scope DG.TipView.prototype */ {
      classNames: 'dg-tipview'.w(),

      isEditable: false,

      localize: true,

      show: function( iWindowLocation, iText) {
        var this_ = this,
            kWidth = 200,
            tViewLocation = DG.ViewUtilities.windowToViewCoordinates(iWindowLocation, this.get('parentView')),
            tParentFrame = this.getPath('parentView').clippingFrame(),
            tHeight;
        this_.set('value', iText);
        this_.adjust({left: 0, top: -500, width: kWidth, height: 0, opacity: 0 });
        this_.set('isVisible', true);
        this.invokeLater( function() {
          tHeight = this_._view_layer.scrollHeight;
          tViewLocation.x = Math.min(tViewLocation.x, tParentFrame.x + tParentFrame.width - kWidth);
          tViewLocation.y = Math.min(tViewLocation.y, tParentFrame.y + tParentFrame.height - tHeight);
          this_.set('isVisible', false);
          this_.adjust({left: tViewLocation.x, top: tViewLocation.y});
          this_.set('isVisible', true);
          this_.animate({height: tHeight - 10, opacity: 1},
              {duration: 0.5, delay: 0.25, timing: 'ease-in-out'});
        }, 10);
      },

      hide: function() {
        this.set('isVisible', false);
      }

    });
/* >>>>>>>>>> BEGIN source/resources/main_page.js */
// ==========================================================================
//                              DG.mainPage
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================

// This page describes the main user interface for your application.
DG.mainPage = SC.Page.design((function() {

  var kIsMobileDevice = SC.browser.device !== SC.DEVICE.desktop,
      kIsComponentMode = DG.get('componentMode') === 'yes',
      kIsEmbeddedMode = DG.get('embeddedMode') === 'yes',
      kToolbarHeight = DG.STANDALONE_MODE ? 0 : 66,
      kInfobarHeight = 28,
      kIconTopPadding = 17;

  // begin compatible browser main page design
  return DG.Browser.isCompatibleBrowser() ? {

  // The main pane is made visible on screen as soon as your app is loaded.
  // Add childViews to this pane for views to display immediately on page load.
  mainPane: SC.MainPane.design({

    // Makes text selectable in the background page in shared embedded mode
    isTextSelectable: kIsEmbeddedMode,

    /**
     * Objects in this array have an action they want to pay attention to, a receiver that will be
     * addressed, and a method belong to the receiver that will be called.
     * @property [{}]
     */
    listeners: null,

    /**
     *
     * @param iObject { action: {String}, target: {Object}, method {function}}
     */
    addListener: function( iObject) {
      this.listeners.push( iObject);
    },

    removeListener: function( iObject) {
      this.listeners = this.listeners.filter( function( iListener) {
        return iObject.action !== iListener.action || iObject.target !== iListener.target ||
            iObject.method !== iListener.method;
      });
    },

    sendEvent: function(action, evt) {
      if( action === 'mouseDown' || action === 'touchStart' || action === 'click') {
        // use the underlying event target for class matching
        this.hideInspectorPicker( evt.target);
      }
      this.listeners.forEach( function( iListener) {
        if( iListener.action === action) {
          iListener.method.call( iListener.target, evt);
        }
      });
      return arguments.callee.base.apply(this,arguments);
    },

    hideInspectorPicker: function( iTarget) {
      var tInspectorPicker = DG.get('inspectorPicker');
      if( tInspectorPicker) {
        // We can detect that the event causing us to hide the inspectorPicker occurred in
        // the button that brings it up. In which case, we let the button handle it.
        var classes = iTarget && (typeof iTarget.className === 'string')
                        ? iTarget.className.split(' ')
                        : [],
            parent = iTarget && iTarget.parentNode,
            parentClasses = parent && (typeof parent.className === 'string')
                              ? parent.className.split(' ')
                              : [];
        if ((classes.indexOf('dg-inspector-pane-button') >= 0) ||
            (parentClasses.indexOf('dg-inspector-pane-button') >= 0) ||
            (classes.indexOf(tInspectorPicker.get('buttonIconClass')) >= 0)) {
          // click on launch button -- let the button handle it
        }
        else {
          DG.InspectorPickerPane.close();
        }
      }
    },

    /**
     * When a DG.InspectorPickerPane inits, it sets this property. When we receive a mouseDown,
     * we tell it to remove.
     *
     * @property {DG.InspectorPickerPane}
     */
    inspectorPicker: null,

    childViews: 'navBar topView scrollView tipView'.w(),

    containerViewBinding: 'scrollView.contentView',

    navBar: SC.View.design({
      classNames: 'navBar'.w(),
      layout: { height: kInfobarHeight },
      childViews: 'leftSide'.w(),
      anchorLocation: SC.ANCHOR_TOP,
      isVisible: !(kIsComponentMode || kIsEmbeddedMode),

      // CFM wrapper view
      leftSide: SC.View.design({
        layout: {left: 0, right: 0},
        // The following overrides cause sproutcore to pass on touch events
        // to React. Overriding captureTouch keeps higher level elements from
        // capturing the touch. Calling allowDefault in the touch events
        // propagates the original event through.
        captureTouch: function () {
          return YES;
        },
        touchStart: function (touch) {
          touch.allowDefault();
        },
        touchesDragged: function (touch) {
          touch.allowDefault();
        },
        touchEnd: function (touch) {
          touch.allowDefault();
        },

        classNames: 'leftSide'.w(),
        didAppendToDocument: function() {
          /* global Promise */
          DG.cfmViewConfig = Promise.resolve({
                              // used for the CFM menu bar
                              navBarId: this.getPath('layer.id')
                            });
        }
      }),
    }),

    topView: SC.View.design({
      classNames: 'toolshelf-background'.w(),
      layout: { top: kInfobarHeight, height: kToolbarHeight - 1 },
      childViews: 'iconButtons rightButtons'.w(),

      iconButtons: SC.View.design(SC.FlowedLayout, {
        classNames: 'dg-icon-buttons'.w(),
        layout: { width: 0, height: kToolbarHeight - 1 },
        align: SC.ALIGN_LEFT,
        canWrap: false,
        shouldResizeHeight: false,
        defaultFlowSpacing: { left: 5, top: kIconTopPadding, right: 5 },
        init: function() {
          arguments.callee.base.apply(this,arguments);
          // create tool buttons, left-justified
          DG.toolButtons.forEach( function( iButtonName, iIndex ) {
            var tButton = DG.ToolButtonData[iButtonName];
            if( iIndex === 0) {
              tButton.flowSpacing = { left: 10, top: kIconTopPadding, right: 5 };
            }
            tButton.classNames = tButton.classNames || '';
            tButton.classNames = (tButton.classNames + ' dg-toolshelf-button').w();
            this[ iButtonName] = DG.IconButton.create( tButton);
            this[ iButtonName].set('layout', { width: this[ iButtonName].getWidth(), height: 40 });
            this.appendChild( this[ iButtonName ]);
          }.bind(this));
        }
      }), // iconButtons

      rightButtons: SC.View.design(SC.FlowedLayout, {
        layout: { top: 0, right: 10, width: 0, height: kToolbarHeight - 1 },
        align: SC.ALIGN_RIGHT,
        canWrap: false,
        shouldResizeHeight: false,
        defaultFlowSpacing: { right: 10, top: kIconTopPadding },

        init: function() {
          arguments.callee.base.apply(this,arguments);
          // create right buttons, right-justified
          DG.rightButtons.forEach( function( iButtonName ) {
            var tButton = DG.RightButtonData[iButtonName];
            tButton.classNames.push('dg-toolshelf-button');
            this[ iButtonName] = DG.IconButton.create( tButton);
            this[ iButtonName].set('layout', { width: this[ iButtonName].getWidth()/*, height: 40*/ });
            this.appendChild( this[ iButtonName ]);
          }.bind(this));
          DG.currDocumentController().set('guideButton', this.guideButton);
        },

        /**
         * Override this so that the child views will have a height that fits with their icon and label.
         * Without this, the menu for the options popup appears too low.
         * @param iChild {SC.View}
         * @param iLayout {Object}
         */
        applyPlanToView: function( iChild, iLayout) {
          SC.FlowedLayout.applyPlanToView.apply(this, arguments);
          if( iChild.adjustHeight)
            iChild.adjustHeight();
        }
      }) // rightButtons
    }), // topView

    scrollView: DG.ScrollView.design({
      layout: { top: kInfobarHeight + kToolbarHeight },
      horizontalAlign: SC.ALIGN_LEFT,
      verticalAlign: SC.ALIGN_TOP,
      hasVerticalScroller: !DG.KEEP_IN_BOUNDS_PREF,
      hasHorizontalScroller: !DG.KEEP_IN_BOUNDS_PREF,
      horizontalOverlay: kIsMobileDevice,
      verticalOverlay: kIsMobileDevice,
      classNames: 'dg-doc-background'.w(),
      alwaysBounceVertical: false,
      contentView: DG.ContainerView.design( {
      }),
      touchStart: function(evt) {
        DG.TouchTooltips.hideAllTouchTooltips();
        // By default, this SC.ScrollView captures the touchstart event so that it can decide
        // whether it should use it to scroll the page. To do so, it sets a timer to wait for
        // 150ms and if the touch has moved in that time it triggers a scroll event, while if it
        // hasn't moved the event is dispatched to subviews. In the latter case, however, the
        // event dispatched to content views is a simulated event, as the actual browser event is
        // long gone at this point, and also by default, SC has called preventDefault() on the
        // event, thus preventing any of the corresponding mouse events from being generated by
        // the browser. Calling allowDefault() here tells SC not to call preventDefault(), thus
        // allowing the corresponding mouse events to be generated. To actually receive mouse
        // events, however, one must also override the endTouch() event to call allowDefault() as
        // well, otherwise SC will similarly call preventDefault() on the endtouch event, thus
        // preventing the browser from generating mouse events. See DG.CaseTableView for an
        // example where this has been done so that SlickGrid can respond to mouse events while
        // also allowing DG.CaseTableView to respond to SC's touch events.
        evt.allowDefault();
        return arguments.callee.base.apply(this,arguments);
      }
    }),

    tipView: DG.TipView.design( {
      isVisible: false
    }),

    flagsChanged: function( iEvent) {
//    if( iEvent.altKey)
//      console.log('altKey');
//    else
//      console.log('no altKey');
//    this.rootResponder.sendEvent('mouseMoved', iEvent);
    },

    /**
     * Decide whether the topView should be showing
     */
    init: function() {
      arguments.callee.base.apply(this,arguments);
      this.listeners = [];
      if (kIsComponentMode || kIsEmbeddedMode) {
        var tScrollView = this.get('scrollView');
        this.setPath('topView.isVisible', false);
        tScrollView.adjust('top', 0);
        tScrollView.set('hasHorizontalScroller', false);
        tScrollView.set('hasVerticalScroller', false);
      }
      DG.PluginOverlayContainer.create();
    },

    viewDidResize: function() {
      arguments.callee.base.apply(this,arguments);
      if (DG.KEEP_IN_BOUNDS_PREF) {
        DG.currDocumentController().enforceViewBounds();
      }
    },

    classNameBindings: [
        '_isDraggingFileOrURL:dg-receive-outside-drop',
        '_isDraggingAttr:dg-attr-drop'
    ],

    dragAttributeData: null,
    _isDraggingAttr: false,
    _isDraggingFileOrURL: false,

    /**
     * These methods -- dataDragEntered, dataDragHovered, dataDragDropped,
     * and dataDragExited -- support drags initiated outside the page,
     * specifically drags from plugins.
     */
    dataDragEntered: function (iEvent) {
      function findAttributeRefByID(id) {
        var contexts = DG.currDocumentController().contexts;
        var attrRef;
        contexts && contexts.some(function (context) {
          attrRef = context.getAttrRefByID(id);
          if (attrRef) { attrRef.context = context; }
          return !!attrRef;
        });
        return attrRef;
      }
      function computeDropData(_this, attrRef) {
        return {
          context: attrRef.context,
          collection: attrRef.collection.get('collection'),
          attribute: attrRef.attribute,
          text: attrRef.attribute.get('name')
        };
      }

      var context;
      var attrID = iEvent.dataTransfer.types.find(function (type) {
        var found = type.startsWith('application/x-codap-attr-');
        return found && type.replace('application/x-codap-attr-', '');
      });
      attrID = attrID && attrID.replace('application/x-codap-attr-', '');
      var attrRef = attrID && findAttributeRefByID(attrID);

      // DG.log('main: dataDragEntered: ' + (iEvent.dataTransfer && iEvent.dataTransfer.types.join())
      //     + ' attrID' + attrID
      //     + ' attrRef: ' + (attrRef && [attrRef.context.get('name'), attrRef.collection.get('name'), attrRef.attribute.get('id')].join())
      // );
      if (attrRef) {
        this.set('dragAttributeData', computeDropData(this, attrRef));
        this.set('_isDraggingAttr', true);
      } else {
        this.set('_isDraggingFileOrURL', true);
      }
      if( iEvent.preventDefault)
        iEvent.preventDefault();
    },

    dataDragHovered: function (iEvent) {
      if (this.get('_isDraggingFileOrURL')) {
        iEvent.dataTransfer.dropEffect = 'copy';
      }
      if( iEvent.preventDefault)
        iEvent.preventDefault();
      return YES;
    },

    dataDragDropped: function(iEvent) {
      // Returns whether a string is a URI we care about.
      function isURI(str) {
        var schemes = ['http:', 'https:', 'data:'];
        var s1 = str.toLowerCase();
        return schemes.find(function (scheme) {
          return s1.startsWith(scheme);
        });
      }
      var tElement = this.get('layer');
      var tDataTransfer = iEvent.dataTransfer;
      var isIE = (SC.browser.engine === SC.ENGINE.trident);
      var tFiles = tDataTransfer.files,
          tURIType = isIE ? 'URL': 'text/uri-list',
          tURI = tDataTransfer.getData(tURIType);
      if( tFiles && (tFiles.length > 0)) {
        DG.appController.importFile(tFiles[0]);  // We only deal with the first file
      }
      else if( !SC.empty(tURI) && isURI(tURI)) {
        SC.run(function () {
          DG.appController.importURL( tURI);
        });
      }
      else if (!this.get('_isDraggingAttr') && tDataTransfer.types.includes('text/html')) {
        SC.run(function () {
          DG.appController.importHTMLTable(tDataTransfer.getData('text/html'));
        });
      }
      $(tElement).removeClass('dg-receive-outside-drop');

      if( iEvent.preventDefault)
        iEvent.preventDefault();
      return false;

    },

    dataDragExited: function (iEvent) {
      this.set('_isDraggingFileOrURL', false);
      this.set('_isDraggingAttr', false);
      this.set('dragAttributeData', null);
      if( iEvent.preventDefault)
        iEvent.preventDefault();
    },

    /**
      The mainPane itself should be the default key view, rather than an arbitrary subview.

      When the window gets focus, the mainPane gets a chance to specify the default key view
      (i.e. first responder) via this computed property. (See SC.RootResponder.focus() for details.)
      The base class implementation of nextValidKeyView() returns an arbitrary subview which happens
      to accept firstResponder status. Thus, launching the app results in an arbitrary tool shelf
      button (e.g. Reset Data) having the keyboard focus by default. We fix this and other related
      bugs here by having the mainPane specify that it should be the key view itself rather than
      one of its subviews. If we ever determine that some other view should be the default key
      view (e.g. the game view), this would be the place to specify that.
     */
    nextValidKeyView: function() {
      return this;
    }.property(),

    /**
     * Handle keyboard shortcuts at the document level
     * @param keystring {String}
     * @param evt {Event}
     */
    performKeyEquivalent: function(keystring, evt) {
      var tResult = YES;
      switch( keystring) {
        case 'ctrl_alt_c':
          DG.mainPage.toggleCalculator();
          break;
        case 'ctrl_alt_t':
          DG.mainPage.openCaseTablesForEachContext();
          break;
        case 'ctrl_alt_g':
          DG.mainPage.addGraph();
          break;
        case 'ctrl_alt_s':
          DG.mainPage.addSlider();
          break;
        case 'ctrl_alt_shift_t':
          DG.mainPage.addText();
          break;
        case 'ctrl_z':
          DG.UndoHistory.undo();
          break;
        case 'ctrl_y':
        case 'ctrl_shift_z':
          DG.UndoHistory.redo();
          break;
        default:
          tResult = arguments.callee.base.apply(this,arguments);
      }
      return tResult;
    },

    /**
      Creates the specified component and its associated view.
      This is a handler for a sendAction() call. The original
      client calls sendAction() from the gameController.
      @param  {Object}    iSender -- The caller of sendAction()
      @param  {Object}    iContext -- Parameter object from the caller
              {String}      iContext.type -- The type of component to create
                                              e.g. 'DG.GraphView', 'DG.TableView'
     */
    createComponentAndView: function( iSender, iContext) {
      var typeString = iContext.type,
          dotPos = typeString && typeString.indexOf('.'),
          lastWord = dotPos >= 0 ? typeString.slice( dotPos + 1) : null,
          classProto = lastWord && DG[ lastWord],
          componentsOfType = classProto && DG.mainPage.getComponentsOfType( classProto);
      if( iContext.allowMoreThanOne || !componentsOfType || !componentsOfType.length)
        DG.currDocumentController().createComponentAndView( null, iContext.type, iContext);
    },

  }), // mainPane

    /*
     * DG.mainPage methods
     */

    docView: SC.outlet('mainPane.scrollView.contentView')


  } // end compatible browser mainPage design

  : { // begin incompatible browser main page design
    // The main pane is made visible on screen as soon as your app is loaded.
    // Add childViews to this pane for views to display immediately on page load.
    mainPane: SC.MainPane.design({
      childViews: 'messageView'.w(),

      messageView: SC.LabelView.design({
        layout: { centerX: 0, centerY: 0, width: 400, height:300},
        controlSize: SC.LARGE_CONTROL_SIZE,
        fontWeight: SC.BOLD_WEIGHT,
        textAlign: SC.ALIGN_LEFT,
        localize: true,
        value: 'DG.mainPage.mainPane.messageView.value' // "Unfortunately, DG is not currently..."
      })
    }) // mainPane
  }; // end incompatible browser main page design
}()));

DG.mainPage.toggleCalculator = function() {
  DG.currDocumentController().
      toggleComponent( this.get('docView'), 'calcView');
};

DG.mainPage.openCaseTablesForEachContext = function () {
  DG.currDocumentController().openCaseTablesForEachContext();
};

DG.mainPage.openCaseTableForNewContext = function () {
  DG.appController.importText('new', 'new_table');
};

DG.mainPage.addMap = function() {
  DG.currDocumentController().addMap( this.get('docView'));
};

DG.mainPage.addSlider = function() {
  return DG.currDocumentController().addSlider( this.get('docView'));
};

DG.mainPage.addGraph = function() {
  return DG.currDocumentController().addGraph( this.get('docView'));
};

DG.mainPage.addText = function() {
  return DG.currDocumentController().addText( this.get('docView'));
};

DG.mainPage.addMap = function() {
  return DG.currDocumentController().addMap( this.get('docView'));
};

/* DG.mainPage.getComponentsOfType - Given the prototype class of a type of component, e.g.
  DG.SliderView, return an array containing all of those objects that are content views of
  the document.
*/
DG.mainPage.getComponentsOfType = function( aPrototype) {
  var docView = this.get('docView'),
      tComponentViews = docView && docView.get('childViews'),
      tDesiredViews = tComponentViews && tComponentViews.filter( function( aComponentView) {
            return aComponentView.contentIsInstanceOf && aComponentView.contentIsInstanceOf( aPrototype);
          });
  return tDesiredViews ? tDesiredViews.getEach('contentView') : [];
};

DG.mainPage.closeAllComponents = function() {
  this.get('docView').destroyAllChildren();
};

DG.mainPage.addGameIfNotPresent = function() {
  if( DG.mainPage.mainPane.addGame && (DG.mainPage.getComponentsOfType( DG.GameView).length === 0))
    DG.mainPage.mainPane.addGame();
  // addGameIfNotPresent() is only called on initial presentation of the document,
  // so it's a good time to synchronize the saved change count.
  DG.currDocumentController().updateSavedChangeCount();
};

/* >>>>>>>>>> BEGIN source/main.js */
// ==========================================================================
//                               DG.main
//
//  Copyright (c) 2014 by The Concord Consortium, Inc. All rights reserved.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
// ==========================================================================
/*globals createReactClassFactory, ReactDOMFactories, iframePhone */
sc_require('controllers/app_controller');
sc_require('controllers/authorization');
sc_require('utilities/iframe-phone-emulator');

// This is the function that will start your app running.  The default
// implementation will load any fixtures you have created then instantiate
// your controllers and awake the elements on your page.
//
// As you develop your application you will probably want to override this.
// See comments for some pointers on what to do next.
//
DG.main = function main() {

  DG.Browser.init(); // Import any DG specific browser hacks we need.

  SC.$('body' ).addClass( 'dg');

  // Fix to support touch events in non-SproutCore elements like jQuery UI widgets.
  // By default, SC.RootResponder swallows all touch events except for those
  // intended for specific browser tags (input, textarea, a, select). For non-SC
  // elements to work correctly on touch devices, they need to receive touch events
  // as well. To do so, we monkey-patch SC.RootResponder's ignoreTouchHandle() method
  // to ignore (i.e. allow to be dispatched) touch events in views that have the
  // 'dg-wants-touch' class (or any of its ancestors have the class), which we can
  // then apply to any element that needs it, such as the jQueryUI autocomplete menu.
  var orgIgnoreTouchHandle = SC.RootResponder.prototype.ignoreTouchHandle;
  SC.RootResponder.prototype.ignoreTouchHandle = function(evt) {
    var dgWantsTouch = $(evt.target).closest('.dg-wants-touch').length,
        wantsSCTouch = $(evt.target).closest('.dg-wants-sc-touch').length;
    return wantsSCTouch
              ? NO
              : (dgWantsTouch ? YES : orgIgnoreTouchHandle.call(this, evt));
  };

  // Fix to prevent assignment of touches that have already ended.
  var orgAssignTouch = SC.RootResponder.prototype.assignTouch;
  SC.RootResponder.prototype.assignTouch = function(touch, view) {
    if (touch.hasEnded) {
      console.warn("Attempt to assign a touch that is already finished.");
    }
    else {
      orgAssignTouch.call(this, touch, view);
    }
  };

  var orgIgnoreMouseHandle = SC.RootResponder.prototype.ignoreMouseHandle;
  SC.RootResponder.prototype.ignoreMouseHandle = function(evt) {
    var dgWantsMouse = $(evt.target).closest('.dg-wants-mouse').length,
        dgWantsWheel = $(evt.target).closest('.dg-wants-wheel').length && evt.type === 'mousewheel',
        wantsSCMouse = $(evt.target).closest('.dg-wants-sc-mouse').length;
    return wantsSCMouse
              ? NO
              : (dgWantsMouse ? YES
                : (dgWantsWheel ? YES
                  : orgIgnoreMouseHandle(evt)));
  };

  var orgIgnoreKeyHandle = SC.RootResponder.prototype.ignoreKeyHandle;
  SC.RootResponder.prototype.ignoreKeyHandle = function(evt) {
    var dgWantsKeys = $(evt.target).closest('.dg-wants-keys').length;
    return dgWantsKeys ? YES : orgIgnoreKeyHandle.call(this, evt);
  };

  var orgIgnoreSelectHandle = SC.RootResponder.prototype.ignoreSelectHandle;
  SC.RootResponder.prototype.ignoreSelectHandle = function(evt) {
    var dgWantsSelect = $(evt.target).closest('.dg-wants-select').length;
    return dgWantsSelect ? YES : orgIgnoreSelectHandle.call(this, evt);
  };

  DG.getPath('mainPage.mainPane').appendTo($('#codap'));

  DG.showUserEntryView = true;

  /* begin CFM load/configuration */
  /* global Promise */

  function openDataInteractives(iURLs) {
    if (iURLs) {
      // Create document-specific store.
      var archiver = DG.DocumentHelper.create({}), newDocument;

      DG.currDocumentController().closeDocument();

      // Make a data interactive iFrame using the given URL
      newDocument = archiver.createNewDocumentWithDataInteractives(iURLs);

      DG.currDocumentController().setDocument(newDocument);
    }
  }
  function startEmbeddedServer() {
    function createParentConnection() {
      var tController = DG.ComponentController.extend({}).create(),
          tDataInteractiveHandler = DG.DataInteractivePhoneHandler.create({
            controller: tController
          }),
          iframePhoneHandler = function (command, callback) {
            tDataInteractiveHandler.set('isPhoneInUse', true);
            tDataInteractiveHandler.doCommand(command, function (ret) {
              DG.doCommandResponseHandler(ret, callback);
            });
          };
      tDataInteractiveHandler.rpcEndpoint = new iframePhone.IframePhoneRpcEndpoint(
          iframePhoneHandler, "data-interactive", window.parent);
      tDataInteractiveHandler.rpcEndpoint.call({message: "codap-present"},
          function (reply) {
            DG.log('Got codap-present reply on embedded server data-interactive channel: ' +
                JSON.stringify(reply));
          }
        );
      return tDataInteractiveHandler;
    }

    function createSharedConnection() {
      var tController = DG.ComponentController.extend({}).create(),
          tDataInteractiveHandler = DG.DataInteractivePhoneHandler.create({
            controller: tController
          }),
          iframePhoneHandler = function (command, callback) {
            tDataInteractiveHandler.set('isPhoneInUse', true);
            tDataInteractiveHandler.doCommand(command, function (ret) {
              DG.doCommandResponseHandler(ret, callback);
            });
          };

      tDataInteractiveHandler.rpcEndpoint = new DG.IFramePhoneEmulator(iframePhoneHandler, 'data-interactive', 'codap');
      DG.localIFramePhoneEndpoint = tDataInteractiveHandler.rpcEndpoint;

      tDataInteractiveHandler.rpcEndpoint.call({message: "codap-present"}, function (reply) {
        DG.log('Got codap-present reply on embedded server data-interactive channel: ' + JSON.stringify(reply));
      });
      return tDataInteractiveHandler;
    }


    DG.embeddedModePhoneHandlers = [];

    // if there is a real parent for this page try connecting using IFramePhone,
    if (window.parent !== window) {
      DG.embeddedModePhoneHandlers.push(createParentConnection());
    }

    // otherwise we are embedded in the same context as our host, so we create
    // an emulated connection
    DG.embeddedModePhoneHandlers.push(createSharedConnection());
  }
  function validateDocument(content) {
    if (!content) return null;
    if (typeof content === 'string' && content[0] !== '{') {
      return content;
    }

    // October, 2017: There have been as-yet-unexplained occurrences of documents
    // with duplicate cases. Rather than failing outright, we eliminate the
    // duplicate cases, logging their existence so that (1) users can continue to
    // use the previously corrupt documents and (2) the logs can be used to try
    // to narrow down the circumstances under which the corruption occurs.
    content = removeDuplicateCaseIDs(content);

    // Legacy documents created manually using scripts can have empty metadata fields.
    // We grandfather these documents in by requiring that the metadata fields exist and are empty.
    // We log when these files are encountered, however, in hopes that they eventually get fixed.
    if ((content.appName === "") && (content.appVersion === "") && (content.appBuildNum === "")) {
      DG.log("File '%@' bypassed validation with empty metadata." +
              " This file should be re-saved with valid metadata.", content.name);
      return content;
    }

    return (content.appName === DG.APPNAME) && !!content.appVersion && !!content.appBuildNum ? content : null;
  }
  function translateQueryParameters() {
    var startingDataInteractive = DG.get('startingDataInteractive');
    var diURLs = [];
    if (startingDataInteractive) {
      var diLen = startingDataInteractive.length;
      if ((diLen > 2) && (startingDataInteractive[0] === '[') &&
          (startingDataInteractive[diLen - 1] === ']')) {
        var diStrings = startingDataInteractive.substr(1, diLen - 2);
        diURLs = diStrings.split(',');
      }
      else {
        diURLs.push(startingDataInteractive);
      }
    }

    if (DG.get('runKey'))
      DG.set('showUserEntryView', false);

    if (diURLs.length) {
      DG.set('showUserEntryView', false);
      openDataInteractives(diURLs);
    }
  }

  function removeDuplicateCaseIDs(content) {
    var cases = {},
        duplicates = {};

    if (content.contexts) {
      content.contexts.forEach(function(context) {
        if (context.collections) {
          context.collections.forEach(function(collection) {
            if (collection.cases) {
              collection.cases.forEach(function(iCase) {
                var id = iCase.guid;
                if (!cases[id]) {
                  cases[id] = iCase;
                }
                else {
                  duplicates[id] = iCase;
                }
              });
            }
            DG.ObjectMap.forEach(duplicates, function(id, aCase) {
              var found = collection.cases.indexOf(aCase);
              if (found >= 0) {
                collection.cases.splice(found, 1);
                DG.logUser("validateDocument: removed case with duplicate ID: '%@'", id);
              }
            });
            duplicates = {};
          });
        }
      });
    }
    return content;
  }

  function cfmUrl(filename) {
    var url = null,
        a;

    if (DG.cfmBaseUrl) {
      // safely parse the url and check to only allow *.concord.org or a domain with no tld (like localhost or dev)
      a = document.createElement("A");
      a.href = DG.cfmBaseUrl;
      if (/\.concord\.org$/.test(a.hostname) || (a.hostname.indexOf('.') === -1)) {
        a.pathname = (a.pathname[a.pathname.length - 1] === '/' ? a.pathname : (a.pathname + '/')) + filename;
        url = a.href;
        DG.logWarn('Loading the ' + filename + ' CFM file from ' + url);
      }
      else {
        DG.logError('The cfmBaseUrl domain (' + a.hostname + ') either needs to be *.concord.org or not have a TLD (like localhost)');
      }
    }

    if (!url) {
      // static_url is run at build time so we have to directly reference the paths
      if (filename === 'app.js') {
        url = '../../../../static/dg/de/cert/resources/cloud-file-manager/js/app.js.ignore';
      }
    }

    return url;
  }

  /**
   * Returns a promise which is resolved when the CFM is loaded.
   */
  function cfmLoaded() {
    return new Promise(function(resolve, reject) {
      $.ajax({
        url: cfmUrl('app.js'),
        dataType: 'script',
        success: function() {
          resolve(true);
        },
        failure: function() {
          reject(false);
        }
      });
    });
  }

  function makeNewLocaleUrl(digraph, location) {
    var locMatch = location.pathname.match(/(^.*\/static\/dg\/)[^\/]+(\/cert\/.*$)/);
    var baseURL = 'https://codap.concord.org/releases/latest/static/dg/%@/cert/'.loc(digraph);
    if (locMatch) {
      baseURL = location.schema + location.host + locMatch[1] + digraph + locMatch[2];
    }
    var hash = location.hash;
    if (location.pathname.indexOf('static/dg')>0) {
      baseURL = '../../%@/cert'.loc(digraph);
    }
    if (hash.startsWith('#file=examples:')) {
      hash = '';
    }
    return baseURL + location.search+hash;
  }

  function handleLogLaraData(obj) {
    if (obj.run_remote_endpoint) {
      DG.set('run_remote_endpoint', obj.run_remote_endpoint);
    }
    DG.logUser("laraData: %@".fmt(JSON.stringify(obj)));
  }

  function cfmInit(iCloudFileManager, iViewConfig) {
    var options = {
          autoSaveInterval: 5,
          appName: DG.APPNAME,
          appVersion: DG.VERSION,
          appBuildNum: DG.BUILD_NUM,
          appOrMenuElemId: iViewConfig.navBarId,
          hideMenuBar: DG.get('hideCFMMenu'),
          ui: {
            menuBar: {
              info: "Language menu",
              languageMenu: {
                currentLang: SC.Locale.currentLanguage,
                options: DG.locales.map(function (locale) {
                  return {
                    label: locale.langName,
                    langCode: locale.langDigraph,
                  };
                }),
                onLangChanged: function (langCode) {
                  DG.log('Changed language: ' + langCode);
                  window.location = makeNewLocaleUrl(langCode, window.location);
                }
              }
            },
            menu: [
              { name: 'DG.fileMenu.menuItem.newDocument'.loc(), action: 'newFileDialog' },
              { name: 'DG.fileMenu.menuItem.openDocument'.loc(), action: 'openFileDialog' },
              {
                name: 'DG.fileMenu.menuItem.closeDocument'.loc(),
                action: function () {
                          DG.cfmClient.closeFileDialog(function () {
                            SC.run(function() {
                              DG.appController.closeAndNewDocument();
                            });
                          });
                        }
              },
              { name: 'DG.fileMenu.menuItem.importFile'.loc(), action: 'importDataDialog' },
              {
                name: 'DG.fileMenu.menuItem.revertTo'.loc(),
                items: [
                  { name: 'DG.fileMenu.menuItem.revertToOpened'.loc(), action: 'revertToLastOpenedDialog'},
                  { name: 'DG.fileMenu.menuItem.revertToShared'.loc(), action: 'revertToSharedDialog'}
                ]
              },
              'separator',
              { name: 'DG.fileMenu.menuItem.saveDocument'.loc(), action: 'saveFileAsDialog' },
              { name: 'DG.fileMenu.menuItem.copyDocument'.loc(), action: 'createCopy' },
              {
                name: 'DG.fileMenu.menuItem.share'.loc(),
                items: [
                  { name: 'DG.fileMenu.menuItem.shareGetLink'.loc(), action: 'shareGetLink' },
                  { name: 'DG.fileMenu.menuItem.shareUpdate'.loc(), action: 'shareUpdate' }
                ]
              },
              { name: 'DG.fileMenu.menuItem.renameDocument'.loc(), action: 'renameDialog' }
            ],
          },
          appSetsWindowTitle: true, // CODAP takes responsibility for the window title
          wrapFileContent: false,
          mimeType: 'application/json',
          readableMimeTypes: [
            'application/x-codap-document',
            'application/json',
            'text/csv',
            'text/tab-separated-values'
          ],
          extension: 'codap',
          readableExtensions: ["json", "", "codap", "csv", "txt"],
          enableLaraSharing: true,
          log: function(event, eventData) {
            var params = eventData ? JSON.stringify(eventData) : "";
            DG.logUser("%@: %@", event, params);
          },
          providers: [
            {
              "name": "readOnly",
              "displayName": "DG.fileMenu.provider.examples.displayName".loc(),
              "urlDisplayName": "examples",
              "src": DG.get('exampleListURL'),
              alphabetize: false
            },
            {
              "name": "lara",
              "patch": true,
              patchObjectHash: function(obj) {
                return obj.guid || JSON.stringify(obj);
              },
              logLaraData: function(obj) {
                handleLogLaraData(obj);
              }
            },
            {
              "name": "documentStore",
              "displayName": "Concord Cloud",
              "deprecationPhase": (function() { // IIFE to keep code localized
                                    // queryParam overrides defaults for testing
                                    var phase = DG.getQueryParam('deprecationPhase');
                                    if (phase) return Number(phase);

                                    var currDate = new Date(),
                                        phase2Date = new Date(2016, 10, 15),
                                        phase3Date = new Date(2017, 0, 1);
                                    if (currDate >= phase3Date) return 3;
                                    if (currDate >= phase2Date) return 2;
                                    return 1;
                                  }()),
              "patch": true,
              "patchObjectHash": function(obj) {
                return obj.guid || JSON.stringify(obj);
              }
            },
            "localFile"//,
            //"localStorage"
          ]
        };
    // only enable Google Drive if origin is ssl or localhost
     if (document.location.protocol === 'https:' || document.location.hostname === 'localhost' || document.location.hostname === '127.0.0.1') {
      options.providers.splice(1, 0, {
        "name": "googleDrive",
        "mimeType": "application/json",
        "clientId": DG.get('googleDriveClientID'),
        "apiKey": DG.get('googleDriveAPIKey'),
        "appId": DG.get('googleDriveAppId'),
      });
     }
    if (DG.cfmConfigurationOverride) {
      options = Object.assign(options, DG.cfmConfigurationOverride);
    }
    iCloudFileManager.init(options);
  }

  /*
   * Resolve a single external document ID reference
   */
  function dataContextPromise(iDataContext) {
    return new Promise(function(resolve, reject) {
      // instantiate external document ID references
      var params = { recordid: iDataContext.externalDocumentId };
      if (DG.get('runKey')) {
        params.runKey = DG.get('runKey');
        var hashIndex = params.runKey.indexOf('#');
        if (hashIndex >= 0)
          params.runKey = params.runKey.substr(0, hashIndex);
      }
      if(iDataContext.externalDocumentId != null) {
        $.ajax({
          // external document references were only used with the
          // Concord Document Store
          url: '//document-store.concord.org/document/open',
          data: params,
          dataType: 'json',
          xhrFields: { withCredentials: true },
          success: function(iContents) {
            resolve(iContents);
          },
          error: function(jqXHR, textStatus, errorThrown) {
            reject(errorThrown || textStatus);
          }
        });
      }
      // standard data contexts can just be resolved
      else {
        resolve(iDataContext);
      }
    });
  }

  /*
   * Resolve any external document ID references
   */
  function docContentsPromise(iDocContents) {
    return new Promise(function(resolve, reject) {
      var dataContexts = iDocContents && iDocContents.contexts,
          dataContextPromises = dataContexts && dataContexts.map(function(iDataContext) {
                                  return dataContextPromise(iDataContext);
                                });
      // Once all external document references have been resolved...
      if (dataContextPromises) {
        Promise.all(dataContextPromises)
          .then(function(iResolvedDataContexts) {
                  // replace the array of pre-processed context objects
                  // with the array of resolved context promises
                  iDocContents.contexts = iResolvedDataContexts;
                  resolve(iDocContents);
                },
                function(iReason) {
                  reject(iReason);
                });
      }
      else {
        resolve(iDocContents);
      }
    });
  }

  function parseURL(url) {
    var a = document.createElement('a');
    a.href = url;
    return a;
  }
  /**
   * find expected content from mimeType or URL path extension
   * @param mimeType
   * @param url
   * @return mimeType
   */
  function getExpectedContentType(mimeType, url) {
    var extensionMap = {
      codap: 'application/vnd.codap+json',
      json: 'application/json',
      geojson: 'application/geo+json',
      csv: 'application/csv',
      txt: 'application/csv'
    };
    var parsedURL = url && parseURL(url);
    var path = parsedURL && parsedURL.pathname;
    if (mimeType) {
      return mimeType;
    }
    if (path) {
      return extensionMap[path.replace(/.*\./g, '')];
    }
  }

  function resolveDocument(iDocContents, iMetadata) {
    return new Promise(function (resolve, reject) {
      function makeEmptyDocument() {
        return {
          name: "Untitled Document",
          components: [],
          contexts: [],
          globals: [],
          appName: DG.APPNAME,
          appVersion: DG.VERSION,
          appBuildNum: DG.BUILD_NUM,
          lang: SC.Locale.currentLanguage
        };
      }
      function makePluginDocument(gameState, pluginName, pluginPath) {
        return {
          name: "Untitled Document",
          components: [
            {
              type: 'DG.GameView',
              document: DG.currDocumentController().content,
              layout: {
                isVisible: false
              },
              componentStorage: {
                currentGameName: pluginName,
                currentGameUrl: DG.get('pluginURL') + pluginPath,
                savedGameState: gameState
              }
            }
          ],
          contexts: [],
          globals: [],
          appName: DG.APPNAME,
          appVersion: DG.VERSION,
          appBuildNum: DG.BUILD_NUM,
          lang: SC.Locale.currentLanguage
        };
      }
      function makeCSVDocument(contents, urlString, datasetName) {
        var gameState = {
          contentType: 'text/csv',
          url: urlString,
          text: contents,
          datasetName: datasetName,
          showCaseTable: true
        };
        return makePluginDocument(gameState, 'Import CSV', '/Importer/');
      }
      function makeGeoJSONDocument(contents, urlString, datasetName) {
        var gameState = {
          contentType: 'application/geo+json',
          text: contents,
          name: urlString,
          datasetName: datasetName
        };
        return makePluginDocument(gameState, 'Import GeoJSON', '/Importer/');
      }
      var metadata = iMetadata || {};
      var urlString = metadata.url || ('file:' + metadata.filename);
      var expectedContentType = getExpectedContentType(metadata.contentType, urlString);
      var url = urlString && parseURL(urlString);
      var urlPath = url && url.pathname;
      var datasetName = urlPath?
          urlPath.replace(/.*\//g, '').replace(/\..*/, ''): 'data';
      var contentType;

      if (expectedContentType === 'application/json' || typeof iDocContents === 'object') {
        if (typeof iDocContents === 'string') {
          try {
            iDocContents = JSON.parse(iDocContents);
          }
          catch (ex) {
            reject('JSON parse error in "%@"'.fmt(urlString));
            return;
          }
        }
        if (iDocContents.appName != null &&
            iDocContents.appVersion != null) {
          contentType = 'application/vnd.codap+json';
        } else if (iDocContents.type &&
            (iDocContents.type === 'FeatureCollection' ||
                iDocContents.type === 'Topology')) {
          contentType = 'application/vnd.geo+json';
        }
      } else {
        contentType = expectedContentType;
      }

      // CFM: empty document contents => blank document associated with a particular Provider
      if (!iDocContents) {
        resolve(makeEmptyDocument());
      }
      else if (contentType === 'application/csv') {
        resolve(makeCSVDocument(iDocContents, urlString, datasetName));
      }
      else if (contentType === 'application/vnd.geo+json') {
        resolve(makeGeoJSONDocument(iDocContents, urlString, datasetName));
      }
      else if (contentType === 'application/vnd.codap+json') {
        docContentsPromise(iDocContents).then(
          function (contents) {
            // check if this is a valid CODAP document
            var docContents = validateDocument(iDocContents);
            if (!docContents) {
              reject('DG.AppController.openDocument.error.invalid_format'.loc());
            } else {
              resolve(docContents);
            }
          },
          function (message) {
            reject(message);
          }
        );
      }
      else {
        reject ('Error opening document: %@ -- unknown mime type: %@'
            .loc(urlString, contentType));
      }
    });
  }

  function syncProperty(iDstObj, iSrcObj, iProperty) {
    if(typeof(iSrcObj[iProperty]) !== "undefined")
      iDstObj[iProperty] = iSrcObj[iProperty];
    else
      delete iDstObj[iProperty];
  }

  function cfmShowUserEntryView() {

    var DialogContents = createReactClassFactory({
      close: function () {
        DG.cfmClient.hideBlockingModal();
      },
      authorizeUrlDocument: function () {
        DG.cfmClient.parseUrlAuthorizeAndOpen();
      },
      createNewDocument: function () {
        this.close();
        DG.cfmClient.newFile();
      },
      openDocument: function () {
        this.close();
        DG.cfmClient.openFileDialog();
      },
      componentDidMount: function() {
        this.refs.openButton.focus();
      },
      render: function () {
        var button = ReactDOMFactories.button,
            div = ReactDOMFactories.div;

        return div({onKeyDown: function(evt) {
                    // escape key
                    if (evt.keyCode === 27) this.createNewDocument();
                    // return/enter
                    else if (evt.keyCode === 13) this.openDocument();
                  }.bind(this)}, [
                div({style: {margin: 10}, key: 2},
                    button({ref: 'openButton', onClick: this.openDocument},
                            'DG.main.userEntryView.openDocument'.loc())),
                div({style: {margin: 10}, key: 1},
                    button({ref: 'newButton', onClick: this.createNewDocument},
                            'DG.main.userEntryView.newDocument'.loc()))
        ]);
      }
    });
    if (DG.get('showUserEntryView')) {
      DG.cfmClient.showBlockingModal({
        title: 'DG.main.userEntryView.title'.loc(),
        message: DialogContents({}), // jshint ignore:line
        onDrop: function () { DG.cfmClient.hideBlockingModal(); }}
      );
    }
  }

  function cfmConnect(iCloudFileManager) {
    var presaveChangeCount;
    var disableDirtySync = false;
    DG.cfm = iCloudFileManager;

    if (DG.cfm) {
      /*
       * @param event {object} Event properties:
       *     event.type  { 'closedFile' | 'connected' | 'getContent' | 'importedData' |
       *             'log' | 'newedFile' | 'openedFile' | 'ready' | 'renamedFile' |
       *             'savedFile' | 'sharedFile' | 'stateChanged' | 'unsharedFile' |
       *             'willOpenFile' }
       *     event.data {object}
       *     event.state {object}
       *     event.callback {function}
       *
       * These activities generate the following event streams:
       *   startup: connected, ready
       *   open file: willOpenFile, openedFile, ready
       *   save locally: getContent (2x), savedFile
       *   autosave: getContent, savedFile
       *   close document: closedFile
       *   import file: importedData
       */
      DG.cfm.clientConnect(function (event) {
        /* global _ */
        var docController, /*docContent, docMetadata,*/
            cfmSharedMetadata;

        function syncDocumentDirtyState() {
          !disableDirtySync && DG.cfmClient && DG.cfmClient.dirty(DG.currDocumentController().get('hasUnsavedChanges'));
        }

        function normalizeDocumentName(name) {
          return name?name.replace(/\.codap$/, '').replace(/\.json$/, ''): 'unknown';
        }

        // DG.log('CFM Event: ' + JSON.stringify({
        //   type: event.type,
        //   state: event.state && {
        //     dirty: event.state.dirty,
        //     failures: event.state.failures,
        //     metadata: event.state.metadata && {
        //       autoSaveDisabled: event.state.metadata.autoSaveDisabled,
        //       description: event.state.metadata.description,
        //       filename: event.state.metadata.filename,
        //       name: event.state.metadata.name,
        //       providerName: event.state.metadata.provider.name,
        //
        //       type: event.state.metadata.type,
        //       url: event.state.metadata.url
        //     },
        //     saved: event.state.saved
        //   }
        // }) );
        switch (event.type) {
          case 'connected':
            DG.cfmClient = event.data.client;
            DG.cfmClient.setProviderOptions("documentStore",
                                            {appName: DG.APPNAME,
                                             appVersion: DG.VERSION,
                                             appBuildNum: DG.BUILD_NUM
                                            });
            DG.cfmClient._ui.setMenuBarInfo("Version "+DG.VERSION+" ("+DG.BUILD_NUM+")");

            // synchronize document dirty state on document change
            DG.currDocumentController().addObserver('hasUnsavedChanges', function() {
              syncDocumentDirtyState();
            });

            if ( !SC.empty(DG.startingDocUrl)) {
              DG.cfmClient.openUrlFile(DG.startingDocUrl);
            }

            break;

          // hide the splash screen if CFM requires interaction with the user
          case 'requiresUserInteraction':
            SC.run(function() {
              DG.splash.hideSplash();
            });
            break;

          case "ready":
            if ( SC.empty(DG.startingDocUrl)) {
              cfmShowUserEntryView();
            }
            DG.splash.hideSplash();
            if (event.state.metadata && event.state.metadata.name) {
              DG.currDocumentController().set('documentName',
                  normalizeDocumentName(event.state.metadata.name));
            }
            break;

          case "closedFile":
            cfmShowUserEntryView();
            break;

          case 'getContent':
            DG.currDocumentController().captureCurrentDocumentState(true)
              .then(function(iContents) {
                var cfmSharedMetadata = event.data && event.data.shared || {},
                    docMetadata = iContents.metadata || {},
                    // validate before saving as well as when opening
                    contents = validateDocument(iContents);
                // We save the change count before save so, when the save is
                // complete, we can tell whether there were new changes requiring
                // an additional save.
                presaveChangeCount = DG.currDocumentController().get('changeCount');
                if (contents) {
                  // For now, _permissions must be stored at top-level for Document Store
                  syncProperty(contents, cfmSharedMetadata, '_permissions');
                  // replace 'shared' metadata property with object passed from CFM
                  docMetadata.shared = $.extend(true, {}, cfmSharedMetadata);
                  // combine shared metadata with content to pass back to caller
                  contents.metadata = docMetadata;
                }
                else {
                  DG.logUser("getContent: attempted to return invalid document!");
                }
                event.callback(contents);
              }, function (msg) {
                DG.log(msg);
              });
            break;

          case 'willOpenFile':
            SC.run(function() {
              DG.splash.showSplash();
            });
            break;

          case 'newedFile':
            SC.run(function() {
              DG.appController.closeAndNewDocument();
              DG.splash.hideSplash();
            });
            break;

          case 'openedFile':
            SC.run(function() {
              DG.splash.showSplash();
            });

            setTimeout(function() {
              SC.run(function() {
                DG.cfmClient.hideBlockingModal();
                if (event && event.state && event.state.metadata &&
                    event.state.metadata.provider &&
                    event.state.metadata.provider.name === 'localFile') {
                  event.data.metadata.filename = event.state.metadata.providerData.file.name;
                }
                resolveDocument(event.data.content, event.data.metadata)
                  .then(
                    function(iDocContents) {
                      SC.run(function () {
                        var metadata = event.data.content
                                        ? event.data.content.metadata
                                        : event.data.metadata,
                            sharedMetadata = metadata && metadata.shared,
                            cfmSharedMetadata = sharedMetadata
                                                  ? $.extend(true, {}, sharedMetadata)
                                                  : {};

                        // disable the dirty sync while the existing document is unloaded
                        // and the new document is loaded
                        disableDirtySync = true;
                        DG.appController.closeDocument();
                        DG.store = DG.ModelStore.create();
                        DG.currDocumentController()
                          .setDocument(DG.Document.createDocument(iDocContents));
                        DG.set('showUserEntryView', false);
                        // acknowledge successful open; return shared metadata
                        event.callback(null, cfmSharedMetadata);
                        disableDirtySync = false;
                      });
                    },  // then() error handler
                    function(iReason) {
                      DG.logWarn(iReason);
                      event.callback('DG.AppController.openDocument.error.general'.loc());
                      // we force the state to be clean to avoid the CFM overriding
                      // the file that failed to open with whatever was the previous
                      // document, then close the file.
                      event.state.dirty = false;
                      DG.cfmClient.closeFile();
                      disableDirtySync = false;
                    }
                  );
              });
            }, 0);
            break;

          case 'savedFile':
            SC.run(function() {
              if(DG.currDocumentController().get('changeCount') === presaveChangeCount) {
                // Marking CODAP document clean iff document hasn't changed since getContent()
                DG.currDocumentController().updateSavedChangeCount();
              }
              // synchronize document dirty state after saving, since we may not be clean
              syncDocumentDirtyState();

              // once the file has been saved, we no longer need the 'di'-related URL params
              DG.removeQueryParams(['di', 'di-override']);
            });
            break;

          case 'sharedFile':
            SC.run(function() {
              cfmSharedMetadata = (event.data && event.data.shared) || {};
              if(DG.appController.get('_undoRedoShareInProgressCount')) {
                DG.currDocumentController().set('sharedMetadata', cfmSharedMetadata);
              }
              else {
                DG.UndoHistory.execute(DG.Command.create({
                  name: 'document.share',
                  undoString: 'DG.Undo.document.share',
                  redoString: 'DG.Redo.document.share',
                  log: 'Shared document',
                  execute: function() {
                    var docSharedMetadata;
                    this._cfmSharedMetadata = $.extend(true, {}, cfmSharedMetadata);
                    this.causedChange = false;
                    if(!DG.appController.get('_undoRedoShareInProgressCount')) {
                      docSharedMetadata = DG.currDocumentController().get('sharedMetadata');
                      if(!_.isEqual(docSharedMetadata, cfmSharedMetadata)) {
                        DG.currDocumentController().set('sharedMetadata', cfmSharedMetadata);
                        this.causedChange = true;
                      }
                    }
                  },
                  undo: function() {
                    DG.appController.incrementProperty('_undoRedoShareInProgressCount');
                    DG.cfmClient.unshare(function() {
                      DG.appController.decrementProperty('_undoRedoShareInProgressCount');
                    });
                  },
                  redo: function () {
                    DG.appController.incrementProperty('_undoRedoShareInProgressCount');
                    DG.cfmClient.reshare(this._cfmSharedMetadata, function() {
                      DG.appController.decrementProperty('_undoRedoShareInProgressCount');
                    });
                  }
                }));
              }
            });
            break;

          case 'unsharedFile':
            SC.run(function() {
              docController = DG.currDocumentController();
              // docContent = docController && docController.get('content');
              // docMetadata = docContent && docContent.metadata;
              var docSharedMetadata = docController.get('sharedMetadata') || {};
              cfmSharedMetadata = (event.data && event.data.shared) || {};
              if(DG.appController.get('_undoRedoShareInProgressCount')) {
                DG.currDocumentController().set('sharedMetadata', cfmSharedMetadata);
              }
              else {
                DG.UndoHistory.execute(DG.Command.create({
                  name: 'document.unshare',
                  undoString: 'DG.Undo.document.unshare',
                  redoString: 'DG.Redo.document.unshare',
                  log: 'Unshared document',
                  execute: function() {
                    this.causedChange = false;
                    if(!DG.appController.get('_undoRedoShareInProgressCount')) {
                      docSharedMetadata = DG.currDocumentController().get('sharedMetadata');
                      this._orgSharedMetadata = $.extend(true, {}, docSharedMetadata);
                      if(!_.isEqual(docSharedMetadata, cfmSharedMetadata)) {
                        DG.currDocumentController().set('sharedMetadata', cfmSharedMetadata);
                        this.causedChange = true;
                      }
                    }
                  },
                  undo: function() {
                    DG.appController.incrementProperty('_undoRedoShareInProgressCount');
                    DG.cfmClient.reshare(this._orgSharedMetadata, function() {
                      DG.appController.decrementProperty('_undoRedoShareInProgressCount');
                    });
                  },
                  redo: function () {
                    DG.appController.incrementProperty('_undoRedoShareInProgressCount');
                    DG.cfmClient.unshare(function() {
                      DG.appController.decrementProperty('_undoRedoShareInProgressCount');
                    });
                  }
                }));
              }
            });
            break;

          case "importedData":
            SC.run(function() {
              if (event.data.file) {
                DG.appController.importFile(event.data.file.object);
              }
              else if (event.data.url && (event.data.via === "select")) {
                DG.appController.importURL(event.data.url, event.data.componentType, event.data.name);
              }
              else if (event.data.text && event.data.name) {
                DG.appController.importText(event.data.text, event.data.name);
              }
            });
            break;

          case "renamedFile":
            SC.run(function() {
              var document = DG.currDocumentController();
              var name = event.state.metadata.name;
              document.set('documentName', name);
            });
            break;

          case "log":
            SC.run(function() {
              if (event.data.logEvent === "logLaraData") {
                handleLogLaraData(event.data.logEventData);
              }
            });
            break;
        }
      });

      // Add CFM-specific global functions
      DG.exportFile = function(data, extension, mimetype, callback) {
        DG.cfmClient.saveSecondaryFileAsDialog(data, extension, mimetype, callback);
      };
    }
  }

  DG.splash.showSplash();

  if (DG.get('embeddedMode') === 'yes') {
    $('html').addClass('dg-embedded-mode');

    startEmbeddedServer();
    translateQueryParameters();
  }
  else {
    // only start embedded server if embeddedMode is not on
    if (DG.get('embeddedServer') === 'yes') {
      startEmbeddedServer();
    }
    translateQueryParameters();
  }

  // Load the CFM library and configure the CFM once the
  // library is loaded and the views are configured.
  Promise.all([cfmLoaded(), DG.cfmViewConfig]).then(
    function(iValues) {
      /* global CloudFileManager */
      var viewConfig = iValues[1];
      cfmInit(CloudFileManager, viewConfig);
      cfmConnect(CloudFileManager);
    });
  /* end CFM load/configuration */
};

/* exported main */
window.main = function() {
  DG.main();
  // This Kludge causes the mainPage to get the window's height. Without, it will _sometimes_
  // be the wrong height, apparently because of something to do with timing.
  DG.mainPage.invokeLater( function() {
    DG.mainPage.mainPane.adjust({height: window.innerHeight});
    DG.mainPage.invokeLater( function() {
      DG.mainPage.mainPane.adjust({height: null});
    }, 20);
  },2000);
};


